(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  10647659,     401402]*)
(*NotebookOutlinePosition[  10648338,     401425]*)
(*  CellTagsIndexPosition[  10648294,     401421]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Riemann Sum Plot", "Title"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["A Riemann Sum Plot", "Subsection"],

Cell["\<\
You may wish to enlarge the Help window to full screen size to better view \
the graphics.\
\>", "Text"],

Cell["\<\
A customary topic in calculus courses is the approximation of an area \
integral by a Riemann sum.  Here I show how to generate a graphic for a \
Riemann sum. First, we need a routine to generate a Riemann partition. To \
generate a random partition of n regions, we generate n random numbers \
between 0.3 and 1. (I didn't want the intervals to get too small.)  We then \
form a running sum and scale the resulting array to fit between a and b. The \
norm, being the maximum partition interval, is also calculated and \
returned.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RiemannPartition[n_, a_, 
        b_] := \[IndentingNewLine]Module[{partition, 
          norm}, \[IndentingNewLine]partition = 
          FoldList[Plus, 0, 
            Table[Random[
                Real, {0.3, 1}], {n}]]; \[IndentingNewLine]partition = 
          a + partition \((b - a)\)/
                Last[partition]; \[IndentingNewLine]norm = 
          Max[Abs /@ 
              Drop[RotateLeft[partition, 1] - 
                  partition, \(-1\)]]; \[IndentingNewLine]{norm, 
          partition}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(partition\\)\\\" is similar to existing \
symbol \\\"\\!\\(Partition\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(norm\\)\\\" is similar to existing symbol \\\
\"\\!\\(Norm\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell["This generates 5 random sized intervals between 1 and 2.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RiemannPartition[5, 1, 2]\)], "Input"],

Cell[BoxData[
    \({0.30014365102761653`, {1, 1.3001436510276165`, 1.4392704312585576`, 
        1.6016363310963224`, 1.7796808340156383`, 2.`}}\)], "Output"]
}, Open  ]],

Cell["\<\
For the Riemann sum plot, I create a piece of paper with a Rectangle. The \
Riemann plot itself is put into the Rectangle and the rest of the paper is \
used to display information about the calculation. The routine first \
calculates a partition. It then picks random points, xpoints, within each \
partition interval. It then calculates the function values, ypoints, at those \
points. The exact value of the integral, and the Riemann sum are then \
calculated.\
\>", "Text"],

Cell["\<\
For the Riemann plot itself, each of the rectangles is drawn in LightBlue if \
the area is positive and in MistyRose if it is negative. The rectangles are \
then outlined in Peacock or Peru. The reason these colors are used, instead \
of Black, is to give a nice picture when the partition becomes very fine. The \
Riemann plot is defined with a DontShow statement to suppress the extra plot.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RiemannSumPlot[f_, {xmin_, xmax_}, 
        nn_] := \[IndentingNewLine]Module[{n = Floor[nn], partition, norm, 
          xpoints, ypoints, riemannplot, integral, riemannsum, 
          rectanglei}, \[IndentingNewLine]{norm, partition} = 
          RiemannPartition[n, xmin, xmax]; \[IndentingNewLine]xpoints = 
          Table[Random[
              Real, {partition\[LeftDoubleBracket]i - 1\[RightDoubleBracket], 
                partition\[LeftDoubleBracket]i\[RightDoubleBracket]}], {i, 2, 
              n + 1}]; \[IndentingNewLine]ypoints = 
          f /@ xpoints; \[IndentingNewLine]integral = 
          N[Integrate[
              f[x], {x, xmin, xmax}]]; \[IndentingNewLine]riemannsum = 
          Sum[\((partition\[LeftDoubleBracket]i + 1\[RightDoubleBracket] - 
                  partition\[LeftDoubleBracket]i\[RightDoubleBracket])\) 
              ypoints\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 1, 
              n}]; \[IndentingNewLine]\[IndentingNewLine]riemannplot = 
          DontShow[
            Graphics[\n\t\t{Table[{If[
                      ypoints\[LeftDoubleBracket]
                          i\[RightDoubleBracket] \[GreaterEqual] 0, 
                      LightBlue, MistyRose], 
                    rectanglei = 
                      Polygon[{{partition\[LeftDoubleBracket]
                              i\[RightDoubleBracket], 
                            0}, {partition\[LeftDoubleBracket]
                              i\[RightDoubleBracket], 
                            ypoints\[LeftDoubleBracket]
                              i\[RightDoubleBracket]}, {partition\
\[LeftDoubleBracket]i + 1\[RightDoubleBracket], 
                            ypoints\[LeftDoubleBracket]
                              i\[RightDoubleBracket]}, {partition\
\[LeftDoubleBracket]i + 1\[RightDoubleBracket], 0}}], 
                    If[ypoints\[LeftDoubleBracket]
                          i\[RightDoubleBracket] \[GreaterEqual] 0, Peacock, 
                      Peru], rectanglei /. Polygon \[Rule] Line}, {i, 1, 
                    n}], \[IndentingNewLine]Line[{{xmin, 0}, {xmax, 
                      0}}], \[IndentingNewLine]AbsolutePointSize[4], 
                Table[Point[{xpoints\[LeftDoubleBracket]
                        i\[RightDoubleBracket], 
                      ypoints\[LeftDoubleBracket]
                        i\[RightDoubleBracket]}], {i, 1, 
                    n}], \[IndentingNewLine]Blue, 
                Draw[f[x], {x, xmin, xmax}]}], \n
            AspectRatio \[Rule] 1/GoldenRatio, PlotRange \[Rule] All, 
            Background \[Rule] LightYellow, \n{Frame \[Rule] True, 
              PlotRegion \[Rule] {{0, 0.97}, {0, 
                    0.95}}}]; \[IndentingNewLine]\[IndentingNewLine]Show[
          Graphics[{Rectangle[{0.5, 3}, {9.5, 8.56}, 
                riemannplot], \[IndentingNewLine]Text[
                SequenceForm["\<Riemann Sum for \>", f[x]], {5, 
                  9.25}], \[IndentingNewLine]Text[
                SequenceForm[\*"\"\<\!\(x\_min\) = \>\"", xmin], {0.5, 
                  2.7}, {\(-1\), 0}], \[IndentingNewLine]Text[
                SequenceForm[\*"\"\<\!\(x\_max\) = \>\"", xmax], {0.5, 
                  2.4}, {\(-1\), 0}], \[IndentingNewLine]Text[
                SequenceForm["\<Partitions = \>", n], {5, 2.7}, {\(-1\), 
                  0}], \[IndentingNewLine]Text[
                SequenceForm["\<Partition Norm = \>", norm], {5, 
                  2.4}, {\(-1\), 0}], \[IndentingNewLine]Text[
                SequenceForm["\<Integral    = \>", integral], {0.5, 
                  2}, {\(-1\), 0}], \[IndentingNewLine]Text[
                SequenceForm["\<Riemann Sum = \>", riemannsum], {0.5, 
                  1.7}, {\(-1\), 
                  0}]}], \[IndentingNewLine]AspectRatio \[Rule] 
            Automatic, \[IndentingNewLine]PlotRange \[Rule] {{0, 10}, {1, 
                10}}, \[IndentingNewLine]TextStyle \[Rule] {FontSize \[Rule] 
                12, FontWeight \[Rule] "\<Bold\>"}, \
\[IndentingNewLine]Background \[Rule] 
            Linen, \[IndentingNewLine]ImageSize \[Rule] 
            600]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(ypoints\\)\\\" is similar to existing symbol \
\\\"\\!\\(xpoints\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[TextData[{
  "This displays a specific Riemann sum for ",
  Cell[BoxData[
      \(Sin[x]\)]],
  " over the range ",
  Cell[BoxData[
      \(\(-\[Pi]\) \[LessEqual] x \[LessEqual] \[Pi]\)]],
  " with 20 intervals. Each time the statement is evaluated, a new partition \
will be used."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(RiemannSumPlot[Sin, {\(-\[Pi]\), \[Pi]}, 20];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.5 0.151576 0.309018 0.294303 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -12 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(-1)] -0.0125 .01471 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .30902 m
.02381 .28346 L
.05965 .28346 L
.05965 .30902 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .30902 m
.02381 .28346 L
.05965 .28346 L
.05965 .30902 L
s
1 .894 .882 r
.05965 .30902 m
.05965 .2237 L
.09975 .2237 L
.09975 .30902 L
F
.804 .522 .247 r
.05965 .30902 m
.05965 .2237 L
.09975 .2237 L
.09975 .30902 L
s
1 .894 .882 r
.09975 .30902 m
.09975 .15013 L
.14018 .15013 L
.14018 .30902 L
F
.804 .522 .247 r
.09975 .30902 m
.09975 .15013 L
.14018 .15013 L
.14018 .30902 L
s
1 .894 .882 r
.14018 .30902 m
.14018 .09428 L
.17075 .09428 L
.17075 .30902 L
F
.804 .522 .247 r
.14018 .30902 m
.14018 .09428 L
.17075 .09428 L
.17075 .30902 L
s
1 .894 .882 r
.17075 .30902 m
.17075 .05544 L
.2454 .05544 L
.2454 .30902 L
F
.804 .522 .247 r
.17075 .30902 m
.17075 .05544 L
.2454 .05544 L
.2454 .30902 L
s
1 .894 .882 r
.2454 .30902 m
.2454 .03274 L
.32194 .03274 L
.32194 .30902 L
F
.804 .522 .247 r
.2454 .30902 m
.2454 .03274 L
.32194 .03274 L
.32194 .30902 L
s
1 .894 .882 r
.32194 .30902 m
.32194 .06531 L
.35376 .06531 L
.35376 .30902 L
F
.804 .522 .247 r
.32194 .30902 m
.32194 .06531 L
.35376 .06531 L
.35376 .30902 L
s
1 .894 .882 r
.35376 .30902 m
.35376 .07155 L
.38732 .07155 L
.38732 .30902 L
F
.804 .522 .247 r
.35376 .30902 m
.35376 .07155 L
.38732 .07155 L
.38732 .30902 L
s
1 .894 .882 r
.38732 .30902 m
.38732 .12591 L
.44122 .12591 L
.44122 .30902 L
F
.804 .522 .247 r
.38732 .30902 m
.38732 .12591 L
.44122 .12591 L
.44122 .30902 L
s
1 .894 .882 r
.44122 .30902 m
.44122 .28796 L
.49222 .28796 L
.49222 .30902 L
F
.804 .522 .247 r
.44122 .30902 m
.44122 .28796 L
.49222 .28796 L
.49222 .30902 L
s
.678 .847 .902 r
.49222 .30902 m
.49222 .39068 L
.55569 .39068 L
.55569 .30902 L
F
.2 .63 .79 r
.49222 .30902 m
.49222 .39068 L
.55569 .39068 L
.55569 .30902 L
s
.678 .847 .902 r
.55569 .30902 m
.55569 .45708 L
.5817 .45708 L
.5817 .30902 L
F
.2 .63 .79 r
.55569 .30902 m
.55569 .45708 L
.5817 .45708 L
.5817 .30902 L
s
.678 .847 .902 r
.5817 .30902 m
.5817 .52779 L
.65212 .52779 L
.65212 .30902 L
F
.2 .63 .79 r
.5817 .30902 m
.5817 .52779 L
.65212 .52779 L
.65212 .30902 L
s
.678 .847 .902 r
.65212 .30902 m
.65212 .57353 L
.69167 .57353 L
.69167 .30902 L
F
.2 .63 .79 r
.65212 .30902 m
.65212 .57353 L
.69167 .57353 L
.69167 .30902 L
s
.678 .847 .902 r
.69167 .30902 m
.69167 .59177 L
.75466 .59177 L
.75466 .30902 L
F
.2 .63 .79 r
.69167 .30902 m
.69167 .59177 L
.75466 .59177 L
.75466 .30902 L
s
.678 .847 .902 r
.75466 .30902 m
.75466 .59052 L
.78669 .59052 L
.78669 .30902 L
F
.2 .63 .79 r
.75466 .30902 m
.75466 .59052 L
.78669 .59052 L
.78669 .30902 L
s
.678 .847 .902 r
.78669 .30902 m
.78669 .55875 L
.83257 .55875 L
.83257 .30902 L
F
.2 .63 .79 r
.78669 .30902 m
.78669 .55875 L
.83257 .55875 L
.83257 .30902 L
s
.678 .847 .902 r
.83257 .30902 m
.83257 .5412 L
.87459 .5412 L
.87459 .30902 L
F
.2 .63 .79 r
.83257 .30902 m
.83257 .5412 L
.87459 .5412 L
.87459 .30902 L
s
.678 .847 .902 r
.87459 .30902 m
.87459 .46676 L
.92178 .46676 L
.92178 .30902 L
F
.2 .63 .79 r
.87459 .30902 m
.87459 .46676 L
.92178 .46676 L
.92178 .30902 L
s
.678 .847 .902 r
.92178 .30902 m
.92178 .33794 L
.97619 .33794 L
.97619 .30902 L
F
.2 .63 .79 r
.92178 .30902 m
.92178 .33794 L
.97619 .33794 L
.97619 .30902 L
s
0 0 0 r
.02381 .30902 m
.97619 .30902 L
s
4 Mabswid
.03699 .28346 Mdot
.06839 .2237 Mdot
.11025 .15013 Mdot
.14777 .09428 Mdot
.18122 .05544 Mdot
.31522 .03274 Mdot
.35211 .06531 Mdot
.35769 .07155 Mdot
.39821 .12591 Mdot
.48914 .28796 Mdot
.54262 .39068 Mdot
.57991 .45708 Mdot
.62703 .52779 Mdot
.6693 .57353 Mdot
.6955 .59177 Mdot
.78296 .59052 Mdot
.82261 .55875 Mdot
.8384 .5412 Mdot
.89045 .46676 Mdot
.96127 .33794 Mdot
0 0 1 r
.5 Mabswid
.02381 .30902 m
.06244 .23481 L
.10458 .15951 L
.14415 .09914 L
.18221 .05447 L
.20178 .03757 L
.21267 .03011 L
.22272 .0245 L
.23293 .02007 L
.23832 .01827 L
.24402 .01676 L
.24641 .01625 L
.24897 .01579 L
.25119 .01545 L
.25361 .01516 L
.25507 .01501 L
.25643 .01491 L
.25773 .01483 L
.2584 .01479 L
.25912 .01476 L
.25983 .01474 L
.26048 .01473 L
.26176 .01472 L
.26293 .01472 L
.26416 .01475 L
.26538 .01479 L
.26607 .01483 L
.26671 .01486 L
.26912 .01505 L
.27131 .01528 L
.27364 .0156 L
.27847 .01647 L
.2838 .01778 L
.29326 .02099 L
.30213 .02502 L
.32232 .03778 L
.34082 .05371 L
.38045 .10022 L
.41855 .15838 L
.45911 .23059 L
.49816 .30545 L
.53966 .38514 L
.57964 .45663 L
.61811 .51582 L
.63759 .54096 L
.65902 .56418 L
.67938 .58152 L
.69843 .5933 L
.70884 .59785 L
.71396 .5996 L
Mistroke
.71872 .60092 L
.72301 .60186 L
.72758 .60261 L
.7302 .60292 L
.73148 .60304 L
.73266 .60313 L
.73371 .6032 L
.73487 .60325 L
.73603 .60329 L
.73725 .60332 L
.73856 .60332 L
.73977 .6033 L
.7404 .60329 L
.7411 .60326 L
.74251 .6032 L
.74375 .60312 L
.74508 .60301 L
.74748 .60276 L
.74985 .60244 L
.75235 .60202 L
.7568 .60108 L
.76198 .59967 L
.7668 .59806 L
.77773 .59332 L
.78828 .58734 L
.79823 .58046 L
.81683 .5645 L
.85534 .51958 L
.89632 .45703 L
.93577 .38657 L
.97371 .31383 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -142.25 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
(for) show
178.375 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.000 moveto
0.000 0.000 rmoveto
178.375 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sin) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
199.938 15.000 moveto
(@) show
207.125 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Mathematica2Mono-Bold
%%IncludeFont: Mathematica2Mono-Bold
/Mathematica2Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
214.313 15.000 moveto
(D) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
115.563 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.504941) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.176854) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000@0n_3V1P0000030?[`iP800000103jl>H3000000@0n_3V0`0000040?[`iP<0
0000103jl>H400000?l0n_3VW03jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP8000001P3j
l>H2000000D0n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V00<000000?[`iP3jl>H00P0000040?[`iP800000o`3jl>JM0?[`iP40oooo000P
0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V
0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0
n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002`3jl>H2000000D0n_3V0P00
00030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000D0n_3V0P00
00000`3jl>H000000000000400000?l0n_3VW03jl>H10?ooo`00803jl>H5000000@0n_3V0P000003
0?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<00000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<00000
0`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD0
00002P3jl>H2000000030?[`iP000000000000/0n_3V0P0000050?[`iP8000000`3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000050?[`iP80000000@0n_3V0000003j
l>H0n_3V0P00003o0?[`iYd0n_3V0@3oool00200n_3V0P0000020?[`iP8000000`3jl>H2000000<0
n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`000004
0?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P00
00000`3jl>H000000000000;0?[`iP8000001P3jl>H200000080n_3V100000040?[`iP<000000`3j
l>H00`000000n_3V0?[`iP0200000080n_3V00@000000?[`iP0000000000o`3jl>JM0?[`iP40oooo
000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP00
0000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`00
00000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H000000000000;0?[`iP8000001P3j
l>H200000080n_3V0P0000050?[`iP80000000<0n_3V0000000000000P3jl>H4000000<0n_3V00@0
00000?[`iP0000000000o`3jl>JM0?[`iP40oooo000P0?[`iP8000000P3jl>H2000003<0n_3V0P00
00030?[`iP030000003jl>H0n_3V02D0n_3V0P0000000`3jl>H00000000000090?[`iP@000000`3j
l>H00`000000n_3V0?[`iP02000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3j
l>H2000000H0n_3V0`00003o0?[`iYd0n_3V0@3oool001l0n_3V1P0000040?[`iP800000;`3jl>H5
000002P0n_3V0`00000<0?[`iP8000000`3jl>H5000000@0n_3V0`0000030?[`iP<000000`3jl>H5
000000@0n_3V0P00003o0?[`iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40oooo0010
0?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200n_3V1P0000001@3jl>H00000000000000000
n_3V00<000000P3jl>H3000000<0n_3V100000030?[`iP80000000@0n_3V000000000000n_3V1@00
00030?[`iP`00000;`3jl>H3000000@0n_3V0P00003o0?[`i/T0n_3V0@3oool00280n_3V0P000004
0?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V00@000000?[`iP00000000000`3j
l>H01@000000n_3V000000000000n_3V00<000000P3jl>H2000000@0n_3V0P0000020?[`iP800000
0`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000000000000`3jl>H200000?l0n_3V
b@3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103j
l>H2000000D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3j
l>H200000300n_3V0P0000000`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V0P000004
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V1P0000000`3jl>H0000000000002
0?[`iP8000000P3jl>H2000000D0n_3V1@0000030?[`iP8000008P3jl>H5000000T0n_3V0P000000
0`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000
000000000P3jl>H2000000@0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0`000002
0?[`iP<0000000<0n_3V0000003jl>H0103jl>H2000000<0n_3V0P00000`0?[`iP80000000<0n_3V
000000000000o`3jl>K>0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080n_3V1@0000030?[`
iP@000000`3jl>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H40000
00@0n_3V0P00000`0?[`iP80000000<0n_3V000000000000o`3jl>K>0?[`iP40oooo000R0?[`iP80
00002`3jl>H200000280n_3V0P00000`0?[`iP80000000<0n_3V000000000000o`3jl>K>0?[`iP40
oooo000P0?[`iPH000002@3jl>H200000200n_3V1000000a0?[`iP<00000o`3jl>K?0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3V
o`3jl>HS0?[`iP40oooo000W0?[`iP040000003jl>H000000?[`iP8000000P3jl>H00`000000n_3V
0?[`iP0300000?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P00
00001@3jl>H000000?[`iP000000n_3V00<000000P3jl>H00`000000n_3V0000000F0?[`iP800000
103jl>H200000=X0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<00000
0P3jl>H600000080n_3V100000020?[`iP<0000000@0n_3V0000000000000000203jl>H400000003
0?[`iP00000000000080n_3V100000020?[`iPD0000000L0n_3V00000000000000000?[`iP000000
n_3V00<00000603jl>H3000000@0n_3V0P0000050?[`iP<00000103jl>H3000000@0n_3V10000002
0?[`iP<000001@3jl>H400000080n_3V1P00001g0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000
000000001@000000103jl>H000000000000000020?[`iP80000000<0n_3V0000000000002@3jl>H5
000000P0n_3V0P0000020?[`iP800000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2
000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@0
00000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H00000
0000000:0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`iP800000
103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000
000000030?[`iP800000103jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H00000
000000040?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000N@3jl>H10?ooo`008P3j
l>H3000002L0n_3V0P0000020?[`iP800000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3j
l>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3j
l>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V0000000000000000
0?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V00800000
603jl>H2000000030?[`iP000000000000`0n_3V0P0000020?[`iP80000000@0n_3V000000000000
n_3V1P0000050?[`iP80000000<0n_3V000000000000100000040?[`iP800000N@3jl>H10?ooo`00
8P3jl>H3000001X0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H4000000<0n_3V
1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V
0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H00000
000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003j
l>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000`0n_3V0P0000020?[`iP80
000000D0n_3V000000000000n_3V000000020?[`iP800000103jl>H4000000040?[`iP000000n_3V
0?[`iP8000001@3jl>H2000007T0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W0?[`
iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`
iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP<0000000@0n_3V
000000000000n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0080000000<0
n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H00`000000n_3V0?[`
iP0200000080n_3V0P0000000`3jl>H00000000000020?[`iP040000003jl>H00000000000<0n_3V
0P0000000`3jl>H00000000000020?[`iP040000003jl>H00000000000D0n_3V0P00001i0?[`iP40
oooo000P0?[`iP<0000000@0n_3V0000000000000000903jl>H900000=X0n_3V0P0000000`3jl>H0
0000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H40000
00<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0n_3V0000
000000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3j
l>H00000000000090?[`iP@000000`3jl>H2000000030?[`iP00000000000080n_3V00@000000?[`
iP00000000000`3jl>H2000000030?[`iP00000000000080n_3V00@000000?[`iP00000000001@3j
l>H2000007T0n_3V0@3oool00?l0n_3V;`3jl>H2000000030?[`iP00000000000100n_3V0P00000<
0?[`iP8000008P3jl>H200000080n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H2
000000D0n_3V0P0000000`3jl>H00000000000030?[`iP<000000`3jl>H2000000030?[`iP000000
000000<0n_3V0`0000030?[`iP@00000N@3jl>H10?ooo`00o`3jl>H^0?[`iPD000004@3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H2000001T0n_3V0`0000000`3jl>H00000000000020000
02h0n_3V0`00000:0?[`iPD000000`3jl>H3000000D0n_3V0P0000040?[`iP<000001@3jl>H20000
00D0n_3V0P00001i0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP000000
00000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`iP0000000P3jl>H0
10000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P
0?[`iP<0000000<0n_3V0000000000000P000000103jl>H000000?[`iP0000020?[`iP040000003j
l>H0n_3V00000080n_3V00<000000?[`iP3jl>H0703jl>H2000000@0n_3V0P00003B0?[`iP@00000
103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@00000
0P3jl>H3000000030?[`iP000000000000H000006P3jl>H5000000<0n_3V0`0000310?[`iP40oooo
000Q0?[`iP80000000<0n_3V0000000000001@0000001@3jl>H00000000000000000n_3V00@00000
2`3jl>H500000100n_3V0P0000020?[`iP800000e03jl>H2000000@0n_3V0P0000020?[`iP800000
0P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080
n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103j
l>H000000000003jl>H200000080n_3V0P00000;0?[`iPD000002@3jl>H2000000D0n_3V0P000000
0`3jl>H00000000000300?[`iP40oooo000R0?[`iP<00000:03jl>H500000080n_3V0P0000020?[`
iP800000e03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`
iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3j
l>H00000000000030?[`iP@000006P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000300?[`
iP40oooo000R0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000004@3jl>H200000003
0?[`iP00000000000=@0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H0
00000000003jl>H4000000d0n_3V1@00000;0?[`iP8000000`3jl>H2000000030?[`iP0000000000
0<00n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000_0?[`iP80000000<0n_3V00000000
0000e03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003j
l>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000L0?[`iP8000000P3jl>H2
000000030?[`iP00000000000<00n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000/
0?[`iPT00000dP3jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V
000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3j
l>H5000000<0n_3V1@00000I0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000<00n_3V0@3oool00?l0n_3V;`3jl>H2000000030?[`iP00000000000100n_3V0P00000<
0?[`iP800000>03jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000030
0?[`iP40oooo003o0?[`iRh0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`
iP800000<@3jl>H3000000@0n_3V0`0000310?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`007@3jl>Hi0?ooh0800000A`3oon04000004H0oooP1@000013
0?ooh0800000A`3oon05000004D0oooP100000160?ooh0800000:@3oon0N0?[`iP40oooo000M0?[`
iSP0oooP00@000000?ooh03oon000000AP3oon000`000000oooP0?ooh0190?ooh0030000003oon00
oooP0480oooP00@000000?ooh03oon000000B03oon000`000000oooP0?ooh0150?ooh0030000003o
on00oooP04H0oooP00@000000?ooh03oon000000:03oon0N0?[`iP40oooo000M0?[`iSX0oooP00<0
00000?ooh03oon00AP3oon000`000000oooP0?ooh0180?ooh0030000003oon00oooP0480oooP00@0
00000?ooh03oon000000B03oon000`000000oooP0?ooh0160?ooh0030000003oon00oooP04L0oooP
00<000000?ooh03oon009`3oon0N0?[`iP40oooo000M0?[`iS80oooP100000050?ooh0030000003o
on00oooP03h0oooP100000040?ooh0030000003oon00oooP03l0oooP100000040?ooh0030000003o
on00oooP0480oooP00@000000?ooh03oon000000B03oon000`000000oooP0?ooh0170?ooh0030000
003oon00oooP04L0oooP00<000000?ooh03oon009P3oon0N0?[`iP40oooo000M0?[`iSP0oooP00@0
00000?ooh03oon000000AP3oon0010000000oooP0?ooh00000180?ooh0030000003oon00oooP0480
oooP00@000000?ooh03oon000000B03oon000`000000oooP0?ooh0150?ooh0040000003oon00oooP
000004D0oooP00@000000?ooh03oon000000:03oon0N0?[`iP40oooo000M0?[`iST0oooP0P000018
0?ooh0800000B03oon02000004D0oooP0P0000180?ooh0800000B03oon02000004L0oooP0P00000Y
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`iR40oooPo`00003Z00000180oooP7P3j
l>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP00@0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00;0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00/0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00;0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00/0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00;0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00/0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon002`3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00D0oooP00<000000?ooh03oon00403oon0N
0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00103oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00/0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon002`3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00/0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon002`3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00/0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon002`3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00;0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon001@3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00C0?ooh0030000003oon00oooP04L0
oooP00<000000?ooh03oon00A`3oon000`000000oooP0?ooh0170?ooh0030000003oon00oooP04L0
oooP00<000000?ooh03oon00A`3oon000`000000oooP0?ooh0160?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00
o`3oon3V0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003o
on00oooP0?l0oooPiP3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V5P3oon05
000000H0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP0100oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon3V0?oo
h0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00H0
oooP1000001d0?ooh140003oo`3oon1M0?ooh0@000004P3oon0N0?[`iP40oooo000M0?[`iQ00oooP
100000040?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00L@3oon040000oa40oooP
0`000?oo0?ooh5d0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon001P3oon000`000000oooP0?ooh01^0?ooh0<0003o603oon020000ool0oooPF`3o
on000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V5`3oon02000000P0oooP00<00000
0?ooh03oon00K03oon020000oad0oooP0P000?oo0?ooh5T0oooP00<000000?ooh03oon00403oon0N
0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00JP3oon020000ob40oooP0P000?oo0?oo
h5L0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03o
on00J03oon020000obD0oooP0P000?oo0?ooh5D0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP00<000000?ooh03oon00IP3oon020000obT0oooP0P000?oo0?ooh5<0oooP
00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00I@3o
on000`000?l0oooP0?ooh00[0?ooh080003o00<0oooP000000000000o`3oon1>0?ooh0030000003o
on00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP06@0oooP00<0003o
0?ooh03oon003P3oon0P0<f5?`040000o`000000000000000080cHDoo`3oon1;0?ooh0030000003o
on00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0680oooP0P000?lA
0?ooh0030<f5?`3oi>40onCQ01d0onCQ00H000000000o`000?l000000?oTh@3=QCoo0?ooh4/0oooP
00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00H@3o
on000`000?l0oooP0?ooh00A0?ooh0030<f5?`3oi>40onCQ01h0onCQ0P0000020000o`030<f5?`3o
on00oooP0?l0oooPB@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon00
0`000000oooP0?ooh01P0?ooh0030000o`3oon00oooP0180oooP00<0cHDo0?oTh@3oi>408P3oi>40
0`000?l0oooP0?ooh03o0?ooh4T0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`
iR40oooP00<000000?ooh03oon00G`3oon000`000?l0oooP0?ooh00C0?ooh0030<f5?`3oi>40onCQ
0280onCQ00<0cHDo0000o`3oon00o`3oon190?ooh0030000003oon00oooP0100oooP7P3jl>H10?oo
o`007@3jl>HQ0?ooh0030000003oon00oooP05d0oooP0P000?lF0?ooh0030<f5?`3oi>40onCQ0280
onCQ00<0cHDo0?ooh0000?l0o`3oon190?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`00
7@3jl>HQ0?ooh0<00000G03oon000`000?l0oooP0?ooh00F0?ooh0030<f5?`3oi>40onCQ0280onCQ
00@0cHDo0?ooh03oon00003oo`3oon160?ooh0<000004P3oon0N0?[`iP40oooo000M0?[`iR40oooP
00<000000?ooh03oon00F`3oon000`000?l0oooP0?ooh00G0?ooh0030<f5?`3oi>40onCQ0280onCQ
00@0cHDo0?ooh03oon00oooP0P000?oo0?ooh4H0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP00<000000?ooh03oon00FP3oon000`000?l0oooP0?ooh00H0?ooh0030<f5
?`3oi>40onCQ0280onCQ00<0cHDo0?ooh03oon000`3oon000`000?l0oooP0?ooh03o0?ooh4<0oooP
00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00F03o
on020000oa/0oooP00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0oooP0?ooh0040?ooh0030000o`3o
on00oooP0?l0oooP@P3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon00
0`000000oooP0?ooh01E0?ooh080000000<0003o0?ooh03oon006`3oon000`3=QCl0onCQ0?oTh@0R
0?oTh@030<f5?`3oon00oooP00D0oooP00<0003o0?ooh03oon00o`3oon110?ooh0030000003oon00
oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0500oooP103=QCl20000
00030000o`000000cHDo01d0cHDo903oi>400`3=QCl0oooP0?ooh0060?ooh0030000o`3oon00oooP
0?l0oooP@03oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000
oooP0?ooh01@0?ooh0060<f5?`3oi>40onCQ0?oTh@000000003o0P00000M0?oTh@030<f5?`3oi>40
onCQ0280onCQ00<0cHDo0?ooh03oon001`3oon000`000?l0oooP0?ooh03o0?ooh3l0oooP00<00000
0?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00D03oon001@3=
QCl0onCQ0?oTh@3oi>40003o008000007P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oon00
oooP00P0oooP00<0003o0?ooh03oon00o`3oon0n0?ooh0030000003oon00oooP0100oooP7P3jl>H1
0?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0500oooP00@0cHDo0?oTh@3oi>40003o8@3oi>40
0`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oon00oooP00T0oooP00<0003o0?ooh03oon00o`3oon0m
0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP
0500oooP00@0cHDo0?oTh@3oi>40003o8@3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oon00
oooP00X0oooP00<0003o000000000000o`3oon0l0?ooh0030000003oon00oooP0100oooP7P3jl>H1
0?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0500oooP00<0cHDo0?oTh@000?l08P3oi>400`3=
QCl0onCQ0?oTh@0R0?oTh@d0cHDo00@000000000o`0000000000o`3oon0k0?ooh0030000003oon00
oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0500oooP00<0cHDo0000
o`3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00X0onCQ00@000000000
o`0000000000o`3oon0k0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?oo
h0030000003oon00oooP0500oooP00<0003o0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oT
h@030<f5?`3oi>40onCQ00/0onCQ00<000000000o`3=QCl00P00003o0?ooh3T0oooP00<000000?oo
h03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00C`3oon000`000?l0
cHDo0?oTh@0S0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>4010000?l0
000000000000000=0<f5?ol0oooP:`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0
n_3V8@3oon03000004h0oooP00<0003o0?ooh03=QCl0903oi>400`3=QCl0onCQ0?oTh@0R0?oTh@03
0<f5?`3oi>40onCQ00d0onCQ00@000000000o`0000000000303oi>400`3=QCl0oooP0?ooh03o0?oo
h2L0oooP0`00000B0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh01=0?ooh004
0000o`3oon00oooP0<f5?b@0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oT
h@030<f5?`000000003o00d0onCQ00<0cHDo0?ooh03oon00o`3oon0Y0?ooh0030000003oon00oooP
0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP04`0oooP00D0003o0?ooh03o
on00oooP0<f5?`0T0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>40103=
QCl0onCQ0?oTh@000?l<0?oTh@030<f5?`3oon00oooP0?l0oooP:@3oon000`000000oooP0?ooh00@
0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh01<0?ooh0050000o`3oon00oooP
0?ooh03=QCl0903oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00D0cHDo
0?oTh@3oi>40onCQ0000o`0;0?oTh@030<f5?`3oon00oooP0?l0oooP:@3oon000`000000oooP0?oo
h00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh01;0?ooh0030000o`3oon00
oooP0080oooP00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40
onCQ00d0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`000?l0onCQ0?oTh@080?oTh@030<f5?`3oon00
oooP0?l0oooP:@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`00
0000oooP0?ooh01:0?ooh0030000o`3oon00oooP00<0oooP00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`00
0?l0onCQ0?oTh@070?oTh@030<f5?`3oon00oooP0?l0oooP:@3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh0190?ooh0030000o`3oon00oooP00@0
oooP00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0
onCQ00<0cHDo0?oTh@3oi>40103oi>400`000?l0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP0?l0
oooP:@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP
0?ooh0180?ooh0030000o`3oon00oooP00D0oooP00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ
0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`000?l0onCQ
0?oTh@050?oTh@030<f5?`3oon00oooP0?l0oooP:@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh0170?ooh0030000o`3oon00oooP00H0oooP00<0
cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0
cHDo0?oTh@3oi>401@3oi>400`000?l0onCQ0?oTh@050?oTh@030<f5?`3oon00oooP0?l0oooP:@3o
on000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh015
0?ooh003000000000?l0oooP00P0oooP00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R
0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`000?l0onCQ0?oTh@04
0?oTh@030<f5?`3oon00oooP0?l0oooP:@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool0
01d0n_3V8@3oon000`000000oooP0?ooh0110?ooh0<0cHDo0P0000000`000?l000000<f5?`080<f5
?b@0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ
00L0onCQ00<0003o0?oTh@3oi>400`3oi>400`3=QCl0oooP0?ooh03o0?ooh2T0oooP00<000000?oo
h03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00@@3oon001@3=QCl0
onCQ0?oTh@000000003o00800000203oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ
0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@080?oTh@030000o`3oi>40onCQ
0080onCQ00<0cHDo0?ooh03oon00o`3oon0Y0?ooh0030000003oon00oooP0100oooP7P3jl>H10?oo
o`007@3jl>HQ0?ooh0030000003oon00oooP0440oooP00@0cHDo0?oTh@3oi>40003o0P0000090?oT
h@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oT
h@030<f5?`3oi>40onCQ00T0onCQ00D0003o0?oTh@3oi>40onCQ0<f5?`3o0?ooh2/0oooP00<00000
0?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00@@3oon000`3=
QCl0onCQ0000o`0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00X0onCQ00@0003o0?oTh@3oi>40cHDoo`3oon0[
0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP
0440oooP00<0cHDo0000o`3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ
0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030000o`3oi>40cHDo
0?l0oooP:`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon0300000440
oooP00<0cHDo0000o`3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280
onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030000o`3oi>40cHDo0?l0
oooP:@3oon0300000180oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0440oooP
00<0003o0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ
00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030000o`3=QCl0oooP0?l0oooP
:P3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?oo
h0100?ooh0030000o`3=QCl0onCQ00d0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oT
h@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40303oi>400`000?l0cHDo0?oo
h03o0?ooh2X0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<00000
0?ooh03oon00@03oon000`000?l0cHDo0?oTh@0=0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo
0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0003o
0?ooh03oon00o`3oon0Y0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?oo
h0030000003oon00oooP03l0oooP00<0003o0?ooh03=QCl03P3oi>400`3=QCl0onCQ0?oTh@0R0?oT
h@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oT
h@030<f5?`000?l0oooP0?l0oooP:@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0
n_3V8@3oon000`000000oooP0?ooh00n0?ooh0040000o`3oon00oooP0<f5?`h0onCQ00<0cHDo0?oT
h@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oT
h@3oi>403@3oi>400`3=QCl0003o0?ooh03o0?ooh2T0oooP00<000000?ooh03oon00403oon0N0?[`
iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00?P3oon0010000?l0oooP0?ooh03=QCl>0?oT
h@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oT
h@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?ooh0000?l0o`3oon0Y0?ooh0030000003oon00oooP
0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP03d0oooP00D0003o0?ooh03o
on00oooP0<f5?`0>0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00@0cHDo0?ooh03oon00003oo`3oon0X
0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP
03`0oooP00<0003o0?ooh03oon000P3oon000`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ
0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ
00d0onCQ00@0cHDo0?ooh03oon00003oo`3oon0X0?ooh0030000003oon00oooP0100oooP7P3jl>H1
0?ooo`007@3jl>HQ0?ooh0030000003oon00oooP03`0oooP00<0003o0?ooh03oon000P3oon000`3=
QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00D0cHDo0?ooh03oon00oooP0000o`02
00000?l0oooP9@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`00
0000oooP0?ooh00k0?ooh0030000o`3oon00oooP00<0oooP00<0cHDo0?oTh@3oi>40303oi>400`3=
QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@050<f5?`3oon00oooP0?ooh0000?l00`00003o0?ooh2@0oooP00<00000
0?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00>P3oon000`00
0?l0oooP0?ooh0040?ooh0030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>440<f5
?`04000000000?l00000000001<0cHDoo`3oon0A0?ooh0030000003oon00oooP0100oooP7P3jl>H1
0?ooo`007@3jl>HQ0?ooh0030000003oon00oooP03X0oooP00<0003o0?ooh03oon00103oon000`3=
QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`00
0000003o0?oTh@0B0?oTh@030<f5?`3oon00oooP0?l0oooP3`3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00i0?ooh0030000o`3oon00oooP00D0
oooP00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280
onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00<0
onCQ00<0003o0?oTh@3oi>404@3oi>400`3=QCl0oooP0?ooh03o0?ooh0l0oooP00<000000?ooh03o
on00403oon0N0?[`iP40oooo000M0?[`iR40oooP0`00000i0?ooh0030000o`3oon00oooP00D0oooP
00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ
00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0003o0?oTh@3oi>40403oi>400`3=QCl0oooP0?ooh03o0?ooh0d0oooP0`00000B0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00h0?ooh0030000o`3oon00oooP00H0oooP00<0
cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0
cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0
003o0?oTh@3oi>403`3oi>400`3=QCl0oooP0?ooh03o0?ooh0l0oooP00<000000?ooh03oon00403o
on0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00=`3oon000`000?l0oooP0?ooh007
0?ooh0030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R
0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@05
0?oTh@030000o`3oi>40onCQ00l0onCQ00<0cHDo0?ooh03oon00o`3oon0?0?ooh0030000003oon00
oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP03L0oooP00<0003o0?oo
h03oon001`3oon000`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oT
h@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oT
h@3oi>401P3oi>400`000?l0onCQ0?oTh@0>0?oTh@030<f5?`3oon00oooP0?l0oooP3`3oon000`00
0000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00f0?ooh003
0000o`3oon00oooP00P0oooP00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@03
0<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0003o0?oTh@3oi>403P3oi>400`3=QCl0oooP0?ooh03o0?ooh0l0
oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00
=@3oon000`000?l0oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40
8P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40
3@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030000o`3oi>40onCQ00d0onCQ00<0cHDo0?ooh03oon00
o`3oon0?0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003o
on00oooP03D0oooP00<0003o0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3o
i>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3o
i>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40203oi>400`000?l0onCQ0?oTh@0<0?oTh@030<f5?`3o
on00oooP0?l0oooP3`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon00
0`000000oooP0?ooh00b0?ooh080000000<0003o0?ooh03oon002P3oon000`3=QCl0onCQ0?oTh@0<
0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=
0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40203oi>400`000?l0onCQ0?oTh@0<
0?oTh@030<f5?`3oon00oooP0?l0oooP3`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool0
01d0n_3V8@3oon000`000000oooP0?ooh00a0?ooh080000000<0003o0000003oon002`3oon000`3=
QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`00
0?l0onCQ0?oTh@0;0?oTh@030<f5?`3oon00oooP0?l0oooP3`3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00^0?ooh0<0cHDo0P0000000`000?l0
00000<f5?`0<0<f5?`h0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@03
0<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0000o`3oi>40onCQ00X0onCQ00<0cHDo0?ooh03oon00o`3oon0?0?ooh0030000003oon00oooP0100
oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP02h0oooP00H0cHDo0?oTh@3oi>40
onCQ0000o`00000=0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=
QCl0onCQ0?oTh@0:0?oTh@030000o`3oi>40onCQ00X0onCQ00<0cHDo0?ooh03oon00o`3oon0?0?oo
h0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP02h0
oooP00@0cHDo0?oTh@3oi>40003o3`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ
0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ
00d0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`000?l0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP
0?l0oooP3`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V2`3oon02000000@0
oooP0P0000040?ooh0800000203oon000`000000oooP0?ooh00^0?ooh0040<f5?`3oi>40onCQ0000
o`l0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ
0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ
00/0onCQ00<0003o0?oTh@3oi>402@3oi>400`3=QCl0oooP0?ooh03o0?ooh0l0oooP00<000000?oo
h03oon00403oon0N0?[`iP40oooo000M0?[`iPX0oooP00@000000?ooh03oon000000203oon001000
0000oooP0?ooh00000070?ooh0030000003oon00oooP02h0oooP00<0cHDo0?oTh@000?l0403oi>40
0`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>40
0`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40303oi>40
0`000?l0onCQ0?oTh@080?oTh@030<f5?`3oon00oooP0?l0oooP3`3oon000`000000oooP0?ooh00@
0?ooh1h0n_3V0@3oool001d0n_3V2P3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00
oooP00D0oooP1000000]0?ooh0030<f5?`000?l0onCQ0100onCQ00<0cHDo0?oTh@3oi>40303oi>40
0`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>40
0`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0003o0?oTh@3oi>401`3oi>40
0`3=QCl0oooP0?ooh03o0?ooh0`0oooP1000000B0?ooh1h0n_3V0@3oool001d0n_3V103oon040000
0080oooP00@000000?ooh03oon0000002@3oon02000000P0oooP00<000000?ooh03oon00;P3oon00
0`3=QCl0003o0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>40
0`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>40
0`3=QCl0onCQ0?oTh@0=0?oTh@030000o`3oi>40onCQ00L0onCQ00<0cHDo0?ooh03oon00o`3oon0?
0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>H:0?ooh0040000003oon00oooP
000000T0oooP00<000000?ooh03oon001`3oon000`000000oooP0?ooh00^0?ooh0030000o`3oi>40
onCQ0100onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40
onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40
onCQ00h0onCQ00<0003o0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh03o0?ooh0l0oooP00<00000
0?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iP/0oooP0P00000:0?ooh0<000001`3oon000`00
0000oooP0?ooh00^0?ooh0030000o`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=
QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0003o0?oTh@3oi>401P3oi>400`3=
QCl0oooP0?ooh03o0?ooh0l0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40
oooP00<000000?ooh03oon00;@3oon000`000?l0cHDo0?oTh@0A0?oTh@030<f5?`3oi>40onCQ00`0
onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0
onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030000o`3oi>40onCQ00D0
onCQ00<0cHDo0?ooh03oon00o`3oon0?0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`00
7@3jl>HQ0?ooh0030000003oon00oooP02d0oooP00<0003o0<f5?`3oi>404@3oi>400`3=QCl0onCQ
0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ
0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`000?l0onCQ
0?oTh@050?oTh@030<f5?`3oon00oooP0?l0oooP3`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00/0?ooh0030000o`3oon00cHDo0180onCQ00<0
cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0
cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0
003o0?oTh@3oi>40103oi>400`3=QCl0oooP0?ooh03o0?ooh0l0oooP00<000000?ooh03oon00403o
on0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00;03oon000`000?l0oooP0<f5?`0B
0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R
0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0A
0?oTh@030000o`3oi>40onCQ00<0onCQ00<0cHDo0?ooh03oon00o`3oon0?0?ooh0030000003oon00
oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP02/0oooP00@0003o0?oo
h03oon00cHDo4P3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo
0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo
0?oTh@3oi>404@3oi>400`000?l0onCQ0?oTh@030?oTh@030<f5?`3oon00oooP0?l0oooP3`3oon00
0`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00[0?oo
h0040000o`3oon00oooP0<f5?a80onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R
0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=
0?oTh@030<f5?`3oi>40onCQ0180onCQ00<0003o0?oTh@3oi>400P3oi>400`3=QCl0oooP0?ooh03o
0?ooh0l0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?oo
h03oon00:P3oon001@000?l0oooP0?ooh03oon00cHDo0180onCQ00<0cHDo0?oTh@3oi>40303oi>40
0`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>40
0`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ0180onCQ00<0003o0?oTh@3oi>400P3oi>40
0`3=QCl0oooP0?ooh03o0?ooh0l0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`
iR40oooP00<000000?ooh03oon00:P3oon001@000?l0oooP0?ooh03oon00cHDo0180onCQ00<0cHDo
0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo
0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01<0onCQ00D0003o
0?oTh@3oi>40onCQ0<f5?`3o0?ooh140oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M
0?[`iR40oooP00<000000?ooh03oon00:@3oon000`000?l0oooP0?ooh0020?ooh0030<f5?`3oi>40
onCQ0100onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40
onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40
onCQ01<0onCQ00D0003o0?oTh@3oi>40onCQ0<f5?`3o0?ooh140oooP00<000000?ooh03oon00403o
on0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00:03oon000`000?l0oooP0?ooh003
0?ooh0030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R
0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=
0?oTh@030<f5?`3oi>40onCQ01@0onCQ00@0003o0?oTh@3oi>40cHDoo`3oon0A0?ooh0030000003o
on00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP02P0oooP00<0003o
0?ooh03oon000`3oon000`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo
0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo
0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0E0?oTh@030000o`3oi>40cHDo0?l0oooP4@3oon00
0`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon03000002L0oooP00<0003o0?oo
h03oon00103oon000`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oT
h@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oT
h@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0E0?oTh@030000o`3oi>40cHDo0?l0oooP3`3oon030000
0180oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP02L0oooP00<0003o0?ooh03o
on00103oon000`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3o
i>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3o
i>403@3oi>400`3=QCl0onCQ0?oTh@0F0?oTh@030000o`3=QCl0oooP0?l0oooP403oon000`000000
oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00V0?ooh0030000
o`3oon00oooP00D0oooP00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5
?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5
?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405P3oi>400`000?l0cHDo0?ooh03o0?ooh100oooP
00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon009P3o
on000`000?l0oooP0?ooh0050?ooh0030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40303o
i>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3o
i>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0003o0?ooh03oon00o`3o
on0?0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00
oooP02D0oooP00<0003o0?ooh03oon001P3oon000`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40
onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40
onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030000o`3oon00
oooP0?l0oooP3`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`00
0000oooP0?ooh00U0?ooh0030000o`3oon00oooP00H0oooP00<0cHDo0?oTh@3oi>40403oi>400`3=
QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=
QCl0003o0?ooh03o0?ooh0l0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40
oooP00<000000?ooh03oon00903oon000`000?l0oooP0?ooh0070?ooh0030<f5?`3oi>40onCQ0100
onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280
onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01L0
onCQ00<0cHDo0?ooh0000?l0o`3oon0?0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`00
7@3jl>HQ0?ooh0030000003oon00oooP02@0oooP00<0003o0?ooh03oon001`3oon000`3=QCl0onCQ
0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ
0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ
0?oTh@0G0?oTh@030<f5?`3oon00003o0?l0oooP3`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00S0?ooh0030000o`3oon00oooP00P0oooP00<0
cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0
cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0
cHDo0?oTh@3oi>405`3oi>40103=QCl0oooP0?ooh0000?oo0?ooh0h0oooP00<000000?ooh03oon00
403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon008P3oon000`000?l0oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oT
h@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oT
h@0=0?oTh@030<f5?`3oi>40onCQ01L0onCQ00@0cHDo0?ooh03oon00003oo`3oon0>0?ooh0030000
003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0280oooP00<0
003o0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0
cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0
cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@050<f5?`3oon00oooP0?ooh0000?l0
o`3oon0=0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003o
on00oooP0240oooP00<0003o0?ooh03oon002P3oon000`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3o
i>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3o
i>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@050<f5?`3o
on00oooP0?ooh0000?l0o`3oon0=0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3j
l>HQ0?ooh0030000003oon00oooP0240oooP00<0003o0?ooh03oon002P3oon000`3=QCl0onCQ0?oT
h@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oT
h@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oT
h@0G0?oTh@030<f5?`3oon00oooP0080oooP00<0003o0?ooh03oon00o`3oon0:0?ooh0030000003o
on00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0200oooP00<0003o
0?ooh03oon002`3oon000`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo
0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo
0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oon00oooP00<0oooP00<0003o
0?ooh03oon00o`3oon090?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?oo
h0<000007P3oon02000000030000o`3oon00oooP00/0oooP00<0cHDo0?oTh@3oi>40403oi>400`3=
QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=
QCl0oooP0?ooh0030?ooh0030000o`3oon00oooP0?l0oooP1`3oon0300000180oooP7P3jl>H10?oo
o`007@3jl>HQ0?ooh0030000003oon00oooP01X0oooP0`3=QCl2000000030000o`000000cHDo00d0
cHDo4P3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3o
i>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3o
i>405`3oi>400`3=QCl0oooP0?ooh0040?ooh0030000o`3oon00oooP0?l0oooP203oon000`000000
oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00J0?ooh0030<f5
?`3oi>40onCQ0080000000<0003o0000003oi>40303oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5
?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5
?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5
?`3oon00oooP00@0oooP00<0003o0?ooh03oon00o`3oon080?ooh0030000003oon00oooP0100oooP
7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP01X0oooP00H0cHDo0?oTh@3oi>40onCQ
0000o`00000>0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0
onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0
onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?ooh03oon001@3oon000`000?l0
oooP0?ooh03o0?ooh0L0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP
00<000000?ooh03oon006P3oon001@3=QCl0onCQ0?oTh@3oi>40003o00l0onCQ00<0cHDo0?oTh@3o
i>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3o
i>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3o
i>405`3oi>400`3=QCl0oooP0?ooh0050?ooh0030000o`3oon00oooP0?l0oooP1`3oon000`000000
oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00J0?ooh0040<f5
?`3oi>40onCQ0000oa00onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@03
0<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@03
0<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh0060?ooh003
0000o`3oon00oooP0?l0oooP1P3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V
8@3oon000`000000oooP0?ooh00J0?ooh0040<f5?`3oi>40onCQ0000oa00onCQ00<0cHDo0?oTh@3o
i>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3o
i>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3o
i>405`3oi>400`3=QCl0oooP0?ooh0070?ooh0030000o`3oon00oooP0?l0oooP1@3oon000`000000
oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00J0?ooh0030<f5
?`3oi>40003o0140onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5
?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5
?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh0070?ooh0030000
o`3oon00oooP0?l0oooP1@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3o
on000`000000oooP0?ooh00J0?ooh0030<f5?`000?l0onCQ0140onCQ00<0cHDo0?oTh@3oi>40403o
i>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3o
i>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3o
i>400`3=QCl0oooP0?ooh0080?ooh0030000o`3oon00oooP0?l0oooP103oon000`000000oooP0?oo
h00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00J0?ooh0030<f5?`000?l0
onCQ0140onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40
onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40
onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh0080?ooh0030000o`3oon00
oooP0?l0oooP103oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`00
0000oooP0?ooh00J0?ooh0030000o`3oi>40onCQ0140onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=
QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=
QCl0oooP0?ooh0090?ooh0030000o`3oon00oooP0?l0oooP0`3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00J0?ooh0030000o`3oi>40onCQ0140
onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280
onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0
onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh0090?ooh0030000o`3oon00oooP0?l0
oooP0`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP
0?ooh00I0?ooh0030000o`3=QCl0onCQ0180onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ
0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ
0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP
0?ooh00:0?ooh0030000o`3oon00oooP0?l0oooP0P3oon000`000000oooP0?ooh00@0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00I0?ooh0030000o`3=QCl0onCQ0180onCQ00<0
cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0
cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0
cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh00:0?ooh0030000o`3oon00oooP0?l0oooP0P3o
on000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon03000001P0oooP00<0003o
0?ooh03=QCl04`3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo
0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo
0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oon00oooP00/0oooP00<0003o
0?ooh03oon00oP3oon0300000180oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP
01P0oooP00<0003o0?ooh03=QCl04`3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ
00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ
00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oon00oooP
00/0oooP00<0003o0?ooh03oon00o`3oon010?ooh0030000003oon00oooP0100oooP7P3jl>H10?oo
o`007@3jl>HQ0?ooh0030000003oon00oooP01L0oooP00@0003o0?ooh03oon00cHDo4`3oi>400`3=
QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=
QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oon00oooP00`0oooP00<0003o0?ooh03oon00o`3oon000`00
0000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh00G0?ooh004
0000o`3oon00oooP0<f5?a<0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oT
h@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oT
h@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh00<0?oo
h0030000o`3oon00oooP0?l0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40
oooP00<000000?ooh03oon005P3oon001@000?l0oooP0?ooh03oon00cHDo01<0onCQ00<0cHDo0?oT
h@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oT
h@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oT
h@3oi>405`3oi>400`3=QCl0oooP0?ooh00=0?ooh0030000o`3oon00oooP0?h0oooP00<000000?oo
h03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon005P3oon001@000?l0
oooP0?ooh03oon00cHDo01<0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oT
h@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oT
h@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh00=0?oo
h0030000o`3oon00oooP0?h0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40
oooP00<000000?ooh03oon005@3oon000`000?l0oooP0?ooh0020?ooh0030<f5?`3oi>40onCQ0140
onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280
onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0
onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh00>0?ooh0030000o`3oon00oooP0?d0
oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00
5@3oon000`000?l0oooP0?ooh0020?ooh0030<f5?`3oi>40onCQ0140onCQ00<0cHDo0?oTh@3oi>40
403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>40
8P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40
5`3oi>400`3=QCl0oooP0?ooh00>0?ooh0030000o`3oon00oooP0?d0oooP00<000000?ooh03oon00
403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00503oon000`000?l0oooP0?oo
h0030?ooh0030<f5?`3oi>40onCQ0140onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oT
h@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oT
h@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?oo
h00?0?ooh0030000o`3oon00oooP0?`0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M
0?[`iR40oooP00<000000?ooh03oon00503oon000`000?l0oooP0?ooh0030?ooh0030<f5?`3oi>40
onCQ0140onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40
onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40
onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh00?0?ooh0030000o`3oon00
oooP0?`0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?oo
h03oon004`3oon000`000?l0oooP0?ooh0040?ooh0030<f5?`3oi>40onCQ0140onCQ00<0cHDo0?oT
h@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oT
h@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oT
h@3oi>405`3oi>400`3=QCl0oooP0?ooh00@0?ooh0030000o`3oon00oooP0?/0oooP00<000000?oo
h03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon004P3oon000`000?l0
oooP0?ooh0050?ooh0030<f5?`3oi>40onCQ0140onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0
onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0
onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0
oooP0?ooh00A0?ooh0030000o`3oon00oooP0?X0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP00<000000?ooh03oon004P3oon000`000?l0oooP0?ooh0050?ooh0030<f5
?`3oi>40onCQ0140onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5
?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5
?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh00A0?ooh0030000
o`3oon00oooP0?X0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<0
00000?ooh03oon004@3oon000`000?l0oooP0?ooh0060?ooh0030<f5?`3oi>40onCQ0140onCQ00<0
cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0
cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0
cHDo0?oTh@3oi>405`3oi>400`3=QCl0oooP0?ooh00B0?ooh0030000o`3oon00oooP0?T0oooP00<0
00000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon004@3oon00
0`000?l0oooP0?ooh0060?ooh0030<f5?`3oi>40onCQ0140onCQ00<0cHDo0?oTh@3oi>40403oi>40
0`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>40
0`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>40
0`3=QCl0oooP0?ooh00B0?ooh0030000o`3oon00oooP0?T0oooP00<000000?ooh03oon00403oon0N
0?[`iP40oooo000M0?[`iR40oooP0`00000?0?ooh003000000000?l0oooP00P0oooP00<0cHDo0?oT
h@3oi>404@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oT
h@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oT
h@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oon00oooP01<0oooP00<0003o0?oo
h03oon00mP3oon0300000180oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP00h0
oooP0P0000000`000?l000000?ooh0070?ooh0030<f5?`3oi>40onCQ0140onCQ00<0cHDo0?oTh@3o
i>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3o
i>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3o
i>405`3oi>400`3=QCl0oooP0?ooh00C0?ooh0030000o`3oon00oooP0?P0oooP00<000000?ooh03o
on00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon002@3oon050<f5?`040000
00000?l00000000000T0cHDo4`3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0
onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0
onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oon00oooP01@0
oooP00<0003o0000003oon00m`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V
8@3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0003o0000003oi>40
203oi>400`3=QCl0onCQ0?oTh@0A0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40
303oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>40
3@3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?ooh03oon00
4`3oon0010000000003o00000000003g0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`00
7@3jl>HQ0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400P3oi>400`000?l0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ0140onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ
0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ
0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>4F0<f5?`800000
00<0003o0000003oon00mP3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0080onCQ00<0003o0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@0A0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40303o
i>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3oi>403@3o
i>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40503o
i>400`000000003o0<f5?`3g0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0000o`0<0?oTh@030<f5?`3o
i>40onCQ0140onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3o
i>40onCQ0280onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3o
i>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@0F0?oTh@030000o`3o
on00oooP0?D0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<00000
0?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40003o00`0onCQ00<0cHDo0?oTh@3oi>404@3o
i>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3o
i>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3o
i>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ01H0onCQ00<0003o0?ooh03oon00m@3o
on000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh009
0?ooh0040<f5?`3oi>40onCQ0000o`d0onCQ00<0cHDo0?oTh@3oi>404@3oi>400`3=QCl0onCQ0?oT
h@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oT
h@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oT
h@0G0?oTh@030<f5?`3oi>40onCQ01H0onCQ00<0cHDo0000o`3oon00m@3oon000`000000oooP0?oo
h00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh0090?ooh0040<f5?`3oi>40
onCQ0000o`d0onCQ00<0cHDo0?oTh@3oi>404@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3o
i>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3o
i>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3o
i>40onCQ01H0onCQ00<0cHDo0000o`3oon00m@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3o
ool001d0n_3V8@3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40003o00h0onCQ00<0cHDo
0?oTh@3oi>404@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo
0?oTh@3oi>408P3oi>400`3=QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo
0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ01H0onCQ00<0cHDo
0?ooh0000?l0m@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40003o00h0onCQ00<0cHDo0?oTh@3oi>404@3oi>400`3=
QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=
QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ01H0onCQ00<0cHDo0?ooh0000?l0m@3oon000`00
0000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V5`3oon02000000P0oooP00<000000?ooh03o
on002@3oon000`3=QCl0003o0?oTh@0>0?oTh@030<f5?`3oi>40onCQ0140onCQ00<0cHDo0?oTh@3o
i>40403oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ0280onCQ00<0cHDo0?oTh@3o
i>408P3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3o
i>405`3oi>400`3=QCl0onCQ0?oTh@0F0?oTh@040<f5?`3oon00oooP0000oo@0oooP00<000000?oo
h03oon00403oon0N0?[`iP40oooo000M0?[`iQH0oooP00@000000?ooh03oon0000001`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`000?l0onCQ00h0onCQ00<0cHDo0?oTh@3oi>404@3oi>400`3=
QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>408P3oi>400`3=
QCl0onCQ0?oTh@0R0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=
QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ01H0onCQ00D0cHDo0?ooh03oon00oooP0000o`3c
0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HF0?ooh0040000003oon00oooP
000000L0oooP100000080?ooh0030000o`00000000000>D0000000<0003o000000000000i@000000
0`000?l0oooP0?ooh0060?ooh0@000004P3oon0N0?[`iP40oooo000M0?[`iQH0oooP00@000000?oo
h03oon0000001`3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`000?l0<j7:0?ooh00:0?ooh0030000003oon00oooP0100oooP7P3jl>H1
0?ooo`007@3jl>HF0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00k@3oon00
0`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H0
0`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H0
0`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0003o03>QbP3oon002P3oon00
0`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V5`3oon02000000P0oooP00<000000?oo
h03oon00k@3oon000`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0[MSV01H0[MSV00<0<j7:0:gH
iP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gH
iP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0003o0:gH
iP0cXLX02`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000
oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H05P2]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`000?l0
[MSV03>QbP0;0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000
003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP0E0:gHiP0303>Q
bP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>Q
bP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0E0:gHiP040000
o`2]f>H0[MSV03>QbP/0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP
00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP040:gHiP030000o`2]f>H0[MSV01D0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV
00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV
00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV01D0[MSV
00@0003o0:gHiP2]f>H0<j7:2`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V
8@3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV00D0[MSV00<0003o0:gHiP2]f>H0
502]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
4`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0
502]f>H01@000?l0[MSV0:gHiP2]f>H0<j7:00/0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP050:gHiP030000
o`2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00D0003o0:gHiP2]f>H0[MSV03>QbP0;0?ooh0030000003oon00oooP0100
oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H0
1P2]f>H00`000?l0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
7`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0
502]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?oo
h03]0?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gH
iP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gH
iP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`000?l0[MSV0:gH
iP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M
0?[`iR40oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP070:gHiP030000o`2]f>H0
[MSV0180[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV0180[MSV00<0003o0:gHiP2]f>H00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gH
iP2]f>H01`2]f>H00`000?l0[MSV0:gHiP0B0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0B0:gHiP030000o`2]f>H0[MSV00<0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000
oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H04@2]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`000000
003o0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP0`00003]0?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H0
4@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
4`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV4P0cXLX2000000030000
o`000000<j7:00D0<j7:2@3oon0300000180oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003o
on00oooP0>d0oooP00<0<j7:0:gHiP2]f>H02@2]f>H00`000?l0[MSV0:gHiP0@0:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]
f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]
f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0oooP0?ooh00?0?ooh00400000000
0?l0000000000140oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<0
00000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0
<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP3oon00oooP0100oooP00<0
003o0000003oon004@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon00
0`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV00X0[MSV00<0003o0:gHiP2]f>H03`2]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H0
0`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H0
0`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0?ooh03oon003`3oon00
0`000?l0oooP0?ooh00B0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?oo
h0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H02P2]f>H00`000?l0[MSV0:gHiP0?0:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gH
iP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gH
iP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0oooP0?ooh00?0?oo
h0030000o`3oon00oooP0180oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40
oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP0;0:gHiP030000o`2]f>H0[MSV00h0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP3oon00oooP00h0
oooP00<0003o0?ooh03oon004`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V
8@3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gHiP2]f>H0
3P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
4`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0?ooh03oon00
3@3oon000`000?l0oooP0?ooh00D0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3j
l>HQ0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H0302]f>H00`000?l0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gH
iP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0oooP0?oo
h00=0?ooh0030000o`3oon00oooP01@0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M
0?[`iR40oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP0<0:gHiP030000o`2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP3oon00
oooP00`0oooP00<0003o0?ooh03oon005@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool0
01d0n_3V8@3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0003o0:gH
iP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gH
iP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0?oo
h03oon00303oon000`000?l0oooP0?ooh00E0?ooh0030000003oon00oooP0100oooP7P3jl>H10?oo
o`007@3jl>HQ0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`000?l0
[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0
oooP0?ooh00;0?ooh0030000o`3oon00oooP01H0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP0>0:gHiP030000
o`2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP3oon00oooP00/0oooP00<0003o0?ooh03oon005P3oon000`000000oooP0?ooh00@0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV00h0[MSV00<0
003o0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0
<j7:0?ooh03oon002P3oon000`000?l0oooP0?ooh00G0?ooh0030000003oon00oooP0100oooP7P3j
l>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H03`2]f>H0
0`000?l0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H0
0`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H0
0`0cXLX0oooP0?ooh00:0?ooh0030000o`3oon00oooP01L0oooP00<000000?ooh03oon00403oon0N
0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP0?0:gH
iP030000o`2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gH
iP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gH
iP0303>QbP3oon00oooP00T0oooP00<0003o0?ooh03oon00603oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon0300000>d0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`000?l0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000o`3oon00oooP01H0oooP0`00000B0?ooh1h0n_3V0@3oool001d0n_3V
8@3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV0100[MSV00<0003o0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
4`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0?ooh03oon00
203oon000`000?l0oooP0?ooh00I0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3j
l>HQ0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H04@2]f>H00`000?l0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gH
iP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0oooP0?oo
h0080?ooh0030000o`3oon00oooP01T0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M
0?[`iR40oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP0A0:gHiP030000o`2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP3oon00
oooP00L0oooP00<0003o0?ooh03oon006P3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool0
01d0n_3V8@3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV0180[MSV00<0003o0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gH
iP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0?oo
h03oon001`3oon000`000?l0oooP0?ooh00J0?ooh0030000003oon00oooP0100oooP7P3jl>H10?oo
o`007@3jl>HQ0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H04P2]f>H00`000?l0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0
oooP0?ooh0060?ooh0030000o`3oon00oooP01/0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP030000
o`2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP3oon00oooP00H0oooP00<0003o0?ooh03oon006`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0
003o0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0
<j7:0?ooh03oon001@3oon000`000?l0oooP0?ooh00L0?ooh0030000003oon00oooP0100oooP7P3j
l>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H0502]f>H0
0`000?l0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H0
0`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H0
0`0cXLX0oooP0?ooh0050?ooh0030000o`3oon00oooP01`0oooP00<000000?ooh03oon00403oon0N
0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP0E0:gH
iP030000o`000000[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gH
iP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gH
iP0303>QbP3oon00oooP00@0oooP00<0003o0?ooh03oon007@3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV01@0
[MSV00@000000000o`0000000000102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV
01@0[MSV00<0<j7:0?ooh03oon000`3oon000`000?l0oooP0?ooh00N0?ooh0030000003oon00oooP
0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0>d0oooP5`0cXLX200000003
0000o`000000<j7:00@0<j7:302]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP3oon00oooP00<0
oooP00<0003o0?ooh03oon007P3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V
8@3oon000`000000oooP0?ooh03o0?ooh0H0oooP00<000000000o`3oon00103oon000`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV
0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV
0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0?ooh03oon000P3oon000`000?l0oooP
0?ooh00O0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003o
on00oooP0?l0oooP203oon000`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0
<j7:0:gHiP2]f>H0502]f>H00`0cXLX0oooP0?ooh0020?ooh0030000o`3oon00oooP01l0oooP00<0
00000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP0`00003o0?ooh0P0oooP00<0003o
0?ooh03oon000P3oon000`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00D0<j7:
0?ooh03oon00oooP0000o`0P0?ooh0<000004P3oon0N0?[`iP40oooo000M0?[`iR40oooP00<00000
0?ooh03oon00o`3oon090?ooh0050000o`3oon00oooP0?ooh00cXLX0302]f>H00`0cXLX0[MSV0:gH
iP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gH
iP0D0:gHiP0503>QbP3oon00oooP0?ooh0000?l08P3oon000`000000oooP0?ooh00@0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh0X0oooP00@0003o0?ooh03oon00<j7:
302]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0
702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0
4@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0403>QbP3oon00oooP0000ob<0oooP00<000000?ooh03o
on00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0:0?ooh0040000
o`3oon00oooP03>QbP`0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP03
03>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]f>H0100cXLX0oooP0?ooh0000?lS0?oo
h0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0
oooP2`3oon000`000?l0oooP03>QbP0<0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]
f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0?ooh000
0?l0903oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP
0?ooh03o0?ooh0/0oooP00<0003o0?ooh00cXLX0302]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP000?l0oooP02@0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<0
00000?ooh03oon00o`3oon0<0?ooh0030000o`0cXLX0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H07`2]
f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0502]
f>H00`0cXLX0003o0?ooh00T0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ
0?ooh0030000003oon00oooP0?l0oooP303oon000`000?l0<j7:0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0
[MSV01@0[MSV00<0003o0?ooh03oon00903oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool0
01d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh0d0oooP00<0003o0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0c
XLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0c
XLX0[MSV0:gHiP0D0:gHiP030000o`3oon00oooP02@0oooP00<000000?ooh03oon00403oon0N0?[`
iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0=0?ooh00303>QbP000?l0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0
[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140
[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`000?l0<j7:0?ooh00U0?ooh0030000003oon00oooP0100
oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP3@3oon000`0cXLX0003o
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV
0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV
0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0003o03>QbP3oon009@3oon000`000000oooP
0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh0d0oooP00<0
<j7:0:gHiP000?l02P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0
<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0B0:gHiP030000o`2]f>H0<j7:02H0oooP00<0
00000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0=
0?ooh00303>QbP2]f>H0003o00X0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H04@2]f>H010000?l0[MSV0:gHiP0c
XLXV0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00
oooP0?l0oooP3@3oon00100cXLX0[MSV0:gHiP000?l90:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV0140[MSV00@0
003o0:gHiP2]f>H0<j7:9P3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3o
on0300000?l0oooP3@3oon00100cXLX0[MSV0:gHiP000?l90:gHiP0303>QbP2]f>H0[MSV01l0[MSV
00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV
00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV0100[MSV
00D0003o0:gHiP2]f>H0[MSV03>QbP0T0?ooh0<000004P3oon0N0?[`iP40oooo000M0?[`iR40oooP
00<000000?ooh03oon00o`3oon0=0?ooh00503>QbP2]f>H0[MSV0:gHiP000?l0202]f>H00`0cXLX0
[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP050000o`2]f>H0[MSV0:gHiP0cXLX09P3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh0d0oooP00<0<j7:0:gHiP2]
f>H00P2]f>H00`000?l0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]
f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0003o0:gHiP2]
f>H00P2]f>H00`0cXLX0oooP0?ooh00T0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`00
7@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP3@3oon000`0cXLX0[MSV0:gHiP020:gHiP030000
o`2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>Q
bP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`000?l0[MSV0:gHiP020:gHiP0303>Q
bP3oon00oooP02@0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<0
00000?ooh03oon00o`3oon0=0?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]
f>H00`0cXLX0[MSV0:gHiP0>0:gHiP030000o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00903o
on000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o
0?ooh0d0oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0
[MSV00h0[MSV00<0003o0:gHiP2]f>H00`2]f>H00`0cXLX0oooP0?ooh00T0?ooh0030000003oon00
oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP3@3oon000`0c
XLX0[MSV0:gHiP040:gHiP030000o`2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0c
XLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0c
XLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`00
0?l0[MSV0:gHiP040:gHiP0303>QbP3oon00oooP02@0oooP00<000000?ooh03oon00403oon0N0?[`
iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0=0?ooh00303>QbP2]f>H0[MSV00@0
[MSV00<0003o0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP030000o`2]f>H0[MSV00D0
[MSV00<0<j7:0?ooh03oon00903oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V
8@3oon000`000000oooP0?ooh03o0?ooh0d0oooP00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV
0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV
0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0oooP
0?ooh00T0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003o
on00oooP0?l0oooP3@3oon000`0cXLX0[MSV0:gHiP060:gHiP050000o`2]f>H0[MSV0:gHiP0cXLX0
8@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0
2`2]f>H00`000?l0[MSV0:gHiP060:gHiP0303>QbP3oon00oooP02@0oooP00<000000?ooh03oon00
403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0=0?ooh00303>QbP2]
f>H0[MSV00H0[MSV00D0003o0:gHiP2]f>H0[MSV03>QbP0Q0:gHiP0303>QbP2]f>H0[MSV0100[MSV
00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV
00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP030000o`2]f>H0[MSV00H0[MSV
00<0<j7:0?ooh03oon00903oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3o
on000`000000oooP0?ooh03o0?ooh0d0oooP00<0<j7:0:gHiP2]f>H01`2]f>H010000?l0[MSV0:gH
iP0cXLXQ0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP030000o`2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon00903oon000`000000oooP
0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh0d0oooP00<0
<j7:0:gHiP2]f>H01`2]f>H010000?l0[MSV0:gHiP0cXLXQ0:gHiP0303>QbP2]f>H0[MSV0100[MSV
00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV
00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP030000o`2]f>H0[MSV00L0[MSV
00<0<j7:0?ooh03oon00903oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V2`3o
on02000000@0oooP0P0000040?ooh0800000203oon000`000000oooP0?ooh03o0?ooh0d0oooP00<0
<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV03>QbP0Q0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0
<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV00P0[MSV00<0
<j7:0?ooh03oon00903oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V2P3oon00
10000000oooP0?ooh00000080?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00
o`3oon0=0?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0003o0000000cXLX08@2]f>H00`0cXLX0[MSV
0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV
0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`000?l0[MSV
0:gHiP080:gHiP0303>QbP3oon00oooP02@0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo
000M0?[`iPX0oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?ooh0050?ooh0@00000
o`3oon0<0?ooh0X0<j7:0P0000000`000?l000000:gHiP0P0:gHiP0303>QbP2]f>H0[MSV0100[MSV
00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV
00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP030000o`2]f>H0[MSV00T0[MSV
00<0<j7:0?ooh03oon008@3oon0400000180oooP7P3jl>H10?ooo`007@3jl>H:0?ooh0040000003o
on00oooP000000T0oooP0P0000080?ooh0030000003oon00oooP0?l0oooP5`3oon03000000030000
o`2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0oooP0?ooh00T0?ooh0030000
003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>H:0?ooh0040000003oon00oooP000000T0oooP
00<000000?ooh03oon001`3oon000`000000oooP0?ooh03o0?ooh1P0oooP0P0000000`000?l0[MSV
0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP030000o`2]f>H0[MSV00X0[MSV00<0<j7:0?ooh03oon00903oon000`000000oooP
0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V2`3oon02000000X0oooP0`0000070?ooh0030000003o
on00oooP0?l0oooP6P3oon000`0cXLX0003o0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0
<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03000000000?l0[MSV00`0[MSV00<0
<j7:0?ooh03oon00903oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon00
0`000000oooP0?ooh03o0?ooh1X0oooP00<0<j7:0000o`2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0102]f>H010000000003o00000000
000<0:gHiP0303>QbP3oon00oooP02@0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M
0?[`iR40oooP00<000000?ooh03oon00o`3oon0J0?ooh00303>QbP2]f>H0003o01l0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiPL0<j7:00@000000000o`00000000003@0c
XLXV0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00
oooP0?l0oooP6P3oon00100cXLX0[MSV0:gHiP000?lN0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0
<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0oooP0?ooh0040?ooh0030000o`000000000003@0oooP00<0
00000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0J
0?ooh00403>QbP2]f>H0[MSV0000oah0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gH
iP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gH
iP0A0:gHiP0303>QbP3oon00oooP00<0oooP00<0003o0?ooh03oon00=@3oon000`000000oooP0?oo
h00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh1X0oooP00D0<j7:
0:gHiP2]f>H0[MSV0000o`0M0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]
f>H00`0cXLX0oooP0?ooh0030?ooh0030000o`3oon00oooP03D0oooP00<000000?ooh03oon00403o
on0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0J0?ooh00303>QbP2]f>H0
[MSV0080[MSV00<0003o0:gHiP2]f>H06P2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0
[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0
[MSV0140[MSV00<0<j7:0?ooh03oon000P3oon000`000?l0oooP0?ooh00f0?ooh0030000003oon00
oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP6P3oon000`0c
XLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV01X0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0c
XLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0c
XLX0[MSV0:gHiP0A0:gHiP0303>QbP3oon00oooP0080oooP00<0003o0?ooh03oon00=P3oon000`00
0000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh1X0
oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP0I0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:0:gHiP2]f>H04@2]f>H01@0cXLX0oooP0?ooh03oon00003o03T0oooP00<000000?oo
h03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0J0?ooh003
03>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H06@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP03
03>QbP2]f>H0[MSV0140[MSV00@0<j7:0?ooh03oon00003o>P3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh1X0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`000?l0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]
f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]
f>H04@2]f>H0100cXLX0oooP0?ooh0000?lj0?ooh0030000003oon00oooP0100oooP7P3jl>H10?oo
o`007@3jl>HQ0?ooh0<00000o`3oon0J0?ooh00303>QbP2]f>H0[MSV00D0[MSV00<0003o0:gHiP2]
f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0?ooh000
0?l0>@3oon0300000180oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP
6P3oon000`0cXLX0[MSV0:gHiP050:gHiP030000o`2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
4`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP000?l0oooP03/0oooP00<000000?ooh03oon00
403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0J0?ooh00303>QbP2]
f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]
f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]
f>H0[MSV0140[MSV00<0<j7:0000o`3oon00>`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3o
ool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh1X0oooP00<0<j7:0:gHiP2]f>H01`2]f>H0
0`000?l0[MSV0:gHiP0E0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H0
0`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H0
0`000?l0oooP0?ooh00k0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?oo
h0030000003oon00oooP0?l0oooP6P3oon000`0cXLX0[MSV0:gHiP070:gHiP030000o`2]f>H0[MSV
01D0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP030000o`0cXLX0oooP
03`0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03o
on00o`3oon0J0?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H0502]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0003o03>QbP3oon00?03oon000`000000
oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh1X0oooP
00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV
00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV
00<0<j7:0:gHiP2]f>H03`2]f>H00`000?l0[MSV03>QbP0m0?ooh0030000003oon00oooP0100oooP
7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP6P3oon000`0cXLX0[MSV0:gH
iP090:gHiP030000o`2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gH
iP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gH
iP0>0:gHiP040000o`2]f>H0[MSV03>QbSd0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo
000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0J0?ooh00303>QbP2]f>H0[MSV00X0[MSV00<0
003o0:gHiP2]f>H04P2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00@0
003o0:gHiP2]f>H0<j7:?@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3o
on000`000000oooP0?ooh03o0?ooh1X0oooP00<0<j7:0:gHiP2]f>H02P2]f>H00`000?l0[MSV0:gH
iP0B0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H01@000?l0[MSV0:gH
iP2]f>H0<j7:03d0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<0
00000?ooh03oon00o`3oon0J0?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gHiP2]f>H04@2]
f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00D0003o0:gHiP2]f>H0[MSV
03>QbP0m0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003o
on00oooP0?l0oooP6P3oon000`0cXLX0[MSV0:gHiP0<0:gHiP030000o`2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP030000o`2]f>H0[MSV0080[MSV00<0
<j7:0?ooh03oon00>`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon00
0`000000oooP0?ooh03o0?ooh1X0oooP00<0<j7:0:gHiP2]f>H0302]f>H00`000?l0[MSV0:gHiP0@
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=
0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`000?l0[MSV0:gHiP03
0:gHiP0303>QbP3oon00oooP03/0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`
iR40oooP00<000000?ooh03oon00o`3oon0J0?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0003o0:gH
iP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gH
iP2]f>H00`2]f>H00`0cXLX0oooP0?ooh00k0?ooh0030000003oon00oooP0100oooP7P3jl>H10?oo
o`007@3jl>HQ0?ooh0<00000o`3oon0J0?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0003o0:gHiP2]
f>H03`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0003o0:gHiP2]
f>H0102]f>H00`0cXLX0oooP0?ooh00i0?ooh0<000004P3oon0N0?[`iP40oooo000M0?[`iR40oooP
00<000000?ooh03oon00o`3oon0J0?ooh00303>QbP2]f>H0[MSV00h0[MSV00<0003o0:gHiP2]f>H0
3P2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0003o0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh00k0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3j
l>HQ0?ooh0030000003oon00oooP0?l0oooP6P3oon000`0cXLX0[MSV0:gHiP0?0:gHiP030000o`2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP030000o`2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00>`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3o
ool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh1X0oooP00<0<j7:0:gHiP2]f>H0402]f>H0
0`000?l0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H0
0`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`000?l0[MSV0:gHiP060:gHiP0303>QbP3oon00oooP03/0oooP00<000000?ooh03oon00403oon0N
0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0J0?ooh00303>QbP2]f>H0[MSV
0100[MSV00<0003o0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV
01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0003o0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh00k0?ooh0030000003oon00oooP
0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP6P3oon000`0cXLX0
[MSV0:gHiP0A0:gHiP030000o`000000000000/0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP030000o`2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon00>`3oon000`000000
oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh1X0oooP
00<0<j7:0:gHiP2]f>H04@2]f>H010000000003o00000000000:0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP03/0
oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00
o`3oon0J0?ooh1@0<j7:0P0000000`000?l0000003>QbP0:03>QbQ80[MSV00<0<j7:0:gHiP2]f>H0
702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`000?l0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP03/0oooP00<000000?ooh03oon00
403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0_0?ooh080000000<0
003o0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
003o0:gHiP2]f>H02P2]f>H00`0cXLX0oooP0?ooh00k0?ooh0030000003oon00oooP0100oooP7P3j
l>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP<P3oon000`000?l0oooP0?ooh007
0?ooh00303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=
0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP0;
0:gHiP0303>QbP3oon00oooP03/0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`
iR40oooP00<000000?ooh03oon00o`3oon0b0?ooh0030000o`3oon00oooP00L0oooP00<0<j7:0:gH
iP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV00`0[MSV00<0<j7:0?oo
h03oon00>`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`000000
oooP0?ooh03o0?ooh3<0oooP00<0003o0?ooh03oon001P3oon000`0cXLX0[MSV0:gHiP0@0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP05
03>QbP2]f>H0[MSV0:gHiP000?l03`2]f>H00`0cXLX0oooP0?ooh00k0?ooh0030000003oon00oooP
0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP=03oon000`000?l0
oooP0?ooh0050?ooh00303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00@0<j7:0:gHiP000000003o402]f>H00`0c
XLX0oooP0?ooh00k0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh003
0000003oon00oooP0?l0oooP=@3oon000`000?l0oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:000000000?l00P00000@03>QbSd0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0f0?ooh0030000o`3oon00oooP00<0oooP
00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV
00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0003o00000002000004d0oooP00<000000?ooh03oon00
403oon0N0?[`iP40oooo000M0?[`iR40oooP0`00003o0?ooh3L0oooP00<0003o0?ooh03oon000P3o
on000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0403>QbP000?l00000000004`0oooP0`00000B0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh3P0oooP00D0003o0?ooh03oon00oooP
03>QbP0B0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV
0:gHiP0C0:gHiP030000o`3oon00oooP04l0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo
000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0i0?ooh0040000o`3oon00oooP03>QbQ80[MSV
00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV0180[MSV
00<0003o03>QbP3oon00D03oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3o
on000`000000oooP0?ooh03o0?ooh3X0oooP00<0003o0?ooh00cXLX04P2]f>H00`0cXLX0[MSV0:gH
iP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`000?l0[MSV03>Q
bP1A0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00
oooP0?l0oooP>P3oon000`000?l0oooP03>QbP0B0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP040000o`2]f>H0[MSV03>QbU40oooP00<0
00000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0k
0?ooh0030000o`0cXLX0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=
0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<000000000o`2]f>H00P2]f>H00`0cXLX0oooP0?ooh01?
0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP
0?l0oooP?03oon000`000?l0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP04000000000?l0000000000080[MSV00<0<j7:
0?ooh03oon00C`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`00
0000oooP0?ooh03o0?ooh3`0oooP00<0<j7:0000o`2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0L0:gH
iP0303>QbP2]f>H0[MSV00d0[MSV400cXLX010000000003o00000000000303>QbU40oooP00<00000
0?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0l0?oo
h00303>QbP2]f>H0003o0100[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP3oon00oooP00d0oooP00<0003o000000000000E@3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh3`0oooP00@0<j7:0:gHiP2]
f>H0003o3`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0?oo
h03oon00303oon000`000?l0oooP0?ooh01F0?ooh0030000003oon00oooP0100oooP7P3jl>H10?oo
o`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooP?03oon001@0cXLX0[MSV0:gHiP2]f>H0003o
00h0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP3oon00oooP
00/0oooP00<0003o0?ooh03oon00E`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0
n_3V8@3oon000`000000oooP0?ooh03o0?ooh3`0oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
oooP0?ooh00:0?ooh0030000o`3oon00oooP05P0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0l0?ooh00303>QbP2]f>H0[MSV00<0[MSV
00@0003o0:gHiP00000000002@2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0
[MSV00<0<j7:0?ooh03oon00203oon020000oe/0oooP00<000000?ooh03oon00403oon0N0?[`iP40
oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon0l0?ooh00303>QbP2]f>H0[MSV00@0[MSV
00@0003o0000000000000000202]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0
[MSV00<0<j7:0?ooh03oon001`3oon000`000?l0oooP0?ooh01K0?ooh0030000003oon00oooP0100
oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0<00000o`3oon0l0?ooh0L0<j7:00@000000000o`000?l0
00002@0cXLXN0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0?ooh03oon001P3oon000`000?l0
oooP0?ooh01J0?ooh0<000004P3oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00
o`3oon140?ooh080000000<0003o0?ooh03oon001P3oon000`0cXLX0[MSV0:gHiP0L0:gHiP0303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0?ooh03oon00103oon020000oel0oooP00<000000?ooh03oon00
403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon170?ooh0030000o`3o
on00oooP00D0oooP00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP3o
on00oooP00<0oooP00<0003o0?ooh03oon00G`3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3o
ool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh4P0oooP00<0003o0?ooh03oon00103oon00
0`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0?ooh03oon000P3oon00
0`000?l0oooP0?ooh01P0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?oo
h0030000003oon00oooP0?l0oooPB@3oon000`000?l0oooP0?ooh0030?ooh00303>QbP2]f>H0[MSV
01`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H01@0cXLX0oooP0?ooh03oon00003o06<0oooP00<00000
0?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon00o`3oon1:0?oo
h080003o0`3oon000`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00@0<j7:0?oo
h0000?l0003oI03oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon000`00
0000oooP0?ooh03o0?ooh4`0oooP0P000?l00`3oon00<j7:0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0000o`3oon00I@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0
n_3V8@3oon000`000000oooP0?ooh03o0?ooh4h0oooP00<0003o03>QbP2]f>H00P00000K0:gHiP03
03>QbP2]f>H0[MSV00X0[MSV0P0000000`2]f>H0003o0?ooh01V0?ooh0030000003oon00oooP0100
oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooPC`3oon020000o`<00000
6P2]f>H<03>QbP8000000P000?l00`0cXLX0oooP0?ooh01U0?ooh0030000003oon00oooP0100oooP
7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003oon00oooP0?l0oooPC`3oon001@0cXLX000000000
o`000?l0000001/0<j7:2`3oon020000o`800000J03oon000`000000oooP0?ooh00@0?ooh1h0n_3V
0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh540oooP0P0000020000ob<0oooP0P00
0?l00`3oon0000000000001Y0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ
0?ooh0030000003oon00oooP0?l0oooPE@3oon020000oal0oooP0P000?m^0?ooh0030000003oon00
oooP0100oooP7P3jl>H10?ooo`007@3jl>HF0?ooh0D000001P3oon000`000000oooP0?ooh03o0?oo
h5L0oooP0P000?lK0?ooh080003oL03oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPF@3oon050000oa40
oooP1@000?mb0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00H0oooP1000003o0?ooh5d0oooP4@000?md0?ooh0@000004P3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<0
00000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon001P3oon00
0`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`
iQL0oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00@0?oo
h1h0n_3V0@3oool001d0n_3V8@3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03o
on00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<000000?ooh03oon004`3oon000`000000oooP
0?ooh0170?ooh0030000003oon00oooP04L0oooP00<000000?ooh03oon00A`3oon000`000000oooP
0?ooh0170?ooh0030000003oon00oooP04L0oooP00<000000?ooh03oon00AP3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP0100oooP7P3jl>H10?ooo`007@3jl>HQ0?ooh0030000003o
on00oooP00@0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00;0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00/0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00;0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00/0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00;0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00/0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon002`3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00D0oooP00<000000?ooh03oon00403oon0N0?[`iP40oooo000M0?[`iR40oooP00<00000
0?ooh03oon00103oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00/0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon002`3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00/0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon002`3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00/0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon002`3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00;0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon001@3oon000`000000oooP0?ooh00@0?ooh1h0n_3V0@3oool001d0n_3V8@3oon3o0000
0>X000004P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`iVP0n_3V100000090?[`iP@00000g`3jl>H10?ooo`00o`3jl>IX
0?[`iP8000003@3jl>H200000=l0n_3V0@3oool00=/0n_3V100000020?[`iPP000000P3jl>H40000
00070?[`iP00000000000000003jl>H000000?[`iP0<000000030?[`iP000000000000@0000000@0
n_3V0000000000000000203jl>H5000000@0n_3V1`0000000`3jl>H000000?[`iP03000000P0n_3V
1@0000020?[`iP@000000P3jl>H5000000X0n_3V1@0000020?[`iPH0000000D0n_3V000000000000
00000?[`iP03000000<0n_3V0P0000030?[`iP<0000000@0n_3V00000000000000000`3jl>H20000
0=l0n_3V0@3oool00=`0n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000030?[`iP07
0000003jl>H000000000003jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP000000000000T0n_3V00@000000?[`iP3jl>H0n_3V0P00
00020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V
0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000<0?[`iP040000003jl>H0n_3V0?[`iP80
00000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000040?[`iP800000103jl>H200000003
0?[`iP000000000000@0n_3V0P00003O0?[`iP40oooo003L0?[`iP80000000<0n_3V000000000000
103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP800000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP800000403jl>H2000000<0n_3V0P0000040?[`iP80
000000<0n_3V000000000000103jl>H2000000D0n_3V0`0000050?[`iP800000g`3jl>H10?ooo`00
g03jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H20000
00030?[`iP000000000000<000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000003P3jl>H3
000000@0n_3V0P0000040?[`iP80000000<0n_3V000000000000103jl>H2000000D0n_3V0`000005
0?[`iP800000g`3jl>H10?ooo`00g03jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H20000
0080n_3V0P0000001P3jl>H000000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P00
0000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V
0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V00T0n_3V0`0000050?[`iP800000
103jl>H2000000030?[`iP000000000000@0n_3V0P0000040?[`iP80000000<0n_3V000000000000
103jl>H200000=l0n_3V0@3oool00=`0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P00
00040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3jl>H500000080n_3V1@00
000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000002P3jl>H500000080n_3V1000
00020?[`iP<0000000<0n_3V0000000000002@3jl>H2000000D0n_3V100000030?[`iPD000001@3j
l>H2000000<0n_3V0`000000103jl>H000000000000000030?[`iP800000g`3jl>H10?ooo`00g03j
l>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0G0?[`iP8000006@3j
l>H2000000<0n_3V00<000000?[`iP3jl>H0403jl>H2000000d0n_3V0P00003O0?[`iP40oooo003K
0?[`iPH00000103jl>H2000002l0n_3V1@00000J0?[`iP<00000603jl>H5000000<0n_3V0P00000=
0?[`iP@000002@3jl>H400000=l0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-4.14696, \
-1.99052, 0.0135363, 0.00697164}}]
}, Open  ]],

Cell["\<\
This animates the Riemann sum as the number of intervals is increased \
exponentially. If you have a very slow machine, you may want to decrease the \
upper limit, 8, to 6. The animation does rather give a picture of a Riemann \
sum fading into an integral.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Animate[
      RiemannSumPlot[#\^2 - 1 &, {0, 2}, E\^n], {n, 1, 8, 
        1/4}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, 
      GeneratedCell]\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .0891 L
.39975 .0891 L
.39975 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .0891 L
.39975 .0891 L
.39975 .16187 L
s
1 .894 .882 r
.39975 .16187 m
.39975 .15633 L
.97619 .15633 L
.97619 .16187 L
F
.804 .522 .247 r
.39975 .16187 m
.39975 .15633 L
.97619 .15633 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.36237 .0891 Mdot
.49096 .15633 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.21053) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
171.938 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.435936) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000P0?[`iP<0
0000103jl>H2000000D0n_3V100000030?[`iP<00000103jl>H3000000<0n_3V0`0000050?[`iP<0
0000103jl>H300000?l0n_3VU@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H500000180n_3V0P0000000`3jl>H00000000000030?[`iP8000001P3j
l>H2000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V00800000103j
l>H2000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V000000000000o`3j
l>JD0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iPD000000`3jl>H2000000030?[`iP00
0000000000P0n_3V1P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000000P3j
l>H2000000030?[`iP00000000000?l0n_3VU03jl>H10?ooo`00803jl>H5000000@0n_3V0P000003
0?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<00000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<00000
0`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD0
00004P3jl>H2000000030?[`iP000000000000P0n_3V00<000000?[`iP3jl>H00P0000060?[`iP80
00001@3jl>H2000000<0n_3V100000050?[`iP8000000P3jl>H2000000030?[`iP00000000000?l0
n_3VU03jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V
0P0000001P3jl>H000000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000103j
l>H000000000003jl>H2000000030?[`iP000000n_3V00800000803jl>H2000000030?[`iP000000
000000T0n_3V00@000000?[`iP0000000000103jl>H3000000<0n_3V00<000000?[`iP3jl>H00P00
00020?[`iP80000000<0n_3V0000000000000`3jl>H3000000<0n_3V1000003o0?[`iYD0n_3V0@3o
ool00200n_3V0P0000020?[`iP80000000<0n_3V0000000000000P0000040?[`iP@0000000<0n_3V
0000000000001@0000020?[`iP@000000P3jl>H500000080n_3V1@00000:0?[`iP8000001@3jl>H3
000000030?[`iP000000000000L000008@3jl>H2000000030?[`iP000000000000T0n_3V00@00000
0?[`iP00000000001P3jl>H200000080n_3V100000030?[`iP80000000<0n_3V0000000000001@3j
l>H200000080n_3V0P00003o0?[`iYL0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2
000000<0n_3V00<000000?[`iP3jl>H0;@3jl>H2000000030?[`iP000000000000X0n_3V0`000003
0?[`iP030000003jl>H0n_3V008000000P3jl>H2000000D0n_3V0P0000000`3jl>H0000000000002
0?[`iP030000003jl>H0n_3V008000000`3jl>H200000?l0n_3VUP3jl>H10?ooo`007`3jl>H60000
00@0n_3V0P00000_0?[`iPD00000<03jl>H3000000`0n_3V0P0000040?[`iP<000000`3jl>H50000
00<0n_3V0`0000040?[`iP<000001@3jl>H300000?l0n_3VU03jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko
0?[`iQP0n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H600000005
0?[`iP00000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103j
l>H000000000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`000004
0?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H1
0?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H01000
0000n_3V0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103j
l>H200000080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H000000000
00030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2
000000030?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P000002
0?[`iP800000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000
000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3j
l>H00000000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`
iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP0000000000
00T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
00000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H0
0000000000020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H30000
0080n_3V0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3j
l>H00000000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H40000
00H0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0
n_3V100000030?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@0
0000103jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0
n_3V0P0000050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V
0P00000;0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:0?[`iP800000
1@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H0
0P00003o0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00
000<0?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00
003o0?[`iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0
n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P00
00020?[`iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`000000
0`3jl>H0000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003j
l>H0000001P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3j
l>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V
100000000`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003j
l>H000000?[`iP03000001L0n_3V1P0000020?[`iP800000103jl>H500000080n_3V1P0000020?[`
iP<00000103jl>H3000000@0n_3V0`0000200?[`iP40oooo000Q0?[`iP80000000<0n_3V00000000
00001@000000103jl>H000000000000000020?[`iP80000000<0n_3V0000000000002@3jl>H50000
00T0n_3V0P00003O0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H20000
0080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P00
00020?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0
n_3V0000003jl>H00P0000090?[`iPD00000303jl>H2000000@0n_3V0P0000040?[`iP8000001`3j
l>H2000000<0n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V008000000P3j
l>H00`000000n_3V0?[`iP02000007l0n_3V0@3oool00280n_3V0`00000Y0?[`iP800000gP3jl>H2
000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2
000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:
0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`iP800000103j
l>H2000000030?[`iP000000n_3V008000006P3jl>H2000000/0n_3V0P0000060?[`iP8000000`3j
l>H2000000030?[`iP000000000000D0n_3V0P0000050?[`iP800000O`3jl>H10?ooo`008P3jl>H3
000001X0n_3V1@00000;0?[`iP800000g@3jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2
000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2
000000030?[`iP000000000000X0n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3j
l>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD00000303j
l>H2000000`0n_3V0P0000050?[`iP8000000`3jl>H2000000030?[`iP000000000000D0n_3V0P00
00050?[`iP800000O`3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002X0n_3V0P00003L
0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3j
l>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3j
l>H2000000030?[`iP000000000000X0n_3V0`000000103jl>H000000000003jl>H200000080n_3V
0P0000020?[`iP<0000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02000001X0n_3V
0P00000=0?[`iP800000103jl>H2000000<0n_3V0P0000000`3jl>H00000000000020?[`iP030000
003jl>H0n_3V008000000`3jl>H300000800n_3V0@3oool00200n_3V0`000000103jl>H000000000
0000000V0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V
100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080
n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`0000000`3jl>H00000000000020?[`iP@0
00000P3jl>H3000000030?[`iP000000000000L000006`3jl>H2000000X0n_3V0P0000000`3jl>H0
0000000000040?[`iP8000000`3jl>H2000000030?[`iP00000000000080n_3V100000060?[`iP80
0000O`3jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000
0000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`iP800000;P3jl>H4000000X0n_3V
0P0000000`3jl>H00000000000020?[`iP@000000`3jl>H2000000030?[`iP00000000000080n_3V
0P0000050?[`iP030000003jl>H0n_3V00800000O`3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00
000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000006@3jl>H3000000030?[`iP00
0000000000800000;`3jl>H2000000/0n_3V0`0000050?[`iP800000103jl>H3000000<0n_3V1@00
00030?[`iP<00000P03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H00000
0000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V
00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00
803jl>H3000000030?[`iP00000000000080000000@0n_3V0000003jl>H000000P3jl>H010000000
n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;0000
00@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H30000
00030?[`iP000000000000H000006P3jl>H500000<L0n_3V0@3oool00240n_3V0P0000000`3jl>H0
000000000005000000050?[`iP00000000000000003jl>H01000000;0?[`iPD000002@3jl>H20000
00030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`
iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0
n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V
0P0000020?[`iP8000002`3jl>H5000000T0n_3V0P00003:0?[`iP40oooo000R0?[`iP<00000:03j
l>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P00
00050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P00
00020?[`iP80000000<0n_3V0000000000000`3jl>H4000001X0n_3V0P0000390?[`iP40oooo000R
0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`iP000000
00000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2
000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H4000000d0n_3V1@00000;0?[`iP800000b03jl>H10?ooo`008@3jl>H2000000030?[`iP000000
000002L0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H2
00000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP800000
0P3jl>H2000001`0n_3V0P0000370?[`iP40oooo000P0?[`iP<0000000@0n_3V0000000000000000
9P3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@00000
0P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@0
0000103jl>H400000080n_3V1@0000030?[`iPD000006@3jl>H2000000030?[`iP00000000000<L0
n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000
403jl>H2000000`0n_3V0P00000h0?[`iP80000000<0n_3V000000000000a`3jl>H10?ooo`00CP3j
l>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<@3j
l>H300000<P0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo000M0?[`iRH0oooP0P00001/0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000
J@3oon0500000080oooP0P0000040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3j
l>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000203oon0010000000
oooP0?ooh000001/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon001`3oon001000
0000oooP0?ooh000001Z0?ooh0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?oo
h0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?oo
h01Z0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?oo
h01Y0?ooh0030000003oon00oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00
oooP000006X0oooP00@000000?ooh03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00
J`3oon000`000000oooP0?ooh0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V
0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0
oooP00<000000?ooh03oon00K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0
oooP00<000000?ooh03oon00JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0
n_3V9P3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<0
0000J`3oon02000002@0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o0000
0>X00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
00000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<0
00000?ooh03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0
oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP
0?ooh0060?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000203oon0J0000ool0oooP`03o
on04000001P0oooP7P3jl>H10?ooo`007@3jl>H:0?ooh0@00000103oon000`000000oooP0?ooh006
0?ooh0030000003oon00oooP02<0oooP20000?oo0?ooh;/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh00[0?oo
h0X0003oo`3oon2a0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh080
0000203oon000`000000oooP0?ooh00e0?ooh0T0003oo`3oon2X0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP03h0oooP20000?oo0?ooh:00oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00AP3o
on050000ool0oooPV`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh01;0?ooh0D0003oo`3oon2F0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0500oooP1@000?oo0?ooh940oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00E@3oon050000ool0
oooPS03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh01J0?ooh0D0003oo`3oon270?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP05l0oooP10000?oo0?ooh8<0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00H`3oon050000ool0oooPOP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh01X0?oo
h0@0003oo`3oon1j0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP06`0oooP10000?oo0?ooh7H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP0`00001`0?ooh0<0003oo`3oon1a0?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00L`3oon040000ool0oooPK`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh01g0?ooh0<0003oo`3oon1/
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
07X0oooP10000?oo0?ooh6P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00OP3oon030000ool0oooPI@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0210?ooh0<0003oo`3oon1R0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP08@0oooP0P00
0?oo0?ooh600oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00QP3oon030000ool0oooPG@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0290?ooh0<0003oo`3oon1J0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP08`0oooP0P000?oo0?ooh5P0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
SP3oon030000ool0oooPE@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh02A0?ooh0<0003oo`3oon1B0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP09@0oooP0`000?oo0?ooh4l0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00U`3oon020000
ool0oooPC@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000009T0
oooP0`000?oo0?ooh4P0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh02L0?ooh0<0003oo`3oon170?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP09l0oooP0P000?oo0?ooh4D0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00X@3oon030000ool0oooP@P3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh02T0?oo
h0<0003oo`3oon0o0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0:L0oooP0P000?oo0?ooh3d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00Z@3oon020000o`80oooP0P00003o0?ooh3L0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00Z`3o
on020000o`<00000o`3oon0f0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooPX`3=QCl010000000003o0000o`00000A0<f5?ol0oooP9@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ0:40onCQ0P0000030000o`h0onCQ00<0cHDo0?ooh03oon00o`3oon0S
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>40YP3oi>420000o``0onCQ00<0cHDo0?ooh03oon00o`3oon0S0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40Z03oi>420000o`X0onCQ00<0cHDo0?ooh03oon00o`3oon0S0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>40ZP3oi>420000o`P0onCQ00<0cHDo0?ooh03oon00o`3oon0S0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>40[03oi>430000o`D0onCQ00<0cHDo0?ooh03oon00o`3oon0S0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>40[`3oi>420000o`<0onCQ00<0cHDo0?ooh03oon00o`3oon0S0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@2a0?oT
h@80003o00<0onCQ0<f5?`3oon00o`3oon0R0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@2c0?oTh@80003oo`3oon0U0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0003o0000o`3o0?ooh2<0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@2d0?oTh@030<f5?`3oon00oooP0080003oo`3oon0Q0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40]03oi>40
0`3=QCl0oooP0?ooh0020?ooh080003oo`3oon0O0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=
QCl0oooP0?ooh0040?ooh080003oo`3oon0M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0
oooP0?ooh0060?ooh080003oo`3oon0K0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP
0?ooh0080?ooh080003oo`3oon0I0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP0?oo
h00:0?ooh080003oo`3oon0G0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP0?ooh00<
0?ooh080003oo`3oon0E0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP0?ooh00>0?oo
h080003oo`3oon0C0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP0?ooh00@0?ooh003
0000o`3oon00oooP0?l0oooP403oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0;@0onCQ00<0cHDo0?ooh03oon00
4@3oon020000ool0oooP403oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0;@0onCQ00<0cHDo0?ooh03oon004`3o
on020000ool0oooP3P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03
000000T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP0?ooh00E0?ooh0030000o`3oon00
oooP0?l0oooP2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP0?ooh00F0?ooh080003oo`3oon0;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP0?ooh00H0?ooh080003oo`3oon090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP0?ooh00J0?ooh080003oo`3oon070?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>40]03oi>400`3=QCl0oooP0?ooh00L0?ooh0030000o`3oon00oooP0?l0oooP103o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ0;@0onCQ00<0cHDo0?ooh03oon007@3oon020000ool0oooP103oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030<f5?`3oi>40onCQ0;@0onCQ00<0cHDo0?ooh03oon007`3oon020000ool0oooP0P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40onCQ0;@0onCQ00<0cHDo0?ooh03oon008@3oon020000ool0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@2d0?oTh@030<f5?`3oon00oooP02<0oooP00<0003o0?ooh03oon00o03oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ0;@0onCQ00<0cHDo0?ooh03oon00903oon020000oo`0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@2d
0?oTh@030<f5?`3oon00oooP02H0oooP0P000?l00`3oon0000000000003g0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40]03oi>400`3=QCl0oooP0?ooh00X0?ooh0040000o`000000000000000?H0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>40]03oi>4[0<f5?`04000000000?l0003o00000>/0cHDo2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh0000007
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40]03oi>400`3=QCl0onCQ0?oTh@0Y
0?oTh@8000000P000?oY0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon04000000P0oooPi`000002
0000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP
000000L0oooP00<000000?ooh03oon00lP3oon000`000?l0oooP0?ooh03`0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<00000
0?ooh03oon00l`3oon020000oo00oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ40oooP0P0000080?ooh0030000003oon00oooP0?D0oooP00<0003o0?ooh03oon00k@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03f0?ooh080
003ok@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03h0?ooh0030000o`3oon00oooP0>X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00n@3oon020000onX0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n`3oon000`000?l0oooP0?ooh03W
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?`0oooP00<0003o0?ooh03oon00iP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03m0?ooh080003oiP3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0030000o`3oon00oooP0><0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on010?ooh080003oh`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh0<0oooP00<0003o0?ooh03oon00h03oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0@0oooP0P000?oP0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP1P3oon000`000?l0oooP0?ooh03M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0<00000o`3oon070?ooh080003of`3oon03000001P0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP2@3oon000`000?l0oooP0?ooh03J0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2P3oon02
0000omX0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0<0?ooh0030000o`3oon00oooP0=L0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0=0?ooh080003oe`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0l0oooP
00<0003o0?ooh03oon00e03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh100oooP0P000?oD0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4P3oon000`000?l0oooP0?ooh03A
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP4`3oon020000om40oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0E0?ooh0030000o`3oon00oooP0<h0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0F0?ooh080003o
cP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh1P0oooP00<0003o0?ooh03oon00b`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1T0oooP0P000?o;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP6`3oon000`00
0?l0oooP0?ooh0380?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon0L0?ooh080003oaP3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP7P3oon000`000?l0oooP0?ooh0350?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7`3oon000`000?l0oooP0?oo
h0340?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP803oon020000ol@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0R0?ooh0030000o`3oon00oooP0<40oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0S0?ooh003
0000o`3oon00oooP0<00oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0T0?ooh080003o`03oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2H0oooP00<0003o0?ooh03oon00_@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh2L0oooP00<0003o0?ooh03oon00_03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2P0oooP0P000?nl0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:P3oon000`000?l0
oooP0?ooh02i0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP:`3oon000`000?l0oooP0?ooh02h0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;03oon020000okP0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0^
0?ooh0030000o`3oon00oooP0;D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`00003o0?ooh2l0oooP00<0003o0?ooh03oon00/P3oon03000001P0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<03oon020000ok@0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0b0?ooh0030000
o`3oon00oooP0;40oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0c0?ooh0030000o`3oon00oooP0;00oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0d0?ooh0030000o`3oon00
oooP0:l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0e0?ooh080003o[`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP00<0003o0?ooh03oon00[03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3P0oooP
00<0003o0?ooh03oon00Z`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh3T0oooP0P000?n[0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>`3oon000`000?l0oooP0?ooh02X
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP?03oon000`000?l0oooP0?ooh02W0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?@3oon000`000?l0oooP0?ooh02V0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
?P3oon020000ojH0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon100?ooh0030000o`3oon00oooP0:<0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon110?ooh0030000o`3oon00
oooP0:80oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?oo
h480oooP00<0003o0?ooh03oon00W`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP@`3oon000`000?l0oooP0?ooh02P0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPA03oon000`000?l0oooP
0?ooh02O0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPA@3oon020000oil0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon170?ooh0030000o`3oon00oooP09`0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon180?oo
h0030000o`3oon00oooP09/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon190?ooh0030000o`3oon00oooP09X0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1:0?ooh0030000
o`3oon00oooP09T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1;0?ooh0030000o`3oon00oooP09P0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1<0?ooh0030000o`3oon00
oooP09L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1=0?ooh0030000o`3oon00oooP09H0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1>0?ooh0030000o`3oon00oooP09D0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000
003oon00oooP0?l0oooPC`3oon020000oiD0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh540oooP00<0
003o0?ooh03oon00TP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon00
0`000000oooP0?ooh0060?ooh0@00000o`3oon1A0?ooh0030000o`3oon00oooP08h0oooP1000000H
0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP
0?l0oooPD`3oon000`000?l0oooP0?ooh02@0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1D0?ooh003
0000o`3oon00oooP08l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP
0P0000080?ooh0030000003oon00oooP0?l0oooPE@3oon000`000?l0oooP0?ooh02>0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPEP3o
on000`000?l0oooP0?ooh02=0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPE`3oon000`000?l0oooP0?ooh02<0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF03oon000`00
0?l0oooP0?ooh02;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPF@3oon020000oh/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1K0?ooh0030000o`3oon00oooP08P0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1L0?ooh0030000o`3oon00oooP08L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1M0?ooh0030000o`3oon00oooP08H0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1N0?oo
h0030000o`3oon00oooP08D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1O0?ooh0030000o`3oon00oooP08@0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?ooh0030000
o`3oon00oooP08<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
003o0?ooh640oooP00<0003o0?ooh03oon00P03oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPHP3oon000`000?l0oooP0?ooh0210?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH`3oon020000
oh40oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1U0?ooh0030000o`3oon00oooP07h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1V0?ooh0030000o`3oon00oooP07d0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1W0?ooh0030000o`3oon00oooP07`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1X0?ooh0030000o`3oon00oooP07/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Y0?oo
h0030000o`3oon00oooP07X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1Z0?ooh0030000o`3oon00oooP07T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1[0?ooh0030000
o`3oon00oooP07P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1/0?ooh0030000o`3oon00oooP07L0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1]0?ooh0030000o`3oon00
oooP07H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1^0?ooh0030000o`3oon00oooP07D0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1_0?ooh0030000o`3oon00oooP07@0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1`0?ooh0030000o`3oon00oooP07<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh740oooP0P000?ma0?ooh0<00000603oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1c0?ooh0030000o`3oon00oooP0700oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1d0?oo
h0030000o`3oon00oooP06l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1e0?ooh0030000o`3oon00oooP06h0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1f0?ooh0030000
o`3oon00oooP06d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1g0?ooh0030000o`3oon00oooP06`0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1h0?ooh0030000o`3oon00
oooP06/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1i0?ooh0030000o`3oon00oooP06X0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1j0?ooh0030000o`3oon00oooP06T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1k0?ooh0030000o`3oon00oooP06P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1l0?ooh0030000o`3oon00oooP06L0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1m
0?ooh0030000o`3oon00oooP06H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1n0?ooh0030000o`3oon00oooP06D0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1o0?ooh003
0000o`3oon00oooP06@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`00003o0?ooh800oooP00<0003o0?ooh03oon00H@3oon03000001P0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPP@3oon000`000?l0oooP0?ooh01R0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPPP3oon00
0`000?l0oooP0?ooh01Q0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPP`3oon000`000?l0oooP0?ooh01P0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQ03oon000`000?l0
oooP0?ooh01O0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPQ@3oon000`000?l0oooP0?ooh01N0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQP3oon000`000?l0oooP0?oo
h01M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPQ`3oon000`000?l0oooP0?ooh01L0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPR03oon000`000?l0oooP0?ooh01K0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPR@3oon000`000?l0oooP0?ooh01J0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPRP3oon000`000?l0oooP0?ooh01I0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPR`3o
on000`000?l0oooP0?ooh01H0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPS03oon000`000?l0oooP0?ooh01G0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPS@3oon000`00
0?l0oooP0?ooh01F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon2>0?ooh0030000o`3oon00oooP05<0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh8l0oooP00<0003o0?ooh03oon00E03oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh900oooP00<0
003o0?ooh03oon00D`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh940oooP00<0003o0?ooh03oon00DP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh980oooP00<0003o0?oo
h03oon00D@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh980oooP00<0003o0?ooh03oon00D@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9<0oooP00<0003o0?ooh03oon00
D03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh9@0oooP00<0003o0?ooh03oon00C`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9D0oooP00<0003o0?ooh03oon00CP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h9H0oooP00<0003o0?ooh03oon00C@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh9L0oooP00<0003o0?ooh03oon00C03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9P0oooP
00<0003o0?ooh03oon00B`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh9T0oooP00<0003o0?ooh03oon00BP3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V403oon04000000L0oooP00<000000?ooh03oon00o`3oon2J
0?ooh0030000o`3oon00oooP04T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ00oooP00<000000?ooh03oon00203oon000`000000oooP0?ooh03o0?ooh9/0oooP00<0003o0?oo
h03oon00B03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon000`000000
oooP0?ooh0070?ooh0@00000o`3oon2J0?ooh0030000o`3oon00oooP04D0oooP1000000H0?ooh1h0
n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooP
W03oon000`000?l0oooP0?ooh0170?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon2M0?ooh0030000
o`3oon00oooP04H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P00
00080?ooh0030000003oon00oooP0?l0oooPWP3oon000`000?l0oooP0?ooh0150?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW`3oon00
0`000?l0oooP0?ooh0140?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPX03oon000`000?l0oooP0?ooh0130?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX@3oon000`000?l0
oooP0?ooh0120?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPXP3oon000`000?l0oooP0?ooh0110?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX`3oon000`000?l0oooP0?oo
h0100?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPY03oon000`000?l0oooP0?ooh00o0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon000`000?l0oooP0?ooh00n0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPYP3oon000`000?l0oooP0?ooh00m0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY`3oon000`000?l0oooP0?ooh00l0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ03o
on000`000?l0oooP0?ooh00k0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<00000o`3oon2Y0?ooh0030000o`3oon00oooP03P0oooP0`00000H0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP00<0003o0?ooh03oon00>@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0
oooP00<0003o0?ooh03oon00>@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh:/0oooP00<0003o0?ooh03oon00>03oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:`0oooP00<0
003o0?ooh03oon00=`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:d0oooP00<0003o0?ooh03oon00=P3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:h0oooP00<0003o0?oo
h03oon00=@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh:l0oooP00<0003o0?ooh03oon00=03oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;00oooP00<0003o0?ooh03oon00
<`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh;40oooP00<0003o0?ooh03oon00<P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;80oooP00<0003o0?ooh03oon00<@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;<0oooP00<0003o0?ooh03oon00<03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh;@0oooP00<0003o0?ooh03oon00;`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;D0oooP
00<0003o0?ooh03oon00;P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on0300000?l0oooP]P3oon000`000?l0oooP0?ooh00[0?ooh0<00000603oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh0030000o`3oon00oooP02`0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?oo
h0030000o`3oon00oooP02`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2h0?ooh0030000o`3oon00oooP02/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh0030000
o`3oon00oooP02X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2j0?ooh0030000o`3oon00oooP02T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2k0?ooh0030000o`3oon00
oooP02P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2l0?ooh0030000o`3oon00oooP02L0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2l0?ooh0030000o`3oon00oooP02L0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2m0?ooh0030000o`3oon00oooP02H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n0?ooh0030000o`3oon00oooP02D0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2o
0?ooh0030000o`3oon00oooP02@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon300?ooh0030000o`3oon00oooP02<0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon310?ooh003
0000o`3oon00oooP0280oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon310?ooh0030000o`3oon00oooP0280oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh<80oooP00<0003o0?ooh03oon007`3o
on03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP``3oon00
0`000?l0oooP0?ooh00P0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPa03oon000`000?l0oooP0?ooh00O0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa@3oon000`000?l0
oooP0?ooh00N0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPaP3oon000`000?l0oooP0?ooh00M0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPaP3oon000`000?l0oooP0?oo
h00M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPa`3oon000`000?l0oooP0?ooh00L0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb03oon000`000?l0oooP0?ooh00K0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPb@3oon000`000?l0oooP0?ooh00J0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPbP3oon000`000?l0oooP0?ooh00I0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb`3o
on000`000?l0oooP0?ooh00H0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPb`3oon000`000?l0oooP0?ooh00H0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPc03oon000`00
0?l0oooP0?ooh00G0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPc@3oon000`000?l0oooP0?ooh00F0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon3>0?ooh0030000o`3oon00oooP01<0oooP
0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<l0oooP00<0
003o0?ooh03oon00503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh=00oooP00<0003o0?ooh03oon004`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=40oooP00<0003o0?oo
h03oon004P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh=40oooP00<0003o0?ooh03oon004P3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=80oooP00<0003o0?ooh03oon00
4@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh=<0oooP00<0003o0?ooh03oon00403oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=@0oooP00<0003o0?ooh03oon003`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h=D0oooP00<0003o0?ooh03oon003P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh=H0oooP00<0003o0?ooh03oon003@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=L0oooP
00<0003o0?ooh03oon00303oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh=L0oooP00<0003o0?ooh03oon00303oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon3H
0?ooh0030000o`3oon00oooP00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh=T0oooP00<0003o
0?ooh03oon002P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`00
0000oooP0?ooh0060?ooh0@00000o`3oon3I0?ooh0030000o`3oon00oooP00H0oooP1000000H0?oo
h1h0n_3V0@3oool001d0n_3V4`3oon000`000000oooP0?ooh0050?ooh0030000003oon00oooP0?l0
oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP
0?ooh00000070?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a
0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooPo`00003Z000001P0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003L0?[`iP@000000P3jl>H800000080n_3V
100000001`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H00000000000040000
00040?[`iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`000009
0?[`iPD000000P3jl>H400000080n_3V1@00000B0?[`iPH000001P3jl>H00`000000n_3V0?[`iP04
0?[`iP<0000000@0n_3V0000000000000000i03jl>H10?ooo`00g@3jl>H200000080n_3V0P000003
0?[`iP8000000`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@00000
0P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
2@3jl>H010000000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H20000
00030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
01H0n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003U0?[`
iP40oooo003M0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P0000050?[`iP80
000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`
iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP800000303jl>H5000000D0n_3V0P0000060?[`iPD000001P3jl>H300000>H0n_3V0@3oool00=d0
n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`iP00000000000?[`iP000000n_3V0P000000
0`3jl>H000000000000300000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000002`3jl>H3000000<0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000001H0n_3V0P00
00080?[`iP030000003jl>H0n_3V00H0n_3V0`00003V0?[`iP40oooo003M0?[`iP8000000P3jl>H2
000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V
0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
0000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003j
l>H00P00000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP<0000000<0n_3V0000003j
l>H04P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000>D0
n_3V0@3oool00=d0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P0000040?[`iP@00000
00<0n_3V0000000000001@0000020?[`iP@000000P3jl>H500000080n_3V1@00000:0?[`iP800000
1@3jl>H3000000030?[`iP000000000000L000002`3jl>H500000080n_3V100000020?[`iP<00000
00<0n_3V0000000000004`3jl>H2000000l0n_3V0`0000001@3jl>H00000000000000000n_3V00@0
0000g`3jl>H10?ooo`00g@3jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V
0?[`iP0H0?[`iP8000008@3jl>H4000001P0n_3V00<000000?[`iP3jl>H0g`3jl>H10?ooo`00g03j
l>H6000000@0n_3V0P00000_0?[`iPD000006`3jl>H300000240n_3V0P00000I0?[`iP030000003j
l>H0n_3V0=h0n_3V0@3oool00?l0n_3VN03jl>H00`000000n_3V0?[`iP3M0?[`iP40oooo003o0?[`
iWD0n_3V00@000000?[`iP3jl>H00000g`3jl>H10?ooo`00o`3jl>If0?[`iP800000h03jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .02917 L
.1878 .02917 L
.1878 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .02917 L
.1878 .02917 L
.1878 .16187 L
s
.678 .847 .902 r
.1878 .16187 m
.1878 .17334 L
.57046 .17334 L
.57046 .16187 L
F
.2 .63 .79 r
.1878 .16187 m
.1878 .17334 L
.57046 .17334 L
.57046 .16187 L
s
.678 .847 .902 r
.57046 .16187 m
.57046 .44847 L
.97619 .44847 L
.97619 .16187 L
F
.2 .63 .79 r
.57046 .16187 m
.57046 .44847 L
.97619 .44847 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.17304 .02917 Mdot
.51821 .17334 Mdot
.84137 .44847 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.852029) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.41155) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000G0?[`iPH0
00000P3jl>H2000000D0n_3V100000020?[`iPH0000000<0n_3V000000000000100000020?[`iP<0
0000103jl>H300000?l0n_3VY03jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000`0n_3V0P0000040?[`iP8000001P3jl>H2000000D0n_3V0P00
00050?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V00<000000?[`iP3jl>H00P00
003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2
000000D0n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP000000000000d0n_3V0P0000020?[`iP80000000@0n_3V
000000000000n_3V0P0000000`3jl>H000000?[`iP02000001X0n_3V0P0000090?[`iPH00000103j
l>H2000000D0n_3V0P0000060?[`iP8000001@3jl>H200000?l0n_3VX`3jl>H10?ooo`00803jl>H5
000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`
iP000000000000<000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
0000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003j
l>H00P0000090?[`iPD00000303jl>H2000000T0n_3V00<000000?[`iP3jl>H00P0000050?[`iP80
00001@3jl>H2000000H0n_3V0P0000050?[`iP800000o`3jl>JS0?[`iP40oooo000P0?[`iP800000
0P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP00
0000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000J0?[`iP8000002P3jl>H010000000n_3V0000000000050?[`iP8000001@3j
l>H2000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V00800000o`3j
l>JS0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4
000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2
000000D0n_3V0`0000000`3jl>H0000000000007000001/0n_3V0P00000:0?[`iP040000003jl>H0
0000000000D0n_3V0P0000050?[`iP8000000`3jl>H4000000<0n_3V1000003o0?[`iZ@0n_3V0@3o
ool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H4
000000/0n_3V0`0000030?[`iP@000000`3jl>H4000000<0n_3V0P0000050?[`iP800000o`3jl>JV
0?[`iP40oooo000O0?[`iPH00000103jl>H2000002l0n_3V1@00000Y0?[`iP800000303jl>H20000
00D0n_3V0P0000050?[`iP8000000`3jl>H500000080n_3V1@00003o0?[`iZ<0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H4
00000?l0n_3Vo`3jl>HH0?[`iP40oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200
n_3V1P0000001@3jl>H00000000000000000n_3V00<000000P3jl>H3000000<0n_3V100000030?[`
iP80000000@0n_3V000000000000n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P000005
0?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P00003o
0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H20000
0080n_3V00@000000?[`iP00000000000`3jl>H01@000000n_3V000000000000n_3V00<000000P3j
l>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0
n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2
000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H2000000D0n_3V0P000002
0?[`iP8000000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P000000
0`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`
iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V1P0000000`3jl>H00000000000020?[`
iP8000000P3jl>H2000000D0n_3V1@0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3j
l>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80
000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000020?[`iP80000000@0n_3V00000000
0000n_3V0`0000020?[`iP<0000000<0n_3V0000003jl>H0103jl>H2000000<0n_3V0P00000`0?[`
iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H40000
00<0n_3V100000060?[`iP800000o`3jl>JM0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080
n_3V1@0000030?[`iP@000000`3jl>H2000000030?[`iP000000000000@0000000<0n_3V00000000
00000P3jl>H4000000@0n_3V0P00000`0?[`iP80000000<0n_3V0000000000002@3jl>H2000000D0
n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000080?[`iP800000o`3jl>JM0?[`iP40
oooo000R0?[`iP8000002`3jl>H200000280n_3V0P00000`0?[`iP80000000<0n_3V000000000000
2P3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000040?[`iP030000
003jl>H0n_3V00800000o`3jl>JM0?[`iP40oooo000P0?[`iPH000002@3jl>H200000200n_3V1000
000a0?[`iP<00000303jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`00
00020?[`iPD00000o`3jl>JM0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`
iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP040000003jl>H0
00000?[`iP8000000P3jl>H00`000000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`iP40oooo000P
0?[`iP<0000000<0n_3V0000000000000P0000001@3jl>H000000?[`iP000000n_3V00<000000P3j
l>H00`000000n_3V0000000H0?[`iPD00000f`3jl>H4000000@0n_3V2`0000040?[`iP<000000P3j
l>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`000000103jl>H000000000
000000080?[`iP@0000000<0n_3V0000000000000P3jl>H400000080n_3V1@0000001`3jl>H00000
000000000000n_3V0000003jl>H00`00000H0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`
iP<000000`3jl>H5000000<0n_3V0`0000030?[`iPD000000P3jl>H3000007X0n_3V0@3oool00240
n_3V0P0000000`3jl>H0000000000005000000040?[`iP000000000000000080n_3V0P0000000`3j
l>H00000000000090?[`iPD000002@3jl>H200000=l0n_3V0P0000040?[`iP8000000P3jl>H20000
0080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P000002
0?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0
n_3V0000000000002P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3j
l>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0
n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP030000003j
l>H0n_3V008000000P3jl>H2000000D0n_3V0P0000000`3jl>H00000000000020?[`iP8000001`3j
l>H2000007T0n_3V0@3oool00280n_3V0`00000Y0?[`iP800000gP3jl>H2000000@0n_3V0P000002
0?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V
00000000000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP00
0000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H000000000
00050?[`iP8000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000030?[`iP8000001`3j
l>H2000007P0n_3V0@3oool00280n_3V0`00000J0?[`iPD000002`3jl>H200000=d0n_3V10000003
0?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V
00000000000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0
n_3V0000000000001@3jl>H2000000@0n_3V0P0000030?[`iP80000000<0n_3V000000000000103j
l>H2000000@0n_3V1000001h0?[`iP40oooo000Q0?[`iP80000000<0n_3V000000000000:P3jl>H2
00000=`0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP000000
n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P00
00020?[`iP80000000<0n_3V0000000000002P3jl>H3000000040?[`iP00000000000?[`iP800000
0P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP02000000030?[`iP000000n_3V00800000
603jl>H2000000030?[`iP000000000000X0n_3V0`0000030?[`iP030000003jl>H0n_3V00800000
1@3jl>H200000080n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H2000000030?[`
iP000000000007P0n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP800000
00<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<00000
00@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@0
00000P3jl>H5000000/0n_3V0`0000000`3jl>H00000000000020?[`iP@000000P3jl>H300000003
0?[`iP000000000000L000006@3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H0
0000000000020?[`iP@000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000007P0
n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000
403jl>H2000000`0n_3V0P00000R0?[`iP8000000P3jl>H2000002h0n_3V0P0000000`3jl>H00000
000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000D0n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H000000000001h0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P00
00060?[`iP800000103jl>H2000000H0n_3V0P00000I0?[`iP<0000000<0n_3V0000000000000P00
000^0?[`iP<000002`3jl>H3000000<0n_3V1@0000030?[`iP<00000103jl>H3000000@0n_3V0`00
00040?[`iP<00000N@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H00000
0000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V
00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00
803jl>H3000000030?[`iP00000000000080000000@0n_3V0000003jl>H000000P3jl>H010000000
n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;0000
00@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H30000
00030?[`iP000000000000H000006`3jl>H300000<P0n_3V0@3oool00240n_3V0P0000000`3jl>H0
000000000005000000050?[`iP00000000000000003jl>H01000000;0?[`iPD000002@3jl>H20000
00030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`
iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0
n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V
0P0000020?[`iP8000002`3jl>H5000000T0n_3V00<000000?[`iP3jl>H00P0000370?[`iP40oooo
000R0?[`iP<00000:03jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3j
l>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3j
l>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H4000001`0n_3V0P00
00370?[`iP40oooo000R0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2
000000030?[`iP00000000000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P000006
0?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H4000000d0n_3V1@00000<0?[`iP800000a`3jl>H10?ooo`008@3jl>H2
000000030?[`iP000000000002L0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V
0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P00
00040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00
000000000?[`iP8000000P3jl>H2000001X0n_3V0`0000380?[`iP40oooo000P0?[`iP<0000000@0
n_3V00000000000000009P3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000
000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0
n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@0000030?[`iPD00000703jl>H200000<L0
n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000
403jl>H2000000`0n_3V0P00000h0?[`iP030000003jl>H0n_3V00800000a`3jl>H10?ooo`00CP3j
l>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<@3j
l>H300000<P0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo000M0?[`iRH0oooP0P00001/0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000
J@3oon0500000080oooP0P0000040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3j
l>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000203oon0010000000
oooP0?ooh000001/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon001`3oon001000
0000oooP0?ooh000001Z0?ooh0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?oo
h0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?oo
h01Z0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?oo
h01Y0?ooh0030000003oon00oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00
oooP000006X0oooP00@000000?ooh03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00
J`3oon000`000000oooP0?ooh0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V
0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0
oooP00<000000?ooh03oon00K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0
oooP00<000000?ooh03oon00JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0
n_3V9P3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<0
0000J`3oon02000002@0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o0000
0>X00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
00000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<0
00000?ooh03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0
oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP
0?ooh0060?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000203oon0J0000ool0oooP`03o
on04000001P0oooP7P3jl>H10?ooo`007@3jl>H:0?ooh0@00000103oon000`000000oooP0?ooh006
0?ooh0030000003oon00oooP02<0oooP20000?oo0?ooh;/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh00[0?oo
h0X0003oo`3oon2a0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh080
0000203oon000`000000oooP0?ooh00e0?ooh0T0003oo`3oon2X0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP03h0oooP20000?oo0?ooh:00oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00AP3o
on050000o`H0oooP0P00003o0?ooh9<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00B`3oon050000o`@00000o`3oon2B0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPA`3=QCl50000
o`D0cHDoo`3oon2<0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40A@3oi>4200000080onCQ1@000?oo0?ooh8`0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`000?l0003o00<0003oo`3oon270?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh0030?ooh0@0003oo`3oon230?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh0070?ooh0D0003oo`3oon1n0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40C@3oi>400`3=QCl0oooP0?ooh00<0?ooh0@0003oo`3oon1j0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>40C@3oi>400`3=QCl0oooP0?ooh00@0?ooh0@0003oo`3oon1f0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5
?`3oon00oooP01@0oooP0`000?oo0?ooh740oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon005`3o
on040000ool0oooPK`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon006`3oon03
0000ool0oooPK03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon007P3oon040000
ool0oooPJ03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon008P3oon030000ool0
oooPI@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon009@3oon030000ool0oooP
HP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon00:03oon020000ool0oooPH03o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon00:P3oon030000ool0oooPG@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon00;@3oon030000ool0oooPFP3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon00<03oon020000ool0oooPF03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon00<P3oon030000ool0oooPE@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ04d0onCQ00<0cHDo0?ooh03oon00=@3oon030000ool0oooPDP3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ04d0onCQ00<0cHDo0?ooh03oon00>03oon030000ool0oooPC`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
04d0onCQ00<0cHDo0?ooh03oon00>`3oon020000ool0oooPC@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0
oooP0?ooh00m0?ooh0<0003oo`3oon180?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP0400oooP
0`000?oo0?ooh4L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP04<0oooP0P00
0?oo0?ooh4D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP04D0oooP0`000?oo
0?ooh480oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP04P0oooP0`000?oo0?oo
h3l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP04/0oooP0P000?oo0?ooh3d0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP04d0oooP0P000?oo0?ooh3/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP04l0oooP0P000?oo0?ooh3T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP0540oooP0P000?oo0?ooh3L0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP05<0oooP0`000?oo0?ooh3@0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP05H0oooP0P000?oo0?ooh380oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@1=0?oTh@030<f5?`3oon00oooP05P0oooP0P000?oo0?ooh300oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@1=0?oTh@030<f5?`3oon00oooP05X0oooP0P000?oo0?ooh2h0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1=
0?oTh@030<f5?`3oon00oooP05`0oooP0`000?oo0?ooh2/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1=0?oT
h@030<f5?`3oon00oooP05l0oooP0P000?oo0?ooh2T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03o
on00H@3oon020000ool0oooP9@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh01S0?ooh080003o
o`3oon0U0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh01U0?ooh080003oo`3o
on0S0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh01W0?ooh080003oo`3oon0Q
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh01Y0?ooh080003oo`3oon0O0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh01[0?ooh080003oo`3oon0M0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh01]0?ooh080003oo`3oon0K0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh01_0?ooh080003oo`3oon0I0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh01a0?ooh080003oo`3oon0G0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40C@3oi>400`3=QCl0oooP0?ooh01c0?ooh080003oo`3oon0E0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>40C@3oi>400`3=QCl0oooP0?ooh01e0?ooh080003oo`3oon0C0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
C@3oi>400`3=QCl0oooP0?ooh01g0?ooh0030000o`3oon00oooP0?l0oooP403oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ04d0onCQ00<0cHDo0?ooh03oon00N03oon020000ool0oooP403oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ04d0onCQ00<0cHDo0?ooh03oon00NP3oon020000ool0oooP3P3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=
QCl0oooP0?ooh01l0?ooh0030000o`3oon00oooP0?l0oooP2@3oon03000001P0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0
oooP0?ooh01m0?ooh080003oo`3oon0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP
0?ooh01o0?ooh080003oo`3oon090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?oo
h0210?ooh080003oo`3oon070?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh023
0?ooh0030000o`3oon00oooP0?l0oooP103oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?oo
h03oon00Q03oon020000ool0oooP103oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03o
on00QP3oon020000ool0oooP0P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon00
R03oon020000ool0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP08X0oooP00<0
003o0?ooh03oon00o03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04d0onCQ00<0cHDo0?ooh03oon00R`3oon02
0000oo`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@1=0?oTh@030<f5?`3oon00oooP08d0oooP0P000?oj0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh02?0?ooh0030000o`3oon00oooP0?L0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP0?ooh02@0?ooh080003o
m`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?oo
h00000070?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40C@3oi>400`3=QCl0oooP
0?ooh02B0?ooh080003om@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403o
on0010000000oooP0?ooh00000070?ooh0@00000203oon3W00000080003oj00000080?ooh0@00000
603oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP
0?ooh01I0?ooh00303>QbP2]f>H0[MSV09H0[MSV00<0003o0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV
0:gHiP330:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh01I0?ooh00303>Q
bP2]f>H0[MSV09L0[MSV0P000?lN0:gHiP0303>QbP2]f>H0[MSV0<<0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<0
00000?ooh03oon00F@3oon000`0cXLX0[MSV0:gHiP2I0:gHiP030000o`2]f>H0[MSV01/0[MSV00<0
<j7:0:gHiP2]f>H0``2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP05T0oooP00<0<j7:0:gHiP2]f>H0VP2]f>H2
0000o`030:gHiP000000000001P0[MSV00<0<j7:0:gHiP2]f>H0``2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
05T0oooP00<0<j7:0:gHiP2]f>H0W02]f>H010000?l0000000000000000G0:gHiP0303>QbP2]f>H0
[MSV0<<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh01I0?ooh9l0<j7:00@000000000o`000?l00000600cXL[5
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00n@3oon02000000030000o`3oon00oooP01D0oooP00<0<j7:0:gH
iP2]f>H0``2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?`0oooP00<0003o0?ooh03oon00503oon000`0cXLX0
[MSV0:gHiP330:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o@3oon020000oa@0oooP00<0<j7:0:gHiP2]f>H0
``2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP00<0003o0?ooh03oon004@3oon000`0cXLX0[MSV0:gH
iP330:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon010?ooh080003o4@3oon000`0cXLX0[MSV0:gHiP33
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon030?ooh0030000o`3oon00oooP00h0oooP00<0<j7:0:gH
iP2]f>H0``2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP103oon020000o`h0oooP00<0<j7:0:gHiP2]
f>H0``2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP1P3oon000`000?l0oooP0?ooh00;0?ooh00303>Q
bP2]f>H0[MSV0<<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon0300000?l0oooP1`3oon020000o`/0oooP00<0<j7:0:gHiP2]f>H0``2]
f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon090?ooh0030000o`3oon00oooP00P0oooP00<0<j7:0:gHiP2]f>H0``2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP2P3oon020000o`P0oooP00<0<j7:0:gHiP2]f>H0``2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP303oon000`000?l0oooP0?ooh0050?ooh00303>QbP2]f>H0[MSV0<<0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0d0oooP0P000?l50?ooh00303>QbP2]f>H0[MSV0<<0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh0l0oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gH
iP330:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@0?ooh080003o0P3oon000`0cXLX0[MSV0:gHiP33
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030000o`3oon00<j7:0<D0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh1<0oooP0P000?o50:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>Q
bP000?l0[MSV0<<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00@0<j7:0:gHiP000?l0003o
`P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP503oon001@0cXLX0[MSV0:gHiP2]f>H0003o0<40[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H00P2]f>H20000okl0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP2l
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`00003o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H01@2]f>H20000ok`0[MSV00<0<j7:0?oo
h03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP503oon000`0cXLX0[MSV0:gHiP070:gHiP030000o`2]f>H0[MSV0;T0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP2h0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV00T0[MSV0P000?nh0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gHiP2]f>H0]@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP0<0:gHiP030000o`2]f>H0[MSV
0;@0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H03@2]f>H20000ok@0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H03`2]f>H00`000?l0[MSV
0:gHiP2a0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV0100[MSV00<0
003o0:gHiP2]f>H0/02]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP0A
0:gHiP80003o/02]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP0C0:gH
iP030000o`2]f>H0[MSV0:d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]
f>H0502]f>H00`000?l0[MSV0:gHiP2/0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>Q
bP2]f>H0[MSV01D0[MSV0P000?n/0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]
f>H0[MSV01L0[MSV00<0003o0:gHiP2]f>H0Z@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0D0?ooh00303>QbP2]f>H0
[MSV01P0[MSV00<0003o0:gHiP2]f>H0Z02]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV
01T0[MSV0P000?nX0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV01/0
[MSV00<0003o0:gHiP2]f>H0Y@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV
0:gHiP0L0:gHiP030000o`2]f>H0[MSV0:@0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0
<j7:0:gHiP2]f>H07@2]f>H00`000?l0[MSV0:gHiP2S0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D
0?ooh00303>QbP2]f>H0[MSV01h0[MSV0P000?nS0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?oo
h00303>QbP2]f>H0[MSV0200[MSV00<0003o0:gHiP2]f>H0X02]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP503oon000`0cXLX0[MSV0:gHiP0Q0:gHiP030000o`2]f>H0[MSV09l0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H08P2]f>H20000oil0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0902]f>H00`000?l0[MSV0:gHiP2L0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV02D0[MSV00<0003o0:gHiP2]f>H0V`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP0V0:gHiP030000o`2]f>H0[MSV
09X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H09`2]f>H20000oiX0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0:@2]f>H00`000?l0[MSV
0:gHiP2G0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV02X0[MSV00<0
003o0:gHiP2]f>H0UP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0D0?ooh00303>QbP2]f>H0[MSV02/0[MSV00<0003o
0:gHiP2]f>H0U@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV02`0[MSV00<0003o0:gH
iP2]f>H0U02]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP0]0:gHiP03
0000o`2]f>H0[MSV09<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0
;P2]f>H20000oi<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0<02]
f>H00`000?l0[MSV0:gHiP2@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0
[MSV0340[MSV00<0003o0:gHiP2]f>H0S`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0c
XLX0[MSV0:gHiP0b0:gHiP030000o`2]f>H0[MSV08h0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0
oooP00<0<j7:0:gHiP2]f>H0<`2]f>H00`000?l0[MSV0:gHiP2=0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0D0?ooh00303>QbP2]f>H0[MSV03@0[MSV00<0003o0:gHiP2]f>H0S02]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP0e0:gHiP030000o`2]f>H0[MSV08/0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0=P2]f>H00`000?l0[MSV0:gHiP2:
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0003o0:gH
iP2]f>H0R@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>H@0?ooh0D000001P3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]
f>H0>02]f>H20000ohT0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooP
503oon000`0cXLX0[MSV0:gHiP0j0:gHiP030000o`2]f>H0[MSV08H0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?oo
h0060?ooh0@00000o`3oon0C0?ooh00303>QbP2]f>H0[MSV03/0[MSV00<0003o0:gHiP2]f>H0Q@2]
f>H00`0cXLX0oooP0?ooh0060?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ80oooP00<00000
0?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0?02]f>H0
0`000?l0[MSV0:gHiP240:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?oo
h1@0oooP00<0<j7:0:gHiP2]f>H0?@2]f>H00`000?l0[MSV0:gHiP230:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh003
0000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP0n0:gHiP030000o`2]f>H0[MSV0880
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0?`2]f>H00`000?l0[MSV
0:gHiP210:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV0400[MSV00<0
003o0:gHiP2]f>H0P02]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP11
0:gHiP030000o`2]f>H0[MSV07l0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gH
iP2]f>H0@P2]f>H20000ogl0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]
f>H0A02]f>H00`000?l0[MSV0:gHiP1l0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>Q
bP2]f>H0[MSV04D0[MSV00<0003o0:gHiP2]f>H0N`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503o
on000`0cXLX0[MSV0:gHiP160:gHiP030000o`2]f>H0[MSV07X0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0A`2]f>H00`000?l0[MSV0:gHiP1i0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV04P0[MSV00<0003o0:gHiP2]f>H0N02]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP190:gHiP030000o`2]f>H0[MSV07L0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon0300000?l0oooP503oon000`0cXLX0[MSV0:gHiP1:0:gHiP030000o`2]f>H0[MSV07H0[MSV
00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP1;0:gHiP030000o`2]f>H0[MSV07D0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0C02]f>H20000ogD0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0CP2]f>H00`000?l0[MSV0:gHiP1b0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV04l0[MSV00<0003o0:gHiP2]
f>H0L@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP1@0:gHiP030000
o`2]f>H0[MSV0700[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0D@2]
f>H00`000?l0[MSV0:gHiP1_0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0
[MSV0580[MSV00<0003o0:gHiP2]f>H0KP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0c
XLX0[MSV0:gHiP1C0:gHiP030000o`2]f>H0[MSV06d0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0
oooP00<0<j7:0:gHiP2]f>H0E02]f>H00`000?l0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0D0?ooh00303>QbP2]f>H0[MSV05D0[MSV00<0003o0:gHiP2]f>H0J`2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP1F0:gHiP030000o`2]f>H0[MSV06X0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0E`2]f>H00`000?l0[MSV0:gHiP1Y
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV05P0[MSV00<0003o0:gH
iP2]f>H0J02]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP1I0:gHiP03
0000o`2]f>H0[MSV06L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP503oon000`0cXLX0[MSV0:gHiP1J0:gHiP80003o
I`2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV05`0[MSV00<0003o0:gHiP2]f>H0I02]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP1M0:gHiP030000o`2]f>H0
[MSV06<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0GP2]f>H00`00
0?l0[MSV0:gHiP1R0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV05l0
[MSV00<0003o0:gHiP2]f>H0H@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV
0:gHiP1P0:gHiP030000o`2]f>H0[MSV0600[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0
<j7:0:gHiP2]f>H0H@2]f>H00`000?l0[MSV0:gHiP1O0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D
0?ooh00303>QbP2]f>H0[MSV0680[MSV00<0003o0:gHiP2]f>H0GP2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP503oon000`0cXLX0[MSV0:gHiP1S0:gHiP030000o`2]f>H0[MSV05d0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0I02]f>H00`000?l0[MSV0:gHiP1L0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV06D0[MSV00<0003o0:gHiP2]f>H0
F`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP1V0:gHiP030000o`2]
f>H0[MSV05X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0I`2]f>H0
0`000?l0[MSV0:gHiP1I0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV
06P0[MSV00<0003o0:gHiP2]f>H0F02]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0D0?ooh00303>QbP2]f>H0[MSV06T0
[MSV00<0003o0:gHiP2]f>H0E`2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV06X0[MSV
00<0003o0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gH
iP1[0:gHiP030000o`2]f>H0[MSV05D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:
0:gHiP2]f>H0K02]f>H00`000?l0[MSV0:gHiP1D0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?oo
h00303>QbP2]f>H0[MSV06d0[MSV00<0003o0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP503oon000`0cXLX0[MSV0:gHiP1^0:gHiP030000o`2]f>H0[MSV0580[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0K`2]f>H00`000?l0[MSV0:gHiP1A0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV0700[MSV00<0003o0:gHiP2]f>H0D02]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP1a0:gHiP030000o`2]f>H0
[MSV04l0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`00
0?l0[MSV0:gHiP1>0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV07<0
[MSV00<0003o0:gHiP2]f>H0C@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV
0:gHiP1d0:gHiP030000o`2]f>H0[MSV04`0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0
<j7:0:gHiP2]f>H0M@2]f>H00`000?l0[MSV0:gHiP1;0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D
0?ooh00303>QbP2]f>H0[MSV07H0[MSV00<0003o0:gHiP2]f>H0BP2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0D0?oo
h00303>QbP2]f>H0[MSV07L0[MSV00<0003o0:gHiP2]f>H0B@2]f>H00`0cXLX0oooP0?ooh0070?oo
h0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh003
03>QbP2]f>H0[MSV07P0[MSV00<0003o0:gHiP2]f>H0B02]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
503oon000`0cXLX0[MSV0:gHiP1i0:gHiP030000o`2]f>H0[MSV04L0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0NP2]f>H00`000?l0[MSV0:gHiP160:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV07/0[MSV00<0003o0:gHiP2]f>H0A@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gHiP1k0:gHiP030000o`2]f>H0[MSV
04D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:0:gHiP2]f>H0O02]f>H00`000?l0
[MSV0:gHiP140:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh00303>QbP2]f>H0[MSV07d0[MSV
00<0003o0:gHiP2]f>H0@`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon000`0cXLX0[MSV0:gH
iP1n0:gHiP030000o`2]f>H0[MSV0480[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP00<0<j7:
0:gHiP2]f>H0O`2]f>H010000?l0[MSV0000000000100:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D
0?ooh00303>QbP2]f>H0[MSV0800[MSV00@0003o0000000000000000?`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP503oon2303>QbP04000000000?l0000000000400<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9P0oooP00<00000
0000o`3oon00B`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon040000
00L0oooP00<000000?ooh03oon00o`3oon2J0?ooh0030000o`3oon00oooP04T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00<000000?ooh03oon00203oon000`000000
oooP0?ooh03o0?ooh9/0oooP00<0003o0?ooh03oon00B03oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V4@3oon000`000000oooP0?ooh0070?ooh0@00000o`3oon2J0?ooh0030000
o`3oon00oooP04D0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?oo
h0060?ooh0030000003oon00oooP0?l0oooPW03oon000`000?l0oooP0?ooh0170?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<0
00000?ooh03oon00o`3oon2M0?ooh0030000o`3oon00oooP04H0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPWP3oon00
0`000?l0oooP0?ooh0150?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPW`3oon000`000?l0oooP0?ooh0140?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX03oon000`000?l0
oooP0?ooh0130?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPX@3oon000`000?l0oooP0?ooh0120?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPXP3oon000`000?l0oooP0?oo
h0110?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPX`3oon000`000?l0oooP0?ooh0100?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY03oon000`000?l0oooP0?ooh00o0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPY@3oon000`000?l0oooP0?ooh00n0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPYP3oon000`000?l0oooP0?ooh00m0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY`3o
on000`000?l0oooP0?ooh00l0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPZ03oon000`000?l0oooP0?ooh00k0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2Y0?ooh0030000o`3oon00oooP
03P0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0
oooP00<0003o0?ooh03oon00>@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP00<0003o0?ooh03oon00>@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:/0oooP00<0
003o0?ooh03oon00>03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:`0oooP00<0003o0?ooh03oon00=`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP00<0003o0?oo
h03oon00=P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh:h0oooP00<0003o0?ooh03oon00=@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:l0oooP00<0003o0?ooh03oon00
=03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh;00oooP00<0003o0?ooh03oon00<`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP00<0003o0?ooh03oon00<P3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;80oooP00<0003o0?ooh03oon00<@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh;<0oooP00<0003o0?ooh03oon00<03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;@0oooP
00<0003o0?ooh03oon00;`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;D0oooP00<0003o0?ooh03oon00;P3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP]P3oon000`000?l0oooP0?ooh00[
0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?oo
h0030000o`3oon00oooP02`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2g0?ooh0030000o`3oon00oooP02`0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2h0?ooh0030000
o`3oon00oooP02/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2i0?ooh0030000o`3oon00oooP02X0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh0030000o`3oon00
oooP02T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2k0?ooh0030000o`3oon00oooP02P0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2l0?ooh0030000o`3oon00oooP02L0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2l0?ooh0030000o`3oon00oooP02L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2m0?ooh0030000o`3oon00oooP02H0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n
0?ooh0030000o`3oon00oooP02D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2o0?ooh0030000o`3oon00oooP02@0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon300?ooh003
0000o`3oon00oooP02<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon310?ooh0030000o`3oon00oooP0280oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon310?ooh0030000o`3o
on00oooP0280oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o
0?ooh<80oooP00<0003o0?ooh03oon007`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP``3oon000`000?l0oooP0?ooh00P0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa03oon000`000?l0
oooP0?ooh00O0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPa@3oon000`000?l0oooP0?ooh00N0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPaP3oon000`000?l0oooP0?oo
h00M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPaP3oon000`000?l0oooP0?ooh00M0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa`3oon000`000?l0oooP0?ooh00L0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPb03oon000`000?l0oooP0?ooh00K0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb@3oon000`000?l0oooP0?ooh00J0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPbP3o
on000`000?l0oooP0?ooh00I0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPb`3oon000`000?l0oooP0?ooh00H0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb`3oon000`00
0?l0oooP0?ooh00H0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPc03oon000`000?l0oooP0?ooh00G0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPc@3oon000`000?l0oooP
0?ooh00F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3o
on3>0?ooh0030000o`3oon00oooP01<0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh<l0oooP00<0003o0?ooh03oon00503oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=00oooP00<0003o0?oo
h03oon004`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh=40oooP00<0003o0?ooh03oon004P3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=40oooP00<0003o0?ooh03oon00
4P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh=80oooP00<0003o0?ooh03oon004@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=<0oooP00<0003o0?ooh03oon00403oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h=@0oooP00<0003o0?ooh03oon003`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh=D0oooP00<0003o0?ooh03oon003P3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=H0oooP
00<0003o0?ooh03oon003@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh=L0oooP00<0003o0?ooh03oon00303oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=L0oooP00<0003o
0?ooh03oon00303oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon020000
00P0oooP00<000000?ooh03oon00o`3oon3H0?ooh0030000o`3oon00oooP00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`00
0000oooP0?ooh03o0?ooh=T0oooP00<0003o0?ooh03oon002P3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon3I0?ooh003
0000o`3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4`3oon000`000000oooP
0?ooh0050?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooP
iP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<0
00000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooPo`00
003Z000001P0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003L0?[`iP@000000P3jl>H800000080n_3V100000001`3jl>H00000000000000000n_3V0000003j
l>H0300000000`3jl>H0000000000004000000040?[`iP0000000000000000P0n_3V1@0000040?[`
iPL0000000<0n_3V0000003jl>H00`0000090?[`iPD000000P3jl>H400000080n_3V1@00000B0?[`
iPH000001P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V0000000000000000i03jl>H1
0?ooo`00g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H2000000<0n_3V00L000000?[`
iP00000000000?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000002@3jl>H010000000n_3V0?[`iP3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00D0
n_3V0P0000000`3jl>H000000000003U0?[`iP40oooo003M0?[`iP80000000<0n_3V000000000000
103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP800000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP800000303jl>H5000000D0n_3V0P0000060?[`iPD0
00001P3jl>H300000>H0n_3V0@3oool00=d0n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`
iP00000000000?[`iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V0P000000103j
l>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P000002
0?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00003V
0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H20000
00060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00
000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V
0P0000020?[`iP<0000000<0n_3V0000003jl>H04P3jl>H2000000P0n_3V00<000000?[`iP3jl>H0
1@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3j
l>H500000080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000002`3j
l>H500000080n_3V100000020?[`iP<0000000<0n_3V0000000000004`3jl>H2000000l0n_3V0`00
00001@3jl>H00000000000000000n_3V00@00000g`3jl>H10?ooo`00g@3jl>H200000080n_3V0P00
000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0H0?[`iP8000008@3jl>H4000001P0n_3V00<0
00000?[`iP3jl>H0g`3jl>H10?ooo`00g03jl>H6000000@0n_3V0P00000_0?[`iPD000006`3jl>H3
00000240n_3V0P00000I0?[`iP030000003jl>H0n_3V0=h0n_3V0@3oool00?l0n_3VN03jl>H00`00
0000n_3V0?[`iP3M0?[`iP40oooo003o0?[`iWD0n_3V00@000000?[`iP3jl>H00000g`3jl>H10?oo
o`00o`3jl>If0?[`iP800000h03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .04309 L
.25649 .04309 L
.25649 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .04309 L
.25649 .04309 L
.25649 .16187 L
s
1 .894 .882 r
.25649 .16187 m
.25649 .14675 L
.50997 .14675 L
.50997 .16187 L
F
.804 .522 .247 r
.25649 .16187 m
.25649 .14675 L
.50997 .14675 L
.50997 .16187 L
s
.678 .847 .902 r
.50997 .16187 m
.50997 .17061 L
.73615 .17061 L
.73615 .16187 L
F
.2 .63 .79 r
.50997 .16187 m
.50997 .17061 L
.73615 .17061 L
.73615 .16187 L
s
.678 .847 .902 r
.73615 .16187 m
.73615 .41242 L
.97619 .41242 L
.97619 .16187 L
F
.2 .63 .79 r
.73615 .16187 m
.73615 .41242 L
.97619 .41242 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.2329 .04309 Mdot
.47488 .14675 Mdot
.51395 .17061 Mdot
.80666 .41242 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.532292) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.437411) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V100000030?[`iP<000001@3jl>H2000000@0n_3V100000020?[`iPH0
000000<0n_3V0000000000001000003o0?[`iY/0n_3V0@3oool00200n_3V0P0000020?[`iP800000
0`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP040000
0080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P00
00000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000000`3j
l>H2000000H0n_3V0P0000030?[`iP030000003jl>H0n_3V00800000103jl>H2000000D0n_3V0P00
00050?[`iP8000001@3jl>H200000?l0n_3VW@3jl>H10?ooo`00803jl>H2000000030?[`iP000000
000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V00800000603j
l>H2000000030?[`iP000000000000P0n_3V1P0000050?[`iP800000103jl>H200000080n_3V1P00
00040?[`iP8000001@3jl>H200000?l0n_3VW@3jl>H10?ooo`00803jl>H5000000@0n_3V0P000003
0?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<00000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<00000
0`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD0
00002P3jl>H2000000030?[`iP000000000000P0n_3V00<000000?[`iP3jl>H00P0000060?[`iP80
0000103jl>H200000080n_3V00<000000?[`iP3jl>H00P0000050?[`iP8000001@3jl>H200000?l0
n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V
0P0000001P3jl>H000000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000103j
l>H000000000003jl>H2000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000
000000T0n_3V00@000000?[`iP0000000000103jl>H3000000H0n_3V0P0000020?[`iP040000003j
l>H00000000000D0n_3V0P0000050?[`iP800000o`3jl>JM0?[`iP40oooo000P0?[`iP8000000P3j
l>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP000000000000D000000P3j
l>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H000000000
0007000001T0n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H00000000000H0n_3V
0P0000050?[`iP8000000P3jl>H010000000n_3V0000000000050?[`iP8000001@3jl>H200000?l0
n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V
0?[`iP0U0?[`iP80000000<0n_3V0000000000002P3jl>H3000000<0n_3V00<000000?[`iP3jl>H0
0P0000020?[`iP030000003jl>H0n_3V008000000`3jl>H3000000<0n_3V100000030?[`iP@00000
o`3jl>JM0?[`iP40oooo000O0?[`iPH00000103jl>H2000002l0n_3V1@00000X0?[`iP<00000303j
l>H2000000@0n_3V0`0000030?[`iPD00000103jl>H2000000D0n_3V0P0000050?[`iP800000o`3j
l>JM0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool003d0n_3V1000003o0?[`i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3Vo`3j
l>HG0?[`iP40oooo000P0?[`iPH0000000D0n_3V00000000000000000?[`iP0300000080n_3V0`00
00030?[`iP@000000`3jl>H2000000040?[`iP00000000000?[`iPD000000`3jl>H<000002l0n_3V
0`0000040?[`iP8000001@3jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V
0`0000050?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00
000000000080n_3V0P0000020?[`iP040000003jl>H00000000000<0n_3V00D000000?[`iP000000
00000?[`iP0300000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`iPD0
00002@3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0
n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V
0P0000050?[`iP8000000P3jl>H200000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V
0P00000`0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo
000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iPH0000000<0
n_3V0000000000000P3jl>H200000080n_3V0P0000050?[`iPD000000`3jl>H200000280n_3V1@00
00090?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R
0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP<000000P3jl>H3000000030?[`iP000000n_3V00@0n_3V0P00
00030?[`iP800000<03jl>H2000000030?[`iP000000000000T0n_3V100000030?[`iP@000000`3j
l>H4000000<0n_3V100000030?[`iP@000001P3jl>H200000?l0n_3VW@3jl>H10?ooo`008P3jl>H2
000000<0n_3V1@0000020?[`iPD000000`3jl>H4000000<0n_3V0P0000000`3jl>H0000000000004
000000030?[`iP00000000000080n_3V100000040?[`iP800000<03jl>H2000000030?[`iP000000
000000T0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000203jl>H2
00000?l0n_3VW@3jl>H10?ooo`008P3jl>H2000000/0n_3V0P00000R0?[`iP800000<03jl>H20000
00030?[`iP000000000000X0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`
iP800000103jl>H00`000000n_3V0?[`iP0200000?l0n_3VW@3jl>H10?ooo`00803jl>H6000000T0
n_3V0P00000P0?[`iP@00000<@3jl>H3000000`0n_3V0`0000040?[`iP<00000103jl>H3000000@0
n_3V0`0000040?[`iP<000000P3jl>H500000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80
000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`00
9`3jl>H010000000n_3V0000003jl>H200000080n_3V00<000000?[`iP3jl>H00`00003o0?[`i_l0
n_3V903jl>H10?ooo`00803jl>H3000000030?[`iP00000000000080000000D0n_3V0000003jl>H0
00000?[`iP0300000080n_3V00<000000?[`iP000000603jl>H500000=/0n_3V100000040?[`iP/0
0000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0
000000@0n_3V0000000000000000203jl>H4000000030?[`iP00000000000080n_3V100000020?[`
iPD0000000L0n_3V00000000000000000?[`iP000000n_3V00<00000603jl>H3000000@0n_3V0P00
00050?[`iP<00000103jl>H3000000<0n_3V1@0000020?[`iPD000000P3jl>H3000000@0n_3V1@00
001h0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@000000103jl>H0000000000000
00020?[`iP80000000<0n_3V0000000000002@3jl>H5000000T0n_3V0P00003O0?[`iP800000103j
l>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V
0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000020?[`iP80000000<0n_3V00000000
00000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD0
00002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP030000003jl>H0n_3V0080
00000P3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000050?[`iP8000001`3jl>H2000000<0
n_3V0P00001k0?[`iP40oooo000R0?[`iP<00000:@3jl>H200000=h0n_3V0P0000040?[`iP800000
0P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000
0`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`
iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H0
00000?[`iP02000001P0n_3V0P0000000`3jl>H000000000000<0?[`iP8000001@3jl>H2000000<0
n_3V0P0000050?[`iP8000001`3jl>H2000000<0n_3V0P00001j0?[`iP40oooo000R0?[`iP<00000
6P3jl>H5000000/0n_3V0P00003M0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP800000
1P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP800000
00<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`iP80
00000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80
000000<0n_3V000000000000303jl>H2000000D0n_3V0P0000040?[`iP8000001@3jl>H2000000@0
n_3V100000040?[`iP800000N@3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002X0n_3V
0P00003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H00000
0?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000030?[`iP000000000000X0n_3V0`000000103jl>H000000000003jl>H20000
0080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP020000
01P0n_3V0P0000000`3jl>H00000000000090?[`iP030000003jl>H0n_3V008000000`3jl>H30000
00H0n_3V0P0000050?[`iP8000000P3jl>H2000000030?[`iP000000000000D0n_3V0P00001h0?[`
iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`iP0000000000
0=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP0000000000
0?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;
0?[`iP<0000000<0n_3V0000000000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007
000001T0n_3V0P0000000`3jl>H00000000000090?[`iP@000001P3jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000001h0?[`iP40oooo001=0?[`iP80000000<0n_3V0000
00000000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP8000008P3jl>H20000
0080n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H2000000D0n_3V00<000000?[`
iP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000N03jl>H10?oo
o`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP80
00006@3jl>H3000000030?[`iP000000000000800000;P3jl>H3000000X0n_3V1@0000030?[`iP<0
0000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000007T0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H20000
00030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0
n_3V00D000000?[`iP000000n_3V000000020?[`iP040000003jl>H0n_3V00000080n_3V00<00000
0?[`iP3jl>H0o`3jl>Ko0?[`iR80n_3V0@3oool00200n_3V0`0000000`3jl>H00000000000020000
00040?[`iP000000n_3V00000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`
iP0G0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`00
00020?[`iPH000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000006000001/0n_3V1000
00370?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@0000001@3jl>H0000000000000
0000n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103j
l>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V
0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000/0n_3V1@00000;0?[`
iP800000b03jl>H10?ooo`008P3jl>H3000002P0n_3V0P0000000`3jl>H000000000003L0?[`iP80
0000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000<0
n_3V1000000H0?[`iPH00000a`3jl>H10?ooo`008P3jl>H3000000T0n_3V00<000000?[`iP3jl>H0
3P3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP@000000`3jl>H500000080n_3V
0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V
0P0000020?[`iP80000000@0n_3V000000000000n_3V1000000=0?[`iPD00000203jl>H00`000000
n_3V0?[`iP0200000<P0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W0?[`iP800000
00<0n_3V000000000000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<00000
00@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000I0?[`
iP040000003jl>H0000000000<P0n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V
0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V10000002
0?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V1000
00040?[`iP@000000P3jl>H5000000<0n_3V1@00000I0?[`iP040000003jl>H0000000000<P0n_3V
0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403j
l>H2000000`0n_3V0P00000i0?[`iP<00000b03jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A
0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<P3jl>H200000<P0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iRH0oooP0P00
001/0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000J@3oon0500000080oooP0P00
00040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00
oooP000006X0oooP00@000000?ooh03oon000000203oon0010000000oooP0?ooh000001/0?ooh003
0000003oon00oooP06/0oooP00<000000?ooh03oon001`3oon0010000000oooP0?ooh000001Z0?oo
h0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP0000
06X0oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?ooh01Z0?ooh0030000003oon00
oooP06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?ooh01Y0?ooh0030000003oon00
oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@00000
0?ooh03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?oo
h0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V0@3oool001d0n_3V9@3oon00
10000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03oon00
K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00
JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0n_3V9P3oon02000006`0oooP
0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000002@0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon00
0`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon00
0`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003o
on00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon00
0`000000oooP0?ooh0060?ooh0@00000203oon0J0000ool0oooP`03oon04000001P0oooP7P3jl>H1
0?ooo`007@3jl>H:0?ooh0@00000103oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP
02<0oooP20000?oo0?ooh;/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80
oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh00[0?ooh0X0003oo`3oon2a0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP
0?ooh00e0?ooh0T0003oo`3oon2X0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP03h0oooP20000?oo0?ooh:00oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00AP3oon050000ool0oooPV`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh01;0?oo
h0D0003oo`3oon2F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0500oooP1@000?oo0?ooh940oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00E@3oon050000ool0oooPS03oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh01J0?ooh0D0003oo`3o
on270?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP05l0oooP10000?oo0?ooh8<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00H`3oon050000ool0oooPOP3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh01X0?ooh0@0003o0P3oon0200000?l0
oooPMP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh6<0cHDo10000?l00`000000cHDo0<f5?`080<f5?ol0oooPJ`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>40H@3o
i>43000000<0003o1`3oi>400`3=QCl0oooP0?ooh03o0?ooh6L0oooP0`00000H0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0680onCQ0P000003
0?oTh@@0003o0`3oi>400`3=QCl0oooP0?ooh03o0?ooh6T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1[0?oT
h@<0003o00<0cHDo0?ooh03oon00o`3oon1Y0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40KP3oi>440000ool0
oooPJ03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0onCQ00@0cHDo0?ooh03oon00oooP0`000?oo0?ooh6D0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@1^0?oTh@030<f5?`3oon00oooP00@0oooP0`000?oo0?ooh680oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@1^0?oTh@030<f5?`3oon00oooP00L0oooP0P000?oo0?ooh600oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@1^0?oTh@030<f5?`3oon00oooP00T0oooP0`000?oo0?ooh5d0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@1^0?oTh@030<f5?`3oon00oooP00`0oooP0`000?oo0?ooh5X0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@1^0?oTh@030<f5?`3oon00oooP00l0oooP0P000?oo0?ooh5P0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@1^0?oTh@030<f5?`3oon00oooP0140oooP0`000?oo0?ooh5D0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@1^0?oTh@030<f5?`3oon00oooP01@0oooP0`000?oo0?ooh580oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1^
0?oTh@030<f5?`3oon00oooP01L0oooP0`000?oo0?ooh4l0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1^0?oT
h@030<f5?`3oon00oooP01X0oooP0P000?oo0?ooh4d0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03o
on00703oon030000ool0oooPB03oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40KP3oi>400`3=QCl0oooP0?ooh00O0?ooh0<0003o
o`3oon170?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3oi>40KP3oi>400`3=QCl0oooP0?ooh00R0?ooh080003oo`3o
on150?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<0cHDo0?oTh@3oi>40KP3oi>400`3=QCl0oooP0?ooh00T0?ooh0<0003oo`3oon12
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>40KP3oi>400`3=QCl0oooP0?ooh00W0?ooh0<0003oo`3oon0o0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40KP3oi>400`3=QCl0oooP0?ooh00Z0?ooh080003oo`3oon0m0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>40KP3oi>400`3=QCl0oooP0?ooh00/0?ooh080003oo`3oon0k0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>40KP3oi>400`3=QCl0oooP0?ooh00^0?ooh080003oo`3oon0i0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>40KP3oi>400`3=QCl0oooP0?ooh00`0?ooh080003oo`3oon0g0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40KP3oi>400`3=QCl0oooP0?ooh00b0?ooh0<0003oo`3oon0d0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>40KP3oi>400`3=QCl0oooP0?ooh00e0?ooh080003oo`3oon0b0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
KP3oi>400`3=QCl0oooP0?ooh00g0?ooh080003oo`3oon0`0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40KP3o
i>400`3=QCl0oooP0?ooh00i0?ooh080003oo`3oon0^0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40KP3oi>40
0`3=QCl0oooP0?ooh00k0?ooh0<0003oo`3oon0[0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40KP3oi>400`3=
QCl0oooP0?ooh00n0?ooh080003oo`3oon0Y0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@1^0?oTh@030<f5?`3oon00oooP0400
oooP0P000?oo0?ooh2D0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03oon00@P3oon020000ool0oooP
9@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03oon00A03oon020000ool0oooP8`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03oon00AP3oon020000ool0oooP8@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03oon00B03oon020000ool0oooP7`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03oon00BP3oon020000ool0oooP7@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03oon00C03oon020000ool0oooP6`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ06h0onCQ00<0cHDo0?ooh03oon00CP3oon020000ool0oooP6@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ06h0onCQ00<0cHDo0?ooh03oon00D03oon020000ool0oooP5`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
06h0onCQ00<0cHDo0?ooh03oon00DP3oon020000ool0oooP5@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0
onCQ00<0cHDo0?ooh03oon00E03oon020000ool0oooP4`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0onCQ
00<0cHDo0?ooh03oon00EP3oon000`000?l0oooP0?ooh03o0?ooh100oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@1^0?oTh@030<f5?`3oon00oooP05L0oooP0P000?oo0?ooh100oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1^
0?oTh@030<f5?`3oon00oooP05T0oooP0P000?oo0?ooh0h0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?oo
h03oon00F`3oon000`000?l0oooP0?ooh03o0?ooh0T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03o
on00G03oon020000ool0oooP2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03oon00
GP3oon020000ool0oooP2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03oon00H03o
on020000ool0oooP1`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03oon00HP3oon00
0`000?l0oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1^0?oTh@030<f5?`3oon00oooP
06<0oooP0P000?l20?ooh0800000o`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0onCQ00<0cHDo0?ooh03o
on00I@3oon020000o`<00000oP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0onCQJ@3=QCl010000000003o
0000o`00000@0<f5?nh0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1^0?oTh@030<f5?`3oi>40onCQ06L0onCQ
0P0000000`000?l0onCQ0?oTh@0=0?oTh@030<f5?`3oon00oooP0>`0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@1^0?oTh@030<f5?`3oi>40onCQ06X0onCQ0P000?l=0?oTh@030<f5?`3oon00oooP0>`0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@1^0?oTh@030<f5?`3oi>40onCQ06`0onCQ0P000?l;0?oTh@030<f5?`3oon00
oooP0>`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@1^0?oTh@030<f5?`3oi>40onCQ06h0onCQ00<0003o0?oT
h@3oi>40203oi>400`3=QCl0oooP0?ooh03/0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ06h0
onCQ00<0cHDo0?oTh@3oi>40K`3oi>420000o`P0onCQ00<0cHDo0?ooh03oon00k03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40KP3oi>400`3=QCl0onCQ0?oTh@1a0?oTh@80
003o1P3oi>400`3=QCl0oooP0?ooh03/0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>H@0?ooh0040000003oon00oooP000000L0oooP100000080?ooh>L000000P000?oX000000P0
oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh003
0000003oon00oooP0?80oooP00D0003o0?ooh03oon00oooP03>QbP1]0:gHiP0303>QbP2]f>H0[MSV
0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?<0oooP0P000?l00`3o
on00<j7:0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03o
on00m@3oon0010000?l0<j7:00000000001[0:gHiP0303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03f0?ooh080003o0P00001Z0:gHiP0303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03f0?ooh080000000<0003o0000000cXLX0JP0cXLYd0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00m`3o
on0200000080003oJ@3oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n`3oon00
0`000?l0oooP0?ooh01V0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03l0?oo
h0030000o`3oon00oooP06D0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?d0
oooP0P000?mU0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0030000
o`3oon00oooP0680oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP0@3o
on020000of80oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP0`3oon00
0`000?l0oooP0?ooh01O0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h0@0oooP0P000?mO0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0H0
oooP00<0003o0?ooh03oon00G03oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh0L0oooP
0P000?mL0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2@3oon000`000?l0oooP0?oo
h01I0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0X0oooP0P000?mI
0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0`0oooP00<0003o0?oo
h03oon00EP3oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0=0?ooh080
003oEP3oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0?0?ooh0030000
o`3oon00oooP05<0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403o
on020000oe<0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4P3oon00
0`000?l0oooP0?ooh01@0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h1<0oooP0P000?m@0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1D0
oooP00<0003o0?ooh03oon00C@3oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0F0?ooh080003oC@3oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0H0?ooh0030000o`3oon00oooP04X0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP6@3oon020000odX0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP6`3oon000`000?l0oooP0?ooh0170?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0
oooP703oon020000odL0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0070?ooh0<0
0000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0N0?ooh0030000
o`3oon00oooP04@0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7`3o
on000`000?l0oooP0?ooh0130?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh200oooP0P000?m30?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h280oooP00<0003o0?ooh03oon00@03oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0S0?ooh0030000o`3oon00oooP03l0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP903oon020000ocl0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP9P3oon000`000?l0oooP0?ooh00l0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh2L0oooP00<0003o0?ooh03oon00>`3oon000`0cXLX0[MSV0:gHiP1b
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0X0?ooh080003o>`3oon000`0cXLX0[MSV0:gHiP1b0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0Z0?ooh0030000o`3oon00oooP03P0oooP00<0<j7:0:gHiP2]
f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:`3oon000`000?l0oooP0?ooh00g0?ooh00303>Q
bP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2`0oooP0P000?lg0?ooh00303>QbP2]
f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2h0oooP00<0003o0?ooh03oon00=03oon00
0`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh2l0oooP00<0003o0?ooh03oon00<`3oon000`0c
XLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh300oooP0P000?lc0?ooh00303>QbP2]f>H0[MSV0780
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh380oooP00<0003o0?ooh03oon00<03oon000`0cXLX0[MSV
0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0c0?ooh0030000o`3oon00oooP02l0oooP00<0
<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP=03oon000`000?l0oooP0?ooh00^
0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3D0oooP0P000?l^0?oo
h00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP00<0003o0?ooh03o
on00:`3oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0h0?ooh0030000
o`3oon00oooP02X0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>@3o
on020000obX0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>`3oon00
0`000?l0oooP0?ooh00W0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h3`0oooP00<0003o0?ooh03oon009P3oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0m0?ooh0030000o`3oon00oooP02D0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP?P3oon020000obD0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP@03oon000`000?l0oooP0?ooh00R0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh440oooP00<0003o0?ooh03oon008@3oon000`0cXLX0[MSV0:gHiP1b
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`00003o0?ooh480oooP00<0003o0?ooh03oon00803oon000`0cXLX0[MSV0:gHiP1b0:gH
iP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh4<0oooP00<0003o0?ooh03oon007`3oon000`0cXLX0[MSV0:gHiP1b0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon140?ooh0030000o`3oon00oooP01h0oooP00<0<j7:0:gHiP2]f>H0
LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPA@3oon020000oah0oooP00<0<j7:0:gHiP2]f>H0LP2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPA`3oon000`000?l0oooP0?ooh00K0?ooh00303>QbP2]f>H0
[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4P0oooP00<0003o0?ooh03oon006P3oon000`0c
XLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon190?ooh0030000o`3oon00oooP01T0
oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPBP3oon000`000?l0oooP
0?ooh00H0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4/0oooP00<0
003o0?ooh03oon005`3oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1<
0?ooh0030000o`3oon00oooP01H0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPC@3oon000`000?l0oooP0?ooh00E0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh4h0oooP00<0003o0?ooh03oon00503oon000`0cXLX0[MSV0:gHiP1b0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP
1@0000060?ooh0030000003oon00oooP0?l0oooPC`3oon020000oa@0oooP00<0<j7:0:gHiP2]f>H0
LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1A0?ooh0030000o`3o
on00oooP0140oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000003o
0?ooh540oooP00<0003o0?ooh03oon00403oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00
oooP00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?oo
h0030000003oon00oooP0?l0oooPD`3oon000`000?l0oooP0?ooh00?0?ooh00303>QbP2]f>H0[MSV
0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPE03oon000`000?l0
oooP0?ooh00>0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00
o`3oon1E0?ooh0030000o`3oon00oooP00d0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPEP3oon000`000?l0oooP0?ooh00<0?ooh00303>QbP2]f>H0[MSV0780[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh5L0oooP00<0003o0?ooh03oon002`3oon000`0cXLX0[MSV0:gHiP1b
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1H0?ooh0030000o`3oon00oooP00X0oooP00<0<j7:0:gH
iP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF@3oon020000o`X0oooP00<0<j7:0:gHiP2]
f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF`3oon000`000?l0oooP0?ooh0070?ooh00303>Q
bP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5`0oooP00<0003o0?ooh03oon001P3o
on000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1M0?ooh0030000o`3oon00
oooP00D0oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPGP3oon000`00
0?l0oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV0780[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5l0
oooP00<0003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gHiP1b0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1P0?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H0LP2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3o
on1Q0?ooh0050000o`3oon00oooP0?ooh00cXLX0M02]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000
603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1R0?ooh0040000o`3o
on00oooP03>QbW@0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6<0oooP0P000?l00`0cXLX0[MSV0:gH
iP1b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1U0?ooh0030000o`2]f>H0[MSV0780[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh6D0oooP00<0<j7:0000o`2]f>H0LP2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPI@3oon000`0cXLX0[MSV0000o`1b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1U0?ooh00403>Q
bP2]f>H0[MSV0000og40[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6D0oooP00D0<j7:0:gHiP2]f>H0
[MSV0000o`1`0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1U0?ooh00303>QbP2]f>H0[MSV0080[MSV
00<0003o0:gHiP2]f>H0K@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI@3oon000`0cXLX0[MSV0:gH
iP030:gHiP030000o`2]f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0<j7:
0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP1[0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1U0?oo
h00303>QbP2]f>H0[MSV00D0[MSV00<0003o0:gHiP2]f>H0JP2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPI@3oon000`0cXLX0[MSV0:gHiP060:gHiP030000o`2]f>H0[MSV06T0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh6D0oooP00<0<j7:0:gHiP2]f>H01`2]f>H00`000?l0[MSV0:gHiP1X0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1U0?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H0I`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<00000o`3oon1U0?ooh00303>QbP2]f>H0[MSV00T0[MSV0P000?mW0:gHiP0303>QbP3oon00
oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h6D0oooP00<0<j7:0:gHiP2]f>H02`2]f>H00`000?l0[MSV0:gHiP1T0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1U0?ooh00303>QbP2]f>H0[MSV00`0[MSV00<0003o0:gHiP2]f>H0H`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPI@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP030000o`2]f>H0[MSV0680[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh6D0oooP00<0<j7:0:gHiP2]f>H03P2]f>H00`000?l0[MSV0:gH
iP1Q0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1U0?ooh00303>QbP2]f>H0[MSV00l0[MSV00<0003o
0:gHiP2]f>H0H02]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI@3oon000`0cXLX0[MSV0:gHiP0@0:gH
iP030000o`2]f>H0[MSV05l0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0<j7:0:gHiP2]
f>H04@2]f>H00`000?l0[MSV0:gHiP1N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1U0?ooh00303>Q
bP2]f>H0[MSV0180[MSV00<0003o0:gHiP2]f>H0G@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI@3o
on000`0cXLX0[MSV0:gHiP0C0:gHiP030000o`2]f>H0[MSV05`0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6D0oooP00<0<j7:0:gHiP2]f>H0502]f>H00`000?l0[MSV0:gHiP1K0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1U0?ooh00303>QbP2]f>H0[MSV01D0[MSV00<0003o0:gHiP2]f>H0FP2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPI@3oon000`0cXLX0[MSV0:gHiP0F0:gHiP030000o`2]f>H0[MSV05T0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0<j7:0:gHiP2]f>H05`2]f>H00`000?l0[MSV
0:gHiP1H0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh6D0oooP00<0<j7:0:gHiP2]f>H0602]f>H00`000?l0[MSV0:gH
iP1G0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh6D0oooP00<0<j7:0:gHiP2]f>H06@2]f>H00`000?l0[MSV0:gHiP1F
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1U0?ooh00303>QbP2]f>H0[MSV01X0[MSV00<0003o0:gH
iP2]f>H0E@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI@3oon000`0cXLX0[MSV0:gHiP0K0:gHiP03
0000o`2]f>H0[MSV05@0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0<j7:0:gHiP2]f>H0
702]f>H00`000?l0[MSV0:gHiP1C0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1U0?ooh00303>QbP2]
f>H0[MSV01d0[MSV00<0003o0:gHiP2]f>H0DP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI@3oon00
0`0cXLX0[MSV0:gHiP0N0:gHiP030000o`00000000000540[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h6D0oooP8@0cXLX010000000003o00000000001A03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon260?ooh080000000<0003o0000
003oon00F`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh8L0oooP0P0000000`000?l0oooP0?ooh01J0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPRP3oon000`000?l0oooP
0?ooh01I0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPR`3oon000`000?l0oooP0?ooh01H0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPS03oon000`000?l0oooP0?ooh01G
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPS@3oon000`000?l0oooP0?ooh01F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<00000o`3oon2>0?ooh0030000o`3oon00oooP05<0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8l0oooP00<0003o0?ooh03oon00
E03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh900oooP00<0003o0?ooh03oon00D`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh940oooP00<0003o0?ooh03oon00DP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h980oooP00<0003o0?ooh03oon00D@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh980oooP00<0003o0?ooh03oon00D@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9<0oooP
00<0003o0?ooh03oon00D03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh9@0oooP00<0003o0?ooh03oon00C`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9D0oooP00<0003o
0?ooh03oon00CP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh9H0oooP00<0003o0?ooh03oon00C@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9L0oooP00<0003o0?ooh03o
on00C03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh9P0oooP00<0003o0?ooh03oon00B`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9T0oooP00<0003o0?ooh03oon00BP3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon04000000L0oooP00<00000
0?ooh03oon00o`3oon2J0?ooh0030000o`3oon00oooP04T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ00oooP00<000000?ooh03oon00203oon000`000000oooP0?ooh03o0?oo
h9/0oooP00<0003o0?ooh03oon00B03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V4@3oon000`000000oooP0?ooh0070?ooh0@00000o`3oon2J0?ooh0030000o`3oon00oooP04D0
oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000
003oon00oooP0?l0oooPW03oon000`000?l0oooP0?ooh0170?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00
o`3oon2M0?ooh0030000o`3oon00oooP04H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPWP3oon000`000?l0oooP0?oo
h0150?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPW`3oon000`000?l0oooP0?ooh0140?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX03oon000`000?l0oooP0?ooh0130?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPX@3oon000`000?l0oooP0?ooh0120?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPXP3oon000`000?l0oooP0?ooh0110?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX`3o
on000`000?l0oooP0?ooh0100?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPY03oon000`000?l0oooP0?ooh00o0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon000`00
0?l0oooP0?ooh00n0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPYP3oon000`000?l0oooP0?ooh00m0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY`3oon000`000?l0oooP
0?ooh00l0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPZ03oon000`000?l0oooP0?ooh00k0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2Y0?ooh0030000o`3oon00oooP03P0oooP0`00000H
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP00<0003o0?oo
h03oon00>@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh:X0oooP00<0003o0?ooh03oon00>@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:/0oooP00<0003o0?ooh03oon00
>03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh:`0oooP00<0003o0?ooh03oon00=`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP00<0003o0?ooh03oon00=P3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:h0oooP00<0003o0?ooh03oon00=@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:l0oooP00<0003o0?ooh03oon00=03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;00oooP
00<0003o0?ooh03oon00<`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;40oooP00<0003o0?ooh03oon00<P3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;80oooP00<0003o
0?ooh03oon00<@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh;<0oooP00<0003o0?ooh03oon00<03oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;@0oooP00<0003o0?ooh03o
on00;`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh;D0oooP00<0003o0?ooh03oon00;P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon0300000?l0oooP]P3oon000`000?l0oooP0?ooh00[0?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh0030000o`3oon00
oooP02`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2g0?ooh0030000o`3oon00oooP02`0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2h0?ooh0030000o`3oon00oooP02/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2i0?ooh0030000o`3oon00oooP02X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh0030000o`3oon00oooP02T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2k
0?ooh0030000o`3oon00oooP02P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2l0?ooh0030000o`3oon00oooP02L0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2l0?ooh003
0000o`3oon00oooP02L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2m0?ooh0030000o`3oon00oooP02H0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n0?ooh0030000o`3o
on00oooP02D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2o0?ooh0030000o`3oon00oooP02@0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon300?ooh0030000o`3oon00oooP
02<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon310?ooh0030000o`3oon00oooP0280oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon310?ooh0030000o`3oon00oooP0280oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh<80oooP00<0
003o0?ooh03oon007`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP``3oon000`000?l0oooP0?ooh00P0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa03oon000`000?l0oooP0?ooh00O0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPa@3oon000`000?l0oooP0?ooh00N0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPaP3oon000`000?l0oooP0?ooh00M0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPaP3o
on000`000?l0oooP0?ooh00M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPa`3oon000`000?l0oooP0?ooh00L0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb03oon000`00
0?l0oooP0?ooh00K0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPb@3oon000`000?l0oooP0?ooh00J0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPbP3oon000`000?l0oooP
0?ooh00I0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPb`3oon000`000?l0oooP0?ooh00H0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb`3oon000`000?l0oooP0?ooh00H
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPc03oon000`000?l0oooP0?ooh00G0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPc@3oon000`000?l0oooP0?ooh00F0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon3>0?ooh0030000
o`3oon00oooP01<0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh<l0oooP00<0003o0?ooh03oon00503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=00oooP00<0003o0?ooh03oon004`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h=40oooP00<0003o0?ooh03oon004P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh=40oooP00<0003o0?ooh03oon004P3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=80oooP
00<0003o0?ooh03oon004@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh=<0oooP00<0003o0?ooh03oon00403oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=@0oooP00<0003o
0?ooh03oon003`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh=D0oooP00<0003o0?ooh03oon003P3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=H0oooP00<0003o0?ooh03o
on003@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh=L0oooP00<0003o0?ooh03oon00303oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=L0oooP00<0003o0?ooh03oon00303o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<00000
0?ooh03oon00o`3oon3H0?ooh0030000o`3oon00oooP00/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o
0?ooh=T0oooP00<0003o0?ooh03oon002P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon3I0?ooh0030000o`3oon00oooP
00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4`3oon000`000000oooP0?ooh0050?ooh003
0000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00
o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon00
0`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooPo`00003Z000001P0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003L0?[`iP@00000
0P3jl>H800000080n_3V100000001`3jl>H00000000000000000n_3V0000003jl>H0300000000`3j
l>H0000000000004000000040?[`iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V
0000003jl>H00`0000090?[`iPD000000P3jl>H400000080n_3V1@00000B0?[`iPH000001P3jl>H0
0`000000n_3V0?[`iP040?[`iP<0000000@0n_3V0000000000000000i03jl>H10?ooo`00g@3jl>H2
00000080n_3V0P0000030?[`iP8000000`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`
iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V0000000000002@3jl>H010000000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H0
00000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3j
l>H000000000003U0?[`iP40oooo003M0?[`iP80000000<0n_3V000000000000103jl>H2000000<0
n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H200000004
0?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP800000303jl>H5000000D0n_3V0P0000060?[`iPD000001P3jl>H30000
0>H0n_3V0@3oool00=d0n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`iP00000000000?[`
iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3j
l>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00003V0?[`iP40oooo003M
0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP000000
00000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80
000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP<0
000000<0n_3V0000003jl>H04P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01@3jl>H200000003
0?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000020?[`iP80000000<0n_3V000000000000
0P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3jl>H500000080n_3V
1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000002`3jl>H500000080n_3V
100000020?[`iP<0000000<0n_3V0000000000004`3jl>H2000000l0n_3V0`0000001@3jl>H00000
000000000000n_3V00@00000g`3jl>H10?ooo`00g@3jl>H200000080n_3V0P00000c0?[`iP800000
0`3jl>H00`000000n_3V0?[`iP0H0?[`iP8000008@3jl>H4000001P0n_3V00<000000?[`iP3jl>H0
g`3jl>H10?ooo`00g03jl>H6000000@0n_3V0P00000_0?[`iPD000006`3jl>H300000240n_3V0P00
000I0?[`iP030000003jl>H0n_3V0=h0n_3V0@3oool00?l0n_3VN03jl>H00`000000n_3V0?[`iP3M
0?[`iP40oooo003o0?[`iWD0n_3V00@000000?[`iP3jl>H00000g`3jl>H10?ooo`00o`3jl>If0?[`
iP800000h03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01727 L
.2725 .01727 L
.2725 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01727 L
.2725 .01727 L
.2725 .16187 L
s
.678 .847 .902 r
.2725 .16187 m
.2725 .16869 L
.54869 .16869 L
.54869 .16187 L
F
.2 .63 .79 r
.2725 .16187 m
.2725 .16869 L
.54869 .16869 L
.54869 .16187 L
s
.678 .847 .902 r
.54869 .16187 m
.54869 .22655 L
.67893 .22655 L
.67893 .16187 L
F
.2 .63 .79 r
.54869 .16187 m
.54869 .22655 L
.67893 .22655 L
.67893 .16187 L
s
.678 .847 .902 r
.67893 .16187 m
.67893 .35487 L
.7935 .35487 L
.7935 .16187 L
F
.2 .63 .79 r
.67893 .16187 m
.67893 .35487 L
.7935 .35487 L
.7935 .16187 L
s
.678 .847 .902 r
.7935 .16187 m
.7935 .41648 L
.97619 .41648 L
.97619 .16187 L
F
.2 .63 .79 r
.7935 .16187 m
.7935 .41648 L
.97619 .41648 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.08651 .01727 Mdot
.51091 .16869 Mdot
.59515 .22655 Mdot
.74781 .35487 Mdot
.81065 .41648 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.579989) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.613316) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000030?[`iPH000000P3jl>H3000000@0n_3V0`0000030?[`iPH0
00000P3jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP030000003jl>H0n_3V008000000P3j
l>H00`000000n_3V0?[`iP02000000@0n_3V0P0000030?[`iP80000000<0n_3V000000000000o`3j
l>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3j
l>H2000000030?[`iP000000000000@0n_3V0P0000060?[`iP8000001@3jl>H2000000@0n_3V0P00
00030?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000000000@0
n_3V0P0000060?[`iP8000001@3jl>H2000000@0n_3V0P0000030?[`iP80000000<0n_3V00000000
0000o`3jl>JL0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V
0000000000002@3jl>H4000000D0n_3V0P0000040?[`iP<00000103jl>H3000000D0n_3V0P000003
0?[`iP@00000o`3jl>JM0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP0000000000
00800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`
iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3j
l>H00000000000090?[`iP8000001`3jl>H2000000H0n_3V0P0000050?[`iP800000103jl>H20000
00<0n_3V0P00003o0?[`iYl0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0
n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0n_3V0P0000040?[`iP@0
00000`3jl>H00`000000n_3V0?[`iP0200000080n_3V00<000000?[`iP3jl>H00P0000020?[`iP@0
0000103jl>H200000?l0n_3VWP3jl>H10?ooo`007`3jl>H6000000@0n_3V0P00000_0?[`iPD00000
:03jl>H3000000`0n_3V0`0000040?[`iP800000103jl>H3000000@0n_3V0`0000050?[`iP800000
1@3jl>H300000?l0n_3VW03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V
0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00000000000000003jl>H0
0`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H000000000003jl>H5000000<0
n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0
n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V
0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V0000000000030?[`iP05
0000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`
iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`
iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080
n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP800000103jl>H200000080
n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0
n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000
103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP8000001@3jl>H5000000<0n_3V
0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3V
WP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103j
l>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V0`0000000`3jl>H00000
0?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP@00000
0`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V0P00003o0?[`iYd0n_3V
0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V100000030?[`iP80000000<0
n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103jl>H200000300n_3V0P00
00000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3j
l>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;0?[`iP8000008P3jl>H2
00000300n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2000000D0n_3V0P000005
0?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00003o0?[`iYd0n_3V0@3oool0
0200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00000<0?[`iP<00000103jl>H30000
00@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00003o0?[`iYd0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`
iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`iP030000003jl>H0n_3V
00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H000000000000200000005
0?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H0000001P0n_3V1@00003K0?[`
iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`
iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V100000000`3jl>H0000000000002
0?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H000000?[`iP03000001P0n_3V
0`0000040?[`iP8000001@3jl>H3000000D0n_3V0P0000030?[`iP<00000103jl>H3000000D0n_3V
0`0000030?[`iP<00000NP3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000@0
n_3V00000000000000000P3jl>H2000000030?[`iP000000000000T0n_3V1@0000090?[`iP800000
g`3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000
003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`
iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V
008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H00`00
0000n_3V0?[`iP02000000@0n_3V0P0000050?[`iP8000001@3jl>H2000000<0n_3V0P0000000`3j
l>H00000000000040?[`iP800000N@3jl>H10?ooo`008P3jl>H3000002T0n_3V0P00003N0?[`iP80
0000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0
n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`
iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V000000000000303jl>H20000
00@0n_3V0P0000060?[`iP8000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000050?[`
iP800000N03jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP800000g@3jl>H4000000<0
n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H0
0000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000
003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000`0n_3V0P0000040?[`
iP800000103jl>H4000000<0n_3V100000020?[`iP80000000<0n_3V0000000000000`3jl>H40000
07P0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000Z0?[`iP800000g03jl>H200000003
0?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`
iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3j
l>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H3
000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V
0000000000002@3jl>H00`000000n_3V0?[`iP02000000D0n_3V0P0000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0`0000030?[`iP80000000<0n_3V
000000000000N03jl>H10?ooo`00803jl>H3000000040?[`iP0000000000000002H0n_3V0P000000
0`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000
103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V1000
00020?[`iPD000002`3jl>H3000000030?[`iP00000000000080n_3V100000020?[`iP<0000000<0
n_3V0000000000001`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H4000000H0n_3V0P00
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000N03jl>H10?ooo`00C@3jl>H2
000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2
00000280n_3V0P0000020?[`iP800000;P3jl>H2000000030?[`iP000000000000T0n_3V0P000005
0?[`iP030000003jl>H0n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
000007P0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`
iP8000001P3jl>H2000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000:0?[`
iPD000000P3jl>H5000000<0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`00001i0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS
0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`iP0000000P3jl>H010000000n_3V0?[`iP00
00020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V
0000000000000P000000103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V00000080n_3V
00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V
1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V000000000000
1P00000K0?[`iP<00000b03jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000D0
n_3V00000000000000000?[`iP04000000/0n_3V1@0000090?[`iP80000000<0n_3V000000000000
g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000
003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`
iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000;
0?[`iPD000002@3jl>H00`000000n_3V0?[`iP0200000<L0n_3V0@3oool00280n_3V0`00000X0?[`
iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H20000
00D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000030?[`iP@00000703jl>H200000<L0n_3V0@3oool00280
n_3V0`0000090?[`iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V00000000
0000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`
iP@000003@3jl>H5000000`0n_3V0P0000370?[`iP40oooo000Q0?[`iP80000000<0n_3V00000000
00009`3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000050?[`iP80
00000P3jl>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P000002
0?[`iP8000006@3jl>H00`000000n_3V0?[`iP0200000<L0n_3V0@3oool00200n_3V0`000000103j
l>H0000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP000000
00000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3j
l>H500000080n_3V100000040?[`iP@000000P3jl>H5000000<0n_3V1@00000I0?[`iP@00000b03j
l>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@
0?[`iP800000303jl>H2000003P0n_3V0P00003:0?[`iP40oooo001>0?[`iP<00000g03jl>H50000
0140n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000`0?[`iPD00000a`3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0n_3V9P3oon02
000006`0oooP0P0000040?ooh0800000103oon02000006/0oooP1@00001Y0?ooh0D000000P3oon02
000000@0oooP0P00001[0?ooh0@000008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?oo
h03oon000000JP3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP000006`0oooP
00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0070?ooh0040000003oon00oooP000006X0
oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon00
0000JP3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP06X0oooP00<000000?oo
h03oon00J`3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP06T0oooP00<000000?oo
h03oon008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon001000
0000oooP0?ooh00000090?ooh0800000K@3oon000`000000oooP0?ooh01[0?ooh0030000003oon00
oooP00P0oooP0P00001]0?ooh0030000003oon00oooP0280oooP7P3jl>H10?ooo`007@3jl>HU0?oo
h0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002@3oon000`000000oooP0?oo
h01/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon00203oon000`000000oooP0?oo
h01Z0?ooh0040000003oon00oooP000002<0oooP7P3jl>H10?ooo`007@3jl>HV0?ooh0800000K03o
on02000000X0oooP0`00001[0?ooh0800000K03oon02000000X0oooP0`00001[0?ooh0800000903o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01a0?oo
h0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?oo
h0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<00000
0?ooh03oon009`3oon0200000?l0oooP_@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000203oon0J0000o`<0oooP1000003o0?oo
h;T0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V2P3oon04000000@0oooP00<000000?ooh03o
on001P3oon000`000000oooP0?ooh0090?ooh1X0cHDo20000?mH0<f5?ol0oooPH`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>406`3oi>4200000080onCQ2P000?m=0?oTh@030<f5
?`3oon00oooP0?l0oooPH@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3o
on02000000P0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0Y0?oTh@T0003oA03o
i>400`3=QCl0oooP0?ooh03o0?ooh640oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0b0?oTh@P0003o?03oi>40
0`3=QCl0oooP0?ooh03o0?ooh640oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0j0?oTh@D0003o=`3oi>400`3=
QCl0oooP0?ooh03o0?ooh640oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0o0?oTh@D0003o<P3oi>400`3=QCl0
oooP0?ooh03o0?ooh640oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@140?oTh@D0003o;@3oi>400`3=QCl0oooP
0?ooh03o0?ooh640oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@190?oTh@D0003o:03oi>400`3=QCl0oooP0?oo
h03o0?ooh640oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1>0?oTh@D0003o8`3oi>400`3=QCl0oooP0?ooh03o
0?ooh640oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@1C0?oTh@@0003o7`3oi>400`3=QCl0oooP0?ooh03o0?oo
h640oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@1G0?oTh@D0003o6P3oi>400`3=QCl0oooP0?ooh03o0?ooh640
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@1L0?oTh@@0003o5P3oi>400`3=QCl0oooP0?ooh03o0?ooh640oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@1P0?oTh@@0003o4P3oi>400`3=QCl0oooP0?ooh03o0?ooh640oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40
onCQ06@0onCQ0`000?l?0?oTh@030<f5?`3oon00oooP0?l0oooPG`3oon03000001P0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40I`3oi>440000
o`/0onCQ00<0cHDo0?ooh03oon00o`3oon1Q0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40J`3oi>430000o`P0
onCQ00<0cHDo0?ooh03oon00o`3oon1Q0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40KP3oi>440000o`@0onCQ
00<0cHDo0?ooh03oon00o`3oon1Q0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40LP3oi>430000o`030?oTh@3=
QCl0oooP0?l0oooPHP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07D0onCQ0`000?oo0?ooh680oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@1f0?oTh@040<f5?`3oon00003o0000ool0oooPH03oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
07H0onCQ00@0cHDo0?ooh03oon00oooP0`000?oo0?ooh5d0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1f0?oT
h@030<f5?`3oon00oooP00@0oooP0`000?oo0?ooh5X0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@03
0<f5?`3oon00oooP00L0oooP0P000?oo0?ooh5P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5
?`3oon00oooP00T0oooP0`000?oo0?ooh5D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3o
on00oooP00`0oooP0`000?oo0?ooh580oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3oon00
oooP00l0oooP0`000?oo0?ooh4l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3oon00oooP
0180oooP0P000?oo0?ooh4d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP0`0000090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00503oon030000ool0
oooPB03oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>40MP3oi>400`3=QCl0oooP0?ooh00G0?ooh0<0003oo`3oon170?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>40MP3oi>400`3=QCl0oooP0?ooh00J0?ooh080003oo`3oon150?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>40MP3oi>400`3=QCl0oooP0?ooh00L0?ooh0<0003oo`3oon120?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40MP3oi>400`3=QCl0oooP0?ooh00O0?ooh0<0003oo`3oon0o0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>40MP3oi>400`3=QCl0oooP0?ooh00R0?ooh080003oo`3oon0m0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
MP3oi>400`3=QCl0oooP0?ooh00T0?ooh080003oo`3oon0k0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40MP3o
i>400`3=QCl0oooP0?ooh00V0?ooh080003oo`3oon0i0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40MP3oi>40
0`3=QCl0oooP0?ooh00X0?ooh080003oo`3oon0g0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40MP3oi>400`3=
QCl0oooP0?ooh00Z0?ooh0<0003oo`3oon0d0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40MP3oi>400`3=QCl0
oooP0?ooh00]0?ooh080003oo`3oon0b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40MP3oi>400`3=QCl0oooP
0?ooh00_0?ooh080003oo`3oon0`0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40MP3oi>400`3=QCl0oooP0?oo
h00a0?ooh080003oo`3oon0^0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40MP3oi>400`3=QCl0oooP0?ooh00c
0?ooh0<0003oo`3oon0[0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40MP3oi>400`3=QCl0oooP0?ooh00f0?oo
h080003oo`3oon0Y0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
00002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3oon00oooP03P0oooP0P000?oo0?ooh2D0
oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00>P3oon020000ool0oooP9@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ07H0onCQ00<0cHDo0?ooh03oon00?03oon020000ool0oooP8`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ07H0onCQ00<0cHDo0?ooh03oon00?P3oon020000ool0oooP8@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
07H0onCQ00<0cHDo0?ooh03oon00@03oon020000ool0oooP7`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0
onCQ00<0cHDo0?ooh03oon00@P3oon020000ool0oooP7@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0onCQ
00<0cHDo0?ooh03oon00A03oon020000ool0oooP6`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0
cHDo0?ooh03oon00AP3oon020000ool0oooP6@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo
0?ooh03oon00B03oon020000ool0oooP5`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?oo
h03oon00BP3oon020000ool0oooP5@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03o
on00C03oon020000ool0oooP4`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00
CP3oon000`000?l0oooP0?ooh03o0?ooh100oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3o
on00oooP04l0oooP0P000?oo0?ooh100oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3oon00
oooP0540oooP0P000?oo0?ooh0h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00D`3oon000`00
0?l0oooP0?ooh03o0?ooh0T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00E03oon020000ool0
oooP2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00EP3oon020000ool0oooP
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00F03oon020000ool0oooP1`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00FP3oon000`000?l0oooP0?ooh03o
0?ooh0@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3oon00oooP05/0oooP0P000?oo0?oo
h0@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3oon00oooP05d0oooP0P000?oo0?ooh080
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3oon00oooP05l0oooP0P000?oo0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>40MP3oi>400`3=QCl0oooP0?ooh01Q0?ooh0030000o`3oon00oooP0?`0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@1f0?oTh@030<f5?`3oon00oooP0680oooP0P000?ol0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40MP3oi>400`3=QCl0oooP0?ooh01T0?ooh080003onP3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0
onCQ00<0cHDo0?ooh03oon00IP3oon000`000?l0oooP0?ooh03g0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00I`3oon020000ooL0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ07H0onCQ00<0cHDo0?ooh03oon00J@3oon020000ooD0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon000000
1`3oon04000000P0oooPi`0000020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3j
l>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00PP3oon000`0cXLX0[MSV
0:gHiP1]0:gHiP030000o`2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0?02]f>H00`0cXLX0[MSV
0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000
003oon00oooP0880oooP00<0<j7:0:gHiP2]f>H0KP2]f>H20000o`030:gHiP00000000000140[MSV
00<0<j7:0:gHiP2]f>H0?02]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3o
on02000000P0oooP00<000000?ooh03oon00PP3oon000`0cXLX0[MSV0:gHiP1`0:gHiP040000o`00
0000000000000100[MSV00<0<j7:0:gHiP2]f>H0?02]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>Q
bP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0220?ooh7<0<j7:00@000000000o`000?l00000
4@0cXLXn0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?H0oooP0P0000000`000?l0oooP0?ooh00>0?ooh00303>QbP2]f>H0[MSV03`0[MSV00<0
<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n@3oon02
0000o`h0oooP00<0<j7:0:gHiP2]f>H0?02]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0
[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03k0?ooh0030000o`3oon00oooP00/0oooP00<0<j7:0:gH
iP2]f>H0?02]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03l0?ooh0030000o`3oon00oooP00X0oooP00<0<j7:0:gHiP2]f>H0?02]f>H00`0cXLX0
[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03m0?ooh080003o
2P3oon000`0cXLX0[MSV0:gHiP0l0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0
EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP00<0003o0?ooh03oon001`3oon000`0cXLX0[MSV0:gH
iP0l0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP0@3oon020000o`L0oooP00<0<j7:0:gHiP2]f>H0?02]f>H00`0cXLX0[MSV0:gHiP0e
0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0<0oooP00<0003o0?oo
h03oon00103oon000`0cXLX0[MSV0:gHiP0l0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gH
iP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP103oon020000o`@0oooP00<0<j7:0:gHiP2]
f>H0?02]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh0H0oooP00D0003o0?ooh03oon00oooP03>QbP0n0:gHiP0303>QbP2]f>H0[MSV03D0
[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon070?ooh080003o00<0oooP03>QbP2]f>H0
?@2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon00
1`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2@3o
on000`000?l0<j7:0:gHiP0m0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP2P3oon020000ocd0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H0
0`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0:0?ooh00303>QbP2]f>H0003o
03`0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0:0?ooh00303>QbP2]f>H0[MSV0080003o>P2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP03
03>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0X0oooP00<0<j7:0:gHiP2]f>H0
0P2]f>H00`000?l0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0
EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP2P3oon000`0cXLX0[MSV0:gHiP030:gHiP80003o=`2]
f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh0X0oooP00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP0d0:gHiP0303>QbP2]f>H0
[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2P3oon000`0c
XLX0[MSV0:gHiP060:gHiP80003o=02]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV
05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh0X0oooP00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0
[MSV0:gHiP0a0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP2P3oon000`0cXLX0[MSV0:gHiP090:gHiP80003o<@2]f>H00`0cXLX0[MSV
0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0X0oooP00<0
<j7:0:gHiP2]f>H02`2]f>H00`000?l0[MSV0:gHiP0^0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0
<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2P3oon000`0cXLX0[MSV0:gHiP0<
0:gHiP80003o;P2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh0X0oooP00<0<j7:0:gHiP2]f>H03P2]f>H00`000?l0[MSV0:gHiP0[0:gH
iP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0:0?ooh003
03>QbP2]f>H0[MSV00l0[MSV0P000?l[0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]
f>H0EP2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0:0?ooh00303>QbP2]f>H0[MSV0140[MSV00@0003o0:gHiP000000
00009`2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh0X0oooP00<0<j7:0:gHiP2]f>H04P2]f>H010000?l0000000000000000V0:gHiP03
03>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
2P3oon0E03>QbP04000000000?l0003o000002L0<j7:=`2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0P0?ooh080000000<0003o0?ooh03oon00903oon000`0cXLX0[MSV
0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2<0oooP00<0
003o0?ooh03oon008`3oon000`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh2@0oooP0P000?lS0?ooh00303>QbP2]f>H0[MSV03D0[MSV00<0<j7:
0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP9P3oon000`000?l0oooP0?ooh00P0?oo
h00303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP9`3oon000`000?l0oooP0?ooh00O0?ooh00303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]
f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:03oon020000oal0oooP00<0<j7:0:gHiP2]f>H0
=@2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Z0?ooh0030000o`3o
on00oooP01`0oooP00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0[0?ooh0030000o`3oon00oooP01/0oooP00<0<j7:0:gHiP2]f>H0=@2]f>H0
0`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0/0?ooh080003o6`3oon000`0c
XLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2h0
oooP00<0003o0?ooh03oon00603oon000`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon0300000?l0oooP;`3oon000`000?l0oooP0?ooh00G0?ooh00303>QbP2]f>H0[MSV03D0[MSV
00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0`0?ooh080003o5`3oon000`0cXLX0[MSV0:gH
iP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP00<0003o
0?ooh03oon00503oon000`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh3<0oooP00<0003o0?ooh03oon004`3oon000`0cXLX0[MSV0:gHiP0e0:gH
iP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3@0oooP00<0003o0?ooh03o
on004P3oon000`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh3D0oooP0P000?lB0?ooh00303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0
EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP=`3oon000`000?l0oooP0?ooh00?0?ooh00303>QbP2]
f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>03oon00
0`000?l0oooP0?ooh00>0?ooh00303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP>@3oon020000o`h0oooP00<0<j7:0:gHiP2]f>H0=@2]f>H00`0c
XLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0k0?ooh0030000o`3oon00oooP00/0
oooP00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0l0?ooh0030000o`3oon00oooP00X0oooP00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV
0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0m0?ooh0030000o`3oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0n
0?ooh080003o2@3oon000`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh400oooP00<0003o0?ooh03oon001P3oon000`0cXLX0[MSV0:gHiP0e0:gH
iP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh440oooP00<0003o0?ooh03o
on001@3oon000`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP
@P3oon000`000?l0oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0
EP2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon130?ooh0030000o`3oon00oooP00<0oooP00<0<j7:0:gHiP2]f>H0=@2]
f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon140?ooh0030000o`3oon00
oooP0080oooP00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon150?ooh080003o0P3oon000`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV
05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh4L0oooP00<0003o0?ooh00cXLX0=`2]f>H00`0cXLX0
[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon180?ooh0030000o`0cXLX0[MSV03H0[MSV
00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB@3oon000`000?l0[MSV0:gH
iP0e0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:
0000o`2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon190?oo
h00303>QbP2]f>H0003o03D0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPB@3oon00100cXLX0[MSV0:gHiP000?ld0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh4T0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0c0:gHiP0303>QbP2]f>H0[MSV
05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0
[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00
o`3oon190?ooh00303>QbP2]f>H0[MSV00<0[MSV0P000?l`0:gHiP0303>QbP2]f>H0[MSV05H0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3o
on000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPB@3oon000`0cXLX0[MSV0:gH
iP050:gHiP030000o`2]f>H0[MSV02d0[MSV00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00
oooP00H0oooP1000003o0?ooh4P0oooP00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gHiP0/
0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon001P3oon04000001P0oooP7P3jl>H1
0?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon190?oo
h00303>QbP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]f>H0:`2]f>H00`0cXLX0[MSV0:gHiP1F0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80
oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gHiP2]
f>H0202]f>H00`000?l0[MSV0:gHiP0Z0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP
00<000000?ooh03oon00o`3oon190?ooh00303>QbP2]f>H0[MSV00T0[MSV00<0003o0:gHiP2]f>H0
:@2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon190?ooh00303>QbP2]
f>H0[MSV00X0[MSV00<0003o0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon190?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gHiP2]f>H09`2]f>H0
0`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon190?ooh00303>QbP2]f>H0[MSV
00`0[MSV00<0003o0:gHiP2]f>H09P2]f>H00`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon190?ooh00303>QbP2]f>H0[MSV00d0[MSV0P000?lV0:gHiP0303>QbP2]f>H0[MSV05H0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gHiP2]f>H03`2]f>H00`000?l0[MSV
0:gHiP0S0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0
<j7:0:gHiP2]f>H0402]f>H00`000?l0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gHiP2]f>H04@2]f>H00`000?l0[MSV0:gHiP0Q
0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gH
iP2]f>H04P2]f>H00`000?l0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`000?l0[MSV0:gHiP0O0:gHiP03
03>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gHiP2]f>H0
502]f>H00`000?l0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPB@3o
on000`0cXLX0[MSV0:gHiP0E0:gHiP030000o`2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H0EP2]
f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon190?ooh00303>QbP2]f>H0[MSV01H0[MSV00<0003o0:gHiP2]f>H0702]f>H0
0`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon190?ooh00303>QbP2]f>H0[MSV
01L0[MSV0P000?lL0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0
oooP00<0<j7:0:gHiP2]f>H06@2]f>H00`000?l0[MSV0:gHiP0I0:gHiP0303>QbP2]f>H0[MSV05H0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gHiP2]f>H06P2]f>H00`000?l0[MSV
0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0
<j7:0:gHiP2]f>H06`2]f>H00`000?l0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gHiP2]f>H0702]f>H00`000?l0[MSV0:gHiP0F
0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0<j7:0:gH
iP2]f>H07@2]f>H00`000?l000000000000E0:gHiP0303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh4T0oooP800cXLX010000000003o00000000000E03>QbUP0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh6T0oooP0P0000000`000?l000000?ooh00C0?ooh00303>QbP2]f>H0[MSV05H0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6X0oooP0P0000000`000?l0oooP0?ooh00B0?ooh00303>Q
bP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6d0oooP00<0003o0?ooh03oon004@3o
on000`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1^0?ooh0030000o`3oon00
oooP0100oooP00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK`3oon000`00
0?l0oooP0?ooh00?0?ooh00303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh700
oooP00<0003o0?ooh03oon003P3oon000`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh740oooP
0P000?l>0?ooh00303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL`3oon000`000?l0oooP0?oo
h00;0?ooh00303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7@0oooP00<0003o
0?ooh03oon002P3oon000`0cXLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1e0?oo
h0030000o`3oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPMP3oon000`000?l0oooP0?ooh0080?ooh00303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh7L0oooP00<0003o0?ooh03oon001`3oon000`0cXLX0[MSV0:gHiP1F0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1h0?ooh0030000o`3oon00oooP00H0oooP00<0<j7:0:gHiP2]f>H0EP2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPN@3oon000`000?l0oooP0?ooh0050?ooh00303>QbP2]f>H0
[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7X0oooP00<0003o0?ooh03oon00103oon000`0c
XLX0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1k0?ooh0030000o`3oon00oooP00<0
oooP00<0<j7:0:gHiP2]f>H0EP2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO03oon000`000?l0oooP
0?ooh0020?ooh00303>QbP2]f>H0[MSV05H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7d0oooP00D0
003o0?ooh03oon00oooP03>QbP1H0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1n0?ooh0040000o`3o
on00oooP03>QbUP0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7l0oooP00<0003o0?ooh00cXLX0F02]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<00000o`3oon200?ooh0030000o`0cXLX0[MSV05L0[MSV00<0<j7:0?ooh03oon001`3oon03
000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP@3oon000`00
0?l0[MSV0:gHiP1F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon210?ooh00303>QbP000?l0[MSV05H0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh840oooP00<0<j7:0:gHiP000?l0EP2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPP@3oon00100cXLX0[MSV0:gHiP000?mE0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on210?ooh00503>QbP2]f>H0[MSV0:gHiP000?l0E02]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP@3o
on000`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV0540[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh840oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP1@0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon210?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0003o000000000000C`2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPP@3oon0703>QbP04000000000?l00000000004l0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8P0
oooP0P0000000`000?l000000?ooh01I0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPR@3oon02000000030000o`3oon00oooP05P0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2<0?ooh0030000o`3oon00oooP05L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2=0?ooh0030000o`3oon00oooP05H0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh8h0oooP00<0003o0?oo
h03oon00D`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPS`3oon000`000?l0oooP0?ooh01D0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT03oon000`000?l0oooP0?ooh01C0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT@3o
on000`000?l0oooP0?ooh01B0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPTP3oon000`000?l0oooP0?ooh01A0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPTP3oon000`00
0?l0oooP0?ooh01A0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPT`3oon000`000?l0oooP0?ooh01@0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU03oon000`000?l0oooP
0?ooh01?0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPU@3oon000`000?l0oooP0?ooh01>0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPUP3oon000`000?l0oooP0?ooh01=
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPU`3oon000`000?l0oooP0?ooh01<0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPV03oon000`000?l0oooP0?ooh01;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
V@3oon000`000?l0oooP0?ooh01:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>H@0?ooh0@000001`3oon000`000000oooP0?ooh03o0?ooh9X0oooP00<0003o0?ooh03oon00B@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh008
0?ooh0030000003oon00oooP0?l0oooPV`3oon000`000?l0oooP0?ooh0180?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0030000003oon00oooP00L0oooP1000003o0?oo
h9X0oooP00<0003o0?ooh03oon00A@3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh003
0000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon2L0?ooh0030000o`3oon00oooP04L0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon00
00001`3oon000`000000oooP0?ooh03o0?ooh9d0oooP00<0003o0?ooh03oon00AP3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00
o`3oon2N0?ooh0030000o`3oon00oooP04D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2O0?ooh0030000o`3oon00oooP04@0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2P
0?ooh0030000o`3oon00oooP04<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2Q0?ooh0030000o`3oon00oooP0480oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2R0?ooh003
0000o`3oon00oooP0440oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2S0?ooh0030000o`3oon00oooP0400oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2T0?ooh0030000o`3o
on00oooP03l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2U0?ooh0030000o`3oon00oooP03h0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2V0?ooh0030000o`3oon00oooP
03d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2W0?ooh0030000o`3oon00oooP03`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2X0?ooh0030000o`3oon00oooP03/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh:T0oooP00<0
003o0?ooh03oon00>03oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPZP3oon000`000?l0oooP0?ooh00i0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZP3oon000`000?l0oooP0?ooh00i0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPZ`3oon000`000?l0oooP0?ooh00h0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[03oon000`000?l0oooP0?ooh00g0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[@3o
on000`000?l0oooP0?ooh00f0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP[P3oon000`000?l0oooP0?ooh00e0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[`3oon000`00
0?l0oooP0?ooh00d0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP/03oon000`000?l0oooP0?ooh00c0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon000`000?l0oooP
0?ooh00b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP/P3oon000`000?l0oooP0?ooh00a0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/`3oon000`000?l0oooP0?ooh00`
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP]03oon000`000?l0oooP0?ooh00_0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]@3oon000`000?l0oooP0?ooh00^0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2f0?ooh0030000
o`3oon00oooP02/0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh;L0oooP00<0003o0?ooh03oon00;03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;L0oooP00<0003o0?ooh03oon00;03oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;P0oooP00<0003o0?ooh03oon00:`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh;T0oooP00<0003o0?ooh03oon00:P3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP
00<0003o0?ooh03oon00:@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;/0oooP00<0003o0?ooh03oon00:03oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;`0oooP00<0003o
0?ooh03oon009`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh;`0oooP00<0003o0?ooh03oon009`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;d0oooP00<0003o0?ooh03o
on009P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh;h0oooP00<0003o0?ooh03oon009@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;l0oooP00<0003o0?ooh03oon00903o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<00oooP00<0003o0?ooh03oon008`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<40oooP00<0003o0?ooh03oon008P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<40
oooP00<0003o0?ooh03oon008P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon0300000?l0oooP`P3oon000`000?l0oooP0?ooh00O0?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon330?ooh0030000o`3oon00oooP0200oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon34
0?ooh0030000o`3oon00oooP01l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon350?ooh0030000o`3oon00oooP01h0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon360?ooh003
0000o`3oon00oooP01d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon360?ooh0030000o`3oon00oooP01d0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon370?ooh0030000o`3o
on00oooP01`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon380?ooh0030000o`3oon00oooP01/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?ooh0030000o`3oon00oooP
01X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon3:0?ooh0030000o`3oon00oooP01T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3;0?ooh0030000o`3oon00oooP01P0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on3;0?ooh0030000o`3oon00oooP01P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3<0?ooh0030000o`3oon00oooP01L0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3=0?oo
h0030000o`3oon00oooP01H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP0`00003o0?ooh<h0oooP00<0003o0?ooh03oon004`3oon03000001P0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPc`3oon000`000?l0oooP0?ooh00D0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd03o
on000`000?l0oooP0?ooh00C0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPd@3oon000`000?l0oooP0?ooh00B0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd@3oon000`00
0?l0oooP0?ooh00B0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPdP3oon000`000?l0oooP0?ooh00A0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd`3oon000`000?l0oooP
0?ooh00@0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPe03oon000`000?l0oooP0?ooh00?0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe@3oon000`000?l0oooP0?ooh00>
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPeP3oon000`000?l0oooP0?ooh00=0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe`3oon000`000?l0oooP0?ooh00<0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
e`3oon000`000?l0oooP0?ooh00<0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh=P0oooP00<0003o0?ooh03oon002`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP0?l0oooPf@3oon000`000?l0oooP0?ooh00:0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000003o
0?ooh=T0oooP00<0003o0?ooh03oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HC0?oo
h0030000003oon00oooP00D0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?oo
h03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh080
0000203oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3o
on000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3o
on000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00=`0n_3V100000020?[`iPP000000P3jl>H4000000070?[`iP00000000000000
003jl>H000000?[`iP0<000000030?[`iP000000000000@0000000@0n_3V0000000000000000203j
l>H5000000@0n_3V1`0000000`3jl>H000000?[`iP03000000T0n_3V1@0000020?[`iP@000000P3j
l>H500000180n_3V1P0000060?[`iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H000000000
0000003T0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000`3j
l>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V0?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;
0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<00000
0?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000000`3j
l>H00000000000040?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H000000?[`iP040000
0080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00d0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02
000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000<0?[`iPD000001@3jl>H2
000000H0n_3V1@0000060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H5000000@0n_3V0P0000030?[`
iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<000000P3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3j
l>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP800000
0`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`iP3jl>H0
1P3jl>H300000>H0n_3V0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P00
00020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`iP80
000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`
iP8000000P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP0B0?[`iP800000203jl>H00`00
0000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H200000080
n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H000000000000500000080
n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V00000000
00001`00000;0?[`iPD000000P3jl>H400000080n_3V0`0000000`3jl>H000000000000C0?[`iP80
00003`3jl>H3000000050?[`iP00000000000000003jl>H01000003O0?[`iP40oooo003M0?[`iP80
00000P3jl>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V01P0n_3V0P00000Q0?[`iP@0
0000603jl>H00`000000n_3V0?[`iP3O0?[`iP40oooo003L0?[`iPH00000103jl>H2000002l0n_3V
1@00000K0?[`iP<000008@3jl>H2000001T0n_3V00<000000?[`iP3jl>H0gP3jl>H10?ooo`00o`3j
l>Ih0?[`iP030000003jl>H0n_3V0=d0n_3V0@3oool00?l0n_3VM@3jl>H010000000n_3V0?[`iP00
003O0?[`iP40oooo003o0?[`iWH0n_3V0P00003P0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01763 L
.19531 .01763 L
.19531 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01763 L
.19531 .01763 L
.19531 .16187 L
s
1 .894 .882 r
.19531 .16187 m
.19531 .04763 L
.35578 .04763 L
.35578 .16187 L
F
.804 .522 .247 r
.19531 .16187 m
.19531 .04763 L
.35578 .04763 L
.35578 .16187 L
s
1 .894 .882 r
.35578 .16187 m
.35578 .1198 L
.5407 .1198 L
.5407 .16187 L
F
.804 .522 .247 r
.35578 .16187 m
.35578 .1198 L
.5407 .1198 L
.5407 .16187 L
s
.678 .847 .902 r
.5407 .16187 m
.5407 .20887 L
.62224 .20887 L
.62224 .16187 L
F
.2 .63 .79 r
.5407 .16187 m
.5407 .20887 L
.62224 .20887 L
.62224 .16187 L
s
.678 .847 .902 r
.62224 .16187 m
.62224 .33166 L
.81192 .33166 L
.81192 .16187 L
F
.2 .63 .79 r
.62224 .16187 m
.62224 .33166 L
.81192 .33166 L
.81192 .16187 L
s
.678 .847 .902 r
.81192 .16187 m
.81192 .44133 L
.88349 .44133 L
.88349 .16187 L
F
.2 .63 .79 r
.81192 .16187 m
.81192 .44133 L
.88349 .44133 L
.88349 .16187 L
s
.678 .847 .902 r
.88349 .16187 m
.88349 .50337 L
.97619 .50337 L
.97619 .16187 L
F
.2 .63 .79 r
.88349 .16187 m
.88349 .50337 L
.97619 .50337 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.09087 .01763 Mdot
.24902 .04763 Mdot
.42621 .1198 Mdot
.57079 .20887 Mdot
.72267 .33166 Mdot
.83462 .44133 Mdot
.89157 .50337 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.39832) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.525915) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000030?[`iPD000000`3jl>H3000000<0n_3V0`0000040?[`iPH0
00000P3jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H00`000000n_3V0?[`iP0200000080n_3V0P0000050?[`iP030000003jl>H0n_3V00800000103j
l>H2000000D0n_3V0P0000030?[`iP030000003jl>H0n_3V00800000o`3jl>JL0?[`iP40oooo000P
0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V
0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0
n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V000000000000303jl>H2000000<0n_3V0P00
00070?[`iP8000001@3jl>H2000000@0n_3V0P0000060?[`iP800000o`3jl>JL0?[`iP40oooo000P
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V000000000000303jl>H2000000@0
n_3V0P0000060?[`iP8000000`3jl>H4000000@0n_3V0P0000060?[`iP800000o`3jl>JL0?[`iP40
oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H0
0`000000n_3V0?[`iP02000000D0n_3V0P0000020?[`iP030000003jl>H0n_3V008000000P3jl>H2
000000030?[`iP000000000000@0n_3V0P0000030?[`iP030000003jl>H0n_3V00800000o`3jl>JL
0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H40000
00030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H20000
00D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`
iP@000000`3jl>H2000000030?[`iP00000000000080n_3V100000030?[`iP80000000<0n_3V0000
00000000103jl>H2000000<0n_3V1000003o0?[`iYd0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000T0
n_3V0P0000050?[`iP80000000<0n_3V0000000000000P3jl>H2000000D0n_3V0P0000000`3jl>H0
0000000000020?[`iP@000000`3jl>H200000?l0n_3VW`3jl>H10?ooo`007`3jl>H6000000@0n_3V
0P00000_0?[`iPD00000:03jl>H3000000X0n_3V1@0000030?[`iP<000000`3jl>H5000000<0n_3V
0`0000050?[`iP8000000`3jl>H500000?l0n_3VW03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0
n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00
000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H00000
0000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<0
0000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H10?ooo`00
8P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V
0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H20000
0080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP80
0000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000000000T0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
0000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP800000
1@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H000000000
00020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V
0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000
000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V
0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V1000
00030?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103j
l>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P00
00050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;
0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2
000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00003o
0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00000<0?[`
iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00003o0?[`
iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V0000
00000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`
iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0
000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H00000
01P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H30000
0080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V10000000
0`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H00000
0?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000<0n_3V0`0000050?[`iP<00000
103jl>H3000000<0n_3V1@00001o0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@00
0000103jl>H000000000000000020?[`iP80000000<0n_3V0000000000002@3jl>H5000000T0n_3V
0P00003O0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V
00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000
003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`
iP030000003jl>H0n_3V00800000103jl>H2000000<0n_3V0P0000000`3jl>H00000000000020?[`
iP030000003jl>H0n_3V008000000P3jl>H200000880n_3V0@3oool00280n_3V0`00000Y0?[`iP80
0000gP3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H0
00000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP0000000000
00`0n_3V0P0000050?[`iP8000000P3jl>H2000000030?[`iP000000000000D0n_3V0P0000030?[`
iP800000P@3jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP800000g@3jl>H4000000<0
n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H0
0000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000
003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000`0n_3V0P0000030?[`
iP@000000P3jl>H2000000030?[`iP000000000000D0n_3V0P0000040?[`iP800000P03jl>H10?oo
o`008@3jl>H2000000030?[`iP000000000002X0n_3V0P00003L0?[`iP80000000<0n_3V00000000
00001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`
iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP0000000000
00X0n_3V0`000000103jl>H000000000003jl>H200000080n_3V0P0000020?[`iP<0000000<0n_3V
0000003jl>H00P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H000000000000:
0?[`iP<000000`3jl>H2000000030?[`iP000000000000<0n_3V0`0000040?[`iP<000001P3jl>H2
000007l0n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V
000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V
000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3j
l>H5000000/0n_3V0`0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000030?[`iP00
0000000000L000006@3jl>H2000000030?[`iP000000000000`0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP80000000<0
n_3V000000000000O`3jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`iP800000;P3jl>H2
000000030?[`iP000000000000T0n_3V00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P000002
0?[`iP80000000<0n_3V000000000000O`3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000006@3jl>H3000000030?[`iP0000000000
00800000;P3jl>H3000000/0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`
iP<00000P03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o
0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V00@00000
0?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3
000000030?[`iP00000000000080000000@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`
iP0000020?[`iP030000003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V
0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`
iP000000000000H00000703jl>H200000<P0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000
0005000000050?[`iP00000000000000003jl>H01000000;0?[`iPD000002@3jl>H2000000030?[`
iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP800000
0P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P000002
0?[`iP8000002`3jl>H5000000/0n_3V0P0000380?[`iP40oooo000R0?[`iP<00000:03jl>H20000
00030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000000`3jl>H4000001/0n_3V0P0000380?[`iP40oooo000R0?[`iP<0
00002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0
n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H40000
00d0n_3V1@00000;0?[`iP800000b03jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002L0
n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080
n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2
000001`0n_3V0P0000370?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H2
000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3
000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103j
l>H400000080n_3V1@0000030?[`iPD00000703jl>H200000<L0n_3V0@3oool004d0n_3V0P000000
0`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403jl>H2000000`0n_3V0P00000h
0?[`iP030000003jl>H0n_3V00800000a`3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<03jl>H500000<L0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iRH0oooP0P00001/
0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000J@3oon0500000080oooP0P000004
0?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP
000006X0oooP00@000000?ooh03oon000000203oon0010000000oooP0?ooh000001/0?ooh0030000
003oon00oooP06/0oooP00<000000?ooh03oon001`3oon0010000000oooP0?ooh000001Z0?ooh003
0000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0
oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?ooh01Z0?ooh0030000003oon00oooP
06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?ooh01Y0?ooh0030000003oon00oooP
02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?oo
h03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh008
0?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V0@3oool001d0n_3V9@3oon001000
0000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03oon00K03o
on000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00JP3o
on0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0n_3V9P3oon02000006`0oooP0P00
000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000002@0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`00
0000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00
oooP02T0oooP0P00003o0?ooh;/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ80oooP00<000000?ooh03oon001P3oon04000000P0oooP6P000?l50?ooh0@00000o`3oon2g0?oo
h0@00000603oon0N0?[`iP40oooo000M0?[`iPX0oooP100000040?ooh0030000003oon00oooP00H0
oooP00<000000?ooh03oon002@3oon0J0<f5?`P0003o00<000000<f5?`3=QCl0;`3=QCoo0?ooh8T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon00
1P3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ0P00000:0000obL0onCQ
00<0cHDo0?ooh03oon00o`3oon270?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ02T0onCQ2@00
0?lN0?oTh@030<f5?`3oon00oooP0?l0oooPQ`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0380onCQ20000?lF
0?oTh@030<f5?`3oon00oooP0?l0oooPQ`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03X0onCQ1@000?lA0?oT
h@030<f5?`3oon00oooP0?l0oooPQ`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03l0onCQ1@000?l<0?oTh@03
0<f5?`3oon00oooP0?l0oooPQ`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04@0onCQ1@000?l70?oTh@030<f5
?`3oon00oooP0?l0oooPQ`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04T0onCQ1@000?l20?oTh@030<f5?`3o
on00oooP0?l0oooPQ`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ04h0onCQ1@000?oo0?ooh8L0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oon00oooP00@0003oo`3oon230?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>40D03oi>400`3=QCl0oooP0?ooh0040?ooh0D0003oo`3oon1n0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
D03oi>400`3=QCl0oooP0?ooh0090?ooh0@0003oo`3oon1j0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03o
i>400`3=QCl0oooP0?ooh00=0?ooh0@0003oo`3oon1f0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oon00
oooP0140oooP0`000?l30?ooh0800000o`3oon1/0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oon00oooP
01@0oooP10000?l200000?l0oooPK@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0500onCQ6@3=QCl2000000<0
003o<P3=QCoo0?ooh3X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ01L0onCQ
0P0000020?oTh@@0003o;@3oi>400`3=QCl0oooP0?ooh03o0?ooh3P0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@1@0?oTh@030<f5?`3oi>40onCQ01l0onCQ0`000?lZ0?oTh@030<f5?`3oon00oooP0?l0oooP>03o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ0500onCQ00<0cHDo0?oTh@3oi>408P3oi>430000obL0onCQ00<0cHDo
0?ooh03oon00o`3oon0h0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@0U0?oT
h@80003o9@3oi>400`3=QCl0oooP0?ooh03o0?ooh3P0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@03
0<f5?`3oi>40onCQ02L0onCQ0`000?lR0?oTh@030<f5?`3oon00oooP0?l0oooP>03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ0500onCQ00<0cHDo0?oTh@3oi>40:P3oi>430000oal0onCQ00<0cHDo0?ooh03oon00
o`3oon0h0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@0]0?oTh@80003o7@3o
i>400`3=QCl0oooP0?ooh03o0?ooh3P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40
onCQ02l0onCQ0`000?lJ0?oTh@030<f5?`3oon00oooP0?l0oooP>03oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
0500onCQ00<0cHDo0?oTh@3oi>40<P3oi>430000oaL0onCQ00<0cHDo0?ooh03oon00o`3oon0h0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@0e0?oTh@<0003o503oi>400`3=QCl0
oooP0?ooh03o0?ooh3P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ03P0onCQ
0P000?lB0?oTh@030<f5?`3oon00oooP0?l0oooP>03oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oT
h@0j0?oTh@<0003o3`3oi>400`3=QCl0oooP0?ooh03o0?ooh3H0oooP0`00000H0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0500onCQ00<0cHDo
0?oTh@3oi>40?@3oi>430000o``0onCQ00<0cHDo0?ooh03oon00o`3oon0h0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40D03oi>400`3=QCl0onCQ0?oTh@100?oTh@80003o2P3oi>400`3=QCl0oooP0?ooh03o0?oo
h3P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ0480onCQ0`000?l70?oTh@03
0<f5?`3oon00oooP0?l0oooP>03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0500onCQ00<0cHDo0?oTh@3oi>40
A@3oi>430000o`@0onCQ00<0cHDo0?ooh03oon00o`3oon0h0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03o
i>400`3=QCl0onCQ0?oTh@180?oTh@80003o0P3oi>400`3=QCl0oooP0?ooh03o0?ooh3P0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04X0onCQ0P000?l00`3=QCl0oooP0?ooh03o
0?ooh3P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04`0onCQ0P000?oo0?oo
h3T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04`0onCQ00@0cHDo0?ooh000
0?l0003oo`3oon0g0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<0?oTh@04
0<f5?`3oon00oooP0?ooh0<0003oo`3oon0d0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0
onCQ0?oTh@1<0?oTh@030<f5?`3oon00oooP00@0oooP0P000?oo0?ooh380oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04`0onCQ00<0cHDo0?ooh03oon001P3oon020000ool0oooP
<03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ0500onCQ00<0cHDo0?oTh@3oi>40C03oi>400`3=QCl0oooP0?oo
h0080?ooh080003oo`3oon0^0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<
0?oTh@030<f5?`3oon00oooP00X0oooP0`000?oo0?ooh2/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oT
h@030<f5?`3oi>40onCQ04`0onCQ00<0cHDo0?ooh03oon003@3oon020000ool0oooP:@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3o
i>40D03oi>400`3=QCl0onCQ0?oTh@1<0?oTh@030<f5?`3oon00oooP00l0oooP0P000?oo0?ooh2D0
oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ0500onCQ00<0cHDo0?oTh@3oi>40C03oi>400`3=QCl0oooP0?ooh00A0?ooh080003o
o`3oon0U0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<0?oTh@030<f5?`3o
on00oooP01<0oooP0P000?oo0?ooh2<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40
onCQ04`0onCQ00<0cHDo0?ooh03oon005@3oon020000ool0oooP8@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
0500onCQ00<0cHDo0?oTh@3oi>40C03oi>400`3=QCl0oooP0?ooh00G0?ooh080003oo`3oon0O0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<0?oTh@030<f5?`3oon00oooP01T0
oooP0P000?oo0?ooh1d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04`0onCQ
00<0cHDo0?ooh03oon006`3oon020000o`030?ooh000000000000?l0oooP603oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ0500onCQ00<0cHDo0?oTh@3oi>40C03oi>400`3=QCl0oooP0?ooh00M0?ooh080003o0P00
003o0?ooh1L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04`0onCQ803=QCl2
00000080003o=`3=QCoO0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<0?oT
h@030<f5?`3oi>40onCQ01h0onCQ0P0000000`3oi>40003o0000o`0d0?oTh@030<f5?`3oon00oooP
0=d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04`0onCQ00<0cHDo0?oTh@3o
i>408`3oi>420000oc80onCQ00<0cHDo0?ooh03oon00g@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0500onCQ
00<0cHDo0?oTh@3oi>40C03oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030000o`3oi>40onCQ02l0onCQ
00<0cHDo0?ooh03oon00g@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0500onCQ00<0cHDo0?oTh@3oi>40C03o
i>400`3=QCl0onCQ0?oTh@0V0?oTh@80003o;`3oi>400`3=QCl0oooP0?ooh03M0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<0?oTh@030<f5?`3oi>40onCQ02P0onCQ0P000?l]
0?oTh@030<f5?`3oon00oooP0=d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ0500onCQ00<0cHDo0?oTh@3oi>40C03oi>400`3=
QCl0onCQ0?oTh@0Z0?oTh@030000o`3oi>40onCQ02X0onCQ00<0cHDo0?ooh03oon00f`3oon030000
01P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>40D03oi>400`3=QCl0onCQ0?oTh@1<0?oTh@030<f5?`3oi>40onCQ02/0onCQ0P000?lZ0?oTh@03
0<f5?`3oon00oooP0=d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04`0onCQ
00<0cHDo0?oTh@3oi>40;@3oi>420000obP0onCQ00<0cHDo0?ooh03oon00g@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ0500onCQ00<0cHDo0?oTh@3oi>40C03oi>400`3=QCl0onCQ0?oTh@0_0?oTh@80003o9P3o
i>400`3=QCl0oooP0?ooh03M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<
0?oTh@030<f5?`3oi>40onCQ0340onCQ00<0003o0?oTh@3oi>408`3oi>400`3=QCl0oooP0?ooh03M
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<0?oTh@030<f5?`3oi>40onCQ
0380onCQ0P000?lS0?oTh@030<f5?`3oon00oooP0=d0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@03
0<f5?`3oi>40onCQ04`0onCQ00<0cHDo0?oTh@3oi>40=03oi>420000ob40onCQ00<0cHDo0?ooh03o
on00g@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ0500onCQ00<0cHDo0?oTh@3oi>40C03oi>400`3=QCl0onCQ
0?oTh@0f0?oTh@80003o7`3oi>400`3=QCl0oooP0?ooh03M0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03o
i>400`3=QCl0onCQ0?oTh@1<0?oTh@030<f5?`3oi>40onCQ03P0onCQ00<0003o0?oTh@3oi>40703o
i>400`3=QCl0oooP0?ooh03M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<
0?oTh@030<f5?`3oi>40onCQ03T0onCQ0P000?lL0?oTh@030<f5?`3oon00oooP0=d0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04`0onCQ00<0cHDo0?oTh@3oi>40>`3oi>420000
oaX0onCQ00<0cHDo0?ooh03oon00g@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0500onCQ00<0cHDo0?oTh@3o
i>40C03oi>400`3=QCl0onCQ0?oTh@0m0?oTh@030000o`3oi>40onCQ01L0onCQ00<0cHDo0?ooh03o
on00g@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@1@0?oTh@030<f5?`3oi>40onCQ04`0onCQ
00<0cHDo0?oTh@3oi>40?P3oi>420000oaL0onCQ00<0cHDo0?ooh03oon00g@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40D03oi>400`3=QCl0onCQ0?oTh@1<0?oTh@030<f5
?`3oi>40onCQ0400onCQ0P000?lE0?oTh@030<f5?`3oon00oooP0=d0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon04000000P0oooP
i`0000020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003o
on00oooP000000L0oooP00<000000?ooh03oon00lP3oon000`000?l0oooP0?ooh00@0?ooh00303>Q
bP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>Q
bP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?<0oooP
0P000?l@0?ooh00303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV
0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00m@3o
on000`000?l0oooP0?ooh00=0?ooh00303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0FP2]
f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03f
0?ooh080003o3@3oon000`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05X0[MSV00<0<j7:
0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n03oon000`00
0?l0oooP0?ooh00:0?ooh00303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0FP2]f>H00`0c
XLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03i0?ooh080
003o2P3oon000`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05X0[MSV00<0<j7:0:gHiP2]
f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n`3oon000`000?l0oooP
0?ooh0070?ooh00303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV
0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03l0?ooh0030000o`3o
on00oooP00H0oooP00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1J0:gHiP0303>QbP2]
f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?d0oooP0P000?l6
0?ooh00303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0030000o`3oon00oooP
00<0oooP00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1J0:gHiP0303>QbP2]f>H0[MSV
0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP0@3oon020000o`<0
oooP00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1J0:gHiP0303>QbP2]f>H0[MSV0200
[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP0`3oon0010000?l0oooP
0?ooh00cXLXV0:gHiP0303>QbP2]f>H0[MSV05X0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0
[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon040?ooh080003o00<0<j7:0:gHiP2]f>H0
902]f>H00`0cXLX0[MSV0:gHiP1J0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP1P3oon000`000?l0[MSV0:gHiP0T0:gHiP0303>QbP2]
f>H0[MSV05X0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o
0?ooh0H0oooP00<0<j7:0000o`000?l0902]f>H00`0cXLX0[MSV0:gHiP1J0:gHiP0303>QbP2]f>H0
[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon060?ooh00403>QbP2]f>H0[MSV
0000ob<0[MSV00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0
[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0H0oooP00@0<j7:0:gHiP2]f>H0[MSV0P000?lQ
0:gHiP0303>QbP2]f>H0[MSV05X0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon060?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0003o0:gH
iP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP1J0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gH
iP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP1P3oon000`0cXLX0[MSV0:gHiP040:gHiP80
003o7P2]f>H00`0cXLX0[MSV0:gHiP1J0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]
f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP1P3oon000`0cXLX0[MSV0:gHiP060:gHiP030000
o`2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>Q
bP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0H0oooP00<0<j7:0:gHiP2]f>H01`2]
f>H20000oa/0[MSV00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]
f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0H0oooP00<0<j7:0:gHiP2]f>H02@2]f>H0
10000?l0[MSV00000000000G0:gHiP0303>QbP2]f>H0[MSV05X0[MSV00<0<j7:0:gHiP2]f>H0802]
f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon060?ooh0d0<j7:0P000?l2
000001L0<j7:G02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh1<0oooP0P0000000`000?l000000?ooh00E0?ooh00303>QbP2]f>H0[MSV
05X0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0D0?ooh08000000P000?lE0?ooh00303>QbP2]f>H0[MSV05X0[MSV00<0<j7:0:gHiP2]
f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0H0?ooh0030000
o`3oon00oooP0180oooP00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>Q
bP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1T0oooP0P000?lB0?ooh00303>QbP2]
f>H0[MSV05X0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0K0?ooh0030000o`3oon00oooP00l0oooP00<0<j7:0:gHiP2]f>H0FP2]f>H0
0`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP703oon020000
o`l0oooP00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV
02X0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP7P3oon000`000?l0oooP0?ooh00<0?ooh00303>QbP2]f>H0[MSV05X0
[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0O0?ooh0030000o`3oon00oooP00/0oooP00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV
0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh200oooP0P00
0?l;0?ooh00303>QbP2]f>H0[MSV05X0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gH
iP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0R0?ooh0030000o`3oon00oooP00P0oooP00<0<j7:
0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh2<0oooP00<0003o0?ooh03oon001`3oon000`0cXLX0[MSV0:gHiP1J0:gH
iP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP903oon020000o`L0oooP00<0<j7:0:gHiP2]f>H0FP2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP03
03>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2H0oooP00<0003o0?ooh03oon00
103oon000`0cXLX0[MSV0:gHiP1J0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP9`3oon000`000?l0oooP0?ooh0030?ooh00303>QbP2]
f>H0[MSV05X0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0X0?ooh080003o0`3oon000`0cXLX0[MSV0:gHiP1J0:gHiP0303>QbP2]f>H0
[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:P3oon001000
0?l0oooP0?ooh00cXLYL0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP:`3oon000`000?l0oooP03>QbP1L0:gHiP0303>QbP2]f>H0[MSV
0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;03oon020000oe`0
[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0]0?ooh00303>QbP000?l0[MSV05X0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV
0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh2d0oooP00<0<j7:0:gHiP000?l0FP2]f>H00`0cXLX0[MSV0:gH
iP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;@3oon000`0cXLX0[MSV0:gHiP02
0000oeP0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0]0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o0:gHiP2]f>H0E@2]f>H00`0c
XLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2d0
oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP1D0:gHiP0303>QbP2]f>H0[MSV0200
[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;@3oon000`0cXLX0[MSV
0:gHiP040:gHiP030000o`2]f>H0[MSV05<0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV
0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]0?ooh00303>QbP2]f>H0[MSV00D0[MSV0P00
0?mC0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP;@3oon000`0cXLX0[MSV0:gHiP070:gHiP030000o`2]f>H0[MSV0500[MSV00<0<j7:
0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]0?oo
h00303>QbP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H0C`2]f>H00`0cXLX0[MSV0:gHiP0P0:gH
iP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2d0oooP00<0<j7:0:gHiP2]
f>H02@2]f>H20000odl0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0]0?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gHiP2]f>H0
C02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh2d0oooP00<0<j7:0:gHiP2]f>H0302]f>H00`000?l0[MSV0:gHiP1;0:gHiP0303>QbP2]
f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;@3oon00
0`0cXLX0[MSV0:gHiP0=0:gHiP030000o`2]f>H0[MSV04X0[MSV00<0<j7:0:gHiP2]f>H0802]f>H0
0`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]0?ooh00303>QbP2]f>H0[MSV
00h0[MSV0P000?m:0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP;@3oon000`0cXLX0[MSV0:gHiP0@0:gHiP030000o`2]f>H0[MSV04L0
[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0]0?ooh00303>QbP2]f>H0[MSV0140[MSV00<0003o0:gHiP2]f>H0AP2]f>H00`0cXLX0[MSV
0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP;@3oon000`0cXLX0[MSV0:gH
iP0B0:gHiP030000o`2]f>H0[MSV04D0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gH
iP0Z0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh2d0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`000?l0[MSV0:gHiP14
0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP;@3oon000`0cXLX0[MSV0:gHiP0D0:gHiP030000o`2]f>H0[MSV04<0[MSV00<0<j7:0:gH
iP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]0?ooh003
03>QbP2]f>H0[MSV01D0[MSV0P000?m30:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]
f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;@3oon000`0cXLX0[MSV0:gHiP0G0:gHiP030000
o`2]f>H0[MSV0400[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0]0?ooh00303>QbP2]f>H0[MSV01P0[MSV00<0003o0:gHiP2]f>H0?`2]
f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh2d0oooP00<0<j7:0:gHiP2]f>H06@2]f>H00`000?l0[MSV0:gHiP0n0:gHiP0303>QbP2]f>H0
[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;@3oon000`0c
XLX0[MSV0:gHiP0J0:gHiP030000o`2]f>H0[MSV03d0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0c
XLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]0?ooh00303>QbP2]f>H0[MSV01/0
[MSV00<0003o0:gHiP2]f>H0?02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh2d0oooP00<0<j7:0:gHiP2]f>H0702]f>H00`000?l0[MSV
0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP;@3oon000`0cXLX0[MSV0:gHiP0M0:gHiP030000o`2]f>H0[MSV03X0[MSV00<0
<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]
0?ooh00303>QbP2]f>H0[MSV01h0[MSV00<0003o0:gHiP2]f>H0>@2]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00o`3oon0]0?oo
h00303>QbP2]f>H0[MSV01l0[MSV0P000?li0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gH
iP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon0]0?ooh003
03>QbP2]f>H0[MSV0240[MSV00<0003o0:gHiP2]f>H0=P2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP03
03>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon0/0?ooh00303>Q
bP2]f>H0[MSV0280[MSV00<0003o0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>Q
bP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3j
l>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon0]0?ooh00303>QbP2]
f>H0[MSV02<0[MSV00<0003o0:gHiP2]f>H0=02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]
f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooP;@3oon00
0`0cXLX0[MSV0:gHiP0T0:gHiP030000o`2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0802]f>H0
0`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooP;@3oon000`0c
XLX0[MSV0:gHiP0U0:gHiP030000o`2]f>H0[MSV0380[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0c
XLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]0?ooh00303>QbP2]f>H0[MSV02H0
[MSV00<0003o0:gHiP2]f>H0<@2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh2d0oooP00<0<j7:0:gHiP2]f>H09`2]f>H00`000?l0[MSV
0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP;@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP030000o`2]f>H0[MSV02l0[MSV00<0
<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]
0?ooh00303>QbP2]f>H0[MSV02T0[MSV0P000?l_0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:
0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;@3oon000`0cXLX0[MSV0:gHiP0[0:gH
iP030000o`2]f>H0[MSV02`0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0Z0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0]0?ooh00303>QbP2]f>H0[MSV02`0[MSV00<0003o0:gHiP2]
f>H0:`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh2d0oooP00<0<j7:0:gHiP2]f>H0;@2]f>H00`000?l000000000000Z0:gHiP0303>Q
bP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;@3o
on0`03>QbP04000000000?l00000000002X0<j7:8P2]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1M0?ooh080000000<0003o0000003oon00:03oon000`0cXLX0[MSV0:gH
iP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5h0oooP0P000000
0`000?l0oooP0?ooh00W0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0<00000o`3oon1Q0?ooh0030000o`3oon00oooP02H0oooP00<0<j7:0:gHiP2]f>H0802]f>H00`0c
XLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh680oooP00<0003o0?ooh03oon009@3oon000`0cXLX0
[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6<0oooP
0P000?lU0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPI@3oon000`000?l0oooP0?ooh00R0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0
<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPIP3oon000`000?l0oooP0?ooh00Q
0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPI`3oon000`000?l0oooP0?ooh00P0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gH
iP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ03oon000`000?l0oooP0?ooh00O0?ooh003
03>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
J@3oon000`000?l0oooP0?ooh00N0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPJP3oon000`000?l0oooP0?ooh00M0?ooh00303>QbP2]
f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ`3oon00
0`000?l0oooP0?ooh00L0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPK03oon000`000?l0oooP0?ooh00K0?ooh00303>QbP2]f>H0[MSV
0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK@3oon000`000?l0
oooP0?ooh00J0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPKP3oon000`000?l0oooP0?ooh00I0?ooh00303>QbP2]f>H0[MSV0200[MSV
00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK`3oon000`000?l0oooP0?oo
h00H0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPL03oon000`000?l0oooP0?ooh00G0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:
0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon1a0?ooh080003o5`3oon000`0cXLX0[MSV0:gHiP0P0:gH
iP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL`3oon000`000?l0oooP0?ooh00D0?ooh003
03>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
M03oon000`000?l0oooP0?ooh00C0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPM@3oon000`000?l0oooP0?ooh00B0?ooh00303>QbP2]
f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPMP3oon00
0`000?l0oooP0?ooh00A0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPM`3oon000`000?l0oooP0?ooh00@0?ooh00303>QbP2]f>H0[MSV
0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPN03oon000`000?l0
oooP0?ooh00?0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPN@3oon000`000?l0oooP0?ooh00>0?ooh00303>QbP2]f>H0[MSV0200[MSV
00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPNP3oon000`000?l0oooP0?oo
h00=0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPN`3oon000`000?l0oooP0?ooh00<0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:
0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO03oon000`000?l0oooP0?ooh00;0?oo
h00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPO@3oon000`000?l0oooP0?ooh00:0?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]
f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPOP3oon000`000?l0oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO`3o
on000`000?l0oooP0?ooh0080?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0:P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<00000o`3oon200?ooh0030000o`3oon00oooP00L0oooP00<0<j7:0:gHiP2]f>H0802]f>H0
0`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh840oooP00<0003o0?ooh03oon001P3oon000`0c
XLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh880
oooP00<0003o0?ooh03oon001@3oon000`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh8<0oooP00<0003o0?ooh03oon00103oon000`0cXLX0[MSV
0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8@0oooP00<0
003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh8D0oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gHiP0P
0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8H0oooP00D0003o0?oo
h03oon00oooP03>QbP0R0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h8L0oooP00@0003o0?ooh03oon00<j7:8P2]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon280?ooh0030000o`3oon00<j7:0280[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPR@3oon000`000?l0<j7:0:gHiP0Q0:gHiP0303>QbP2]f>H0[MSV02X0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP00<0003o0:gHiP2]f>H0802]f>H00`0cXLX0[MSV
0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2:0?ooh00303>QbP000?l0[MSV0200[MSV00<0
<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPRP3oon000`0cXLX0[MSV0000o`0P
0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP00@0<j7:0:gH
iP2]f>H0003o7`2]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh8X0oooP00D0<j7:0:gH
iP2]f>H0[MSV0000o`0N0:gHiP0303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon001`3oon03
000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPRP3oon000`0c
XLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPRP3oon000`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0[MSV01X0
[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPRP3oon000`0cXLX0[MSV
0:gHiP040:gHiP030000o`2]f>H0[MSV01T0[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPRP3oon000`0cXLX0[MSV0:gHiP050:gHiP030000o`2]f>H0[MSV01P0[MSV00<0
<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPRP3oon000`0cXLX0[MSV0:gHiP05
0:gHiP030000o`2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPRP3oon000`0cXLX0[MSV0:gHiP060:gHiP030000o`000000000001L0[MSV00<0<j7:0:gH
iP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPRP3oon000`0cXLX0[MSV0:gHiP060:gHiP04
000000000?l00000000001H0[MSV00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPRP3oon0903>QbP80000000<0003o0000000cXLX05P0cXLX/0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2D0?ooh080000000<0003o0?ooh03oon00503oon000`0cXLX0[MSV0:gHiP0Z0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2G0?ooh0030000o`3oon00oooP01<0oooP00<0<j7:0:gHiP2]f>H0:P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPV03oon000`000?l0oooP0?ooh00B0?ooh00303>QbP2]f>H0
[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9T0oooP00<0003o0?ooh03oon004@3oon000`0c
XLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ00oooP100000070?ooh0030000003oon00oooP0?l0oooPVP3oon000`000?l0
oooP0?ooh00@0?ooh00303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh0080?ooh0030000
003oon00oooP0?l0oooPV`3oon000`000?l0oooP0?ooh00?0?ooh00303>QbP2]f>H0[MSV02X0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3o
on000`000000oooP0?ooh0070?ooh0@00000o`3oon2J0?ooh0030000o`3oon00oooP00l0oooP00<0
<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0060?ooh0@00000603oon0N0?[`iP40oooo000M
0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh9`0oooP00<0003o
0?ooh03oon003P3oon000`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon00
0`000000oooP0?ooh03o0?ooh9d0oooP00<0003o0?ooh03oon003@3oon000`0cXLX0[MSV0:gHiP0Z
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPWP3oon000`000?l0oooP0?ooh00<0?oo
h00303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9l0oooP00<0003o0?ooh03o
on002`3oon000`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2P0?ooh0030000
o`3oon00oooP00X0oooP00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX@3o
on000`000?l0oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh:80oooP00<0003o0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2S0?ooh0030000o`3oon00oooP00L0oooP00<0<j7:0:gHiP2]f>H0:P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPY03oon000`000?l0oooP0?ooh0060?ooh00303>QbP2]f>H0[MSV02X0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00<0003o0?ooh03oon001@3oon000`0cXLX0[MSV
0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2V0?ooh0030000o`3oon00oooP00@0oooP00<0
<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY`3oon000`000?l0oooP0?ooh003
0?ooh00303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:P0oooP00<0003o0?oo
h03oon000P3oon000`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh:T0oooP00D0003o0?ooh03o
on00oooP03>QbP0/0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP00@0003o0?ooh03oon00<j7:;02]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPZP3oon0010000?l0oooP0?ooh00cXLX/0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2[0?ooh0030000o`3oon00<j7:02`0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:`0oooP
00<0003o03>QbP2]f>H0:`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[@3oon000`000?l0[MSV0:gH
iP0Z0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2]0?ooh00303>QbP000?l0[MSV02X0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh:d0oooP00<0<j7:0:gHiP000?l00P00000X0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2]0?ooh00403>QbP2]f>H000000000o`8000009`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP[@3oon0203>QbP80000000<0003o0000000cXLX09`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/03oon02000000030000
o`3oon00oooP0340oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2c0?ooh0030000o`3oon00oooP0300oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2d0?ooh0030000o`3oon00
oooP02l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2e0?ooh0030000o`3oon00oooP02h0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh;H0oooP00<0003o0?ooh03oon00:`3oon03000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]`3oon000`000?l0oooP
0?ooh00/0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP]`3oon000`000?l0oooP0?ooh00/0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^03oon000`000?l0oooP0?ooh00[
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP^@3oon000`000?l0oooP0?ooh00Z0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^P3oon000`000?l0oooP0?ooh00Y0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
^`3oon000`000?l0oooP0?ooh00X0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP_03oon000`000?l0oooP0?ooh00W0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_03oon00
0`000?l0oooP0?ooh00W0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP_@3oon000`000?l0oooP0?ooh00V0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_P3oon000`000?l0
oooP0?ooh00U0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP_`3oon000`000?l0oooP0?ooh00T0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`03oon000`000?l0oooP0?oo
h00S0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP`@3oon000`000?l0oooP0?ooh00R0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`@3oon000`000?l0oooP0?ooh00R0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon320?ooh003
0000o`3oon00oooP01l0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<<0oooP00<0003o0?ooh03oon00803oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<@0oooP00<0003o0?ooh03oon007`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<D0oooP00<0003o0?ooh03oon007P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<H0oooP00<0003o0?ooh03oon007@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<H0
oooP00<0003o0?ooh03oon007@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh<L0oooP00<0003o0?ooh03oon00703oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<P0oooP00<0
003o0?ooh03oon006`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh<T0oooP00<0003o0?ooh03oon006P3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<X0oooP00<0003o0?oo
h03oon006@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh</0oooP00<0003o0?ooh03oon00603oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh</0oooP00<0003o0?ooh03oon00
603oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh<`0oooP00<0003o0?ooh03oon005`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<d0oooP00<0003o0?ooh03oon005P3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPcP3oon000`00
0?l0oooP0?ooh00C0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon3?0?ooh0030000o`3oon00oooP01@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3@0?ooh0030000o`3oon00oooP01<0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on3A0?ooh0030000o`3oon00oooP0180oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3A0?ooh0030000o`3oon00oooP0180oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3B0?oo
h0030000o`3oon00oooP0140oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon3C0?ooh0030000o`3oon00oooP0100oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3D0?ooh0030000
o`3oon00oooP00l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon3E0?ooh0030000o`3oon00oooP00h0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3F0?ooh0030000o`3oon00
oooP00d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon3G0?ooh0030000o`3oon00oooP00`0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3G0?ooh0030000o`3oon00oooP00`0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000
003oon00oooP0?l0oooPf03oon000`000?l0oooP0?ooh00;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00
o`3oon3I0?ooh0030000o`3oon00oooP00X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ80oooP00<000000?ooh03oon001P3oon0400000?l0oooPf@3oon000`000?l0oooP0?oo
h0060?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ<0oooP00<000000?ooh03oon001@3oon00
0`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP
0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP
00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H40000
0080n_3V200000020?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0
n_3V00000000000010000000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`
iP000000n_3V00<000002@3jl>H500000080n_3V100000020?[`iPD000004P3jl>H6000000H0n_3V
00<000000?[`iP3jl>H0103jl>H3000000040?[`iP000000000000000>@0n_3V0@3oool00=d0n_3V
0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003j
l>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V
000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3j
l>H200000080n_3V0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0
n_3V000000000000i@3jl>H10?ooo`00g@3jl>H2000000030?[`iP000000000000@0n_3V0P000003
0?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P00
00020?[`iP8000000P3jl>H2000000`0n_3V1@0000050?[`iP8000001P3jl>H5000000H0n_3V0`00
003V0?[`iP40oooo003M0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003j
l>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP060?[`iP<00000iP3jl>H10?ooo`00
g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H00000
0000003jl>H000000?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2
000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3
000000030?[`iP000000n_3V0180n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P000000
0`3jl>H000000000003U0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000030?[`iP0000000000
00800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`
iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000000/0n_3V1@0000020?[`
iP@000000P3jl>H3000000030?[`iP000000000001<0n_3V0P00000?0?[`iP<0000000D0n_3V0000
0000000000000?[`iP0400000=l0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000<`3jl>H20000
00<0n_3V00<000000?[`iP3jl>H0603jl>H200000240n_3V1000000H0?[`iP030000003jl>H0n_3V
0=l0n_3V0@3oool00=`0n_3V1P0000040?[`iP800000;`3jl>H5000001/0n_3V0`00000Q0?[`iP80
00006@3jl>H00`000000n_3V0?[`iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<000000?[`iP3jl>H0
g@3jl>H10?ooo`00o`3jl>Ie0?[`iP040000003jl>H0n_3V00000=l0n_3V0@3oool00?l0n_3VMP3j
l>H200000>00n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01512 L
.14558 .01512 L
.14558 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01512 L
.14558 .01512 L
.14558 .16187 L
s
1 .894 .882 r
.14558 .16187 m
.14558 .0327 L
.26994 .0327 L
.26994 .16187 L
F
.804 .522 .247 r
.14558 .16187 m
.14558 .0327 L
.26994 .0327 L
.26994 .16187 L
s
1 .894 .882 r
.26994 .16187 m
.26994 .07231 L
.33477 .07231 L
.33477 .16187 L
F
.804 .522 .247 r
.26994 .16187 m
.26994 .07231 L
.33477 .07231 L
.33477 .16187 L
s
1 .894 .882 r
.33477 .16187 m
.33477 .1143 L
.50743 .1143 L
.50743 .16187 L
F
.804 .522 .247 r
.33477 .16187 m
.33477 .1143 L
.50743 .1143 L
.50743 .16187 L
s
.678 .847 .902 r
.50743 .16187 m
.50743 .16729 L
.56553 .16729 L
.56553 .16187 L
F
.2 .63 .79 r
.50743 .16187 m
.50743 .16729 L
.56553 .16729 L
.56553 .16187 L
s
.678 .847 .902 r
.56553 .16187 m
.56553 .2295 L
.65791 .2295 L
.65791 .16187 L
F
.2 .63 .79 r
.56553 .16187 m
.56553 .2295 L
.65791 .2295 L
.65791 .16187 L
s
.678 .847 .902 r
.65791 .16187 m
.65791 .32438 L
.74009 .32438 L
.74009 .16187 L
F
.2 .63 .79 r
.65791 .16187 m
.65791 .32438 L
.74009 .32438 L
.74009 .16187 L
s
.678 .847 .902 r
.74009 .16187 m
.74009 .37178 L
.86749 .37178 L
.86749 .16187 L
F
.2 .63 .79 r
.74009 .16187 m
.74009 .37178 L
.86749 .37178 L
.86749 .16187 L
s
.678 .847 .902 r
.86749 .16187 m
.86749 .55474 L
.97619 .55474 L
.97619 .16187 L
F
.2 .63 .79 r
.86749 .16187 m
.86749 .55474 L
.97619 .55474 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.04885 .01512 Mdot
.19031 .0327 Mdot
.32172 .07231 Mdot
.41554 .1143 Mdot
.50869 .16729 Mdot
.59912 .2295 Mdot
.7146 .32438 Mdot
.76559 .37178 Mdot
.93604 .55474 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.362582) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.59107) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000030?[`iP<00000103jl>H600000080n_3V0`0000050?[`iP80
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP030000003j
l>H0n_3V00800000103jl>H2000000D0n_3V0P0000030?[`iP80000000<0n_3V000000000000103j
l>H200000?l0n_3VY03jl>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P000003
0?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H2000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP00
0000000000`0n_3V0P0000050?[`iP800000103jl>H2000000<0n_3V0P0000000`3jl>H000000000
00040?[`iP800000o`3jl>JT0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P000000
1P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP800000
00@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80
000000<0n_3V000000000000303jl>H2000000<0n_3V100000040?[`iP8000000`3jl>H200000003
0?[`iP000000000000@0n_3V0P00003o0?[`iZ@0n_3V0@3oool00200n_3V0P0000020?[`iP800000
0`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H20000
00@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02
000001P0n_3V0P0000000`3jl>H00000000000090?[`iP030000003jl>H0n_3V008000000P3jl>H2
000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V0000000000001@3jl>H2
00000?l0n_3VX`3jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3jl>H00000000000020000
00@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H50000
00X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`iP80000000<0n_3V0000
000000002@3jl>H4000000<0n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H20000
00030?[`iP000000000000D0n_3V0P00003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000T0
n_3V0P0000050?[`iP80000000<0n_3V0000000000000P3jl>H4000000<0n_3V0P0000000`3jl>H0
0000000000020?[`iP030000003jl>H0n_3V00800000o`3jl>JS0?[`iP40oooo000O0?[`iPH00000
103jl>H2000002l0n_3V1@00000X0?[`iP<000002P3jl>H5000000<0n_3V0`0000050?[`iP800000
103jl>H3000000<0n_3V1@00003o0?[`iZ<0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40
oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200n_3V1P0000001@3jl>H000000000
00000000n_3V00<000000P3jl>H3000000<0n_3V100000030?[`iP80000000@0n_3V000000000000
n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P0000050?[`iP<00000103jl>H3000000@0
n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V00@000000?[`iP000000
00000`3jl>H01@000000n_3V000000000000n_3V00<000000P3jl>H2000000@0n_3V0P0000020?[`
iP8000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000000000000`3jl>H20000
00@0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
00000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H0
0000000000020?[`iP800000103jl>H2000000D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0
n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0
n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V000000000000
0P3jl>H2000000@0n_3V1P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000D0n_3V
1@0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000090?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V
0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3j
l>H2000000@0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0`0000020?[`iP<00000
00<0n_3V0000003jl>H0103jl>H2000000<0n_3V0P00000`0?[`iP80000000<0n_3V000000000000
2@3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000<0n_3V100000060?[`iP800000
o`3jl>JM0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080n_3V1@0000030?[`iP@000000`3j
l>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H4000000@0n_3V0P00
000`0?[`iP80000000<0n_3V0000000000002@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3j
l>H2000000D0n_3V0P0000080?[`iP800000o`3jl>JM0?[`iP40oooo000R0?[`iP8000002`3jl>H2
00000280n_3V0P00000`0?[`iP80000000<0n_3V0000000000002P3jl>H2000000D0n_3V0P000005
0?[`iP8000001@3jl>H2000000D0n_3V0P0000040?[`iP030000003jl>H0n_3V00800000o`3jl>JM
0?[`iP40oooo000P0?[`iPH000002@3jl>H200000200n_3V1000000a0?[`iP<00000303jl>H30000
00@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000020?[`iPD00000o`3jl>JM0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP0000000000
0?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP040000003jl>H000000?[`iP8000000P3jl>H00`00
0000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0000000<0n_3V00000000
00000P0000001@3jl>H000000?[`iP000000n_3V00<000000P3jl>H00`000000n_3V0000000H0?[`
iPD00000f`3jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`
iPH000000P3jl>H400000080n_3V0`000000103jl>H000000000000000080?[`iP@0000000<0n_3V
0000000000000P3jl>H400000080n_3V1@0000001`3jl>H00000000000000000n_3V0000003jl>H0
0`00000H0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<000000`3jl>H5000000<0n_3V
0`0000040?[`iP<000000`3jl>H5000007P0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000
0005000000040?[`iP000000000000000080n_3V0P0000000`3jl>H00000000000090?[`iPD00000
2@3jl>H200000=l0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP800000
0P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3j
l>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000000`3jl>H20000
00@0n_3V00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00D0n_3V00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
07/0n_3V0@3oool00280n_3V0`00000Y0?[`iP800000gP3jl>H2000000@0n_3V0P0000020?[`iP80
00000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000
000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V
00800000603jl>H2000000030?[`iP000000000000`0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000`3jl>H2000000L0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H20000
07X0n_3V0@3oool00280n_3V0`00000J0?[`iPD000002`3jl>H200000=d0n_3V100000030?[`iPD0
00000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000
000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V
008000002@3jl>H5000000X0n_3V0P0000000`3jl>H000000000000<0?[`iP8000000P3jl>H20000
00030?[`iP000000000000@0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP0000000000
00@0n_3V0P00001i0?[`iP40oooo000Q0?[`iP80000000<0n_3V000000000000:P3jl>H200000=`0
n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000002P3jl>H3000000040?[`iP00000000000?[`iP8000000P3jl>H2
00000080n_3V0`0000000`3jl>H000000?[`iP02000000030?[`iP000000n_3V00800000603jl>H2
000000030?[`iP000000000000X0n_3V0`0000030?[`iP@000001P3jl>H200000080n_3V00<00000
0?[`iP3jl>H00P0000030?[`iP<000001P3jl>H2000007P0n_3V0@3oool00200n_3V0`000000103j
l>H0000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP000000
00000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3j
l>H500000080n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`0000000`3jl>H000000000
00020?[`iP@000000P3jl>H3000000030?[`iP000000000000L000006@3jl>H2000000030?[`iP00
0000000000`0n_3V0P0000020?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V1000
00030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000007P0n_3V0@3o
ool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403jl>H2
000000`0n_3V0P00000R0?[`iP8000000P3jl>H2000002h0n_3V0P0000000`3jl>H0000000000009
0?[`iP030000003jl>H0n_3V008000000`3jl>H2000000@0n_3V0P0000000`3jl>H0000000000002
0?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000001h
0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H20000
00H0n_3V0P00000I0?[`iP<0000000<0n_3V0000000000000P00000^0?[`iP<000002`3jl>H30000
00D0n_3V0`0000030?[`iP<000000`3jl>H5000000<0n_3V0`0000040?[`iP<00000N@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V
0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H1
0?ooo`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H000000P3j
l>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`iP000000
00000080000000@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000
003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH00000
0`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000H00000
6P3jl>H300000<T0n_3V0@3oool00240n_3V0P0000000`3jl>H0000000000005000000050?[`iP00
000000000000003jl>H01000000;0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V
0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V
0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000002`3jl>H5
000000/0n_3V0P0000380?[`iP40oooo000R0?[`iP<00000:03jl>H2000000030?[`iP0000000000
0=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H20000
00@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000
000000000`3jl>H4000001`0n_3V0P0000370?[`iP40oooo000R0?[`iP<000002@3jl>H00`000000
n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V100000030?[`iPD0
00000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H4000000d0n_3V1@00000:0?[`
iP@00000a`3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002L0n_3V0P0000000`3jl>H0
00000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H0
00000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000001T0n_3V0P000000
0`3jl>H00000000000370?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H2
000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3
000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103j
l>H400000080n_3V1@0000030?[`iPD000006@3jl>H2000000030?[`iP00000000000<L0n_3V0@3o
ool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403jl>H2
000000`0n_3V0P00000h0?[`iP80000000<0n_3V000000000000a`3jl>H10?ooo`00CP3jl>H30000
0=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<@3jl>H30000
0<P0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M
0?[`iRH0oooP0P00001/0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000J@3oon05
00000080oooP0P0000040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3jl>HU0?oo
h0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000203oon0010000000oooP0?oo
h000001/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon001`3oon0010000000oooP
0?ooh000001Z0?ooh0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000
003oon00oooP000006X0oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?ooh01Z0?oo
h0030000003oon00oooP06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?ooh01Y0?oo
h0030000003oon00oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP0000
06X0oooP00@000000?ooh03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00J`3oon00
0`000000oooP0?ooh0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V0@3oool0
01d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0oooP00<0
00000?ooh03oon00K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP00<0
00000?ooh03oon00JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0n_3V9P3o
on02000006`0oooP0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<00000J`3o
on02000002@0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000
603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP01@0oooP0P00
003o0?ooh=00oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<00000
0?ooh03oon001P3oon000`000000oooP0?ooh00C0?ooh0@00000o`3oon3?0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP100000080?oo
h1X0003o8P3=QCoo0?ooh9h0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V2P3oon04000000@0
oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00P0
onCQ0P00000=0?oTh@P0003o6@3oi>400`3=QCl0oooP0?ooh03o0?ooh9l0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ01l0onCQ2P000?l?0?oTh@030<f5?`3oon00oooP0?l0oooP
W`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0Y0?oTh@T0003o1P3oi>400`3=QCl0oooP0?oo
h03o0?ooh9l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0b0?oTh@P0003oo`3oon2P0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40>03oi>400`3=QCl0oooP0000o`040000ool0oooPV`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0
onCQ00<0cHDo0?ooh03oon00103oon050000ool0oooPUP3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ
00<0cHDo0?ooh03oon002@3oon050000o`@0oooP0P00003o0?ooh8/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@0h0?oThA40cHDo1@000?l2000002H0cHDoo`3oon1T0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>40
0`3=QCl0onCQ0?oTh@0A0?oTh@8000001@000?lR0?oTh@030<f5?`3oon00oooP0?l0oooPHP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>404P3oi>42000000@0onCQ10000?lN0?oT
h@030<f5?`3oon00oooP0?l0oooPHP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3o
i>40703oi>450000oaT0onCQ00<0cHDo0?ooh03oon00o`3oon1R0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
>03oi>400`3=QCl0onCQ0?oTh@0Q0?oTh@@0003o5@3oi>400`3=QCl0oooP0?ooh03o0?ooh680oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ02D0onCQ10000?lA0?oTh@030<f5?`3o
on00oooP0?l0oooPHP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03
000000T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0Y0?oTh@<0003o3P3oi>40
0`3=QCl0oooP0?ooh03o0?ooh600oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40;03oi>440000
o`X0onCQ00<0cHDo0?ooh03oon00o`3oon1R0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0
onCQ0?oTh@0`0?oTh@<0003o1`3oi>400`3=QCl0oooP0?ooh03o0?ooh680oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03<0onCQ10000?l30?oTh@030<f5?`3oon00oooP0?l0oooP
HP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40=`3oi>430000o`030<f5?`3o
on00oooP0?l0oooPHP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>43
0000ool0oooPHP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=
QCl0oooP0?ooh0020000ool0oooPH03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3o
i>40>P3oi>400`3=QCl0oooP0?ooh0020?ooh0<0003oo`3oon1M0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
>03oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oon00oooP00D0oooP0`000?oo0?ooh5X0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?ooh03oon00203o
on020000ool0oooPF03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>40
0`3=QCl0oooP0?ooh00:0?ooh0<0003oo`3oon1E0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=
QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oon00oooP00d0oooP0`000?oo0?ooh580oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?ooh03oon00403oon030000o`80
oooP0P00003o0?ooh4/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ
00<0cHDo0?ooh03oon004`3oon020000o`<00000o`3oon1:0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3o
i>40onCQ03X0onCQ5`3=QCl010000000003o0000o`000?l50<f5?ol0oooP@`3oon03000001P0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03o
i>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01D0onCQ0P0000001P3oi>40003o0000
o`000?l0onCQ0<f5?ol0oooPA@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40
>P3oi>400`3=QCl0onCQ0?oTh@0K0?oTh@80003oo`3oon150?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03o
i>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01`0onCQ00@0cHDo0000o`000?l0003o
o`3oon120?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3o
i>40onCQ01`0onCQ00@0cHDo0?ooh03oon00oooP0`000?oo0?ooh3l0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40703oi>400`3=QCl0oooP0?oo
h0040?ooh080003oo`3oon0m0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j
0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?ooh03oon001P3oon020000ool0oooP>`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0L0?oT
h@030<f5?`3oon00oooP00P0oooP0P000?oo0?ooh3T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0h0?oTh@03
0<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40703oi>400`3=QCl0oooP0?ooh00:0?ooh080
003oo`3oon0g0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5
?`3oi>40onCQ01`0onCQ00<0cHDo0?ooh03oon00303oon030000ool0oooP=03oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3o
on00oooP00l0oooP0P000?oo0?ooh380oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40
onCQ03X0onCQ00<0cHDo0?oTh@3oi>40703oi>400`3=QCl0oooP0?ooh00A0?ooh080003oo`3oon0`
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ
01`0onCQ00<0cHDo0?ooh03oon004`3oon020000ool0oooP;P3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0
onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oon00oooP01D0
oooP0`000?oo0?ooh2/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ
00<0cHDo0?oTh@3oi>40703oi>400`3=QCl0oooP0?ooh00H0?ooh080003oo`3oon0Y0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oT
h@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40703oi>400`3=QCl0oooP0?oo
h00J0?ooh080003oo`3oon0U0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo
0?oTh@3oi>40703oi>400`3=QCl0oooP0?ooh00L0?ooh080003oo`3oon0U0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oo
h03oon007P3oon020000ool0oooP8`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3o
i>40>P3oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oon00oooP0200oooP0P000?oo0?ooh240
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40
703oi>400`3=QCl0oooP0?ooh00R0?ooh080003o0P00003o0?ooh1d0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40703oi>4V0<f5?`0400000000
0?l0003o000002/0cHDol03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3o
i>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ02<0onCQ0`0000020000obT0onCQ00<0
cHDo0?ooh03oon00kP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>40
0`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ02@0onCQ0P0000020?oTh@80003o9`3oi>40
0`3=QCl0oooP0?ooh03^0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j0?oT
h@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oTh@3oi>40:P3oi>420000obD0onCQ00<0cHDo0?oo
h03oon00kP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0
onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ02`0onCQ0P000?lS0?oTh@030<f5?`3oon00oooP0>h0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40
703oi>400`3=QCl0onCQ0?oTh@0^0?oTh@80003o8@3oi>400`3=QCl0oooP0?ooh03^0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0
cHDo0?oTh@3oi>40<03oi>400`000?l0onCQ0?oTh@0N0?oTh@030<f5?`3oon00oooP0>h0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40703oi>40
0`3=QCl0onCQ0?oTh@0a0?oTh@80003o7P3oi>400`3=QCl0oooP0?ooh03^0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oT
h@3oi>40<`3oi>420000oa`0onCQ00<0cHDo0?ooh03oon00kP3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0
onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oTh@3oi>40=@3oi>400`000?l0
onCQ0?oTh@0I0?oTh@030<f5?`3oon00oooP0>`0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40
>P3oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ03H0onCQ0P000?lI0?oTh@030<f5
?`3oon00oooP0>h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0
cHDo0?oTh@3oi>40703oi>400`3=QCl0onCQ0?oTh@0h0?oTh@80003o5`3oi>400`3=QCl0oooP0?oo
h03^0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40
onCQ01`0onCQ00<0cHDo0?oTh@3oi>40>P3oi>420000oaD0onCQ00<0cHDo0?ooh03oon00kP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0L0?oT
h@030<f5?`3oi>40onCQ03`0onCQ00<0003o0?oTh@3oi>404P3oi>400`3=QCl0oooP0?ooh03^0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01`0
onCQ00<0cHDo0?oTh@3oi>40?@3oi>420000oa80onCQ00<0cHDo0?ooh03oon00kP3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5
?`3oi>40onCQ03l0onCQ0P000?l@0?oTh@030<f5?`3oon00oooP0>h0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@0h0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40703oi>400`3=QCl0onCQ0?oT
h@110?oTh@80003o3P3oi>400`3=QCl0oooP0?ooh03^0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>40
0`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oTh@3oi>40@`3oi>40
0`000?l0onCQ0?oTh@0;0?oTh@030<f5?`3oon00oooP0>h0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0h0?oT
h@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40703oi>400`3=QCl0onCQ0?oTh@140?oT
h@80003o2`3oi>400`3=QCl0oooP0?ooh03^0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40>03oi>400`3=QCl0
onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oTh@3oi>40AP3oi>420000o`T0
onCQ00<0cHDo0?ooh03oon00kP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40
>P3oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ04P0onCQ00<0003o0?oTh@3oi>40
1P3oi>400`3=QCl0oooP0?ooh03^0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ03P0onCQ00<0
cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ04T0onCQ0P00
0?l60?oTh@030<f5?`3oon00oooP0>h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ03P0onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3o
i>40onCQ04/0onCQ0P000?l40?oTh@030<f5?`3oon00oooP0>h0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon04000000P0oooPi`00
00020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00
oooP000000L0oooP00<000000?ooh03oon00lP3oon000`000?l0oooP03>QbP02000001X0[MSV00<0
<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0
<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00l`3o
on020000o`<000006@2]f>H00`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0
<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00
oooP0?@0oooP00@000000000o`00000000006P0cXLX/0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0
<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00m@3oon00
0`000000003o0000o`0I0?ooh00303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H0
0`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03h0?oo
h0030000o`3oon00oooP01H0oooP00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0[MSV0:gHiP0U0:gH
iP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?T0
oooP0P000?lF0?ooh00303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0
[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03k0?ooh0030000
o`3oon00oooP01<0oooP00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>Q
bP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?`0oooP00<0
003o0?ooh03oon004P3oon000`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0
<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o@3oon02
0000oa80oooP00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0
[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP00<0003o0?oo
h03oon003`3oon000`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gH
iP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon010?ooh080
003o3`3oon000`0cXLX0[MSV0:gHiP0Z0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]
f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon030?ooh0030000
o`3oon00oooP00`0oooP00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>Q
bP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP103o
on020000o``0oooP00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]
f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP1P3oon00
0`000?l0oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H0
0`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP1`3oon020000
o`T0oooP00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV
03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon090?ooh0030000o`3oon00oooP00H0
oooP00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0
[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2P3oon020000o`H0oooP
00<0<j7:0:gHiP2]f>H0:P2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV
00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP303oon000`000?l0oooP0?oo
h0030?ooh00303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gH
iP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0d0oooP0P000?l3
0?ooh00303>QbP2]f>H0[MSV02X0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0k
0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0l0oooP00@0003o0?oo
h03oon00<j7:;02]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:
0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403oon020000o`0303>QbP2]f>H0[MSV
02X0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV
0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh180oooP00<0003o0:gHiP2]f>H0:P2]f>H00`0cXLX0
[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP4P3oon000`0cXLX0003o0000o`0Z0:gHiP0303>QbP2]f>H0[MSV02D0[MSV
00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0B0?ooh00403>QbP2]f>H0[MSV0000obT0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV
0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh180oooP00@0
<j7:0:gHiP2]f>H0[MSV0P000?lW0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H0
>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0B0?ooh00303>QbP2]
f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]
f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4P3oon00
0`0cXLX0[MSV0:gHiP040:gHiP80003o902]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0
[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4P3oon000`0c
XLX0[MSV0:gHiP060:gHiP030000o`2]f>H0[MSV0240[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0c
XLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP4P3oon000`0cXLX0
[MSV0:gHiP070:gHiP80003o8@2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0
[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0B0?ooh00303>QbP2]f>H0[MSV00T0[MSV
00<0003o0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV
00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4P3oon000`0cXLX0[MSV0:gH
iP0:0:gHiP030000o`2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gH
iP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh180oooP00<0<j7:
0:gHiP2]f>H02`2]f>H20000o`8000006`2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0
[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4P3oon0?03>Q
bP04000000000?l00000000001/0<j7:9`2]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0
[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh240oooP0P0000000`000?l000000?ooh00I0?oo
h00303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0R0?ooh08000000P000?lI0?ooh00303>QbP2]f>H0[MSV02D0
[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0V0?ooh0030000o`3oon00oooP01H0oooP00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV
0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2L0oooP00<0
003o0?ooh03oon005@3oon000`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0
<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:03oon020000oaD0oooP00<0<j7:
0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh2X0oooP00<0003o0?ooh03oon004P3oon000`0cXLX0[MSV0:gHiP0U0:gH
iP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP:`3oon000`000?l0oooP0?ooh00A0?ooh00303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]
f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0/0?ooh080003o
4@3oon000`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0
<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP;P3oon000`000?l0oooP0?ooh00>0?ooh00303>QbP2]
f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o
0?ooh2l0oooP00<0003o0?ooh03oon003@3oon000`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0
[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0`0?ooh080003o3@3oon000`0c
XLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP<P3oon000`000?l0oooP0?ooh00:0?ooh00303>QbP2]f>H0[MSV02D0
[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0c0?ooh0030000o`3oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV
0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3@0oooP00<0
003o0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0
<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP=@3oon020000o`P0oooP00<0<j7:
0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh3L0oooP00<0003o0?ooh03oon001@3oon000`0cXLX0[MSV0:gHiP0U0:gH
iP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP>03oon000`000?l0oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]
f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0i0?ooh080003o
103oon000`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0
<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP>`3oon001@000?l0oooP0?ooh03oon00<j7:02L0[MSV
00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0l0?ooh0040000o`3oon00oooP03>QbRL0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV
0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0m0?ooh0030000o`3oon00<j7:02L0[MSV00<0
<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0n
0?ooh080003o9`2]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh3l0oooP00<0<j7:0000o`2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0k0:gH
iP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3l0oooP00<0<j7:0:gHiP00
0?l09@2]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP
?`3oon00100cXLX0[MSV0:gHiP000?lT0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]
f>H0<P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0o0?ooh00503>QbP2]f>H0[MSV0:gHiP000?l08`2]f>H00`0cXLX0
[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3l0oooP
00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV03/0[MSV
00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?`3oon000`0cXLX0[MSV0:gH
iP030:gHiP80003o802]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh3l0oooP00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP0M
0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP?`3oon000`0cXLX0[MSV0:gHiP060:gHiP030000o`2]f>H0[MSV01`0[MSV00<0<j7:0:gH
iP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0o0?ooh003
03>QbP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP03
03>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3l0oooP00<0<j7:0:gHiP2]f>H0
202]f>H00`000?l0[MSV0:gHiP0J0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0
<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP?`3oon000`0cXLX0[MSV0:gHiP090:gHiP030000o`2]
f>H0[MSV01T0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0o0?ooh00303>QbP2]f>H0[MSV00X0[MSV00<0003o0:gHiP2]f>H0602]f>H0
0`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h3l0oooP00<0<j7:0:gHiP2]f>H02`2]f>H00`000?l0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV
03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?`3oon000`0cXLX0
[MSV0:gHiP0<0:gHiP030000o`2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0
[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0oooP?`3oon000`0cXLX0[MSV
0:gHiP0=0:gHiP80003o5P2]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3o
on000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooP?`3oon000`0cXLX0[MSV0:gH
iP0?0:gHiP030000o`2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gH
iP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ80oooP00<000000?ooh03oon001P3oon0400000?l0oooP?P3oon000`0cXLX0[MSV0:gHiP0@
0:gHiP030000o`2]f>H0[MSV0180[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b
0:gHiP0303>QbP3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`00
0000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooP?`3oon000`0cXLX0[MSV0:gHiP0A0:gH
iP030000o`2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80
oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh3l0oooP00<0<j7:0:gHiP2]
f>H04P2]f>H00`000?l0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]
f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh3l0oooP00<0<j7:0:gHiP2]f>H0
4`2]f>H00`000?l0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0
<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP?`3oon000`0cXLX0[MSV0:gHiP0D0:gHiP030000o`2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0o0?ooh00303>QbP2]f>H0[MSV01D0[MSV00<0003o0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h3l0oooP00<0<j7:0:gHiP2]f>H05P2]f>H010000?l0[MSV00000000000;0:gHiP0303>QbP2]f>H0
[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?`3oon000`0c
XLX0[MSV0:gHiP0G0:gHiP80003o0P00000:0:gHiP0303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gH
iP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?`3oon0J03>QbP80000000<0003o0000000c
XLX02P0cXLXm0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5X0oooP
0P0000000`000?l0oooP0?ooh0080?ooh00303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0
<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPG@3oon000`000?l0oooP0?ooh0070?ooh00303>QbP2]
f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPGP3oon00
0`000?l0oooP0?ooh0060?ooh00303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPG`3oon000`000?l0oooP0?ooh0050?ooh00303>QbP2]f>H0[MSV
03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH03oon000`000?l0
oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000
o`3oon1Q0?ooh0030000o`3oon00oooP00<0oooP00<0<j7:0:gHiP2]f>H0>`2]f>H00`0cXLX0[MSV
0:gHiP0b0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh680oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gH
iP0k0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6<0oooP0P000?l2
0?ooh00303>QbP2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPI@3oon000`000?l0oooP03>QbP0m0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh6H0oooP00<0003o03>QbP2]f>H0?02]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1W0?ooh0030000o`2]f>H0[MSV03/0[MSV00<0<j7:0:gHiP2]f>H0
<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPI`3oon000`0cXLX0003o0:gHiP0k0:gHiP0303>QbP2]
f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6L0oooP00<0<j7:0:gHiP000?l0>`2]f>H0
0`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh00403>QbP2]f>H0[MSV
0000ocX0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI`3oon001@0c
XLX0[MSV0:gHiP2]f>H0003o03T0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPI`3oon000`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV03H0[MSV00<0<j7:0:gH
iP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI`3oon000`0cXLX0[MSV0:gHiP030:gHiP03
0000o`2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
I`3oon000`0cXLX0[MSV0:gHiP040:gHiP030000o`2]f>H0[MSV03@0[MSV00<0<j7:0:gHiP2]f>H0
<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPI`3oon000`0cXLX0[MSV0:gHiP050:gHiP030000o`2]
f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI`3oon00
0`0cXLX0[MSV0:gHiP060:gHiP030000o`2]f>H0[MSV0380[MSV00<0<j7:0:gHiP2]f>H0<P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0<00000o`3oon1W0?ooh00303>QbP2]f>H0[MSV00L0[MSV0P000?l200000300[MSV00<0<j7:0:gH
iP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1W0?ooh00303>QbP2]f>H0[MSV00P0[MSV00@000000000o`00
00000000;`2]f>H00`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh0/0
<j7:0P0000000`000?l0000003>QbP0_03>QbS@0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7<0oooP
0P0000000`000?l0oooP0?ooh00]0?ooh00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh7H0oooP00<0003o0?ooh03oon00;03oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1g0?ooh0030000o`3oon00oooP02/0oooP00<0<j7:0:gHiP2]f>H0<P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPN03oon000`000?l0oooP0?ooh00Z0?ooh00303>QbP2]f>H0[MSV
0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh7T0oooP00<0003o0?ooh03oon00:@3oon000`0cXLX0
[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1j0?ooh0030000o`3oon00oooP02P0oooP
00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPN`3oon000`000?l0oooP0?oo
h00W0?ooh00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP00<0003o
0?ooh03oon009P3oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1m0?oo
h0030000o`3oon00oooP02D0oooP00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPOP3oon000`000?l0oooP0?ooh00T0?ooh00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh7l0oooP00<0003o0?ooh03oon008`3oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
003o0?ooh800oooP00<0003o0?ooh03oon008P3oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3o
on00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh840oooP00<0003o0?ooh03oon008@3oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon220?ooh0030000o`3oon00oooP0200oooP00<0<j7:0:gHiP2]f>H0<P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPP`3oon000`000?l0oooP0?ooh00O0?ooh00303>QbP2]f>H0[MSV0380
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh8@0oooP00<0003o0?ooh03oon007P3oon000`0cXLX0[MSV
0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon250?ooh0030000o`3oon00oooP01d0oooP00<0
<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQP3oon000`000?l0oooP0?ooh00L
0?ooh00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8L0oooP00<0003o0?oo
h03oon006`3oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon280?ooh003
0000o`3oon00oooP01X0oooP00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
R@3oon000`000?l0oooP0?ooh00I0?ooh00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh8X0oooP00<0003o0?ooh03oon00603oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2;0?ooh0030000o`3oon00oooP01L0oooP00<0<j7:0:gHiP2]f>H0<P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPS03oon000`000?l0oooP0?ooh00F0?ooh00303>QbP2]f>H0[MSV
0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh8d0oooP00<0003o0?ooh03oon005@3oon000`0cXLX0
[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP0`00003o0?ooh8h0oooP00<0003o0?ooh03oon00503oon000`0cXLX0[MSV
0:gHiP0b0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8l0oooP00<0003o0?ooh03oon004`3oon000`0cXLX0[MSV0:gH
iP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2@0?ooh0030000o`3oon00oooP0180oooP00<0<j7:
0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT@3oon000`000?l0oooP0?ooh00A0?oo
h00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh980oooP00<0003o0?ooh03o
on00403oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2B0?ooh0030000
o`3oon00oooP0100oooP00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT`3o
on000`000?l0oooP0?ooh00?0?ooh00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh9@0oooP00<0003o0?ooh03oon003P3oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2E0?ooh0030000o`3oon00oooP00d0oooP00<0<j7:0:gHiP2]f>H0<P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPUP3oon000`000?l0oooP0?ooh00<0?ooh00303>QbP2]f>H0[MSV0380
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh9L0oooP00<0003o0?ooh03oon002`3oon000`0cXLX0[MSV
0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2H0?ooh0030000o`3oon00oooP00X0oooP00<0
<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPV@3oon000`000?l0oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V403oon04000000L0oooP00<000000?ooh03oon00o`3oon2J0?oo
h0030000o`3oon00oooP00P0oooP00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0030000003oon00oooP00P0
oooP00<000000?ooh03oon00o`3oon2K0?ooh0030000o`3oon00oooP00L0oooP00<0<j7:0:gHiP2]
f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HA0?ooh0030000003oon00oooP00L0oooP1000003o0?ooh9X0oooP00<0003o0?ooh03oon00
1`3oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00H0oooP1000000H0?ooh1h0n_3V
0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPW03o
on000`000?l0oooP0?ooh0060?ooh00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP0?l0oooPW@3oon000`000?l0oooP0?ooh0050?ooh00303>QbP2]
f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon2N0?ooh0030000o`3oon00
oooP00@0oooP00<0<j7:0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW`3oon000`00
0?l0oooP0?ooh0030?ooh00303>QbP2]f>H0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:00
oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gHiP0b0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2Q0?ooh0050000o`3oon00oooP0?ooh00cXLX0=02]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
XP3oon0010000?l0oooP0?ooh00cXLXd0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2S0?ooh0030000
o`3oon00<j7:03@0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:@0oooP00<0003o03>QbP2]f>H0<`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPY@3oon000`000?l0[MSV0:gHiP0b0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2U0?ooh00303>QbP000?l0[MSV0380[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0
oooP00<0<j7:0:gHiP000?l0<P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon00100cXLX0[MSV
0:gHiP000?la0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP0`00003o0?ooh:D0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0`0:gHiP03
03>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh:D0oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP0]0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2U0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o0:gHiP2]f>H0;@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPY@3oon000`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0
[MSV02`0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`00
0?l0[MSV0:gHiP0[0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2U0?ooh00303>QbP2]f>H0[MSV00D0
[MSV00<0003o0:gHiP2]f>H0:P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon000`0cXLX0[MSV
0:gHiP060:gHiP030000o`2]f>H0[MSV02T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00<0
<j7:0:gHiP2]f>H01`2]f>H00`000?l0[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2U
0?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H09`2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPY@3oon000`0cXLX0[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV02H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh:D0oooP00<0<j7:0:gHiP2]f>H02P2]f>H00`000?l0[MSV0:gHiP0U0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2U0?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gHiP2]f>H0
902]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon000`0cXLX0[MSV0:gHiP0<0:gHiP030000o`2]
f>H0[MSV02<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00<0<j7:0:gHiP2]f>H03@2]f>H0
0`000?l0[MSV0:gHiP0R0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh:D0oooP00<0<j7:0:gHiP2]f>H03P2]f>H00`00
0?l0[MSV0:gHiP0Q0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00<0<j7:0:gHiP2]f>H03`2]f>H00`000?l0
[MSV0:gHiP0P0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2U0?ooh00303>QbP2]f>H0[MSV00l0[MSV
00<0003o0:gHiP2]f>H0802]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon000`0cXLX0[MSV0:gH
iP0@0:gHiP030000o`2]f>H0[MSV01l0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00<0<j7:
0:gHiP2]f>H04@2]f>H00`000?l0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2U0?oo
h00303>QbP2]f>H0[MSV0180[MSV00<0003o0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPY@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP030000o`2]f>H0[MSV01`0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh:D0oooP00<0<j7:0:gHiP2]f>H0502]f>H00`000?l0[MSV0:gHiP0K0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2U0?ooh00303>QbP2]f>H0[MSV01@0[MSV00<0003o0:gHiP2]f>H06`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPY@3oon000`0cXLX0[MSV0:gHiP0E0:gHiP030000o`2]f>H0
[MSV01X0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00<0<j7:0:gHiP2]f>H05P2]f>H00`00
0?l0[MSV0:gHiP0I0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2U0?ooh00303>QbP2]f>H0[MSV01L0
[MSV00<0003o0:gHiP2]f>H0602]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon000`0cXLX0[MSV
0:gHiP0H0:gHiP030000o`2]f>H0[MSV01L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00<0
<j7:0:gHiP2]f>H06@2]f>H00`000?l0[MSV0:gHiP0F0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2U
0?ooh00303>QbP2]f>H0[MSV01T0[MSV00<0003o0:gHiP2]f>H05P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2U0?oo
h00303>QbP2]f>H0[MSV01X0[MSV00<0003o0:gHiP2]f>H05@2]f>H00`0cXLX0oooP0?ooh0070?oo
h0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2U0?ooh003
03>QbP2]f>H0[MSV01/0[MSV00<0003o0:gHiP2]f>H0502]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
Y@3oon000`0cXLX0[MSV0:gHiP0L0:gHiP030000o`2]f>H0[MSV01<0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh:D0oooP00<0<j7:0:gHiP2]f>H07@2]f>H00`000?l000000000000B0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2U0?ooh00303>QbP2]f>H0[MSV01d0[MSV00@000000000o`00000000004@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPY@3oon0P03>QbP04000000000?l0000000000180<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<H0oooP00<000000000o`3oon007@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<P0oooP00<0003o0?ooh03oon006`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<T0
oooP00<0003o0?ooh03oon006P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh<X0oooP00<0003o0?ooh03oon006@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh</0oooP00<0
003o0?ooh03oon00603oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh</0oooP00<0003o0?ooh03oon00603oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<`0oooP00<0003o0?oo
h03oon005`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh<d0oooP00<0003o0?ooh03oon005P3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPcP3oon000`000?l0oooP0?ooh00C0?ooh0<00000
603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3?0?ooh0030000o`3o
on00oooP01@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon3@0?ooh0030000o`3oon00oooP01<0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3A0?ooh0030000o`3oon00oooP
0180oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon3A0?ooh0030000o`3oon00oooP0180oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3B0?ooh0030000o`3oon00oooP0140oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on3C0?ooh0030000o`3oon00oooP0100oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3D0?ooh0030000o`3oon00oooP00l0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3E0?oo
h0030000o`3oon00oooP00h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon3F0?ooh0030000o`3oon00oooP00d0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3G0?ooh0030000
o`3oon00oooP00`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon3G0?ooh0030000o`3oon00oooP00`0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPf03oon00
0`000?l0oooP0?ooh00;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?oo
h0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3I0?ooh0030000o`3oon00
oooP00X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?oo
h03oon001P3oon0400000?l0oooPf@3oon000`000?l0oooP0?ooh0060?ooh0@00000603oon0N0?[`
iP40oooo000M0?[`iQ<0oooP00<000000?ooh03oon001@3oon000`000000oooP0?ooh03o0?ooh>H0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon00
00001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon00
0`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H400000080n_3V200000020?[`iP@00000
00L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V00000000000010000000103j
l>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V00<000002@3jl>H5
00000080n_3V100000020?[`iPD000004P3jl>H6000000H0n_3V00<000000?[`iP3jl>H0103jl>H3
000000040?[`iP000000000000000>@0n_3V0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2
000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP0400000080n_3V
0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000T0n_3V
00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3j
l>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`
iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000i@3jl>H10?oo
o`00g@3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H200000003
0?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003jl>H20000
00030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00`0n_3V1@0000050?[`iP8000001P3jl>H5000000H0n_3V0`00003V0?[`iP40oooo003M0?[`iPD0
0000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V
0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`
iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`iP800000203j
l>H00`000000n_3V0?[`iP060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H200000080n_3V0P000003
0?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H000000?[`iP800000
103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
2P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V0080
00002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0180
n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003U0?[`iP40
oooo003M0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4000000030?[`
iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V
0`0000000`3jl>H0000000000007000000/0n_3V1@0000020?[`iP@000000P3jl>H3000000030?[`
iP000000000001<0n_3V0P00000?0?[`iP<0000000D0n_3V00000000000000000?[`iP0400000=l0
n_3V0@3oool00=d0n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H0
603jl>H200000240n_3V1000000H0?[`iP030000003jl>H0n_3V0=l0n_3V0@3oool00=`0n_3V1P00
00040?[`iP800000;`3jl>H5000001/0n_3V0`00000Q0?[`iP8000006@3jl>H00`000000n_3V0?[`
iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<000000?[`iP3jl>H0g@3jl>H10?ooo`00o`3jl>Ie0?[`
iP040000003jl>H0n_3V00000=l0n_3V0@3oool00?l0n_3VMP3jl>H200000>00n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01494 L
.06903 .01494 L
.06903 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01494 L
.06903 .01494 L
.06903 .16187 L
s
1 .894 .882 r
.06903 .16187 m
.06903 .02085 L
.14192 .02085 L
.14192 .16187 L
F
.804 .522 .247 r
.06903 .16187 m
.06903 .02085 L
.14192 .02085 L
.14192 .16187 L
s
1 .894 .882 r
.14192 .16187 m
.14192 .04698 L
.26643 .04698 L
.26643 .16187 L
F
.804 .522 .247 r
.14192 .16187 m
.14192 .04698 L
.26643 .04698 L
.26643 .16187 L
s
1 .894 .882 r
.26643 .16187 m
.26643 .05365 L
.31879 .05365 L
.31879 .16187 L
F
.804 .522 .247 r
.26643 .16187 m
.26643 .05365 L
.31879 .05365 L
.31879 .16187 L
s
1 .894 .882 r
.31879 .16187 m
.31879 .07338 L
.43151 .07338 L
.43151 .16187 L
F
.804 .522 .247 r
.31879 .16187 m
.31879 .07338 L
.43151 .07338 L
.43151 .16187 L
s
1 .894 .882 r
.43151 .16187 m
.43151 .15595 L
.49578 .15595 L
.49578 .16187 L
F
.804 .522 .247 r
.43151 .16187 m
.43151 .15595 L
.49578 .15595 L
.49578 .16187 L
s
.678 .847 .902 r
.49578 .16187 m
.49578 .17626 L
.56779 .17626 L
.56779 .16187 L
F
.2 .63 .79 r
.49578 .16187 m
.49578 .17626 L
.56779 .17626 L
.56779 .16187 L
s
.678 .847 .902 r
.56779 .16187 m
.56779 .2083 L
.66447 .2083 L
.66447 .16187 L
F
.2 .63 .79 r
.56779 .16187 m
.56779 .2083 L
.66447 .2083 L
.66447 .16187 L
s
.678 .847 .902 r
.66447 .16187 m
.66447 .34413 L
.76904 .34413 L
.76904 .16187 L
F
.2 .63 .79 r
.66447 .16187 m
.66447 .34413 L
.76904 .34413 L
.76904 .16187 L
s
.678 .847 .902 r
.76904 .16187 m
.76904 .39075 L
.84001 .39075 L
.84001 .16187 L
F
.2 .63 .79 r
.76904 .16187 m
.76904 .39075 L
.84001 .39075 L
.84001 .16187 L
s
.678 .847 .902 r
.84001 .16187 m
.84001 .45988 L
.90911 .45988 L
.90911 .16187 L
F
.2 .63 .79 r
.84001 .16187 m
.84001 .45988 L
.90911 .45988 L
.90911 .16187 L
s
.678 .847 .902 r
.90911 .16187 m
.90911 .55399 L
.97619 .55399 L
.97619 .16187 L
F
.2 .63 .79 r
.90911 .16187 m
.90911 .55399 L
.97619 .55399 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.04235 .01494 Mdot
.12106 .02085 Mdot
.24679 .04698 Mdot
.26876 .05365 Mdot
.32447 .07338 Mdot
.49033 .15595 Mdot
.52274 .17626 Mdot
.56999 .2083 Mdot
.73629 .34413 Mdot
.78503 .39075 Mdot
.85206 .45988 Mdot
.93541 .55399 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.261467) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.57768) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000050?[`iP8000001@3jl>H2000000@0n_3V0`0000040?[`iP<0
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP030000003j
l>H0n_3V00800000103jl>H2000000D0n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP00000000000?l0n_3VX`3jl>H10?ooo`00803jl>H2000000030?[`iP000000
000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V00800000603j
l>H2000000030?[`iP000000000000`0n_3V0P0000040?[`iP8000001@3jl>H2000000<0n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000o`3jl>JS0?[`iP40oooo000P
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V000000000000303jl>H2000000@0
n_3V0P0000050?[`iP8000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
00000000003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V
0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`
iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P000000
0`3jl>H00000000000090?[`iP030000003jl>H0n_3V008000001@3jl>H2000000D0n_3V0P000002
0?[`iP@00000103jl>H300000?l0n_3VY03jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3j
l>H0000000000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`
iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`
iP80000000<0n_3V0000000000002@3jl>H4000000H0n_3V0P0000050?[`iP8000000P3jl>H20000
00D0n_3V0P0000000`3jl>H000000000003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000T0
n_3V0P0000050?[`iP030000003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`iP02000000<0
n_3V0P0000040?[`iP80000000<0n_3V000000000000o`3jl>JS0?[`iP40oooo000O0?[`iPH00000
103jl>H2000002l0n_3V1@00000X0?[`iP<000002P3jl>H500000080n_3V1@0000020?[`iPD00000
103jl>H3000000<0n_3V0`00003o0?[`iZ@0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40
oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200n_3V1P0000001@3jl>H000000000
00000000n_3V00<000000P3jl>H3000000<0n_3V100000030?[`iP80000000@0n_3V000000000000
n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P0000050?[`iP<00000103jl>H3000000@0
n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V00@000000?[`iP000000
00000`3jl>H01@000000n_3V000000000000n_3V00<000000P3jl>H2000000@0n_3V0P0000020?[`
iP8000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000000000000`3jl>H20000
00@0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
00000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H0
0000000000020?[`iP800000103jl>H2000000D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0
n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0
n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V000000000000
0P3jl>H2000000@0n_3V1P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000D0n_3V
1@0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000090?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V
0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3j
l>H2000000@0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0`0000020?[`iP<00000
00<0n_3V0000003jl>H0103jl>H2000000<0n_3V0P00000`0?[`iP80000000<0n_3V000000000000
2@3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000<0n_3V100000060?[`iP800000
o`3jl>JM0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080n_3V1@0000030?[`iP@000000`3j
l>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H4000000@0n_3V0P00
000`0?[`iP80000000<0n_3V0000000000002@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3j
l>H2000000D0n_3V0P0000080?[`iP800000o`3jl>JM0?[`iP40oooo000R0?[`iP8000002`3jl>H2
00000280n_3V0P00000`0?[`iP80000000<0n_3V0000000000002P3jl>H2000000D0n_3V0P000005
0?[`iP8000001@3jl>H2000000D0n_3V0P0000040?[`iP030000003jl>H0n_3V00800000o`3jl>JM
0?[`iP40oooo000P0?[`iPH000002@3jl>H200000200n_3V1000000a0?[`iP<00000303jl>H30000
00@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000020?[`iPD00000o`3jl>JM0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP0000000000
0?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP040000003jl>H000000?[`iP8000000P3jl>H00`00
0000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0000000<0n_3V00000000
00000P0000001@3jl>H000000?[`iP000000n_3V00<000000P3jl>H00`000000n_3V0000000H0?[`
iPD00000f`3jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`
iPH000000P3jl>H400000080n_3V0`000000103jl>H000000000000000080?[`iP@0000000<0n_3V
0000000000000P3jl>H400000080n_3V1@0000001`3jl>H00000000000000000n_3V0000003jl>H0
0`00000H0?[`iP<00000103jl>H2000000@0n_3V1@0000030?[`iP<000000`3jl>H600000080n_3V
100000030?[`iP<000001@3jl>H2000007T0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000
0005000000040?[`iP000000000000000080n_3V0P0000000`3jl>H00000000000090?[`iPD00000
2@3jl>H200000=l0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP800000
0P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3j
l>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000000`3jl>H20000
00@0n_3V0P0000050?[`iP80000000<0n_3V000000000000103jl>H2000000D0n_3V0P0000030?[`
iP80000000<0n_3V000000000000103jl>H2000007T0n_3V0@3oool00280n_3V0`00000Y0?[`iP80
0000gP3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H0
00000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP0000000000
00X0n_3V0P0000040?[`iP80000000<0n_3V000000000000103jl>H200000080n_3V1P0000020?[`
iP80000000<0n_3V000000000000103jl>H2000007T0n_3V0@3oool00280n_3V0`00000J0?[`iPD0
00002`3jl>H200000=d0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H0
00000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3j
l>H000000000000;0?[`iP8000000`3jl>H2000000030?[`iP000000000000@0n_3V0P0000020?[`
iP030000003jl>H0n_3V008000000`3jl>H2000000030?[`iP000000000000@0n_3V0P00001i0?[`
iP40oooo000Q0?[`iP80000000<0n_3V000000000000:P3jl>H200000=`0n_3V0P0000000`3jl>H0
0000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H20000
00@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000
000000002P3jl>H3000000040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V0`000000
0`3jl>H000000?[`iP02000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000
000000`0n_3V0P0000020?[`iP@000001@3jl>H2000000<0n_3V00@000000?[`iP00000000000`3j
l>H4000000H0n_3V0P00001h0?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3j
l>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3j
l>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000
103jl>H400000080n_3V1@00000;0?[`iP<0000000<0n_3V0000000000000P3jl>H400000080n_3V
0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`iP800000
00<0n_3V0000000000000P3jl>H2000000L0n_3V0P0000030?[`iP040000003jl>H00000000000<0
n_3V0P0000080?[`iP800000N03jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V
0P0000000`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`iP800000
;P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000030?[`iP800000
103jl>H4000000@0n_3V0`0000040?[`iP800000103jl>H00`000000n_3V0?[`iP02000007P0n_3V
0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3j
l>H2000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000;0?[`iP<000001@3j
l>H3000000@0n_3V0P0000050?[`iP8000001@3jl>H300000080n_3V1@00001h0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V
0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo
000W0?[`iP050000003jl>H000000?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP03
0000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V000000000000
0P000000103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`
iP3jl>H05`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`
iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V0000000000001P00000J0?[`
iPH0000000<0n_3V0000000000000`0000300?[`iP40oooo000Q0?[`iP80000000<0n_3V00000000
00001@0000001@3jl>H00000000000000000n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3j
l>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H20000
0080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP800000
0P3jl>H2000000/0n_3V1@00000;0?[`iP8000000`3jl>H200000<<0n_3V0@3oool00280n_3V0`00
000X0?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3j
l>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3j
l>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP@000006`3jl>H2000000@0n_3V0P00
00320?[`iP40oooo000R0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2
000000030?[`iP00000000000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P000006
0?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H4000000d0n_3V1@00000;0?[`iP8000001@3jl>H200000<40n_3V0@3o
ool00240n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0n_3V000000000000g03jl>H2
000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P00
00060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
0000103jl>H000000000003jl>H200000080n_3V0P00000K0?[`iP8000001P3jl>H200000<00n_3V
0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V000000000000
g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000
n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000<0
n_3V1@00000K0?[`iP8000000`3jl>H2000000030?[`iP00000000000<00n_3V0@3oool004d0n_3V
0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403jl>H2000000`0n_3V
0P00000h0?[`iP@000000`3jl>H2000000030?[`iP00000000000<00n_3V0@3oool004h0n_3V0`00
003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H200000380n_3V0P00
00040?[`iP<00000`@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool001d0n_3V9P3oon02000006`0oooP0P0000040?ooh0800000103oon02000006/0oooP
1@00001Y0?ooh0D000000P3oon02000000@0oooP0P00001[0?ooh0@000008`3oon0N0?[`iP40oooo
000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon0010000000oooP0?ooh00000080?ooh004
0000003oon00oooP000006`0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0070?oo
h0040000003oon00oooP000006X0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`
iRD0oooP00@000000?ooh03oon000000JP3oon0010000000oooP0?ooh000000;0?ooh0030000003o
on00oooP06X0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh00:0?ooh0030000003o
on00oooP06T0oooP00<000000?ooh03oon008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@00000
0?ooh03oon000000JP3oon0010000000oooP0?ooh00000090?ooh0800000K@3oon000`000000oooP
0?ooh01[0?ooh0030000003oon00oooP00P0oooP0P00001]0?ooh0030000003oon00oooP0280oooP
7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon00
00002@3oon000`000000oooP0?ooh01/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03o
on00203oon000`000000oooP0?ooh01Z0?ooh0040000003oon00oooP000002<0oooP7P3jl>H10?oo
o`007@3jl>HV0?ooh0800000K03oon02000000X0oooP0`00001[0?ooh0800000K03oon02000000X0
oooP0`00001[0?ooh0800000903oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h?l00000jP00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3o
on000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03o
on004@3oon0200000?l0oooPd`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0100oooP1000003o0?ooh=80oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3o
on04000000P0oooP6P000?oo0?ooh<00oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V2P3oon04
000000@0oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ00D0onCQ0P00000<0?oTh@040<f5?`3oon00oooP0?ooh0P0003o3@3oon0200000?l0oooP[03o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh006
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0oooP0?ooh009
0?ooh0X0003o0P3oon0400000?l0oooPZ`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oT
hAH0cHDo2@000?l50<f5?ol0oooPX`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3o
i>405P3oi>42000000@0onCQ20000?oo0?ooh:00oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5
?`3oi>40onCQ0200onCQ00@0cHDo0?ooh03oon00oooP1@000?oo0?ooh9/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?ooh03oon001P3oon050000ool0oooP
UP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0oooP0?oo
h00;0?ooh0D0003oo`3oon2A0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P
0?oTh@030<f5?`3oon00oooP0100oooP1@000?oo0?ooh8`0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oT
h@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?ooh03oon005@3oon050000ool0oooPQ`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0oooP0?ooh00J0?ooh0@0
003oo`3oon230?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5
?`3oon00oooP01h0oooP1@000?oo0?ooh7h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3o
i>40onCQ0200onCQ00<0cHDo0?ooh03oon008`3oon040000ool0oooPNP3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0oooP0?ooh00W0?ooh0@0003oo`3oon1f
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=
QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?ooh03oon00:`3oon030000
o`80oooP0P00003o0?ooh6d0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>4a0<f5?`@0
003o00<000000<f5?`3=QCl01P3=QCoo0?ooh6H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5
?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40;`3oi>43000000<0003o1@3oi>400`3=QCl0oooP
0?ooh03o0?ooh6@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0
cHDo0?oTh@3oi>40<03oi>42000000<0onCQ10000?l0103oi>40cHDo00000000003o0?ooh6@0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>@3o
i>430000o`800000o`3oon1S0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P
0?oTh@030<f5?`3oi>40onCQ03X0onCQ0P0000030000oaH0cHDoo`3oon1<0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0000
000000000P3oi>420000oa<0onCQ00<0cHDo0?ooh03oon00o`3oon1:0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3o
i>40103oi>430000oa00onCQ00<0cHDo0?ooh03oon00o`3oon1:0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
4`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40
1`3oi>430000o`d0onCQ00<0cHDo0?ooh03oon00o`3oon1:0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3o
i>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>402P3o
i>420000o`/0onCQ00<0cHDo0?ooh03oon00o`3oon1:0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>40
0`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40303oi>43
0000o`P0onCQ00<0cHDo0?ooh03oon00o`3oon1:0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=
QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>403`3oi>430000
o`D0onCQ00<0cHDo0?ooh03oon00o`3oon1:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0
onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>404P3oi>430000o`80
onCQ00<0cHDo0?ooh03oon00o`3oon1:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ
0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>405@3oi>420000o`040<f5
?`3oon00000000000?l0oooPB@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5
?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>405`3oi>430000o`800000<P3=QCoo0?ooh1@0oooP
0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3o
i>40onCQ01L0onCQ00<0cHDo0000000000000`000?l`0?oTh@030<f5?`3oon00oooP0?l0oooP503o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0j
0?oTh@030<f5?`3oi>40onCQ01L0onCQ00@0cHDo0?oTh@00000000000P3oi>420000obh0onCQ00<0
cHDo0?ooh03oon00o`3oon0D0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P
0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@05
0?oTh@<0003o:`3oi>400`3=QCl0oooP0?ooh03o0?ooh1@0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oT
h@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0G0?oT
h@030<f5?`3oi>40onCQ00P0onCQ0`000?lX0?oTh@030<f5?`3oon00oooP0?l0oooP503oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0j0?oTh@03
0<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>402`3oi>420000obH0onCQ00<0cHDo0?ooh03o
on00o`3oon0D0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5
?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@0=0?oTh@80003o
903oi>400`3=QCl0oooP0?ooh03o0?ooh1@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3o
i>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3o
i>40onCQ00l0onCQ0P000?lR0?oTh@030<f5?`3oon00oooP0?l0oooP503oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40
onCQ01L0onCQ00<0cHDo0?oTh@3oi>404@3oi>420000ob00onCQ00<0cHDo0?ooh03oon00o`3oon0D
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ
03X0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@0C0?oTh@<0003o7@3oi>400`3=
QCl0oooP0?ooh03o0?ooh1@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200
onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ01H0
onCQ0P000?lK0?oTh@030<f5?`3oon00oooP0?l0oooP503oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ
00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01L0onCQ
00<0cHDo0?oTh@3oi>40603oi>420000oaT0onCQ00<0cHDo0?ooh03oon00o`3oon0D0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0
cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@0J0?oTh@80003o5`3oi>400`3=QCl0oooP0?oo
h03o0?ooh1@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo
0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ01`0onCQ0`000?lD
0?oTh@030<f5?`3oon00oooP0?l0oooP503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oT
h@3oi>40803oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oT
h@3oi>407`3oi>420000oa80onCQ00<0cHDo0?ooh03oon00o`3oon0D0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@03
0<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@03
0<f5?`3oi>40onCQ0240onCQ0P000?l@0?oTh@030<f5?`3oon00oooP0?l0oooP4P3oon03000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
4`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>40
5`3oi>400`3=QCl0onCQ0?oTh@0S0?oTh@80003o3P3oi>400`3=QCl0oooP0?ooh03o0?ooh1@0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3o
i>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ02D0onCQ0P000?l<0?oTh@030<f5?`3o
on00oooP0?l0oooP503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>40
0`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>409`3oi>42
0000o`X0onCQ00<0cHDo0?ooh03oon00o`3oon0D0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=
QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=
QCl0onCQ0?oTh@0Y0?oTh@80003o203oi>400`3=QCl0oooP0?ooh03o0?ooh1@0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0
onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ02/0onCQ0P000?l60?oTh@030<f5?`3oon00oooP0?l0
oooP503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ
0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40;@3oi>420000o`@0onCQ
00<0cHDo0?ooh03oon00o`3oon0D0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oT
h@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oT
h@0_0?oTh@80003o0P3oi>400`3=QCl0oooP0?ooh03o0?ooh1@0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C
0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0G
0?oTh@030<f5?`3oi>40onCQ0340onCQ0P000?l00`3=QCl0oooP0?ooh03o0?ooh1@0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=
QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ03<0onCQ0P000?oo0?ooh1D0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0
onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ03<0onCQ00@0cHDo0?ooh0000?l0003oo`3oon0C0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0
onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@0c0?oTh@050<f5?`3oon00oooP0?oo
h0000?l0o`3oon0B0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@03
0<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@0c0?oTh@03
0<f5?`3oon00oooP0080oooP0P000?oo0?ooh100oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5
?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5
?`3oi>40onCQ03<0onCQ00<0cHDo0?ooh03oon00103oon020000ool0oooP3P3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>404`3o
i>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>405`3o
i>400`3=QCl0onCQ0?oTh@0c0?oTh@030<f5?`3oon00oooP00H0oooP00<0003o0?ooh03oon00o`3o
on090?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>40
0`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ03<0onCQ00<0cHDo0?ooh03oon001`3oon02
0000ool0oooP2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=
QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40<`3oi>400`3=
QCl0oooP0?ooh0090?ooh080003oo`3oon090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0
onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0
onCQ0?oTh@0c0?oTh@030<f5?`3oon00oooP00/0oooP0P000?oo0?ooh0L0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ
0?oTh@0G0?oTh@030<f5?`3oi>40onCQ03<0onCQ00<0cHDo0?ooh03oon003@3oon000`000?l0oooP
0?ooh03o0?ooh0@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ00<0
cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ03<0onCQ00<0
cHDo0?ooh03oon003P3oon020000ool0oooP103oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo
0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo
0?oTh@3oi>40<`3oi>400`3=QCl0oooP0?ooh00@0?ooh080003oo`3oon020?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0onCQ00<0cHDo0?oT
h@3oi>405`3oi>400`3=QCl0onCQ0?oTh@0c0?oTh@030<f5?`3oon00oooP0180oooP0P000?oo0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ03X0
onCQ00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@0c0?oTh@030<f5?`3oon00oooP01@0
oooP00<0003o0?ooh03oon00o03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40
803oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40
<`3oi>400`3=QCl0oooP0?ooh00E0?ooh080003oo03oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0
cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0
cHDo0?oTh@3oi>40<`3oi>400`3=QCl0oooP0?ooh00G0?ooh080003o00<0oooP000000000000m`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0j
0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40<`3oi>4L0<f5?`050000o`000000
00000000003=QCl0m@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02
000000P0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40
onCQ0200onCQ00<0cHDo0?oTh@3oi>40>P3oi>400`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40
onCQ03<0onCQ00<0cHDo0?oTh@3oi>406@3oi>401@000000003o0000o`000000cHDo0?D0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40803o
i>400`3=QCl0onCQ0?oTh@0j0?oTh@030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40<`3o
i>400`3=QCl0onCQ0?oTh@0J0?oTh@8000000P000?oe0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP100000080?ooh>L000000P00
0?oX000000P0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP0>l0oooP00@0<j7:0:gHiP2]f>H0003o7`2]f>H00`0cXLX0[MSV
0:gHiP0/0:gHiP0303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV
0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000
003oon00oooP0>l0oooP00@0<j7:0:gHiP2]f>H0[MSV0P000?lM0:gHiP0303>QbP2]f>H0[MSV02`0
[MSV00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03_0?ooh00303>Q
bP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H06P2]f>H00`0cXLX0[MSV0:gHiP0/0:gHiP0303>Q
bP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>Q
bP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03_0?ooh00303>QbP2]f>H0[MSV00@0[MSV0P00
0?lJ0:gHiP0303>QbP2]f>H0[MSV02`0[MSV00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gH
iP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0>l0oooP00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV02`0[MSV00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0
[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0>l0oooP00<0<j7:0:gH
iP2]f>H01`2]f>H20000o`8000005@2]f>H00`0cXLX0[MSV0:gHiP0/0:gHiP0303>QbP2]f>H0[MSV
0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03_0?ooh0/0<j7:00@000000000o`00000000005@0cXLX^0:gH
iP0303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gH
iP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03j0?ooh080000000<0003o0000003o
on004`3oon000`0cXLX0[MSV0:gHiP0/0:gHiP0303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]
f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03k0?ooh08000000P000?lC0?ooh00303>QbP2]f>H0[MSV02`0[MSV00<0<j7:0:gHiP2]f>H0
<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H0
7P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP00<0003o0?ooh03oon00403oon000`0cXLX0[MSV0:gH
iP0/0:gHiP0303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gH
iP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh040oooP0P000?l@
0?ooh00303>QbP2]f>H0[MSV02`0[MSV00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP0`3oon000`000?l0oooP0?ooh00=0?ooh00303>QbP2]f>H0[MSV02`0[MSV00<0<j7:0:gH
iP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gH
iP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP103oon020000o`d0oooP00<0<j7:0:gHiP2]
f>H0;02]f>H00`0cXLX0[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon060?ooh0030000
o`3oon00oooP00X0oooP00<0<j7:0:gHiP2]f>H0;02]f>H00`0cXLX0[MSV0:gHiP0`0:gHiP0303>Q
bP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
003o0?ooh0L0oooP0P000?l:0?ooh00303>QbP2]f>H0[MSV02`0[MSV00<0<j7:0:gHiP2]f>H0<02]
f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]
f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon090?ooh0030000o`3oon00oooP00L0oooP00<0<j7:0:gHiP2]f>H0;02]f>H0
0`0cXLX0[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H0
0`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0:0?ooh080003o1`3oon000`0c
XLX0[MSV0:gHiP0/0:gHiP0303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0c
XLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0`0
oooP00<0003o0?ooh03oon00103oon000`0cXLX0[MSV0:gHiP0/0:gHiP0303>QbP2]f>H0[MSV0300
[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0d0oooP0P000?l40?ooh00303>QbP2]f>H0[MSV02`0[MSV
00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3`3oon001@000?l0oooP0?oo
h03oon00<j7:02h0[MSV00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>Q
bP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403o
on020000o`030?ooh0000000000002d0[MSV00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gH
iP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP4P3oon0010000?l0000000000000000/0:gHiP0303>QbP2]f>H0[MSV0300[MSV00<0
<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh180oooP00@000000000o`000?l00000;@0cXLXb0:gHiP0303>QbP2]
f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0C0?ooh080000000<0003o0?ooh03oon00:P3oon000`0cXLX0[MSV0:gHiP0`
0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0F0?ooh080003o:P3oon000`0cXLX0[MSV0:gHiP0`0:gH
iP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0H0?ooh0030000o`3oon00oooP02L0oooP00<0<j7:0:gHiP2]
f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP6@3oon020000obL0oooP00<0<j7:0:gHiP2]f>H0
<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H0
7P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP6`3oon000`000?l0oooP0?ooh00T0?ooh00303>QbP2]
f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]
f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon0300000?l0oooP703oon020000ob@0oooP00<0<j7:0:gHiP2]f>H0<02]f>H0
0`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H0
0`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0N0?ooh0030000o`3oon00oooP0240oooP00<0<j7:0:gHiP2]f>H0<02]f>H00`0c
XLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP7`3oon000`000?l0oooP0?ooh00P0?ooh00303>QbP2]f>H0[MSV0300
[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh200oooP0P000?lP0?ooh00303>QbP2]f>H0[MSV0300[MSV
00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh280oooP00<0003o0?ooh03oon007@3oon000`0cXLX0[MSV0:gH
iP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gH
iP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0S0?ooh0030000o`3oon00oooP01`0oooP00<0<j7:
0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:
0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP903oon020000oa`0oooP00<0<j7:0:gH
iP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gH
iP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP9P3oon000`000?l0oooP0?ooh00I0?ooh003
03>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP03
03>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2L0oooP00<0003o0?ooh03oon00
603oon000`0cXLX0[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
7P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0X0?ooh080003o603o
on000`0cXLX0[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]
f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Z0?ooh0030000o`3oon00
oooP01D0oooP00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0
[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:`3oon000`00
0?l0oooP0?ooh00D0?ooh00303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0c
XLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2`0
oooP0P000?lD0?ooh00303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0
[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2h0oooP
00<0003o0?ooh03oon004@3oon000`0cXLX0[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV
00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh2l0oooP00<0
003o0?ooh03oon00403oon000`0cXLX0[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0
<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00L0oooP0`00
000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh300oooP0P000?l@
0?ooh00303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N
0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP00<0003o0?oo
h03oon003@3oon000`0cXLX0[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gH
iP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0c0?ooh003
0000o`3oon00oooP00`0oooP00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP03
03>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
=03oon000`000?l0oooP0?ooh00;0?ooh00303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0
802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh3D0oooP0P000?l;0?ooh00303>QbP2]f>H0[MSV0300[MSV00<0<j7:0:gHiP2]f>H0802]
f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh3L0oooP00<0003o0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0
[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0h0?ooh0030000o`3oon00oooP00L0oooP00<0<j7:0:gHiP2]f>H0<02]f>H00`0c
XLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP>@3oon020000o`L0oooP00<0<j7:0:gHiP2]f>H0<02]f>H00`0cXLX0
[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP>`3oon000`000?l0oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV0300[MSV
00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh3`0oooP00<0003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gH
iP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gH
iP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0m0?ooh0030000o`3oon00oooP0080oooP00<0<j7:
0:gHiP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:
0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?P3oon020000o`80oooP00<0<j7:0:gH
iP2]f>H0<02]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gH
iP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@03oon000`000?l0oooP03>QbP0b0:gHiP03
03>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon110?ooh0030000o`0cXLX0[MSV0340[MSV00<0<j7:0:gHiP2]f>H0
802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP@P3o
on000`000?l0[MSV0:gHiP0`0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]
f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh480oooP00<0<j7:0000o`2]f>H0<02]f>H0
0`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP@P3oon000`0cXLX0[MSV0000o`0`0:gHiP0303>QbP2]f>H0[MSV
0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon120?ooh00303>QbP2]f>H0[MSV0080003o;P2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP03
03>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
@P3oon000`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV02/0[MSV00<0<j7:0:gHiP2]f>H0
802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh480oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP0Z0:gHiP0303>QbP2]
f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon120?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0003o0:gHiP2]f>H0:@2]f>H0
0`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP@P3oon000`0cXLX0[MSV0:gHiP050:gHiP030000o`2]f>H0[MSV
02P0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh480oooP00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0
[MSV0:gHiP0W0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0
[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon120?ooh00303>QbP2]f>H0[MSV00L0[MSV
00<0003o0:gHiP2]f>H09P2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@P3oon000`0cXLX0[MSV0:gH
iP080:gHiP030000o`2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gH
iP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh480oooP00<0<j7:
0:gHiP2]f>H02@2]f>H00`000?l0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:
0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP
0?l0oooP@P3oon000`0cXLX0[MSV0:gHiP0:0:gHiP80003o902]f>H00`0cXLX0[MSV0:gHiP0P0:gH
iP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0
oooP00<000000?ooh03oon00o`3oon120?ooh00303>QbP2]f>H0[MSV00`0[MSV00<0003o0:gHiP2]
f>H08@2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000003o0?ooh440oooP00<0<j7:0:gHiP2]f>H0
3@2]f>H00`000?l0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
7P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00H0oooP1000000H0?ooh1h0n_3V
0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooP@P3o
on000`0cXLX0[MSV0:gHiP0>0:gHiP030000o`2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0802]
f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh006
0?ooh0030000003oon00oooP0?l0oooP@P3oon000`0cXLX0[MSV0:gHiP0?0:gHiP030000o`2]f>H0
[MSV01h0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0
[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon120?ooh00303>QbP2]f>H0[MSV
0100[MSV00<0003o0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@P3oon000`0cXLX0
[MSV0:gHiP0A0:gHiP030000o`2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0
[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh480oooP
00<0<j7:0:gHiP2]f>H04P2]f>H00`000?l0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV0200[MSV
00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on120?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0003o0:gHiP2]f>H06P2]f>H00`0cXLX0[MSV0:gH
iP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP@P3oon000`0cXLX0[MSV0:gHiP0D0:gHiP80003o6P2]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP@P3oon000`0cXLX0[MSV0:gHiP0F0:gHiP030000o`2]f>H0[MSV01L0[MSV00<0<j7:0:gH
iP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh480oooP00<0<j7:0:gHiP2]f>H05`2]f>H00`000?l0[MSV0:gHiP0F0:gHiP03
03>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon120?ooh00303>QbP2]f>H0[MSV01P0[MSV00<0003o0:gHiP2]f>H0
5@2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H0
7P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP@P3oon000`0cXLX0[MSV0:gHiP0I0:gHiP030000o`2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]
f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh480oooP00<0<j7:0:gHiP2]f>H06P2]f>H0
0`000?l0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H0
0`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon120?ooh00303>QbP2]f>H0[MSV
01/0[MSV00<0003o0:gHiP2]f>H04P2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon120?ooh00303>QbP2]f>H0[MSV01`0
[MSV00<0003o0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon120?ooh00303>QbP2]f>H0[MSV01d0[MSV
00<0003o0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@P3oon000`0cXLX0[MSV0:gH
iP0N0:gHiP80003o0P00000>0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]
f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon120?ooh280<j7:00@00000
0000o`00000000003P0cXLXR0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPI03oon02000000030000o`000000oooP00`0oooP00<0<j7:
0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh6D0oooP0P0000000`000?l0oooP0?ooh00;0?ooh00303>QbP2]f>H0[MSV
0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1X0?ooh0030000o`3oon00oooP00X0oooP00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0
[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6T0oooP
00<0003o0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJP3oon000`000?l0oooP0?oo
h0080?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gH
iP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1[0?ooh0030000o`3oon00oooP00L0oooP00<0<j7:
0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh6`0oooP00<0003o0?ooh03oon001P3oon000`0cXLX0[MSV0:gHiP0P0:gH
iP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPK@3oon000`000?l0oooP0?ooh0050?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1^0?ooh0030000
o`3oon00oooP00@0oooP00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>Q
bP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6l0oooP00<0003o0?ooh03oon000`3o
on000`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPL03oon000`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0
[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?oo
h740oooP0P000?l20?ooh00303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0c
XLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh7<0oooP00<0003o0?ooh00cXLX08P2]f>H00`0cXLX0
[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7@0oooP
00<0003o03>QbP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh7D0oooP00<0003o0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gH
iP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7D0oooP00<0<j7:
0000o`2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh7D0oooP00<0<j7:0:gHiP000?l0802]f>H00`0cXLX0[MSV0:gHiP0N0:gH
iP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7D0oooP00@0<j7:0:gHiP2]
f>H0003o7`2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh7D0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0N0:gHiP0303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPM@3oon000`0cXLX0
[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0
[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1e0?ooh00303>QbP2]f>H0[MSV00<0[MSV
00<0003o0000000000006P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh7D0oooP00<0<j7:0:gHiP2]f>H00`2]f>H010000000003o0000
0000000I0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPM@3oon0603>QbP80000000<0003o0000000cXLX06@0cXLXP0:gHiP0303>QbP2]
f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP0P0000000`000?l0oooP0?ooh00G
0?ooh00303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPO`3oon000`000?l0oooP0?ooh00F0?ooh00303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gH
iP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<00000o`3oon200?ooh0030000o`3oon00oooP01D0oooP00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh840oooP00<0003o0?ooh03oon00
503oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh880oooP00<0003o0?ooh03oon004`3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]
f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8<0oooP00<0003o0?ooh03oon004P3oon00
0`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h8@0oooP00<0003o0?ooh03oon004@3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh8D0oooP00<0003o0?ooh03oon00403oon000`0cXLX0
[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8H0oooP
00<0003o0?ooh03oon003`3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8L0oooP00<0003o0?ooh03oon003P3oon000`0cXLX0[MSV0:gH
iP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8P0oooP00<0003o
0?ooh03oon003@3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh8T0oooP00<0003o0?ooh03oon00303oon000`0cXLX0[MSV0:gHiP0N0:gH
iP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP00<0003o0?ooh03o
on002`3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh8/0oooP00<0003o0?ooh03oon002P3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>Q
bP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8`0oooP00<0003o0?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh8d0oooP00<0003o0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0
[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon0300000?l0oooPSP3oon000`000?l0oooP0?ooh0070?ooh00303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2?0?ooh0030000o`3oon00oooP00H0
oooP00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2@0?ooh0030000o`3oon00oooP00D0oooP00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV
0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2A0?ooh0030000o`3oon00oooP00@0oooP00<0
<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2B
0?ooh0030000o`3oon00oooP00<0oooP00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2B0?ooh0030000o`3oon00oooP00<0oooP00<0<j7:0:gH
iP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2C0?ooh003
0000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2D0?ooh0050000o`3oon00oooP0?ooh00cXLX0802]f>H00`0cXLX0
[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2E0?ooh0040000o`3oon00oooP03>QbR00
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPUP3oon000`000?l0oooP
03>QbP0P0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9L0oooP00<0
003o03>QbP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2H
0?ooh0030000o`2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPV03oon000`0cXLX0003o0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon04000000L0
oooP00<000000?ooh03oon00o`3oon2H0?ooh00303>QbP2]f>H0003o01h0[MSV00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>H@0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00o`3oon2H0?ooh00403>Q
bP2]f>H0[MSV0000oad0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0030000003oon00oooP00L0oooP
1000003o0?ooh9L0oooP00D0<j7:0:gHiP2]f>H0003o0:gHiP02000001X0[MSV00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0oooP0?ooh0060?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ80oooP
00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh9P0oooP00D0<j7:0:gHiP2]f>H0
[MSV0000o`03000001T0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0
oooP00<000000?ooh03oon00o`3oon2H0?ooh0@0<j7:00@000000000o`00000000006P0cXLXP0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40
oooP0P0000080?ooh0030000003oon00oooP0?l0oooPW@3oon000`000000003o0?ooh00I0?ooh003
03>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9l0oooP00<0003o0?ooh03oon00
5`3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2P0?ooh0030000o`3o
on00oooP01H0oooP00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX@3oon00
0`000?l0oooP0?ooh00E0?ooh00303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:80oooP00<0003o0?ooh03oon00503oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2S0?ooh0030000o`3oon00oooP01<0oooP00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPY03oon000`000?l0oooP0?ooh00B0?ooh00303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh:D0oooP00<0003o0?ooh03oon004@3oon000`0cXLX0[MSV0:gH
iP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2V0?ooh0030000o`3oon00oooP0100oooP00<0<j7:
0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY`3oon000`000?l0oooP0?ooh00?0?oo
h00303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:P0oooP00<0003o0?ooh03o
on003P3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh:T0oooP00<0003o0?ooh03oon00
3@3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP00<0003o0?ooh03oon00303o
on000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Z0?ooh0030000o`3oon00
oooP00`0oooP00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ`3oon000`00
0?l0oooP0?ooh00;0?ooh00303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:`0
oooP00<0003o0?ooh03oon002P3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2]0?ooh0030000o`3oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP[P3oon000`000?l0oooP0?ooh0080?ooh00303>QbP2]f>H0[MSV01h0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:l0oooP00<0003o0?ooh03oon001`3oon000`0cXLX0[MSV0:gHiP0N
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2`0?ooh0030000o`3oon00oooP00H0oooP00<0<j7:0:gH
iP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon000`000?l0oooP0?ooh0050?ooh003
03>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;80oooP00<0003o0?ooh03oon00
103oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2c0?ooh0030000o`3o
on00oooP00<0oooP00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]03oon00
0`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;D0oooP00D0003o0?ooh03oon00oooP03>QbP0P0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh;H0oooP00@0003o0?oo
h03oon00<j7:802]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh0030000o`3oon00<j7:0200[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh;L0oooP00<0003o0?ooh00cXLX0802]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
^03oon000`000?l0<j7:0:gHiP0O0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh0030000o`2]
f>H0[MSV01h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;T0oooP00<0<j7:0000o`2]f>H07P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP^@3oon000`0cXLX0[MSV0000o`0N0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2i0?ooh00403>QbP2]f>H0[MSV0000oad0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;T0
oooP00@0<j7:0:gHiP2]f>H0003o7@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^@3oon001@0cXLX0
[MSV0:gHiP2]f>H0003o01`0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;T0oooP00<0<j7:0:gHiP2]
f>H00P2]f>H00`000?l0[MSV0:gHiP0I0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh00303>Q
bP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H0602]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^@3o
on000`0cXLX0[MSV0:gHiP040:gHiP030000o`2]f>H0[MSV01L0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh;T0oooP00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP0F0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2i0?ooh00303>QbP2]f>H0[MSV00D0[MSV00<0003o0:gHiP2]f>H05P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon2i0?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H05@2]f>H00`0cXLX0
oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2i0?ooh00303>QbP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]f>H0502]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP^@3oon000`0cXLX0[MSV0:gHiP080:gHiP030000o`2]f>H0[MSV01<0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;T0oooP00<0<j7:0:gHiP2]f>H02@2]f>H00`000?l000000000000B
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh0`0<j7:00@000000000o`00000000004P0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPa@3oon0010000000003o00000000000M0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPaP3oon000`000000003o0?ooh00M0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPb03oon000`000?l0oooP0?ooh00K0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb@3oon000`000?l0oooP0?ooh00J0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPbP3o
on000`000?l0oooP0?ooh00I0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPb`3oon000`000?l0oooP0?ooh00H0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb`3oon000`00
0?l0oooP0?ooh00H0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPc03oon000`000?l0oooP0?ooh00G0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPc@3oon000`000?l0oooP
0?ooh00F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3o
on3>0?ooh0030000o`3oon00oooP01<0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh<l0oooP00<0003o0?ooh03oon00503oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=00oooP00<0003o0?oo
h03oon004`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh=40oooP00<0003o0?ooh03oon004P3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=40oooP00<0003o0?ooh03oon00
4P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh=80oooP00<0003o0?ooh03oon004@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=<0oooP00<0003o0?ooh03oon00403oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h=@0oooP00<0003o0?ooh03oon003`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh=D0oooP00<0003o0?ooh03oon003P3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=H0oooP
00<0003o0?ooh03oon003@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh=L0oooP00<0003o0?ooh03oon00303oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=L0oooP00<0003o
0?ooh03oon00303oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon020000
00P0oooP00<000000?ooh03oon00o`3oon3H0?ooh0030000o`3oon00oooP00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`00
0000oooP0?ooh03o0?ooh=T0oooP00<0003o0?ooh03oon002P3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon3I0?ooh003
0000o`3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4`3oon000`000000oooP
0?ooh0050?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooP
iP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<0
00000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooPo`00
003Z000001P0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003L0?[`iP@000000P3jl>H800000080n_3V100000001`3jl>H00000000000000000n_3V0000003j
l>H0300000000`3jl>H0000000000004000000040?[`iP0000000000000000P0n_3V1@0000040?[`
iPL0000000<0n_3V0000003jl>H00`0000090?[`iPD000000P3jl>H400000080n_3V1@00000B0?[`
iPH000001P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V0000000000000000i03jl>H1
0?ooo`00g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H2000000<0n_3V00L000000?[`
iP00000000000?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000002@3jl>H010000000n_3V0?[`iP3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00D0
n_3V0P0000000`3jl>H000000000003U0?[`iP40oooo003M0?[`iP80000000<0n_3V000000000000
103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP800000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP800000303jl>H5000000D0n_3V0P0000060?[`iPD0
00001P3jl>H300000>H0n_3V0@3oool00=d0n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`
iP00000000000?[`iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V0P000000103j
l>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P000002
0?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00003V
0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H20000
00060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00
000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V
0P0000020?[`iP<0000000<0n_3V0000003jl>H04P3jl>H2000000P0n_3V00<000000?[`iP3jl>H0
1@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3j
l>H500000080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000002`3j
l>H500000080n_3V100000020?[`iP<0000000<0n_3V0000000000004`3jl>H2000000l0n_3V0`00
00001@3jl>H00000000000000000n_3V00@00000g`3jl>H10?ooo`00g@3jl>H200000080n_3V0P00
000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0H0?[`iP8000008@3jl>H4000001P0n_3V00<0
00000?[`iP3jl>H0g`3jl>H10?ooo`00g03jl>H6000000@0n_3V0P00000_0?[`iPD000006`3jl>H3
00000240n_3V0P00000I0?[`iP030000003jl>H0n_3V0=h0n_3V0@3oool00?l0n_3VN03jl>H00`00
0000n_3V0?[`iP3M0?[`iP40oooo003o0?[`iWD0n_3V00@000000?[`iP3jl>H00000g`3jl>H10?oo
o`00o`3jl>If0?[`iP800000h03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01529 L
.09023 .01529 L
.09023 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01529 L
.09023 .01529 L
.09023 .16187 L
s
1 .894 .882 r
.09023 .16187 m
.09023 .02687 L
.17247 .02687 L
.17247 .16187 L
F
.804 .522 .247 r
.09023 .16187 m
.09023 .02687 L
.17247 .02687 L
.17247 .16187 L
s
1 .894 .882 r
.17247 .16187 m
.17247 .03699 L
.21965 .03699 L
.21965 .16187 L
F
.804 .522 .247 r
.17247 .16187 m
.17247 .03699 L
.21965 .03699 L
.21965 .16187 L
s
1 .894 .882 r
.21965 .16187 m
.21965 .04621 L
.26364 .04621 L
.26364 .16187 L
F
.804 .522 .247 r
.21965 .16187 m
.21965 .04621 L
.26364 .04621 L
.26364 .16187 L
s
1 .894 .882 r
.26364 .16187 m
.26364 .06396 L
.34769 .06396 L
.34769 .16187 L
F
.804 .522 .247 r
.26364 .16187 m
.26364 .06396 L
.34769 .06396 L
.34769 .16187 L
s
1 .894 .882 r
.34769 .16187 m
.34769 .08777 L
.41637 .08777 L
.41637 .16187 L
F
.804 .522 .247 r
.34769 .16187 m
.34769 .08777 L
.41637 .08777 L
.41637 .16187 L
s
1 .894 .882 r
.41637 .16187 m
.41637 .12298 L
.44522 .12298 L
.44522 .16187 L
F
.804 .522 .247 r
.41637 .16187 m
.41637 .12298 L
.44522 .12298 L
.44522 .16187 L
s
1 .894 .882 r
.44522 .16187 m
.44522 .14538 L
.51675 .14538 L
.51675 .16187 L
F
.804 .522 .247 r
.44522 .16187 m
.44522 .14538 L
.51675 .14538 L
.51675 .16187 L
s
.678 .847 .902 r
.51675 .16187 m
.51675 .17333 L
.56232 .17333 L
.56232 .16187 L
F
.2 .63 .79 r
.51675 .16187 m
.51675 .17333 L
.56232 .17333 L
.56232 .16187 L
s
.678 .847 .902 r
.56232 .16187 m
.56232 .22157 L
.6133 .22157 L
.6133 .16187 L
F
.2 .63 .79 r
.56232 .16187 m
.56232 .22157 L
.6133 .22157 L
.6133 .16187 L
s
.678 .847 .902 r
.6133 .16187 m
.6133 .27729 L
.68675 .27729 L
.68675 .16187 L
F
.2 .63 .79 r
.6133 .16187 m
.6133 .27729 L
.68675 .27729 L
.68675 .16187 L
s
.678 .847 .902 r
.68675 .16187 m
.68675 .30178 L
.74299 .30178 L
.74299 .16187 L
F
.2 .63 .79 r
.68675 .16187 m
.68675 .30178 L
.74299 .30178 L
.74299 .16187 L
s
.678 .847 .902 r
.74299 .16187 m
.74299 .40918 L
.82462 .40918 L
.82462 .16187 L
F
.2 .63 .79 r
.74299 .16187 m
.74299 .40918 L
.82462 .40918 L
.82462 .16187 L
s
.678 .847 .902 r
.82462 .16187 m
.82462 .47208 L
.8931 .47208 L
.8931 .16187 L
F
.2 .63 .79 r
.82462 .16187 m
.82462 .47208 L
.8931 .47208 L
.8931 .16187 L
s
.678 .847 .902 r
.8931 .16187 m
.8931 .59715 L
.97619 .59715 L
.97619 .16187 L
F
.2 .63 .79 r
.8931 .16187 m
.8931 .59715 L
.97619 .59715 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.05349 .01529 Mdot
.16065 .02687 Mdot
.2091 .03699 Mdot
.24412 .04621 Mdot
.29928 .06396 Mdot
.35933 .08777 Mdot
.43226 .12298 Mdot
.47253 .14538 Mdot
.5182 .17333 Mdot
.58839 .22157 Mdot
.65991 .27729 Mdot
.68892 .30178 Mdot
.80347 .40918 Mdot
.86333 .47208 Mdot
.97118 .59715 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.176497) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.71464) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000H0n_3V0P0000030?[`iPH000000P3jl>H4000000<0n_3V0`0000040?[`iP@0
0000o`3jl>JS0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000060?[`iP8000001@3j
l>H2000000D0n_3V0P0000030?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VY03j
l>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2
000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000000000/0n_3V0P00
00050?[`iP8000000P3jl>H600000080n_3V0P000000103jl>H000000000003jl>H600000?l0n_3V
X`3jl>H10?ooo`00803jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V
0000003jl>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`
iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP0000000000
00/0n_3V0P0000050?[`iP8000000P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000001@3j
l>H000000000003jl>H000000080n_3V0P00003o0?[`iZ@0n_3V0@3oool00200n_3V0P0000020?[`
iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003j
l>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H00000
0?[`iP02000001P0n_3V0P0000000`3jl>H000000000000<0?[`iP800000103jl>H2000000<0n_3V
00@000000?[`iP00000000000`3jl>H4000000<0n_3V00@000000?[`iP0000000000o`3jl>JT0?[`
iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H400000003
0?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0
n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H000000000000<0?[`iP80
0000103jl>H2000000<0n_3V00@000000?[`iP00000000000`3jl>H2000000D0n_3V00@000000?[`
iP0000000000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`
iP030000003jl>H0n_3V02D0n_3V0P0000000`3jl>H00000000000090?[`iP030000003jl>H0n_3V
008000000P3jl>H4000000@0n_3V0`0000040?[`iP8000001@3jl>H300000?l0n_3VY03jl>H10?oo
o`007`3jl>H6000000@0n_3V0P00000_0?[`iPD00000:03jl>H3000000X0n_3V1@0000040?[`iP80
00001@3jl>H2000000D0n_3V0`0000040?[`iP800000o`3jl>JT0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool003d0n_3V1000003o0?[`
i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3Vo`3jl>HG0?[`iP40oooo000P0?[`iPH00000
00D0n_3V00000000000000000?[`iP0300000080n_3V0`0000030?[`iP@000000`3jl>H200000004
0?[`iP00000000000?[`iPD000000`3jl>H<000002l0n_3V0`0000040?[`iP8000001@3jl>H30000
00@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP800000o`3jl>JN0?[`
iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`iP04
0000003jl>H00000000000<0n_3V00D000000?[`iP00000000000?[`iP0300000080n_3V0P000004
0?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000
000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`
iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000050?[`iP8000000P3jl>H20000
0080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000`0?[`iP80000000<0n_3V0000
000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iPH0000000<0n_3V0000000000000P3jl>H200000080
n_3V0P0000050?[`iPD000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V00000000
00002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`
iP00000000000080n_3V0P0000040?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP<0
00000P3jl>H3000000030?[`iP000000n_3V00@0n_3V0P0000030?[`iP800000<03jl>H200000003
0?[`iP000000000000T0n_3V100000030?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@0
00001P3jl>H200000?l0n_3VW@3jl>H10?ooo`008P3jl>H2000000<0n_3V1@0000020?[`iPD00000
0`3jl>H4000000<0n_3V0P0000000`3jl>H0000000000004000000030?[`iP00000000000080n_3V
100000040?[`iP800000<03jl>H2000000030?[`iP000000000000T0n_3V0P0000050?[`iP800000
1@3jl>H2000000D0n_3V0P0000050?[`iP800000203jl>H200000?l0n_3VW@3jl>H10?ooo`008P3j
l>H2000000/0n_3V0P00000R0?[`iP800000<03jl>H2000000030?[`iP000000000000X0n_3V0P00
00050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000103jl>H00`000000n_3V0?[`
iP0200000?l0n_3VW@3jl>H10?ooo`00803jl>H6000000T0n_3V0P00000P0?[`iP@00000<@3jl>H3
000000`0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<000000P3jl>H5
00000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H020000000
0`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H010000000n_3V0000003jl>H2
00000080n_3V00<000000?[`iP3jl>H00`00003o0?[`i_l0n_3V903jl>H10?ooo`00803jl>H30000
00030?[`iP00000000000080000000D0n_3V0000003jl>H000000?[`iP0300000080n_3V00<00000
0?[`iP000000603jl>H500000=/0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P000003
0?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000@0n_3V0000000000000000203j
l>H4000000030?[`iP00000000000080n_3V100000020?[`iPD0000000L0n_3V0000000000000000
0?[`iP000000n_3V00<00000603jl>H3000000@0n_3V0P0000040?[`iPH000000`3jl>H2000000@0
n_3V0`0000040?[`iP@000000P3jl>H3000000H0n_3V0P00001i0?[`iP40oooo000Q0?[`iP800000
00<0n_3V0000000000001@000000103jl>H000000000000000020?[`iP80000000<0n_3V00000000
00002@3jl>H5000000T0n_3V0P00003O0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP80
00001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H01000
0000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000
000000X0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V0P000004
0?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000
000000<0n_3V0P0000060?[`iP8000001@3jl>H2000000<0n_3V0P0000000`3jl>H0000000000004
0?[`iP8000001@3jl>H2000000D0n_3V0P00001i0?[`iP40oooo000R0?[`iP<00000:@3jl>H20000
0=h0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H20000
00@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000
000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H2
000000@0n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H000000000000;
0?[`iP8000001@3jl>H2000000<0n_3V0P000000103jl>H000000000003jl>H6000000D0n_3V0P00
00040?[`iP800000N@3jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP800000g@3jl>H4
000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2
000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P000000
1@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0
n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000/0n_3V0P00
00050?[`iP8000000`3jl>H2000000050?[`iP00000000000?[`iP0000000P3jl>H2000000@0n_3V
100000040?[`iP800000N@3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002X0n_3V0P00
003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`
iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP800000
0P3jl>H2000000030?[`iP000000000000X0n_3V0`000000103jl>H000000000003jl>H200000080
n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02000001P0
n_3V0P0000000`3jl>H000000000000;0?[`iP8000001P3jl>H200000080n_3V100000030?[`iP04
0000003jl>H00000000000<0n_3V0P0000000`3jl>H00000000000050?[`iP800000N03jl>H10?oo
o`00803jl>H3000000040?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000003L0?[`
iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003jl>H5
00000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000002`3jl>H3
000000030?[`iP00000000000080n_3V100000020?[`iP<0000000<0n_3V0000000000001`00000I
0?[`iP80000000<0n_3V0000000000002`3jl>H2000000H0n_3V0P0000020?[`iP8000001@3jl>H0
10000000n_3V0000000000030?[`iP80000000<0n_3V0000000000001@3jl>H2000007P0n_3V0@3o
ool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403jl>H2
000000`0n_3V0P00000R0?[`iP8000000P3jl>H2000002h0n_3V0P0000000`3jl>H0000000000009
0?[`iP@000000`3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000050?[`iP<000000`3jl>H2
000000030?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P00001h0?[`iP40oooo001>0?[`
iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000I0?[`
iP<0000000<0n_3V0000000000000P00000^0?[`iP<00000303jl>H2000000<0n_3V1@0000040?[`
iP<00000103jl>H2000000@0n_3V0`0000030?[`iPD00000N03jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V
0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H01@00
0000n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`
iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`iP00000000000080000000@0n_3V
0000003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V01L0n_3V
0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V
1P0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000H000006P3jl>H600000080n_3V
0`0000310?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@0000001@3jl>H000000000
00000000n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000
103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0
n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000/0n_3V1@00000;
0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000<00n_3V0@3oool00280n_3V0`00000X0?[`
iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H20000
00D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000030?[`iP@000006`3jl>H2000000H0n_3V0P0000300?[`
iP40oooo000R0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H200000003
0?[`iP00000000000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H0
00000000003jl>H4000000d0n_3V1@00000;0?[`iP8000001P3jl>H200000<00n_3V0@3oool00240
n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0n_3V000000000000g03jl>H200000003
0?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`
iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103j
l>H000000000003jl>H200000080n_3V0P00000K0?[`iP8000000`3jl>H00`000000n_3V0?[`iP02
00000<00n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V
000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V
000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3j
l>H5000000<0n_3V1@00000K0?[`iP8000000`3jl>H400000<40n_3V0@3oool004d0n_3V0P000000
0`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403jl>H2000000`0n_3V0P00000h
0?[`iP@000000`3jl>H200000<<0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H200000380n_3V0P0000030?[`iPD00000`03jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0n_3V9P3oon02
000006`0oooP0P0000040?ooh0800000103oon02000006/0oooP1@00001Y0?ooh0D000000P3oon02
000000@0oooP0P00001[0?ooh0@000008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?oo
h03oon000000JP3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP000006`0oooP
00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0070?ooh0040000003oon00oooP000006X0
oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon00
0000JP3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP06X0oooP00<000000?oo
h03oon00J`3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP06T0oooP00<000000?oo
h03oon008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon001000
0000oooP0?ooh00000090?ooh0800000K@3oon000`000000oooP0?ooh01[0?ooh0030000003oon00
oooP00P0oooP0P00001]0?ooh0030000003oon00oooP0280oooP7P3jl>H10?ooo`007@3jl>HU0?oo
h0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002@3oon000`000000oooP0?oo
h01/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon00203oon000`000000oooP0?oo
h01Z0?ooh0040000003oon00oooP000002<0oooP7P3jl>H10?ooo`007@3jl>HV0?ooh0800000K03o
on02000000X0oooP0`00001[0?ooh0800000K03oon02000000X0oooP0`00001[0?ooh0800000903o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01a0?oo
h0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?oo
h0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon005`3oon0200000?l0oooPc@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh006
0?ooh0030000003oon00oooP01H0oooP1000003o0?ooh<`0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon04000000P0oooP6P000?l70<f5
?ol0oooP^@3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H:0?ooh0@00000103oon000`000000
oooP0?ooh0060?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>42000000X0
onCQ20000?oo0?ooh;/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP
00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ
00<0cHDo0?ooh0000?l02@000?oo0?ooh;40oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3o
i>400`3=QCl0oooP0?ooh0090?ooh0T0003oo`3oon2X0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>40
0`3=QCl0oooP0?ooh00B0?ooh0P0003o1@3oon0200000?l0oooPV@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
01d0onCQ00<0cHDo0?ooh03oon006P3oon050000o`<00000o`3oon2H0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>407@3oi>4Q0<f5?`03000000000?l0003o00<0003o0P3=QCoo0?ooh9@0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0M0?oTh@030<f5?`3oi>40onCQ01l0onCQ0P0000030?oTh@D0003oo`3oon2A0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@040<f5?`3oon00oooP0?ooh0D0003o
o`3oon2<0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3o
on00oooP00H0oooP1@000?l40?ooh0800000o`3oon210?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>40
0`3=QCl0onCQ0?oTh@0U0?oTh@h0cHDo10000?l3000000<0cHDoo`3oon1m0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<000000000
o`000?l00`000?l00`3=QCl0oooP0?ooh03o0?ooh7/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0M0?oTh@03
0<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oTh@3oi>403`3oi>42000000<0onCQ10000?oo0?ooh7X0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oTh@3oi>40
503oi>40103=QCl0oooP0?ooh03oon040000o`@0oooP0P00003o0?ooh700oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ01d0onCQ
00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oon00oooP00D0oooP
0`000?l400000?l0oooPK@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3o
i>40onCQ01@0onCQ2`3=QCl40000o`P0cHDoo`3oon1W0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>40
0`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>402@3oi>42
000000040?oTh@000?l0003o0000o`@0onCQ00<0cHDo0?ooh03oon00o`3oon1U0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo
0?oTh@3oi>403`3oi>440000o`030<f5?`3oon00oooP0?l0oooPI@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ
01<0onCQ0`000?oo0?ooh6D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0
onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oon00oooP00<0
003oo`3oon1R0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5
?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0oooP0?ooh0030?ooh080003o
o`3oon1P0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3o
i>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0oooP0?ooh0050?ooh0<0003oo`3o
on1M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40
onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0oooP0?ooh0080?ooh0<0003o0`3oon02
00000?l0oooPE@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=
QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?ooh03oon002`3oon020000
o`@00000o`3oon1D0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@03
0<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>4@0<f5?`<0003o00<000000<f5?`3=
QCl0503=QCoo0?ooh3h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ
00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ00h0onCQ
0P0000030000oa<0onCQ00<0cHDo0?ooh03oon00o`3oon0l0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3o
i>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3o
i>400`3=QCl0onCQ0?oTh@0C0?oTh@<0003o403oi>400`3=QCl0oooP0?ooh03o0?ooh3`0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oTh@3oi>40503oi>40
0`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ01H0onCQ0P000?l>0?oTh@030<f5?`3oon00
oooP0?l0oooP?03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon030000
00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ
01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0H0?oTh@<0003o2`3oi>400`3=
QCl0oooP0?ooh03o0?ooh3X0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0
onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>406`3oi>430000o`P0
onCQ00<0cHDo0?ooh03oon00o`3oon0l0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ
0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ
0?oTh@0N0?oTh@80003o1P3oi>400`3=QCl0oooP0?ooh03o0?ooh3`0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oT
h@0C0?oTh@030<f5?`3oi>40onCQ0200onCQ0`000?l30?oTh@030<f5?`3oon00oooP0?l0oooP?03o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D
0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>408`3oi>430000o`030<f5?`3oon00
oooP0?l0oooP?03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=
QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>409P3oi>420000
ool0oooP?@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0
onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>409P3oi>401@3=QCl0
oooP0000o`000?l0oooP00800000o`3oon0h0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0
onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0
onCQ0?oTh@0V0?oTh@@0cHDo0P000?l2000001X0cHDoo`3oon0M0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
7@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40
4`3oi>400`3=QCl0onCQ0?oTh@0V0?oTh@040<f5?`3oi>40onCQ0?oTh@8000000P000?lI0?oTh@03
0<f5?`3oon00oooP0?l0oooP6`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>40
9@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40
9P3oi>400`3=QCl0onCQ0?oTh@020?oTh@80000000@0onCQ0000o`000?l0003o5P3oi>400`3=QCl0
oooP0?ooh03o0?ooh1/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ
00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ02H0onCQ
00<0cHDo0?oTh@3oi>40203oi>420000oa@0onCQ00<0cHDo0?ooh03oon00o`3oon0K0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0
cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ00X0onCQ0P00
0?lB0?oTh@030<f5?`3oon00oooP0?l0oooP6`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo
0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo
0?oTh@3oi>409P3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@80003o403oi>400`3=QCl0oooP0?ooh03o
0?ooh1/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oT
h@3oi>40503oi>400`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ02H0onCQ00<0cHDo0?oT
h@3oi>403P3oi>430000o`d0onCQ00<0cHDo0?ooh03oon00o`3oon0K0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3o
i>404`3oi>400`3=QCl0onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ0140onCQ0P000?l;0?oTh@03
0<f5?`3oon00oooP0?l0oooP6`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5
?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0V0?oTh@030<f5
?`3oi>40onCQ01<0onCQ0P000?l90?oTh@030<f5?`3oon00oooP0?l0oooP6@3oon03000001P0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3o
i>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3o
i>400`3=QCl0onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ01D0onCQ0P000?l70?oTh@030<f5?`3o
on00oooP0?l0oooP6`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>40
0`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>409P3oi>40
0`3=QCl0onCQ0?oTh@0G0?oTh@80003o1@3oi>400`3=QCl0oooP0?ooh03o0?ooh1/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=
QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ02H0onCQ00<0cHDo0?oTh@3oi>406@3oi>420000
o`<0onCQ00<0cHDo0?ooh03oon00o`3oon0K0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0
onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0
onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ01/0onCQ0P000?l00`3oi>40cHDo0?ooh03o0?ooh1`0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oTh@3oi>40
503oi>400`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ02H0onCQ00<0cHDo0?oTh@3oi>40
7@3oi>420000ool0oooP7@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3o
i>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>409P3o
i>400`3=QCl0onCQ0?oTh@0N0?oTh@030<f5?`000?l0003o0?l0oooP6`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40
onCQ01<0onCQ00<0cHDo0?oTh@3oi>409P3oi>400`3=QCl0onCQ0?oTh@0N0?oTh@030<f5?`3oon00
oooP0080003oo`3oon0I0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oT
h@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0V0?oT
h@030<f5?`3oi>40onCQ01h0onCQ00<0cHDo0?ooh03oon000P3oon020000o`800000o`3oon0E0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0
onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ01h0
onCQ1P3=QCl010000000003o0000o`0000050<f5?ol0oooP3`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0
onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0
onCQ00<0cHDo0?oTh@3oi>409P3oi>400`3=QCl0onCQ0?oTh@0N0?oTh@030<f5?`3oi>40onCQ00<0
onCQ0`0000020000o`<0onCQ00<0cHDo0?ooh03oon00o`3oon0=0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
7@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40
4`3oi>400`3=QCl0onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ01h0onCQ00<0cHDo0?oTh@3oi>40
103oi>4200000080onCQ00@0003o0?oTh@3oi>40cHDoo`3oon0?0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
7@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40
4`3oi>400`3=QCl0onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ01h0onCQ00<0cHDo0?oTh@3oi>40
2@3oi>420000o`030<f5?`3oon00oooP0?l0oooP3@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0
cHDo0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0
cHDo0?oTh@3oi>409P3oi>400`3=QCl0onCQ0?oTh@0N0?oTh@030<f5?`3oi>40onCQ00/0onCQ0P00
0?oo0?ooh0h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`000009
0?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D
0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>409P3oi>400`3=QCl0onCQ0?oTh@0N
0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?ooh0000?l0o`3oon0;0?ooh0<00000603oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0M0?oT
h@030<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0C0?oT
h@030<f5?`3oi>40onCQ02H0onCQ00<0cHDo0?oTh@3oi>407P3oi>400`3=QCl0onCQ0?oTh@0;0?oT
h@030<f5?`3oon00oooP0080003oo`3oon0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0
onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0
onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ01h0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0
oooP0?ooh0020?ooh080003oo`3oon090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ
0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ
0?oTh@0V0?oTh@030<f5?`3oi>40onCQ01h0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0oooP
0?ooh0040?ooh080003oo`3oon070?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0onCQ0?oT
h@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oT
h@0V0?oTh@030<f5?`3oi>40onCQ01h0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0oooP0?oo
h0060?ooh0030000o`3oon00oooP0?l0oooP103oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo
0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo
0?oTh@3oi>409P3oi>400`3=QCl0onCQ0?oTh@0N0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo
0?ooh03oon001`3oon020000o`030?ooh000000000000?l0oooP0@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ
01<0onCQ00<0cHDo0?oTh@3oi>409P3oi>400`3=QCl0onCQ0?oTh@0N0?oTh@030<f5?`3oi>40onCQ
00/0onCQ303=QCl20000o`800000503=QCo[0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>407@3oi>400`3=QCl0
onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0
onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ01h0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0
onCQ0?oTh@090?oTh@8000000P000?lC0?oTh@030<f5?`3oon00oooP0>T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ
0?oTh@0C0?oTh@030<f5?`3oi>40onCQ02H0onCQ00<0cHDo0?oTh@3oi>407P3oi>400`3=QCl0onCQ
0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00X0onCQ0P0000000`3oi>40003o0?oTh@0A0?oTh@030<f5
?`3oon00oooP0>T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40onCQ02D0onCQ00<0
cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ02H0onCQ00<0
cHDo0?oTh@3oi>407P3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00h0onCQ0P00
0?l@0?oTh@030<f5?`3oon00oooP0>T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0M0?oTh@030<f5?`3oi>40
onCQ02D0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40
onCQ02H0onCQ00<0cHDo0?oTh@3oi>407P3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40
onCQ0100onCQ0P000?l>0?oTh@030<f5?`3oon00oooP0>T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0M0?oT
h@030<f5?`3oi>40onCQ02D0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0C0?oT
h@030<f5?`3oi>40onCQ02H0onCQ00<0cHDo0?oTh@3oi>407P3oi>400`3=QCl0onCQ0?oTh@0;0?oT
h@030<f5?`3oi>40onCQ0180onCQ00<0003o0?oTh@3oi>402`3oi>400`3=QCl0oooP0?ooh03Y0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01d0onCQ00<0cHDo0?oTh@3oi>409@3oi>400`3=QCl0
onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>409P3oi>400`3=QCl0
onCQ0?oTh@0N0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>404`3oi>420000o`/0
onCQ00<0cHDo0?ooh03oon00j@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3o
i>407@3oi>400`3=QCl0onCQ0?oTh@0U0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3o
i>404`3oi>400`3=QCl0onCQ0?oTh@0V0?oTh@030<f5?`3oi>40onCQ01h0onCQ00<0cHDo0?oTh@3o
i>402`3oi>400`3=QCl0onCQ0?oTh@0E0?oTh@80003o2@3oi>400`3=QCl0oooP0?ooh03Y0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0
oooP100000080?ooh>L000000P000?oX000000P0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V
403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?80oooP00<0003o0?ooh03o
on00103oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]
f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000
oooP0?ooh03c0?ooh080003o103oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01H0
[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000
003oon00oooP0?D0oooP00D0003o0?ooh03oon00oooP03>QbP0E0:gHiP0303>QbP2]f>H0[MSV01H0
[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
mP3oon020000o`030?ooh0000000000001@0[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV
0:gHiP0Q0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV
0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03h0?ooh0040000o`00
00000000000001<0[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP0303>Q
bP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>Q
bP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03h0?ooh004000000000?l0003o000001@0<j7:
602]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H0
9@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03i0?ooh080000000<0003o0?ooh03oon004@3oon000`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]
f>H0[MSV0240[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]
f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?`0oooP00<0003o
0?ooh03oon00403oon000`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV0240[MSV00<0<j7:
0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:
0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?d0oooP0P000?l@0?ooh00303>QbP2]f>H0[MSV
01H0[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV
02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon000`000?l0oooP0?ooh00=0?ooh00303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]
f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon010?ooh080003o
3@3oon000`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV0240[MSV00<0<j7:0:gHiP2]f>H0
602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H0
9P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP0`3oon000`000?l0oooP0?ooh00:0?ooh00303>QbP2]
f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]
f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon040?ooh080003o2P3oon000`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0
[MSV0240[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0
[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP1P3oon000`00
0?l0oooP0?ooh0070?ooh00303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0c
XLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0c
XLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh0L0oooP0P000?l70?ooh00303>QbP2]f>H0[MSV01H0
[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00L0
oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0T0oooP
00<0003o0?ooh03oon00103oon000`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV0240[MSV
00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV
00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2P3oon020000o`@0oooP00<0
<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0
<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh0`0oooP00D0003o0?ooh03oon00oooP03>QbP0H0:gHiP0303>QbP2]
f>H0[MSV0240[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]
f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3@3oon02
0000o`030?ooh00cXLX0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H
0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0?0?ooh0030000o`0cXLX0[MSV01L0[MSV00<0<j7:0:gH
iP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gH
iP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@0?ooh080
003o5`2]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]
f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh100oooP00<0<j7:0:gHiP000?l05P2]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP0303>Q
bP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>Q
bP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh100oooP00<0<j7:0:gHiP2]f>H00P00
0?lD0:gHiP0303>QbP2]f>H0[MSV0240[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gH
iP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP403oon000`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV0140[MSV00<0<j7:
0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:
0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@0?oo
h00303>QbP2]f>H0[MSV00<0[MSV0P000?lA0:gHiP0303>QbP2]f>H0[MSV0240[MSV00<0<j7:0:gH
iP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gH
iP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403oon000`0cXLX0[MSV0:gHiP050:gHiP03
0000o`2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP03
03>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0@0?ooh00303>QbP2]f>H0[MSV00H0[MSV0P000?l>0:gHiP0303>Q
bP2]f>H0[MSV0240[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>Q
bP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403o
on000`0cXLX0[MSV0:gHiP080:gHiP030000o`000000000000/0[MSV00<0<j7:0:gHiP2]f>H08@2]
f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]
f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh100oooP2`0cXLX010000000003o0000o`00
000;03>QbR<0[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]
f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0K0?ooh0<0000000<0003o
0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP0Q0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:
0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh1`0oooP0P0000000`3oon00003o0?ooh0080?ooh00303>QbP2]f>H0[MSV
0240[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP803oon020000o`L0
oooP00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0R0?ooh0030000o`3oon00oooP00@0oooP00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV
0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV
0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0S0?ooh0030000o`3oon00oooP00<0oooP00<0
<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0
<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0T
0?ooh080003o0`3oon000`0cXLX0[MSV0:gHiP0Q0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:
0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh2H0oooP00@0003o0?ooh03oon00<j7:8`2]f>H00`0cXLX0[MSV0:gHiP0H
0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0W0?ooh0030000o`3oon00<j7:02<0[MSV00<0<j7:0:gH
iP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gH
iP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:03oon020000ob<0[MSV00<0<j7:0:gHiP2]
f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]
f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:@3oon000`0cXLX0003o0:gHiP0Q0:gHiP0303>Q
bP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>Q
bP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2T0oooP00<0<j7:0:gHiP000?l08@2]
f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]
f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Y0?ooh00303>QbP2]f>H0
[MSV0080003o7`2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:
0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Y0?oo
h00303>QbP2]f>H0[MSV0080[MSV00<0003o0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0H0:gH
iP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP0`00003o0?ooh2T0oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP0K0:gHiP03
03>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP03
03>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:@3oon000`0cXLX0[MSV0:gHiP040:gHiP80003o
6`2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H0
7P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Y0?ooh00303>QbP2]
f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]
f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0Y0?ooh00303>QbP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]f>H05`2]f>H0
0`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H0
0`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Y0?ooh00303>QbP2]f>H0[MSV
00P0[MSV00<0003o0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV
02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0Y0?ooh00303>QbP2]f>H0[MSV00T0[MSV0P000?lF0:gHiP0303>QbP2]f>H0[MSV01P0
[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh2T0oooP00<0<j7:0:gHiP2]f>H02`2]f>H00`000?l0[MSV
0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV
0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2T0oooP00<0
<j7:0:gHiP2]f>H0302]f>H00`000?l0[MSV0:gHiP0B0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0
<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh2T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H20000oa80[MSV00<0<j7:
0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:
0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:@3oon000`0cXLX0[MSV0:gHiP0?0:gH
iP030000o`2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gH
iP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP:@3oon000`0cXLX0[MSV0:gHiP0@0:gHiP030000o`2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]
f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]
f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:@3oon000`0cXLX0[MSV0:gHiP0A0:gHiP030000
o`2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>Q
bP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:@3o
on000`0cXLX0[MSV0:gHiP0B0:gHiP80003o00<000000:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gH
iP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Y0?ooh00303>QbP2]f>H0[MSV0180[MSV0P000000
0`000?l000000:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H0
0`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h2T0oooP5@0cXLX3000000030000o`0cXLX0<j7:00X0<j7:6P2]f>H00`0cXLX0[MSV0:gHiP0U0:gH
iP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0o0?ooh080
000000<0oooP0000o`3oon002@3oon000`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00L0
oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4<0oooP
00<0003o0?ooh03oon001`3oon000`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02D0[MSV
00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on140?ooh0030000o`3oon00oooP00H0oooP00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gH
iP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPA@3oon020000o`H0oooP00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0U
0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPA`3oon000`000?l0oooP0?ooh0030?ooh00303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gH
iP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh4P0oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gHiP0H0:gHiP03
03>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon190?ooh0050000o`3oon00oooP0?ooh00cXLX06P2]f>H00`0cXLX0
[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPBP3oon0010000?l0oooP0?ooh00cXLXJ0:gHiP0303>QbP2]f>H0[MSV02D0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1;0?ooh0030000o`3oon00<j7:01X0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV
0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4`0oooP00<0
003o0000000000006@2]f>H00`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0
<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPC03oon0010000000003o00000000
000I03>QbRL0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1<0?ooh080000000<0003o0000003oon005`3oon000`0cXLX0[MSV0:gHiP0U
0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0D000001P3oon000`00
0000oooP0?ooh03o0?ooh4d0oooP0P0000020000oaL0oooP00<0<j7:0:gHiP2]f>H09@2]f>H00`0c
XLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh003
0000003oon00oooP0?l0oooPD@3oon000`000?l0oooP0?ooh00D0?ooh00303>QbP2]f>H0[MSV02D0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon00
1P3oon0400000?l0oooPD@3oon000`000?l0oooP0?ooh00C0?ooh00303>QbP2]f>H0[MSV02D0[MSV
00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00H0oooP
1000000H0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003o
on00oooP0?l0oooPD`3oon000`000?l0oooP0?ooh00B0?ooh00303>QbP2]f>H0[MSV02D0[MSV00<0
<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon00
0`000000oooP0?ooh03o0?ooh5@0oooP00<0003o0?ooh03oon004@3oon000`0cXLX0[MSV0:gHiP0U
0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`00
0000oooP0?ooh03o0?ooh5D0oooP00<0003o0?ooh03oon00403oon000`0cXLX0[MSV0:gHiP0U0:gH
iP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPEP3oon000`000?l0oooP0?ooh00?0?ooh00303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]
f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1G0?ooh0030000
o`3oon00oooP00h0oooP00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>Q
bP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5P0oooP00<0003o0?ooh03oon003@3o
on000`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPF@3oon020000o`d0oooP00<0<j7:0:gHiP2]f>H09@2]f>H0
0`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h5/0oooP00<0003o0?ooh03oon002P3oon000`0cXLX0[MSV0:gHiP0U0:gHiP0303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPG03oon000`000?l0
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0
[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1M0?ooh0030000o`3oon00oooP00P0oooP
00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh5h0oooP00<0003o0?ooh03oon001`3oon000`0cXLX0[MSV0:gH
iP0U0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPG`3oon000`000?l0oooP0?ooh0060?ooh00303>QbP2]f>H0[MSV02D0[MSV00<0<j7:
0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?oo
h0030000o`3oon00oooP00D0oooP00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gH
iP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPH@3oon000`000?l0oooP0?ooh0040?ooh003
03>QbP2]f>H0[MSV02D0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP03
03>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh680oooP00<0003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gHiP0U0:gHiP0303>Q
bP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH`3o
on020000o`<0oooP00<0<j7:0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]
f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6D0oooP00@0003o0?ooh03oon00<j7:9`2]
f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6H0oooP00<0003o0?ooh00cXLX09`2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0
[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6L0oooP00<0003o03>QbP2]f>H09P2]f>H00`0c
XLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6P0
oooP00<0003o0:gHiP2]f>H09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6P0oooP00<0<j7:0000o`2]f>H09@2]f>H00`0cXLX0[MSV
0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6P0oooP00<0
<j7:0:gHiP000?l09@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh6P0oooP00@0<j7:0:gHiP2]f>H0003o902]f>H00`0cXLX0[MSV0:gH
iP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6P0oooP00D0<j7:
0:gHiP2]f>H0[MSV0000o`0S0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPJ03oon000`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0
[MSV0200[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1X0?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H07`2]f>H00`0c
XLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6P0
oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV01h0
[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ03oon000`0cXLX0[MSV
0:gHiP050:gHiP030000o`2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV
0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh6P0oooP00<0<j7:0:gHiP2]f>H01P2]f>H20000oad0[MSV00<0
<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00L0oooP0`00
000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6P0oooP00<0<j7:
0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP0J0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:
0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ03oon000`0cXLX0[MSV0:gHiP090:gH
iP030000o`2]f>H0[MSV01T0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1X0?ooh00303>QbP2]f>H0[MSV00X0[MSV00<0003o0:gHiP2]
f>H0602]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh6P0oooP00<0<j7:0:gHiP2]f>H02`2]f>H00`000?l0[MSV0:gHiP0G0:gHiP0303>Q
bP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ03o
on000`0cXLX0[MSV0:gHiP0<0:gHiP030000o`2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H07P2]
f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1X0?ooh00303>QbP2]f>H0
[MSV00d0[MSV00<0003o0:gHiP2]f>H05@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0
[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6P0oooP00<0<j7:0:gHiP2]f>H03P2]f>H00`00
0?l0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPJ03oon000`0cXLX0[MSV0:gHiP0?0:gHiP030000o`2]f>H0[MSV01<0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1X0?ooh00303>QbP2]f>H0[MSV0100[MSV00<0003o0:gHiP2]f>H04P2]f>H00`0cXLX0[MSV
0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6P0oooP00<0
<j7:0:gHiP2]f>H04@2]f>H00`000?l0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01h0[MSV00<0
<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ03oon000`0cXLX0[MSV0:gHiP0B
0:gHiP030000o`2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1X0?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0003o0:gH
iP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh6P0oooP00<0<j7:0:gHiP2]f>H0502]f>H00`000?l0[MSV0:gHiP0>0:gHiP03
03>QbP2]f>H0[MSV01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon1X0?ooh00303>Q
bP2]f>H0[MSV01D0[MSV00<0003o0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>Q
bP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPJ03oon000`0cXLX0[MSV0:gHiP0F0:gHiP030000o`2]
f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1X0?ooh00303>QbP2]f>H0[MSV01L0[MSV00<0003o0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h6P0oooP00<0<j7:0:gHiP2]f>H0602]f>H00`000?l0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ03oon000`0cXLX0
[MSV0:gHiP0I0:gHiP030000o`000000000000T0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H00`0cXLX0
[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1X0?ooh00303>QbP2]f>H0[MSV01T0[MSV
00@000000000o`0000000000202]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6P0oooP700cXLX2000000030000o`000000<j7:00P0<j7:
802]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon250?ooh080000000<0
003o0?ooh03oon001P3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh8P0oooP00<0003o0?ooh03oon001@3oon000`0cXLX0[MSV0:gHiP0N
0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8T0oooP00<0003o0?oo
h03oon00103oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh8X0oooP00<0003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gHiP0N0:gHiP03
03>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8/0oooP00<0003o0?ooh03oon00
0P3oon000`0cXLX0[MSV0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh8`0oooP00D0003o0?ooh03oon00oooP03>QbP0P0:gHiP0303>QbP2]f>H0[MSV02H0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8d0oooP00@0003o0?ooh03oon00<j7:802]f>H00`0cXLX0[MSV
0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh8h0oooP00<0003o0?ooh00cXLX0802]f>H00`0cXLX0[MSV0:gH
iP0V0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh8l0oooP00<0003o03>QbP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0V
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2@0?ooh0030000o`2]f>H0[MSV01h0[MSV00<0<j7:0:gH
iP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT03oon000`0cXLX0003o0:gHiP0N0:gHiP03
03>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh900oooP00<0<j7:0:gHiP000?l0
7P2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2@0?ooh00303>QbP2]
f>H0003o01h0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT03oon00
100cXLX0[MSV0:gHiP000?lM0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh900oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0L0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh900oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP0I
0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh900oooP00<0<j7:0:gH
iP2]f>H00`2]f>H00`000?l0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh900oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP0G0:gHiP03
03>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh900oooP00<0<j7:0:gHiP2]f>H0
1@2]f>H00`000?l0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh900oooP00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gHiP0E0:gHiP0303>QbP2]
f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V403oon04000000L0oooP00<000000?ooh03oon00o`3oon2@0?ooh00303>QbP2]f>H0
[MSV00L0[MSV00<0003o0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00<000000?oo
h03oon00203oon000`000000oooP0?ooh03o0?ooh900oooP00<0<j7:0:gHiP2]f>H0202]f>H00`00
0?l0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon000`000000oooP0?ooh0070?ooh0@0
0000o`3oon2?0?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V
4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPT03oon000`0cXLX0[MSV
0:gHiP090:gHiP030000o`2]f>H0[MSV0180[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003o
on00oooP000000L0oooP00<000000?ooh03oon00o`3oon2@0?ooh00303>QbP2]f>H0[MSV00X0[MSV
00<0003o0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003o
on00oooP0?l0oooPT03oon000`0cXLX0[MSV0:gHiP0;0:gHiP030000o`2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT03oon000`0cXLX0[MSV0:gHiP0<
0:gHiP030000o`2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPT03oon000`0cXLX0[MSV0:gHiP0=0:gHiP030000o`2]f>H0[MSV00h0[MSV00<0<j7:0:gH
iP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT03oon000`0cXLX0[MSV0:gHiP0>0:gHiP03
0000o`000000000000d0[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
T03oon0A03>QbP04000000000?l00000000000d0<j7::02]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
X@3oon02000000030000o`000000oooP00/0oooP00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPXP3oon02000000030000o`3oon00oooP00X0oooP00<0<j7:0:gHiP2]f>H09P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPY@3oon000`000?l0oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:H0oooP00<0003o0?ooh03oon00203oon000`0c
XLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2W0?ooh0030000o`3oon00oooP00L0
oooP00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ03oon000`000?l0oooP
0?ooh0060?ooh00303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPZ@3oon000`000?l0oooP0?oo
h0050?ooh00303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZP3oon000`000?l0oooP0?ooh004
0?ooh00303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP00<0003o0?oo
h03oon00103oon000`0cXLX0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2[0?ooh003
0000o`3oon00oooP00<0oooP00<0<j7:0:gHiP2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
[03oon000`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV02H0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh:d0oooP00D0003o0?ooh03oon00oooP03>QbP0X0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2^0?ooh0040000o`3oon00oooP03>QbRP0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:l0oooP00<0
003o0?ooh00cXLX0:02]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/03oon000`000?l0<j7:0:gHiP0W
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh0030000o`2]f>H0[MSV02H0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh;40oooP00<0<j7:0000o`2]f>H09P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
/@3oon000`0cXLX0[MSV0000o`0V0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh00403>QbP2]
f>H0[MSV0000obD0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP00D0<j7:0:gHiP2]f>H0[MSV
0000o`0T0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh;40oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gH
iP0Q0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;40oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP0P
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0003o0:gH
iP2]f>H0802]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon000`0cXLX0[MSV0:gHiP040:gHiP03
0000o`2]f>H0[MSV01l0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP00<0<j7:0:gHiP2]f>H0
1@2]f>H00`000?l0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh00303>QbP2]
f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon00
0`0cXLX0[MSV0:gHiP070:gHiP030000o`2]f>H0[MSV01`0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;40oooP00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP0K0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2a0?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H06`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP/@3oon000`0cXLX0[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV01X0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;40oooP00<0<j7:0:gHiP2]f>H02P2]f>H00`000?l0[MSV0:gH
iP0I0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0003o
0:gHiP2]f>H0602]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon000`0cXLX0[MSV0:gHiP0<0:gH
iP030000o`2]f>H0[MSV01L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP00<0<j7:0:gHiP2]
f>H03@2]f>H00`000?l0[MSV0:gHiP0F0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh00303>Q
bP2]f>H0[MSV00d0[MSV00<0003o0:gHiP2]f>H05P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2a0?ooh00303>QbP2]
f>H0[MSV00h0[MSV00<0003o0:gHiP2]f>H05@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh00303>QbP2]f>H0
[MSV00l0[MSV00<0003o0:gHiP2]f>H0502]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon000`0c
XLX0[MSV0:gHiP0@0:gHiP030000o`2]f>H0[MSV01<0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40
oooP00<0<j7:0:gHiP2]f>H04@2]f>H00`000?l0[MSV0:gHiP0B0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2a0?ooh00303>QbP2]f>H0[MSV0180[MSV00<0003o0:gHiP2]f>H04@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP/@3oon000`0cXLX0[MSV0:gHiP0B0:gHiP030000o`2]f>H0[MSV0140[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;40oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`000?l0[MSV0:gHiP0@
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh00303>QbP2]f>H0[MSV01@0[MSV00<0003o0:gH
iP2]f>H03`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon000`0cXLX0[MSV0:gHiP0E0:gHiP03
0000o`2]f>H0[MSV00h0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP00<0<j7:0:gHiP2]f>H0
5P2]f>H00`000?l0[MSV0:gHiP0=0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh00303>QbP2]
f>H0[MSV01L0[MSV00<0003o0:gHiP2]f>H0302]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon00
0`0cXLX0[MSV0:gHiP0G0:gHiP030000o`2]f>H0[MSV00`0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;40oooP00<0<j7:0:gHiP2]f>H0602]f>H00`000?l0[MSV0:gHiP0;0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2a0?ooh00303>QbP2]f>H0[MSV01T0[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000
o`3oon2a0?ooh00303>QbP2]f>H0[MSV01X0[MSV00<0003o0:gHiP2]f>H02@2]f>H00`0cXLX0oooP
0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2a0?ooh00303>QbP2]f>H0[MSV01/0[MSV00<0003o0:gHiP2]f>H0202]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP/@3oon000`0cXLX0[MSV0:gHiP0L0:gHiP030000o`2]f>H0[MSV00L0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh;40oooP00<0<j7:0:gHiP2]f>H07@2]f>H00`000?l0[MSV0:gHiP060:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2a0?ooh00303>QbP2]f>H0[MSV01d0[MSV00<0003o0:gHiP2]
f>H01P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon000`0cXLX0[MSV0:gHiP0N0:gHiP030000
o`2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP00<0<j7:0:gHiP2]f>H07`2]
f>H00`000?l0[MSV0:gHiP040:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh00303>QbP2]f>H0
[MSV0200[MSV00<0003o0:gHiP2]f>H00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon000`0c
XLX0[MSV0:gHiP0Q0:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40
oooP00<0<j7:0:gHiP2]f>H08P2]f>H01@000?l0[MSV0:gHiP2]f>H0<j7:00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh003
03>QbP2]f>H0[MSV02<0[MSV00@0003o0000002]f>H0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP9@0cXLX01@000000
003o000000000000<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40
oooP0P0000080?ooh0030000003oon00oooP0?l0oooPeP3oon02000000030000o`000000oooP00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon00
00001`3oon000`000000oooP0?ooh03o0?ooh=L0oooP0P0000000`000?l0oooP0?ooh00:0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP
1000003o0?ooh=T0oooP00<0003o0?ooh03oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3j
l>HC0?ooh0030000003oon00oooP00D0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<0
00000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA
0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03o
on00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00=`0n_3V100000020?[`iPP000000P3jl>H4000000070?[`iP000000
00000000003jl>H000000?[`iP0<000000030?[`iP000000000000@0000000@0n_3V000000000000
0000203jl>H5000000@0n_3V1`0000000`3jl>H000000?[`iP03000000T0n_3V1@0000020?[`iP@0
00000P3jl>H500000180n_3V1P0000060?[`iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H0
000000000000003T0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP80
00000`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0
n_3V0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H0
0P00000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V
00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P00
00000`3jl>H00000000000040?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H000000?[`
iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000d0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H00000
0?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000<0?[`iPD00000
1@3jl>H2000000H0n_3V1@0000060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H5000000@0n_3V0P00
00030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<0
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<0
00000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`
iP3jl>H01P3jl>H300000>H0n_3V0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0
n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`000004
0?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P00
00030?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP0B0?[`iP800000203j
l>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H2
00000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H0000000000005
00000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V
0000000000001`00000;0?[`iPD000000P3jl>H400000080n_3V0`0000000`3jl>H000000000000C
0?[`iP8000003`3jl>H3000000050?[`iP00000000000000003jl>H01000003O0?[`iP40oooo003M
0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V01P0n_3V0P00000Q
0?[`iP@00000603jl>H00`000000n_3V0?[`iP3O0?[`iP40oooo003L0?[`iPH00000103jl>H20000
02l0n_3V1@00000K0?[`iP<000008@3jl>H2000001T0n_3V00<000000?[`iP3jl>H0gP3jl>H10?oo
o`00o`3jl>Ih0?[`iP030000003jl>H0n_3V0=d0n_3V0@3oool00?l0n_3VM@3jl>H010000000n_3V
0?[`iP00003O0?[`iP40oooo003o0?[`iWH0n_3V0P00003P0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01504 L
.0951 .01504 L
.0951 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01504 L
.0951 .01504 L
.0951 .16187 L
s
1 .894 .882 r
.0951 .16187 m
.0951 .02622 L
.16661 .02622 L
.16661 .16187 L
F
.804 .522 .247 r
.0951 .16187 m
.0951 .02622 L
.16661 .02622 L
.16661 .16187 L
s
1 .894 .882 r
.16661 .16187 m
.16661 .02949 L
.20052 .02949 L
.20052 .16187 L
F
.804 .522 .247 r
.16661 .16187 m
.16661 .02949 L
.20052 .02949 L
.20052 .16187 L
s
1 .894 .882 r
.20052 .16187 m
.20052 .04673 L
.24874 .04673 L
.24874 .16187 L
F
.804 .522 .247 r
.20052 .16187 m
.20052 .04673 L
.24874 .04673 L
.24874 .16187 L
s
1 .894 .882 r
.24874 .16187 m
.24874 .05066 L
.28133 .05066 L
.28133 .16187 L
F
.804 .522 .247 r
.24874 .16187 m
.24874 .05066 L
.28133 .05066 L
.28133 .16187 L
s
1 .894 .882 r
.28133 .16187 m
.28133 .07238 L
.32824 .07238 L
.32824 .16187 L
F
.804 .522 .247 r
.28133 .16187 m
.28133 .07238 L
.32824 .07238 L
.32824 .16187 L
s
1 .894 .882 r
.32824 .16187 m
.32824 .0909 L
.36681 .0909 L
.36681 .16187 L
F
.804 .522 .247 r
.32824 .16187 m
.32824 .0909 L
.36681 .0909 L
.36681 .16187 L
s
1 .894 .882 r
.36681 .16187 m
.36681 .10304 L
.43049 .10304 L
.43049 .16187 L
F
.804 .522 .247 r
.36681 .16187 m
.36681 .10304 L
.43049 .10304 L
.43049 .16187 L
s
1 .894 .882 r
.43049 .16187 m
.43049 .12391 L
.46655 .12391 L
.46655 .16187 L
F
.804 .522 .247 r
.43049 .16187 m
.43049 .12391 L
.46655 .12391 L
.46655 .16187 L
s
1 .894 .882 r
.46655 .16187 m
.46655 .147 L
.49109 .147 L
.49109 .16187 L
F
.804 .522 .247 r
.46655 .16187 m
.46655 .147 L
.49109 .147 L
.49109 .16187 L
s
.678 .847 .902 r
.49109 .16187 m
.49109 .175 L
.53686 .175 L
.53686 .16187 L
F
.2 .63 .79 r
.49109 .16187 m
.49109 .175 L
.53686 .175 L
.53686 .16187 L
s
.678 .847 .902 r
.53686 .16187 m
.53686 .19497 L
.56166 .19497 L
.56166 .16187 L
F
.2 .63 .79 r
.53686 .16187 m
.53686 .19497 L
.56166 .19497 L
.56166 .16187 L
s
.678 .847 .902 r
.56166 .16187 m
.56166 .23668 L
.61995 .23668 L
.61995 .16187 L
F
.2 .63 .79 r
.56166 .16187 m
.56166 .23668 L
.61995 .23668 L
.61995 .16187 L
s
.678 .847 .902 r
.61995 .16187 m
.61995 .25771 L
.67333 .25771 L
.67333 .16187 L
F
.2 .63 .79 r
.61995 .16187 m
.61995 .25771 L
.67333 .25771 L
.67333 .16187 L
s
.678 .847 .902 r
.67333 .16187 m
.67333 .29365 L
.71062 .29365 L
.71062 .16187 L
F
.2 .63 .79 r
.67333 .16187 m
.67333 .29365 L
.71062 .29365 L
.71062 .16187 L
s
.678 .847 .902 r
.71062 .16187 m
.71062 .34215 L
.7579 .34215 L
.7579 .16187 L
F
.2 .63 .79 r
.71062 .16187 m
.71062 .34215 L
.7579 .34215 L
.7579 .16187 L
s
.678 .847 .902 r
.7579 .16187 m
.7579 .36706 L
.79707 .36706 L
.79707 .16187 L
F
.2 .63 .79 r
.7579 .16187 m
.7579 .36706 L
.79707 .36706 L
.79707 .16187 L
s
.678 .847 .902 r
.79707 .16187 m
.79707 .4377 L
.84886 .4377 L
.84886 .16187 L
F
.2 .63 .79 r
.79707 .16187 m
.79707 .4377 L
.84886 .4377 L
.84886 .16187 L
s
.678 .847 .902 r
.84886 .16187 m
.84886 .51425 L
.91061 .51425 L
.91061 .16187 L
F
.2 .63 .79 r
.84886 .16187 m
.84886 .51425 L
.91061 .51425 L
.91061 .16187 L
s
.678 .847 .902 r
.91061 .16187 m
.91061 .60185 L
.97619 .60185 L
.97619 .16187 L
F
.2 .63 .79 r
.91061 .16187 m
.91061 .60185 L
.97619 .60185 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.04628 .01504 Mdot
.15694 .02622 Mdot
.17472 .02949 Mdot
.24591 .04673 Mdot
.25917 .05066 Mdot
.32192 .07238 Mdot
.36646 .0909 Mdot
.39273 .10304 Mdot
.43401 .12391 Mdot
.47531 .147 Mdot
.52079 .175 Mdot
.55085 .19497 Mdot
.60865 .23668 Mdot
.63573 .25771 Mdot
.67942 .29365 Mdot
.73414 .34215 Mdot
.76067 .36706 Mdot
.83116 .4377 Mdot
.90118 .51425 Mdot
.975 .60185 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.150173) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.728215) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000H0n_3V0P0000030?[`iPD000000`3jl>H3000000<0n_3V1@0000020?[`iPH0
00000P3jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP8000001P3j
l>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000000000000P3jl>H2000000L0n_3V0P00
00030?[`iP030000003jl>H0n_3V00800000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V
000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H010000002
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
000H0?[`iP80000000<0n_3V0000000000002`3jl>H2000000@0n_3V0P0000040?[`iP80000000<0
n_3V0000000000000`3jl>H2000000H0n_3V0P0000060?[`iP800000o`3jl>JL0?[`iP40oooo000P
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002`3jl>H2000000D0
n_3V0P0000030?[`iP80000000<0n_3V000000000000103jl>H2000000D0n_3V0P0000060?[`iP80
0000o`3jl>JL0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V
000000000000303jl>H2000000D0n_3V0P0000030?[`iP<000001P3jl>H2000000@0n_3V0P000003
0?[`iP030000003jl>H0n_3V00800000o`3jl>JL0?[`iP40oooo000P0?[`iP8000000P3jl>H20000
00030?[`iP000000000000800000103jl>H4000000030?[`iP000000000000D000000P3jl>H40000
0080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H00000000000070000
01T0n_3V0P0000000`3jl>H000000000000<0?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H20000
00<0n_3V1000003o0?[`iYd0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0
n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000T0n_3V00<000000?[`iP3j
l>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP@000000`3jl>H200000?l0n_3VW`3jl>H10?ooo`00
7`3jl>H6000000@0n_3V0P00000_0?[`iPD00000:03jl>H3000000X0n_3V1@0000030?[`iP<00000
103jl>H3000000@0n_3V0`0000050?[`iP8000000`3jl>H500000?l0n_3VW03jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@0
0000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803j
l>H6000000050?[`iP00000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V
0P000000103jl>H000000000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0
n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0
n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000
0P3jl>H010000000n_3V0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`
iP800000103jl>H200000080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3j
l>H00000000000030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP80
0000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080
n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H200000003
0?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V
0P0000000`3jl>H00000000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V
0P0000020?[`iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`
iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P00
00000`3jl>H00000000000020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000
003jl>H300000080n_3V0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V
0P0000000`3jl>H00000000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@00000
0`3jl>H4000000H0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3j
l>H5000000<0n_3V100000030?[`iP80000000<0n_3V000000000000100000000`3jl>H000000000
00020?[`iP@00000103jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3j
l>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3o
ool00280n_3V0P00000;0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:
0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<00000
0?[`iP3jl>H00P00003o0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H40000
0340n_3V0`00000<0?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H30000
0080n_3V1@00003o0?[`iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V
00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP00
0000n_3V0P0000020?[`iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200
n_3V0`0000000`3jl>H0000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`
iP030000003jl>H0000001P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`
iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000
000000P0n_3V100000000`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP000000
00000000003jl>H000000?[`iP03000001P0n_3V0`0000040?[`iP800000103jl>H600000080n_3V
0`0000040?[`iP<000000`3jl>H6000000<0n_3V0P0000040?[`iP<00000N@3jl>H10?ooo`008@3j
l>H2000000030?[`iP000000000000D0000000@0n_3V00000000000000000P3jl>H2000000030?[`
iP000000000000T0n_3V1@0000090?[`iP800000g`3jl>H2000000@0n_3V0P0000020?[`iP800000
0P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080
n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3j
l>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3j
l>H00000000000030?[`iP8000001P3jl>H2000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`
iP80000000<0n_3V000000000000103jl>H2000000D0n_3V0P0000030?[`iP030000003jl>H0n_3V
00800000N03jl>H10?ooo`008P3jl>H3000002T0n_3V0P00003N0?[`iP800000103jl>H200000080
n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H0
0000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000
003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002`3jl>H2000000H0n_3V0P0000020?[`
iP80000000<0n_3V000000000000103jl>H2000000D0n_3V0P0000060?[`iP800000N03jl>H10?oo
o`008P3jl>H3000001X0n_3V1@00000;0?[`iP800000g@3jl>H4000000<0n_3V1@0000020?[`iP80
00001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H00000000000000000n_3V
008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`
iPD000002P3jl>H2000000030?[`iP000000000000/0n_3V0P0000060?[`iP8000000P3jl>H20000
00030?[`iP000000000000@0n_3V0P0000050?[`iP8000001P3jl>H2000007P0n_3V0@3oool00240
n_3V0P0000000`3jl>H000000000000Z0?[`iP800000g03jl>H2000000030?[`iP000000000000D0
n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H20000
00H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`
iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000
n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002`3jl>H2
000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V000000000000103jl>H2
000000H0n_3V0P0000030?[`iP<00000N@3jl>H10?ooo`00803jl>H3000000040?[`iP0000000000
000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H4
00000080n_3V0`000000103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3j
l>H4000000@0n_3V100000020?[`iPD000002`3jl>H3000000030?[`iP00000000000080n_3V1000
00020?[`iP<0000000<0n_3V0000000000001`00000I0?[`iP80000000<0n_3V0000000000002`3j
l>H2000000<0n_3V100000030?[`iP80000000<0n_3V000000000000103jl>H2000000H0n_3V0P00
00050?[`iP800000N03jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`iP800000;P3jl>H2
000000030?[`iP000000000000T0n_3V100000030?[`iP8000001@3jl>H2000000030?[`iP000000
00000080n_3V100000030?[`iP030000003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`iP02
000007P0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`
iP8000001P3jl>H2000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000<0?[`
iP8000000`3jl>H5000000<0n_3V0`0000050?[`iP8000000`3jl>H5000000<0n_3V0`00001i0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS
0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`iP0000000P3jl>H010000000n_3V0?[`iP00
00020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V
0000000000000P000000103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V00000080n_3V
00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V
1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V000000000000
1P00000J0?[`iPD000000`3jl>H300000<40n_3V0@3oool00240n_3V0P0000000`3jl>H000000000
0005000000050?[`iP00000000000000003jl>H01000000;0?[`iPD000002@3jl>H2000000030?[`
iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP800000
0P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P000002
0?[`iP8000002`3jl>H5000000T0n_3V0P0000050?[`iP80000000<0n_3V000000000000`03jl>H1
0?ooo`008P3jl>H3000002P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H20000
0080n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000J0?[`
iP800000103jl>H2000000030?[`iP00000000000<00n_3V0@3oool00280n_3V0`0000090?[`iP03
0000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H4000000<0
n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP@000003@3jl>H50000
00/0n_3V0P0000030?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`008@3jl>H200000003
0?[`iP000000000002L0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V00000000
00001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`
iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP0000000000
0?[`iP8000000P3jl>H2000001`0n_3V0P0000020?[`iP80000000<0n_3V000000000000`03jl>H1
0?ooo`00803jl>H3000000040?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000003L
0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003j
l>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000000`3j
l>H5000001T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000`03j
l>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@
0?[`iP800000303jl>H2000003P0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
000000000000`03jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H20000
00@0n_3V0P0000060?[`iP800000<@3jl>H3000000@0n_3V0`0000310?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`007@3jl>HV0?ooh0800000K03oon02
000000@0oooP0P0000040?ooh0800000J`3oon05000006T0oooP1@0000020?ooh0800000103oon02
000006/0oooP1000000S0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z
0?ooh0040000003oon00oooP000000P0oooP00@000000?ooh03oon000000K03oon000`000000oooP
0?ooh01[0?ooh0030000003oon00oooP00L0oooP00@000000?ooh03oon000000JP3oon000`000000
oooP0?ooh00T0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh004
0000003oon00oooP000000/0oooP00<000000?ooh03oon00JP3oon000`000000oooP0?ooh01[0?oo
h0030000003oon00oooP00X0oooP00<000000?ooh03oon00J@3oon000`000000oooP0?ooh00S0?oo
h1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP
000000T0oooP0P00001]0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon00203oon02
000006d0oooP00<000000?ooh03oon008P3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?oo
h03oon000000JP3oon0010000000oooP0?ooh00000090?ooh0030000003oon00oooP06`0oooP00<0
00000?ooh03oon00J`3oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP06X0oooP00@0
00000?ooh03oon0000008`3oon0N0?[`iP40oooo000M0?[`iRH0oooP0P00001/0?ooh08000002P3o
on03000006/0oooP0P00001/0?ooh08000002P3oon03000006/0oooP0P00000T0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`iQ/0oooPo`00003Z000001P0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>H@0?ooh0D000001P3oon000`000000oooP0?ooh00C0?ooh0800000o`3oon3A0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<00000
0?ooh03oon004P3oon0400000?l0oooPd03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000203oon0J0000o`X0cHDoo`3oon2f0?oo
h0@00000603oon0N0?[`iP40oooo000M0?[`iPX0oooP100000040?ooh0030000003oon00oooP00H0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@070?oTh@8000003P3oi>480000o`03
0?oTh@3=QCl0oooP0?l0oooP^03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
7`3oi>4:0000ool0oooP/@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3o
on02000000P0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3o
on00oooP00H0oooP2@000?oo0?ooh:P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oon00
oooP00l0oooP20000?l30?ooh0800000o`3oon2K0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40803oi>4J0<f5
?`D0003o00@000000<f5?`3=QCl0cHDo0`3oon0200000?l0oooPTP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
0200onCQ00<0cHDo0?oTh@3oi>406@3oi>43000000D0003o00<0oooP0000000000000P00003o0?oo
h940oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01X0onCQ0P0000030?oTh@80
cHDo1@000?l;0<f5?ol0oooPQP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40
7`3oi>40103=QCl0onCQ0?oTh@3oi>42000000030?oTh@000?l0003o00<0003o1@3oi>400`3=QCl0
oooP0?ooh03o0?ooh8@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ
00<0cHDo0?oTh@3oi>402@3oi>450000o`030<f5?`3oon00oooP0?l0oooPQ03oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ0200onCQ00<0cHDo0?oTh@3oi>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@@0003oo`3o
on230?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40
onCQ00h0onCQ00@0cHDo0?ooh03oon00oooP1@000?oo0?ooh7h0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P
0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0oooP0?ooh006
0?ooh0@0003oo`3oon1j0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oT
h@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?ooh03oon002P3oon040000ool0oooPMP3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3o
i>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?ooh03o
on003P3oon030000o`80oooP0P00003o0?ooh6d0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40
7`3oi>400`3=QCl0onCQ0?oTh@0>0?oThA@0cHDo10000?l00`000000oooP0?ooh03o0?ooh6`0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3o
i>400`3=QCl0onCQ0?oTh@0B0?oTh@<000000`000?l00`3oon0000000000003o0?ooh6T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>40
0`3=QCl0onCQ0?oTh@0C0?oTh@8000000`3=QCl40000o`T0cHDoo`3oon1O0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oT
h@3oi>40503oi>40103=QCl0onCQ0?oTh@3oi>44000000<0003o1@3oi>400`3=QCl0oooP0?ooh03o
0?ooh5d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oT
h@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ0080onCQ0P0000040?oT
h@<0003o0P3oi>400`3=QCl0oooP0?ooh03o0?ooh5d0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@03
0<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@03
0<f5?`3oi>40onCQ00/0onCQ0P000?l00`3=QCl0oooP0?ooh03o0?ooh5d0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ
0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ0`000?oo0?ooh5d0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oT
h@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?ooh03oon000`000?oo0?ooh5X0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>40
0`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?ooh03oon000`3oon02
0000ool0oooPF03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>407`3oi>400`3=
QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=
QCl0oooP0?ooh0050?ooh0<0003oo`3oon1E0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0
onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0
onCQ0?oTh@0=0?oTh@030<f5?`3oon00oooP00P0oooP0`000?oo0?ooh580oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ
0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?ooh03oon002`3oon030000o`<0oooP
0P00003o0?ooh4X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0
cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0
cHDo0?ooh03oon003P3oon020000o`@00000o`3oon190?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40
onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40
onCQ00d0onCQ4`3=QCl30000o`030000003=QCl0oooP0?l0oooPA@3oon03000001P0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40803oi>400`3=
QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=
QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ0140onCQ0P0000030000ool0oooPA`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@03
0<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@04
0<f5?`3oon00003o0000ool0oooPA@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3o
i>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3o
i>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@040<f5?`3oon00oooP0?ooh0<0003oo`3oon120?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0
onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0
onCQ00<0cHDo0?ooh03oon00103oon030000ool0oooP?`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ
00<0cHDo0?oTh@3oi>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01@0onCQ
00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oon00oooP00L0oooP
0P000?oo0?ooh3d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0
cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0
cHDo0?oTh@3oi>40503oi>400`3=QCl0oooP0?ooh0090?ooh080003oo`3oon0k0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo
0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo
0?ooh03oon002`3oon020000o`80oooP0P00003o0?ooh3D0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oT
h@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oT
h@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0oooP0?ooh00=0?oo
h080003o0`00003o0?ooh3@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0
onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0
onCQ00<0cHDo0?oTh@3oi>40503oi>4A0<f5?`04000000000?l0003o0000ool0oooP=03oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@03
0<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@03
0<f5?`3oi>40onCQ00l0onCQ0P0000000`3oon00003o0000o`3o0?ooh380oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ
0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ
0?oTh@0@0?oTh@040<f5?`3oon00oooP0?ooh080003oo`3oon0`0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40
503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40
403oi>400`3=QCl0oooP0?ooh0030?ooh080003oo`3oon0^0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40803o
i>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40503o
i>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40403o
i>400`3=QCl0oooP0?ooh0050?ooh0<0003o00<0oooP000000000000o`3oon0X0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo
0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo
0?oTh@3oi>40403oi>400`3=QCl0oooP0?ooh0080?ooh080003o0P00003o0?ooh2L0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ
0200onCQ00<0cHDo0?oTh@3oi>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ
01@0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ
0100onCQ2`3=QCl200000080003o4@3=QCoo0?ooh1@0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3o
i>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3o
i>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3o
i>402@3oi>42000000030?oTh@000?l0003o00h0onCQ00<0cHDo0?ooh03oon00o`3oon0D0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ
00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ
00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0>0?oTh@80003o303oi>400`3=QCl0oooP
0?ooh03o0?ooh1@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0
cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0
cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ0100onCQ0P00
0?l:0?oTh@030<f5?`3oon00oooP0?l0oooP503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo
0?oTh@3oi>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo
0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo
0?oTh@3oi>404P3oi>420000o`P0onCQ00<0cHDo0?ooh03oon00o`3oon0D0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oT
h@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oT
h@3oi>40403oi>400`3=QCl0onCQ0?oTh@0D0?oTh@80003o1P3oi>400`3=QCl0oooP0?ooh03o0?oo
h1@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3o
i>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3o
i>40503oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ01H0onCQ0P000?l40?oTh@03
0<f5?`3oon00oooP0?l0oooP503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>40
7`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40
3@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40
603oi>420000o`80onCQ00<0cHDo0?ooh03oon00o`3oon0D0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40803o
i>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40503o
i>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40403o
i>400`3=QCl0onCQ0?oTh@0J0?oTh@80003o00<0cHDo000000000000o`3oon0D0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo
0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo
0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0L0?oTh@80003o0P00003o0?ooh1<0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=
QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=
QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ01`0onCQ0P0000020000o`l0cHDoo`3oon040?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0
onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0
onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0L0?oTh@050<f5?`00000000000?oT
h@000?l03@3oi>400`3=QCl0oooP0?ooh03o0?ooh080oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@03
0<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@03
0<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0@0?oTh@03
0<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oTh@3oi>400P3oi>420000o`/0onCQ00<0cHDo0?ooh03o
on00o`3oon020?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5
?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5
?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5
?`3oi>40onCQ00@0onCQ0P000?l90?oTh@030<f5?`3oon00oooP0?l0oooP0P3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>40803o
i>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40503o
i>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40403o
i>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0003o0?oTh@3oi>401P3o
i>400`3=QCl0oooP0?ooh03o0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo
0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo
0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo
0?oTh@3oi>401`3oi>420000o`H0onCQ00<0cHDo0?ooh03oon00o`3oon020?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oT
h@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oT
h@3oi>40403oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ00T0onCQ0P000?l40?oT
h@030<f5?`3oon00oooP0?l0oooP0P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3o
i>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3o
i>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3o
i>40703oi>400`3=QCl0onCQ0?oTh@0;0?oTh@80003o0P3oi>400`3=QCl0oooP0?ooh03o0?ooh080
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>40
3P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40
503oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oTh@3oi>40
3@3oi>400`000?l0onCQ0<f5?`3o0?ooh0@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0P0?oTh@030<f5?`3o
i>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3o
i>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3o
i>40onCQ01`0onCQ00<0cHDo0?oTh@3oi>403P3oi>420000ool0oooP103oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ0200onCQ00<0cHDo0?oTh@3oi>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40
onCQ01@0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40
onCQ0100onCQ00<0cHDo0?oTh@3oi>40703oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`000?l0
003o00800000o`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>407`3oi>400`3=
QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=
QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40703oi>400`3=
QCl0onCQ0?oTh@0?0?oTh@80cHDo00@000000000o`000?l000001`3=QCog0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>40803oi>400`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oT
h@3oi>40503oi>400`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oT
h@3oi>40403oi>400`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oT
h@0000000P0000000`000?l0onCQ0?oTh@040?oTh@030<f5?`3oon00oooP0?D0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0
onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0
onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0
onCQ0?oTh@02000000030?oTh@000?l0003o00@0onCQ00<0cHDo0?ooh03oon00m@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ0200onCQ00<0cHDo0?oTh@3oi>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5
?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5
?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40703oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5
?`3oi>40onCQ00D0onCQ0P000?l20?oTh@030<f5?`3oon00oooP0?D0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@0P0?oTh@030<f5?`3oi>40onCQ01l0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oT
h@0D0?oTh@030<f5?`3oi>40onCQ00d0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oT
h@0@0?oTh@030<f5?`3oi>40onCQ01`0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oT
h@070?oTh@030000o`3oi>40cHDo0?L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40803oi>40
0`3=QCl0onCQ0?oTh@0O0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40503oi>40
0`3=QCl0onCQ0?oTh@0=0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40403oi>40
0`3=QCl0onCQ0?oTh@0L0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203oi>42
0000ooL0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?oo
h03oon0000001`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ0200onCQ00<0cHDo
0?oTh@3oi>407`3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo
0?oTh@3oi>403@3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo
0?oTh@3oi>40703oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo
0000o`000?l0m@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon001000
0000oooP0?ooh00000070?ooh0@00000203oon3W00000080003oj00000080?ooh0@00000603oon0N
0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03]
0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV01T0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@
0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F
0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP
000000L0oooP00<000000?ooh03oon00k@3oon000`0cXLX0[MSV0:gHiP030:gHiP80003o3P2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV01T0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H0
0`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H0
0`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?oo
h0800000203oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV00D0[MSV00<0003o0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV01T0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gH
iP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gH
iP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H01P2]f>H20000o`/0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0I0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03]0?ooh00303>QbP2]f>H0[MSV00P0[MSV00@0003o0:gHiP000000
00001`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV01T0[MSV00<0<j7:0:gHiP2]
f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]
f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]
f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0>d0oooP00<0<j7:0:gHiP2]f>H02@2]f>H20000o`800000
1P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV01T0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H0
7@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0>d0oooP300cXLX2000000030000o`000000<j7:00H0<j7:2`2]
f>H00`0cXLX0[MSV0:gHiP0I0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]
f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03j
0?ooh080000000<0003o0?ooh03oon00103oon000`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV01T0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0
[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0
[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?d0oooP0P000?l40?oo
h00303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H06@2]f>H00`0cXLX0[MSV0:gHiP0G0:gH
iP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gH
iP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon001@000?l0oooP0?ooh03oon00<j7:00/0[MSV00<0<j7:0:gH
iP2]f>H06@2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gH
iP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon010?ooh080
003o00<0oooP03>QbP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0I0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0<0oooP00<0003o03>QbP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP0I0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV
0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV
0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0@0oooP0P00
0?l:0:gHiP0303>QbP2]f>H0[MSV01T0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gH
iP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gH
iP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP103oon000`0cXLX0[MSV0000o`090:gHiP0303>QbP2]f>H0[MSV01T0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:
0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon040?ooh00303>QbP2]f>H0[MSV0080003o00<0[MSV0000
00000000102]f>H00`0cXLX0[MSV0:gHiP0I0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gH
iP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?oo
h03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP103oon0503>QbP040000o`0000000000000000@0<j7:6`2]f>H00`0cXLX0[MSV0:gHiP0G0:gH
iP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gH
iP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon090?ooh004000000000?l0003o000000<0oooP00<0<j7:0:gH
iP2]f>H06@2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gH
iP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0:0?ooh080
000000D0003o0?ooh03oon00oooP03>QbP0K0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gH
iP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh0d0oooP0P000?l00`3oon00<j7:0:gHiP0J0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0l0oooP00<0003o03>QbP2]f>H06P2]f>H00`0cXLX0[MSV
0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV
0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV
0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@0?ooh080003o6P2]f>H00`0cXLX0[MSV0:gH
iP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gH
iP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gH
iP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@0?ooh00303>QbP2]f>H0003o01T0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:
0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403oon000`0cXLX0[MSV0:gHiP020000
oaL0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV
01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV
01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403oon000`0cXLX0
[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP403oon000`0cXLX0[MSV0:gHiP030:gHiP80003o502]f>H00`0cXLX0[MSV
0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV
0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV
0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@0?ooh00303>QbP2]f>H0[MSV00D0[MSV00<0
003o0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0
<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@
0?ooh00303>QbP2]f>H0[MSV00H0[MSV0P000?lA0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:
0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh100oooP00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP0>0:gH
iP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gH
iP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP403oon000`0cXLX0[MSV0:gHiP090:gHiP80
003o3P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]
f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]
f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh100oooP00<0<j7:0:gHiP2]f>H0
2`2]f>H00`000?l0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0
5P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh100oooP00<0<j7:0:gHiP2]f>H0302]f>H00`000?l0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]
f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh100oooP00<0<j7:0:gHiP2]f>H03@2]f>H2
0000o`X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0
[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0
[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403oon000`0c
XLX0[MSV0:gHiP0?0:gHiP030000o`2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0c
XLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0c
XLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP403oon000`0cXLX0[MSV0:gHiP0@0:gHiP030000o`2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0
[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0
[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403oon000`0cXLX0[MSV
0:gHiP0A0:gHiP80003o0P0000040:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0
5P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh100oooP00<0<j7:0:gHiP2]f>H04P2]f>H010000000003o0000000000030:gHiP0303>Q
bP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>Q
bP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh100oooP5@0cXLX2000000030000o`00
0000<j7:00<0<j7:6@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0
<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP9P3oon0200000080003o0P3oon00
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H0
0`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H0
0`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Z0?ooh0030000o`3oon00<j7:
01T0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV
0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV
01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh2/0oooP00<0003o03>QbP2]f>H0602]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP;03oon020000oaP0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV
0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV
0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2`0oooP00<0
<j7:0:gHiP000?l05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0
<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0/0?ooh00403>QbP2]f>H0[MSV0000oaH0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0
<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP;03oon00100cXLX0[MSV0:gHiP2]f>H20000oa@0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]
f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh2`0oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0
[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0/0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0003o000000000000402]f>H00`0c
XLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0c
XLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP;03oon0703>QbP04000000000?l0000000000100<j7:4P2]f>H00`0c
XLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0c
XLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3<0
oooP0P0000020000o`l0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP03
03>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP03
03>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3@0oooP0P0000000`3oon00003o
0?ooh00=0?ooh00303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV
0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV
0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0h0?ooh0030000o`3oon00oooP00/0oooP00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh3T0oooP0P000?l;0?ooh00303>QbP2]f>H0[MSV0100[MSV00<0<j7:
0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:
0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0k0?oo
h0030000o`3oon00oooP00P0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gH
iP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3`0oooP00<0003o0?ooh03o
on001`3oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]
f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]
f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?@3oon000`000?l0oooP0?ooh0060?ooh00303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>Q
bP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0n0?ooh080003o1P3oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]
f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@03oon00
0`000?l0oooP0?ooh0030?ooh00303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0502]f>H0
0`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H0
0`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon110?ooh0030000o`3oon00oooP
0080oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV
0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV
01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon0300000?l0oooP@P3oon001@000?l0oooP0?ooh03oon00<j7:0180[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gH
iP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4<0oooP00@0003o0?ooh03o
on00<j7:4P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh4@0oooP00<0003o0?ooh00cXLX04P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP03
03>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP03
03>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4D0oooP0P000?lB0:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>Q
bP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPAP3o
on000`0cXLX0003o0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPAP3oon000`0cXLX0[MSV0000o`02000000h0[MSV00<0<j7:
0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:
0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon160?oo
h00403>QbP2]f>H000000000o`8000003@2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0
[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4H0oooP0P0cXLX2000000030000o`000000<j7:
00d0<j7:5P2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gH
iP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon190?ooh080
000000<0003o0?ooh03oon002`3oon000`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh4`0oooP00<0003o0?ooh03oon002P3oon000`0cXLX0[MSV
0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV
0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4d0oooP00<0
003o0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh4h0oooP00<0003o0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP0D
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K
0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00o`3oon1?0?oo
h080003o203oon000`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000
oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPD@3oon000`000?l0oooP0?ooh0050?ooh003
03>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP03
03>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP
1000003o0?ooh540oooP00<0003o0?ooh03oon00103oon000`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>Q
bP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3j
l>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1C0?ooh0030000o`3o
on00oooP00<0oooP00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]
f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<00000
0?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh5@0oooP00<0003o0?ooh03oon000P3oon00
0`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H0
0`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?oo
h03oon00o`3oon1E0?ooh0050000o`3oon00oooP0?ooh00cXLX05P2]f>H00`0cXLX0[MSV0:gHiP0@
0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1F0?ooh0040000o`3oon00oooP03>QbQH0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:
0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPE`3oon000`000?l0oooP03>QbP0F0:gH
iP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5P0oooP00<0003o03>QbP2]
f>H05@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]
f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1I0?ooh080003o
5@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H0
6`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1I0?ooh00303>QbP2]
f>H0003o01@0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]
f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF@3oon00
100cXLX0[MSV0:gHiP000?lC0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]
f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh5T0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0B0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh5T0oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP0?
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K
0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5T0oooP00<0<j7:0:gH
iP2]f>H00`2]f>H00`000?l0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh5T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP03
03>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPF@3oon000`0cXLX0[MSV0:gHiP050:gHiP030000
o`2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>Q
bP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000
603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1I0?ooh00303>QbP2]
f>H0[MSV00H0[MSV00<0003o0000000000002`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]
f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1I0?ooh0T0<j7:00@000000000o`000?l000002`0cXLXB0:gHiP0303>QbP2]
f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1R0?ooh0<0000000<0003o0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP0@
0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1S0?ooh080000000<0oooP0000o`3oon00203oon000`0c
XLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0c
XLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh0030000o`3oon00oooP00H0
oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0
[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ03oon000`000?l0oooP
0?ooh0050?ooh00303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV
0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6T0oooP00<0
003o0?ooh03oon00103oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0
<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Z
0?ooh0030000o`3oon00oooP00<0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0F
0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPJ`3oon000`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh6`0oooP00D0003o0?ooh03oon00oooP03>QbP0B0:gHiP0303>QbP2]f>H0[MSV
01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1]0?ooh0040000o`3oon00oooP03>QbQ80[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`0c
XLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6h0
oooP00<0003o0?ooh00cXLX04P2]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0
[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK`3oon000`000?l00000
0000000A0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV
0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1_0?ooh004000000000?l0000000000140<j7:
602]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPK`3o
on0200000080003o403oon000`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0
<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1`0?ooh080000000<0oooP0000o`3oon003P3oon00
0`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPM03oon000`000?l0oooP0?ooh00<0?ooh00303>QbP2]f>H0[MSV
01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1e0?ooh0030000o`3oon00oooP00/0oooP00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0
[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7H0oooP
00<0003o0?ooh03oon002P3oon000`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV
00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPM`3oon000`000?l0oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gH
iP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1h0?ooh0030000o`3oon00oooP00P0oooP00<0<j7:
0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh7T0oooP00<0003o0?ooh03oon001`3oon000`0cXLX0[MSV0:gHiP0F0:gH
iP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPNP3oon000`000?l0oooP0?ooh0060?ooh00303>QbP2]f>H0[MSV01H0[MSV00<0<j7:0:gHiP2]
f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1k0?ooh0030000
o`3oon00oooP00D0oooP00<0<j7:0:gHiP2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>Q
bP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP00<0003o0?ooh03oon00103o
on000`0cXLX0[MSV0:gHiP0F0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPO@3oon000`000?l0oooP0?ooh0030?ooh00303>QbP2]f>H0
[MSV01H0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1n0?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H05P2]f>H00`0c
XLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7l0
oooP00D0003o0?ooh03oon00oooP03>QbP0H0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gH
iP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<00000o`3oon200?ooh0040000o`3oon00oooP03>QbQP0[MSV00<0<j7:0:gH
iP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh840oooP00<0003o0?ooh00c
XLX0602]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh880oooP00<0003o03>QbP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>Q
bP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8<0oooP00<0003o0:gHiP2]f>H05P2]
f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh8<0oooP00<0<j7:0000o`2]f>H05P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0
[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8<0oooP00<0<j7:0:gHiP000?l05P2]f>H00`0c
XLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8<0
oooP00@0<j7:0:gHiP2]f>H0003o5@2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV
01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh8<0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0D0:gH
iP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPP`3oon000`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]
f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon230?ooh00303>Q
bP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>Q
bP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8<0oooP00<0<j7:0:gHiP2]f>H0102]
f>H00`000?l0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPP`3oon000`0cXLX0[MSV0:gHiP050:gHiP030000o`2]f>H0
[MSV00h0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon230?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H03@2]f>H00`0c
XLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8<0
oooP00<0<j7:0:gHiP2]f>H01`2]f>H00`000?l0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV01/0
[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon230?ooh00303>QbP2]f>H0[MSV00P0[MSV
00<0003o0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV
00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPP`3oon000`0cXLX0[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon23
0?ooh00303>QbP2]f>H0[MSV00X0[MSV00<0003o0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0K
0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8<0oooP00<0<j7:0:gH
iP2]f>H02`2]f>H00`000?l0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gH
iP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP`3oon000`0cXLX0[MSV0:gHiP0<0:gHiP03
0000o`000000000000L0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon230?ooh00303>QbP2]f>H0[MSV00`0[MSV00@0003o000000000000
00001P2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh8<0oooP3`0cXLX010000000003o00000000000703>QbQd0[MSV00<0<j7:0:gHiP2]
f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT`3oon000`000000003o0?ooh0060?ooh00303>Q
bP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU@3o
on000`000?l0oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPUP3oon000`000?l0oooP0?ooh0030?ooh00303>QbP2]f>H0
[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU`3oon000`00
0?l0oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPV03oon001@000?l0oooP0?ooh03oon00<j7:01d0[MSV00<0<j7:0:gH
iP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPV@3oon0010000?l0oooP0?ooh00cXLXM0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V403oon04000000L0oooP00<000000?ooh03oon00o`3oon2J0?ooh003
0000o`3oon00<j7:01d0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0030000003oon00oooP00P0oooP
00<000000?ooh03oon00o`3oon2K0?ooh0030000o`0cXLX0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0
7@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HA0?ooh0030000003oon00oooP00L0oooP1000003o0?ooh9X0oooP00<0003o03>QbP2]f>H0702]
f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3o
ool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPW03oon00
0`000?l0[MSV0:gHiP0K0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh0000007
0?ooh0030000003oon00oooP0?l0oooPW03oon000`0cXLX0003o0:gHiP0K0:gHiP0303>QbP2]f>H0
[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon2L0?ooh00303>QbP2]f>H0003o
01/0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW03oon00100cXLX0
[MSV0:gHiP000?lJ0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9`0
oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0I0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh9`0oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP0F0:gHiP03
03>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9`0oooP00<0<j7:0:gHiP2]f>H0
0`2]f>H00`000?l0[MSV0:gHiP0E0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh9`0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9`0oooP00<0<j7:0:gHiP2]f>H01@2]f>H0
0`000?l0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h9`0oooP00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gHiP0B0:gHiP0303>QbP2]f>H0[MSV
01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh9`0oooP00<0<j7:0:gHiP2]f>H01`2]f>H00`000?l0
[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9`0oooP
00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV01d0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh9`0oooP00<0<j7:0:gHiP2]f>H02@2]f>H00`000?l0[MSV0:gH
iP0?0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPW03oon000`0cXLX0[MSV0:gHiP0:
0:gHiP030000o`2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh007
0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2L0?oo
h00303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0M0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2L0?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2L0?ooh00303>Q
bP2]f>H0[MSV00`0[MSV00<0003o0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2L0?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0003o0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2L0?ooh00303>QbP2]f>H0
[MSV00h0[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2L0?ooh00303>QbP2]f>H0[MSV00l0[MSV00<0003o0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2L0?ooh00303>QbP2]f>H0[MSV0100
[MSV00<0003o0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2L0?ooh00303>QbP2]f>H0[MSV0140[MSV00<0003o0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2L0?ooh00303>QbP2]f>H0[MSV0180[MSV00<0
003o0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2L
0?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP0M
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2L0?ooh00303>QbP2]f>H0[MSV01@0[MSV00<0003o0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2L0?ooh003
03>QbP2]f>H0[MSV01D0[MSV00<0003o0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2L0?ooh00303>QbP2]f>H0[MSV01H0[MSV00<0003o0000002]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh9`0oooP600cXLX2000000030000o`00
0000<j7:0080<j7:7`2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2d0?ooh0<0000000@0003o0?ooh03oon00<j7:7`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP]@3oon02000000040000o`3oon00oooP03>QbQl0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;P0oooP00<0003o0?ooh00cXLX07`2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP^@3oon000`000?l0<j7:0:gHiP0N0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh003
0000o`2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP00<0<j7:0000o`2]f>H0
7@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP^P3oon000`0cXLX0[MSV0000o`0M0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2j0?ooh00303>QbP2]f>H0003o01d0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;X0oooP00@0<j7:0:gHiP2]f>H0003o702]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^P3oon001@0c
XLX0[MSV0:gHiP2]f>H0003o01/0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP00<0<j7:0:gH
iP2]f>H00P2]f>H00`000?l0[MSV0:gHiP0H0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh003
03>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H05`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
^P3oon000`0cXLX0[MSV0:gHiP040:gHiP030000o`2]f>H0[MSV01H0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh;X0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP0F0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o
0?ooh;X0oooP00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP0E0:gHiP0303>QbP3oon00
oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;X0oooP00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gHiP0D0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2j0?ooh00303>QbP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]f>H04`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP^P3oon000`0cXLX0[MSV0:gHiP080:gHiP030000o`2]f>H0[MSV0180[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;X0oooP00<0<j7:0:gHiP2]f>H02@2]f>H00`000?l0[MSV0:gH
iP0A0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh00303>QbP2]f>H0[MSV00T0[MSV00<0003o
0:gHiP2]f>H04@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^P3oon000`0cXLX0[MSV0:gHiP0:0:gH
iP030000o`2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP00<0<j7:0:gHiP2]
f>H02`2]f>H00`000?l0[MSV0:gHiP0?0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh00303>Q
bP2]f>H0[MSV00`0[MSV00<0003o0:gHiP2]f>H03P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^P3o
on000`0cXLX0[MSV0:gHiP0=0:gHiP030000o`2]f>H0[MSV00d0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh;X0oooP00<0<j7:0:gHiP2]f>H03P2]f>H00`000?l0[MSV0:gHiP0<0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2j0?ooh00303>QbP2]f>H0[MSV00h0[MSV00<0003o0:gHiP2]f>H0302]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP^P3oon000`0cXLX0[MSV0:gHiP0?0:gHiP030000o`2]f>H0[MSV00/0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`000?l0[MSV
0:gHiP0:0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh;X0oooP00<0<j7:0:gHiP2]f>H04@2]f>H00`000?l0[MSV0:gH
iP090:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;X0oooP00<0<j7:0:gHiP2]f>H04P2]f>H00`000?l0[MSV0:gHiP08
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0003o0:gH
iP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^P3oon000`0cXLX0[MSV0:gHiP0D0:gHiP03
0000o`2]f>H0[MSV00H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP00<0<j7:0:gHiP2]f>H0
502]f>H00`000?l0[MSV0:gHiP060:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh00303>QbP2]
f>H0[MSV01D0[MSV00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^P3oon00
0`0cXLX0[MSV0:gHiP0F0:gHiP030000o`2]f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;X0oooP00<0<j7:0:gHiP2]f>H05`2]f>H00`000?l0[MSV0:gHiP030:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2j0?ooh00303>QbP2]f>H0[MSV01P0[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP^P3oon000`0cXLX0[MSV0:gHiP0I0:gHiP050000o`2]f>H0[MSV0:gHiP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh;X0oooP00<0<j7:0:gHiP2]f>H06P2]f>H010000?l0[MSV0:gHiP0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
^P3oon000`0cXLX0[MSV0:gHiP0J0:gHiP040000o`2]f>H0[MSV03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooP
^P3oon000`0cXLX0[MSV0:gHiP0K0:gHiP030000o`000000000000/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP
0?ooh03o0?ooh;X0oooP00<0<j7:0:gHiP2]f>H06`2]f>H010000000003o00000000000:0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP
1000003o0?ooh;T0oooP7P0cXLX2000000030000o`000000oooP00H0oooP1000000H0?ooh1h0n_3V
0@3oool001d0n_3V4`3oon000`000000oooP0?ooh0050?ooh0030000003oon00oooP0?l0oooPf@3o
on02000000/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@00000
0?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03o
on00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H400000080n_3V20000002
0?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V000000000000
10000000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V00<0
00002@3jl>H500000080n_3V100000020?[`iPD000004P3jl>H6000000H0n_3V00<000000?[`iP3j
l>H0103jl>H3000000040?[`iP000000000000000>@0n_3V0@3oool00=d0n_3V0P0000020?[`iP80
00000`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP04
00000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
000000T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V
0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V
0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000
i@3jl>H10?ooo`00g@3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3j
l>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000
003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP800000
0P3jl>H2000000`0n_3V1@0000050?[`iP8000001P3jl>H5000000H0n_3V0`00003V0?[`iP40oooo
003M0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80
000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3j
l>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`
iP800000203jl>H00`000000n_3V0?[`iP060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H200000080
n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H00000
0?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP00
0000n_3V0180n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000
003U0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4
000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2
000000D0n_3V0`0000000`3jl>H0000000000007000000/0n_3V1@0000020?[`iP@000000P3jl>H3
000000030?[`iP000000000001<0n_3V0P00000?0?[`iP<0000000D0n_3V00000000000000000?[`
iP0400000=l0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<00000
0?[`iP3jl>H0603jl>H200000240n_3V1000000H0?[`iP030000003jl>H0n_3V0=l0n_3V0@3oool0
0=`0n_3V1P0000040?[`iP800000;`3jl>H5000001/0n_3V0`00000Q0?[`iP8000006@3jl>H00`00
0000n_3V0?[`iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<000000?[`iP3jl>H0g@3jl>H10?ooo`00
o`3jl>Ie0?[`iP040000003jl>H0n_3V00000=l0n_3V0@3oool00?l0n_3VMP3jl>H200000>00n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01643 L
.07739 .01643 L
.07739 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01643 L
.07739 .01643 L
.07739 .16187 L
s
1 .894 .882 r
.07739 .16187 m
.07739 .01676 L
.0999 .01676 L
.0999 .16187 L
F
.804 .522 .247 r
.07739 .16187 m
.07739 .01676 L
.0999 .01676 L
.0999 .16187 L
s
1 .894 .882 r
.0999 .16187 m
.0999 .01991 L
.12194 .01991 L
.12194 .16187 L
F
.804 .522 .247 r
.0999 .16187 m
.0999 .01991 L
.12194 .01991 L
.12194 .16187 L
s
1 .894 .882 r
.12194 .16187 m
.12194 .02447 L
.1467 .02447 L
.1467 .16187 L
F
.804 .522 .247 r
.12194 .16187 m
.12194 .02447 L
.1467 .02447 L
.1467 .16187 L
s
1 .894 .882 r
.1467 .16187 m
.1467 .02988 L
.18554 .02988 L
.18554 .16187 L
F
.804 .522 .247 r
.1467 .16187 m
.1467 .02988 L
.18554 .02988 L
.18554 .16187 L
s
1 .894 .882 r
.18554 .16187 m
.18554 .0336 L
.21437 .0336 L
.21437 .16187 L
F
.804 .522 .247 r
.18554 .16187 m
.18554 .0336 L
.21437 .0336 L
.21437 .16187 L
s
1 .894 .882 r
.21437 .16187 m
.21437 .04511 L
.27201 .04511 L
.27201 .16187 L
F
.804 .522 .247 r
.21437 .16187 m
.21437 .04511 L
.27201 .04511 L
.27201 .16187 L
s
1 .894 .882 r
.27201 .16187 m
.27201 .06312 L
.29951 .06312 L
.29951 .16187 L
F
.804 .522 .247 r
.27201 .16187 m
.27201 .06312 L
.29951 .06312 L
.29951 .16187 L
s
1 .894 .882 r
.29951 .16187 m
.29951 .06795 L
.32338 .06795 L
.32338 .16187 L
F
.804 .522 .247 r
.29951 .16187 m
.29951 .06795 L
.32338 .06795 L
.32338 .16187 L
s
1 .894 .882 r
.32338 .16187 m
.32338 .07989 L
.35851 .07989 L
.35851 .16187 L
F
.804 .522 .247 r
.32338 .16187 m
.32338 .07989 L
.35851 .07989 L
.35851 .16187 L
s
1 .894 .882 r
.35851 .16187 m
.35851 .10604 L
.41658 .10604 L
.41658 .16187 L
F
.804 .522 .247 r
.35851 .16187 m
.35851 .10604 L
.41658 .10604 L
.41658 .16187 L
s
1 .894 .882 r
.41658 .16187 m
.41658 .14249 L
.47182 .14249 L
.47182 .16187 L
F
.804 .522 .247 r
.41658 .16187 m
.41658 .14249 L
.47182 .14249 L
.47182 .16187 L
s
.678 .847 .902 r
.47182 .16187 m
.47182 .16419 L
.53788 .16419 L
.53788 .16187 L
F
.2 .63 .79 r
.47182 .16187 m
.47182 .16419 L
.53788 .16419 L
.53788 .16187 L
s
.678 .847 .902 r
.53788 .16187 m
.53788 .20086 L
.60309 .20086 L
.60309 .16187 L
F
.2 .63 .79 r
.53788 .16187 m
.53788 .20086 L
.60309 .20086 L
.60309 .16187 L
s
.678 .847 .902 r
.60309 .16187 m
.60309 .24319 L
.6308 .24319 L
.6308 .16187 L
F
.2 .63 .79 r
.60309 .16187 m
.60309 .24319 L
.6308 .24319 L
.6308 .16187 L
s
.678 .847 .902 r
.6308 .16187 m
.6308 .27104 L
.65966 .27104 L
.65966 .16187 L
F
.2 .63 .79 r
.6308 .16187 m
.6308 .27104 L
.65966 .27104 L
.65966 .16187 L
s
.678 .847 .902 r
.65966 .16187 m
.65966 .29647 L
.68802 .29647 L
.68802 .16187 L
F
.2 .63 .79 r
.65966 .16187 m
.65966 .29647 L
.68802 .29647 L
.68802 .16187 L
s
.678 .847 .902 r
.68802 .16187 m
.68802 .31578 L
.7394 .31578 L
.7394 .16187 L
F
.2 .63 .79 r
.68802 .16187 m
.68802 .31578 L
.7394 .31578 L
.7394 .16187 L
s
.678 .847 .902 r
.7394 .16187 m
.7394 .36242 L
.75947 .36242 L
.75947 .16187 L
F
.2 .63 .79 r
.7394 .16187 m
.7394 .36242 L
.75947 .36242 L
.75947 .16187 L
s
.678 .847 .902 r
.75947 .16187 m
.75947 .39853 L
.81183 .39853 L
.81183 .16187 L
F
.2 .63 .79 r
.75947 .16187 m
.75947 .39853 L
.81183 .39853 L
.81183 .16187 L
s
.678 .847 .902 r
.81183 .16187 m
.81183 .43849 L
.83688 .43849 L
.83688 .16187 L
F
.2 .63 .79 r
.81183 .16187 m
.81183 .43849 L
.83688 .43849 L
.83688 .16187 L
s
.678 .847 .902 r
.83688 .16187 m
.83688 .44756 L
.85748 .44756 L
.85748 .16187 L
F
.2 .63 .79 r
.83688 .16187 m
.83688 .44756 L
.85748 .44756 L
.85748 .16187 L
s
.678 .847 .902 r
.85748 .16187 m
.85748 .46892 L
.88469 .46892 L
.88469 .16187 L
F
.2 .63 .79 r
.85748 .16187 m
.85748 .46892 L
.88469 .46892 L
.88469 .16187 L
s
.678 .847 .902 r
.88469 .16187 m
.88469 .5105 L
.9379 .5105 L
.9379 .16187 L
F
.2 .63 .79 r
.88469 .16187 m
.88469 .5105 L
.9379 .5105 L
.9379 .16187 L
s
.678 .847 .902 r
.9379 .16187 m
.9379 .59589 L
.97619 .59589 L
.97619 .16187 L
F
.2 .63 .79 r
.9379 .16187 m
.9379 .59589 L
.97619 .59589 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.0752 .01643 Mdot
.07988 .01676 Mdot
.11331 .01991 Mdot
.14641 .02447 Mdot
.17666 .02988 Mdot
.19439 .0336 Mdot
.24024 .04511 Mdot
.29694 .06312 Mdot
.31022 .06795 Mdot
.34073 .07989 Mdot
.39895 .10604 Mdot
.46754 .14249 Mdot
.50375 .16419 Mdot
.5594 .20086 Mdot
.61717 .24319 Mdot
.6523 .27104 Mdot
.68273 .29647 Mdot
.70494 .31578 Mdot
.7558 .36242 Mdot
.79287 .39853 Mdot
.83192 .43849 Mdot
.84051 .44756 Mdot
.86042 .46892 Mdot
.89788 .5105 Mdot
.97016 .59589 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.138741) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.674886) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000050?[`iP800000103jl>H4000000<0n_3V0`0000040?[`iP<0
0000103jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP000000000000@0n_3V0P0000050?[`iP8000000`3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000o`3j
l>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3j
l>H2000000030?[`iP000000000000@0n_3V0P0000020?[`iPH000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000o`3j
l>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003j
l>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V00000000
00002@3jl>H2000000030?[`iP000000000000@0n_3V0P0000020?[`iP030000003jl>H0n_3V0080
00000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V
0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`
iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`
iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H
0?[`iP80000000<0n_3V0000000000002@3jl>H4000000H0n_3V0P0000020?[`iP040000003jl>H0
0000000000@0n_3V0`0000040?[`iP<000000`3jl>H400000?l0n_3VW@3jl>H10?ooo`00803jl>H2
00000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H0000000000005
00000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V
0000000000001`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H2000000P0n_3V0P000002
0?[`iP040000003jl>H00000000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H200000?l0n_3VW`3jl>H10?ooo`00803jl>H200000080n_3V0P00000c
0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0U0?[`iP80000000<0n_3V0000000000002P3jl>H2
000000@0n_3V00<000000?[`iP3jl>H00P0000030?[`iP<000000`3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000030?[`iP800000o`3jl>JN0?[`iP40oooo000O0?[`
iPH00000103jl>H2000002l0n_3V1@00000X0?[`iP<00000303jl>H300000080n_3V1@0000040?[`
iP800000103jl>H3000000@0n_3V0`0000050?[`iP<00000o`3jl>JL0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool003d0n_3V1000003o
0?[`i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3Vo`3jl>HG0?[`iP40oooo000P0?[`iPH0
000000D0n_3V00000000000000000?[`iP0300000080n_3V0`0000030?[`iP@000000`3jl>H20000
00040?[`iP00000000000?[`iPD000000`3jl>H<000002l0n_3V0`0000040?[`iP8000001@3jl>H3
000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP800000o`3jl>JN
0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`
iP040000003jl>H00000000000<0n_3V00D000000?[`iP00000000000?[`iP0300000080n_3V0P00
00040?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP00
0000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P000004
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000050?[`iP8000000P3jl>H2
00000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000`0?[`iP80000000<0n_3V
0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H20000
00030?[`iP00000000000080n_3V0P0000040?[`iPH0000000<0n_3V0000000000000P3jl>H20000
0080n_3V0P0000050?[`iPD000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000
000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`
iP<000000P3jl>H3000000030?[`iP000000n_3V00@0n_3V0P0000030?[`iP800000<03jl>H20000
00030?[`iP000000000000T0n_3V100000030?[`iP@000000`3jl>H4000000<0n_3V100000030?[`
iP@000001P3jl>H200000?l0n_3VW@3jl>H10?ooo`008P3jl>H2000000<0n_3V1@0000020?[`iPD0
00000`3jl>H4000000<0n_3V0P0000000`3jl>H0000000000004000000030?[`iP00000000000080
n_3V100000040?[`iP800000<03jl>H2000000030?[`iP000000000000T0n_3V0P0000050?[`iP80
00001@3jl>H2000000D0n_3V0P0000050?[`iP800000203jl>H200000?l0n_3VW@3jl>H10?ooo`00
8P3jl>H2000000/0n_3V0P00000R0?[`iP800000<03jl>H2000000030?[`iP000000000000X0n_3V
0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000103jl>H00`000000n_3V
0?[`iP0200000?l0n_3VW@3jl>H10?ooo`00803jl>H6000000T0n_3V0P00000P0?[`iP@00000<@3j
l>H3000000`0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<000000P3j
l>H500000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H02000
00000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H010000000n_3V0000003j
l>H200000080n_3V00<000000?[`iP3jl>H00`00003o0?[`i_l0n_3V903jl>H10?ooo`00803jl>H3
000000030?[`iP00000000000080000000D0n_3V0000003jl>H000000?[`iP0300000080n_3V00<0
00000?[`iP000000603jl>H500000=/0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P00
00030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000@0n_3V0000000000000000
203jl>H4000000030?[`iP00000000000080n_3V100000020?[`iPD0000000L0n_3V000000000000
00000?[`iP000000n_3V00<00000603jl>H3000000@0n_3V0P0000040?[`iPH000000P3jl>H30000
00@0n_3V0`0000050?[`iP800000103jl>H400000080n_3V1P00001g0?[`iP40oooo000Q0?[`iP80
000000<0n_3V0000000000001@000000103jl>H000000000000000020?[`iP80000000<0n_3V0000
000000002@3jl>H5000000T0n_3V0P00003O0?[`iP800000103jl>H200000080n_3V0P0000020?[`
iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H0
10000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP00
0000000000X0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V0P00
00040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP00
0000000000<0n_3V0P0000060?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V0P00
00000`3jl>H00000000000040?[`iP8000001@3jl>H2000000D0n_3V0P00001i0?[`iP40oooo000R
0?[`iP<00000:@3jl>H200000=h0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P000005
0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P000002
0?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P00
00020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P00
00000`3jl>H000000000000;0?[`iP8000001P3jl>H200000080n_3V0P0000000`3jl>H000000000
00040?[`iP8000000P3jl>H6000000@0n_3V0P00001i0?[`iP40oooo000R0?[`iP<000006P3jl>H5
000000/0n_3V0P00003M0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2
000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V
0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3j
l>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0
n_3V0000000000002`3jl>H2000000H0n_3V0P0000020?[`iP80000000<0n_3V000000000000103j
l>H200000080n_3V00<000000?[`iP3jl>H00P0000050?[`iP800000N@3jl>H10?ooo`008@3jl>H2
000000030?[`iP000000000002X0n_3V0P00003L0?[`iP80000000<0n_3V0000000000001@3jl>H2
00000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0`00
0000103jl>H000000000003jl>H200000080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H0
0P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H000000000000;0?[`iP800000
103jl>H3000000@0n_3V0`0000060?[`iP8000000P3jl>H010000000n_3V0000000000050?[`iP80
0000N@3jl>H10?ooo`00803jl>H3000000040?[`iP0000000000000002H0n_3V0P0000000`3jl>H0
00000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H0
00000000003jl>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`
iPD000002`3jl>H3000000030?[`iP00000000000080n_3V100000020?[`iP<0000000<0n_3V0000
000000001`00000I0?[`iP80000000<0n_3V0000000000002`3jl>H2000000H0n_3V0P0000020?[`
iP80000000<0n_3V0000000000001@3jl>H200000080n_3V00@000000?[`iP00000000001@3jl>H2
000007T0n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000
00000000403jl>H2000000`0n_3V0P00000R0?[`iP8000000P3jl>H2000002h0n_3V0P0000000`3j
l>H00000000000090?[`iP@000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3j
l>H00000000000020?[`iP030000003jl>H0n_3V008000000`3jl>H3000000<0n_3V1000001i0?[`
iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H2000000H0
n_3V0P00000I0?[`iP<0000000<0n_3V0000000000000P00000^0?[`iP<00000303jl>H2000000@0
n_3V0`0000040?[`iP<000000`3jl>H5000000@0n_3V0P0000050?[`iP800000N@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`
iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?oo
o`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H000000P3jl>H0
0`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`iP0000000000
0080000000@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003j
l>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3j
l>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000H000006P3j
l>H5000000<0n_3V0`0000310?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@000000
1@3jl>H00000000000000000n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3jl>H000000000
003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@0
00000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H20000
00/0n_3V1@0000090?[`iP8000001@3jl>H00`000000n_3V0?[`iP0200000<00n_3V0@3oool00280
n_3V0`00000X0?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P0000020?[`iP80
00000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP@000006P3jl>H2000000L0
n_3V0P0000300?[`iP40oooo000R0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD00000
2@3jl>H2000000030?[`iP00000000000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V
0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H4000000d0n_3V1@00000;0?[`iP8000001P3jl>H200000<00
n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0n_3V000000000000
g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0
n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000L0?[`iP8000000P3jl>H00`00
0000n_3V0?[`iP0200000<00n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`
iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`
iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V10000004
0?[`iP@000000P3jl>H5000000<0n_3V1@00000I0?[`iP80000000<0n_3V0000000000000P3jl>H4
00000<40n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000
00000000403jl>H2000000`0n_3V0P00000h0?[`iP80000000<0n_3V0000000000000P3jl>H20000
0<<0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H200000340n_3V0`0000030?[`iPD00000`03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0n_3V9P3oon02000006`0oooP0P0000040?oo
h0800000103oon02000006/0oooP1@00001Y0?ooh0D000000P3oon02000000@0oooP0P00001[0?oo
h0@000008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon001000
0000oooP0?ooh00000080?ooh0040000003oon00oooP000006`0oooP00<000000?ooh03oon00J`3o
on000`000000oooP0?ooh0070?ooh0040000003oon00oooP000006X0oooP00<000000?ooh03oon00
903oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon0010000000oooP
0?ooh000000;0?ooh0030000003oon00oooP06X0oooP00<000000?ooh03oon00J`3oon000`000000
oooP0?ooh00:0?ooh0030000003oon00oooP06T0oooP00<000000?ooh03oon008`3oon0N0?[`iP40
oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon0010000000oooP0?ooh00000090?oo
h0800000K@3oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP0P00001]0?oo
h0030000003oon00oooP0280oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP0000
06X0oooP00@000000?ooh03oon0000002@3oon000`000000oooP0?ooh01/0?ooh0030000003oon00
oooP06/0oooP00<000000?ooh03oon00203oon000`000000oooP0?ooh01Z0?ooh0040000003oon00
oooP000002<0oooP7P3jl>H10?ooo`007@3jl>HV0?ooh0800000K03oon02000000X0oooP0`00001[
0?ooh0800000K03oon02000000X0oooP0`00001[0?ooh0800000903oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740
oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05
000000H0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon008@3oon020000
00030?ooh000000000000?l0oooP`03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000203oon0J0000o`@00000o`3oon2l0?ooh0@0
0000603oon0N0?[`iP40oooo000M0?[`iPX0oooP100000040?ooh0030000003oon00oooP00H0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0D0?oTh@<0000020000?l40<f5?`D0oooP
0P00003o0?ooh;00oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<0
00000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01D0onCQ0P00
00000`3=QCl00000000000050?oTh@X0003o0P0000030<f5?ol0oooP[03oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>42
000000T0003o1P3oon0200000?l0oooPX03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oT
h@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@8000000`3oi>450<f5?`P0003o00<000000?oo
h03oon00o`3oon2M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401`3oi>43000000D0003o203oon0200000?l0
oooPT@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ0P0000050?ooh0D0003o0P3oon0400000?l0oooP
T03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00T0onCQ2`3=QCl50000o`040000003=QCl0cHDo0<f5?`80oooP
0P00003o0?ooh8T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0
cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0onCQ0P00
00050000o`@00000o`3oon280?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@08
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@
0?oTh@80cHDo1@000?l80<f5?ol0oooPO`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oT
h@3oi>40203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>40403oi>400`3=QCl0onCQ0?oTh@0200000080onCQ10000?l30?oTh@030<f5?`3oon00oooP
0?l0oooPO@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0
onCQ0?oTh@080?oTh@D0003oo`3oon1n0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ
0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?ooh0000?l00`000?oo0?ooh7X0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3o
i>400`3=QCl0oooP0?ooh0030?ooh0@0003o0P3oon0200000?l0oooPLP3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>405`3oi>40
0`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ2P3=QCl30000o`8000003P3=QCoo
0?ooh640oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0;0?oT
h@030<f5?`3oi>40onCQ00P0onCQ0P0000040000o`/0onCQ00<0cHDo0?ooh03oon00o`3oon1Q0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0
onCQ00<0cHDo0?oTh@3oi>402@3oi>42000000<0onCQ0`000?l80?oTh@030<f5?`3oon00oooP0?l0
oooPH@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ
0?oTh@0;0?oTh@030<f5?`3oi>40onCQ0140onCQ10000?l40?oTh@030<f5?`3oon00oooP0?l0oooP
H@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oT
h@0;0?oTh@030<f5?`3oi>40onCQ01D0onCQ0`000?l00`3oi>40cHDo0?ooh03o0?ooh680oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>40
0`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>40
0`3=QCl0onCQ0?oTh@0H0?oTh@<0003oo`3oon1R0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=
QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>40103=
QCl0oooP0000o`000?oo0?ooh600oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ
0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@040<f5?`3oon00oooP
0?ooh0<0003oo`3oon1M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oT
h@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0oooP0?ooh0040?oo
h0<0003o00<0oooP000000000000o`3oon1G0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>4:0<f5?`80
003o0P00003o0?ooh5H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ
00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00L0onCQ
0P0000030000o`<0oooP0P00003o0?ooh500oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3o
i>40onCQ00P0onCQ0P0000000`3=QCl0oooP0000o`020000o`<00000o`3oon1?0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo
0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@@0cHDo00@000000000o`000?l0003o1@3=
QCoo0?ooh4X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo
0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo
0?oTh@3oi>400P3oi>42000000030?oTh@000?l0003o0080onCQ00<0cHDo0?ooh03oon00o`3oon18
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=
QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=
QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=
QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>401`3oi>430000
ool0oooPB03oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0
onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0
onCQ00@0cHDo0000o`000?l0003oo`3oon170?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0
onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00@0cHDo0?ooh03oon00oooP0P000?l20?oo
h0800000o`3oon110?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@03
0<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ00T0onCQ1P3=QCl30000o`8000001`3=QCoo0?ooh3T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ
0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@040?oTh@8000000`000?l50?oTh@030<f5?`3oon00oooP0?l0oooP=`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3o
i>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00D0onCQ0P0000020?oTh@80003o0`3oi>400`3=QCl0oooP0?ooh03o0?ooh3L0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>40
0`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>40
0`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0onCQ0?oTh@0;0?oTh@80003o00<0onCQ0<f5?`3oon00o`3oon0h0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oT
h@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>403@3oi>420000ool0oooP>@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3o
i>40203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3o
i>40403oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3o
i>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0000o`00
0?l0o`3oon0g0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5
?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5
?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5
?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0oooP0?ooh0030000ool0oooP
=03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oT
h@0;0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?ooh03oon000`3oon020000ool0oooP<P3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@08
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0;
0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?ooh03oon001@3oon020000ool0oooP<03oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0;0?oT
h@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oT
h@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?ooh03oon001`3oon020000ool0oooP;P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?ooh03oon002@3oon030000ool0oooP:`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5
?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5
?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ00h0onCQ00<0cHDo0?ooh03oon00303oon020000ool0oooP:@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>405`3o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3o
i>400`3=QCl0oooP0?ooh00>0?ooh080003o0P00003o0?ooh2<0oooP0`00000H0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo
0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo
0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ4P3=QCl0
10000000003o0000o`0000070<f5?ol0oooP7@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo
0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo
0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo
0?oTh@3oi>403`3oi>4300000080003o1@3oi>400`3=QCl0oooP0?ooh03o0?ooh1/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=
QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=
QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ0100onCQ0P0000020?oTh@80003o0`3oi>400`3=
QCl0oooP0?ooh03o0?ooh1/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0
onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100
onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01H0
onCQ0P000?l00`3oi>40cHDo0?ooh03o0?ooh1`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5
?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5
?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5
?`3oi>40onCQ01P0onCQ0P000?oo0?ooh1d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3o
i>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3o
i>40onCQ01T0onCQ00<0cHDo0000o`000?l0o`3oon0K0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>40
0`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>40
0`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>40
0`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oon00oooP0080003oo`3oon0I0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oT
h@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oon00oooP0080oooP0P000?oo0?oo
h1L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3o
i>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3o
i>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3o
i>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?ooh03o
on00103oon020000ool0oooP5@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40
403oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>40
2P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40
6@3oi>400`3=QCl0oooP0?ooh0060?ooh080003oo`3oon0C0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3o
i>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oon00oooP00P0oooP00<0003o0?ooh03oon00o`3o
on0@0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40
onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40
onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40
onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oon00
oooP00T0oooP0P000?oo0?ooh100oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ
0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ
00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ
01T0onCQ00<0cHDo0?ooh03oon002`3oon020000ool0oooP3P3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0
onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0
onCQ0?oTh@0I0?oTh@030<f5?`3oon00oooP00d0oooP00<0003o0?ooh03oon00o`3oon090?ooh0<0
0000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ
0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?ooh03oon003P3oon020000ool0oooP
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oT
h@0;0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0oooP0?oo
h00@0?ooh080003oo`3oon090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@08
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@
0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0I
0?oTh@030<f5?`3oon00oooP0180oooP0P000?l20?ooh0800000o`3oon030?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oT
h@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oon00oooP01@0oooP00<0003o0000
000000000P00003o0?ooh080oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0
onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100
onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01T0
onCQ603=QCl20000o`800000o`3oon020?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ
0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ
0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ
0?oTh@0I0?oTh@030<f5?`3oi>40onCQ01H0onCQ00<000000000o`000?l0o`3oon020?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>405`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0
cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0
cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0
cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ01P0onCQ00<0
cHDo0000o`000?l0o`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ01L0onCQ00<0cHDo0?oTh@3oi>40203oi>40
0`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40403oi>40
0`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>40
0`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>406@3oi>40
0`3=QCl0onCQ0?oTh@0H0?oTh@040<f5?`3oon00oooP0000ooh0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I
0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>
0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>40603oi>40103=QCl0oooP0?ooh03o
on020000oo`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo
0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo
0?oTh@3oi>40603oi>400`3=QCl0oooP0?ooh0030?ooh080003onP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
01L0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ
00T0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ
01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ
00h0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0H0?oTh@030<f5?`3oon00oooP
00D0oooP00<0003o0?ooh03oon00m`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0G0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@0I0?oTh@03
0<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@03
0<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>40603oi>400`3=QCl0oooP0?ooh0060?ooh080
003om`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP
0?ooh00000070?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>405`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0
onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0
onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ01P0onCQ00<0cHDo0?ooh03oon00203oon020000ooD0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon00
00001`3oon04000000P0oooPi`0000020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`00
7@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00h`3oon0>03>QbP04
000000000?l00000000000l0<j7:7`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV
0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?40oooP0P0000020000
o`h0oooP00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV
0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V4@3oon02000000P0oooP00<000000?ooh03oon00lP3oon02000000030?ooh0000?l0oooP00`0
oooP00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03f0?ooh080003o2`3oon000`0cXLX0[MSV0:gHiP0M0:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?P0oooP00<0
003o0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?T0oooP0P000?l80?ooh00303>QbP2]f>H0
[MSV01d0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00n`3oon000`000?l0oooP0?ooh0050?ooh00303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o03oon000`000?l0
oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o@3oon020000o`@0oooP00<0<j7:0:gHiP2]f>H0
7@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh0050000o`3oon00oooP0?ooh00cXLX07`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh040oooP0P000?l00`3oon00<j7:0:gH
iP0N0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP0`3oon000`000?l0<j7:0:gHiP0N0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP103oon020000oah0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon040?ooh003
03>QbP2]f>H0003o01d0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`00003o0?ooh0@0oooP00<0<j7:0:gHiP2]f>H00P000?lK0:gHiP0303>QbP2]f>H0[MSV00/0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV
00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon040?ooh00303>QbP2]f>H0[MSV0080[MSV00<0
003o0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh0@0oooP00<0<j7:0:gHiP2]f>H00`2]f>H20000oaP0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon040?oo
h00303>QbP2]f>H0[MSV00D0[MSV00@0003o0:gHiP0000000000502]f>H00`0cXLX0[MSV0:gHiP0;
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0@0oooP2@0cXLX20000
o`800000500cXLX=0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0d0
oooP0P0000000`000?l000000?ooh00B0?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]
f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3P3oon0200000080003o4P3oon000`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh180oooP00<0
003o0?ooh03oon003`3oon000`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh1<0oooP0P000?l?0?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP5@3oon000`000?l0oooP0?ooh00<0?oo
h00303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP5P3oon020000o``0oooP00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0H0?ooh0030000o`3oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
2`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0I0?ooh080003o2@3o
on000`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh1/0oooP00<0003o0?ooh03oon001P3oon000`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon0300000?l0oooP703oon020000o`H0oooP00<0<j7:0:gHiP2]f>H02`2]f>H00`0c
XLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0c
XLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh1h0oooP00<0003o0?ooh03oon000`3oon000`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1l0oooP
00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00/0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh200oooP0P000?l20?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP8P3oon000`000?l0oooP03>QbP0=
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2<0oooP00<0003o03>Q
bP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0T0?ooh080
003o302]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0T0?ooh00303>Q
bP2]f>H0003o00/0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP903o
on00100cXLX0[MSV0:gHiP000?l:0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh2@0oooP00@0<j7:0:gHiP2]f>H0[MSV0P000?l2000000H0[MSV00<0<j7:0:gHiP2]f>H0
2`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP903oon000`0cXLX0[MSV0:gHiP020:gHiP0400000000
0?l00000000000D0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP903o
on0503>QbP80000000<0003o0000000cXLX01@0cXLX=0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Z
0?ooh08000000P000?l40?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h2h0oooP00D0003o0?ooh03oon00oooP03>QbP0=0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh2l0oooP00@0003o0?oo
h03oon00<j7:3@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0`0?ooh080003o00<0<j7:0:gHiP2]f>H02`2]f>H00`0c
XLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP<P3oon000`000?l0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0b0?ooh00303>QbP000?l0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP00<0
<j7:0:gHiP000?l02`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<P3oon000`0cXLX0[MSV0:gHiP02
0000o`T0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`00
0?l0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0c
XLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0b0?ooh00303>QbP2]f>H0[MSV00<0
[MSV00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<P3oon000`0cXLX0[MSV
0:gHiP040:gHiP80003o1@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV
00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<P3oon000`0cXLX0[MSV0:gH
iP060:gHiP030000o`00000000000080[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP00<0<j7:
0:gHiP2]f>H01P2]f>H01P000000003o000000000000[MSV03>QbP`0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0b0?ooh0T0<j7:0P00
000010000?l0000003>QbP0cXLX<0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP?03oon0200000080003o00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh400oooP00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh400oooP00<0<j7:0000o`2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP@03oon000`0cXLX0
[MSV0000o`0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon100?ooh00403>QbP2]f>H0[MSV0000o`T0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon100?ooh00503>QbP2]f>H0[MSV0:gHiP00
0?l0202]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh400oooP00<0<j7:0:gHiP2]f>H00P2]f>H20000o`H0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon100?ooh00303>QbP2]
f>H0[MSV00@0[MSV00<0003o0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]
f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh400oooP00<0<j7:0:gHiP2]f>H01@2]f>H0
0`000?l0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP@03oon000`0cXLX0[MSV0:gHiP060:gHiP050000o`0000000000
0:gHiP0cXLX06@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon100?oo
h00303>QbP2]f>H0[MSV00H0[MSV00D000000000o`000000000003>QbP0I0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh400oooP2@0cXLX2000000030000o`000000<j7:
01T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPBP3oon0200000003
0000o`0cXLX0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP03
03>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
C@3oon000`000?l0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh4d0oooP00<0<j7:0000o`2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@000006
0?ooh0030000003oon00oooP0?l0oooPC@3oon00100cXLX0[MSV0000o`000?lF0:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]
f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPC@3oon00
1@0cXLX0[MSV0:gHiP2]f>H0003o01D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00
oooP00H0oooP1000003o0?ooh4`0oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP0B
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon001P3oon04000001P0oooP7P3jl>H1
0?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1=0?oo
h00303>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80
oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh4d0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`000?l000000000000@0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP
00<000000?ooh03oon00o`3oon1=0?ooh0L0<j7:00@000000000o`0000000000400cXLX80:gHiP03
03>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1D0?ooh080000000<0003o0000003oon003P3oon000`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV
0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1E0?ooh080000000<0003o0?ooh03oon003@3o
on000`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]
f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1H0?ooh0030000o`3oon00
oooP00`0oooP00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF@3oon020000
o``0oooP00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF`3oon000`000?l0
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5`0oooP
00<0003o0?ooh03oon00203oon000`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1M0?ooh0030000o`3oon00oooP00L0oooP00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPGP3oon000`000?l0oooP0?ooh0060?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh5l0oooP00<0003o0?ooh03oon001@3oon000`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1P0?ooh0030000o`3oon00oooP00@0oooP00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]
f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0<00000o`3oon1Q0?ooh0030000o`3oon00oooP00<0oooP00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1R0?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPH`3oon020000o`80oooP00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPI@3oon000`000?l0oooP03>QbP080:gHiP0303>QbP2]f>H0[MSV
01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1V0?ooh0030000o`0cXLX0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6L0oooP
00<0003o0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV
00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI`3oon000`0cXLX0003o0:gH
iP060:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gH
iP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh00303>QbP2]f>H0003o00H0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh6L0oooP00@0<j7:0:gHiP2]f>H0003o1@2]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:
0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPI`3oon001@0cXLX0[MSV0:gHiP2]f>H0003o00@0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h6L0oooP00<0<j7:0:gHiP2]f>H00P2]f>H01@000?l0[MSV0:gHiP2]f>H0<j7:01T0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?oo
h00303>QbP2]f>H0[MSV00<0[MSV00@0003o000000000000<j7:6@2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6L0oooP1P0cXLX01000
0000003o00000000000I0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPK@3oon02000000030000o`000000[MSV01P0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1^0?ooh080
000000<0003o0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon0300000?l0oooPL03oon000`0cXLX0003o0000o`0G0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV
00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1`0?ooh00403>QbP2]f>H0[MSV0000oaH0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1`0?ooh00503>QbP2]f>H0[MSV0:gHiP000?l05@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh700oooP00<0<j7:0:gHiP2]f>H00P2]
f>H00`000?l0[MSV0:gHiP0B0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPL03oon000`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0
[MSV0140[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1`0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0003o0:gHiP2]f>H0402]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh700
oooP00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL03oon000`0cXLX0[MSV
0:gHiP060:gHiP030000o`2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV
0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1`0?ooh00303>QbP2]f>H0[MSV00L0[MSV00<0
003o0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh700oooP00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP0<
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:
0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPL03oon000`0cXLX0[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1`0?ooh003
03>QbP2]f>H0[MSV00X0[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP03
03>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh700oooP00<0<j7:0:gHiP2]f>H0
2`2]f>H00`000?l0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPL03oon000`0cXLX0[MSV0:gHiP0<0:gHiP030000o`00
0000000000P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o
0?ooh700oooP00<0<j7:0:gHiP2]f>H0302]f>H010000000003o0000000000070:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1`0?ooh0l0<j7:0P000000
0`000?l0000003>QbP0703>QbP/0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:
0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPP03oon02000000030000o`3oon00oooP00D0oooP00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0c
XLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon230?ooh0030000o`3oon00oooP00@0
oooP00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon240?ooh0030000o`3oon00oooP00<0oooP00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV
0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon250?ooh0030000o`3oon00oooP0080oooP00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon26
0?ooh0050000o`3oon00oooP0?ooh00cXLX02`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon270?ooh0040000o`3oon00oooP03>QbP/0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPR03oon000`000?l0oooP03>QbP0;0:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8T0oooP00<0003o03>QbP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0c
XLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2:0?ooh0030000o`2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPRP3oon000`0cXLX0003o
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP00<0
<j7:0:gHiP000?l02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2:
0?ooh00403>QbP2]f>H0[MSV0000o`P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2:
0?ooh00503>QbP2]f>H0[MSV0:gHiP000?l01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3o
on00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh8X0oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`00
0?l0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8X0
oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP00<0<j7:0:gHiP2]f>H01@2]f>H01@000?l0[MSV
0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP03
03>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP00<0<j7:0:gHiP2]f>H0
1@2]f>H01@000?l000000000002]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP
200cXLX01@000000003o000000000000<j7:00T0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh980oooP
0P0000000`000?l0000003>QbP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2C0?ooh080000000<0
003o03>QbP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPUP3oon000`000?l0000000000007
0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2F0?ooh004000000000?l00000000000H0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh9H0oooP0P0000000`000?l0000003>QbP0603>QbP`0[MSV00<0<j7:0:gH
iP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2G0?ooh080
000000<0003o0?ooh03oon00103oon000`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0@000001`3oon000`000000oooP0?ooh03o0?ooh9X0oooP
00<0003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01L0[MSV
00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>H@0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00o`3o
on2K0?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon000`000000oooP0?ooh0070?ooh0@00000o`3oon2J
0?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon001P3oon04000001P0oooP7P3jl>H1
0?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon2L0?oo
h0050000o`3oon00oooP0?ooh00cXLX0302]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPW@3oon00
10000?l0oooP0?ooh00cXLX<0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA
0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh9h0oooP00<0003o0?ooh00cXLX0302]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h9l0oooP00@0003o03>QbP00000000002P2]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:00oooP00@0003o00000000000000002@2]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:00oooP00@000000000o`00000000002P0cXLXI0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh:40oooP00<000000000o`3oon002@3oon000`0cXLX0[MSV0:gHiP0G0:gH
iP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:<0oooP00<0003o0?ooh03o
on001`3oon000`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh:@0oooP00<0003o0?ooh03oon001P3oon000`0cXLX0[MSV0:gHiP0G0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00<0003o0?ooh03oon001@3o
on000`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh:H0oooP00<0003o0?ooh03oon00103oon000`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0
[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:L0oooP00<0003o0?ooh03oon000`3oon000`0c
XLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:P0
oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon0300000?l0oooPZ@3oon001@000?l0oooP0?ooh03oon00<j7:01T0[MSV00<0<j7:0:gHiP2]
f>H0402]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2Z0?ooh0040000o`3oon00oooP03>QbQT0[MSV00<0<j7:0:gHiP2]
f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZP3oon0010000?l0oooP0?ooh00cXLXI0:gHiP03
03>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:/0oooP00<0003o0?ooh00cXLX0
6@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2/0?ooh0030000o`0c
XLX0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[@3oon00
0`000?l0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:d0oooP00<0<j7:0000o`2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2]0?ooh00303>QbP2]f>H0003o01L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP[@3oon00100cXLX0[MSV0:gHiP000?lF0:gHiP0303>QbP2]f>H0[MSV0100
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0E0:gHiP03
03>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP00<0<j7:0:gHiP2]f>H0
0P2]f>H00`000?l0[MSV0:gHiP0B0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh:d0oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l000000:gHiP0A0:gHiP0303>QbP2]
f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP1@0cXLX2000000030000o`000000
<j7:0140<j7:4P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/P3oon03000000030000o`3oon00oooP
00l0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2c0?ooh080000000<0oooP0000o`3o
on003`3oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;L0oooP00<0003o0?ooh03oon00
3@3oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh0030000o`3o
on00oooP00d0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^03oon00
0`000?l0oooP0?ooh00<0?ooh00303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;T0oooP00<0003o0?ooh03oon002`3oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2j0?ooh0030000o`3oon00oooP00X0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP^`3oon000`000?l0oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0100[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;`0oooP00<0003o0?ooh03oon00203oon000`0cXLX0[MSV0:gH
iP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2l0?ooh0030000o`3oon00oooP00P0oooP00<0<j7:
0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_@3oon000`000?l0oooP0?ooh0070?oo
h00303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;h0oooP00<0003o0?ooh03o
on001P3oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2o0?ooh0030000
o`3oon00oooP00D0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`03o
on000`000?l0oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<40oooP00<0003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon310?ooh0030000o`3oon00oooP00<0oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon320?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon330?ooh0050000o`3oon00oooP0?ooh00cXLX04P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
a03oon0010000?l0oooP0?ooh00cXLXB0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon350?ooh0030000
o`3oon00<j7:0180[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<H0oooP00<0003o03>QbP2]f>H04@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPaP3oon000`000?l0<j7:0:gHiP0A0:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon370?ooh0030000o`2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<L0
oooP00<0<j7:0000o`2]f>H0402]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa`3oon000`0cXLX0[MSV
0000o`0@0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon370?ooh00403>QbP2]f>H0[MSV0000o`l0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<L0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0>0:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon370?ooh00503>QbP2]f>H0[MSV0:gHiP000?l03P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPa`3oon000`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV00/0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh<L0oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP0:
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`00003o0?ooh<L0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP090:gH
iP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh<L0oooP00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP080:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon370?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H0
1`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPa`3oon000`0cXLX0[MSV0:gHiP070:gHiP030000o`2]
f>H0[MSV00H0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<L0oooP00<0<j7:0:gHiP2]f>H01`2]f>H0
0`000?l0[MSV0:gHiP060:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon370?ooh00303>QbP2]f>H0[MSV
00P0[MSV00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa`3oon000`0cXLX0
[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<L0oooP
00<0<j7:0:gHiP2]f>H02P2]f>H00`000?l0[MSV0:gHiP030:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on370?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPa`3oon000`0cXLX0[MSV0:gHiP0<0:gHiP050000o`00000000000:gHiP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<L0oooP00<0<j7:0:gHiP2]f>H0302]f>H01@000000003o000000000000<j7:00/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon37
0?ooh0l0<j7:00D000000000o`000000000003>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh=L0oooP00<00000
0000o`3oon00303oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon001000
0000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPf@3oon000`000?l0oooP0?ooh00:
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP
00H0oooP1000003o0?ooh=T0oooP00<0003o0?ooh03oon001P3oon04000001P0oooP7P3jl>H10?oo
o`007@3jl>HC0?ooh0030000003oon00oooP00D0oooP00<000000?ooh03oon00o`3oon3V0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0
oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<00000
0?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<00000
0?ooh03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=`0n_3V100000020?[`iPP000000P3jl>H4000000070?[`
iP00000000000000003jl>H000000?[`iP0<000000030?[`iP000000000000@0000000@0n_3V0000
000000000000203jl>H5000000@0n_3V1`0000000`3jl>H000000?[`iP03000000T0n_3V1@000002
0?[`iP@000000P3jl>H500000180n_3V1P0000060?[`iP030000003jl>H0n_3V00@0n_3V0`000000
103jl>H0000000000000003T0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P000003
0?[`iP8000000`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP800000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000
003jl>H0n_3V0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000
003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H20000
00P0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0
n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H0
00000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000d0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3j
l>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000<0?[`
iPD000001@3jl>H2000000H0n_3V1@0000060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H5000000@0
n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000
000000<000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;
0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<0
00000?[`iP3jl>H01P3jl>H300000>H0n_3V0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2
000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V
0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V
0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP0B0?[`iP80
0000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000i@3jl>H10?ooo`00
g@3jl>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H00000
0000000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<00000
00<0n_3V0000000000001`00000;0?[`iPD000000P3jl>H400000080n_3V0`0000000`3jl>H00000
0000000C0?[`iP8000003`3jl>H3000000050?[`iP00000000000000003jl>H01000003O0?[`iP40
oooo003M0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V01P0n_3V
0P00000Q0?[`iP@00000603jl>H00`000000n_3V0?[`iP3O0?[`iP40oooo003L0?[`iPH00000103j
l>H2000002l0n_3V1@00000K0?[`iP<000008@3jl>H2000001T0n_3V00<000000?[`iP3jl>H0gP3j
l>H10?ooo`00o`3jl>Ih0?[`iP030000003jl>H0n_3V0=d0n_3V0@3oool00?l0n_3VM@3jl>H01000
0000n_3V0?[`iP00003O0?[`iP40oooo003o0?[`iWH0n_3V0P00003P0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.03989 .01472 L
.03989 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.03989 .01472 L
.03989 .16187 L
s
1 .894 .882 r
.03989 .16187 m
.03989 .0157 L
.0701 .0157 L
.0701 .16187 L
F
.804 .522 .247 r
.03989 .16187 m
.03989 .0157 L
.0701 .0157 L
.0701 .16187 L
s
1 .894 .882 r
.0701 .16187 m
.0701 .01748 L
.0925 .01748 L
.0925 .16187 L
F
.804 .522 .247 r
.0701 .16187 m
.0701 .01748 L
.0925 .01748 L
.0925 .16187 L
s
1 .894 .882 r
.0925 .16187 m
.0925 .01839 L
.10876 .01839 L
.10876 .16187 L
F
.804 .522 .247 r
.0925 .16187 m
.0925 .01839 L
.10876 .01839 L
.10876 .16187 L
s
1 .894 .882 r
.10876 .16187 m
.10876 .02015 L
.1474 .02015 L
.1474 .16187 L
F
.804 .522 .247 r
.10876 .16187 m
.10876 .02015 L
.1474 .02015 L
.1474 .16187 L
s
1 .894 .882 r
.1474 .16187 m
.1474 .02481 L
.163 .02481 L
.163 .16187 L
F
.804 .522 .247 r
.1474 .16187 m
.1474 .02481 L
.163 .02481 L
.163 .16187 L
s
1 .894 .882 r
.163 .16187 m
.163 .02981 L
.18844 .02981 L
.18844 .16187 L
F
.804 .522 .247 r
.163 .16187 m
.163 .02981 L
.18844 .02981 L
.18844 .16187 L
s
1 .894 .882 r
.18844 .16187 m
.18844 .03863 L
.22263 .03863 L
.22263 .16187 L
F
.804 .522 .247 r
.18844 .16187 m
.18844 .03863 L
.22263 .03863 L
.22263 .16187 L
s
1 .894 .882 r
.22263 .16187 m
.22263 .04119 L
.2452 .04119 L
.2452 .16187 L
F
.804 .522 .247 r
.22263 .16187 m
.22263 .04119 L
.2452 .04119 L
.2452 .16187 L
s
1 .894 .882 r
.2452 .16187 m
.2452 .04669 L
.27068 .04669 L
.27068 .16187 L
F
.804 .522 .247 r
.2452 .16187 m
.2452 .04669 L
.27068 .04669 L
.27068 .16187 L
s
1 .894 .882 r
.27068 .16187 m
.27068 .06372 L
.29864 .06372 L
.29864 .16187 L
F
.804 .522 .247 r
.27068 .16187 m
.27068 .06372 L
.29864 .06372 L
.29864 .16187 L
s
1 .894 .882 r
.29864 .16187 m
.29864 .06619 L
.3171 .06619 L
.3171 .16187 L
F
.804 .522 .247 r
.29864 .16187 m
.29864 .06619 L
.3171 .06619 L
.3171 .16187 L
s
1 .894 .882 r
.3171 .16187 m
.3171 .0743 L
.36148 .0743 L
.36148 .16187 L
F
.804 .522 .247 r
.3171 .16187 m
.3171 .0743 L
.36148 .0743 L
.36148 .16187 L
s
1 .894 .882 r
.36148 .16187 m
.36148 .09282 L
.40296 .09282 L
.40296 .16187 L
F
.804 .522 .247 r
.36148 .16187 m
.36148 .09282 L
.40296 .09282 L
.40296 .16187 L
s
1 .894 .882 r
.40296 .16187 m
.40296 .11377 L
.43921 .11377 L
.43921 .16187 L
F
.804 .522 .247 r
.40296 .16187 m
.40296 .11377 L
.43921 .11377 L
.43921 .16187 L
s
1 .894 .882 r
.43921 .16187 m
.43921 .12677 L
.46375 .12677 L
.46375 .16187 L
F
.804 .522 .247 r
.43921 .16187 m
.43921 .12677 L
.46375 .12677 L
.46375 .16187 L
s
1 .894 .882 r
.46375 .16187 m
.46375 .15612 L
.49741 .15612 L
.49741 .16187 L
F
.804 .522 .247 r
.46375 .16187 m
.46375 .15612 L
.49741 .15612 L
.49741 .16187 L
s
.678 .847 .902 r
.49741 .16187 m
.49741 .16659 L
.5123 .16659 L
.5123 .16187 L
F
.2 .63 .79 r
.49741 .16187 m
.49741 .16659 L
.5123 .16659 L
.5123 .16187 L
s
.678 .847 .902 r
.5123 .16187 m
.5123 .1766 L
.5278 .1766 L
.5278 .16187 L
F
.2 .63 .79 r
.5123 .16187 m
.5123 .1766 L
.5278 .1766 L
.5278 .16187 L
s
.678 .847 .902 r
.5278 .16187 m
.5278 .18777 L
.55879 .18777 L
.55879 .16187 L
F
.2 .63 .79 r
.5278 .16187 m
.5278 .18777 L
.55879 .18777 L
.55879 .16187 L
s
.678 .847 .902 r
.55879 .16187 m
.55879 .20883 L
.58671 .20883 L
.58671 .16187 L
F
.2 .63 .79 r
.55879 .16187 m
.55879 .20883 L
.58671 .20883 L
.58671 .16187 L
s
.678 .847 .902 r
.58671 .16187 m
.58671 .23656 L
.63062 .23656 L
.63062 .16187 L
F
.2 .63 .79 r
.58671 .16187 m
.58671 .23656 L
.63062 .23656 L
.63062 .16187 L
s
.678 .847 .902 r
.63062 .16187 m
.63062 .27688 L
.67059 .27688 L
.67059 .16187 L
F
.2 .63 .79 r
.63062 .16187 m
.63062 .27688 L
.67059 .27688 L
.67059 .16187 L
s
.678 .847 .902 r
.67059 .16187 m
.67059 .28803 L
.7067 .28803 L
.7067 .16187 L
F
.2 .63 .79 r
.67059 .16187 m
.67059 .28803 L
.7067 .28803 L
.7067 .16187 L
s
.678 .847 .902 r
.7067 .16187 m
.7067 .32684 L
.73249 .32684 L
.73249 .16187 L
F
.2 .63 .79 r
.7067 .16187 m
.7067 .32684 L
.73249 .32684 L
.73249 .16187 L
s
.678 .847 .902 r
.73249 .16187 m
.73249 .3597 L
.76013 .3597 L
.76013 .16187 L
F
.2 .63 .79 r
.73249 .16187 m
.73249 .3597 L
.76013 .3597 L
.76013 .16187 L
s
.678 .847 .902 r
.76013 .16187 m
.76013 .3933 L
.79166 .3933 L
.79166 .16187 L
F
.2 .63 .79 r
.76013 .16187 m
.76013 .3933 L
.79166 .3933 L
.79166 .16187 L
s
.678 .847 .902 r
.79166 .16187 m
.79166 .41973 L
.82545 .41973 L
.82545 .16187 L
F
.2 .63 .79 r
.79166 .16187 m
.79166 .41973 L
.82545 .41973 L
.82545 .16187 L
s
.678 .847 .902 r
.82545 .16187 m
.82545 .44029 L
.85908 .44029 L
.85908 .16187 L
F
.2 .63 .79 r
.82545 .16187 m
.82545 .44029 L
.85908 .44029 L
.85908 .16187 L
s
.678 .847 .902 r
.85908 .16187 m
.85908 .48649 L
.88507 .48649 L
.88507 .16187 L
F
.2 .63 .79 r
.85908 .16187 m
.85908 .48649 L
.88507 .48649 L
.88507 .16187 L
s
.678 .847 .902 r
.88507 .16187 m
.88507 .50391 L
.9051 .50391 L
.9051 .16187 L
F
.2 .63 .79 r
.88507 .16187 m
.88507 .50391 L
.9051 .50391 L
.9051 .16187 L
s
.678 .847 .902 r
.9051 .16187 m
.9051 .5649 L
.95118 .5649 L
.95118 .16187 L
F
.2 .63 .79 r
.9051 .16187 m
.9051 .5649 L
.95118 .5649 L
.95118 .16187 L
s
.678 .847 .902 r
.95118 .16187 m
.95118 .57592 L
.97619 .57592 L
.97619 .16187 L
F
.2 .63 .79 r
.95118 .16187 m
.95118 .57592 L
.97619 .57592 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02406 .01472 Mdot
.06275 .0157 Mdot
.08911 .01748 Mdot
.09908 .01839 Mdot
.1153 .02015 Mdot
.14851 .02481 Mdot
.17631 .02981 Mdot
.21576 .03863 Mdot
.2258 .04119 Mdot
.24579 .04669 Mdot
.29862 .06372 Mdot
.30546 .06619 Mdot
.32683 .0743 Mdot
.37074 .09282 Mdot
.41449 .11377 Mdot
.43935 .12677 Mdot
.49061 .15612 Mdot
.50758 .16659 Mdot
.52327 .1766 Mdot
.54021 .18777 Mdot
.57074 .20883 Mdot
.60849 .23656 Mdot
.65942 .27688 Mdot
.67279 .28803 Mdot
.71734 .32684 Mdot
.75293 .3597 Mdot
.78762 .3933 Mdot
.81382 .41973 Mdot
.83363 .44029 Mdot
.87645 .48649 Mdot
.89205 .50391 Mdot
.94459 .5649 Mdot
.95376 .57592 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(33) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0967743) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.669381) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<000000`3jl>H3000000D0n_3V0`0000040?[`iP<0
00000`3jl>H600000?l0n_3VV`3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3j
l>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3j
l>JM0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000050?[`iP8000001@3j
l>H200000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JM0?[`iP40oooo000P
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000030?[`iP@000001@3jl>H200000080
n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JM0?[`iP40oooo000P0?[`iP800000
0P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP00
0000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V10000003
0?[`iP80000000<0n_3V0000000000000`3jl>H3000000@0n_3V0`0000050?[`iP800000o`3jl>JM
0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H40000
00030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H20000
00D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`
iP8000001@3jl>H2000000D0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H20000
00030?[`iP000000000000@0n_3V0P00003o0?[`iYd0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0
n_3V0P0000050?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V00<000000?[`iP3j
l>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H400000?l0n_3VW@3jl>H10?ooo`00
7`3jl>H6000000@0n_3V0P00000_0?[`iPD00000:03jl>H3000000`0n_3V0`0000040?[`iP<00000
0`3jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VW@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@0
0000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803j
l>H6000000050?[`iP00000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V
0P000000103jl>H000000000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0
n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0
n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000
0P3jl>H010000000n_3V0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`
iP800000103jl>H200000080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3j
l>H00000000000030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP80
0000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080
n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H200000003
0?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V
0P0000000`3jl>H00000000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V
0P0000020?[`iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`
iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P00
00000`3jl>H00000000000020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000
003jl>H300000080n_3V0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V
0P0000000`3jl>H00000000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@00000
0`3jl>H4000000H0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3j
l>H5000000<0n_3V100000030?[`iP80000000<0n_3V000000000000100000000`3jl>H000000000
00020?[`iP@00000103jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3j
l>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3o
ool00280n_3V0P00000;0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:
0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<00000
0?[`iP3jl>H00P00003o0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H40000
0340n_3V0`00000<0?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H30000
0080n_3V1@00003o0?[`iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V
00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP00
0000n_3V0P0000020?[`iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200
n_3V0`0000000`3jl>H0000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`
iP030000003jl>H0000001P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`
iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000
000000P0n_3V100000000`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP000000
00000000003jl>H000000?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000<0n_3V
0`0000050?[`iP<000001@3jl>H2000000D0n_3V0P0000040?[`iP@000000`3jl>H300000780n_3V
0@3oool00240n_3V0P0000000`3jl>H0000000000005000000040?[`iP000000000000000080n_3V
0P0000000`3jl>H00000000000090?[`iPD000002@3jl>H200000=l0n_3V0P0000040?[`iP800000
0P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0
n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000002P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`
iP80000000<0n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000040?[`
iP8000000`3jl>H2000000030?[`iP000000000000@0n_3V0P0000050?[`iP8000001@3jl>H20000
00<0n_3V00<000000?[`iP3jl>H00P00001a0?[`iP40oooo000R0?[`iP<00000:@3jl>H200000=h0
n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0
n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V00000000
00002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H20000
00@0n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H00000000000090?[`
iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000040?[`
iP8000001@3jl>H200000080n_3V1P0000050?[`iP800000L@3jl>H10?ooo`008P3jl>H3000001X0
n_3V1@00000;0?[`iP800000g@3jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0
n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H200000003
0?[`iP000000000000X0n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H20000
0080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H20000
00030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000030?[`iP@000000P3jl>H20000
00030?[`iP000000000000@0n_3V0P0000050?[`iP8000000P3jl>H00`000000n_3V0?[`iP020000
00H0n_3V0P00001a0?[`iP40oooo000Q0?[`iP80000000<0n_3V000000000000:P3jl>H200000=`0
n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000002P3jl>H3000000040?[`iP00000000000?[`iP8000000P3jl>H2
00000080n_3V0`0000000`3jl>H000000?[`iP02000000030?[`iP000000n_3V00800000603jl>H2
000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000000P3jl>H4000000H0n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V00000000
00040?[`iP<00000LP3jl>H10?ooo`00803jl>H3000000040?[`iP0000000000000002H0n_3V0P00
00000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`00
0000103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V
100000020?[`iPD000002`3jl>H3000000030?[`iP00000000000080n_3V100000020?[`iP<00000
00<0n_3V0000000000001`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP800000203jl>H2000000D0n_3V
0P0000020?[`iP040000003jl>H00000000000H0n_3V0P00001a0?[`iP40oooo001=0?[`iP800000
00<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP800000
8P3jl>H200000080n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H00`000000n_3V
0?[`iP0200000080n_3V00<000000?[`iP3jl>H00P0000030?[`iP<000000`3jl>H00`000000n_3V
0?[`iP0200000740n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P00
00040?[`iP8000001P3jl>H2000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00
000;0?[`iP<00000103jl>H3000000D0n_3V0`0000020?[`iPD000000P3jl>H5000000@0n_3V0P00
00040?[`iP<00000LP3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H00000
0000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V
00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00
803jl>H3000000030?[`iP00000000000080000000@0n_3V0000003jl>H000000P3jl>H010000000
n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;0000
00@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H30000
00030?[`iP000000000000H000006`3jl>H3000000@0n_3V0`0000310?[`iP40oooo000Q0?[`iP80
000000<0n_3V0000000000001@0000001@3jl>H00000000000000000n_3V00@000002`3jl>H50000
00T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`
iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H0
10000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00
000000000?[`iP8000000P3jl>H2000000/0n_3V1@0000090?[`iP030000003jl>H0n_3V00800000
0P3jl>H00`000000n_3V0?[`iP0200000<00n_3V0@3oool00280n_3V0`00000X0?[`iP80000000<0
n_3V000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P00
00060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
00000`3jl>H00000000000030?[`iP@00000703jl>H2000000D0n_3V0P0000300?[`iP40oooo000R
0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`iP000000
00000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2
000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H4000000d0n_3V1@00000<0?[`iP8000001@3jl>H200000<00n_3V0@3oool00240n_3V0P000000
0`3jl>H000000000000W0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP000000
000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103j
l>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000
003jl>H200000080n_3V0P00000J0?[`iP<00000103jl>H300000<40n_3V0@3oool00200n_3V0`00
0000103jl>H0000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`
iP00000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@0
00000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000<0n_3V1@00000L0?[`iP80
00001@3jl>H200000<00n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP800000
00<0n_3V000000000000403jl>H2000000`0n_3V0P00000h0?[`iP030000003jl>H0n_3V00800000
0P3jl>H00`000000n_3V0?[`iP0200000<00n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3j
l>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H200000340n_3V0`0000040?[`iP<00000`@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0n_3V
9P3oon02000006`0oooP0P0000040?ooh0800000103oon02000006/0oooP1@00001Y0?ooh0D00000
0P3oon02000000@0oooP0P00001[0?ooh0@000008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@0
00000?ooh03oon000000JP3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP0000
06`0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0070?ooh0040000003oon00oooP
000006X0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?oo
h03oon000000JP3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP06X0oooP00<0
00000?ooh03oon00J`3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP06T0oooP00<0
00000?ooh03oon008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3o
on0010000000oooP0?ooh00000090?ooh0800000K@3oon000`000000oooP0?ooh01[0?ooh0030000
003oon00oooP00P0oooP0P00001]0?ooh0030000003oon00oooP0280oooP7P3jl>H10?ooo`007@3j
l>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002@3oon000`000000
oooP0?ooh01/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon00203oon000`000000
oooP0?ooh01Z0?ooh0040000003oon00oooP000002<0oooP7P3jl>H10?ooo`007@3jl>HV0?ooh080
0000K03oon02000000X0oooP0`00001[0?ooh0800000K03oon02000000X0oooP0`00001[0?ooh080
0000903oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
5@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?oo
h01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00203oon0200000?l0
oooPg03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP
0?ooh0060?ooh0030000003oon00oooP00L0oooP1000000@0?ooh08000002`3oon0200000?l0oooP
_03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?oo
h0060?ooh0@000001P3oon02000001X0003o103oon0400000080oooP0P00003o0?ooh;@0oooP1000
000H0?ooh1h0n_3V0@3oool001d0n_3V2P3oon04000000@0oooP00<000000?ooh03oon001P3oon00
0`000000oooP0?ooh0080?ooh08000001`3oi>400`3=QCl0onCQ0?oTh@060?oTh@@0000000<0onCQ
0<f5?`3=QCl00P3=QCl80000o`030<f5?`0000000000008000000`3=QCl20?ooh0800000o`3oon2_
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP
00H0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ
00L0onCQ0P0000020?oTh@030<f5?`3oi>40onCQ00H0onCQ0P0000000`3=QCl0003o0000o`080000
o`<000003P3=QCoo0?ooh:00oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40
oooP0P0000080?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0
onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400P0000030?oTh@03
0<f5?`3oi>40000000T0003o1`3oi>4200000?l0oooPW`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00D0onCQ
00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00D0onCQ
00<0cHDo0?oTh@3oi>400P0000070?oTh@P0003o0P0000060<f5?ol0oooPV03oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>403`3oi>42000000D0003o0P3oi>400`3=QCl0oooP0?oo
h0030?ooh0800000o`3oon2A0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@
0?oTh@800000103oi>450000o`80oooP1000003o0?ooh900oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oT
h@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oT
h@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>430<f5?`D0003o00<000000<f5
?`3=QCl00P3=QCoo0?ooh8`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0
onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100
onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@030?oTh@8000001@000?oo0?ooh8`0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40
1@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`000?l0003o00<0003oo`3oon270?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0
cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0
cHDo0?oTh@3oi>402@3oi>400`3=QCl0oooP0?ooh0030?ooh0@0003o0`3oon0200000?l0oooPOP3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@08
0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@05
0?oTh@030<f5?`3oi>40onCQ00T0onCQ2P3=QCl50000o`030000003=QCl0cHDo00800000o`3oon1i
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ
00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@090?oTh@<0000010000?l20000
00P0cHDoo`3oon1`0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@03
0<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@80
00000P3oi>42000000@0003o1@3oi>400`3=QCl0oooP0?ooh03o0?ooh6h0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ00D0onCQ
00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00D0onCQ
00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00T0onCQ
00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl00000000000030?oTh@<0003o00<0onCQ000000000000
o`3oon1^0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203o
i>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>401P3o
i>440000o`/0cHDoo`3oon1T0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@
0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>
0?oTh@030<f5?`3oi>40onCQ00H0onCQ100000030000o`L0onCQ00<0cHDo0?ooh03oon00o`3oon1R
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ
00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ
00L0onCQ0P0000040?oTh@@0003o0`3oi>400`3=QCl0oooP0?ooh03o0?ooh680oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@060?oTh@<0003o00<0cHDo0?ooh03oon00o`3oon1R0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>40
1@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40
1@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40
2@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40
2@3oi>430000ool0oooPHP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403o
i>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?ooh03oon000P00
0?oo0?ooh600oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo
0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP0080oooP0`000?oo
0?ooh5d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oT
h@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oT
h@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oT
h@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00D0oooP0`000?l20?oo
h0800000o`3oon1F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@03
0<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>4;0<f5?`80003o0`0000000`3oon00
00000000003o0?ooh580oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ
00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00T0onCQ
00@000000000o`000?l0003o1000003o0?ooh540oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5
?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5
?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ00X0onCQ0P0000001@3=QCl0003o0000o`000?l0000000@0cHDoo`3oon1=0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00D0onCQ
00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00800000
0`000?l00`3oi>40cHDo0?ooh03o0?ooh4`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3o
i>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3o
i>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401@3oi>420000o`<0oooP0P00003o0?ooh4P0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40
onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40
onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40
onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40
onCQ00T0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@040<f5?`000?l0
003o0000o`<00000o`3oon150?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo
0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo
0?oTh@3oi>401P3oi>430<f5?`04000000000?l0003o0000o`l0cHDoo`3oon0h0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo
0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00H0onCQ00@0cHDo
0?oTh@3oi>40onCQ0P0000000`3oi>40003o0000o`0<0?oTh@030<f5?`3oon00oooP0?l0oooP=P3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@08
0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@05
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@08
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ00H0onCQ0`000?l90?oTh@030<f5?`3oon00oooP0?l0oooP=P3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oT
h@030<f5?`3oi>40onCQ00T0onCQ0`000?l60?oTh@030<f5?`3oon00oooP0?l0oooP=P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00`0onCQ0P000?l40?oTh@030<f5?`3oon00oooP0?l0oooP=P3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5
?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5
?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5
?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5
?`3oi>40onCQ00h0onCQ0P000?l20?oTh@030<f5?`3oon00oooP0?l0oooP=P3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ0100onCQ0P000?l00`3=QCl0oooP0?ooh03o0?ooh3H0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@05
0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@05
0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B
0?oTh@80003o0P3oon0200000?l0oooP<`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oT
h@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oT
h@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oo
h0000?l00P000?l200000?l0oooP<P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3o
i>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3o
i>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3o
i>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3o
i>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0180onCQ0`3=QCl200000080
003o3`3=QCoo0?ooh2<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ
00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0onCQ
00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@040<f5?`3oi>40onCQ0?oTh@80
000000<0onCQ0000o`000?l0303oi>400`3=QCl0oooP0?ooh03o0?ooh240oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ
0?oTh@0B0?oTh@030<f5?`3oi>40onCQ00H0onCQ0P000?l:0?oTh@030<f5?`3oon00oooP0?l0oooP
8@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oT
h@050?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oT
h@060?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oTh@3oi>40203oi>430000o`L0onCQ00<0
cHDo0?ooh03oon00o`3oon0Q0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@
0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0;
0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>404P3oi>400`3=QCl0onCQ0?oTh@0;
0?oTh@80003o1@3oi>400`3=QCl0oooP0?ooh03o0?ooh240oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oT
h@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oT
h@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oT
h@3oi>403@3oi>420000o`<0onCQ00<0cHDo0?ooh03oon00o`3oon0O0?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@03
0<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@03
0<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@03
0<f5?`3oi>40onCQ00l0onCQ0P000?l00`3oi>40cHDo0?ooh03o0?ooh280oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ
0?oTh@0B0?oTh@030<f5?`3oi>40onCQ0140onCQ0P000?oo0?ooh2<0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oT
h@0B0?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0000o`000?l00P3oon0200000?l0oooP7@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@08
0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@05
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@08
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oTh@3oi>404P3oi>400`3=QCl0oooP0?ooh002
0000o`<00000o`3oon0L0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oT
h@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oT
h@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oT
h@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0;0?oT
h@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>404P3oi>400`3=QCl0onCQ0?oTh@0B0?oT
h@@0cHDo00@000000000o`000?l000002P3=QCoo0?ooh180oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oT
h@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oT
h@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oT
h@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oT
h@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oT
h@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oTh@3oi>400P3oi>4200000080003o203oi>400`3=
QCl0oooP0?ooh03o0?ooh100oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0
onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100
onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0
onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ0180
onCQ00<0cHDo0?oTh@3oi>401P3oi>420000o`H0onCQ00<0cHDo0?ooh03oon00o`3oon0@0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00D0onCQ
00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>404P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ00P0onCQ
0P000?l40?oTh@030<f5?`3oon00oooP0?l0oooP403oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0
cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0
cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0
cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0
cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0180onCQ00<0
cHDo0?oTh@3oi>404P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@80003o0P3oi>400`3=QCl0oooP0?oo
h03o0?ooh100oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo
0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo
0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo
0?oTh@3oi>40303oi>420000o`800000o`3oon0A0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=
QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=
QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>404P3oi>400`3=
QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ00d0onCQ00@000000000o`00000000002P3=QCoo
0?ooh0H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oT
h@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oT
h@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oT
h@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oT
h@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oT
h@3oi>403@3oi>4200000080003o2@3oi>400`3=QCl0oooP0?ooh03o0?ooh0@0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oTh@3oi>403P3oi>4200000003
0?oTh@000?l0003o00L0onCQ00<0cHDo0?ooh03oon00o`3oon040?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5
?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5
?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5
?`3oi>40onCQ0180onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030000
o`3oi>40onCQ00@0onCQ00<0cHDo0?ooh03oon00o`3oon020?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3o
i>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3o
i>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5?`3o
i>40onCQ0180onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@030?oTh@80003o103o
i>400`3=QCl0oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40
onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40
onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40
onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40
onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40
onCQ0180onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@050?oTh@80003o0P3oi>40
0`3=QCl0oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ
00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ
0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ
00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ
00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ
0180onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@070?oTh@80003o00<0cHDo0?oo
h03oon00o`3oon040?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@03
0<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>404P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@03
0<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`000?l0oooP0?ooh03o0?ooh0@0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40
1@3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40
1P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oTh@3oi>40
3P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`000?l0003o0?l0oooP103oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ0180onCQ00<0cHDo0?oTh@3oi>404P3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?ooh03oon000P000?oo0?ooh080oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@05
0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@05
0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B
0?oTh@030<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oon00oooP0080oooP0P000?oo0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=
QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=
QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>404P3oi>400`3=
QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0oooP0?ooh0040?ooh0030000o`3oon00oooP0?`0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@050?oTh@03
0<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@050?oTh@03
0<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@03
0<f5?`3oi>40onCQ0180onCQ00<0cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oon00oooP00D0oooP0P000?ol0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ
0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ
0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@0>0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>404P3oi>400`3=QCl0onCQ
0?oTh@0B0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0oooP
0?ooh0070?ooh080003o00<0oooP000000000000m`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00D0onCQ00<0
cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0
cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0
cHDo0?oTh@3oi>403P3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0
cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0180onCQ00<0
cHDo0?oTh@3oi>404P3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ00T0onCQ303=
QCl010000?l000000000000000020<f5?o@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3o
i>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3o
i>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@0>0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>404P3o
i>400`3=QCl0onCQ0?oTh@0B0?oTh@030<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@090?oTh@06000000000?l0003o0000003oi>40cHDom03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@03
0<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0>0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>404P3oi>400`3=QCl0onCQ0?oTh@0B0?oTh@03
0<f5?`3oi>40onCQ00h0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@80
00000P000?l00`3=QCl0oooP0?ooh03b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>H@0?ooh0040000003oon00oooP000000L0oooP100000080?ooh>L000000P000?oX000000P0
oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh003
0000003oon00oooP0?00oooP00@0<j7:0:gHiP000?l0[MSV0P0000000`2]f>H0<j7:0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0C0:gH
iP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP0000
00L0oooP00<000000?ooh03oon00l03oon000`0cXLX0[MSV0:gHiP020000o`80000000<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0
oooP00<000000?ooh03oon00l03oon0303>QbP80000000<0003o0000000cXLX01P2]f>H00`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03d0?ooh0800000
0P000?l60:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?L0oooP00<0<j7:0000o`2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]
f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03g0?ooh00503>QbP2]f>H0003o0000o`2]f>H00P00
00000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H04`2]
f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03g
0?ooh0@0<j7:00@0003o00000000000000003`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00n`3oon0010000000003o00000000000?0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03l0?ooh003000000000?l0003o00l0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H0
0`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?h0oooP00<0<j7:0000o`2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0?0:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gH
iP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00oP3oon00100cXLX0[MSV0000o`000?l20:gHiP800000202]f>H00`0c
XLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0c
XLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0c
XLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0c
XLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00oP3oon001@0cXLX0[MSV0:gHiP2]f>H0003o
00@000001`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gH
iP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00oP3oon0503>QbP80
003o0P00000803>QbP`0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP03
03>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0D0oooP00<000000000o`3oon00
1`3oon000`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0
402]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
2`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
3P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh0L0oooP0P000?l60?ooh00303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]
f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP2@3oon000`000?l0oooP0?ooh0030?ooh00303>QbP2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0
[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0X0oooP0P000?l30?ooh00303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV
00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh0`0oooP00@0003o0?ooh03oon00<j7:302]f>H00`0c
XLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0c
XLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP3@3oon020000o`0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh0l0oooP00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3`3o
on000`0cXLX0003o0000o`0:0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0?0?ooh00503>QbP2]f>H0
[MSV0000o`2]f>H00P0000060:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0?0?ooh0@0<j7:0P000?l2
000000H0<j7:5@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh1<0oooP0P0000000`000?l000000?ooh0040?ooh00303>QbP2]f>H0[MSV
01<0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0D0?ooh08000000P000?l40?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]
f>H0402]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0H0?ooh0050000
o`3oon00oooP0?ooh00cXLX05@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00l0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0
[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh1T0oooP0P000?l00`3oon00<j7:0:gHiP0D0:gHiP0303>Q
bP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP6`3o
on000`000?l0<j7:0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<00000o`3oon0L0?ooh080003o502]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0
[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP703oon000`0cXLX0[MSV0000o`0C0:gHiP0303>QbP2]f>H0[MSV
0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP703oon00100cXLX0
[MSV0:gHiP000?lB0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0c
XLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP703oon00100cXLX0[MSV0:gHiP2]f>H20000oa00[MSV00<0<j7:0:gH
iP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0L0?ooh003
03>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP03
03>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1`0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`000?l0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP703oon000`0cXLX0[MSV0:gHiP050:gHiP80003o0P00
000:0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP703oon000`0cXLX0[MSV0:gHiP060:gHiP04000000000?l00000000000T0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0L
0?ooh0T0<j7:0P0000000`000?l0000003>QbP0903>QbQ80[MSV00<0<j7:0:gHiP2]f>H03`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H0
0`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP9P3oon0200000080003o203oon000`0cXLX0[MSV0:gHiP0@0:gH
iP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2X0oooP00<0003o0?ooh03o
on001@3oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh2/0oooP00<0003o0?ooh03oon00103oon000`0cXLX0[MSV0:gHiP0@0:gHiP0303>Q
bP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>Q
bP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>Q
bP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2`0oooP0P000?l40?ooh00303>QbP2]
f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;P3oon00
1@000?l0oooP0?ooh03oon00<j7:0180[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0_
0?ooh0040000o`3oon00oooP03>QbQ80[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?oo
h0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0`
0?ooh080003o00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0b0?ooh0030000o`2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0c
XLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP<P3oon000`0cXLX0003o0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00l0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0
[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh380oooP00<0<j7:0:gHiP000?l0402]f>H00`0cXLX0[MSV
0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV
0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0b0?ooh00303>QbP2]f>H0[MSV0080003o3P2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0b0?ooh00303>QbP2]f>H0
[MSV0080[MSV00<0003o0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0b0?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0c
XLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0c
XLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0b0?ooh00303>QbP2]f>H0[MSV00@0
[MSV0P000?l:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP
00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00l0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV
00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh380oooP00<0<j7:0:gHiP2]f>H01`2]f>H00`000?l0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP00<0<j7:
0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh380oooP00<0<j7:0:gHiP2]f>H02@2]f>H20000o`030000002]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<P3oon0<03>QbP80
000000<0003o0000000cXLX00`0cXLXA0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0n0?ooh0<00000
00D0003o0?ooh03oon00oooP03>QbP0A0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh3l0oooP0P0000001@3oon00003o
0?ooh03oon00<j7:0140[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@`3oon000`000?l0oooP03>QbP0A0:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon140?ooh0040000o`0cXLX00000000000l0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh4D0oooP0P000?l2000000h0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4D0oooP0P000000
0`000?l0000003>QbP0>03>QbP/0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<
0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon160?ooh080000000<0003o0?ooh03oon00303oon000`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0c
XLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPB@3oon000`000?l0oooP0?ooh00;0?ooh00303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0
[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1:0?ooh0030000o`3oon00oooP00X0oooP00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV
0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4/0oooP00<0
003o0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPC03oon000`000?l0oooP0?ooh008
0?ooh00303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<
0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1=0?ooh0030000o`3oon00oooP00L0oooP00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh4h0oooP00<0003o0?ooh03oon001P3oon000`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0D000001P3oon000`000000oooP
0?ooh03o0?ooh4l0oooP0P000?l60?ooh00303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
2`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
3P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?oo
h03o0?ooh540oooP00<0003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000003o
0?ooh540oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0060?ooh0@00000603oon0N
0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?oo
h5<0oooP00D0003o0?ooh03oon00oooP03>QbP0;0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:
0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1D0?oo
h0040000o`3oon00oooP03>QbP/0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<
0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPE@3oon000`000?l0oooP03>QbP0;0:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPEP3oon000`000?l0<j7:0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]
f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPE`3oon000`000?l0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPE`3o
on000`0cXLX0003o0:gHiP090:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPE`3oon00100cXLX0[MSV0000o`000?l2000000H0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1G
0?ooh00503>QbP2]f>H0[MSV000000000?l00P0000050:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPE`3oon0303>QbP80000000<0003o
0000000cXLX01@0cXLX=0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h5/0oooP0P0000000`000?l0oooP0?ooh0030?ooh00303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gH
iP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPGP3oon000`000?l0oooP0?ooh0020?ooh003
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
G`3oon001@000?l0oooP0?ooh03oon00<j7:00d0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPH03oon0010000?l0oooP0?ooh00cXLX=0:gHiP0303>QbP2]f>H0[MSV00`0
[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon0300000?l0oooPH@3oon000`000?l0oooP03>QbP0=0:gHiP0303>QbP2]f>H0[MSV00`0[MSV
00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPHP3oon000`000?l0<j7:0:gHiP0<0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh6<0oooP0P000?l<0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh6<0oooP00<0<j7:0:gHiP000?l02`2]f>H00`0cXLX0[MSV0:gHiP0<0:gH
iP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1S0?ooh00403>QbP2]f>H0[MSV0000o`X0[MSV00<0<j7:0:gH
iP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gH
iP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH`3oon001@0cXLX0[MSV0:gHiP2]f>H0003o
00T0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH`3oon000`0cXLX0
[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPH`3oon000`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH`3oon000`0cXLX0[MSV0:gH
iP040:gHiP030000o`2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPH`3oon000`0cXLX0[MSV0:gHiP050:gHiP040000o`2]f>H0000000000080[MSV00<0
<j7:0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH`3oon000`0cXLX0[MSV0:gHiP06
0:gHiP060000o`00000000000000002]f>H0<j7:3P2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH`3o
on0903>QbP04000000000?l0000000000080<j7:3P2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK@3o
on001@000000003o0?ooh03oon00<j7:00h0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV
0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6l0oooP00<0
003o0?ooh00cXLX03P2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL03oon000`000?l0<j7:0:gHiP0=
0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`00003o0?ooh740oooP0P000?l=0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh740oooP00<0<j7:0:gHiP00
0?l0302]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]
f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL@3oon00100cXLX0[MSV0:gHiP000?l;0:gHiP03
03>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1a0?ooh00503>QbP2]f>H0[MSV0:gHiP000?l02P2]f>H00`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPL@3oon000`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh740oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1a0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0003o
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL@3oon000`0cXLX0[MSV0:gHiP050:gH
iP030000o`2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh740oooP00<0<j7:0:gHiP2]
f>H01P2]f>H00`000?l0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1a0?ooh00303>Q
bP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL@3o
on000`0cXLX0[MSV0:gHiP080:gHiP050000o`2]f>H0[MSV0:gHiP0cXLX03`2]f>H00`0cXLX0[MSV
0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh740oooP00<0
<j7:0:gHiP2]f>H02@2]f>H010000?l000000000000cXLX?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL@3oon0<03>QbP0400000000
0?l00000000000l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1m0?ooh080000000<0003o0000002]f>H03P2]f>H00`0cXLX0[MSV0:gH
iP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPOP3oon02000000030000o`2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00
oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h800oooP00<0<j7:0000o`2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh800oooP00<0<j7:0:gHiP000?l03@2]f>H00`0cXLX0
[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh800oooP
00@0<j7:0:gHiP2]f>H0003o302]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh800oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`0;0:gHiP03
03>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
P03oon000`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
3P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon200?ooh00303>QbP2]
f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh800oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`000?l0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPP03oon000`0cXLX0[MSV0:gHiP050:gHiP030000o`2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon200?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0003o000000000000102]f>H00`0cXLX0
[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh800oooP
00<0<j7:0:gHiP2]f>H01P2]f>H010000000003o0000000000030:gHiP0303>QbP2]f>H0[MSV00h0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP03oon0903>QbP800000
00<0003o0000000cXLX00`0cXLX@0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh8X0oooP0P0000001@000?l0oooP0?ooh03oon00<j7:0100[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPS@3oon0010000?l0oooP0?ooh00cXLX@0:gHiP0303>Q
bP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon0300000?l0oooPSP3oon000`000?l0oooP03>QbP0@0:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPS`3oon000`000?l0<j7:0:gHiP0?0:gHiP0303>QbP2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh900oooP00<0003o0:gHiP2]f>H03P2]f>H00`0c
XLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2@0?ooh00303>QbP000?l0[MSV00h0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT03oon000`0cXLX0[MSV
0000o`0>0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh900oooP00@0
<j7:0:gHiP000?l0[MSV0P00000;0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh900oooP00@0<j7:0:gHiP2]f>H0003o0`00000:0:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh900oooP0`0cXLX010000000003o00000000000;03>QbP`0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh9@0oooP00<000000000o`3oon002P3oon000`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2F0?ooh0030000o`3oon00oooP00P0oooP00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU`3oon000`000?l0oooP0?ooh0070?oo
h00303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9P0oooP00<0003o0?ooh03o
on001P3oon000`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2I0?ooh0030000
o`3oon00oooP00D0oooP00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0@000001`3oon000`000000oooP0?oo
h03o0?ooh9X0oooP00<0003o0?ooh03oon00103oon000`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00<00000
0?ooh03oon00203oon000`000000oooP0?ooh03o0?ooh9/0oooP00<0003o0?ooh03oon000`3oon00
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ40oooP00<000000?ooh03oon001`3oon0400000?l0oooPVP3oon000`00
0?l0oooP0?ooh0030?ooh00303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon001P3oon040000
01P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03o
on00o`3oon2L0?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000
003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon2M0?ooh0050000o`3oon00oooP0?oo
h00cXLX0302]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh9h0oooP00@0003o0?ooh03o
on00<j7:302]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW`3oon000`000?l0oooP03>QbP0<0:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2P0?ooh0030000o`0cXLX0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh:40oooP00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX@3oon00
0`0cXLX0003o0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Q0?ooh00303>QbP2]f>H0003o
00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:40oooP00@0<j7:0:gHiP2]f>H0003o2@2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPX@3oon001@0cXLX0[MSV0:gHiP2]f>H0003o00P0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh:40oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2Q0?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPX@3oon000`0cXLX0[MSV0:gHiP040:gHiP030000o`00
0000000000<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon0300000?l0oooPX@3oon000`0cXLX0[MSV0:gHiP040:gHiP04000000000?l0
000000000080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPX@3oon0703>QbP80000000<0003o0000000cXLX00P0cXLX8
0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPZ@3oon000`000000003o0?ooh0020?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2[0?ooh004
0000o`3oon00oooP03>QbPP0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2/0?ooh0030000o`3oon00<j7:00P0[MSV00<0<j7:0:gHiP2]
f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2]0?ooh0030000
o`0cXLX0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2^0?ooh0030000o`2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2^0?ooh00303>QbP000?l0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2^0?ooh00403>QbP2]f>H0003o000000D0[MSV00<0<j7:0:gHiP2]f>H0502]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2^0?ooh00503>QbP0000000000
0000o`0000001@0cXLXF0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:l0oooP0`0000000`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/03oon02000000030?ooh0000?l0oooP0080
oooP00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2d0?ooh0040000o`3oon00oooP03>QbQH0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP]@3oon000`000?l0oooP03>QbP0F0:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on0300000?l0oooP]P3oon000`000?l0<j7:0:gHiP0E0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP]`3oon000`000?l0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh;L0oooP00<0003o0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2g0?ooh00303>QbP000?l0[MSV01@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]`3oon000`0cXLX0[MSV0000o`0D0:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;L0oooP00@0<j7:0:gHiP2]f>H0003o
4`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh00503>QbP2]
f>H0[MSV0:gHiP000?l04P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2g0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?oo
h00303>QbP2]f>H0[MSV00<0[MSV00<0003o0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2g0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0003o0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh00303>Q
bP2]f>H0[MSV00D0[MSV00<0003o0:gHiP2]f>H0302]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2g0?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh00303>QbP2]f>H0
[MSV00L0[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2g0?ooh00303>QbP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh;L0oooP00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]`3oon000`0cXLX0[MSV
0:gHiP090:gHiP030000o`2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP]`3oon000`0cXLX0[MSV0:gHiP0:0:gHiP030000o`2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]`3oon000`0cXLX0[MSV0:gHiP0;
0:gHiP030000o`2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP]`3oon000`0cXLX0[MSV0:gHiP0<0:gHiP030000o`2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]`3oon000`0cXLX0[MSV0:gHiP0<0:gHiP03
0000o`2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
]`3oon000`0cXLX0[MSV0:gHiP0=0:gHiP030000o`2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP]`3oon000`0cXLX0[MSV0:gHiP0>0:gHiP030000o`2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]`3oon00
0`0cXLX0[MSV0:gHiP0?0:gHiP030000o`00000000000080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP]`3oon000`0cXLX0[MSV0:gHiP0?0:gHiP06000000000?l00000
0000002]f>H0<j7:2`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]`3oon0B03>QbP80000000@0003o
0000000cXLX0<j7:2`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPbP3oon001@000000003o0?ooh03o
on00<j7:00/0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<`0oooP00<0003o0?ooh00cXLX02`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPc@3oon000`000?l0<j7:0:gHiP0:0:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh<h0
oooP00<0003o0000000000002@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3>0?ooh004000000000?l00000000000T0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<h0oooP0P0000000`000?l000000?ooh00C0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPc`3oon02000000030000o`3o
on00oooP0180oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon3A0?ooh0030000o`3oon00oooP0180oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3B0?ooh0030000o`3oon00oooP
0140oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon3C0?ooh0030000o`3oon00oooP0100oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3D0?ooh0030000o`3oon00oooP00l0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on3E0?ooh0030000o`3oon00oooP00h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3F0?ooh0030000o`3oon00oooP00d0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3G0?oo
h0030000o`3oon00oooP00`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon3G0?ooh0030000o`3oon00oooP00`0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooP
f03oon000`000?l0oooP0?ooh00;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3I0?ooh0030000
o`3oon00oooP00X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<0
00000?ooh03oon001P3oon0400000?l0oooPf@3oon000`000?l0oooP0?ooh0060?ooh0@00000603o
on0N0?[`iP40oooo000M0?[`iQ<0oooP00<000000?ooh03oon001@3oon000`000000oooP0?ooh03o
0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?oo
h03oon0000001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00
L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H400000080n_3V200000020?[`
iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V0000000000001000
0000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V00<00000
2@3jl>H500000080n_3V100000020?[`iPD000004P3jl>H6000000H0n_3V00<000000?[`iP3jl>H0
103jl>H3000000040?[`iP000000000000000>@0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000
0`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP040000
0080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P00
00000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
000F0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000i@3j
l>H10?ooo`00g@3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2
000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3j
l>H2000000`0n_3V1@0000050?[`iP8000001P3jl>H5000000H0n_3V0`00003V0?[`iP40oooo003M
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`iP80
0000203jl>H00`000000n_3V0?[`iP060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H200000080n_3V
0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H000000?[`
iP800000103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000
n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000
n_3V0180n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003U
0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H40000
00030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H20000
00D0n_3V0`0000000`3jl>H0000000000007000000/0n_3V1@0000020?[`iP@000000P3jl>H30000
00030?[`iP000000000001<0n_3V0P00000?0?[`iP<0000000D0n_3V00000000000000000?[`iP04
00000=l0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`
iP3jl>H0603jl>H200000240n_3V1000000H0?[`iP030000003jl>H0n_3V0=l0n_3V0@3oool00=`0
n_3V1P0000040?[`iP800000;`3jl>H5000001/0n_3V0`00000Q0?[`iP8000006@3jl>H00`000000
n_3V0?[`iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<000000?[`iP3jl>H0g@3jl>H10?ooo`00o`3j
l>Ie0?[`iP040000003jl>H0n_3V00000=l0n_3V0@3oool00?l0n_3VMP3jl>H200000>00n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.05353 .01472 L
.05353 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.05353 .01472 L
.05353 .16187 L
s
1 .894 .882 r
.05353 .16187 m
.05353 .01531 L
.07507 .01531 L
.07507 .16187 L
F
.804 .522 .247 r
.05353 .16187 m
.05353 .01531 L
.07507 .01531 L
.07507 .16187 L
s
1 .894 .882 r
.07507 .16187 m
.07507 .01726 L
.10042 .01726 L
.10042 .16187 L
F
.804 .522 .247 r
.07507 .16187 m
.07507 .01726 L
.10042 .01726 L
.10042 .16187 L
s
1 .894 .882 r
.10042 .16187 m
.10042 .0228 L
.13675 .0228 L
.13675 .16187 L
F
.804 .522 .247 r
.10042 .16187 m
.10042 .0228 L
.13675 .0228 L
.13675 .16187 L
s
1 .894 .882 r
.13675 .16187 m
.13675 .02506 L
.16029 .02506 L
.16029 .16187 L
F
.804 .522 .247 r
.13675 .16187 m
.13675 .02506 L
.16029 .02506 L
.16029 .16187 L
s
1 .894 .882 r
.16029 .16187 m
.16029 .02708 L
.17301 .02708 L
.17301 .16187 L
F
.804 .522 .247 r
.16029 .16187 m
.16029 .02708 L
.17301 .02708 L
.17301 .16187 L
s
1 .894 .882 r
.17301 .16187 m
.17301 .03046 L
.19821 .03046 L
.19821 .16187 L
F
.804 .522 .247 r
.17301 .16187 m
.17301 .03046 L
.19821 .03046 L
.19821 .16187 L
s
1 .894 .882 r
.19821 .16187 m
.19821 .03757 L
.21245 .03757 L
.21245 .16187 L
F
.804 .522 .247 r
.19821 .16187 m
.19821 .03757 L
.21245 .03757 L
.21245 .16187 L
s
1 .894 .882 r
.21245 .16187 m
.21245 .04233 L
.24476 .04233 L
.24476 .16187 L
F
.804 .522 .247 r
.21245 .16187 m
.21245 .04233 L
.24476 .04233 L
.24476 .16187 L
s
1 .894 .882 r
.24476 .16187 m
.24476 .04705 L
.26556 .04705 L
.26556 .16187 L
F
.804 .522 .247 r
.24476 .16187 m
.24476 .04705 L
.26556 .04705 L
.26556 .16187 L
s
1 .894 .882 r
.26556 .16187 m
.26556 .05485 L
.27966 .05485 L
.27966 .16187 L
F
.804 .522 .247 r
.26556 .16187 m
.26556 .05485 L
.27966 .05485 L
.27966 .16187 L
s
1 .894 .882 r
.27966 .16187 m
.27966 .06698 L
.30974 .06698 L
.30974 .16187 L
F
.804 .522 .247 r
.27966 .16187 m
.27966 .06698 L
.30974 .06698 L
.30974 .16187 L
s
1 .894 .882 r
.30974 .16187 m
.30974 .06782 L
.32832 .06782 L
.32832 .16187 L
F
.804 .522 .247 r
.30974 .16187 m
.30974 .06782 L
.32832 .06782 L
.32832 .16187 L
s
1 .894 .882 r
.32832 .16187 m
.32832 .07693 L
.35686 .07693 L
.35686 .16187 L
F
.804 .522 .247 r
.32832 .16187 m
.32832 .07693 L
.35686 .07693 L
.35686 .16187 L
s
1 .894 .882 r
.35686 .16187 m
.35686 .08921 L
.36928 .08921 L
.36928 .16187 L
F
.804 .522 .247 r
.35686 .16187 m
.35686 .08921 L
.36928 .08921 L
.36928 .16187 L
s
1 .894 .882 r
.36928 .16187 m
.36928 .09427 L
.38794 .09427 L
.38794 .16187 L
F
.804 .522 .247 r
.36928 .16187 m
.36928 .09427 L
.38794 .09427 L
.38794 .16187 L
s
1 .894 .882 r
.38794 .16187 m
.38794 .10759 L
.41372 .10759 L
.41372 .16187 L
F
.804 .522 .247 r
.38794 .16187 m
.38794 .10759 L
.41372 .10759 L
.41372 .16187 L
s
1 .894 .882 r
.41372 .16187 m
.41372 .12868 L
.44581 .12868 L
.44581 .16187 L
F
.804 .522 .247 r
.41372 .16187 m
.41372 .12868 L
.44581 .12868 L
.44581 .16187 L
s
1 .894 .882 r
.44581 .16187 m
.44581 .13857 L
.46776 .13857 L
.46776 .16187 L
F
.804 .522 .247 r
.44581 .16187 m
.44581 .13857 L
.46776 .13857 L
.46776 .16187 L
s
1 .894 .882 r
.46776 .16187 m
.46776 .14381 L
.47968 .14381 L
.47968 .16187 L
F
.804 .522 .247 r
.46776 .16187 m
.46776 .14381 L
.47968 .14381 L
.47968 .16187 L
s
1 .894 .882 r
.47968 .16187 m
.47968 .15191 L
.51464 .15191 L
.51464 .16187 L
F
.804 .522 .247 r
.47968 .16187 m
.47968 .15191 L
.51464 .15191 L
.51464 .16187 L
s
.678 .847 .902 r
.51464 .16187 m
.51464 .18393 L
.53708 .18393 L
.53708 .16187 L
F
.2 .63 .79 r
.51464 .16187 m
.51464 .18393 L
.53708 .18393 L
.53708 .16187 L
s
.678 .847 .902 r
.53708 .16187 m
.53708 .19255 L
.56299 .19255 L
.56299 .16187 L
F
.2 .63 .79 r
.53708 .16187 m
.53708 .19255 L
.56299 .19255 L
.56299 .16187 L
s
.678 .847 .902 r
.56299 .16187 m
.56299 .22528 L
.59975 .22528 L
.59975 .16187 L
F
.2 .63 .79 r
.56299 .16187 m
.56299 .22528 L
.59975 .22528 L
.59975 .16187 L
s
.678 .847 .902 r
.59975 .16187 m
.59975 .23047 L
.61685 .23047 L
.61685 .16187 L
F
.2 .63 .79 r
.59975 .16187 m
.59975 .23047 L
.61685 .23047 L
.61685 .16187 L
s
.678 .847 .902 r
.61685 .16187 m
.61685 .25146 L
.62962 .25146 L
.62962 .16187 L
F
.2 .63 .79 r
.61685 .16187 m
.61685 .25146 L
.62962 .25146 L
.62962 .16187 L
s
.678 .847 .902 r
.62962 .16187 m
.62962 .2622 L
.64204 .2622 L
.64204 .16187 L
F
.2 .63 .79 r
.62962 .16187 m
.62962 .2622 L
.64204 .2622 L
.64204 .16187 L
s
.678 .847 .902 r
.64204 .16187 m
.64204 .27134 L
.65432 .27134 L
.65432 .16187 L
F
.2 .63 .79 r
.64204 .16187 m
.64204 .27134 L
.65432 .27134 L
.65432 .16187 L
s
.678 .847 .902 r
.65432 .16187 m
.65432 .28567 L
.68742 .28567 L
.68742 .16187 L
F
.2 .63 .79 r
.65432 .16187 m
.65432 .28567 L
.68742 .28567 L
.68742 .16187 L
s
.678 .847 .902 r
.68742 .16187 m
.68742 .30808 L
.69934 .30808 L
.69934 .16187 L
F
.2 .63 .79 r
.68742 .16187 m
.68742 .30808 L
.69934 .30808 L
.69934 .16187 L
s
.678 .847 .902 r
.69934 .16187 m
.69934 .32717 L
.7261 .32717 L
.7261 .16187 L
F
.2 .63 .79 r
.69934 .16187 m
.69934 .32717 L
.7261 .32717 L
.7261 .16187 L
s
.678 .847 .902 r
.7261 .16187 m
.7261 .36759 L
.76369 .36759 L
.76369 .16187 L
F
.2 .63 .79 r
.7261 .16187 m
.7261 .36759 L
.76369 .36759 L
.76369 .16187 L
s
.678 .847 .902 r
.76369 .16187 m
.76369 .38132 L
.77635 .38132 L
.77635 .16187 L
F
.2 .63 .79 r
.76369 .16187 m
.76369 .38132 L
.77635 .38132 L
.77635 .16187 L
s
.678 .847 .902 r
.77635 .16187 m
.77635 .40118 L
.807 .40118 L
.807 .16187 L
F
.2 .63 .79 r
.77635 .16187 m
.77635 .40118 L
.807 .40118 L
.807 .16187 L
s
.678 .847 .902 r
.807 .16187 m
.807 .41761 L
.83153 .41761 L
.83153 .16187 L
F
.2 .63 .79 r
.807 .16187 m
.807 .41761 L
.83153 .41761 L
.83153 .16187 L
s
.678 .847 .902 r
.83153 .16187 m
.83153 .4382 L
.85091 .4382 L
.85091 .16187 L
F
.2 .63 .79 r
.83153 .16187 m
.83153 .4382 L
.85091 .4382 L
.85091 .16187 L
s
.678 .847 .902 r
.85091 .16187 m
.85091 .49246 L
.88453 .49246 L
.88453 .16187 L
F
.2 .63 .79 r
.85091 .16187 m
.85091 .49246 L
.88453 .49246 L
.88453 .16187 L
s
.678 .847 .902 r
.88453 .16187 m
.88453 .50245 L
.89851 .50245 L
.89851 .16187 L
F
.2 .63 .79 r
.88453 .16187 m
.88453 .50245 L
.89851 .50245 L
.89851 .16187 L
s
.678 .847 .902 r
.89851 .16187 m
.89851 .53129 L
.92248 .53129 L
.92248 .16187 L
F
.2 .63 .79 r
.89851 .16187 m
.89851 .53129 L
.92248 .53129 L
.92248 .16187 L
s
.678 .847 .902 r
.92248 .16187 m
.92248 .54994 L
.93506 .54994 L
.93506 .16187 L
F
.2 .63 .79 r
.92248 .16187 m
.92248 .54994 L
.93506 .54994 L
.93506 .16187 L
s
.678 .847 .902 r
.93506 .16187 m
.93506 .56223 L
.95476 .56223 L
.95476 .16187 L
F
.2 .63 .79 r
.93506 .16187 m
.93506 .56223 L
.95476 .56223 L
.95476 .16187 L
s
.678 .847 .902 r
.95476 .16187 m
.95476 .59112 L
.97619 .59112 L
.97619 .16187 L
F
.2 .63 .79 r
.95476 .16187 m
.95476 .59112 L
.97619 .59112 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02599 .01472 Mdot
.05404 .01531 Mdot
.08644 .01726 Mdot
.13542 .0228 Mdot
.15007 .02506 Mdot
.16187 .02708 Mdot
.17955 .03046 Mdot
.21146 .03757 Mdot
.23009 .04233 Mdot
.24703 .04705 Mdot
.2725 .05485 Mdot
.3076 .06698 Mdot
.30988 .06782 Mdot
.33345 .07693 Mdot
.36261 .08921 Mdot
.37394 .09427 Mdot
.40212 .10759 Mdot
.44287 .12868 Mdot
.46067 .13857 Mdot
.46983 .14381 Mdot
.48361 .15191 Mdot
.53445 .18393 Mdot
.5473 .19255 Mdot
.59344 .22528 Mdot
.60041 .23047 Mdot
.62782 .25146 Mdot
.64136 .2622 Mdot
.65266 .27134 Mdot
.66998 .28567 Mdot
.69617 .30808 Mdot
.7177 .32717 Mdot
.76122 .36759 Mdot
.77543 .38132 Mdot
.79552 .40118 Mdot
.81176 .41761 Mdot
.83164 .4382 Mdot
.88183 .49246 Mdot
.89076 .50245 Mdot
.91602 .53129 Mdot
.93198 .54994 Mdot
.94234 .56223 Mdot
.96627 .59112 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.078935) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.688076) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP80
0000103jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0
n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2
000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00
00030?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40
oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4
000000@0n_3V0`0000040?[`iP<000000`3jl>H2000000030?[`iP000000000000D0n_3V0P000002
0?[`iP@00000o`3jl>JM0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP0000000000
00800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`
iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3j
l>H00000000000090?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0P00003o0?[`
iYl0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3j
l>H09@3jl>H2000000030?[`iP000000000000X0n_3V0P0000040?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP03
0000003jl>H0n_3V008000000`3jl>H200000?l0n_3VWP3jl>H10?ooo`007`3jl>H6000000@0n_3V
0P00000_0?[`iPD00000:03jl>H3000000`0n_3V0`0000030?[`iP<00000103jl>H3000000@0n_3V
0`0000030?[`iPD00000103jl>H300000?l0n_3VW03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0
n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00
000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H00000
0000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<0
0000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H10?ooo`00
8P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V
0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H20000
0080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP80
0000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000000000T0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
0000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP800000
1@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H000000000
00020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V
0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000
000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V
0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V1000
00030?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103j
l>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P00
00050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;
0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2
000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00003o
0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00000<0?[`
iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00003o0?[`
iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V0000
00000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`
iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0
000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H00000
01P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H30000
0080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V10000000
0`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H00000
0?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000D0n_3V0P0000040?[`iP<00000
0`3jl>H3000000D0n_3V0`0000040?[`iP<00000N@3jl>H10?ooo`008@3jl>H2000000030?[`iP00
0000000000D0000000@0n_3V00000000000000000P3jl>H2000000030?[`iP000000000000T0n_3V
1@0000090?[`iP800000g`3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V
0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3j
l>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`
iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`iP800000103jl>H20000
00030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`
iP800000103jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V0000
00000000103jl>H2000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V
00800000N03jl>H10?ooo`008P3jl>H3000002T0n_3V0P00003N0?[`iP800000103jl>H200000080
n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H0
0000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000
003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP0000000000
00@0n_3V0P0000030?[`iP80000000<0n_3V0000000000001@3jl>H2000000D0n_3V0P0000050?[`
iP800000N03jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP800000g@3jl>H4000000<0
n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H0
0000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000
003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3j
l>H00000000000040?[`iP8000000`3jl>H2000000030?[`iP000000000000<0n_3V100000050?[`
iP8000001@3jl>H2000007P0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000Z0?[`iP80
0000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003j
l>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P000002
0?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00000H
0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000000000D0n_3V0P000003
0?[`iP<000000`3jl>H2000000030?[`iP000000000000<0n_3V0`0000030?[`iP030000003jl>H0
n_3V00800000N03jl>H10?ooo`00803jl>H3000000040?[`iP0000000000000002H0n_3V0P000000
0`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000
103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V1000
00020?[`iPD000002`3jl>H3000000030?[`iP00000000000080n_3V100000020?[`iP<0000000<0
n_3V0000000000001`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00
0000000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000D0n_3V0P0000020?[`iP@00000N@3jl>H10?ooo`00C@3jl>H2000000030?[`iP000000
00000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P000002
0?[`iP800000;P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H0000000000002
0?[`iP030000003jl>H0n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000020?[`iP030000003jl>H0n_3V008000000P3jl>H2000007/0n_3V0@3oool0
04h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
01T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000;0?[`iP<000000`3jl>H50000
00<0n_3V0`0000040?[`iP<00000103jl>H3000000<0n_3V1@00001h0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P000000
0`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`
iP050000003jl>H000000?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003j
l>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P000000
103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H0
5`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<00000
0P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V0000000000001P00000K0?[`iP@00000
0P3jl>H500000<00n_3V0@3oool00240n_3V0P0000000`3jl>H0000000000005000000050?[`iP00
000000000000003jl>H01000000;0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V
0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V
0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000002`3jl>H5
000000/0n_3V0P0000030?[`iP800000``3jl>H10?ooo`008P3jl>H3000002P0n_3V0P0000000`3j
l>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00030?[`iP000000000000<0n_3V1000000H0?[`iPH000000`3jl>H200000<80n_3V0@3oool00280
n_3V0`0000090?[`iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V00000000
0000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`
iP@000003@3jl>H5000000P0n_3V00<000000?[`iP3jl>H00P0000050?[`iP800000`@3jl>H10?oo
o`008@3jl>H2000000030?[`iP000000000002L0n_3V0P0000000`3jl>H000000000003L0?[`iP80
000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00040?[`iP00000000000?[`iP8000000P3jl>H2000001T0n_3V00@000000?[`iP00000000001P3j
l>H200000<00n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0
n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0
n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@00000
0P3jl>H5000000<0n_3V1@00000I0?[`iP040000003jl>H00000000000<0n_3V0P0000000`3jl>H0
0000000000300?[`iP40oooo001=0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`
iP00000000000100n_3V0P00000<0?[`iP800000>@3jl>H3000000<0n_3V0P0000000`3jl>H00000
000000300?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103j
l>H2000000H0n_3V0P00000b0?[`iP800000103jl>H300000<40n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iRH0oooP0P00001/0?ooh0800000
103oon02000000@0oooP0P00001[0?ooh0D00000J@3oon0500000080oooP0P0000040?ooh0800000
J`3oon04000002<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP
00@000000?ooh03oon000000203oon0010000000oooP0?ooh000001/0?ooh0030000003oon00oooP
06/0oooP00<000000?ooh03oon001`3oon0010000000oooP0?ooh000001Z0?ooh0030000003oon00
oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@00000
0?ooh03oon0000002`3oon000`000000oooP0?ooh01Z0?ooh0030000003oon00oooP06/0oooP00<0
00000?ooh03oon002P3oon000`000000oooP0?ooh01Y0?ooh0030000003oon00oooP02<0oooP7P3j
l>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000
2@3oon02000006d0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0080?ooh0800000
K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?oo
h000001Z0?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03oon00K03oon000`000000
oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00JP3oon0010000000
oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0n_3V9P3oon02000006`0oooP0P00000:0?ooh0<0
0000J`3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000002@0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
5@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`000000oooP0?oo
h01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00
oooP1@0000060?ooh0030000003oon00oooP00T0oooP0P00000<0?ooh0800000o`3oon3=0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP
00<000000?ooh03oon00203oon04000000X0oooP1000000=0?ooh0800000o`3oon2m0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000
00070?ooh003000000000?l0003o01P0003o0`3oon0400000?l0oooP^@3oon04000001P0oooP7P3j
l>H10?ooo`007@3jl>H:0?ooh0@00000103oon000`000000oooP0?ooh0060?ooh0030000003oon00
oooP00T0oooP0P00000<0?oTh@8000002@3oi>400`3=QCl0003o0000o`060000o`@0cHDoo`3oon2g
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP
00H0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>4200000080onCQ2P000?l:0?ooh0800000o`3oon2U0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00@0oooP2@000?l4000000@0oooP0P00003o0?ooh9h0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40
2@3oi>4@0<f5?`P0003o0`0000030?ooh0800000o`3oon2H0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403P3o
i>42000000@0cHDo00<000000000o`000?l00`000?l400000?l0oooPU`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40
onCQ00l0onCQ00<0cHDo0?oTh@3oi>400`3oi>42000000<0onCQ1@000?l20<f5?`80oooP0P00003o
0?ooh900oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0000
000000000P3oi>450000o`800000203=QCoo0?ooh8L0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0000000000050000
o`@0onCQ00<0cHDo0?ooh03oon00o`3oon250?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>400P0000040?oTh@D0
003o1@3oon0200000?l0oooPP03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0000o`000?l0
0P000?l400000?l0oooPO`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ1@3=QCl50000ool0oooPOP3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@03
0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>400`3oi>4200000080oooP10000?l0
0`3oon0000000000003o0?ooh7L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ
00@0onCQ1`3=QCl40000o`D0cHDoo`3oon1a0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>40103oi>44000000<0003o00@0onCQ0<f5?`0000000000o`3oon1]0?oo
h0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401@3oi>42000000@0
onCQ10000?l00`000000cHDo0<f5?`060<f5?ol0oooPIP3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@0<0?oTh@<000000`000?l50?oTh@030<f5
?`3oon00oooP0?l0oooPI03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`000000000000<0onCQ10000?l00`3oi>40cHDo0?oo
h03o0?ooh6D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo
0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@070?oTh@<0003o0P00003o0?ooh6<0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=
QCl0onCQ0?oTh@080?oTh@030<f5?`000000003o0080003o0P3=QCoo0?ooh600oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`0000000000008000000P000?oo0?ooh600oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ
0?oTh@080?oTh@040<f5?`3oi>40000000000080onCQ00@0cHDo0000o`000?l0003oo`3oon1M0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0
onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0
onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00`0
onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oon00oooP0?oo
h0<0003oo`3oon1J0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@040?oTh@03
0<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oon00oooP00@0oooP0P000?oo0?ooh5P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5
?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5
?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?ooh03oon001P3oon030000o`80oooP0`00003o0?ooh500oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ303=QCl30000o`<000001`3=
QCoo0?ooh4P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo
0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo
0?oTh@3oi>402P3oi>42000000<0003o1P3oi>400`3=QCl0oooP0?ooh03o0?ooh4H0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=
QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402`3oi>430000
00030?oTh@000?l0003o00@0onCQ00<0cHDo0?ooh03oon00o`3oon160?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@020?oTh@<0
003o00<0onCQ0<f5?`3oon000P00003o0?ooh4<0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40
0`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00D0onCQ0`000?l300000?l0oooP
A03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ00D0cHDo000000000?l0003o0000000:0<f5?ol0oooP
>P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ00@0cHDo0?oTh@00000000000`000?l70?oTh@030<f5
?`3oon00oooP0?l0oooP>03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40103o
i>430000o`@0onCQ00<0cHDo0?ooh03oon00o`3oon0h0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>40
0`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>40
0`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>40
0`3=QCl0onCQ0?oTh@070?oTh@80003o0P3oi>400`3=QCl0oooP0?ooh03o0?ooh3P0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=
QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=
QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00T0onCQ0P000?l0103=QCl0oooP00000000003o
0?ooh3L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oT
h@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00/0onCQ0P000?l30000
0?l0oooP=P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402`3oi>401@3=QCl0
00000000o`000?l000000080cHDoo`3oon0d0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@0;0?oTh@040<f5?`3oi>400000000000<0003o00<0oooP000000000000o`3oon0a0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0
onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0
onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00`0
onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00`0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00<0
onCQ00<0cHDo0000o`000?l00P0000050<f5?ol0oooP:`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`00000000000080003o
103oi>400`3=QCl0oooP0?ooh03o0?ooh2T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ000000000000onCQ0080003o
0P3oi>400`3=QCl0oooP0?ooh03o0?ooh2T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@<0003oo`3o
on0[0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40
onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40
onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40
onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40
onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0003o0000o`3o0?ooh2T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ
00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ
00l0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ
00X0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ
00H0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ
00H0onCQ00<0cHDo0?ooh03oon000P000?l20?ooh0800000o`3oon0Q0?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oon00oooP0080oooP0P000?l300000?l0oooP8P3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ
1P3=QCl010000000003o0000o`0000040<f5?ol0oooP7P3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>40103oi>4200000080003o0P3oi>400`3=QCl0oooP0?ooh03o0?ooh1`0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303o
i>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00P0onCQ0P000?l00`3=QCl0oooP0?oo
h03o0?ooh1`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo
0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo
0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ0P000?oo
0?ooh1d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oT
h@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00@0cHDo0?oo
h0000?l0003oo`3oon0K0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0;0?oT
h@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oT
h@040<f5?`3oon00oooP0?ooh080003oo`3oon0I0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=
QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=
QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=
QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=
QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oon00oooP00<0oooP0P000?oo0?ooh1L0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0
onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?ooh03oon001@3oon020000ool0
oooP5@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ
0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ
0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0oooP
0?ooh0070?ooh080003oo`3oon0C0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oT
h@0;0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oT
h@0:0?oTh@030<f5?`3oon00oooP00T0oooP00@0003o0?ooh00000000000o`3oon0?0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0
cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0
cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0
cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@d0cHDo0P000?l200000?l0oooP3P3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@03
0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@0<
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0<
0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@03
0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:
0?oTh@8000000P000?oo0?ooh0h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`0000090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=
QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=
QCl0onCQ0?oTh@0;0?oTh@80000000<0oooP0000o`3oon00o`3oon0:0?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0oooP0?ooh0020000o`80
oooP0P00003o0?ooh0L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00/0onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0oooP0?ooh0020?ooh080003o0`00003o0?ooh0H0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303o
i>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40303o
i>460<f5?`04000000000?l0003o00000080cHDoo`3oon040?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3o
i>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3o
i>400`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40103o
i>42000000030000o`3oi>40cHDo00800000o`3oon020?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>40
0`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>40
0`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>40
0`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>40
0`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401`3oi>42
0000o`<000000`3=QCom0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0;0?oT
h@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oT
h@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>4010000000003o0000o`000002
0?oTh@030<f5?`3oon00oooP0?/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ
00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ
00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ
00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ
00/0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ
00X0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`0000000000
0080003o00<0onCQ0<f5?`3oon00o03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3o
i>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3o
i>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3o
i>40103oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3o
i>400`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3o
i>402`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3o
i>402P3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3o
i>400P3oi>4010000?l0cHDo00000000003k0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@0;0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0
onCQ0?oTh@030?oTh@80003o0P00000>0<f5?n`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5
?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5
?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5
?`3oi>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5
?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5
?`3oi>40onCQ00<0onCQ0P0000020000o`d0onCQ00<0cHDo0?ooh03oon00jP3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3o
i>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl000000000003oi>40003o00`0onCQ
00<0cHDo0?ooh03oon00jP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3o
on02000000P0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@0;0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ00/0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>420000o`X0onCQ00<0cHDo0?ooh03oon00jP3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>402`3oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oT
h@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oT
h@0;0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oT
h@0:0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00@0onCQ0P000?l80?oTh@030<f5?`3oon00oooP0>X0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3o
on04000000P0oooPi`0000020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H@
0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00lP3oon000`000?l0oooP0?oo
h0030?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP0>0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03c0?ooh080003o0`3o
on000`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA
0?ooh0800000203oon000`000000oooP0?ooh03e0?ooh0040000o`3oon00oooP03>QbPX0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00mP3oon02
0000o`0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0>
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00n03oon000`000?l0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?P0oooP00<0<j7:0000o`00
0?l0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03h0?ooh00403>QbP2]f>H0[MSV0000o`L0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n03oon001@0cXLX0[MSV0:gHiP2]f>H0003o00H0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
n03oon000`0cXLX0[MSV0:gHiP020:gHiP80003o102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03h0?ooh00303>QbP2]f>H0[MSV00@0[MSV00D0
003o0:gHiP000000000003>QbP0<0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
2`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03h0?ooh0P0<j7:0P000?l2000000`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP0@3oon02000000030000o`000000[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP0P3oon0200000080003o2`2]f>H00`0cXLX0[MSV0:gHiP0>0:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon040?ooh00403>QbP2]f>H0003o0:gHiP8000001`2]f>H00`0c
XLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh0@0oooP0`0cXLX20000o`8000001`0cXLX@0:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh0L0oooP0P0000000`000?l000000?ooh0050?ooh00303>QbP2]f>H0[MSV00h0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh0P0oooP0P0000020000o`D0oooP00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP303oon000`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0
[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0d0oooP0P000?l20?ooh00303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh0l0oooP00<0003o0?ooh00cXLX0402]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP403oon020000oa00[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh140oooP00<0
<j7:0000o`2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4@3oon00100cXLX0[MSV0000o`00
0?l=0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0A0?ooh00503>QbP2]f>H0[MSV0:gHiP000?l0302]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP4@3oon000`0cXLX0[MSV0:gHiP020:gHiP80003o2P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP4@3oon000`0cXLX0[MSV0:gHiP040:gHiP030000o`2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh140oooP00<0<j7:0:gHiP2]f>H01@2]f>H20000o`L0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh140oooP00<0<j7:0:gHiP2]f>H01`2]f>H00`000?l0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh140oooP00<0<j7:0:gHiP2]f>H0202]f>H20000o`@0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP4@3oon000`0cXLX0[MSV0:gHiP0:0:gHiP050000o`00000000000:gHiP0cXLX0202]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh140oooP3@0cXLX01@000000003o000000000000<j7:00P0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0N0?ooh08000000P000?l2
000000L0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0O0?ooh0<0000000<0003o0000000000001P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh240oooP0P0000000`000?l0
000003>QbP0603>QbPD0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP03
03>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
8P3oon0200000080003o1@3oon000`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh2H0oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2L0oooP00D0003o
0?ooh03oon00oooP03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh2P0oooP0P000?l00`3oon00<j7:0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh2X0oooP00<0003o03>QbP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0[0?ooh0030000o`2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:`3oon000`0cXLX0003o0000o`030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2/0oooP00D0<j7:0:gHiP2]f>H0003o
0:gHiP02000000D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon0300000?l0oooP:`3oon001@0cXLX0[MSV0:gHiP2]f>H0003o00<00000
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0[0?ooh0@0<j7:00@000000000o`000?l00000102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP<03oon02000000030000o`2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh340oooP00<0<j7:0:gHiP000?l00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<@3oon00100c
XLX0[MSV0:gHiP000?l20:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0a0?ooh00403>QbP2]f>H0[MSV
0:gHiP80003o00<000000:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh340oooP100cXLX2000000030000o`000000[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0e0?ooh0<0000000<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3H0oooP0P0000000`2]f>H0003o
0000o`020:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP=`3oon001@0cXLX0[MSV0:gHiP2]f>H0003o008000003`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0g0?ooh00603>QbP2]f>H0[MSV0:gHiP000000
003o0P00000>0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP
100cXLX2000000030000o`000000[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP?03oon0200000080003o3@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0m0?ooh00403>QbP2]f>H0[MSV0000o``0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP?@3oon001@0cXLX0[MSV0:gHiP2]f>H0003o00/0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0m0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00L0oooP0`00000H
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3d0oooP00<0<j7:0:gH
iP2]f>H00`2]f>H00`000?l00000000000070:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh3d0oooP00<0<j7:0:gHiP2]f>H00`2]f>H010000000003o0000000000060:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3d0oooP1P0cXLX200000080
003o1`0cXLX50:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon140?ooh080000000<0oooP0000o`3oon00
103oon000`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon180?ooh0030000o`3o
on00oooP0080oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB@3oon00
1@000?l0oooP0?ooh03oon00<j7:00D0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4X0oooP00@0003o
0?ooh03oon00<j7:1@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB`3oon000`000?l0oooP03>QbP05
0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1<0?ooh0030000o`0cXLX0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh4d0oooP00<0003o0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP03
03>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
C@3oon000`0cXLX0003o0:gHiP030:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0oooPC@3o
on00100cXLX0[MSV0000o`000?l20000000303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?oo
h03o0?ooh4d0oooP00D0<j7:0:gHiP2]f>H000000000o`02000000`0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon0400000?l0oooPC03o
on0303>QbP80000000<0003o0000002]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HB
0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1A0?ooh080000000<0003o
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`00
0000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPD`3oon000`0cXLX0003o0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000
oooP0?ooh03o0?ooh5<0oooP00<0<j7:0:gHiP000?l02P2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5<0oooP00@0<j7:0:gHiP2]f>H0
003o2@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh5<0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`080:gHiP0303>QbP2]f>H0[MSV00l0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPD`3oon000`0cXLX0[MSV
0:gHiP020:gHiP030000o`2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1C0?ooh00303>QbP2]f>H0[MSV00<0[MSV0P00
0?l2000000<0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1C0?ooh00303>QbP2]f>H0[MSV00@0[MSV00@000000000o`00000000000P2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh5<0oooP1`0cXLX2000000030000o`000000<j7:0080<j7:4@2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1K0?ooh080000000@0003o0?ooh03oon00<j7:4@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1N0?ooh0030000o`3oon00<j7:
0140[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPG`3oon000`000?l0
<j7:0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh600oooP
00<0003o0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh600oooP00<0
<j7:0000o`2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00L0oooP0`00
000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh600oooP00<0<j7:
0:gHiP000?l03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?oo
h00303>QbP2]f>H0[MSV0080003o3@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1P0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?ooh00303>QbP2]f>H0[MSV00<0[MSV
00<0003o0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1P0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0003o0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?ooh00303>QbP2]f>H0[MSV00D0[MSV00<0003o
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?oo
h00303>QbP2]f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1P0?ooh00303>QbP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?ooh00303>Q
bP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1P0?ooh00303>QbP2]f>H0[MSV00T0[MSV00<0003o0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?ooh00303>QbP2]f>H0
[MSV00X0[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1P0?ooh00303>QbP2]f>H0[MSV00/0[MSV00D0003o0:gHiP2]f>H0[MSV03>QbP06
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1P0?ooh00303>QbP2]f>H0[MSV00`0[MSV00@0003o0:gH
iP00000000001P2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH03oon000`0cXLX0[MSV0:gHiP0=0:gH
iP040000o`0000000000000000D0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPH03oon0@03>QbP04000000000?l0003o
000000D0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPL@3oon02000000030000o`2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh780oooP00<0<j7:0:gHiP000?l0102]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
LP3oon00100cXLX0[MSV0:gHiP000?l30:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1b0?ooh00503>Q
bP2]f>H0[MSV0:gHiP000?l00P2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPLP3oon000`0cXLX0[MSV
0:gHiP020:gHiP030000o`000000000000d0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1b0?ooh0D0<j7:00@000000000o`0000000000
302]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh7L0oooP0P0000000`000?l000000:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPN03oon02000000030000o`2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1i0?ooh00303>QbP2]f>H0003o00/0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1i0?ooh00403>QbP2]f>H0[MSV0000
o`X0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1i0?ooh00503>QbP2]f>H0[MSV0:gHiP000?l02@2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7T0oooP00<0<j7:0:gHiP2]
f>H00P2]f>H00`000?l0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPN@3oon000`0cXLX0[MSV0:gHiP030:gHiP030000
o`2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
003o0?ooh7T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l00000000000040:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1i0?ooh00303>QbP2]f>H0
[MSV00@0[MSV00@000000000o`00000000000`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7T0oooP1`0cXLX2000000030000o`000000
<j7:00<0<j7:2`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon210?oo
h080000000D0003o0?ooh03oon00oooP03>QbP0;0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh8@0oooP00@0003o0?ooh03oon00<j7:2`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon250?ooh0030000o`3oon00<j7:00/0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQP3oon000`000?l0<j7:0:gHiP0:0:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8L0oooP00<0003o0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon270?ooh00403>QbP00
0?l00000000000P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQ`3o
on000`0cXLX000000000o`02000000L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPQ`3oon001@0cXLX00000000000000?l0000000P0<j7:2@2]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPR@3oon02000000030000o`3oon00oooP00D0oooP00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPS03oon000`000?l0oooP0?ooh0040?ooh00303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh8d0oooP00<0003o0?ooh03oon000`3oon000`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP0`00003o0?ooh8h0oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8l0oooP00D0003o0?ooh03oon00oooP03>QbP090:gHiP0303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2@0?ooh0040000o`3oon00oooP03>QbPT0[MSV00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh940oooP00<0003o0?ooh00cXLX02@2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPTP3oon00
0`000?l00000000000080:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2B0?ooh0040000o`0000000000
000000L0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh980oooP00@000000000o`0000000000200cXLX?
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPT`3oon000`000000003o0?ooh0070?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2E0?ooh003
0000o`3oon00oooP00D0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9H0oooP00<0003o0?ooh03oon00
103oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPU`3oon000`000?l0oooP0?ooh0030?ooh00303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2H0?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h9T0oooP00D0003o0?ooh03oon00oooP03>QbP0?0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>H@0?ooh0@000001`3oon000`000000oooP0?ooh03o0?ooh9X0oooP00@0003o0?oo
h03oon00<j7:3`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`00
0000oooP0?ooh0080?ooh0030000003oon00oooP0?l0oooPV`3oon000`000?l0oooP03>QbP0?0:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0030000003oon00oooP00L0
oooP1000003o0?ooh9X0oooP00<0003o0?ooh00cXLX03`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon001P3oon04000001P0oooP7P3jl>H10?ooo`00
7@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon2L0?ooh0030000
o`0cXLX0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@0
00000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh9d0oooP00<0003o0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<0
00000?ooh03oon00o`3oon2M0?ooh00303>QbP000?l0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2M0?ooh00303>QbP2]f>H0
003o00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2M0?ooh00403>QbP2]f>H0[MSV0000o``0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2M0?ooh00503>QbP2]f>H0[MSV
0:gHiP000?l02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh9d0oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPW@3oon000`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2M0?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0003o0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9d0oooP00<0<j7:0:gHiP2]f>H01@2]
f>H00`000?l0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPW@3oon000`0cXLX0[MSV0:gHiP060:gHiP030000o`2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2M0?ooh00303>QbP2]f>H0[MSV00L0[MSV00<0003o0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9d0
oooP00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2M0?ooh00303>QbP2]f>H0[MSV00T0[MSV
00D0003o0:gHiP2]f>H0[MSV03>QbP060:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03o
on001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
W@3oon000`0cXLX0[MSV0:gHiP0:0:gHiP040000o`2]f>H0[MSV03>QbPH0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW@3oon000`0cXLX0[MSV0:gHiP0:0:gHiP040000
o`000000000003>QbPH0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
W@3oon0=03>QbP04000000000?l00000000000H0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPZP3oon02000000030000o`000000[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPZ`3oon02000000030000o`2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[@3oon000`0cXLX0003o0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP00<0<j7:0:gH
iP000?l00P0000020:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0
oooP0P0cXLX010000000003o00000000000203>QbP/0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:l0
oooP0P00000010000?l000000?ooh00cXLX;0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2`0?ooh080
000000<0003o0?ooh00cXLX02`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/`3oon000`000?l0<j7:
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2d0?ooh0030000o`2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;@0oooP00<0<j7:0000o`2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2d0?oo
h00303>QbP2]f>H0003o00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]03oon00100cXLX0[MSV0:gHiP000?l80:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2d0?ooh00403>QbP2]f>H0[MSV0000o`P0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh;@0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`070:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2d0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP]03oon000`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;@0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2d0?ooh00303>QbP2]f>H0[MSV00D0[MSV00D0003o
0000002]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP]03oon0703>QbP04000000000?l0000000000080<j7:1@2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh;/0oooP0P00000010000?l000000?ooh00cXLX50:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_03oon02000000030000o`3oon00
<j7:00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2o0?ooh0030000o`0cXLX0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon300?ooh0030000o`2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon300?ooh00303>QbP000?l0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon300?ooh00303>QbP000?l0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh<00oooP00<0<j7:
0:gHiP000?l00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP`03oon00100cXLX0[MSV0:gHiP000?l20000000303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`03oon0303>QbP04000000000?l00000
000000T0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP``3oon020000
00030000o`000000[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPa03oon02000000030000o`2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPaP3oon000`000?l0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<H0oooP00<0<j7:0000o`2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon360?ooh00303>QbP2]f>H0003o008000001@2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon360?ooh080<j7:00@000000000
o`00000000001@0cXLX90:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon380?ooh080000000<0003o0000
003oon000`3oon000`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?ooh080
000000<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon3;0?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPc03oon001@000?l0oooP0?ooh03oon00<j7:00T0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh<d0oooP00@0003o0?ooh03oon00<j7:2@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon3>0?ooh0030000o`3o
on00<j7:00T0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPc`3oon000`000?l0<j7:0:gHiP080:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon3@0?ooh0030000o`2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=00
oooP00<0<j7:0000o`2]f>H01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd03oon000`0cXLX0003o
0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3@0?ooh00303>QbP2]f>H0003o00L0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh=00oooP00@0<j7:0:gHiP2]f>H0003o1P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPd03oon001@0cXLX0[MSV0:gHiP2]f>H0003o008000000`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPd03oon001P0cXLX0[MSV0:gHiP2]f>H000000000o`8000000P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPd03oon0403>QbP80000000<0003o0000000cXLX00P0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe@3oon02
000000030000o`3oon00oooP00`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon3G0?ooh0030000o`3oon00oooP00`0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0
oooPf03oon000`000?l0oooP0?ooh00;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3I0?ooh003
0000o`3oon00oooP00X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP
00<000000?ooh03oon001P3oon0400000?l0oooPf@3oon000`000?l0oooP0?ooh0060?ooh0@00000
603oon0N0?[`iP40oooo000M0?[`iQ<0oooP00<000000?ooh03oon001@3oon000`000000oooP0?oo
h03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@00000
0?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03o
on00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H400000080n_3V20000002
0?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V000000000000
10000000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V00<0
00002@3jl>H500000080n_3V100000020?[`iPD000004P3jl>H6000000H0n_3V00<000000?[`iP3j
l>H0103jl>H3000000040?[`iP000000000000000>@0n_3V0@3oool00=d0n_3V0P0000020?[`iP80
00000`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP04
00000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
000000T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V
0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V
0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000
i@3jl>H10?ooo`00g@3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3j
l>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000
003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP800000
0P3jl>H2000000`0n_3V1@0000050?[`iP8000001P3jl>H5000000H0n_3V0`00003V0?[`iP40oooo
003M0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80
000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3j
l>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`
iP800000203jl>H00`000000n_3V0?[`iP060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H200000080
n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H00000
0?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP00
0000n_3V0180n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000
003U0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4
000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2
000000D0n_3V0`0000000`3jl>H0000000000007000000/0n_3V1@0000020?[`iP@000000P3jl>H3
000000030?[`iP000000000001<0n_3V0P00000?0?[`iP<0000000D0n_3V00000000000000000?[`
iP0400000=l0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<00000
0?[`iP3jl>H0603jl>H200000240n_3V1000000H0?[`iP030000003jl>H0n_3V0=l0n_3V0@3oool0
0=`0n_3V1P0000040?[`iP800000;`3jl>H5000001/0n_3V0`00000Q0?[`iP8000006@3jl>H00`00
0000n_3V0?[`iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<000000?[`iP3jl>H0g@3jl>H10?ooo`00
o`3jl>Ie0?[`iP040000003jl>H0n_3V00000=l0n_3V0@3oool00?l0n_3VMP3jl>H200000>00n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01474 L
.03286 .01474 L
.03286 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01474 L
.03286 .01474 L
.03286 .16187 L
s
1 .894 .882 r
.03286 .16187 m
.03286 .01484 L
.05184 .01484 L
.05184 .16187 L
F
.804 .522 .247 r
.03286 .16187 m
.03286 .01484 L
.05184 .01484 L
.05184 .16187 L
s
1 .894 .882 r
.05184 .16187 m
.05184 .01554 L
.06473 .01554 L
.06473 .16187 L
F
.804 .522 .247 r
.05184 .16187 m
.05184 .01554 L
.06473 .01554 L
.06473 .16187 L
s
1 .894 .882 r
.06473 .16187 m
.06473 .01632 L
.08509 .01632 L
.08509 .16187 L
F
.804 .522 .247 r
.06473 .16187 m
.06473 .01632 L
.08509 .01632 L
.08509 .16187 L
s
1 .894 .882 r
.08509 .16187 m
.08509 .0179 L
.10553 .0179 L
.10553 .16187 L
F
.804 .522 .247 r
.08509 .16187 m
.08509 .0179 L
.10553 .0179 L
.10553 .16187 L
s
1 .894 .882 r
.10553 .16187 m
.10553 .01983 L
.12773 .01983 L
.12773 .16187 L
F
.804 .522 .247 r
.10553 .16187 m
.10553 .01983 L
.12773 .01983 L
.12773 .16187 L
s
1 .894 .882 r
.12773 .16187 m
.12773 .02336 L
.13989 .02336 L
.13989 .16187 L
F
.804 .522 .247 r
.12773 .16187 m
.12773 .02336 L
.13989 .02336 L
.13989 .16187 L
s
1 .894 .882 r
.13989 .16187 m
.13989 .02496 L
.1629 .02496 L
.1629 .16187 L
F
.804 .522 .247 r
.13989 .16187 m
.13989 .02496 L
.1629 .02496 L
.1629 .16187 L
s
1 .894 .882 r
.1629 .16187 m
.1629 .03117 L
.18436 .03117 L
.18436 .16187 L
F
.804 .522 .247 r
.1629 .16187 m
.1629 .03117 L
.18436 .03117 L
.18436 .16187 L
s
1 .894 .882 r
.18436 .16187 m
.18436 .03589 L
.20911 .03589 L
.20911 .16187 L
F
.804 .522 .247 r
.18436 .16187 m
.18436 .03589 L
.20911 .03589 L
.20911 .16187 L
s
1 .894 .882 r
.20911 .16187 m
.20911 .03767 L
.23116 .03767 L
.23116 .16187 L
F
.804 .522 .247 r
.20911 .16187 m
.20911 .03767 L
.23116 .03767 L
.23116 .16187 L
s
1 .894 .882 r
.23116 .16187 m
.23116 .04349 L
.24037 .04349 L
.24037 .16187 L
F
.804 .522 .247 r
.23116 .16187 m
.23116 .04349 L
.24037 .04349 L
.24037 .16187 L
s
1 .894 .882 r
.24037 .16187 m
.24037 .04599 L
.24894 .04599 L
.24894 .16187 L
F
.804 .522 .247 r
.24037 .16187 m
.24037 .04599 L
.24894 .04599 L
.24894 .16187 L
s
1 .894 .882 r
.24894 .16187 m
.24894 .04989 L
.27492 .04989 L
.27492 .16187 L
F
.804 .522 .247 r
.24894 .16187 m
.24894 .04989 L
.27492 .04989 L
.27492 .16187 L
s
1 .894 .882 r
.27492 .16187 m
.27492 .05885 L
.29835 .05885 L
.29835 .16187 L
F
.804 .522 .247 r
.27492 .16187 m
.27492 .05885 L
.29835 .05885 L
.29835 .16187 L
s
1 .894 .882 r
.29835 .16187 m
.29835 .06641 L
.3146 .06641 L
.3146 .16187 L
F
.804 .522 .247 r
.29835 .16187 m
.29835 .06641 L
.3146 .06641 L
.3146 .16187 L
s
1 .894 .882 r
.3146 .16187 m
.3146 .07216 L
.33832 .07216 L
.33832 .16187 L
F
.804 .522 .247 r
.3146 .16187 m
.3146 .07216 L
.33832 .07216 L
.33832 .16187 L
s
1 .894 .882 r
.33832 .16187 m
.33832 .0814 L
.3642 .0814 L
.3642 .16187 L
F
.804 .522 .247 r
.33832 .16187 m
.33832 .0814 L
.3642 .0814 L
.3642 .16187 L
s
1 .894 .882 r
.3642 .16187 m
.3642 .09839 L
.38914 .09839 L
.38914 .16187 L
F
.804 .522 .247 r
.3642 .16187 m
.3642 .09839 L
.38914 .09839 L
.38914 .16187 L
s
1 .894 .882 r
.38914 .16187 m
.38914 .10403 L
.41581 .10403 L
.41581 .16187 L
F
.804 .522 .247 r
.38914 .16187 m
.38914 .10403 L
.41581 .10403 L
.41581 .16187 L
s
1 .894 .882 r
.41581 .16187 m
.41581 .11695 L
.42581 .11695 L
.42581 .16187 L
F
.804 .522 .247 r
.41581 .16187 m
.41581 .11695 L
.42581 .11695 L
.42581 .16187 L
s
1 .894 .882 r
.42581 .16187 m
.42581 .12558 L
.4375 .12558 L
.4375 .16187 L
F
.804 .522 .247 r
.42581 .16187 m
.42581 .12558 L
.4375 .12558 L
.4375 .16187 L
s
1 .894 .882 r
.4375 .16187 m
.4375 .13043 L
.45549 .13043 L
.45549 .16187 L
F
.804 .522 .247 r
.4375 .16187 m
.4375 .13043 L
.45549 .13043 L
.45549 .16187 L
s
1 .894 .882 r
.45549 .16187 m
.45549 .14326 L
.47207 .14326 L
.47207 .16187 L
F
.804 .522 .247 r
.45549 .16187 m
.45549 .14326 L
.47207 .14326 L
.47207 .16187 L
s
1 .894 .882 r
.47207 .16187 m
.47207 .14909 L
.48107 .14909 L
.48107 .16187 L
F
.804 .522 .247 r
.47207 .16187 m
.47207 .14909 L
.48107 .14909 L
.48107 .16187 L
s
1 .894 .882 r
.48107 .16187 m
.48107 .15876 L
.50062 .15876 L
.50062 .16187 L
F
.804 .522 .247 r
.48107 .16187 m
.48107 .15876 L
.50062 .15876 L
.50062 .16187 L
s
.678 .847 .902 r
.50062 .16187 m
.50062 .16953 L
.51378 .16953 L
.51378 .16187 L
F
.2 .63 .79 r
.50062 .16187 m
.50062 .16953 L
.51378 .16953 L
.51378 .16187 L
s
.678 .847 .902 r
.51378 .16187 m
.51378 .17604 L
.53685 .17604 L
.53685 .16187 L
F
.2 .63 .79 r
.51378 .16187 m
.51378 .17604 L
.53685 .17604 L
.53685 .16187 L
s
.678 .847 .902 r
.53685 .16187 m
.53685 .18886 L
.55226 .18886 L
.55226 .16187 L
F
.2 .63 .79 r
.53685 .16187 m
.53685 .18886 L
.55226 .18886 L
.55226 .16187 L
s
.678 .847 .902 r
.55226 .16187 m
.55226 .20251 L
.57645 .20251 L
.57645 .16187 L
F
.2 .63 .79 r
.55226 .16187 m
.55226 .20251 L
.57645 .20251 L
.57645 .16187 L
s
.678 .847 .902 r
.57645 .16187 m
.57645 .21907 L
.58551 .21907 L
.58551 .16187 L
F
.2 .63 .79 r
.57645 .16187 m
.57645 .21907 L
.58551 .21907 L
.58551 .16187 L
s
.678 .847 .902 r
.58551 .16187 m
.58551 .22516 L
.59363 .22516 L
.59363 .16187 L
F
.2 .63 .79 r
.58551 .16187 m
.58551 .22516 L
.59363 .22516 L
.59363 .16187 L
s
.678 .847 .902 r
.59363 .16187 m
.59363 .23137 L
.61443 .23137 L
.61443 .16187 L
F
.2 .63 .79 r
.59363 .16187 m
.59363 .23137 L
.61443 .23137 L
.61443 .16187 L
s
.678 .847 .902 r
.61443 .16187 m
.61443 .25294 L
.64072 .25294 L
.64072 .16187 L
F
.2 .63 .79 r
.61443 .16187 m
.61443 .25294 L
.64072 .25294 L
.64072 .16187 L
s
.678 .847 .902 r
.64072 .16187 m
.64072 .2708 L
.65457 .2708 L
.65457 .16187 L
F
.2 .63 .79 r
.64072 .16187 m
.64072 .2708 L
.65457 .2708 L
.65457 .16187 L
s
.678 .847 .902 r
.65457 .16187 m
.65457 .28587 L
.68033 .28587 L
.68033 .16187 L
F
.2 .63 .79 r
.65457 .16187 m
.65457 .28587 L
.68033 .28587 L
.68033 .16187 L
s
.678 .847 .902 r
.68033 .16187 m
.68033 .29506 L
.70061 .29506 L
.70061 .16187 L
F
.2 .63 .79 r
.68033 .16187 m
.68033 .29506 L
.70061 .29506 L
.70061 .16187 L
s
.678 .847 .902 r
.70061 .16187 m
.70061 .31407 L
.70898 .31407 L
.70898 .16187 L
F
.2 .63 .79 r
.70061 .16187 m
.70061 .31407 L
.70898 .31407 L
.70898 .16187 L
s
.678 .847 .902 r
.70898 .16187 m
.70898 .32556 L
.72625 .32556 L
.72625 .16187 L
F
.2 .63 .79 r
.70898 .16187 m
.70898 .32556 L
.72625 .32556 L
.72625 .16187 L
s
.678 .847 .902 r
.72625 .16187 m
.72625 .33705 L
.74382 .33705 L
.74382 .16187 L
F
.2 .63 .79 r
.72625 .16187 m
.72625 .33705 L
.74382 .33705 L
.74382 .16187 L
s
.678 .847 .902 r
.74382 .16187 m
.74382 .3678 L
.76723 .3678 L
.76723 .16187 L
F
.2 .63 .79 r
.74382 .16187 m
.74382 .3678 L
.76723 .3678 L
.76723 .16187 L
s
.678 .847 .902 r
.76723 .16187 m
.76723 .37383 L
.77656 .37383 L
.77656 .16187 L
F
.2 .63 .79 r
.76723 .16187 m
.76723 .37383 L
.77656 .37383 L
.77656 .16187 L
s
.678 .847 .902 r
.77656 .16187 m
.77656 .39474 L
.79574 .39474 L
.79574 .16187 L
F
.2 .63 .79 r
.77656 .16187 m
.77656 .39474 L
.79574 .39474 L
.79574 .16187 L
s
.678 .847 .902 r
.79574 .16187 m
.79574 .41796 L
.81349 .41796 L
.81349 .16187 L
F
.2 .63 .79 r
.79574 .16187 m
.79574 .41796 L
.81349 .41796 L
.81349 .16187 L
s
.678 .847 .902 r
.81349 .16187 m
.81349 .42513 L
.83496 .42513 L
.83496 .16187 L
F
.2 .63 .79 r
.81349 .16187 m
.81349 .42513 L
.83496 .42513 L
.83496 .16187 L
s
.678 .847 .902 r
.83496 .16187 m
.83496 .44379 L
.85945 .44379 L
.85945 .16187 L
F
.2 .63 .79 r
.83496 .16187 m
.83496 .44379 L
.85945 .44379 L
.85945 .16187 L
s
.678 .847 .902 r
.85945 .16187 m
.85945 .46961 L
.8687 .46961 L
.8687 .16187 L
F
.2 .63 .79 r
.85945 .16187 m
.85945 .46961 L
.8687 .46961 L
.8687 .16187 L
s
.678 .847 .902 r
.8687 .16187 m
.8687 .4791 L
.87792 .4791 L
.87792 .16187 L
F
.2 .63 .79 r
.8687 .16187 m
.8687 .4791 L
.87792 .4791 L
.87792 .16187 L
s
.678 .847 .902 r
.87792 .16187 m
.87792 .4997 L
.89844 .4997 L
.89844 .16187 L
F
.2 .63 .79 r
.87792 .16187 m
.87792 .4997 L
.89844 .4997 L
.89844 .16187 L
s
.678 .847 .902 r
.89844 .16187 m
.89844 .51663 L
.91144 .51663 L
.91144 .16187 L
F
.2 .63 .79 r
.89844 .16187 m
.89844 .51663 L
.91144 .51663 L
.91144 .16187 L
s
.678 .847 .902 r
.91144 .16187 m
.91144 .53371 L
.93437 .53371 L
.93437 .16187 L
F
.2 .63 .79 r
.91144 .16187 m
.91144 .53371 L
.93437 .53371 L
.93437 .16187 L
s
.678 .847 .902 r
.93437 .16187 m
.93437 .56419 L
.94738 .56419 L
.94738 .16187 L
F
.2 .63 .79 r
.93437 .16187 m
.93437 .56419 L
.94738 .56419 L
.94738 .16187 L
s
.678 .847 .902 r
.94738 .16187 m
.94738 .57112 L
.96054 .57112 L
.96054 .16187 L
F
.2 .63 .79 r
.94738 .16187 m
.94738 .57112 L
.96054 .57112 L
.96054 .16187 L
s
.678 .847 .902 r
.96054 .16187 m
.96054 .60291 L
.97619 .60291 L
.97619 .16187 L
F
.2 .63 .79 r
.96054 .16187 m
.96054 .60291 L
.97619 .60291 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.03049 .01474 Mdot
.0378 .01484 Mdot
.0595 .01554 Mdot
.07356 .01632 Mdot
.09388 .0179 Mdot
.11258 .01983 Mdot
.1392 .02336 Mdot
.14949 .02496 Mdot
.18306 .03117 Mdot
.20444 .03589 Mdot
.21189 .03767 Mdot
.23438 .04349 Mdot
.24335 .04599 Mdot
.25662 .04989 Mdot
.28459 .05885 Mdot
.30606 .06641 Mdot
.32134 .07216 Mdot
.34436 .0814 Mdot
.38289 .09839 Mdot
.39479 .10403 Mdot
.42073 .11695 Mdot
.43715 .12558 Mdot
.44609 .13043 Mdot
.46888 .14326 Mdot
.47885 .14909 Mdot
.49495 .15876 Mdot
.51225 .16953 Mdot
.5224 .17604 Mdot
.54184 .18886 Mdot
.56175 .20251 Mdot
.58497 .21907 Mdot
.59328 .22516 Mdot
.60162 .23137 Mdot
.6297 .25294 Mdot
.65199 .2708 Mdot
.67022 .28587 Mdot
.68108 .29506 Mdot
.703 .31407 Mdot
.71591 .32556 Mdot
.72859 .33705 Mdot
.76144 .3678 Mdot
.76771 .37383 Mdot
.78907 .39474 Mdot
.81209 .41796 Mdot
.81908 .42513 Mdot
.83695 .44379 Mdot
.86106 .46961 Mdot
.86974 .4791 Mdot
.88831 .4997 Mdot
.90327 .51663 Mdot
.91811 .53371 Mdot
.94399 .56419 Mdot
.94977 .57112 Mdot
.97586 .60291 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(54) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0560074) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.659831) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<000000`3jl>H3000000D0n_3V0`0000040?[`iP<0
00000`3jl>H600000?l0n_3VV`3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P0000040?[`iP8000000`3j
l>H2000000030?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P0000040?[`iP800000o`3j
l>JM0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3j
l>H2000000030?[`iP000000000000D0n_3V0P0000050?[`iP8000000P3jl>H2000000030?[`iP00
0000000000D0n_3V0P0000040?[`iP800000o`3jl>JM0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000000000D0
n_3V0P0000030?[`iP@000000P3jl>H2000000030?[`iP000000000000D0n_3V0P0000040?[`iP80
0000o`3jl>JM0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V
0000000000002@3jl>H4000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V
0000000000000`3jl>H3000000@0n_3V0`0000050?[`iP800000o`3jl>JM0?[`iP40oooo000P0?[`
iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP0000000000
00D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3j
l>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H40000
00<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H20000
00@0n_3V0P00003o0?[`iYd0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0
n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0n_3V0P0000040?[`iP80
00001@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP03
0000003jl>H0n_3V008000000P3jl>H400000?l0n_3VW@3jl>H10?ooo`007`3jl>H6000000@0n_3V
0P00000_0?[`iPD00000:03jl>H3000000`0n_3V0`0000020?[`iPD000000`3jl>H3000000@0n_3V
0`0000040?[`iP<000001@3jl>H200000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0
n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00
000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H00000
0000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<0
0000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H10?ooo`00
8P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V
0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H20000
0080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP80
0000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000000000T0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
0000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP800000
1@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H000000000
00020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V
0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000
000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V
0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V1000
00030?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103j
l>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P00
00050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;
0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2
000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00003o
0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00000<0?[`
iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00003o0?[`
iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V0000
00000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`
iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0
000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H00000
01P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H30000
0080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V10000000
0`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H00000
0?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000@0n_3V0`0000040?[`iP<00000
103jl>H3000000@0n_3V0`0000050?[`iP800000103jl>H400000740n_3V0@3oool00240n_3V0P00
00000`3jl>H0000000000005000000040?[`iP000000000000000080n_3V0P0000000`3jl>H00000
000000090?[`iPD000002@3jl>H200000=l0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V
0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP04
0000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000
000000002P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H20000
00@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000
000000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V
008000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V000000000000103jl>H2000000D0n_3V0P00001b0?[`iP40oooo000R0?[`iP<0
0000:@3jl>H200000=h0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP80
00001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80
000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`
iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3j
l>H00000000000090?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00@0n_3V0P0000020?[`iPH00000L@3jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP80
0000g@3jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0
n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`
iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP0000000000
00T0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H20000
0080n_3V00<000000?[`iP3jl>H00P00001b0?[`iP40oooo000Q0?[`iP80000000<0n_3V00000000
0000:P3jl>H200000=`0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H300000004
0?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000040?[`iP0000000000
0?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP02000000030?[`iP000000
n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H0000000000002
0?[`iP030000003jl>H0n_3V008000000P3jl>H4000000<0n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V00@000000?[`iP0000000000LP3j
l>H10?ooo`00803jl>H3000000040?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000
003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000
003jl>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD00000
2`3jl>H3000000030?[`iP00000000000080n_3V100000020?[`iP<0000000<0n_3V000000000000
1`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V
100000030?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000050?[`iP8000000P3jl>H010000000n_3V00000000001b0?[`iP40oooo001=0?[`iP800000
00<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP800000
8P3jl>H200000080n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`
iP00000000000080n_3V0P0000060?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V008000000`3jl>H300000780n_3V
0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3j
l>H2000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000;0?[`iP<000000`3j
l>H5000000@0n_3V0`0000030?[`iP<00000103jl>H3000000<0n_3V1@0000040?[`iP800000LP3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo000V0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V
8`3jl>H10?ooo`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H0
00000P3jl>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`
iP00000000000080000000@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`
iP030000003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`
iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`iP0000000000
00H000006`3jl>H3000000@0n_3V100000300?[`iP40oooo000Q0?[`iP80000000<0n_3V00000000
00001@0000001@3jl>H00000000000000000n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3j
l>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H20000
0080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP800000
0P3jl>H2000000/0n_3V1@0000090?[`iP030000003jl>H0n_3V00800000103jl>H200000<40n_3V
0@3oool00280n_3V0`00000X0?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P00
00020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00
00030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP@00000703j
l>H2000000030?[`iP000000000000@00000`03jl>H10?ooo`008P3jl>H3000000T0n_3V00<00000
0?[`iP3jl>H03P3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP@000000`3jl>H5
00000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V1000000=0?[`iPD00000303j
l>H2000000040?[`iP000000n_3V0?[`iP800000`@3jl>H10?ooo`008@3jl>H2000000030?[`iP00
0000000002L0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000001@3j
l>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP800000
1P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80
00000P3jl>H2000001T0n_3V00<000000?[`iP3jl>H00P0000020?[`iP040000003jl>H000000000
0<40n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V0000
00000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V0000
00000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5
000000<0n_3V1@00000I0?[`iP@000000`3jl>H010000000n_3V0000000000310?[`iP40oooo001=
0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<
0?[`iP800000>03jl>H2000000H0n_3V0`0000310?[`iP40oooo001>0?[`iP<00000g03jl>H50000
0140n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000`0?[`iPD00000103jl>H20000
0<40n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M
0?[`iRH0oooP0P00001/0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000J@3oon05
00000080oooP0P0000040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3jl>HU0?oo
h0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000203oon0010000000oooP0?oo
h000001/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon001`3oon0010000000oooP
0?ooh000001Z0?ooh0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000
003oon00oooP000006X0oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?ooh01Z0?oo
h0030000003oon00oooP06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?ooh01Y0?oo
h0030000003oon00oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP0000
06X0oooP00@000000?ooh03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00J`3oon00
0`000000oooP0?ooh0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V0@3oool0
01d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0oooP00<0
00000?ooh03oon00K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP00<0
00000?ooh03oon00JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0n_3V9P3o
on02000006`0oooP0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<00000J`3o
on02000002@0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000
603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP00`0oooP0P00
00000`3oon000000000000090?ooh0800000o`3oon3:0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon002`3oon07
000000L0oooP100000040?ooh0800000o`3oon330?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP100000080?ooh1X0003o00<000000<f5
?`3=QCl00P3=QCl20?ooh0800000o`3oon2g0?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iPX0
oooP100000040?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@02000000030?oTh@000000000000D0onCQ00@0cHDo0?oTh@3oi>40onCQ0P000000103o
i>40cHDo0?oTh@3oi>43000000P0003o0P0000050<f5?`80oooP0P00003o0?ooh;00oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`00
0000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@04
0?oTh@040<f5?`3oi>40onCQ0?oTh@800000103oi>40103=QCl0onCQ00000000000:0000o`800000
1@3=QCl50?ooh0800000o`3oon2S0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0
203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>40
0P0000050?oTh@040<f5?`3oi>400000000000T0003o0P3oon0400000080oooP0P00003o0?ooh9h0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400P0000050?oTh@<0
cHDo20000?l300000?l0oooPW@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ0P0000020<f5?`03000000000?l0003o00<0
003o0`3=QCoo0?ooh9P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3o
i>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3o
i>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ0080onCQ0P0000030?oTh@D0
003o1P3oon0200000?l0oooPSP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
oooP0?ooh0050000o`@00000o`3oon2=0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@P0
cHDo1@000?l60?ooh0800000o`3oon240?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00H0onCQ0P0000020?ooh0D0003o100000000`3oon0000000000003o0?ooh800
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>480<f5?`@0
003o1000003o0?ooh7l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3o
i>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3o
i>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3o
i>401`3oi>400`3=QCl0onCQ0?oTh@060?oTh@80000000<0onCQ0000o`000?l00`000?l70<f5?ol0
oooPM`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@03
0<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0000000000000P3oi>440000o`80onCQ00<0cHDo00000000
0000o`3oon1e0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@060?oTh@@0003o0P0000000`3oon00
00000000003o0?ooh740oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`0000090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@03
0<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40203oi>42000000<0003o0`00003o0?ooh6h0
oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5
?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00T0
onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl000000000003oi>40000000@0003o0`3oon020000
0?l0oooPJP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oT
h@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo0080000000<0onCQ0<f5?`000?l00P000?l300000?l0oooPJ@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ
0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo
0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo
0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ0`3=QCl00`000000003o0000
o`020000o`H0cHDoo`3oon1R0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3oi>4200000080onCQ0`000?l20?oTh@03
0<f5?`3oon00oooP0?l0oooPH03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>40203oi>430000ool0oooPHP3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh005
0<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ
00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ
00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ
00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo
0?oTh@3oi>402P3oi>40103=QCl0003o0000o`3oon0200000?l0oooPG@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40
onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0
cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0
cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>40
2P3oi>430<f5?`<0003o00<000000<f5?`3=QCl0103=QCoo0?ooh5H0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oT
h@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5
?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5
?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00X0
onCQ00<0cHDo0?oTh@3oi>400`0000030000o`<0onCQ00<0cHDo0?ooh03oon00o`3oon1D0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3o
i>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3o
i>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3o
i>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=
QCl0onCQ0?oTh@0:0?oTh@040<f5?`3oi>40onCQ0?oTh@8000000`3oi>420000o`040?oTh@3=QCl0
oooP0?ooh0800000o`3oon1B0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00P0onCQ
0`000?l400000?l0oooPD@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ
0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ
0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@070?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@80
cHDo0`000?l00`000000cHDo0<f5?`3o0?ooh4l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0
onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00P0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@02000000<0003o0P3oon0200000?l0oooPB`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh005
0<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ
00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ
00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ
00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo
0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo
0000o`000?l00`00003o0?ooh4X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`0000090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@04
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@07
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@07
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00@0onCQ0P3=QCl010000000003o0000o`000?l70<f5?ol0oooP@@3oon03000001P0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ
0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ
0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@0200000004
0?oTh@000?l0003o0000o`<0onCQ00<0cHDo0?ooh03oon00o`3oon110?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3o
i>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=
QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@06
0?oTh@80003o00<0onCQ0<f5?`3oon00o`3oon120?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`08
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@07
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@08
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@080?oTh@<0003o00<0
oooP000000000000o`3oon0o0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@80cHDo0`000?l00`000000cHDo
0<f5?`060<f5?ol0oooP=P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ
0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ
0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@070?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0000000200000080
003o1P3oi>400`3=QCl0oooP0?ooh03o0?ooh3@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0
onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00P0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>400P0000020?oTh@80003o103oi>400`3=QCl0oooP0?ooh03o0?ooh3@0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0
onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oT
h@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oT
h@030<f5?`3oi>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40
onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40
onCQ00T0onCQ00<0cHDo0?oTh@3oi>401P3oi>420000o`80onCQ00<0cHDo0?ooh03oon00o`3oon0d
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo
0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00P0onCQ0P000?l00`3=QCl0oooP0?oo
h03o0?ooh3@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@040?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>430000ool0oooP
=03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5
?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oon00oooP0080
003oo`3oon0b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oo
h03oon000P3oon020000o`030?ooh000000000000?l0oooP;@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oT
h@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oT
h@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>40203oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>40
0`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0onCQ0?oTh@0:0?oTh@L0cHDo0P000?l200000080cHDoo`3oon0Z0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oT
h@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>40
0`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oT
h@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103oi>42000000<0003o00<0
cHDo0?ooh03oon00o`3oon0X0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>401@3oi>4200000080onCQ0P000?l200000?l0oooP9`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00D0cHDo0?oTh@3oi>40onCQ
0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ
0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>401@3=QCl000000000o`000?l00000
00T0cHDoo`3oon0K0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=
QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@04
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@09
0?oTh@040<f5?`000000000000000080003o1`3oi>400`3=QCl0oooP0?ooh03o0?ooh1/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
1@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5
?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@040<f5
?`3oi>40000000000080onCQ0P000?l50?oTh@030<f5?`3oon00oooP0?l0oooP6`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5
?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00T0
onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oT
h@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oT
h@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>401@3oi>420000o`<0onCQ00<0cHDo0?ooh03oon00o`3oon0K0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3o
i>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=
QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=
QCl0onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@07
0?oTh@80003o00<0onCQ0<f5?`3oon00o`3oon0L0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`08
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@07
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@08
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@090?oTh@80003o00<0
oooP000000000000o`3oon0J0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`000?l0003o00800000
00<0cHDo0?ooh03oon00o`3oon0F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5
?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0
onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`00000000000080
003o00<0cHDo0?ooh03oon00o`3oon0F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ
00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ
00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5?`3oi>400000
0000003oi>400P000?oo0?ooh1L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo
0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo
0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo
0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00P0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3o
i>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>400P3o
i>401@3=QCl0oooP0000o`000?l0oooP00800000o`3oon0B0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ
0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ
0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ0080onCQ00@0cHDo0?ooh03oon00oooP0P000?l200000?l0oooP4@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh005
0<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ
00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ
00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ
00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo
0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo
0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@020?oTh@@0cHDo0P0000000`000?l000000?ooh002
00000?l0oooP3P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@04
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@07
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@07
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40203oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ0080onCQ0P0000020000o`<00000o`3oon0=0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5
?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oT
h@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oT
h@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5
?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>430<f5?`04000000000?l0003o000000<0
cHDoo`3oon0:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000
2@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oT
h@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oT
h@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@040<f5?`3oi>40onCQ0?oTh@80000000@0003o0?oTh@3oi>40cHDoo`3oon080?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3o
i>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00T0onCQ
00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ
0P000?l00`3=QCl0oooP0?ooh03o0?ooh0P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ
00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0onCQ
00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00P0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3o
i>402@3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3o
i>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00H0onCQ0P000?oo0?ooh0T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oT
h@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oT
h@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40onCQ00H0onCQ00@0cHDo0?ooh0000?l0003oo`3oon070?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oT
h@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>40
0`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oT
h@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oT
h@0:0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oT
h@060?oTh@060<f5?`3oon00oooP0?ooh0000?l0oooP0P00003o0?ooh0<0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ
0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ
00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ
00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ
00X0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
00H0onCQ1@3=QCl20000o`800000o`3oon020?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oT
h@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oT
h@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oT
h@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40
onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40
onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40
onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40
onCQ0080onCQ0P0000020000ool0oooP0P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>40
0`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40203oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oT
h@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oT
h@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oT
h@030?oTh@80000000<0cHDo0000o`000?l00P00003m0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5
?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oT
h@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oT
h@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5
?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5
?`3oi>40onCQ00D0onCQ0P3=QCl010000000003o00000000003l0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40
onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0
onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@0:0?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@090?oT
h@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@060?oT
h@030<f5?`3oi>40onCQ00D0onCQ00@0cHDo0?oTh@00000000000P000?ol0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oT
h@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>40
0`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oT
h@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oT
h@0:0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oT
h@060?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>400P0000000`3=QCl0003o0000
o`3j0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0
cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0
cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0
cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@080?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0`3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40
2@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>40103=QCl0oooP0?ooh0000?l20?ooh0800000m@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ
0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ
00X0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ
00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ
00X0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
00H0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oon00oooP
0?ooh080003o0`00003d0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?oo
h0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3o
i>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3o
i>40onCQ00P0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00T0onCQ
00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@020?oTh@D0cHDo00D000000000o`000?l0
00000<f5?`3c0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000
003oon00oooP000000L0oooP100000080?ooh>L000000P000?oX000000P0oooP1000000H0?ooh1h0
n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?40
oooP00<0<j7:0000o`2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>Q
bPX0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP0?40oooP00@0<j7:0:gHiP000?l0003o0`2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPX0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00l@3oon001@0cXLX0[MSV0:gHiP2]f>H0
003o0080000000<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX:0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00l@3oon0403>QbP040000
00000?l0003o000000X0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:2P2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?D0oooP0`0000000`000?l0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0403>QbP2]f>H0[MSV03>QbPX0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03f0?ooh080000000<0<j7:0000o`000?l00P0000060:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>Q
bP2]f>H0[MSV03>QbPX0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03h0?ooh080<j7:00@000000000o`00000000001P0cXLX60:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX:0:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00nP3oon02000000030000
o`000000oooP00@0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:2P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?/0oooP0P0000020000o`@0oooP00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:2P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP00D0003o0?ooh03oon00oooP03>QbP060:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX:0:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon010?ooh080003o00<0oooP03>Q
bP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:2P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP0`3oon000`000?l0<j7:0:gHiP02000000<0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPX0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0@0oooP0P000?l3000000<0
<j7:2`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPX0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0D0oooP00@00000
0000o`00000000000P3oon000`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:2P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon060?ooh003000000000?l0003o0080oooP00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPX0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP2@3oon000`000?l0oooP03>QbP0;0:gHiP0303>QbP2]f>H0
[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:2P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2P3oon020000o`/0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX:0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0;0?ooh00303>QbP000?l0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX:0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0;0?ooh00403>QbP2]f>H0003o0000o`800000
1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPX0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0/0oooP0`0cXLX01000
0000003o00000000000603>QbP@0[MSV00@0<j7:0:gHiP2]f>H0<j7:2P2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3P3oon0200000080003o
1@3oon000`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPX0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0l0oooP0P0000000`3o
on00003o0?ooh0030?ooh00303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:2P2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4`3o
on020000o`80oooP00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX:0:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0E0?ooh003
0000o`3oon00<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:2P2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP5P3oon020000o`@0[MSV00@0<j7:
0:gHiP2]f>H0<j7:2P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP5`3oon000`0cXLX0003o0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPX0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h1L0oooP00@0<j7:0:gHiP000?l0003o0P0000020:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1L0oooP0`0c
XLX01P000000003o000000000000[MSV03>QbPX0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon0300000?l0oooP6P3oon0200000080003o00<0[MSV03>QbP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0K0?ooh080000000@0[MSV
0000o`00000000002@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP703oon0203>QbP04000000000?l00000000000P0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1h0oooP0P0000020000
o`P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh1l0oooP0P000000102]f>H0003o0000000000050:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0O0?ooh0<0<j7:00@000000000o`000000
00001@0cXLX;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP8P3oon020000
0080003o103oon000`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP8`3oon02000000030?ooh0000?l0oooP0080oooP00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2L0oooP00@0003o0?ooh03oon00<j7:
2`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2P0oooP0P000?l00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:P3oon000`00
0?l0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:P3oon00
0`0cXLX0003o0:gHiP090:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:P3o
on00100cXLX0[MSV0000o`000?l80:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP:P3oon001@0cXLX0[MSV0:gHiP2]f>H0003o00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP07
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o
0?ooh2X0oooP00<0<j7:0:gHiP2]f>H00P2]f>H010000?l0[MSV0000000000030:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0Z0?ooh00303>QbP2]f>H0[MSV00<0[MSV0P000?l200000080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Z0?ooh0H0<j7:0P0000000`000?l0
000003>QbP0203>QbPH0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<@3oon02000000040000o`3oon00oooP
03>QbPH0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP=03oon000`000?l0oooP03>QbP060:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh3D0oooP0P000?l60:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3H0oooP00<0<j7:0000o`2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0f0?ooh00303>QbP2]f>H0003o00@0[MSV00<0<j7:0:gH
iP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP=P3oon000`0cXLX0[MSV0:gHiP020000o`80[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP=P3o
on000`0cXLX0[MSV0:gHiP020:gHiP030000o`000000<j7:00`0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3H0oooP100cXLX2000000030000
o`000000[MSV00/0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh3X0oooP0`0000000`000?l0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0k0?ooh080000000<0<j7:0000
o`000?l02P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP?@3oon00100cXLX0[MSV0:gHiP000?l90:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0m0?ooh00503>QbP2]f>H0[MSV0:gHiP00
0?l0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0m0?oo
h00303>QbP2]f>H0[MSV0080[MSV00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0m0?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0003o
000000000000102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP?@3oon000`0cXLX0[MSV0:gHiP030:gHiP04000000000?l00000000000<0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3d0
oooP1P0cXLX200000080003o100cXLX90:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPA03oon02000000050?ooh0000?l0oooP0?ooh00cXLX02@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh4P0oooP00<0003o0?ooh00cXLX02@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00<0003o000000000000202]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00@000000000o`0000000000200cXLX30:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP0P0000000`000?l000000?ooh0060?oo
h00503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPBP3oon02000000030000o`3oon00
oooP00D0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1=0?ooh0030000o`3o
on00oooP00@0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1>0?ooh0030000
o`3oon00oooP00<0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0
oooPC`3oon020000o`<0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`00
0000oooP0?ooh03o0?ooh540oooP00@0003o0?ooh03oon00<j7:0`2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<00000
0?ooh03oon001P3oon0400000?l0oooPD@3oon000`000?l0oooP03>QbP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0?ooh03oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00
oooP00H0oooP00<000000?ooh03oon00o`3oon1C0?ooh0030000o`00000000000080[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB
0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1C0?ooh004000000000?l0
000000000080<j7:1`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh5<0oooP0P00000010000?l000000?oo
h00cXLX70:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1D0?ooh080000000<0003o0?ooh00cXLX01`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
E`3oon000`000?l0<j7:0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1H0?ooh0030000o`2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh5P0oooP00<0<j7:0000o`000?l00P0000030:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1H0?ooh080<j7:
00@000000000o`00000000000`0cXLX80:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPFP3oon02000000050000o`000000oooP0?ooh00cXLX0202]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5/0oooP0P0000001000
0?l0oooP0?ooh00cXLX80:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPGP3oon000`000?l0oooP03>QbP080:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPG`3oon0010000?l0<j7:0000000000060:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH03oon0010000?l000000000
000000050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon1P0?ooh0040000
00000?l00000000000H0<j7:2P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh640oooP00<000000000o`3o
on001@3oon000`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6<0
oooP0P000?l40?ooh00303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPI@3oon001@000?l0oooP0?ooh03oon00<j7:00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPIP3oon0010000?l0oooP0?ooh00cXLX:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6L0oooP00<0003o0?ooh00cXLX02P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1X
0?ooh0030000o`0cXLX0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ@3oon00
0`000?l0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6T0oooP00<0<j7:
0000o`2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Y0?ooh00303>QbP2]f>H0
003o00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ@3oon00100cXLX0[MSV0:gHiP00
0?l70:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6T0oooP00D0<j7:0:gHiP2]f>H0[MSV
0000o`060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6T0oooP00<0<j7:0:gHiP2]f>H0
0P2]f>H00`000?l0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6T0oooP
00<0<j7:0:gHiP2]f>H00`2]f>H01P000?l0[MSV000000000000[MSV03>QbP@0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h6T0oooP00<0<j7:0:gHiP2]f>H0102]f>H01@000?l00000000000000000<j7:00@0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPJ@3oon07
03>QbP05000000000?l0003o0000000cXLX0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1a0?ooh080000000<0003o0000000000000`2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPL`3oon0010000000003o0000000000020:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1c0?ooh0800000
00<0003o0000000cXLX00P0cXLX80:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPM03oon02000000040000o`3oon00oooP03>QbPP0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1g0?ooh0030000o`3oon00<j7:00P0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1h0?ooh003
0000o`0cXLX0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1i0?ooh0030000o`2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1i0?ooh00303>QbP000?l0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1i0?ooh00303>QbP2]f>H0003o00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1i0?ooh004
03>QbP2]f>H0[MSV0000o`D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1i0?ooh00503>QbP2]f>H0[MSV0:gHiP000?l00P0000020:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPN@3oon001P0cXLX0[MSV0:gHiP2]
f>H000000000o`80000000<0[MSV03>QbP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1i0?ooh0@0<j7:0P00000010000?l0000003>QbP0cXLX80:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0
oooPOP3oon02000000030000o`3oon00<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?oo
h0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon210?ooh003
0000o`0cXLX0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPPP3oon000`000?l0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh880oooP00<0<j7:0000o`2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon220?ooh00303>QbP2]f>H0003o00H0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPPP3oon00100cXLX0[MSV0:gHiP000?l50:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh880oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`04
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh880oooP00<0<j7:0:gHiP2]f>H00P2]f>H0
1@000?l0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh880oooP00<0<j7:0:gHiP2]f>H00`2]
f>H010000?l0[MSV0:gHiP0cXLX90:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon220?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0003o0000000cXLX02@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPPP3oon0603>QbP80000000<0003o0000002]f>H0
202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPR03oon03000000030000o`2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8T0oooP
0P000000100cXLX0003o0000000000060:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2;0?ooh00303>QbP000000003o0080
00001@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon2;0?ooh00503>QbP00000000000000o`0000001P0cXLX;0:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2=0?ooh080000000<0003o0?ooh03oon000`3oon000`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPT03oon000`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2A0?ooh0050000o`3oon00oooP
0?ooh00cXLX02`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh980oooP00@0003o0?ooh03oon00<j7:2`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh980oooP00@0003o0?ooh03oon00<j7:2`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9<0oooP00<0003o0?ooh00cXLX0
2`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9@0oooP
00@0003o03>QbP00000000002@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh9D0oooP00@0003o0000000000000000202]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9D0oooP00@000000000o`00000000002@0cXLX4
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9H0oooP00<000000000o`3oon00203oon00
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9P0oooP00<0003o
0?ooh03oon001P3oon000`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh9T0oooP00<0003o0?ooh03oon001@3oon000`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon04
000000L0oooP00<000000?ooh03oon00o`3oon2J0?ooh0030000o`3oon00oooP00@0oooP00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ00oooP00<000000?ooh03oon00203oon000`000000oooP0?ooh03o
0?ooh9/0oooP00<0003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon00
0`000000oooP0?ooh0070?ooh0@00000o`3oon2J0?ooh0030000o`3oon00oooP00<0oooP00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3o
ool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPW03oon00
0`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00
oooP000000L0oooP00<000000?ooh03oon00o`3oon2M0?ooh0050000o`3oon00oooP0?ooh00cXLX0
102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPWP3oon0010000?l0oooP
0?ooh00cXLX40:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9l0oooP00<0003o0?ooh00c
XLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2P0?ooh0030000o`000000000000<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX03oon0010000000003o00000000000303>Q
bP<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:00oooP0P0000001@000?l000000?ooh03oon00<j7:
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:40oooP0P00000010000?l0oooP0?ooh00cXLX30:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2T0?ooh0040000o`3oon00000000000080[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh:D0oooP00H0003o00000000000000000:gHiP0cXLX90:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon001000
0000003o00000000000203>QbPT0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2V0?ooh005000000000?l0oooP0?ooh00cXLX02@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:P0oooP00<0003o0?ooh00cXLX02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon0300000?l0oooPZ@3oon000`000?l0<j7:0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Z0?ooh0030000o`2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2Z0?ooh0030000o`2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Z0?ooh00303>QbP000?l0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Z0?oo
h00303>QbP2]f>H0003o00L0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2Z0?ooh00503>QbP2]f>H0[MSV0000o`2]f>H00P0000030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPZP3oon001@0cXLX0[MSV0:gHiP2]f>H0003o00<000000P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP100cXLX010000000
003o00000000000303>QbPD0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP[`3oon000`000000003o0?ooh0020?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon0010000?l0oooP0?ooh00cXLX50:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;80oooP00<0003o0?ooh00cXLX0
1@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2c0?ooh0030000o`0c
XLX0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]03oon00
0`000?l0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;@0oooP00<0<j7:0000o`2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh;@0
oooP00@0<j7:0:gHiP000?l000000P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP
00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;@0
oooP00D0<j7:000000000000003o0000000203>QbP/0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;D0
oooP0P00000010000?l000000?ooh00cXLX;0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2f0?ooh080
000000<0003o0?ooh00cXLX02`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^@3oon000`000?l0<j7:
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh0030000o`2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;X0oooP00<0<j7:0000o`2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP^P3oon000`0cXLX0[MSV0000o`090:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh003
03>QbP2]f>H0003o008000001`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^P3oon00100cXLX0[MSV
000000000?l2000000H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP0P0cXLX2000000030000
o`000000<j7:00H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;d0oooP0P0000000`000?l0oooP0?ooh0040?ooh00303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon300?ooh0030000o`3oon00oooP00<0oooP00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h<40oooP00<0003o0?ooh03oon000P3oon000`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`@3oon000`000?l0
oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP0`00003o0?ooh<80oooP00D0003o0?ooh03oon00oooP03>QbP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<0
0000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon330?ooh0040000
o`3oon00oooP03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon340?ooh0030000o`3oon00<j7:00D0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon350?ooh0030000o`0c
XLX0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon360?ooh0030000o`2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon360?ooh0030000o`2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon360?ooh00303>QbP000?l0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon360?ooh00303>QbP2]f>H0003o00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on360?ooh00403>QbP2]f>H0[MSV0000o`80000000<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon360?ooh0<0<j7:00@000000000o`0000000000
1@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?ooh080000000<0
003o0000002]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3:
0?ooh003000000000?l0<j7:008000000`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon3<0?ooh0040000o`000000000000000080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPc03oon0010000000003o00000000000303>QbPL0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon030000
0?l0oooPc@3oon000`000000003o0?ooh0020?ooh00303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?oo
h03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPc`3oon0010000?l0oooP0?ooh00cXLX70:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3@0?ooh003
0000o`3oon00<j7:00L0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=40oooP00<0003o03>QbP2]f>H0
1P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPd@3oon000`000?l0<j7:0:gHiP060:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon3B0?ooh0030000o`2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h=80oooP00<0<j7:0000o`2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPdP3oon000`0cXLX0
[MSV0000o`050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3B0?ooh00403>QbP2]f>H0[MSV0000o`@0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh=80oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`030:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon3B0?ooh00303>QbP2]f>H0[MSV0080[MSV00@0003o0:gHiP2]f>H0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh=80oooP00<0<j7:0:gHiP2]f>H00P2]f>H010000?l0[MSV0:gHiP0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP
0?ooh03o0?ooh=80oooP00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV03>QbP0;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP
00<000000?ooh03oon00o`3oon3B0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0003o0000003oon00
2P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?oo
h0060?ooh0@00000o`3oon3A0?ooh0H0<j7:0P0000000`000?l000000?ooh0060?ooh0@00000603o
on0N0?[`iP40oooo000M0?[`iQ<0oooP00<000000?ooh03oon001@3oon000`000000oooP0?ooh03o
0?ooh=P0oooP1000000:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?oo
h0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3I0?ooh08000002`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?oo
h03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00
L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooPo`00003Z0000
01P0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003L0?[`
iP@000000P3jl>H800000080n_3V100000001`3jl>H00000000000000000n_3V0000003jl>H03000
00000`3jl>H0000000000004000000040?[`iP0000000000000000P0n_3V1@0000040?[`iPL00000
00<0n_3V0000003jl>H00`0000090?[`iPD000000P3jl>H400000080n_3V1@00000B0?[`iPH00000
1P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V0000000000000000i03jl>H10?ooo`00
g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H2000000<0n_3V00L000000?[`iP000000
00000?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000002@3jl>H010000000n_3V0?[`iP3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P00
00020?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P00
00000`3jl>H000000000003U0?[`iP40oooo003M0?[`iP80000000<0n_3V000000000000103jl>H2
000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3j
l>H200000080n_3V0P0000020?[`iP800000303jl>H5000000D0n_3V0P0000060?[`iPD000001P3j
l>H300000>H0n_3V0@3oool00=d0n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`iP000000
00000?[`iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V0P000000103jl>H00000
0000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00003V0?[`iP40
oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V0P000002
0?[`iP<0000000<0n_3V0000003jl>H04P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01@3jl>H2
000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3jl>H50000
0080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000002`3jl>H50000
0080n_3V100000020?[`iP<0000000<0n_3V0000000000004`3jl>H2000000l0n_3V0`0000001@3j
l>H00000000000000000n_3V00@00000g`3jl>H10?ooo`00g@3jl>H200000080n_3V0P00000c0?[`
iP8000000`3jl>H00`000000n_3V0?[`iP0H0?[`iP8000008@3jl>H4000001P0n_3V00<000000?[`
iP3jl>H0g`3jl>H10?ooo`00g03jl>H6000000@0n_3V0P00000_0?[`iPD000006`3jl>H300000240
n_3V0P00000I0?[`iP030000003jl>H0n_3V0=h0n_3V0@3oool00?l0n_3VN03jl>H00`000000n_3V
0?[`iP3M0?[`iP40oooo003o0?[`iWD0n_3V00@000000?[`iP3jl>H00000g`3jl>H10?ooo`00o`3j
l>If0?[`iP800000h03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01474 L
.03619 .01474 L
.03619 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01474 L
.03619 .01474 L
.03619 .16187 L
s
1 .894 .882 r
.03619 .16187 m
.03619 .01483 L
.05543 .01483 L
.05543 .16187 L
F
.804 .522 .247 r
.03619 .16187 m
.03619 .01483 L
.05543 .01483 L
.05543 .16187 L
s
1 .894 .882 r
.05543 .16187 m
.05543 .01637 L
.07492 .01637 L
.07492 .16187 L
F
.804 .522 .247 r
.05543 .16187 m
.05543 .01637 L
.07492 .01637 L
.07492 .16187 L
s
1 .894 .882 r
.07492 .16187 m
.07492 .01665 L
.08805 .01665 L
.08805 .16187 L
F
.804 .522 .247 r
.07492 .16187 m
.07492 .01665 L
.08805 .01665 L
.08805 .16187 L
s
1 .894 .882 r
.08805 .16187 m
.08805 .01781 L
.10338 .01781 L
.10338 .16187 L
F
.804 .522 .247 r
.08805 .16187 m
.08805 .01781 L
.10338 .01781 L
.10338 .16187 L
s
1 .894 .882 r
.10338 .16187 m
.10338 .01927 L
.11297 .01927 L
.11297 .16187 L
F
.804 .522 .247 r
.10338 .16187 m
.10338 .01927 L
.11297 .01927 L
.11297 .16187 L
s
1 .894 .882 r
.11297 .16187 m
.11297 .02123 L
.13187 .02123 L
.13187 .16187 L
F
.804 .522 .247 r
.11297 .16187 m
.11297 .02123 L
.13187 .02123 L
.13187 .16187 L
s
1 .894 .882 r
.13187 .16187 m
.13187 .02252 L
.14047 .02252 L
.14047 .16187 L
F
.804 .522 .247 r
.13187 .16187 m
.13187 .02252 L
.14047 .02252 L
.14047 .16187 L
s
1 .894 .882 r
.14047 .16187 m
.14047 .02443 L
.14943 .02443 L
.14943 .16187 L
F
.804 .522 .247 r
.14047 .16187 m
.14047 .02443 L
.14943 .02443 L
.14943 .16187 L
s
1 .894 .882 r
.14943 .16187 m
.14943 .02614 L
.15691 .02614 L
.15691 .16187 L
F
.804 .522 .247 r
.14943 .16187 m
.14943 .02614 L
.15691 .02614 L
.15691 .16187 L
s
1 .894 .882 r
.15691 .16187 m
.15691 .02644 L
.16385 .02644 L
.16385 .16187 L
F
.804 .522 .247 r
.15691 .16187 m
.15691 .02644 L
.16385 .02644 L
.16385 .16187 L
s
1 .894 .882 r
.16385 .16187 m
.16385 .02798 L
.17163 .02798 L
.17163 .16187 L
F
.804 .522 .247 r
.16385 .16187 m
.16385 .02798 L
.17163 .02798 L
.17163 .16187 L
s
1 .894 .882 r
.17163 .16187 m
.17163 .03016 L
.18612 .03016 L
.18612 .16187 L
F
.804 .522 .247 r
.17163 .16187 m
.17163 .03016 L
.18612 .03016 L
.18612 .16187 L
s
1 .894 .882 r
.18612 .16187 m
.18612 .03277 L
.19485 .03277 L
.19485 .16187 L
F
.804 .522 .247 r
.18612 .16187 m
.18612 .03277 L
.19485 .03277 L
.19485 .16187 L
s
1 .894 .882 r
.19485 .16187 m
.19485 .03502 L
.21354 .03502 L
.21354 .16187 L
F
.804 .522 .247 r
.19485 .16187 m
.19485 .03502 L
.21354 .03502 L
.21354 .16187 L
s
1 .894 .882 r
.21354 .16187 m
.21354 .04219 L
.23592 .04219 L
.23592 .16187 L
F
.804 .522 .247 r
.21354 .16187 m
.21354 .04219 L
.23592 .04219 L
.23592 .16187 L
s
1 .894 .882 r
.23592 .16187 m
.23592 .04392 L
.24763 .04392 L
.24763 .16187 L
F
.804 .522 .247 r
.23592 .16187 m
.23592 .04392 L
.24763 .04392 L
.24763 .16187 L
s
1 .894 .882 r
.24763 .16187 m
.24763 .04755 L
.25456 .04755 L
.25456 .16187 L
F
.804 .522 .247 r
.24763 .16187 m
.24763 .04755 L
.25456 .04755 L
.25456 .16187 L
s
1 .894 .882 r
.25456 .16187 m
.25456 .05133 L
.26521 .05133 L
.26521 .16187 L
F
.804 .522 .247 r
.25456 .16187 m
.25456 .05133 L
.26521 .05133 L
.26521 .16187 L
s
1 .894 .882 r
.26521 .16187 m
.26521 .05354 L
.28168 .05354 L
.28168 .16187 L
F
.804 .522 .247 r
.26521 .16187 m
.26521 .05354 L
.28168 .05354 L
.28168 .16187 L
s
1 .894 .882 r
.28168 .16187 m
.28168 .05802 L
.28878 .05802 L
.28878 .16187 L
F
.804 .522 .247 r
.28168 .16187 m
.28168 .05802 L
.28878 .05802 L
.28878 .16187 L
s
1 .894 .882 r
.28878 .16187 m
.28878 .06133 L
.29984 .06133 L
.29984 .16187 L
F
.804 .522 .247 r
.28878 .16187 m
.28878 .06133 L
.29984 .06133 L
.29984 .16187 L
s
1 .894 .882 r
.29984 .16187 m
.29984 .06458 L
.3076 .06458 L
.3076 .16187 L
F
.804 .522 .247 r
.29984 .16187 m
.29984 .06458 L
.3076 .06458 L
.3076 .16187 L
s
1 .894 .882 r
.3076 .16187 m
.3076 .07039 L
.32441 .07039 L
.32441 .16187 L
F
.804 .522 .247 r
.3076 .16187 m
.3076 .07039 L
.32441 .07039 L
.32441 .16187 L
s
1 .894 .882 r
.32441 .16187 m
.32441 .07729 L
.34183 .07729 L
.34183 .16187 L
F
.804 .522 .247 r
.32441 .16187 m
.32441 .07729 L
.34183 .07729 L
.34183 .16187 L
s
1 .894 .882 r
.34183 .16187 m
.34183 .08173 L
.35634 .08173 L
.35634 .16187 L
F
.804 .522 .247 r
.34183 .16187 m
.34183 .08173 L
.35634 .08173 L
.35634 .16187 L
s
1 .894 .882 r
.35634 .16187 m
.35634 .08733 L
.36731 .08733 L
.36731 .16187 L
F
.804 .522 .247 r
.35634 .16187 m
.35634 .08733 L
.36731 .08733 L
.36731 .16187 L
s
1 .894 .882 r
.36731 .16187 m
.36731 .09258 L
.3778 .09258 L
.3778 .16187 L
F
.804 .522 .247 r
.36731 .16187 m
.36731 .09258 L
.3778 .09258 L
.3778 .16187 L
s
1 .894 .882 r
.3778 .16187 m
.3778 .09708 L
.38669 .09708 L
.38669 .16187 L
F
.804 .522 .247 r
.3778 .16187 m
.3778 .09708 L
.38669 .09708 L
.38669 .16187 L
s
1 .894 .882 r
.38669 .16187 m
.38669 .10461 L
.39842 .10461 L
.39842 .16187 L
F
.804 .522 .247 r
.38669 .16187 m
.38669 .10461 L
.39842 .10461 L
.39842 .16187 L
s
1 .894 .882 r
.39842 .16187 m
.39842 .11012 L
.41319 .11012 L
.41319 .16187 L
F
.804 .522 .247 r
.39842 .16187 m
.39842 .11012 L
.41319 .11012 L
.41319 .16187 L
s
1 .894 .882 r
.41319 .16187 m
.41319 .11349 L
.42189 .11349 L
.42189 .16187 L
F
.804 .522 .247 r
.41319 .16187 m
.41319 .11349 L
.42189 .11349 L
.42189 .16187 L
s
1 .894 .882 r
.42189 .16187 m
.42189 .12494 L
.44452 .12494 L
.44452 .16187 L
F
.804 .522 .247 r
.42189 .16187 m
.42189 .12494 L
.44452 .12494 L
.44452 .16187 L
s
1 .894 .882 r
.44452 .16187 m
.44452 .13474 L
.45558 .13474 L
.45558 .16187 L
F
.804 .522 .247 r
.44452 .16187 m
.44452 .13474 L
.45558 .13474 L
.45558 .16187 L
s
1 .894 .882 r
.45558 .16187 m
.45558 .13905 L
.47022 .13905 L
.47022 .16187 L
F
.804 .522 .247 r
.45558 .16187 m
.45558 .13905 L
.47022 .13905 L
.47022 .16187 L
s
1 .894 .882 r
.47022 .16187 m
.47022 .14722 L
.47794 .14722 L
.47794 .16187 L
F
.804 .522 .247 r
.47022 .16187 m
.47022 .14722 L
.47794 .14722 L
.47794 .16187 L
s
1 .894 .882 r
.47794 .16187 m
.47794 .15009 L
.4929 .15009 L
.4929 .16187 L
F
.804 .522 .247 r
.47794 .16187 m
.47794 .15009 L
.4929 .15009 L
.4929 .16187 L
s
1 .894 .882 r
.4929 .16187 m
.4929 .15935 L
.50204 .15935 L
.50204 .16187 L
F
.804 .522 .247 r
.4929 .16187 m
.4929 .15935 L
.50204 .15935 L
.50204 .16187 L
s
.678 .847 .902 r
.50204 .16187 m
.50204 .16422 L
.52068 .16422 L
.52068 .16187 L
F
.2 .63 .79 r
.50204 .16187 m
.50204 .16422 L
.52068 .16422 L
.52068 .16187 L
s
.678 .847 .902 r
.52068 .16187 m
.52068 .1801 L
.52873 .1801 L
.52873 .16187 L
F
.2 .63 .79 r
.52068 .16187 m
.52068 .1801 L
.52873 .1801 L
.52873 .16187 L
s
.678 .847 .902 r
.52873 .16187 m
.52873 .18128 L
.53878 .18128 L
.53878 .16187 L
F
.2 .63 .79 r
.52873 .16187 m
.52873 .18128 L
.53878 .18128 L
.53878 .16187 L
s
.678 .847 .902 r
.53878 .16187 m
.53878 .18783 L
.5478 .18783 L
.5478 .16187 L
F
.2 .63 .79 r
.53878 .16187 m
.53878 .18783 L
.5478 .18783 L
.5478 .16187 L
s
.678 .847 .902 r
.5478 .16187 m
.5478 .19751 L
.5626 .19751 L
.5626 .16187 L
F
.2 .63 .79 r
.5478 .16187 m
.5478 .19751 L
.5626 .19751 L
.5626 .16187 L
s
.678 .847 .902 r
.5626 .16187 m
.5626 .21113 L
.57687 .21113 L
.57687 .16187 L
F
.2 .63 .79 r
.5626 .16187 m
.5626 .21113 L
.57687 .21113 L
.57687 .16187 L
s
.678 .847 .902 r
.57687 .16187 m
.57687 .21394 L
.58663 .21394 L
.58663 .16187 L
F
.2 .63 .79 r
.57687 .16187 m
.57687 .21394 L
.58663 .21394 L
.58663 .16187 L
s
.678 .847 .902 r
.58663 .16187 m
.58663 .23398 L
.60729 .23398 L
.60729 .16187 L
F
.2 .63 .79 r
.58663 .16187 m
.58663 .23398 L
.60729 .23398 L
.60729 .16187 L
s
.678 .847 .902 r
.60729 .16187 m
.60729 .23887 L
.62114 .23887 L
.62114 .16187 L
F
.2 .63 .79 r
.60729 .16187 m
.60729 .23887 L
.62114 .23887 L
.62114 .16187 L
s
.678 .847 .902 r
.62114 .16187 m
.62114 .25026 L
.64129 .25026 L
.64129 .16187 L
F
.2 .63 .79 r
.62114 .16187 m
.62114 .25026 L
.64129 .25026 L
.64129 .16187 L
s
.678 .847 .902 r
.64129 .16187 m
.64129 .26864 L
.65634 .26864 L
.65634 .16187 L
F
.2 .63 .79 r
.64129 .16187 m
.64129 .26864 L
.65634 .26864 L
.65634 .16187 L
s
.678 .847 .902 r
.65634 .16187 m
.65634 .28145 L
.66929 .28145 L
.66929 .16187 L
F
.2 .63 .79 r
.65634 .16187 m
.65634 .28145 L
.66929 .28145 L
.66929 .16187 L
s
.678 .847 .902 r
.66929 .16187 m
.66929 .28612 L
.67898 .28612 L
.67898 .16187 L
F
.2 .63 .79 r
.66929 .16187 m
.66929 .28612 L
.67898 .28612 L
.67898 .16187 L
s
.678 .847 .902 r
.67898 .16187 m
.67898 .30715 L
.69546 .30715 L
.69546 .16187 L
F
.2 .63 .79 r
.67898 .16187 m
.67898 .30715 L
.69546 .30715 L
.69546 .16187 L
s
.678 .847 .902 r
.69546 .16187 m
.69546 .31063 L
.70842 .31063 L
.70842 .16187 L
F
.2 .63 .79 r
.69546 .16187 m
.69546 .31063 L
.70842 .31063 L
.70842 .16187 L
s
.678 .847 .902 r
.70842 .16187 m
.70842 .32511 L
.71645 .32511 L
.71645 .16187 L
F
.2 .63 .79 r
.70842 .16187 m
.70842 .32511 L
.71645 .32511 L
.71645 .16187 L
s
.678 .847 .902 r
.71645 .16187 m
.71645 .33448 L
.73407 .33448 L
.73407 .16187 L
F
.2 .63 .79 r
.71645 .16187 m
.71645 .33448 L
.73407 .33448 L
.73407 .16187 L
s
.678 .847 .902 r
.73407 .16187 m
.73407 .35419 L
.74865 .35419 L
.74865 .16187 L
F
.2 .63 .79 r
.73407 .16187 m
.73407 .35419 L
.74865 .35419 L
.74865 .16187 L
s
.678 .847 .902 r
.74865 .16187 m
.74865 .3638 L
.76168 .3638 L
.76168 .16187 L
F
.2 .63 .79 r
.74865 .16187 m
.74865 .3638 L
.76168 .3638 L
.76168 .16187 L
s
.678 .847 .902 r
.76168 .16187 m
.76168 .36851 L
.78135 .36851 L
.78135 .16187 L
F
.2 .63 .79 r
.76168 .16187 m
.76168 .36851 L
.78135 .36851 L
.78135 .16187 L
s
.678 .847 .902 r
.78135 .16187 m
.78135 .3883 L
.79113 .3883 L
.79113 .16187 L
F
.2 .63 .79 r
.78135 .16187 m
.78135 .3883 L
.79113 .3883 L
.79113 .16187 L
s
.678 .847 .902 r
.79113 .16187 m
.79113 .39932 L
.80481 .39932 L
.80481 .16187 L
F
.2 .63 .79 r
.79113 .16187 m
.79113 .39932 L
.80481 .39932 L
.80481 .16187 L
s
.678 .847 .902 r
.80481 .16187 m
.80481 .42083 L
.82558 .42083 L
.82558 .16187 L
F
.2 .63 .79 r
.80481 .16187 m
.80481 .42083 L
.82558 .42083 L
.82558 .16187 L
s
.678 .847 .902 r
.82558 .16187 m
.82558 .44451 L
.84292 .44451 L
.84292 .16187 L
F
.2 .63 .79 r
.82558 .16187 m
.82558 .44451 L
.84292 .44451 L
.84292 .16187 L
s
.678 .847 .902 r
.84292 .16187 m
.84292 .45053 L
.85675 .45053 L
.85675 .16187 L
F
.2 .63 .79 r
.84292 .16187 m
.84292 .45053 L
.85675 .45053 L
.85675 .16187 L
s
.678 .847 .902 r
.85675 .16187 m
.85675 .46757 L
.8692 .46757 L
.8692 .16187 L
F
.2 .63 .79 r
.85675 .16187 m
.85675 .46757 L
.8692 .46757 L
.8692 .16187 L
s
.678 .847 .902 r
.8692 .16187 m
.8692 .48459 L
.88672 .48459 L
.88672 .16187 L
F
.2 .63 .79 r
.8692 .16187 m
.8692 .48459 L
.88672 .48459 L
.88672 .16187 L
s
.678 .847 .902 r
.88672 .16187 m
.88672 .50688 L
.90185 .50688 L
.90185 .16187 L
F
.2 .63 .79 r
.88672 .16187 m
.88672 .50688 L
.90185 .50688 L
.90185 .16187 L
s
.678 .847 .902 r
.90185 .16187 m
.90185 .52929 L
.92358 .52929 L
.92358 .16187 L
F
.2 .63 .79 r
.90185 .16187 m
.90185 .52929 L
.92358 .52929 L
.92358 .16187 L
s
.678 .847 .902 r
.92358 .16187 m
.92358 .54983 L
.94445 .54983 L
.94445 .16187 L
F
.2 .63 .79 r
.92358 .16187 m
.92358 .54983 L
.94445 .54983 L
.94445 .16187 L
s
.678 .847 .902 r
.94445 .16187 m
.94445 .56843 L
.95902 .56843 L
.95902 .16187 L
F
.2 .63 .79 r
.94445 .16187 m
.94445 .56843 L
.95902 .56843 L
.95902 .16187 L
s
.678 .847 .902 r
.95902 .16187 m
.95902 .59556 L
.97619 .59556 L
.97619 .16187 L
F
.2 .63 .79 r
.95902 .16187 m
.95902 .59556 L
.97619 .59556 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02995 .01474 Mdot
.03706 .01483 Mdot
.07433 .01637 Mdot
.0784 .01665 Mdot
.09287 .01781 Mdot
.10758 .01927 Mdot
.12398 .02123 Mdot
.1335 .02252 Mdot
.14615 .02443 Mdot
.15652 .02614 Mdot
.15823 .02644 Mdot
.1668 .02798 Mdot
.1781 .03016 Mdot
.19062 .03277 Mdot
.20069 .03502 Mdot
.22959 .04219 Mdot
.23597 .04392 Mdot
.24875 .04755 Mdot
.26135 .05133 Mdot
.2684 .05354 Mdot
.28215 .05802 Mdot
.29183 .06133 Mdot
.301 .06458 Mdot
.3167 .07039 Mdot
.33432 .07729 Mdot
.34517 .08173 Mdot
.35831 .08733 Mdot
.37021 .09258 Mdot
.38007 .09708 Mdot
.39599 .10461 Mdot
.40725 .11012 Mdot
.41395 .11349 Mdot
.43594 .12494 Mdot
.45387 .13474 Mdot
.46153 .13905 Mdot
.47568 .14722 Mdot
.48055 .15009 Mdot
.49592 .15935 Mdot
.50379 .16422 Mdot
.52865 .1801 Mdot
.53043 .18128 Mdot
.5403 .18783 Mdot
.55455 .19751 Mdot
.57396 .21113 Mdot
.57789 .21394 Mdot
.60508 .23398 Mdot
.61154 .23887 Mdot
.62628 .25026 Mdot
.64935 .26864 Mdot
.66493 .28145 Mdot
.67052 .28612 Mdot
.69511 .30715 Mdot
.69909 .31063 Mdot
.71541 .32511 Mdot
.72577 .33448 Mdot
.74708 .35419 Mdot
.75725 .3638 Mdot
.76218 .36851 Mdot
.78255 .3883 Mdot
.79366 .39932 Mdot
.8149 .42083 Mdot
.83763 .44451 Mdot
.84331 .45053 Mdot
.85918 .46757 Mdot
.87473 .48459 Mdot
.89468 .50688 Mdot
.91429 .52929 Mdot
.93189 .54983 Mdot
.94753 .56843 Mdot
.96989 .59556 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0475319) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.660563) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<0
0000103jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H000000000
00020?[`iP030000003jl>H0n_3V00800000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V
000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H010000002
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
000H0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0P00
00000`3jl>H00000000000050?[`iP800000o`3jl>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H200000080
n_3V0P0000000`3jl>H00000000000050?[`iP800000o`3jl>JL0?[`iP40oooo000P0?[`iP800000
0P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP00
0000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V10000003
0?[`iP80000000<0n_3V0000000000000P3jl>H00`000000n_3V0?[`iP0200000080n_3V10000004
0?[`iP<00000o`3jl>JM0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP0000000000
00800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`
iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3j
l>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P0000000`3jl>H00000000000020?[`
iP@000000`3jl>H2000000P0n_3V0P00003o0?[`iY`0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0
n_3V0P0000050?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000060?[`iP80
0000103jl>H00`000000n_3V0?[`iP0200000?l0n_3VW03jl>H10?ooo`007`3jl>H6000000@0n_3V
0P00000_0?[`iPD00000:03jl>H3000000`0n_3V0`0000040?[`iP<000000`3jl>H3000000<0n_3V
1@0000040?[`iP<000000`3jl>H300000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0
n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00
000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H00000
0000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<0
0000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H10?ooo`00
8P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V
0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H20000
0080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP80
0000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000000000T0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
0000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP800000
1@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H000000000
00020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V
0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000
000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V
0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V1000
00030?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103j
l>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P00
00050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;
0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2
000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00003o
0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00000<0?[`
iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00003o0?[`
iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V0000
00000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`
iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0
000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H00000
01P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H30000
0080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V10000000
0`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H00000
0?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000@0n_3V100000040?[`iP800000
103jl>H3000000@0n_3V0`0000030?[`iPH0000000@0n_3V0000000000000000L`3jl>H10?ooo`00
8@3jl>H2000000030?[`iP000000000000D0000000@0n_3V00000000000000000P3jl>H200000003
0?[`iP000000000000T0n_3V1@0000090?[`iP800000g`3jl>H2000000@0n_3V0P0000020?[`iP80
00000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H20000
0080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000
0`3jl>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P000002
0?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P000000
0`3jl>H00000000000030?[`iP800000103jl>H2000000030?[`iP000000000000@0n_3V0P000005
0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V00<000000?[`iP3jl>H00P000004
0?[`iP8000001@3jl>H200000780n_3V0@3oool00280n_3V0`00000Y0?[`iP800000gP3jl>H20000
00@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H20000
00H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`
iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2
000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P000000
103jl>H000000000003jl>H6000000@0n_3V0P0000060?[`iP8000001@3jl>H2000000@0n_3V0P00
00060?[`iP800000L@3jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP800000g@3jl>H4
000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2
000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P000000
1@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0
n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000T0n_3V0P00
00001@3jl>H000000000003jl>H000000080n_3V0P0000050?[`iP8000001P3jl>H2000000D0n_3V
0P0000040?[`iP800000103jl>H400000740n_3V0@3oool00240n_3V0P0000000`3jl>H000000000
000Z0?[`iP800000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0
n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP800000
0P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000
n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003j
l>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V00@000000?[`iP00000000001P3jl>H200000080n_3V00<000000?[`iP3jl>H00P0000030?[`
iP<000001@3jl>H2000000<0n_3V0P0000000`3jl>H000000000001a0?[`iP40oooo000P0?[`iP<0
000000@0n_3V00000000000000009P3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3j
l>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4
000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0n_3V
0000000000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P000000
0`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H010000000n_3V00000000
00060?[`iP8000000P3jl>H4000000H0n_3V0P0000040?[`iP8000000`3jl>H2000000030?[`iP00
000000000740n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V
000000000000403jl>H2000000`0n_3V0P00000R0?[`iP8000000P3jl>H2000002h0n_3V0P000000
0`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000`3jl>H3000000<0n_3V00<00000
0?[`iP3jl>H00P0000020?[`iP8000001@3jl>H00`000000n_3V0?[`iP0200000080n_3V10000003
0?[`iP80000000<0n_3V000000000000L@3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000006@3jl>H3000000030?[`iP0000000000
00800000;P3jl>H3000000/0n_3V0`0000050?[`iP8000000`3jl>H500000080n_3V1@0000030?[`
iP<000001@3jl>H2000000@0n_3V0`00001b0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08
000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H00000
0?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3j
l>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P000000103jl>H000000?[`iP00
00020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V
100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V
100000020?[`iP<0000000<0n_3V0000000000001P00000L0?[`iP800000103jl>H300000<40n_3V
0@3oool00240n_3V0P0000000`3jl>H0000000000005000000050?[`iP00000000000000003jl>H0
1000000;0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP800000
0P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0
n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000002`3jl>H5000000/0n_3V0P000003
0?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`008P3jl>H3000002P0n_3V0P0000000`3j
l>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00030?[`iP000000000000<0n_3V1000000K0?[`iP8000000`3jl>H2000000030?[`iP0000000000
0<00n_3V0@3oool00280n_3V0`0000090?[`iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80
000000<0n_3V000000000000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0
n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H200000004
0?[`iP00000000000?[`iP@000003@3jl>H5000000/0n_3V0P0000030?[`iP80000000<0n_3V0000
00000000`03jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002L0n_3V0P0000000`3jl>H0
00000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H0
00000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000001`0n_3V0P000002
0?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00803jl>H3000000040?[`iP0000000000
000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H4
00000080n_3V0`000000103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3j
l>H4000000@0n_3V100000020?[`iPD000000`3jl>H5000001`0n_3V0P0000020?[`iP80000000<0
n_3V000000000000`03jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H000000000000@0?[`iP800000303jl>H2000003P0n_3V00<000000?[`iP3jl>H00P000002
0?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<03jl>H5000000<0n_3V0`0000310?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`007@3jl>HV
0?ooh0800000K03oon02000000@0oooP0P0000040?ooh0800000J`3oon05000006T0oooP1@000002
0?ooh0800000103oon02000006/0oooP1000000S0?ooh1h0n_3V0@3oool001d0n_3V9@3oon001000
0000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000P0oooP00@000000?ooh03oon000000
K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00L0oooP00@000000?ooh03oon00
0000JP3oon000`000000oooP0?ooh00T0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP
0?ooh000001Z0?ooh0040000003oon00oooP000000/0oooP00<000000?ooh03oon00JP3oon000`00
0000oooP0?ooh01[0?ooh0030000003oon00oooP00X0oooP00<000000?ooh03oon00J@3oon000`00
0000oooP0?ooh00S0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?oo
h0040000003oon00oooP000000T0oooP0P00001]0?ooh0030000003oon00oooP06/0oooP00<00000
0?ooh03oon00203oon02000006d0oooP00<000000?ooh03oon008P3oon0N0?[`iP40oooo000M0?[`
iRD0oooP00@000000?ooh03oon000000JP3oon0010000000oooP0?ooh00000090?ooh0030000003o
on00oooP06`0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0080?ooh0030000003o
on00oooP06X0oooP00@000000?ooh03oon0000008`3oon0N0?[`iP40oooo000M0?[`iRH0oooP0P00
001/0?ooh08000002P3oon03000006/0oooP0P00001/0?ooh08000002P3oon03000006/0oooP0P00
000T0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`iQ/0oooPo`00003Z000001P0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP
0740oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>H@0?ooh0D000001P3oon000`000000oooP0?ooh00;0?ooh08000000P3o
on0200000?l0oooPe@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon00
0`000000oooP0?ooh0060?ooh0030000003oon00oooP00X0oooP2000000?0?ooh0@00000o`3oon31
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP
00H0oooP100000080?ooh1X0003o0`0000040?ooh08000001@3oon0200000?l0oooP/03oon040000
01P0oooP7P3jl>H10?ooo`007@3jl>H:0?ooh0@00000103oon000`000000oooP0?ooh0060?ooh003
0000003oon00oooP00T0oooP00@0cHDo0?oTh@00000000000P3oi>42000000L0onCQ00<0cHDo0?oT
h@3oi>401@3oi>43000000P0003o0P0000030<f5?`@000001@3oon0200000?l0oooPZ`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00H0onCQ100000030?oTh@030<f5?`000000000000X0003o0`3oon0400000080
oooP0P00003o0?ooh:H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP
0P0000080?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ
0000000000040?oTh@050<f5?`00000000000?oTh@3=QCl02@000?l300000080cHDo00<0oooP0000
00000000o`3oon2P0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>4200000080onCQ00<000000000o`000?l01P000?l00`00
0000oooP0?ooh00300000?l0oooPVP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3o
i>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3o
i>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0000000000000P3oi>40103=
QCl000000000000000050000o`80000000<0cHDo000000000000o`3oon2F0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>40
0`3=QCl0onCQ0?oTh@020?oTh@060<f5?`3oi>4000000000003=QCl0onCQ0`0000050000o`030000
003=QCl0oooP00800000o`3oon2A0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>43000000040?oTh@0000000000000000D0003o00D000000<f5
?`3=QCl0cHDo0?ooh00200000?l0oooPRP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P0000000`3oi>40cHDo
00000002000000D0003o0`0000000`3oon0000000000003o0?ooh8H0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5
?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5
?`<0onCQ00@0cHDo0?oTh@00000000000`3oi>400`3=QCl000000000o`040000o`8000001@3=QCoo
0?ooh800oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oT
h@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ
000000000000cHDo0080000010000?l20?oTh@030<f5?`3oon00oooP0?l0oooPOP3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0
onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oT
h@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@060<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ
0P0000030?oTh@D0003o1@3oon0200000?l0oooPM`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=
QCl0onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0oooP0?ooh004
0000o`H00000o`3oon1d0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oT
h@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@L0cHDo10000?l300000?l0oooPL`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>40
0`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>40
0`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0
onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl3
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3o
i>40onCQ00D0onCQ0`0000030000o`<0cHDo0P00003o0?ooh6`0oooP0`00000H0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo
0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo
0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0
onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@080?oT
h@80000000<0onCQ0000o`000?l00P000?l200000?l0oooPK@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0
onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oT
h@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3o
i>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ
0?oTh@080?oTh@030<f5?`3oi>40onCQ0080onCQ0P0000030000o`80oooP0P00003o0?ooh6P0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@04
0<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@80000000<0onCQ
0<f5?`000?l00`000?l300000?l0oooPI@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ
0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@03000000<0003o00<000000<f5
?`3=QCl00`3=QCoo0?ooh5l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ1@0000030000o`80onCQ0P00003o0?ooh5h0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40
1`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oT
h@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3o
i>40onCQ0<f5?`@0onCQ00<0cHDo0000000000000`3oi>420000o`<00000o`3oon1M0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0
cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0
onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`08
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@030<f5?`3oi>40onCQ00@0onCQ00@000000000o`000?l0003o0P3=QCl200000?l0oooP
F@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oT
h@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo
0?oTh@3oi>40cHDo103oi>400`3=QCl0onCQ0?oTh@050?oTh@80000000@0onCQ0000o`000?l0003o
0P0000000`3=QCl000000000003o0?ooh5D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oT
h@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>40
0`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3o
i>40103=QCl0onCQ0?oTh@3oi>4200000080003o1000003o0?ooh5@0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5
?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5
?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0
cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080000000D0onCQ0000o`000?l0
003o000000020<f5?ol0oooPDP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40
1P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40
1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@04
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3o
i>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl0103oi>42000000<0003o0`3oon0200000?l0oooPC@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0
onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oT
h@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00<0003o0`00003o0?ooh4`0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ
0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0
cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3o
i>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00@0cHDo0?oTh@3oi>40onCQ0`3=QCl0
10000000003o0000o`0000020<f5?ol0oooPBP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@05
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>42000000<0003o
o`3oon180?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@04
0<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40
onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@050<f5?`000?l0003o0000o`3oon000P00003o0?oo
h4@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3o
i>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5
?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@@0cHDo0P000?l200000080cHDoo`3oon11
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ
00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3o
i>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`04
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>40103=QCl0onCQ0?oTh@3oi>42000000<0003o
00<0cHDo000000000000o`3oon0o0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ
00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0
onCQ0?oTh@020?oTh@8000000P3oi>430000o`030000003=QCl0cHDo0080cHDoo`3oon0j0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=
QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@<000000P000?l20?oT
h@800000o`3oon0i0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40
0`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`00000000000080onCQ0P000?l300000?l0oooP>03oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ
00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ
00<0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo
0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo
0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>400`3=
QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00L0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@030?oTh@0400000000
0?l0003o000000<0cHDoo`3oon0e0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ
00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0
onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ0P0000020000o`040?oTh@3=QCl000000000
0?l0oooP<`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00L0onCQ00<0cHDo0?oTh@3oi>401P3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0?oTh@<0003o0P00003o0?ooh380oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5
?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@020?oTh@8000000P000?l20<f5?`800000o`3oon0^0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0
cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0
onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`08
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl000000000003oi>420000o`<00000o`3oon0]0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40
103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ
0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@04000000000?l0
003o00000080cHDoo`3oon0[0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@05
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`000000000000<0003oo`3oon0[0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ
0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oT
h@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40
onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3o
i>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0000o`00
0?l0oooP0P00003o0?ooh2H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP0`0000090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00L0onCQ00<0cHDo0?oTh@3oi>401P3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>40
0`3=QCl0onCQ0?oTh@020?oTh@<0cHDo0P000?l200000?l0oooP8`3oon03000001P0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@02
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5
?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0
onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ
00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3o
i>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3o
i>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P00
00020000ool0oooP9@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>40
0`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401@3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ
00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00L0onCQ00<0cHDo0?oTh@3oi>40
1P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0?oTh@80000000<0oooP0000o`00
0?l00P00003o0?ooh240oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@030<f5?`3oi>40onCQ
00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@<0cHDo00<000000000
o`000?l00`00003o0?ooh1h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0
onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ
0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@030<f5?`3oi>40
onCQ00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
onCQ00<000000P000?l200000?l0oooP7@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ
0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@080?oTh@03
0<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>400`3=QCl0onCQ0?oTh@050?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00L0onCQ00<0
cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00@0
cHDo0?oTh@3oi>40onCQ100000020000o`<0cHDoo`3oon0J0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ
0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oT
h@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40
onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3o
i>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@80000000@0onCQ0000o`000?l0cHDoo`3oon0J0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40
103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ
0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@050?oTh@040<f5?`3oi>40
onCQ0?oTh@80003oo`3oon0I0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@05
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@050?oTh@060<f5?`3oi>40onCQ0?oTh@3=QCl0oooP0P000?oo0?ooh1L0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oT
h@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40
onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ
00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0
onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`070?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`030?ooh080003o0P00003o0?ooh1<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3o
i>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=
QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@030<f5
?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5
?`3oi>40onCQ00D0onCQ00@0cHDo0?oTh@3oi>40onCQ1@3=QCl010000000003o0000o`0000030<f5
?ol0oooP3`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00L0onCQ00<0cHDo0?oTh@3oi>401P3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>401@3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ0`00000010000?l0onCQ0?oTh@3=QCoo0?ooh0l0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@04
0<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40
onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3o
i>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`050?oTh@80000000@0onCQ0000o`000?l0cHDoo`3oon0?0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>40
0`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oT
h@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oT
h@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
2P3oi>420000ool0oooP3P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on03000000T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40
103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@050?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl02P3oi>40103=QCl0oooP0000o`3oon0200000?l0oooP203oon03
000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>40
0`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oT
h@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@03
0<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oT
h@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
2P3oi>430<f5?`80003o0P00003o0?ooh0T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oT
h@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>40
0`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`0:0?oTh@030<f5?`3oi>40onCQ
008000000P000?l00`3oon0000000000003o0?ooh0H0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ
0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0
cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3o
i>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`07
0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`0:0?oTh@040<f5?`3o
i>40onCQ0?oTh@80000000<0cHDo0000o`000?l00P0000020<f5?ol0oooP0`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ
00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3o
i>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>40
0`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103o
i>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00L0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@040?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00X0onCQ00<0cHDo0?oTh@3oi>400P3oi>40203=QCl0onCQ000000000000003o0000003oi>40cHDo
o`3oon030?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3oi>40
103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@050?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl02P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
008000000P000?l00`3=QCl0oooP0?ooh03o0?ooh040oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ
0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0
cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40
203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3o
i>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`07
0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`0:0?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>420000o`030?ooh000000000000?h0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5
?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`0:0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>420<f5?`80
003o0`00003l0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5
?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>400`3o
i>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@060?oT
h@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@050?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl02P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
onCQ00@0onCQ00D0cHDo0?oTh@00000000000000o`0300000?/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@03
0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@03
0?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3o
i>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0
onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oT
h@3oi>40203oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo
0?oTh@3oi>401@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`070?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`0:0?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@0200000080
003o00<000000<f5?`3=QCl00P3=QCog0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40
onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0
cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=
QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl02P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`0200000080003o0P3o
i>400`3=QCl0oooP0?ooh03e0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@05
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oT
h@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl02P3oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030000o`3oi>40cHDo
0?L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@050?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl0203oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oTh@3oi>40
0`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00D0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01`3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@05
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl02P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@80003o0P00003e0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00D0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`080?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00P0onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0onCQ0?oT
h@030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>401@3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`070?oTh@030<f5?`3oi>40onCQ
00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`0:0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00@000000000o`000?l00000
0P3=QCob0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003o
on00oooP000000L0oooP100000080?ooh>L000000P000?oX000000P0oooP1000000H0?ooh1h0n_3V
0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0>h0oooP
0P0000000`3oon0000000000o`02000000L0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00l@3oon020000
0080003o1P3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP060:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P00
00080?ooh0030000003oon00oooP0?80oooP0P0000000`3oon00003o0?ooh0040?ooh00503>QbP2]
f>H0[MSV0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03f0?ooh080
003o0`3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP06
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00n03oon0010000?l0oooP0?ooh00cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP060:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n@3oon020000o`0503>QbP2]f>H0[MSV0:gHiP0c
XLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03k0?ooh0050000o`2]f>H0[MSV
0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03k0?ooh00303>QbP00
0?l0[MSV00<000000`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03k0?ooh080<j7:
0P000?l300000080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP060:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o@3oon0200000003
0000o`000000000000<0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00oP3oon0200000080
003o0P3oon0200000080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP0`3oon000`000?l0
000000000002000000030:gHiP0cXLX0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0@0oooP0P000?l200000080
<j7:1P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP1@3oon001@000000003o0?ooh03oon00<j7:00H0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP1`3oon020000
o`0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP2@3oon000`000?l0[MSV0:gHiP0200000080[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h0T0oooP00<0<j7:0000o`000?l00`0000000`2]f>H0<j7:0:gHiP050:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2@3oon0203>QbP04000000000?l00000
00000080<j7:1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh0`0oooP00D000000000o`000?l0oooP03>QbP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP3`3oon000`000?l0<j7:0:gHiP050:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403oon020000o`D0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@0?ooh00303>QbP2]
f>H0003o00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0@0?ooh00303>QbP2]f>H0[MSV0080003o0P0000000`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh100oooP100cXLX00`000000003o00000002000000<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP503oon0200000080003o0P0000020:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh1D0oooP0`0000000`000?l0000003>QbP0203>QbPT0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh1L0oooP0P0000020000o`030?ooh00cXLX0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1/0oooP00<0
003o03>QbP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0<00000o`3oon0L0?ooh080003o202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0L0?ooh00303>QbP2]f>H0003o00L0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh1`0oooP00@0<j7:0:gHiP2]f>H0003o1P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP703oon00100cXLX0[MSV
0:gHiP2]f>H20000o`@0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh1`0oooP00<0<j7:0:gHiP2]f>H00`2]f>H01@000?l0
[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0L0?ooh00303>QbP2]f>H0[MSV00@0[MSV00@0003o0:gHiP00000000001P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1`0oooP200cXLX2
0000o`8000001@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh2@0oooP0P00000010000?l000000000000000030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP9@3oon02000000040000o`000000000000000080[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0V0?ooh00503>Q
bP000000003o0000o`0000000`0cXLX90:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2P0
oooP0P00000010000?l0oooP0?ooh00cXLX90:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h2/0oooP00<0003o0?ooh00cXLX02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0/0?oo
h080003o2@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]0?ooh00403>QbP000?l00000
000000H0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0]0?ooh00303>QbP000000003o008000001P0cXLX6
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3o
on00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh2h0oooP0P0000020000o`D0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;`3oon02
000000030?ooh0000?l0oooP00<0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<`3oon00
1@000?l0oooP0?ooh03oon00<j7:00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3@0oooP00@0003o0?ooh03oon00<j7:
1P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP=@3oon020000o`0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP
00<0003o0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP=`3oon000`0cXLX0003o0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0g0?ooh00503>QbP2]f>H0003o0000o`0000000P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP=`3oon0203>QbP80
000000@0003o0000000cXLX0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh3T0oooP0`0000000`000?l0oooP03>QbP050:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>P3oon02000000030?ooh0000?l0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0n0?oo
h080003o102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h3h0oooP00<0<j7:0:gHiP000?l00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh3h0oooP00@0<j7:0:gHiP2]f>H0003o0P0000000`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon0300000?l0oooP?P3oon001@0cXLX0[MSV0:gHiP000000003o00800000102]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh3h0oooP0`0cXLX2000000030000o`000000000000<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP@P3oon02000000030000o`00000000000080[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP@`3oon0200000080003o0`0cXLX70:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on140?ooh080000000@0oooP0000o`3oon00<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB03oon000`000?l0<j7:
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon190?ooh0030000o`2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP
00<0<j7:0000o`2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB@3oon000`0cXLX0[MSV0000o`050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon190?ooh00403>QbP2]f>H0[MSV0000o`@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP00D0<j7:0:gHiP2]
f>H0[MSV0000o`030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP08
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon190?ooh00303>QbP2]f>H0[MSV0080[MSV00@0003o0:gH
iP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<00000
0?ooh03oon00o`3oon190?ooh00303>QbP2]f>H0[MSV00<0[MSV0P000?l00`000000[MSV0:gHiP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<00000
0?ooh03oon00o`3oon190?ooh0H0<j7:0P0000000`000?l00000000000030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000003o0?ooh4h0oooP0`000000
0`000?l00000000000020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0060?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon00
0`000000oooP0?ooh03o0?ooh500oooP0`0000000`000?l0000003>QbP0203>QbP<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1B0?oo
h080000000@0003o0?ooh03oon00<j7:0`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?oo
h0030000003oon00oooP0?l0oooPE@3oon000`000?l0oooP03>QbP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh5H0oooP00<0003o03>QbP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1G0?ooh0050000o`2]f>H0[MSV0:gHiP0c
XLX0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPE`3oon000`0cXLX0003o0:gHiP02000000P0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh5L0oooP00@0<j7:0:gHiP000?l0003o0P0000070:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1G0?ooh080<j7:0P0000000`000?l000000:gHiP060:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1J0?ooh080000000<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPF`3oon000`0cXLX0[MSV0000o`060:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1K0?ooh004
03>QbP2]f>H0[MSV0000o`8000000`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF`3oon0303>QbP04
000000000?l00000000000<0<j7:1P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh5h0oooP0P0000001@000?l000000?ooh03oon00<j7:
00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh5l0
oooP0P00000010000?l0oooP0?ooh00cXLX60:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1R0?ooh0030000o`3oon00<j7:00H0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1S0?ooh080003o
1P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh6@0oooP00<0<j7:0000o`2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6@0oooP00<0<j7:0:gHiP000?l0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h6@0oooP00@0<j7:0:gHiP2]f>H0003o0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6@0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPI03oon000`0cXLX0[MSV0:gHiP020:gHiP030000o`000000000000D0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI03oon0503>QbP04000000000?l000000000
00@0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ@3oon0200000003
0000o`000000[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
JP3oon02000000030000o`2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPJ`3oon00100cXLX0[MSV0000o`2]f>H20000000303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh6/0oooP00@0<j7:0:gHiP2]f>H0003o0`0000090:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1[0?ooh0<0<j7:00@000000000o`00000000002@2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPK`3oon0010000000003o0000000000080:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh700oooP00@0
00000000o`000?l00000200cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1`0?ooh0<0000000<0003o0?ooh03oon001@3oon000`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPL@3oon02000000030?ooh0000?l0oooP00D0oooP00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h7D0oooP00<0003o0?ooh03oon000`3oon000`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPMP3oon000`000?l0
oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1g0?ooh0050000o`3oon00oooP0?ooh00c
XLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh7P0oooP00@0003o0?ooh03oon00<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7T0oooP00<0003o0?ooh00cXLX0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh7X0oooP00<0003o0000000000000`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7X0oooP00@000000000o`00000000000P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7X0oooP0P0000000`000?l0000003>QbP0203>QbPD0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPN`3oon02000000040000o`3oon00oooP03>QbPD0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPOP3oon000`000?l0oooP03>QbP050:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7l0oooP00<0003o03>QbP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh800oooP00<0003o0000002]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7l0oooP0P0000000`000?l0000003>Q
bP0303>QbPX0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7l0oooP0`0000001@000?l0oooP0?ooh03o
on00<j7:00X0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh800oooP0P0000001@3oon00003o0?ooh03o
on00<j7:00X0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8@0oooP00<0003o0?ooh00cXLX02P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPQ@3oon000`000?l0<j7:0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon260?ooh0030000o`2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8H0oooP
00<0<j7:0000o`2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQP3oon000`0cXLX0[MSV0000
o`080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon260?ooh00403>QbP2]f>H0[MSV0000o`L0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh8H0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`02000000@0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh8H0oooP00H0<j7:0:gHiP2]f>H0[MSV000000000?l2000000<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8H0oooP100cXLX2000000030000o`000000<j7:00<0<j7:1`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh8/0oooP0P0000001@000?l0oooP0?ooh03oon00<j7:00L0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh8h0oooP00@0003o0?ooh03oon00<j7:1`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon001`3o
on03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPS`3oon00
0`000?l0oooP03>QbP070:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPT03oon000`000?l0<j7:0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT@3oon000`000?l0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPT@3oon000`0cXLX0003o0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT@3oon000`0cXLX0003o0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPT@3oon000`0cXLX0[MSV0000o`050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT@3oon00100cXLX0[MSV0:gHiP000?l4
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPT@3oon001@0cXLX0[MSV0:gHiP2]f>H0003o0080000000<0[MSV03>QbP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2A0?ooh0@0<j7:00D000000000
o`000000000003>QbP060:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h9D0oooP0P00000010000?l000000000000000050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh9H0oooP0P00000010000?l000000000000000040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9P0oooP00@000000000o`00000000001@0cXLX5
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ00oooP100000070?ooh0030000003oon00oooP0?l0oooPV@3oon000`000000003o0?ooh0040?oo
h00303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP0?l0
oooPV`3oon000`000?l0oooP0?ooh0020?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon000`000000oooP
0?ooh0070?ooh0@00000o`3oon2J0?ooh0030000o`3oon00oooP0080oooP00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0060?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ80oooP00<0
00000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh9`0oooP00D0003o0?ooh03oon00oooP
03>QbP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh9d0oooP
00@0003o0?ooh03oon00<j7:1@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh9h0oooP
00<0003o0?ooh00cXLX01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW`3oon000`000?l000000000
00040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2O0?ooh004000000000?l00000000000@0<j7:1`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh9l0oooP0P0000000`000?l000000?ooh0020?ooh00303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2P0?oo
h080000000D0003o0?ooh03oon00oooP03>QbP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX`3oon0010000?l0oooP0?ooh00cXLX7
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPY03oon000`000?l0oooP03>QbP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon000`000?l0<j7:0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
YP3oon000`000?l0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPYP3oon00100cXLX0003o0000000000040:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPYP3o
on000`0cXLX000000000o`02000000<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh:H0oooP00D0<j7:000000000000003o0000000403>QbPL0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2X0?ooh080000000D0003o0?ooh03oon00oooP03>Q
bP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP00D0003o
0?ooh03oon00oooP03>QbP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh:/0oooP00@0003o0?ooh03oon00<j7:1`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2/0?ooh0030000o`3oon00<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP[@3oon000`000?l0<j7:0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:h0oooP00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2^0?ooh00303>QbP000?l0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[P3oon000`0cXLX0[MSV0000
o`050:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:h0oooP00@0<j7:
0:gHiP2]f>H0003o0P0000020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh:h0oooP0`0cXLX010000000003o00000000000203>QbPT0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh;40oooP0P00000010000?l000000?ooh00cXLX90:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2b
0?ooh080000000<0003o0?ooh00cXLX02@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]@3oon000`00
0?l0<j7:0:gHiP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh;H0oooP00<0003o0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2f0?ooh00303>QbP000?l0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;H0oooP00<0
<j7:0000o`2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]P3oon000`0cXLX0[MSV0000o`07
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2f0?ooh00403>QbP2]f>H0[MSV0000o`H0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh;H0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`050:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2f0?ooh00303>QbP2]f>H0[MSV0080[MSV00<0003o0000002]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP]P3oon0403>QbP80000000<0003o0000000cXLX00P0cXLX90:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
^P3oon02000000050000o`000000oooP0?ooh00cXLX02@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;/0oooP0P00000010000?l0oooP
0?ooh00cXLX90:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP_P3oon000`000?l0oooP03>QbP090:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_`3oon000`000?l0<j7:0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP`03oon000`000?l0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`03oon000`0cXLX0003o0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP`03oon000`0cXLX0003o0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0<00000o`3oon300?ooh00303>QbP2]f>H0003o00L0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<00oooP00@0<j7:0:gHiP2]f>H0003o
0P0000040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP`03oon0303>QbP04000000000?l00000000000@0<j7:1`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon330?ooh080000000<0003o0000003oon000P3o
on000`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<@0oooP0P0000001@000?l0oooP0?ooh03oon00<j7:00L0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPaP3oon001@000?l0oooP0?ooh03oon00<j7:00L0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa`3oon0010000?l0oooP0?ooh00c
XLX70:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<P0oooP00<0003o
0?ooh00cXLX01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?oo
h0030000o`0cXLX0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPbP3oon000`000?l0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<X0oooP00<0<j7:0000o`0000001@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon3:0?ooh004000000000?l00000000000D0<j7:1`2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPbP3oon02000000030000o`000000oooP00<0oooP00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPb`3oon02000000030000o`3oon00oooP0080oooP00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon3>0?ooh0050000o`3oon00oooP0?ooh00cXLX01`2]f>H0
0`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon3?0?ooh0040000o`3oon00oooP03>QbPL0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h=00oooP00<0003o0?ooh00cXLX01`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd@3oon000`000?l0
<j7:0:gHiP060:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3A0?ooh0030000o`0cXLX0[MSV00H0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh=80oooP00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPdP3oon000`0cXLX0003o0:gHiP050:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3B0?oo
h00303>QbP2]f>H0003o00D0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=80oooP00@0<j7:0:gHiP2]
f>H0003o102]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPdP3oon001P0cXLX0[MSV0:gHiP2]f>H0003o
00000080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=80oooP00<0<j7:0:gHiP2]f>H00P0000001000
0?l000000:gHiP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPdP3oon0303>QbP80000000@0003o0000000cXLX0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?oo
h03oon00o`3oon3F0?ooh080000000<0003o0?ooh03oon002`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP
0?l0oooPf@3oon000`000?l0oooP0?ooh00:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000003o0?ooh=T0oooP00<0003o0?ooh03o
on001P3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HC0?ooh0030000003oon00oooP00D0oooP
00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?oo
h03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?oo
h0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
5@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
5@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=`0n_3V1000
00020?[`iPP000000P3jl>H4000000070?[`iP00000000000000003jl>H000000?[`iP0<00000003
0?[`iP000000000000@0000000@0n_3V0000000000000000203jl>H5000000@0n_3V1`0000000`3j
l>H000000?[`iP03000000T0n_3V1@0000020?[`iP@000000P3jl>H500000180n_3V1P0000060?[`
iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H0000000000000003T0?[`iP40oooo003M0?[`
iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000`3jl>H01`000000n_3V000000000000
n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000090?[`iP040000003jl>H0n_3V0?[`iP8000000P3jl>H2000000040?[`
iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01@3jl>H200000003
0?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000000`3jl>H00000000000040?[`iP800000
0`3jl>H2000000D0n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V0P0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000d0n_3V0P0000020?[`iP800000
00@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P00000<0?[`iPD000001@3jl>H2000000H0n_3V1@0000060?[`iP<0
0000iP3jl>H10?ooo`00g@3jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000
n_3V0000003jl>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V0P000002
0?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01P3jl>H300000>H0n_3V0@3oool0
0=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V0000
00000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V
0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V
0`0000000`3jl>H000000?[`iP0B0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP800000
00<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H200000080n_3V0P0000000`3jl>H000000000
0002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3j
l>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000;0?[`iPD000000P3j
l>H400000080n_3V0`0000000`3jl>H000000000000C0?[`iP8000003`3jl>H3000000050?[`iP00
000000000000003jl>H01000003O0?[`iP40oooo003M0?[`iP8000000P3jl>H2000003<0n_3V0P00
00030?[`iP030000003jl>H0n_3V01P0n_3V0P00000Q0?[`iP@00000603jl>H00`000000n_3V0?[`
iP3O0?[`iP40oooo003L0?[`iPH00000103jl>H2000002l0n_3V1@00000K0?[`iP<000008@3jl>H2
000001T0n_3V00<000000?[`iP3jl>H0gP3jl>H10?ooo`00o`3jl>Ih0?[`iP030000003jl>H0n_3V
0=d0n_3V0@3oool00?l0n_3VM@3jl>H010000000n_3V0?[`iP00003O0?[`iP40oooo003o0?[`iWH0
n_3V0P00003P0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01473 L
.03152 .01473 L
.03152 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01473 L
.03152 .01473 L
.03152 .16187 L
s
1 .894 .882 r
.03152 .16187 m
.03152 .01477 L
.03787 .01477 L
.03787 .16187 L
F
.804 .522 .247 r
.03152 .16187 m
.03152 .01477 L
.03787 .01477 L
.03787 .16187 L
s
1 .894 .882 r
.03787 .16187 m
.03787 .01487 L
.05014 .01487 L
.05014 .16187 L
F
.804 .522 .247 r
.03787 .16187 m
.03787 .01487 L
.05014 .01487 L
.05014 .16187 L
s
1 .894 .882 r
.05014 .16187 m
.05014 .01557 L
.06567 .01557 L
.06567 .16187 L
F
.804 .522 .247 r
.05014 .16187 m
.05014 .01557 L
.06567 .01557 L
.06567 .16187 L
s
1 .894 .882 r
.06567 .16187 m
.06567 .01607 L
.07198 .01607 L
.07198 .16187 L
F
.804 .522 .247 r
.06567 .16187 m
.06567 .01607 L
.07198 .01607 L
.07198 .16187 L
s
1 .894 .882 r
.07198 .16187 m
.07198 .0163 L
.07856 .0163 L
.07856 .16187 L
F
.804 .522 .247 r
.07198 .16187 m
.07198 .0163 L
.07856 .0163 L
.07856 .16187 L
s
1 .894 .882 r
.07856 .16187 m
.07856 .01724 L
.08771 .01724 L
.08771 .16187 L
F
.804 .522 .247 r
.07856 .16187 m
.07856 .01724 L
.08771 .01724 L
.08771 .16187 L
s
1 .894 .882 r
.08771 .16187 m
.08771 .01784 L
.09358 .01784 L
.09358 .16187 L
F
.804 .522 .247 r
.08771 .16187 m
.08771 .01784 L
.09358 .01784 L
.09358 .16187 L
s
1 .894 .882 r
.09358 .16187 m
.09358 .01851 L
.10511 .01851 L
.10511 .16187 L
F
.804 .522 .247 r
.09358 .16187 m
.09358 .01851 L
.10511 .01851 L
.10511 .16187 L
s
1 .894 .882 r
.10511 .16187 m
.10511 .01949 L
.1129 .01949 L
.1129 .16187 L
F
.804 .522 .247 r
.10511 .16187 m
.10511 .01949 L
.1129 .01949 L
.1129 .16187 L
s
1 .894 .882 r
.1129 .16187 m
.1129 .0206 L
.12583 .0206 L
.12583 .16187 L
F
.804 .522 .247 r
.1129 .16187 m
.1129 .0206 L
.12583 .0206 L
.12583 .16187 L
s
1 .894 .882 r
.12583 .16187 m
.12583 .02158 L
.13141 .02158 L
.13141 .16187 L
F
.804 .522 .247 r
.12583 .16187 m
.12583 .02158 L
.13141 .02158 L
.13141 .16187 L
s
1 .894 .882 r
.13141 .16187 m
.13141 .02351 L
.14158 .02351 L
.14158 .16187 L
F
.804 .522 .247 r
.13141 .16187 m
.13141 .02351 L
.14158 .02351 L
.14158 .16187 L
s
1 .894 .882 r
.14158 .16187 m
.14158 .02389 L
.14731 .02389 L
.14731 .16187 L
F
.804 .522 .247 r
.14158 .16187 m
.14158 .02389 L
.14731 .02389 L
.14731 .16187 L
s
1 .894 .882 r
.14731 .16187 m
.14731 .02484 L
.15485 .02484 L
.15485 .16187 L
F
.804 .522 .247 r
.14731 .16187 m
.14731 .02484 L
.15485 .02484 L
.15485 .16187 L
s
1 .894 .882 r
.15485 .16187 m
.15485 .02638 L
.16382 .02638 L
.16382 .16187 L
F
.804 .522 .247 r
.15485 .16187 m
.15485 .02638 L
.16382 .02638 L
.16382 .16187 L
s
1 .894 .882 r
.16382 .16187 m
.16382 .02844 L
.17366 .02844 L
.17366 .16187 L
F
.804 .522 .247 r
.16382 .16187 m
.16382 .02844 L
.17366 .02844 L
.17366 .16187 L
s
1 .894 .882 r
.17366 .16187 m
.17366 .03217 L
.18834 .03217 L
.18834 .16187 L
F
.804 .522 .247 r
.17366 .16187 m
.17366 .03217 L
.18834 .03217 L
.18834 .16187 L
s
1 .894 .882 r
.18834 .16187 m
.18834 .03422 L
.20348 .03422 L
.20348 .16187 L
F
.804 .522 .247 r
.18834 .16187 m
.18834 .03422 L
.20348 .03422 L
.20348 .16187 L
s
1 .894 .882 r
.20348 .16187 m
.20348 .03802 L
.2177 .03802 L
.2177 .16187 L
F
.804 .522 .247 r
.20348 .16187 m
.20348 .03802 L
.2177 .03802 L
.2177 .16187 L
s
1 .894 .882 r
.2177 .16187 m
.2177 .04276 L
.2323 .04276 L
.2323 .16187 L
F
.804 .522 .247 r
.2177 .16187 m
.2177 .04276 L
.2323 .04276 L
.2323 .16187 L
s
1 .894 .882 r
.2323 .16187 m
.2323 .04344 L
.24256 .04344 L
.24256 .16187 L
F
.804 .522 .247 r
.2323 .16187 m
.2323 .04344 L
.24256 .04344 L
.24256 .16187 L
s
1 .894 .882 r
.24256 .16187 m
.24256 .04851 L
.25535 .04851 L
.25535 .16187 L
F
.804 .522 .247 r
.24256 .16187 m
.24256 .04851 L
.25535 .04851 L
.25535 .16187 L
s
1 .894 .882 r
.25535 .16187 m
.25535 .05009 L
.26254 .05009 L
.26254 .16187 L
F
.804 .522 .247 r
.25535 .16187 m
.25535 .05009 L
.26254 .05009 L
.26254 .16187 L
s
1 .894 .882 r
.26254 .16187 m
.26254 .05303 L
.27419 .05303 L
.27419 .16187 L
F
.804 .522 .247 r
.26254 .16187 m
.26254 .05303 L
.27419 .05303 L
.27419 .16187 L
s
1 .894 .882 r
.27419 .16187 m
.27419 .05545 L
.28285 .05545 L
.28285 .16187 L
F
.804 .522 .247 r
.27419 .16187 m
.27419 .05545 L
.28285 .05545 L
.28285 .16187 L
s
1 .894 .882 r
.28285 .16187 m
.28285 .05935 L
.28813 .05935 L
.28813 .16187 L
F
.804 .522 .247 r
.28285 .16187 m
.28285 .05935 L
.28813 .05935 L
.28813 .16187 L
s
1 .894 .882 r
.28813 .16187 m
.28813 .06169 L
.29566 .06169 L
.29566 .16187 L
F
.804 .522 .247 r
.28813 .16187 m
.28813 .06169 L
.29566 .06169 L
.29566 .16187 L
s
1 .894 .882 r
.29566 .16187 m
.29566 .06542 L
.30576 .06542 L
.30576 .16187 L
F
.804 .522 .247 r
.29566 .16187 m
.29566 .06542 L
.30576 .06542 L
.30576 .16187 L
s
1 .894 .882 r
.30576 .16187 m
.30576 .06841 L
.3126 .06841 L
.3126 .16187 L
F
.804 .522 .247 r
.30576 .16187 m
.30576 .06841 L
.3126 .06841 L
.3126 .16187 L
s
1 .894 .882 r
.3126 .16187 m
.3126 .07239 L
.3246 .07239 L
.3246 .16187 L
F
.804 .522 .247 r
.3126 .16187 m
.3126 .07239 L
.3246 .07239 L
.3246 .16187 L
s
1 .894 .882 r
.3246 .16187 m
.3246 .07516 L
.33102 .07516 L
.33102 .16187 L
F
.804 .522 .247 r
.3246 .16187 m
.3246 .07516 L
.33102 .07516 L
.33102 .16187 L
s
1 .894 .882 r
.33102 .16187 m
.33102 .07699 L
.34546 .07699 L
.34546 .16187 L
F
.804 .522 .247 r
.33102 .16187 m
.33102 .07699 L
.34546 .07699 L
.34546 .16187 L
s
1 .894 .882 r
.34546 .16187 m
.34546 .08348 L
.36038 .08348 L
.36038 .16187 L
F
.804 .522 .247 r
.34546 .16187 m
.34546 .08348 L
.36038 .08348 L
.36038 .16187 L
s
1 .894 .882 r
.36038 .16187 m
.36038 .0902 L
.37532 .0902 L
.37532 .16187 L
F
.804 .522 .247 r
.36038 .16187 m
.36038 .0902 L
.37532 .0902 L
.37532 .16187 L
s
1 .894 .882 r
.37532 .16187 m
.37532 .09627 L
.38092 .09627 L
.38092 .16187 L
F
.804 .522 .247 r
.37532 .16187 m
.37532 .09627 L
.38092 .09627 L
.38092 .16187 L
s
1 .894 .882 r
.38092 .16187 m
.38092 .09877 L
.38995 .09877 L
.38995 .16187 L
F
.804 .522 .247 r
.38092 .16187 m
.38092 .09877 L
.38995 .09877 L
.38995 .16187 L
s
1 .894 .882 r
.38995 .16187 m
.38995 .10214 L
.4039 .10214 L
.4039 .16187 L
F
.804 .522 .247 r
.38995 .16187 m
.38995 .10214 L
.4039 .10214 L
.4039 .16187 L
s
1 .894 .882 r
.4039 .16187 m
.4039 .10914 L
.41606 .10914 L
.41606 .16187 L
F
.804 .522 .247 r
.4039 .16187 m
.4039 .10914 L
.41606 .10914 L
.41606 .16187 L
s
1 .894 .882 r
.41606 .16187 m
.41606 .1158 L
.42856 .1158 L
.42856 .16187 L
F
.804 .522 .247 r
.41606 .16187 m
.41606 .1158 L
.42856 .1158 L
.42856 .16187 L
s
1 .894 .882 r
.42856 .16187 m
.42856 .12712 L
.44361 .12712 L
.44361 .16187 L
F
.804 .522 .247 r
.42856 .16187 m
.42856 .12712 L
.44361 .12712 L
.44361 .16187 L
s
1 .894 .882 r
.44361 .16187 m
.44361 .12992 L
.45875 .12992 L
.45875 .16187 L
F
.804 .522 .247 r
.44361 .16187 m
.44361 .12992 L
.45875 .12992 L
.45875 .16187 L
s
1 .894 .882 r
.45875 .16187 m
.45875 .14135 L
.47165 .14135 L
.47165 .16187 L
F
.804 .522 .247 r
.45875 .16187 m
.45875 .14135 L
.47165 .14135 L
.47165 .16187 L
s
1 .894 .882 r
.47165 .16187 m
.47165 .14902 L
.48579 .14902 L
.48579 .16187 L
F
.804 .522 .247 r
.47165 .16187 m
.47165 .14902 L
.48579 .14902 L
.48579 .16187 L
s
1 .894 .882 r
.48579 .16187 m
.48579 .15573 L
.491 .15573 L
.491 .16187 L
F
.804 .522 .247 r
.48579 .16187 m
.48579 .15573 L
.491 .15573 L
.491 .16187 L
s
1 .894 .882 r
.491 .16187 m
.491 .16176 L
.50065 .16176 L
.50065 .16187 L
F
.804 .522 .247 r
.491 .16187 m
.491 .16176 L
.50065 .16176 L
.50065 .16187 L
s
.678 .847 .902 r
.50065 .16187 m
.50065 .16465 L
.50551 .16465 L
.50551 .16187 L
F
.2 .63 .79 r
.50065 .16187 m
.50065 .16465 L
.50551 .16465 L
.50551 .16187 L
s
.678 .847 .902 r
.50551 .16187 m
.50551 .16701 L
.51722 .16701 L
.51722 .16187 L
F
.2 .63 .79 r
.50551 .16187 m
.50551 .16701 L
.51722 .16701 L
.51722 .16187 L
s
.678 .847 .902 r
.51722 .16187 m
.51722 .17534 L
.52665 .17534 L
.52665 .16187 L
F
.2 .63 .79 r
.51722 .16187 m
.51722 .17534 L
.52665 .17534 L
.52665 .16187 L
s
.678 .847 .902 r
.52665 .16187 m
.52665 .18218 L
.5324 .18218 L
.5324 .16187 L
F
.2 .63 .79 r
.52665 .16187 m
.52665 .18218 L
.5324 .18218 L
.5324 .16187 L
s
.678 .847 .902 r
.5324 .16187 m
.5324 .1844 L
.54785 .1844 L
.54785 .16187 L
F
.2 .63 .79 r
.5324 .16187 m
.5324 .1844 L
.54785 .1844 L
.54785 .16187 L
s
.678 .847 .902 r
.54785 .16187 m
.54785 .19663 L
.55679 .19663 L
.55679 .16187 L
F
.2 .63 .79 r
.54785 .16187 m
.54785 .19663 L
.55679 .19663 L
.55679 .16187 L
s
.678 .847 .902 r
.55679 .16187 m
.55679 .20623 L
.57199 .20623 L
.57199 .16187 L
F
.2 .63 .79 r
.55679 .16187 m
.55679 .20623 L
.57199 .20623 L
.57199 .16187 L
s
.678 .847 .902 r
.57199 .16187 m
.57199 .21036 L
.58676 .21036 L
.58676 .16187 L
F
.2 .63 .79 r
.57199 .16187 m
.57199 .21036 L
.58676 .21036 L
.58676 .16187 L
s
.678 .847 .902 r
.58676 .16187 m
.58676 .22279 L
.59498 .22279 L
.59498 .16187 L
F
.2 .63 .79 r
.58676 .16187 m
.58676 .22279 L
.59498 .22279 L
.59498 .16187 L
s
.678 .847 .902 r
.59498 .16187 m
.59498 .23141 L
.60225 .23141 L
.60225 .16187 L
F
.2 .63 .79 r
.59498 .16187 m
.59498 .23141 L
.60225 .23141 L
.60225 .16187 L
s
.678 .847 .902 r
.60225 .16187 m
.60225 .23391 L
.60777 .23391 L
.60777 .16187 L
F
.2 .63 .79 r
.60225 .16187 m
.60225 .23391 L
.60777 .23391 L
.60777 .16187 L
s
.678 .847 .902 r
.60777 .16187 m
.60777 .24567 L
.62349 .24567 L
.62349 .16187 L
F
.2 .63 .79 r
.60777 .16187 m
.60777 .24567 L
.62349 .24567 L
.62349 .16187 L
s
.678 .847 .902 r
.62349 .16187 m
.62349 .24881 L
.63264 .24881 L
.63264 .16187 L
F
.2 .63 .79 r
.62349 .16187 m
.62349 .24881 L
.63264 .24881 L
.63264 .16187 L
s
.678 .847 .902 r
.63264 .16187 m
.63264 .25722 L
.63907 .25722 L
.63907 .16187 L
F
.2 .63 .79 r
.63264 .16187 m
.63264 .25722 L
.63907 .25722 L
.63907 .16187 L
s
.678 .847 .902 r
.63907 .16187 m
.63907 .26224 L
.65143 .26224 L
.65143 .16187 L
F
.2 .63 .79 r
.63907 .16187 m
.63907 .26224 L
.65143 .26224 L
.65143 .16187 L
s
.678 .847 .902 r
.65143 .16187 m
.65143 .27427 L
.65796 .27427 L
.65796 .16187 L
F
.2 .63 .79 r
.65143 .16187 m
.65143 .27427 L
.65796 .27427 L
.65796 .16187 L
s
.678 .847 .902 r
.65796 .16187 m
.65796 .28625 L
.67081 .28625 L
.67081 .16187 L
F
.2 .63 .79 r
.65796 .16187 m
.65796 .28625 L
.67081 .28625 L
.67081 .16187 L
s
.678 .847 .902 r
.67081 .16187 m
.67081 .28795 L
.68061 .28795 L
.68061 .16187 L
F
.2 .63 .79 r
.67081 .16187 m
.67081 .28795 L
.68061 .28795 L
.68061 .16187 L
s
.678 .847 .902 r
.68061 .16187 m
.68061 .2995 L
.69379 .2995 L
.69379 .16187 L
F
.2 .63 .79 r
.68061 .16187 m
.68061 .2995 L
.69379 .2995 L
.69379 .16187 L
s
.678 .847 .902 r
.69379 .16187 m
.69379 .31003 L
.70104 .31003 L
.70104 .16187 L
F
.2 .63 .79 r
.69379 .16187 m
.69379 .31003 L
.70104 .31003 L
.70104 .16187 L
s
.678 .847 .902 r
.70104 .16187 m
.70104 .31882 L
.71687 .31882 L
.71687 .16187 L
F
.2 .63 .79 r
.70104 .16187 m
.70104 .31882 L
.71687 .31882 L
.71687 .16187 L
s
.678 .847 .902 r
.71687 .16187 m
.71687 .33363 L
.7284 .33363 L
.7284 .16187 L
F
.2 .63 .79 r
.71687 .16187 m
.71687 .33363 L
.7284 .33363 L
.7284 .16187 L
s
.678 .847 .902 r
.7284 .16187 m
.7284 .34423 L
.74113 .34423 L
.74113 .16187 L
F
.2 .63 .79 r
.7284 .16187 m
.7284 .34423 L
.74113 .34423 L
.74113 .16187 L
s
.678 .847 .902 r
.74113 .16187 m
.74113 .35773 L
.7546 .35773 L
.7546 .16187 L
F
.2 .63 .79 r
.74113 .16187 m
.74113 .35773 L
.7546 .35773 L
.7546 .16187 L
s
.678 .847 .902 r
.7546 .16187 m
.7546 .37141 L
.77033 .37141 L
.77033 .16187 L
F
.2 .63 .79 r
.7546 .16187 m
.7546 .37141 L
.77033 .37141 L
.77033 .16187 L
s
.678 .847 .902 r
.77033 .16187 m
.77033 .38334 L
.78602 .38334 L
.78602 .16187 L
F
.2 .63 .79 r
.77033 .16187 m
.77033 .38334 L
.78602 .38334 L
.78602 .16187 L
s
.678 .847 .902 r
.78602 .16187 m
.78602 .39326 L
.79407 .39326 L
.79407 .16187 L
F
.2 .63 .79 r
.78602 .16187 m
.78602 .39326 L
.79407 .39326 L
.79407 .16187 L
s
.678 .847 .902 r
.79407 .16187 m
.79407 .41011 L
.80656 .41011 L
.80656 .16187 L
F
.2 .63 .79 r
.79407 .16187 m
.79407 .41011 L
.80656 .41011 L
.80656 .16187 L
s
.678 .847 .902 r
.80656 .16187 m
.80656 .41485 L
.81159 .41485 L
.81159 .16187 L
F
.2 .63 .79 r
.80656 .16187 m
.80656 .41485 L
.81159 .41485 L
.81159 .16187 L
s
.678 .847 .902 r
.81159 .16187 m
.81159 .42753 L
.8231 .42753 L
.8231 .16187 L
F
.2 .63 .79 r
.81159 .16187 m
.81159 .42753 L
.8231 .42753 L
.8231 .16187 L
s
.678 .847 .902 r
.8231 .16187 m
.8231 .43399 L
.83182 .43399 L
.83182 .16187 L
F
.2 .63 .79 r
.8231 .16187 m
.8231 .43399 L
.83182 .43399 L
.83182 .16187 L
s
.678 .847 .902 r
.83182 .16187 m
.83182 .44936 L
.84541 .44936 L
.84541 .16187 L
F
.2 .63 .79 r
.83182 .16187 m
.83182 .44936 L
.84541 .44936 L
.84541 .16187 L
s
.678 .847 .902 r
.84541 .16187 m
.84541 .45403 L
.8581 .45403 L
.8581 .16187 L
F
.2 .63 .79 r
.84541 .16187 m
.84541 .45403 L
.8581 .45403 L
.8581 .16187 L
s
.678 .847 .902 r
.8581 .16187 m
.8581 .47551 L
.8671 .47551 L
.8671 .16187 L
F
.2 .63 .79 r
.8581 .16187 m
.8581 .47551 L
.8671 .47551 L
.8671 .16187 L
s
.678 .847 .902 r
.8671 .16187 m
.8671 .47636 L
.87505 .47636 L
.87505 .16187 L
F
.2 .63 .79 r
.8671 .16187 m
.8671 .47636 L
.87505 .47636 L
.87505 .16187 L
s
.678 .847 .902 r
.87505 .16187 m
.87505 .49967 L
.88879 .49967 L
.88879 .16187 L
F
.2 .63 .79 r
.87505 .16187 m
.87505 .49967 L
.88879 .49967 L
.88879 .16187 L
s
.678 .847 .902 r
.88879 .16187 m
.88879 .50953 L
.89709 .50953 L
.89709 .16187 L
F
.2 .63 .79 r
.88879 .16187 m
.88879 .50953 L
.89709 .50953 L
.89709 .16187 L
s
.678 .847 .902 r
.89709 .16187 m
.89709 .51413 L
.90442 .51413 L
.90442 .16187 L
F
.2 .63 .79 r
.89709 .16187 m
.89709 .51413 L
.90442 .51413 L
.90442 .16187 L
s
.678 .847 .902 r
.90442 .16187 m
.90442 .52888 L
.91588 .52888 L
.91588 .16187 L
F
.2 .63 .79 r
.90442 .16187 m
.90442 .52888 L
.91588 .52888 L
.91588 .16187 L
s
.678 .847 .902 r
.91588 .16187 m
.91588 .53427 L
.92785 .53427 L
.92785 .16187 L
F
.2 .63 .79 r
.91588 .16187 m
.91588 .53427 L
.92785 .53427 L
.92785 .16187 L
s
.678 .847 .902 r
.92785 .16187 m
.92785 .54512 L
.93917 .54512 L
.93917 .16187 L
F
.2 .63 .79 r
.92785 .16187 m
.92785 .54512 L
.93917 .54512 L
.93917 .16187 L
s
.678 .847 .902 r
.93917 .16187 m
.93917 .56405 L
.95256 .56405 L
.95256 .16187 L
F
.2 .63 .79 r
.93917 .16187 m
.93917 .56405 L
.95256 .56405 L
.95256 .16187 L
s
.678 .847 .902 r
.95256 .16187 m
.95256 .58133 L
.96672 .58133 L
.96672 .16187 L
F
.2 .63 .79 r
.95256 .16187 m
.95256 .58133 L
.96672 .58133 L
.96672 .16187 L
s
.678 .847 .902 r
.96672 .16187 m
.96672 .59852 L
.97619 .59852 L
.97619 .16187 L
F
.2 .63 .79 r
.96672 .16187 m
.96672 .59852 L
.97619 .59852 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02839 .01473 Mdot
.03259 .01477 Mdot
.03946 .01487 Mdot
.06008 .01557 Mdot
.0695 .01607 Mdot
.07319 .0163 Mdot
.08618 .01724 Mdot
.09325 .01784 Mdot
.10029 .01851 Mdot
.1096 .01949 Mdot
.11906 .0206 Mdot
.12666 .02158 Mdot
.14024 .02351 Mdot
.14269 .02389 Mdot
.14873 .02484 Mdot
.15791 .02638 Mdot
.16923 .02844 Mdot
.18781 .03217 Mdot
.19719 .03422 Mdot
.21333 .03802 Mdot
.23171 .04276 Mdot
.23421 .04344 Mdot
.252 .04851 Mdot
.25727 .05009 Mdot
.2668 .05303 Mdot
.27435 .05545 Mdot
.28607 .05935 Mdot
.29286 .06169 Mdot
.30333 .06542 Mdot
.31147 .06841 Mdot
.32192 .07239 Mdot
.329 .07516 Mdot
.33359 .07699 Mdot
.34933 .08348 Mdot
.36487 .0902 Mdot
.37832 .09627 Mdot
.38371 .09877 Mdot
.39085 .10214 Mdot
.40526 .10914 Mdot
.41849 .1158 Mdot
.44 .12712 Mdot
.44514 .12992 Mdot
.46555 .14135 Mdot
.47874 .14902 Mdot
.48996 .15573 Mdot
.49982 .16176 Mdot
.50448 .16465 Mdot
.50825 .16701 Mdot
.52133 .17534 Mdot
.5318 .18218 Mdot
.53516 .1844 Mdot
.55326 .19663 Mdot
.56706 .20623 Mdot
.57289 .21036 Mdot
.59006 .22279 Mdot
.60168 .23141 Mdot
.605 .23391 Mdot
.62037 .24567 Mdot
.62442 .24881 Mdot
.63512 .25722 Mdot
.64141 .26224 Mdot
.65624 .27427 Mdot
.67068 .28625 Mdot
.6727 .28795 Mdot
.68626 .2995 Mdot
.6984 .31003 Mdot
.70837 .31882 Mdot
.72484 .33363 Mdot
.73639 .34423 Mdot
.75085 .35773 Mdot
.7652 .37141 Mdot
.7775 .38334 Mdot
.78757 .39326 Mdot
.80438 .41011 Mdot
.80905 .41485 Mdot
.8214 .42753 Mdot
.82761 .43399 Mdot
.84221 .44936 Mdot
.8466 .45403 Mdot
.86647 .47551 Mdot
.86725 .47636 Mdot
.88828 .49967 Mdot
.89702 .50953 Mdot
.90108 .51413 Mdot
.91393 .52888 Mdot
.91858 .53427 Mdot
.92788 .54512 Mdot
.94387 .56405 Mdot
.95823 .58133 Mdot
.9723 .59852 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0332425) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.667475) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<000001@3jl>H2000000@0n_3V100000040?[`iP80
0000103jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP8000001@3j
l>H2000000D0n_3V0P0000030?[`iP030000003jl>H0n_3V00800000o`3jl>JL0?[`iP40oooo000P
0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V
0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0
n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000040?[`iP8000000P3jl>H6000000@0n_3V0P00
00060?[`iP800000o`3jl>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P000000
1P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP800000
00@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80
000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000040?[`iP8000000P3jl>H00`000000n_3V0?[`iP02000000D0n_3V0P0000060?[`iP80
0000o`3jl>JL0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V
0000000000002@3jl>H4000000<0n_3V100000060?[`iP8000000P3jl>H010000000n_3V00000000
00060?[`iP8000000P3jl>H00`000000n_3V0?[`iP0200000?l0n_3VW03jl>H10?ooo`00803jl>H2
00000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H0000000000005
00000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V
0000000000001`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H2000000D0n_3V0P000008
0?[`iP8000000P3jl>H010000000n_3V0000000000060?[`iP8000000P3jl>H400000?l0n_3VW@3j
l>H10?ooo`00803jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0U
0?[`iP80000000<0n_3V0000000000002P3jl>H2000000D0n_3V0P0000040?[`iP030000003jl>H0
n_3V008000000`3jl>H3000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`iP800000o`3jl>JO
0?[`iP40oooo000O0?[`iPH00000103jl>H2000002l0n_3V1@00000X0?[`iP<00000303jl>H30000
00@0n_3V0`0000020?[`iPD00000103jl>H2000000<0n_3V1@0000020?[`iPD00000o`3jl>JL0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool003d0n_3V1000003o0?[`i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3Vo`3jl>HG0?[`
iP40oooo000P0?[`iPH0000000D0n_3V00000000000000000?[`iP0300000080n_3V0`0000030?[`
iP@000000`3jl>H2000000040?[`iP00000000000?[`iPD000000`3jl>H<000002l0n_3V0`000004
0?[`iP8000001@3jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`000005
0?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP0000000000
0080n_3V0P0000020?[`iP040000003jl>H00000000000<0n_3V00D000000?[`iP00000000000?[`
iP0300000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`iPD000002@3j
l>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3o
ool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P000005
0?[`iP8000000P3jl>H200000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000`
0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iPH0000000<0n_3V0000
000000000P3jl>H200000080n_3V0P0000050?[`iPD000000`3jl>H200000280n_3V1@0000090?[`
iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP80
0000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP8000000P3jl>H200000004
0?[`iP00000000000?[`iP<000000P3jl>H3000000030?[`iP000000n_3V00@0n_3V0P0000030?[`
iP800000<03jl>H2000000030?[`iP000000000000T0n_3V100000030?[`iP@000000`3jl>H40000
00<0n_3V100000030?[`iP@000001P3jl>H200000?l0n_3VW@3jl>H10?ooo`008P3jl>H2000000<0
n_3V1@0000020?[`iPD000000`3jl>H4000000<0n_3V0P0000000`3jl>H000000000000400000003
0?[`iP00000000000080n_3V100000040?[`iP800000<03jl>H2000000030?[`iP000000000000T0
n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000203jl>H200000?l0
n_3VW@3jl>H10?ooo`008P3jl>H2000000/0n_3V0P00000R0?[`iP800000<03jl>H2000000030?[`
iP000000000000X0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000
103jl>H00`000000n_3V0?[`iP0200000?l0n_3VW@3jl>H10?ooo`00803jl>H6000000T0n_3V0P00
000P0?[`iP@00000<@3jl>H3000000`0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`00
00040?[`iP<000000P3jl>H500000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0
n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H0
10000000n_3V0000003jl>H200000080n_3V00<000000?[`iP3jl>H00`00003o0?[`i_l0n_3V903j
l>H10?ooo`00803jl>H3000000030?[`iP00000000000080000000D0n_3V0000003jl>H000000?[`
iP0300000080n_3V00<000000?[`iP000000603jl>H500000=/0n_3V100000040?[`iP/00000103j
l>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000@0
n_3V0000000000000000203jl>H4000000030?[`iP00000000000080n_3V100000020?[`iPD00000
00L0n_3V00000000000000000?[`iP000000n_3V00<00000603jl>H3000000@0n_3V0P0000050?[`
iP<00000103jl>H3000000@0n_3V0`0000030?[`iPD000000`3jl>H400000080n_3V1@0000030?[`
iP<00000LP3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000@0n_3V00000000
000000000P3jl>H2000000030?[`iP000000000000T0n_3V1@0000090?[`iP800000g`3jl>H20000
00@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V
0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3j
l>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3j
l>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2000000030?[`iP00
000000000080n_3V00<000000?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V008000000P3j
l>H2000000L0n_3V0P0000030?[`iP8000001@3jl>H00`000000n_3V0?[`iP0200000740n_3V0@3o
ool00280n_3V0`00000Y0?[`iP800000gP3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2
000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000000000000?[`
iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V00800000603j
l>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000050?[`iP8000001@3j
l>H2000000<0n_3V0P0000030?[`iPH000000`3jl>H2000000L0n_3V0P00001a0?[`iP40oooo000R
0?[`iP<000006P3jl>H5000000/0n_3V0P00003M0?[`iP@000000`3jl>H500000080n_3V0P000005
0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P000002
0?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P00
00020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00
000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000000000D0n_3V0P00
00050?[`iP800000103jl>H200000080n_3V00<000000?[`iP3jl>H00P0000050?[`iP8000001P3j
l>H200000740n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000Z0?[`iP800000g03jl>H2
000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P00
00060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
00000`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP800000
0P3jl>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP800000
00<0n_3V0000000000002@3jl>H2000000030?[`iP000000000000<0n_3V0`0000040?[`iP<00000
1P3jl>H200000080n_3V00@000000?[`iP00000000001P3jl>H200000080n_3V00<000000?[`iP3j
l>H00P00001a0?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H200000003
0?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H300000004
0?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H40000
0080n_3V1@00000;0?[`iP<0000000<0n_3V0000000000000P3jl>H400000080n_3V0`0000000`3j
l>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000
000000001@3jl>H2000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H01000
0000n_3V0000000000030?[`iP80000000<0n_3V0000000000000P3jl>H400000780n_3V0@3oool0
04d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403jl>H20000
00`0n_3V0P00000R0?[`iP8000000P3jl>H2000002h0n_3V0P0000000`3jl>H00000000000090?[`
iP80000000<0n_3V0000000000000P3jl>H00`000000n_3V0?[`iP0200000080n_3V00<000000?[`
iP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000`3jl>H3000000<0n_3V0P0000000`3j
l>H00000000000020?[`iP800000M03jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP80
00001P3jl>H2000000@0n_3V0P0000060?[`iP8000006@3jl>H3000000030?[`iP00000000000080
0000;P3jl>H3000000/0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP80
0000103jl>H3000000<0n_3V1@00001a0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP080000
00030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`
iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR
0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P000000103jl>H000000?[`iP000002
0?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V1000
00040?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V1000
00020?[`iP<0000000<0n_3V0000000000001P00000J0?[`iP<000001@3jl>H300000<40n_3V0@3o
ool00240n_3V0P0000000`3jl>H0000000000005000000050?[`iP00000000000000003jl>H01000
000;0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3j
l>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V
0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80
000000@0n_3V000000000000n_3V0P0000020?[`iP8000002`3jl>H5000000/0n_3V0P0000030?[`
iP80000000<0n_3V000000000000`03jl>H10?ooo`008P3jl>H3000002P0n_3V0P0000000`3jl>H0
00000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H2000000H0
n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H200000003
0?[`iP000000000000<0n_3V1000000L0?[`iP8000000P3jl>H2000000030?[`iP00000000000<00
n_3V0@3oool00280n_3V0`0000090?[`iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP800000
00<0n_3V000000000000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V
0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`
iP00000000000?[`iP@000003@3jl>H5000000X0n_3V100000020?[`iP80000000<0n_3V00000000
0000`03jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002L0n_3V0P0000000`3jl>H00000
0000003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H00000
0?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000001T0n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00803jl>H300000004
0?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000
000000000P3jl>H400000080n_3V0`000000103jl>H000000000003jl>H500000080n_3V10000003
0?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000000`3jl>H5000001T0n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00C@3jl>H20000
00030?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H20000
03P0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000`03jl>H10?oo
o`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP80
0000<@3jl>H3000000@0n_3V0`0000310?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`007@3jl>HV0?ooh0800000K03oon02000000@0oooP0P0000040?oo
h0800000J`3oon05000006T0oooP1@0000020?ooh0800000103oon02000006/0oooP1000000S0?oo
h1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP
000000P0oooP00@000000?ooh03oon000000K03oon000`000000oooP0?ooh01[0?ooh0030000003o
on00oooP00L0oooP00@000000?ooh03oon000000JP3oon000`000000oooP0?ooh00T0?ooh1h0n_3V
0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000/0
oooP00<000000?ooh03oon00JP3oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00X0
oooP00<000000?ooh03oon00J@3oon000`000000oooP0?ooh00S0?ooh1h0n_3V0@3oool001d0n_3V
9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0oooP0P00001]0?oo
h0030000003oon00oooP06/0oooP00<000000?ooh03oon00203oon02000006d0oooP00<000000?oo
h03oon008P3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon001000
0000oooP0?ooh00000090?ooh0030000003oon00oooP06`0oooP00<000000?ooh03oon00J`3oon00
0`000000oooP0?ooh0080?ooh0030000003oon00oooP06X0oooP00@000000?ooh03oon0000008`3o
on0N0?[`iP40oooo000M0?[`iRH0oooP0P00001/0?ooh08000002P3oon03000006/0oooP0P00001/
0?ooh08000002P3oon03000006/0oooP0P00000T0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooPo`00003Z000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000
oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0D000001P3oon00
0`000000oooP0?ooh00;0?ooh0@0000000<0oooP000000000000203oon0200000?l0oooPbP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?oo
h0030000003oon00oooP00X0oooP2@0000060?ooh0@000000P3oon03000000D0oooP0P00003o0?oo
h;d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03o
on001P3oon04000000P0oooP6P000?l00`3=QCl0oooP0?ooh00600000080oooP0P0000020?ooh080
0000o`3oon2_0?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iPX0oooP100000040?ooh0030000
003oon00oooP00H0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ00000003000000030?oT
h@000000000000@0onCQ00@0cHDo0?oTh@3oi>40onCQ0P0000000`3oi>40cHDo00000004000000P0
003o2P0000020?ooh080000000<0oooP000000000000o`3oon2Z0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00
2@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>4000000080000000<0onCQ0<f5?`3oi>400P3oi>44000000X0
003o00<0cHDo0000000000001@0000040?ooh0800000o`3oon2S0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0
onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>400000
00000080onCQ0P0000001@3=QCl0onCQ000000000000cHDo00T0003o0P3oon04000000030?ooh000
000000000?l0oooPW`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ
0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oT
h@80000000D0onCQ000000000000onCQ0<f5?`080000o`8000000P3oon0200000?l0oooPVP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3o
i>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5
?`<0onCQ1@0000050000o`80000000@0cHDo0?ooh00000000000o`3oon2E0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oT
h@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>420000
00030?oTh@00000000000080onCQ0P0000050000o`80000000<0cHDo0?ooh03oon00o`3oon2A0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo
0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40
cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`00000000000?oTh@3=QCl00P000005
0000o`<0oooP0P00003o0?ooh8`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0
cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00H0cHDo
0?oTh@3oi>40onCQ0<f5?`3oi>42000000040?oTh@3=QCl0cHDo0<f5?`D0003o00<000000?ooh03o
on000P00003o0?ooh8L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3o
i>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oT
h@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3o
i>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ0`0000050000o`030000003=QCl0oooP
00<0oooP0P00003o0?ooh7l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo
0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
1@3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ0P0000020?oTh@<0000010000?l0
0`3oon0000000000000200000?l0oooPOP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oT
h@3oi>42000000040?oTh@3=QCl0cHDo0<f5?`D0003oo`3oon1n0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0
onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ
0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>42000000030<f5?`000?l0003o
0080003o0P3oon0300000?l0oooPM@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40
0`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@04
0?oTh@030<f5?`3oi>40onCQ00@0onCQ1@3=QCl40000o`800000o`3oon1d0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon001@3=QCl0onCQ0?oTh@3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40
onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ
0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0
cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00<0onCQ0`00
00030000o`030<f5?`3oon00oooP0?l0oooPKP3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5
?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@<000000P3oi>440000o`800000
00<0oooP000000000000o`3oon1Z0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@03
0<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080
onCQ0`3=QCl010000000003o0000o`000?l300000?l0oooPJ@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oT
h@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3o
i>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0000010000?l00`3oon0000000000003o
0?ooh6D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3o
i>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oT
h@3oi>42000000050?oTh@00000000000?oTh@3=QCl00`000?l300000?l0oooPHP3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0
onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ
00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oT
h@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oT
h@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oT
h@3oi>40cHDo0`0000030000o`040000003=QCl0cHDo0<f5?ol0oooPGP3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0
cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo
0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40
cHDo0?oTh@0500000080003o00@0onCQ0<f5?`0000000000o`3oon1L0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3o
i>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=
QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0
onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@04
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@04
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@8000000P3oi>430000o`@00000o`3oon1I0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5
?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=
QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@04
0<f5?`3oi>40onCQ0?oTh@8000000`000?l200000?l0oooPF03oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oT
h@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3o
i>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@000000P000?l30?ooh0800000o`3oon1C0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0
cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40
103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3o
i>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103o
i>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0
onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl000000000003=
QCl30000o`D00000o`3oon1@0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5
?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ
00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@04000000000?l0003o0000o`<00000o`3o
on1?0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oT
h@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40
103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=
QCl0onCQ0?oTh@3=QCl30?oTh@<000000`000?l30?ooh0800000o`3oon1:0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oT
h@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=
QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oT
h@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oT
h@050<f5?`3oi>4000000000003=QCl00P000?l400000?l0oooPB@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`02
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=
QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl3
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ
0?oTh@<0cHDo0`000?l500000?l0oooP@`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3o
i>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0
onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0
cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>42
000000<0003o0`00003o0?ooh4@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0
cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3o
i>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`04
0?oTh@040<f5?`000000000000000080003o00<000000<f5?`3=QCl00`3=QCoo0?ooh3l0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ
0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl4
0?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5
?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40000000<000000`00
0?l20?oTh@030<f5?`3oon00oooP0?l0oooP?@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ
0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@<0003o0P00003o0?ooh3d0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@04
0<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40
onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01P3oi>4010000000003o0000o`0000040<f5?ol0oooP>03oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oT
h@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3o
i>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@<000000P000?l2
0?oTh@030<f5?`3oon00oooP0?l0oooP=P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`00000000000080onCQ0P00
0?l0103=QCl0oooP00000000003o0?ooh3D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80
onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3o
i>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@040?oTh@80
003o0`0000030<f5?ol0oooP<@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=
QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0000
00000?l00P000?l20?oTh@030<f5?`3oon00oooP0?l0oooP;`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oT
h@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3o
i>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40
onCQ00@0onCQ00D0cHDo0?oTh@00000000000?oTh@020000o`030<f5?`00000000000?l0oooP;`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5
?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ
00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oT
h@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>420000o`@00000
o`3oon0/0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080
onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo
0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3o
i>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@80
00000P000?l300000?l0oooP:`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=
QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oT
h@3oi>40103oi>40103=QCl000000000000000030000o`800000o`3oon0Y0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oT
h@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=
QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oT
h@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00<0
cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`<00000
0P000?l00`000000cHDo0<f5?`030<f5?ol0oooP8`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon03000000T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@03
0<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ0`0000020000o`<0onCQ00<0cHDo0?oo
h03oon00o`3oon0O0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>40
103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ
0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`04
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@04
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@04
0?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5
?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo
0?oTh@3oi>40cHDo0`3oi>4200000080onCQ0P000?l00`3oi>4000000000003o0?ooh280oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ
0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl4
0?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5
?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
1P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40
cHDo0`3oi>400`3=QCl0onCQ0?oTh@030?oTh@80003o0P00003o0?ooh240oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@04
0<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl4
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5
?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ
00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ
00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ
0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@8000000P000?l40<f5?ol0oooP7@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ
0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo
0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oT
h@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo
1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5
?`3oi>40onCQ00@0onCQ0P0000001@3oi>40003o0000o`3oi>40cHDo00800000o`3oon0K0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3o
i>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oT
h@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=
QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ
0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@80003o0`00003o
0?ooh1X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3o
i>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oT
h@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@04
0<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0
cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00<0onCQ
00@000000000o`000?l000000`3=QCoo0?ooh1L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oT
h@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oT
h@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@04
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0000000000000P000?l00`3oi>40cHDo0?ooh03o
0?ooh1H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3o
i>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oT
h@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@04
0<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0
cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?oTh@3oi>400P3oi>420000ool0oooP5`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40
cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo
0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ
00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`000?l0003o
0?l0oooP5@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5
?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oon00oooP0080003o0P00003o0?ooh140oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ
0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl4
0?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5
?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
1P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40
cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3o
i>400`3oi>440<f5?`03000000000?l0000000<00000o`3oon0>0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0
onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ
0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl5
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00<0cHDo0?oT
h@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo
0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo
0?oTh@3oi>40onCQ0P0000020000o`<00000o`3oon0=0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5
?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=
QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3o
i>40103oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3o
i>400P3oi>4300000080003o00<000000<f5?`3=QCl00`3=QCoo0?ooh0P0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0050<f5?`3oi>40onCQ0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40
cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ
00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00@0onCQ00@0cHDo000000000000003o103oi>400`3=QCl0oooP0?ooh03o0?ooh0@0oooP0`00
000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0
cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo
0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40
cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40onCQ0P000?l20?oTh@030<f5?`3oon00oooP
0?l0oooP1P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5
?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40
103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3o
i>420000o`030<f5?`3oon00oooP0?l0oooP1P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ
0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>401@3oi>420000o`030?ooh000000000000?l0oooP103oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0
onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ
00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oT
h@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oT
h@3oi>40103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oT
h@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oT
h@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl3
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@03
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401@3oi>420<f5?`050000o`000000
00000000003=QCl0o`3oon020?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5
?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ
00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ
0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@050?oTh@030<f5?`3oi>4000000080003o00<000000<f5?`3oon00o`3oon010?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3o
i>40103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oT
h@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=
QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00H0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ
0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40
onCQ008000000P000?oo0?ooh080oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0
cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3o
i>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`04
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3o
i>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0003o0000o`0200000?d0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on001@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@04
0<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40
onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3o
i>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oT
h@3oi>400`3oi>420<f5?`04000000000?l0000000000080cHDonP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ
0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo
0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oT
h@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo
1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5
?`3oi>40000000000080003o00<0onCQ0<f5?`3oon00n@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40
cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ
00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ0080000000<0onCQ0000o`000?l00P00003h0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`02
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=
QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl3
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>40103o
i>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40
103oi>4010000000003o00000000003g0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40
cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ
00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00@0onCQ0P0000020000ooL0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0
cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo
0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40
cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00@0cHDo000000000000oooP0P000?l200000?<0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon040000
00P0oooPi`0000020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh004
0000003oon00oooP000000L0oooP00<000000?ooh03oon00k`3oon03000000040000o`0000000000
000000<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP0000
00L0oooP00<000000?ooh03oon00l03oon0300000080003o0P0000020:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0
<j7:0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00l`3oon02000000030000
o`000000<j7:0080<j7:102]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0
[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?@0oooP0P000002
0000o`030?ooh00cXLX0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>Q
bP2]f>H0[MSV03>QbPD0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0
<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03h0?ooh003
0000o`0cXLX0[MSV0080000000D0[MSV03>QbP2]f>H0[MSV03>QbP060:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?T0oooP0P00
0?l30000000403>QbP2]f>H0[MSV03>QbPH0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP03
03>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gH
iP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n@3oon000`0cXLX000000000o`020000
000403>QbP2]f>H0[MSV03>QbPH0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]
f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>Q
bP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n`3oon0010000000003o0?ooh00cXLX20:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:
00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0
[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o@3oon020000o`030:gHiP000000000000H0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
oP3oon000`0cXLX0003o00000002000000D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP03
03>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gH
iP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon000`000000003o0000o`020000
00D0<j7:102]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on010?ooh080000000<0003o0000003oon000`3oon000`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPD0
[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh080oooP0P0000020000o`<0
oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon060?ooh0040000o`3oon00oooP03>QbP@0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H0100cXLX0
[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<00000o`3oon070?ooh080003o00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP0303>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX5
0:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>Q
bP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0T0oooP00H0003o0:gHiP00000000000:gH
iP0cXLX60:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP03
03>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gH
iP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon090?ooh00303>QbP000?l0003o
0080000000<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2P3o
on02000000030000o`000000<j7:00H0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>Q
bP2]f>H0[MSV03>QbPD0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0
<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0/0
oooP0P0000020000o`H0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV
03>QbPD0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]
f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0h0oooP00@0<j7:
0000o`2]f>H0[MSV0P0000000`2]f>H0<j7:0:gHiP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3P3oon00100cXLX0
[MSV0000o`000?l30000000303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX50:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV
03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0>0?ooh0<0<j7:00<0
00000000o`0000000`0000050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H0100cXLX0
[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4P3oon000`000000003o0000o`03000000@0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0D0?ooh004000000000?l00000000000D0<j7:0`2]f>H01`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>Q
bPD0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0
<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1D0oooP00<000000000
o`000?l0103oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX01`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00@0<j7:0:gHiP2]f>H0<j7:
1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh1P0oooP00D0003o0?ooh03oon00oooP03>QbP030:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0
[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP6@3oon02
0000o`030?ooh00cXLX0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00L0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0[MSV03>Q
bPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0K0?ooh0060000o`0cXLX000000000002]f>H0<j7:0`2]f>H0
0`0cXLX0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]
f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX4
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0L0?ooh080003o0P0000001`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>Q
bPD0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0
<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP703oon02000000030000o`000000<j7:
00<0[MSV00<0<j7:0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV
03>QbPD0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]
f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1d0oooP0P000000
0`000?l0<j7:0:gHiP020:gHiP0303>QbP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0P0?ooh080003o0P2]f>H00`0cXLX0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
803oon000`0cXLX0[MSV0000o`02000000030:gHiP0cXLX0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0P0?ooh080<j7:00<000000000o`0000000P0000070:gHiP0303>QbP2]f>H0[MSV0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP8P3oon0200000080003o0P0000060:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0
[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP8`3oon03
000000030000o`000000[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX50:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV
03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0U0?ooh080000000<0
003o0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2H0oooP00@0<j7:0:gHiP000?l0
003o102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2H0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gH
iP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP9P3oon000`0cXLX0[MSV0:gHiP020:gHiP040000o`00
0000000003>QbP@0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP9P3oon0503>QbP03000000000?l0003o008000000`2]f>H0100cXLX0
[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0[0?oo
h0<0000000<0003o0000000000000P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0403>QbP2]f>H0
[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh2`0oooP0`0000000`000?l0000003>QbP0203>QbP80[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0
[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0^0?ooh08000000P000?l0
1@3oon00<j7:0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh380oooP00D0003o000000000000[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbPD0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0b0?ooh005000000000?l000000000000cXLX01@2]f>H0100cXLX0
[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<P3oon02000000030000o`000000<j7:00D0
[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3<0oooP0P0000020000o`03
0000002]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0
<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3D0
oooP0P0000000`000?l0000003>QbP0303>QbP80[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh3D0oooP0`0000001@000?l0oooP0?ooh03oon00<j7:0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh3H0oooP0P0000001@3oon00003o0000o`3oon00<j7:0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3/0oooP00D0003o03>QbP2]f>H0
[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?03oon0010000?l0[MSV0:gHiP0cXLX50:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP?03oon00100cXLX0003o0000000000050:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
?03oon001@0cXLX000000000o`000?l0000000@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0
[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0m0?ooh0<00000
00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3h0oooP0P0000000`2]f>H0003o0:gH
iP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<00000o`3oon0o0?ooh00403>QbP2]f>H0[MSV0000o`80[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP04
03>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00L0oooP0`00
000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3l0oooP00H0<j7:
0:gHiP2]f>H0[MSV0000o`2]f>H2000000<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP?`3oon000`0cXLX0[MSV0:gHiP020:gHiP040000o`00
0000000000000080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP?`3oon0503>QbP03000000000?l0003o0080000000<0[MSV03>QbP2]f>H0102]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPA@3oon02000000040000o`000000
<j7:03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]
f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4H0oooP0P000000
0`000?l0oooP03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon190?oo
h0030000o`0cXLX0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0
<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4X0
oooP00<0003o0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
BP3oon00100cXLX0003o0000000000020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1:0?ooh00303>QbP000000003o008000000P0cXLX30:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPB`3oon02000000040000o`000000oooP03>QbP<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1<0?ooh080000000<0003o0?ooh00cXLX00`2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP
00<000000?ooh03oon00o`3oon1?0?ooh080003o0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh006
0?ooh0030000003oon00oooP0?l0oooPD03oon001@0cXLX0003o000000000000<j7:00L0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP
00H0oooP1000003o0?ooh4l0oooP00<0<j7:000000000?l00P0000070:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:
0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon001P3oon04000001P0
oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00
o`3oon1@0?ooh00503>QbP00000000000000o`0000001`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV
03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?oo
h03o0?ooh580oooP0P0000000`000?l0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0
<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon1D0?oo
h00303>QbP000?l0[MSV008000000`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1D0?ooh00303>QbP2]f>H0003o00<00000
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1D0?ooh080<j7:00@000000000o`00000000000`0cXLX40:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1G0?ooh003000000000?l0oooP
0080oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPF@3oon020000o`030?ooh00cXLX0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5/0oooP00<0003o03>QbP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPG03oon000`000?l0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1L0?ooh00303>QbP000?l0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh5`0oooP00<0<j7:0:gHiP000?l00P0000000`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPG03oon0203>QbP04000000000?l00000000000D0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1N0?ooh080000000<0003o0000002]f>H0102]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon0300000?l0oooPG`3oon02000000030000o`2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh640oooP00<0<j7:0000o`2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh640oooP00@0<j7:0:gHiP000?l0003o0P0000000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h640oooP0`0cXLX010000000003o0000000000060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6@0oooP0P0000000`000?l0
00000:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh6D0oooP0P0000000`000?l0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h6L0oooP00<0<j7:0000o`2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh00303>QbP2]f>H0003o00@0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPI`3oon001@0cXLX0[MSV0:gHiP000?l0[MSV0080000000<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV
0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI`3oon001@0c
XLX0[MSV0:gHiP2]f>H0003o00<000001`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPI`3oon0403>QbP04000000000?l00000000000L0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6`0oooP00<000000000o`0cXLX0
1`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0
[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPKP3oon00
0`000?l0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1^0?ooh00303>QbP000?l0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh6h0oooP00<0<j7:0:gHiP000?l01@2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon1^0?ooh00303>QbP2]f>H0[MSV0080003o0P0000000`2]
f>H0<j7:0:gHiP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0c
XLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1^0?ooh0@0<j7:00D000000000o`000000
000003>QbP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX4
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPLP3oon02000000030000o`00
0000<j7:00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1c0?ooh080000000<0003o03>Q
bP2]f>H01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7H0oooP00<0003o0:gHiP2]f>H0
102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7H0oooP00<0<j7:0000o`2]f>H0102]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh7H0oooP00<0<j7:0:gHiP000?l00P0000020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPMP3oon0203>QbP04000000000?l0000000000080<j7:
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1h0?ooh080000000@0003o0000003oon00<j7:0`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1i0?ooh080000000<0003o0?ooh00cXLX00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1l0?ooh0030000o`0cXLX0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO@3o
on001@000?l000000000002]f>H0<j7:00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7d0oooP00D000000000o`000000000003>QbP05
0:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1m0?ooh080000000<0003o0000000cXLX01@2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon1n0?ooh080000000<0003o03>QbP2]f>H0102]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000
603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon210?ooh0030000o`2]
f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh840oooP00<0<j7:0000o`2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP@3oon000`0cXLX0[MSV0000o`03
0:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon210?ooh00403>QbP2]f>H0[MSV0000o`80[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh840oooP00D0<j7:0:gHiP2]f>H0[MSV0000
o`0200000080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh840oooP100cXLX01P000000003o000000000000[MSV03>QbP@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon250?ooh080000000@0003o000000000000<j7:102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8H0oooP0P0000000`000?l00000
000000040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQ`3oon0200000003
0000o`000000[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon280?oo
h080000000<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh8X0oooP00<0<j7:0000o`2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh8X0oooP00<0<j7:0:gHiP000?l00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh8X0oooP00@0<j7:0:gHiP2]f>H0003o0P0000040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPRP3oon001@0c
XLX0[MSV0:gHiP000000003o008000000`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP0`0cXLX2000000030000o`00
0000[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPSP3oon02000000050000o`00000000000:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPS`3oon000`0cXLX000000000o`020000000303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8l0oooP00H0<j7:
000000000000003o0000000cXLX50:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2A0?ooh004000000000?l0oooP03>QbPD0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9<0oooP00<0003o
03>QbP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPU03oon000`000?l0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2D0?ooh00303>QbP000?l0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9@0
oooP00<0<j7:0:gHiP000?l00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPU03oon00100cXLX0[MSV0:gHiP000?l20000000303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2D0?ooh0<0<j7:00@0
00000000o`00000000001@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9L0
oooP0P0000000`000?l00000000000040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0@000001`3oon000`00
0000oooP0?ooh03o0?ooh9P0oooP0P0000000`000?l00000000000030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@
0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00o`3oon2I0?ooh080000000<0003o
0000000cXLX00`0cXLX40:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V4@3oon000`000000oooP0?ooh0070?ooh0@00000o`3oon2I0?ooh00300000000
0?l0oooP00<0oooP00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00H0oooP1000000H0?ooh1h0
n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooP
W03oon001@000?l0oooP0?ooh03oon00<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<00000
0?ooh03oon00o`3oon2M0?ooh0040000o`3oon00oooP03>QbP@0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP
0?ooh03o0?ooh9h0oooP00<0003o0?ooh00cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2O0?ooh003
0000o`0cXLX0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX03oon000`000?l0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:00oooP00<0<j7:0000o`2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2P0?ooh00303>QbP2]f>H0003o0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX03oon00100cXLX0[MSV
0:gHiP000?l2000000<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:00oooP0`0cXLX010000000003o0000000000020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2S0?ooh080000000<0003o0000000cXLX00P0cXLX50:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY03oon02000000040000o`3oon00oooP
03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2W
0?ooh0030000o`3oon00<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2X0?ooh0030000o`0cXLX0[MSV00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh:T0oooP00<0003o0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPZ@3oon000`0cXLX0003o0:gHiP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ@3oon000`0cXLX0003o0:gHiP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ@3oon00
0`0cXLX0[MSV0000o`030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPZ@3oon00100cXLX0[MSV0:gHiP000?l20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPZ@3oon001P0cXLX0[MSV0:gHiP2]f>H0003o0:gHiP80
00000P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Y0?ooh00303>QbP2]f>H0[MSV0080
[MSV00H0003o00000000000000000:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Y0?oo
h0D0<j7:00H000000000o`00000000000:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2_
0?ooh005000000000?l0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[`3oon00
1@0cXLX0[MSV0000o`2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:l0oooP00@0<j7:
0:gHiP2]f>H0003o0P0000020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2_0?ooh00503>QbP2]f>H0
[MSV000000000?l00P0000000`2]f>H0<j7:0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[`3oon0303>QbP80000000@0003o
000000000000<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;<0oooP0P0000000`000?l00000000000050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2c0?ooh00503>QbP0000000000
0000o`0000001@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP]@3oon02000000030000o`2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh0030000o`2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2g0?ooh00303>QbP000?l0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh00303>QbP2]f>H0003o00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g
0?ooh00403>QbP2]f>H0[MSV0000o`80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh00703>QbP2]f>H0[MSV0:gHiP000?l00000
03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;L0oooP0`0c
XLX2000000030000o`000000[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP^P3oon02000000030000o`000000000000<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP^`3oon02000000030000o`00000000000080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_03oon02000000030000o`000000<j7:0080
<j7:1@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_@3oon02000000040000o`3oon00oooP03>QbPD0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh<00oooP00<0003o0?ooh00cXLX01@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP`@3oon000`000?l0<j7:0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon31
0?ooh0030000o`000000000000@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP`@3oon0010000000003o000000000004
03>QbPD0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00
oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h<40oooP0P0000000`000?l000000?ooh0020?ooh00303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon320?ooh080
000000D0003o0?ooh03oon00oooP03>QbP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa@3oon0010000?l0oooP0?ooh00cXLX50:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPaP3oon000`000?l0oooP03>QbP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPaP3oon000`000?l0oooP03>QbP050:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa`3o
on000`000?l0<j7:0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPb03oon000`000?l0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb03oon00100c
XLX0003o0000000000020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPb03oon000`0cXLX000000000o`0200000080<j7:1P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?ooh080000000@0003o0000003o
on00<j7:1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3:0?ooh005
000000000?l0oooP0?ooh00cXLX01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon3<0?ooh0030000o`3oon00<j7:00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPc@3oon000`000?l0<j7:0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on0300000?l0oooPcP3oon000`000?l0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPcP3oon000`0cXLX0003o0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh<h0oooP00<0<j7:0:gHiP000?l00P0000020:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh<h0oooP00@0<j7:0:gHiP000000003o0P0000000`2]
f>H0<j7:0:gHiP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3>0?ooh080<j7:00@000000000o`00
000000000P0cXLX40:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3A0?ooh005000000000?l0oooP0?oo
h00cXLX0102]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd`3oon000`000?l0oooP03>QbP040:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon3D0?ooh0030000o`0cXLX0[MSV00<0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh=D0oooP00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe@3oon00
0`0cXLX0003o0:gHiP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3E0?ooh00303>QbP2]f>H0003o
0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh=D0oooP00<0<j7:0:gHiP000?l00P0000000`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000
203oon000`000000oooP0?ooh03o0?ooh=D0oooP0P0cXLX010000000003o00000000000;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0
oooP00<000000?ooh03oon00o`3oon3G0?ooh080000000<0003o0000003oon002P3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000
o`3oon3G0?ooh080000000<0003o0?ooh03oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3j
l>HC0?ooh0030000003oon00oooP00D0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<0
00000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA
0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03o
on00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00=`0n_3V100000020?[`iPP000000P3jl>H4000000070?[`iP000000
00000000003jl>H000000?[`iP0<000000030?[`iP000000000000@0000000@0n_3V000000000000
0000203jl>H5000000@0n_3V1`0000000`3jl>H000000?[`iP03000000T0n_3V1@0000020?[`iP@0
00000P3jl>H500000180n_3V1P0000060?[`iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H0
000000000000003T0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP80
00000`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0
n_3V0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H0
0P00000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V
00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P00
00000`3jl>H00000000000040?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H000000?[`
iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000d0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H00000
0?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000<0?[`iPD00000
1@3jl>H2000000H0n_3V1@0000060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H5000000@0n_3V0P00
00030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<0
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<0
00000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`
iP3jl>H01P3jl>H300000>H0n_3V0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0
n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`000004
0?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P00
00030?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP0B0?[`iP800000203j
l>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H2
00000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H0000000000005
00000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V
0000000000001`00000;0?[`iPD000000P3jl>H400000080n_3V0`0000000`3jl>H000000000000C
0?[`iP8000003`3jl>H3000000050?[`iP00000000000000003jl>H01000003O0?[`iP40oooo003M
0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V01P0n_3V0P00000Q
0?[`iP@00000603jl>H00`000000n_3V0?[`iP3O0?[`iP40oooo003L0?[`iPH00000103jl>H20000
02l0n_3V1@00000K0?[`iP<000008@3jl>H2000001T0n_3V00<000000?[`iP3jl>H0gP3jl>H10?oo
o`00o`3jl>Ih0?[`iP030000003jl>H0n_3V0=d0n_3V0@3oool00?l0n_3VM@3jl>H010000000n_3V
0?[`iP00003O0?[`iP40oooo003o0?[`iWH0n_3V0P00003P0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01473 L
.03231 .01473 L
.03231 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01473 L
.03231 .01473 L
.03231 .16187 L
s
1 .894 .882 r
.03231 .16187 m
.03231 .01489 L
.04187 .01489 L
.04187 .16187 L
F
.804 .522 .247 r
.03231 .16187 m
.03231 .01489 L
.04187 .01489 L
.04187 .16187 L
s
1 .894 .882 r
.04187 .16187 m
.04187 .01518 L
.05241 .01518 L
.05241 .16187 L
F
.804 .522 .247 r
.04187 .16187 m
.04187 .01518 L
.05241 .01518 L
.05241 .16187 L
s
1 .894 .882 r
.05241 .16187 m
.05241 .01528 L
.06379 .01528 L
.06379 .16187 L
F
.804 .522 .247 r
.05241 .16187 m
.05241 .01528 L
.06379 .01528 L
.06379 .16187 L
s
1 .894 .882 r
.06379 .16187 m
.06379 .01585 L
.07515 .01585 L
.07515 .16187 L
F
.804 .522 .247 r
.06379 .16187 m
.06379 .01585 L
.07515 .01585 L
.07515 .16187 L
s
1 .894 .882 r
.07515 .16187 m
.07515 .01673 L
.08069 .01673 L
.08069 .16187 L
F
.804 .522 .247 r
.07515 .16187 m
.07515 .01673 L
.08069 .01673 L
.08069 .16187 L
s
1 .894 .882 r
.08069 .16187 m
.08069 .01694 L
.08954 .01694 L
.08954 .16187 L
F
.804 .522 .247 r
.08069 .16187 m
.08069 .01694 L
.08954 .01694 L
.08954 .16187 L
s
1 .894 .882 r
.08954 .16187 m
.08954 .01786 L
.09368 .01786 L
.09368 .16187 L
F
.804 .522 .247 r
.08954 .16187 m
.08954 .01786 L
.09368 .01786 L
.09368 .16187 L
s
1 .894 .882 r
.09368 .16187 m
.09368 .0183 L
.10069 .0183 L
.10069 .16187 L
F
.804 .522 .247 r
.09368 .16187 m
.09368 .0183 L
.10069 .0183 L
.10069 .16187 L
s
1 .894 .882 r
.10069 .16187 m
.10069 .01888 L
.10753 .01888 L
.10753 .16187 L
F
.804 .522 .247 r
.10069 .16187 m
.10069 .01888 L
.10753 .01888 L
.10753 .16187 L
s
1 .894 .882 r
.10753 .16187 m
.10753 .01938 L
.11185 .01938 L
.11185 .16187 L
F
.804 .522 .247 r
.10753 .16187 m
.10753 .01938 L
.11185 .01938 L
.11185 .16187 L
s
1 .894 .882 r
.11185 .16187 m
.11185 .01997 L
.11804 .01997 L
.11804 .16187 L
F
.804 .522 .247 r
.11185 .16187 m
.11185 .01997 L
.11804 .01997 L
.11804 .16187 L
s
1 .894 .882 r
.11804 .16187 m
.11804 .02103 L
.12424 .02103 L
.12424 .16187 L
F
.804 .522 .247 r
.11804 .16187 m
.11804 .02103 L
.12424 .02103 L
.12424 .16187 L
s
1 .894 .882 r
.12424 .16187 m
.12424 .02161 L
.1317 .02161 L
.1317 .16187 L
F
.804 .522 .247 r
.12424 .16187 m
.12424 .02161 L
.1317 .02161 L
.1317 .16187 L
s
1 .894 .882 r
.1317 .16187 m
.1317 .02246 L
.13584 .02246 L
.13584 .16187 L
F
.804 .522 .247 r
.1317 .16187 m
.1317 .02246 L
.13584 .02246 L
.13584 .16187 L
s
1 .894 .882 r
.13584 .16187 m
.13584 .02359 L
.14237 .02359 L
.14237 .16187 L
F
.804 .522 .247 r
.13584 .16187 m
.13584 .02359 L
.14237 .02359 L
.14237 .16187 L
s
1 .894 .882 r
.14237 .16187 m
.14237 .02435 L
.14863 .02435 L
.14863 .16187 L
F
.804 .522 .247 r
.14237 .16187 m
.14237 .02435 L
.14863 .02435 L
.14863 .16187 L
s
1 .894 .882 r
.14863 .16187 m
.14863 .02508 L
.16009 .02508 L
.16009 .16187 L
F
.804 .522 .247 r
.14863 .16187 m
.14863 .02508 L
.16009 .02508 L
.16009 .16187 L
s
1 .894 .882 r
.16009 .16187 m
.16009 .02746 L
.16573 .02746 L
.16573 .16187 L
F
.804 .522 .247 r
.16009 .16187 m
.16009 .02746 L
.16573 .02746 L
.16573 .16187 L
s
1 .894 .882 r
.16573 .16187 m
.16573 .02794 L
.17027 .02794 L
.17027 .16187 L
F
.804 .522 .247 r
.16573 .16187 m
.16573 .02794 L
.17027 .02794 L
.17027 .16187 L
s
1 .894 .882 r
.17027 .16187 m
.17027 .02885 L
.17652 .02885 L
.17652 .16187 L
F
.804 .522 .247 r
.17027 .16187 m
.17027 .02885 L
.17652 .02885 L
.17652 .16187 L
s
1 .894 .882 r
.17652 .16187 m
.17652 .03061 L
.18489 .03061 L
.18489 .16187 L
F
.804 .522 .247 r
.17652 .16187 m
.17652 .03061 L
.18489 .03061 L
.18489 .16187 L
s
1 .894 .882 r
.18489 .16187 m
.18489 .03292 L
.19579 .03292 L
.19579 .16187 L
F
.804 .522 .247 r
.18489 .16187 m
.18489 .03292 L
.19579 .03292 L
.19579 .16187 L
s
1 .894 .882 r
.19579 .16187 m
.19579 .03513 L
.20394 .03513 L
.20394 .16187 L
F
.804 .522 .247 r
.19579 .16187 m
.19579 .03513 L
.20394 .03513 L
.20394 .16187 L
s
1 .894 .882 r
.20394 .16187 m
.20394 .03751 L
.21422 .03751 L
.21422 .16187 L
F
.804 .522 .247 r
.20394 .16187 m
.20394 .03751 L
.21422 .03751 L
.21422 .16187 L
s
1 .894 .882 r
.21422 .16187 m
.21422 .03998 L
.22557 .03998 L
.22557 .16187 L
F
.804 .522 .247 r
.21422 .16187 m
.21422 .03998 L
.22557 .03998 L
.22557 .16187 L
s
1 .894 .882 r
.22557 .16187 m
.22557 .04196 L
.22969 .04196 L
.22969 .16187 L
F
.804 .522 .247 r
.22557 .16187 m
.22557 .04196 L
.22969 .04196 L
.22969 .16187 L
s
1 .894 .882 r
.22969 .16187 m
.22969 .0437 L
.23899 .0437 L
.23899 .16187 L
F
.804 .522 .247 r
.22969 .16187 m
.22969 .0437 L
.23899 .0437 L
.23899 .16187 L
s
1 .894 .882 r
.23899 .16187 m
.23899 .04655 L
.25045 .04655 L
.25045 .16187 L
F
.804 .522 .247 r
.23899 .16187 m
.23899 .04655 L
.25045 .04655 L
.25045 .16187 L
s
1 .894 .882 r
.25045 .16187 m
.25045 .0504 L
.26002 .0504 L
.26002 .16187 L
F
.804 .522 .247 r
.25045 .16187 m
.25045 .0504 L
.26002 .0504 L
.26002 .16187 L
s
1 .894 .882 r
.26002 .16187 m
.26002 .05231 L
.26782 .05231 L
.26782 .16187 L
F
.804 .522 .247 r
.26002 .16187 m
.26002 .05231 L
.26782 .05231 L
.26782 .16187 L
s
1 .894 .882 r
.26782 .16187 m
.26782 .05517 L
.27675 .05517 L
.27675 .16187 L
F
.804 .522 .247 r
.26782 .16187 m
.26782 .05517 L
.27675 .05517 L
.27675 .16187 L
s
1 .894 .882 r
.27675 .16187 m
.27675 .05873 L
.28496 .05873 L
.28496 .16187 L
F
.804 .522 .247 r
.27675 .16187 m
.27675 .05873 L
.28496 .05873 L
.28496 .16187 L
s
1 .894 .882 r
.28496 .16187 m
.28496 .05974 L
.29145 .05974 L
.29145 .16187 L
F
.804 .522 .247 r
.28496 .16187 m
.28496 .05974 L
.29145 .05974 L
.29145 .16187 L
s
1 .894 .882 r
.29145 .16187 m
.29145 .06205 L
.2987 .06205 L
.2987 .16187 L
F
.804 .522 .247 r
.29145 .16187 m
.29145 .06205 L
.2987 .06205 L
.2987 .16187 L
s
1 .894 .882 r
.2987 .16187 m
.2987 .06448 L
.30519 .06448 L
.30519 .16187 L
F
.804 .522 .247 r
.2987 .16187 m
.2987 .06448 L
.30519 .06448 L
.30519 .16187 L
s
1 .894 .882 r
.30519 .16187 m
.30519 .06651 L
.31097 .06651 L
.31097 .16187 L
F
.804 .522 .247 r
.30519 .16187 m
.30519 .06651 L
.31097 .06651 L
.31097 .16187 L
s
1 .894 .882 r
.31097 .16187 m
.31097 .0726 L
.32253 .0726 L
.32253 .16187 L
F
.804 .522 .247 r
.31097 .16187 m
.31097 .0726 L
.32253 .0726 L
.32253 .16187 L
s
1 .894 .882 r
.32253 .16187 m
.32253 .07266 L
.3294 .07266 L
.3294 .16187 L
F
.804 .522 .247 r
.32253 .16187 m
.32253 .07266 L
.3294 .07266 L
.3294 .16187 L
s
1 .894 .882 r
.3294 .16187 m
.3294 .07811 L
.3419 .07811 L
.3419 .16187 L
F
.804 .522 .247 r
.3294 .16187 m
.3294 .07811 L
.3419 .07811 L
.3419 .16187 L
s
1 .894 .882 r
.3419 .16187 m
.3419 .08376 L
.35396 .08376 L
.35396 .16187 L
F
.804 .522 .247 r
.3419 .16187 m
.3419 .08376 L
.35396 .08376 L
.35396 .16187 L
s
1 .894 .882 r
.35396 .16187 m
.35396 .08687 L
.35782 .08687 L
.35782 .16187 L
F
.804 .522 .247 r
.35396 .16187 m
.35396 .08687 L
.35782 .08687 L
.35782 .16187 L
s
1 .894 .882 r
.35782 .16187 m
.35782 .08782 L
.36281 .08782 L
.36281 .16187 L
F
.804 .522 .247 r
.35782 .16187 m
.35782 .08782 L
.36281 .08782 L
.36281 .16187 L
s
1 .894 .882 r
.36281 .16187 m
.36281 .09123 L
.37453 .09123 L
.37453 .16187 L
F
.804 .522 .247 r
.36281 .16187 m
.36281 .09123 L
.37453 .09123 L
.37453 .16187 L
s
1 .894 .882 r
.37453 .16187 m
.37453 .09669 L
.3841 .09669 L
.3841 .16187 L
F
.804 .522 .247 r
.37453 .16187 m
.37453 .09669 L
.3841 .09669 L
.3841 .16187 L
s
1 .894 .882 r
.3841 .16187 m
.3841 .10047 L
.39212 .10047 L
.39212 .16187 L
F
.804 .522 .247 r
.3841 .16187 m
.3841 .10047 L
.39212 .10047 L
.39212 .16187 L
s
1 .894 .882 r
.39212 .16187 m
.39212 .10509 L
.39875 .10509 L
.39875 .16187 L
F
.804 .522 .247 r
.39212 .16187 m
.39212 .10509 L
.39875 .10509 L
.39875 .16187 L
s
1 .894 .882 r
.39875 .16187 m
.39875 .10851 L
.40609 .10851 L
.40609 .16187 L
F
.804 .522 .247 r
.39875 .16187 m
.39875 .10851 L
.40609 .10851 L
.40609 .16187 L
s
1 .894 .882 r
.40609 .16187 m
.40609 .1142 L
.41791 .1142 L
.41791 .16187 L
F
.804 .522 .247 r
.40609 .16187 m
.40609 .1142 L
.41791 .1142 L
.41791 .16187 L
s
1 .894 .882 r
.41791 .16187 m
.41791 .11929 L
.42711 .11929 L
.42711 .16187 L
F
.804 .522 .247 r
.41791 .16187 m
.41791 .11929 L
.42711 .11929 L
.42711 .16187 L
s
1 .894 .882 r
.42711 .16187 m
.42711 .12349 L
.43339 .12349 L
.43339 .16187 L
F
.804 .522 .247 r
.42711 .16187 m
.42711 .12349 L
.43339 .12349 L
.43339 .16187 L
s
1 .894 .882 r
.43339 .16187 m
.43339 .12429 L
.44396 .12429 L
.44396 .16187 L
F
.804 .522 .247 r
.43339 .16187 m
.43339 .12429 L
.44396 .12429 L
.44396 .16187 L
s
1 .894 .882 r
.44396 .16187 m
.44396 .1298 L
.44809 .1298 L
.44809 .16187 L
F
.804 .522 .247 r
.44396 .16187 m
.44396 .1298 L
.44809 .1298 L
.44809 .16187 L
s
1 .894 .882 r
.44809 .16187 m
.44809 .13816 L
.46025 .13816 L
.46025 .16187 L
F
.804 .522 .247 r
.44809 .16187 m
.44809 .13816 L
.46025 .13816 L
.46025 .16187 L
s
1 .894 .882 r
.46025 .16187 m
.46025 .14082 L
.47127 .14082 L
.47127 .16187 L
F
.804 .522 .247 r
.46025 .16187 m
.46025 .14082 L
.47127 .14082 L
.47127 .16187 L
s
1 .894 .882 r
.47127 .16187 m
.47127 .14619 L
.47667 .14619 L
.47667 .16187 L
F
.804 .522 .247 r
.47127 .16187 m
.47127 .14619 L
.47667 .14619 L
.47667 .16187 L
s
1 .894 .882 r
.47667 .16187 m
.47667 .1494 L
.48513 .1494 L
.48513 .16187 L
F
.804 .522 .247 r
.47667 .16187 m
.47667 .1494 L
.48513 .1494 L
.48513 .16187 L
s
1 .894 .882 r
.48513 .16187 m
.48513 .15639 L
.49456 .15639 L
.49456 .16187 L
F
.804 .522 .247 r
.48513 .16187 m
.48513 .15639 L
.49456 .15639 L
.49456 .16187 L
s
1 .894 .882 r
.49456 .16187 m
.49456 .1588 L
.50209 .1588 L
.50209 .16187 L
F
.804 .522 .247 r
.49456 .16187 m
.49456 .1588 L
.50209 .1588 L
.50209 .16187 L
s
.678 .847 .902 r
.50209 .16187 m
.50209 .16442 L
.51353 .16442 L
.51353 .16187 L
F
.2 .63 .79 r
.50209 .16187 m
.50209 .16442 L
.51353 .16442 L
.51353 .16187 L
s
.678 .847 .902 r
.51353 .16187 m
.51353 .17087 L
.51997 .17087 L
.51997 .16187 L
F
.2 .63 .79 r
.51353 .16187 m
.51353 .17087 L
.51997 .17087 L
.51997 .16187 L
s
.678 .847 .902 r
.51997 .16187 m
.51997 .17875 L
.53038 .17875 L
.53038 .16187 L
F
.2 .63 .79 r
.51997 .16187 m
.51997 .17875 L
.53038 .17875 L
.53038 .16187 L
s
.678 .847 .902 r
.53038 .16187 m
.53038 .18138 L
.5348 .18138 L
.5348 .16187 L
F
.2 .63 .79 r
.53038 .16187 m
.53038 .18138 L
.5348 .18138 L
.5348 .16187 L
s
.678 .847 .902 r
.5348 .16187 m
.5348 .18892 L
.54628 .18892 L
.54628 .16187 L
F
.2 .63 .79 r
.5348 .16187 m
.5348 .18892 L
.54628 .18892 L
.54628 .16187 L
s
.678 .847 .902 r
.54628 .16187 m
.54628 .19401 L
.55321 .19401 L
.55321 .16187 L
F
.2 .63 .79 r
.54628 .16187 m
.54628 .19401 L
.55321 .19401 L
.55321 .16187 L
s
.678 .847 .902 r
.55321 .16187 m
.55321 .20212 L
.56351 .20212 L
.56351 .16187 L
F
.2 .63 .79 r
.55321 .16187 m
.55321 .20212 L
.56351 .20212 L
.56351 .16187 L
s
.678 .847 .902 r
.56351 .16187 m
.56351 .20983 L
.57548 .20983 L
.57548 .16187 L
F
.2 .63 .79 r
.56351 .16187 m
.56351 .20983 L
.57548 .20983 L
.57548 .16187 L
s
.678 .847 .902 r
.57548 .16187 m
.57548 .21439 L
.58777 .21439 L
.58777 .16187 L
F
.2 .63 .79 r
.57548 .16187 m
.57548 .21439 L
.58777 .21439 L
.58777 .16187 L
s
.678 .847 .902 r
.58777 .16187 m
.58777 .22816 L
.59767 .22816 L
.59767 .16187 L
F
.2 .63 .79 r
.58777 .16187 m
.58777 .22816 L
.59767 .22816 L
.59767 .16187 L
s
.678 .847 .902 r
.59767 .16187 m
.59767 .2301 L
.60371 .2301 L
.60371 .16187 L
F
.2 .63 .79 r
.59767 .16187 m
.59767 .2301 L
.60371 .2301 L
.60371 .16187 L
s
.678 .847 .902 r
.60371 .16187 m
.60371 .23974 L
.61281 .23974 L
.61281 .16187 L
F
.2 .63 .79 r
.60371 .16187 m
.60371 .23974 L
.61281 .23974 L
.61281 .16187 L
s
.678 .847 .902 r
.61281 .16187 m
.61281 .24342 L
.62153 .24342 L
.62153 .16187 L
F
.2 .63 .79 r
.61281 .16187 m
.61281 .24342 L
.62153 .24342 L
.62153 .16187 L
s
.678 .847 .902 r
.62153 .16187 m
.62153 .24805 L
.63213 .24805 L
.63213 .16187 L
F
.2 .63 .79 r
.62153 .16187 m
.62153 .24805 L
.63213 .24805 L
.63213 .16187 L
s
.678 .847 .902 r
.63213 .16187 m
.63213 .25915 L
.64151 .25915 L
.64151 .16187 L
F
.2 .63 .79 r
.63213 .16187 m
.63213 .25915 L
.64151 .25915 L
.64151 .16187 L
s
.678 .847 .902 r
.64151 .16187 m
.64151 .26239 L
.6481 .26239 L
.6481 .16187 L
F
.2 .63 .79 r
.64151 .16187 m
.64151 .26239 L
.6481 .26239 L
.6481 .16187 L
s
.678 .847 .902 r
.6481 .16187 m
.6481 .27117 L
.65878 .27117 L
.65878 .16187 L
F
.2 .63 .79 r
.6481 .16187 m
.6481 .27117 L
.65878 .27117 L
.65878 .16187 L
s
.678 .847 .902 r
.65878 .16187 m
.65878 .28441 L
.66902 .28441 L
.66902 .16187 L
F
.2 .63 .79 r
.65878 .16187 m
.65878 .28441 L
.66902 .28441 L
.66902 .16187 L
s
.678 .847 .902 r
.66902 .16187 m
.66902 .28978 L
.67877 .28978 L
.67877 .16187 L
F
.2 .63 .79 r
.66902 .16187 m
.66902 .28978 L
.67877 .28978 L
.67877 .16187 L
s
.678 .847 .902 r
.67877 .16187 m
.67877 .29735 L
.68688 .29735 L
.68688 .16187 L
F
.2 .63 .79 r
.67877 .16187 m
.67877 .29735 L
.68688 .29735 L
.68688 .16187 L
s
.678 .847 .902 r
.68688 .16187 m
.68688 .3072 L
.69592 .3072 L
.69592 .16187 L
F
.2 .63 .79 r
.68688 .16187 m
.68688 .3072 L
.69592 .3072 L
.69592 .16187 L
s
.678 .847 .902 r
.69592 .16187 m
.69592 .31089 L
.70146 .31089 L
.70146 .16187 L
F
.2 .63 .79 r
.69592 .16187 m
.69592 .31089 L
.70146 .31089 L
.70146 .16187 L
s
.678 .847 .902 r
.70146 .16187 m
.70146 .31622 L
.70555 .31622 L
.70555 .16187 L
F
.2 .63 .79 r
.70146 .16187 m
.70146 .31622 L
.70555 .31622 L
.70555 .16187 L
s
.678 .847 .902 r
.70555 .16187 m
.70555 .31845 L
.70988 .31845 L
.70988 .16187 L
F
.2 .63 .79 r
.70555 .16187 m
.70555 .31845 L
.70988 .31845 L
.70988 .16187 L
s
.678 .847 .902 r
.70988 .16187 m
.70988 .32687 L
.72002 .32687 L
.72002 .16187 L
F
.2 .63 .79 r
.70988 .16187 m
.70988 .32687 L
.72002 .32687 L
.72002 .16187 L
s
.678 .847 .902 r
.72002 .16187 m
.72002 .33452 L
.73165 .33452 L
.73165 .16187 L
F
.2 .63 .79 r
.72002 .16187 m
.72002 .33452 L
.73165 .33452 L
.73165 .16187 L
s
.678 .847 .902 r
.73165 .16187 m
.73165 .34179 L
.73787 .34179 L
.73787 .16187 L
F
.2 .63 .79 r
.73165 .16187 m
.73165 .34179 L
.73787 .34179 L
.73787 .16187 L
s
.678 .847 .902 r
.73787 .16187 m
.73787 .35149 L
.75032 .35149 L
.75032 .16187 L
F
.2 .63 .79 r
.73787 .16187 m
.73787 .35149 L
.75032 .35149 L
.75032 .16187 L
s
.678 .847 .902 r
.75032 .16187 m
.75032 .35847 L
.76152 .35847 L
.76152 .16187 L
F
.2 .63 .79 r
.75032 .16187 m
.75032 .35847 L
.76152 .35847 L
.76152 .16187 L
s
.678 .847 .902 r
.76152 .16187 m
.76152 .36821 L
.76998 .36821 L
.76998 .16187 L
F
.2 .63 .79 r
.76152 .16187 m
.76152 .36821 L
.76998 .36821 L
.76998 .16187 L
s
.678 .847 .902 r
.76998 .16187 m
.76998 .38064 L
.77844 .38064 L
.77844 .16187 L
F
.2 .63 .79 r
.76998 .16187 m
.76998 .38064 L
.77844 .38064 L
.77844 .16187 L
s
.678 .847 .902 r
.77844 .16187 m
.77844 .38753 L
.78267 .38753 L
.78267 .16187 L
F
.2 .63 .79 r
.77844 .16187 m
.77844 .38753 L
.78267 .38753 L
.78267 .16187 L
s
.678 .847 .902 r
.78267 .16187 m
.78267 .39829 L
.79412 .39829 L
.79412 .16187 L
F
.2 .63 .79 r
.78267 .16187 m
.78267 .39829 L
.79412 .39829 L
.79412 .16187 L
s
.678 .847 .902 r
.79412 .16187 m
.79412 .40063 L
.80522 .40063 L
.80522 .16187 L
F
.2 .63 .79 r
.79412 .16187 m
.79412 .40063 L
.80522 .40063 L
.80522 .16187 L
s
.678 .847 .902 r
.80522 .16187 m
.80522 .41215 L
.8114 .41215 L
.8114 .16187 L
F
.2 .63 .79 r
.80522 .16187 m
.80522 .41215 L
.8114 .41215 L
.8114 .16187 L
s
.678 .847 .902 r
.8114 .16187 m
.8114 .42356 L
.81907 .42356 L
.81907 .16187 L
F
.2 .63 .79 r
.8114 .16187 m
.8114 .42356 L
.81907 .42356 L
.81907 .16187 L
s
.678 .847 .902 r
.81907 .16187 m
.81907 .42738 L
.82556 .42738 L
.82556 .16187 L
F
.2 .63 .79 r
.81907 .16187 m
.81907 .42738 L
.82556 .42738 L
.82556 .16187 L
s
.678 .847 .902 r
.82556 .16187 m
.82556 .43583 L
.82982 .43583 L
.82982 .16187 L
F
.2 .63 .79 r
.82556 .16187 m
.82556 .43583 L
.82982 .43583 L
.82982 .16187 L
s
.678 .847 .902 r
.82982 .16187 m
.82982 .4423 L
.83915 .4423 L
.83915 .16187 L
F
.2 .63 .79 r
.82982 .16187 m
.82982 .4423 L
.83915 .4423 L
.83915 .16187 L
s
.678 .847 .902 r
.83915 .16187 m
.83915 .45017 L
.844 .45017 L
.844 .16187 L
F
.2 .63 .79 r
.83915 .16187 m
.83915 .45017 L
.844 .45017 L
.844 .16187 L
s
.678 .847 .902 r
.844 .16187 m
.844 .45954 L
.85234 .45954 L
.85234 .16187 L
F
.2 .63 .79 r
.844 .16187 m
.844 .45954 L
.85234 .45954 L
.85234 .16187 L
s
.678 .847 .902 r
.85234 .16187 m
.85234 .4669 L
.8589 .4669 L
.8589 .16187 L
F
.2 .63 .79 r
.85234 .16187 m
.85234 .4669 L
.8589 .4669 L
.8589 .16187 L
s
.678 .847 .902 r
.8589 .16187 m
.8589 .46744 L
.87101 .46744 L
.87101 .16187 L
F
.2 .63 .79 r
.8589 .16187 m
.8589 .46744 L
.87101 .46744 L
.87101 .16187 L
s
.678 .847 .902 r
.87101 .16187 m
.87101 .48227 L
.8803 .48227 L
.8803 .16187 L
F
.2 .63 .79 r
.87101 .16187 m
.87101 .48227 L
.8803 .48227 L
.8803 .16187 L
s
.678 .847 .902 r
.8803 .16187 m
.8803 .49091 L
.89213 .49091 L
.89213 .16187 L
F
.2 .63 .79 r
.8803 .16187 m
.8803 .49091 L
.89213 .49091 L
.89213 .16187 L
s
.678 .847 .902 r
.89213 .16187 m
.89213 .50574 L
.89691 .50574 L
.89691 .16187 L
F
.2 .63 .79 r
.89213 .16187 m
.89213 .50574 L
.89691 .50574 L
.89691 .16187 L
s
.678 .847 .902 r
.89691 .16187 m
.89691 .50995 L
.90869 .50995 L
.90869 .16187 L
F
.2 .63 .79 r
.89691 .16187 m
.89691 .50995 L
.90869 .50995 L
.90869 .16187 L
s
.678 .847 .902 r
.90869 .16187 m
.90869 .52906 L
.91741 .52906 L
.91741 .16187 L
F
.2 .63 .79 r
.90869 .16187 m
.90869 .52906 L
.91741 .52906 L
.91741 .16187 L
s
.678 .847 .902 r
.91741 .16187 m
.91741 .53464 L
.92287 .53464 L
.92287 .16187 L
F
.2 .63 .79 r
.91741 .16187 m
.91741 .53464 L
.92287 .53464 L
.92287 .16187 L
s
.678 .847 .902 r
.92287 .16187 m
.92287 .54472 L
.92854 .54472 L
.92854 .16187 L
F
.2 .63 .79 r
.92287 .16187 m
.92287 .54472 L
.92854 .54472 L
.92854 .16187 L
s
.678 .847 .902 r
.92854 .16187 m
.92854 .55364 L
.93787 .55364 L
.93787 .16187 L
F
.2 .63 .79 r
.92854 .16187 m
.92854 .55364 L
.93787 .55364 L
.93787 .16187 L
s
.678 .847 .902 r
.93787 .16187 m
.93787 .55807 L
.94668 .55807 L
.94668 .16187 L
F
.2 .63 .79 r
.93787 .16187 m
.93787 .55807 L
.94668 .55807 L
.94668 .16187 L
s
.678 .847 .902 r
.94668 .16187 m
.94668 .56868 L
.95347 .56868 L
.95347 .16187 L
F
.2 .63 .79 r
.94668 .16187 m
.94668 .56868 L
.95347 .56868 L
.95347 .16187 L
s
.678 .847 .902 r
.95347 .16187 m
.95347 .5848 L
.96322 .5848 L
.96322 .16187 L
F
.2 .63 .79 r
.95347 .16187 m
.95347 .5848 L
.96322 .5848 L
.96322 .16187 L
s
.678 .847 .902 r
.96322 .16187 m
.96322 .5882 L
.96786 .5882 L
.96786 .16187 L
F
.2 .63 .79 r
.96322 .16187 m
.96322 .5882 L
.96786 .5882 L
.96786 .16187 L
s
.678 .847 .902 r
.96786 .16187 m
.96786 .59638 L
.97619 .59638 L
.97619 .16187 L
F
.2 .63 .79 r
.96786 .16187 m
.96786 .59638 L
.97619 .59638 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.0278 .01473 Mdot
.04039 .01489 Mdot
.05056 .01518 Mdot
.05326 .01528 Mdot
.0656 .01585 Mdot
.07952 .01673 Mdot
.08237 .01694 Mdot
.09347 .01786 Mdot
.09814 .0183 Mdot
.10391 .01888 Mdot
.10856 .01938 Mdot
.11384 .01997 Mdot
.12249 .02103 Mdot
.12688 .02161 Mdot
.13304 .02246 Mdot
.14078 .02359 Mdot
.14565 .02435 Mdot
.15019 .02508 Mdot
.16397 .02746 Mdot
.16656 .02794 Mdot
.17139 .02885 Mdot
.18032 .03061 Mdot
.19131 .03292 Mdot
.20118 .03513 Mdot
.21122 .03751 Mdot
.22112 .03998 Mdot
.22872 .04196 Mdot
.23514 .0437 Mdot
.24528 .04655 Mdot
.25829 .0504 Mdot
.26451 .05231 Mdot
.2735 .05517 Mdot
.28424 .05873 Mdot
.28722 .05974 Mdot
.29389 .06205 Mdot
.30074 .06448 Mdot
.30632 .06651 Mdot
.32246 .0726 Mdot
.32263 .07266 Mdot
.33636 .07811 Mdot
.34998 .08376 Mdot
.35727 .08687 Mdot
.35944 .08782 Mdot
.36719 .09123 Mdot
.37924 .09669 Mdot
.38734 .10047 Mdot
.397 .10509 Mdot
.40398 .10851 Mdot
.41535 .1142 Mdot
.42523 .11929 Mdot
.43322 .12349 Mdot
.43473 .12429 Mdot
.44493 .1298 Mdot
.45997 .13816 Mdot
.46463 .14082 Mdot
.47392 .14619 Mdot
.47939 .1494 Mdot
.49105 .15639 Mdot
.49501 .1588 Mdot
.50412 .16442 Mdot
.51435 .17087 Mdot
.52657 .17875 Mdot
.53058 .18138 Mdot
.54193 .18892 Mdot
.54944 .19401 Mdot
.5612 .20212 Mdot
.57214 .20983 Mdot
.57852 .21439 Mdot
.59732 .22816 Mdot
.59992 .2301 Mdot
.61267 .23974 Mdot
.61747 .24342 Mdot
.62345 .24805 Mdot
.63754 .25915 Mdot
.6416 .26239 Mdot
.65245 .27117 Mdot
.66848 .28441 Mdot
.67487 .28978 Mdot
.68376 .29735 Mdot
.69516 .3072 Mdot
.69939 .31089 Mdot
.70543 .31622 Mdot
.70795 .31845 Mdot
.71737 .32687 Mdot
.72582 .33452 Mdot
.73375 .34179 Mdot
.7442 .35149 Mdot
.75163 .35847 Mdot
.76187 .36821 Mdot
.77473 .38064 Mdot
.78177 .38753 Mdot
.79263 .39829 Mdot
.79498 .40063 Mdot
.80639 .41215 Mdot
.81755 .42356 Mdot
.82125 .42738 Mdot
.82937 .43583 Mdot
.83554 .4423 Mdot
.84298 .45017 Mdot
.85174 .45954 Mdot
.85856 .4669 Mdot
.85906 .46744 Mdot
.87263 .48227 Mdot
.88044 .49091 Mdot
.89367 .50574 Mdot
.8974 .50995 Mdot
.91409 .52906 Mdot
.9189 .53464 Mdot
.92754 .54472 Mdot
.93511 .55364 Mdot
.93885 .55807 Mdot
.94774 .56868 Mdot
.96109 .5848 Mdot
.96388 .5882 Mdot
.97056 .59638 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(115) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0262597) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.665622) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000030?[`iPD0
00000P3jl>H500000?l0n_3VW03jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP030000003j
l>H0n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000050?[`iP800000o`3j
l>JO0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3j
l>H2000000030?[`iP000000000000<0n_3V0P0000050?[`iP800000o`3jl>JN0?[`iP40oooo000P
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H200000003
0?[`iP000000000000@0n_3V0P0000050?[`iP800000o`3jl>JM0?[`iP40oooo000P0?[`iP800000
0P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP00
0000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V10000003
0?[`iP030000003jl>H0n_3V008000000P3jl>H4000000H0n_3V0P0000050?[`iP800000o`3jl>JL
0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H40000
00030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H20000
00D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`
iP8000001@3jl>H2000000D0n_3V100000030?[`iP8000001@3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000003o0?[`iY`0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0
n_3V0P0000050?[`iP800000103jl>H2000000H0n_3V0P0000040?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000?l0n_3VW03jl>H10?ooo`007`3jl>H6000000@0n_3V
0P00000_0?[`iPD00000:03jl>H3000000`0n_3V0`0000040?[`iP<000000P3jl>H5000000@0n_3V
0`0000030?[`iP<00000103jl>H300000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0
n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00
000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H00000
0000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<0
0000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H10?ooo`00
8P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V
0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H20000
0080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP80
0000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000000000T0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
0000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP800000
1@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H000000000
00020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V
0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000
000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V
0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V1000
00030?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103j
l>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P00
00050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;
0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2
000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00003o
0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00000<0?[`
iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00003o0?[`
iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V0000
00000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`
iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0
000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H00000
01P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H30000
0080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V10000000
0`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H00000
0?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000<0n_3V1@0000030?[`iP<00000
0`3jl>H5000000<0n_3V0`0000030?[`iP<000001P3jl>H200000780n_3V0@3oool00240n_3V0P00
00000`3jl>H0000000000005000000040?[`iP000000000000000080n_3V0P0000000`3jl>H00000
000000090?[`iPD000002@3jl>H200000=l0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V
0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP04
0000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000
000000002P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H20000
00@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000
000000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000001@3jl>H20000
00030?[`iP00000000000080n_3V0P0000050?[`iP030000003jl>H0n_3V00800000103jl>H20000
00D0n_3V0P00001b0?[`iP40oooo000R0?[`iP<00000:@3jl>H200000=h0n_3V0P0000040?[`iP80
00000P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H200000005
0?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3j
l>H000000?[`iP02000001P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000
000000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000030?[`iP8000001`3jl>H20000
00D0n_3V0P0000040?[`iP800000LP3jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP80
0000g@3jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0
n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`
iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP0000000000
00T0n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000030?[`iP0000000000
00@0n_3V0P0000060?[`iP8000000`3jl>H4000000@0n_3V0P00001b0?[`iP40oooo000Q0?[`iP80
000000<0n_3V000000000000:P3jl>H200000=`0n_3V0P0000000`3jl>H00000000000050?[`iP80
00000P3jl>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H30000
00040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP02
000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P000000
0`3jl>H00000000000050?[`iP8000000P3jl>H4000000H0n_3V0P0000020?[`iP030000003jl>H0
n_3V008000000P3jl>H2000000030?[`iP000000000000D0n_3V0P00001a0?[`iP40oooo000P0?[`
iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3j
l>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0
n_3V0000000000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P00
00000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000050?[`iP80000000<0n_3V0000000000000P3jl>H4000000<0n_3V0P00
00000`3jl>H00000000000050?[`iP800000L@3jl>H10?ooo`00C@3jl>H2000000030?[`iP000000
00000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P000002
0?[`iP800000;P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3jl>H0000000000002
0?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P00001a
0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H20000
00H0n_3V0P00000I0?[`iP<0000000<0n_3V0000000000000P00000^0?[`iP<000002`3jl>H30000
00@0n_3V0`0000050?[`iP<000000`3jl>H3000000<0n_3V1@0000030?[`iP<000000`3jl>H50000
0740n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko
0?[`iR<0n_3V0@3oool002L0n_3V00D000000?[`iP000000n_3V000000020?[`iP040000003jl>H0
n_3V00000080n_3V00<000000?[`iP3jl>H0o`3jl>Ko0?[`iR80n_3V0@3oool00200n_3V0`000000
0`3jl>H0000000000002000000040?[`iP000000n_3V00000080n_3V00@000000?[`iP3jl>H00000
0P3jl>H00`000000n_3V0?[`iP0G0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`iP<00000
0P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`0000000`3jl>H00000
00000006000001X0n_3V1P0000000`3jl>H000000000000400000080n_3V0`00002j0?[`iP40oooo
000Q0?[`iP80000000<0n_3V0000000000001@0000001@3jl>H00000000000000000n_3V00@00000
2`3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V
0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP80
00000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00040?[`iP00000000000?[`iP8000000P3jl>H2000000/0n_3V1@00000;0?[`iP8000001@3jl>H2
000000<0n_3V00<000000?[`iP3jl>H00P00002i0?[`iP40oooo000R0?[`iP<00000:03jl>H20000
00030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000000`3jl>H4000001/0n_3V0P0000050?[`iP8000001P3jl>H20000
0;T0n_3V0@3oool00280n_3V0`0000090?[`iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80
000000<0n_3V000000000000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0
n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H200000004
0?[`iP00000000000?[`iP@000003@3jl>H5000000/0n_3V0P0000050?[`iP8000001P3jl>H20000
0;T0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0n_3V00000000
0000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003j
l>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000K0?[`iP8000001@3jl>H2
000000<0n_3V00<000000?[`iP3jl>H00P00002i0?[`iP40oooo000P0?[`iP<0000000@0n_3V0000
0000000000009P3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H0000000000002
0?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@00
00020?[`iP@00000103jl>H400000080n_3V1@0000030?[`iPD000006`3jl>H2000000D0n_3V0P00
00030?[`iP@00000^P3jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H000000000000@0?[`iP800000303jl>H2000003P0n_3V100000030?[`iP@000000`3jl>H2
00000;`0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`
iP8000001P3jl>H200000380n_3V0P0000050?[`iP8000000`3jl>H500000;T0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iRH0oooP0P00001/
0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000J@3oon0500000080oooP0P000004
0?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP
000006X0oooP00@000000?ooh03oon000000203oon0010000000oooP0?ooh000001/0?ooh0030000
003oon00oooP06/0oooP00<000000?ooh03oon001`3oon0010000000oooP0?ooh000001Z0?ooh003
0000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0
oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?ooh01Z0?ooh0030000003oon00oooP
06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?ooh01Y0?ooh0030000003oon00oooP
02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?oo
h03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh008
0?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V0@3oool001d0n_3V9@3oon001000
0000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03oon00K03o
on000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00JP3o
on0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0n_3V9P3oon02000006`0oooP0P00
000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000002@0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`00
0000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP00X0oooP0P0000040?ooh08000000`3o
on0400000?l0oooPc@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon00
0`000000oooP0?ooh0060?ooh0030000003oon00oooP00T0oooP100000020?ooh0@0000000<0oooP
000000000000100000030?ooh0800000103oon0400000?l0oooP_`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000203oon0J0000
o`D000000P3oon02000000030?ooh000000000000080000000<0oooP000000000000o`3oon2_0?oo
h0@00000603oon0N0?[`iP40oooo000M0?[`iPX0oooP100000040?ooh0030000003oon00oooP00H0
oooP00<000000?ooh03oon002@3oon001@3=QCl000000000003oi>40cHDo0080onCQ0P0000000`3=
QCl0onCQ0?oTh@04000000<0onCQ100000020?oTh@03000000000?l0003o00H0003o2`0000020?oo
h080000000<0oooP000000000000o`3oon2Y0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon001@3=QCl0
onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`000000000000<0onCQ00<0cHDo0000000000000P0000020?oTh@8000002P000?l;0000
00030?ooh000000000000?l0oooPX`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo
00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>40103=QCl000000000003oi>44000000040?oTh@000000
0000000000T0003o2P00003o0?ooh9h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40onCQ0?oTh@3=QCl0
onCQ0P0000001@3oi>40cHDo000000000000cHDo00<0000020000?l3000000@0oooP0P00003o0?oo
h9L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3o
i>40onCQ0<f5?`80onCQ00@0cHDo000000000000onCQ1@0000050000o`030<f5?`000000000000@0
0000o`3oon2D0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0
onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0000000000000P00
00030?oTh@D0003o0`000000103=QCl0oooP00000000003o0?ooh8l0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oT
h@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5
?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo
0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>400000008000001@00
0?l300000080oooP0P00003o0?ooh8X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0
onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@030<f5?`3oi>40onCQ00@0000000<0onCQ0<f5?`0000001@000?l3
000000040<f5?`3oon00000000000?l0oooPQ@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103o
i>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3o
i>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ
0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oT
h@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@070<f5
?`3oi>4000000000003=QCl0onCQ000000050000o`<000000P3oon0200000?l0oooPP03oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh005
0<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo
0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo
0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>42000000030?oTh@3=
QCl0000000@0003o100000000`3oon0000000000003o0?ooh7`0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3o
i>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3o
i>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oT
h@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo
0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00@0cHDo0?oTh@00000000000P3=QCl50000
o`<0000000<0oooP000000000000o`3oon1h0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40
cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>42000000030<f5
?`000000003o00<0003o1@00003o0?ooh7D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=
QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40
103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@060<f5?`3oi>40
00000000003oi>40000010000?l200000?l0oooPM03oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon03000000T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5
?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oT
h@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo
0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`0000000000008000000`000?l00`3oon0000000000003o0?ooh6h0oooP0`00000H
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo
0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0
onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=
QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0
onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0<f5?`3oi>42000000030?oTh@3=QCl0003o
00<0003o00@0cHDo0?ooh03oon00oooP0P00003o0?ooh6T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40
cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40
onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=
QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0000000000002000000<0
003o1P00003o0?ooh6H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=
QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ000000000000onCQ00<0cHDo10000?l300000?l0oooP
I@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5
?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oT
h@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0
cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`04
0?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40onCQ0`0000030000o`030?ooh000
000000000?l0oooPHP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oT
h@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5
?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080
onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=
QCl0onCQ000000000000cHDo00<0003o00<000000?ooh03oon00o`3oon1O0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oT
h@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>40
1`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@03
0<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0
onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`0000020000
o`030?ooh0000000000000800000o`3oon1K0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40
cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@020?oTh@060<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0P0000020<f5?`<0003o1@00003o0?oo
h5P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3o
i>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@06
0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0
103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`030?oTh@030<f5?`3oi>400000008000000`000?l500000?l0oooPE@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5
?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080
onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40
cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ
00<0cHDo0?oTh@3oi>401@0000020000o`H00000o`3oon1B0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ
0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ
0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40
cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>40
0`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo0080onCQ00<0cHDo0000000000000`000?l400000?l0oooPD@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3o
i>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ
00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40
0`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40
onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@8000000`000?l00`000000
cHDo0?ooh03o0?ooh4l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=
QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo0080onCQ0P0000030000o`<0oooP0P00003o0?ooh4X0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0
onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oT
h@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ
00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5
?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0cHDo
0?oTh@3oi>40cHDo0?ooh0020000o`@00000o`3oon190?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<000002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0
onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ
0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40103=QCl30000o`030000
003=QCl0cHDo0?l0oooPA@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ
00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=
QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103o
i>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ0P0000030000o`80oooP0P00003o0?oo
h4<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3o
i>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@06
0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0
103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080003o
0`0000000`3=QCl0oooP0?ooh03o0?ooh3l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=
QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40
103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40
onCQ0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401`3=
QCl0onCQ0?oTh@3oi>40cHDo0?oTh@0000000`000?l00`3=QCl0oooP0?ooh03o0?ooh3l0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
1@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oT
h@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5
?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40
onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ0P000000103o
i>40003o0000o`000?l200000?l0oooP?@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5
?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@04
0<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl01@3oi>420<f5?`05000000000?l0003o0000003=QCl00P00003o0?oo
h3T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3o
i>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@06
0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0
103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ
00<0cHDo0?oTh@0000000P0000020000o`<00000o`3oon0h0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ
0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ
0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40
cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>40
0`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5
?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@030<f5?`3oi>40onCQ0080000000@0onCQ
000000000?l0003o0P0000000`3oon0000000000003o0?ooh3@0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3o
i>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3o
i>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oT
h@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo
0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40
cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl00000000000020000o`@00000o`3oon0c0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40
cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@000000
00000<f5?`030000o`030000003=QCl0cHDo0?l0oooP<@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=
QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3o
i>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5
?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl4
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>400`3=QCl0onCQ0?oTh@030?oTh@060<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0P0000020000o`040<f5?`3oon00000000000?l0oooP;P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh005
0<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo
0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo
0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>400`3=QCl0onCQ
0?oTh@030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl01@3oi>420000o`<00000o`3oon0]0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=
QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=
QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ
0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oT
h@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@030<f5?`3o
i>40onCQ00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`050?oTh@040<f5?`000000003o0000o`<0
0000o`3oon0[0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0
onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`05
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`050?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`050?oTh@040<f5
?`3oi>400000000000<0003o00<000000<f5?`3oon00o`3oon0X0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40
onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0
onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3o
i>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5
?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103o
i>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3o
i>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0
cHDo0?oTh@3=QCl0onCQ0<f5?`050?oTh@040<f5?`3oi>40onCQ0?oTh@<000000P000?l00`3oon00
00000000003o0?ooh2H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`0000090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@03
0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo
0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ
00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5
?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3o
i>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl01@3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080000000@0onCQ0<f5?`000?l0003o0P00003o0?ooh2<0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oT
h@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oT
h@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ
0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl2
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ
00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5
?`3oi>40cHDo0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0000
000000000P000?l00`3oon0000000000003o0?ooh280oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo
00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ
0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5
?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ
0<f5?`3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>400000
0000003=QCl00P000?l200000?l0oooP8@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5
?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@04
0<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl01@3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40cHDo0?oT
h@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`0200000080003oo`3oon0Q0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=
QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oT
h@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`050?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`05
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401P3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@80
000000<0oooP0000o`000?l00P00003o0?ooh1d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0
onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oT
h@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3o
i>40103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0<f5
?`3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>430<f5?`04000000000?l0003o00000?l0oooP703oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo
0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0
onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=
QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>400`3=QCl0onCQ0?oTh@030?oTh@05
0<f5?`3oi>40cHDo0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<000000P000?l00`3oon0000000000
003o0?ooh1P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3o
i>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103o
i>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@04
0<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl4
0?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oT
h@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo00D0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ
0?oTh@3oi>42000000040<f5?`3oon00003o0000o`800000o`3oon0G0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3o
i>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=
QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5
?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ
0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40
onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@030<f5?`3oi>40onCQ00<0onCQ
00D0cHDo0?oTh@3=QCl0onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>420<f5?`8000000P000?l0
103oon00000000000000003o0?ooh1<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0
onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ
0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0<f5?`3oi>40
cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ0080000000<0oooP0000o`000?l0
0`00003o0?ooh180oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0
103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oT
h@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo00D0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo0P0000020000o`040000003=QCl0cHDo
0<f5?ol0oooP3`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`04
0?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ
00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5
?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0
onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01@3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl01@3oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3o
i>40onCQ00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@<0000000<0003o0?oTh@3oi>40
0P00003o0?ooh0h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0
103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oT
h@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo00D0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0?oTh@030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>42
0000o`<00000o`3oon0=0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40
onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0
0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3o
i>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`050?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`050?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40
0P3oi>4010000000003o0000o`00003o0?ooh0d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP0`0000090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0
onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40
cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3o
i>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3o
i>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl01@3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl0
1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oT
h@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
onCQ00<0onCQ0P0000000`000?l0oooP0?ooh03o0?ooh0T0oooP0`00000H0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5
?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@04
0<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl01@3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40cHDo0?oT
h@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl00P000?l20?ooh0800000o`3oon070?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0
cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl2
0?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0onCQ0?oT
h@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo
0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@04
0<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@030<f5?`3oi>40
onCQ00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`020?oo
h080003o0`00003o0?ooh0H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oT
h@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oT
h@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5
?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ
0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ
00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo00D0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40cHDo00<0cHDo00<000000000o`000?l00P00003o0?ooh0D0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
1@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oT
h@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5
?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40
onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00<0cHDo0?oT
h@3oi>400`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0
onCQ0P0000000`000?l00000000000020<f5?ol0oooP0P3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=
QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3o
i>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5
?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl4
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3o
i>40cHDo0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`02
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0000000000002
0000o`040?oTh@3=QCl0000000000?l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0
onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ
0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0<f5?`3oi>40
cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@00000000000?oTh@020000
o`<00000oP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oT
h@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0
cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0
onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
1@3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl01@3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
onCQ00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@030?oTh@03000000000?l0003o00800000o@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3o
i>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo
0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`040?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01@3oi>400`3=
QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl01@3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=
QCl0103oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`00000000000000o`8000000P3=QCoj0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oT
h@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oT
h@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401P3=QCl0
onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00@0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`02
0?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oTh@030<f5
?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5
?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@00000000000P000?l00`3oi>40cHDo
0?ooh03i0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ
00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40103=
QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103o
i>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`050?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`05
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`050?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3o
i>400`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl00P000000103o
i>40003o0000o`3oon0200000?L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo
0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ
0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo
00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0<f5?`040?oTh@030<f5?`000?l0000000<00000m@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0?oT
h@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0<f5?`020?oTh@070<f5
?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo
0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40
cHDo0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`04
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40onCQ0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3o
i>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>40
1@3=QCl0onCQ0<f5?`3oi>40cHDo00D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@040<f5?`000000003o0000o`<00000m03oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh0000007
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40cHDo00@0onCQ00<0cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=
QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oT
h@3oi>40cHDo103oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`050?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`050?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`05
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3o
i>400`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=
QCl0103oi>40103=QCl0onCQ0000000000020000o`030000003=QCl0cHDo0?80oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon040000
00P0oooPi`0000020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh004
0000003oon00oooP000000L0oooP00<000000?ooh03oon00l@3oon0010000000003o000000000002
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP04
03>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX4
0:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00
oooP0?40oooP0P0000020000o`<0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP04
03>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000
oooP0?ooh03b0?ooh080000000<0oooP0000o`3oon000P0000020:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV
0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]
f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00mP3oon020000o`80000000<0[MSV03>QbP2]f>H00`2]f>H00`0cXLX0[MSV03>Q
bP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03f0?oo
h080000000@0003o0000000cXLX0<j7:102]f>H00`0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03g0?ooh08000000P000?l00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP03
03>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?/0oooP00P0003o0:gHiP00000000000:gHiP0cXLX0[MSV03>Q
bP@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV
0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?/0oooP
00<0<j7:0000o`0000000`0000000`2]f>H0<j7:0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0803>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03k0?ooh00403>QbP000000003o0000o`<0000000<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o@3oon02000000040000o`000000000003>QbP@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP04
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP00@000000000o`000?l0<j7:102]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon030?ooh0030000
o`2]f>H0[MSV0080000000D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP0`3oon000`0cXLX0003o0000o`03000000<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0D0oooP00<000000000o`0000000`0000000`2]f>H0<j7:
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon060?ooh003000000000?l0003o00<0000000<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP08
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP203oon001@000000003o000000000000<j7:00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV
03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0
<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0
100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gH
iP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP03
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon090?ooh004000000000?l0003o03>QbP@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0
[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP05
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0<0?ooh0030000o`2]f>H0[MSV0080000000<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0<0?ooh00303>QbP000?l0003o00<000001@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0<0?ooh080<j7:00@0
00000000o`00000000001@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV
03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0
<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0
100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gH
iP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP03
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0?0?ooh003000000000?l0003o00D0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]
f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4@3o
on00100cXLX0003o0:gHiP2]f>H20000000303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0803>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh140oooP00@0<j7:0:gHiP000?l0003o0`000005
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0A0?ooh0<0<j7:
00<000000000o`0000000`0000030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0E0?ooh003000000000?l0003o00<000000P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP03
03>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP5`3oon0010000000003o00000000000303>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX5
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP603oon000`000000003o0000o`020?ooh00503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]
f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0
[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV
03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0K0?ooh0030000o`3oon00<j7:00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon0L0?ooh080003o0`2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1d0oooP00D0<j7:0000o`2]f>H0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh1d0oooP00@0<j7:0:gHiP000?l0[MSV0P0000000`2]f>H0
<j7:0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0M0?ooh00303>QbP2]f>H0[MSV0080003o0P0000000`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0
[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0M
0?ooh0<0<j7:0P0000000`000?l00000000000040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]
f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0
[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV
03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Q0?ooh080000000<0003o0000002]f>H00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV
0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
8P3oon0200000080003o0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP903oon000`0cXLX0[MSV0000o`020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0T0?ooh00403>QbP2]f>H0[MSV
0000o`8000000`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX4
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh2@0oooP0`0cXLX010000000003o0000o`0000020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP03
03>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP9`3oon03000000040000o`000000000003>QbP@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV
0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gH
iP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:
0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0c
XLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:03oon03000000030000o`000000000000@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV
0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gH
iP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:
0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0c
XLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:P3oon0200000080003o0P0000020:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh2/0oooP0`0000000`000?l000000000000203>QbP@0[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>Q
bPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP
;@3oon02000000040000o`000000oooP03>QbP@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;P3oon0200000080003o00<0<j7:0:gHiP2]
f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP<P3oon000`000?l0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0b0?ooh006
03>QbP000?l000000000002]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<P3oon000`0cXLX000000000o`020000
000403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0b0?ooh00303>QbP00000000000080003o00@000000:gHiP2]f>H0<j7:102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP04
03>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX4
0:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3@0oooP0`0000001000
0?l0000003>QbP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP=@3oon03000000030000o`3oon00<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>Q
bPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100c
XLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>Q
bP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP03
03>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0f0?ooh080000000<0oooP0000o`000?l0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV
0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3X0oooP00H0<j7:0000o`000000
00000:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3X0oooP00<0<j7:00000000
0?l00P0000000`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV
0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3X0oooP
00H0<j7:000000000000003o0000000cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3`0
oooP0P0000020000o`@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?`3oon000`0cXLX0003o
0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP08
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3l0oooP00<0<j7:0:gHiP000?l00P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0
[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV
00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh3l0oooP00H0<j7:0:gHiP2]f>H0003o0:gHiP0cXLX40:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00L0oooP
0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3l0oooP00H0
<j7:0:gHiP2]f>H0[MSV0000o`0000040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>Q
bP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
0`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0
[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0o0?ooh0<0<j7:0P0000000`000?l00000
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV
0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]
f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon120?ooh0<000000P000?l20000000503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon130?ooh080000000<0[MSV
000000000?l00P0000030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV03>Q
bP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPA03oon0203>QbP80000000<0003o0000002]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP04
03>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX4
0:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4L0oooP0P0000001@00
0?l0[MSV0:gHiP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP04
03>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPB@3oon001@0cXLX0003o000000000000<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPB@3oon000`0cXLX000000000o`02000000<0[MSV00P0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>Q
bP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0c
XLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPBP3oon02000000030000o`000000[MSV0080[MSV00P0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP04
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB`3oon02000000050000o`2]f>H0[MSV0:gH
iP0cXLX00P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0
[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPC@3oon001@0cXLX0003o0:gHiP2]
f>H0<j7:0080[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV
0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00o`3oon1=0?ooh00503>Q
bP2]f>H0003o0000o`0000000P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV
03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?oo
h03oon00o`3oon1=0?ooh080<j7:0P00000020000?l00000000000000000[MSV03>QbP2]f>H0<j7:
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon00
1P3oon0400000?l0oooPCP3oon03000000070000o`00000000000000000cXLX0[MSV03>QbP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon001P3oon04
000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?oo
h03oon00o`3oon1@0?ooh0<0000000H0003o000000000000<j7:0:gHiP0cXLX40:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003o
on00oooP0?l0oooPD`3oon001P000000003o000000000000[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP04
03>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh5@0
oooP00<000000000o`0000000P0000040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0
0`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gH
iP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]
f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh5@0oooP0P00000010000?l000000000000000030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h5D0oooP0P0000000`000?l00000000000030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5L0oooP00<000000000o`2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1H0?oo
h00303>QbP000?l0003o0080000000<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX5
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPF03oon00100cXLX0[MSV000000000?l2000000D0[MSV00@0<j7:
0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5P0oooP0P0cXLX2000000030000o`000000
[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5/0oooP0P000000
0`000?l0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1M
0?ooh00403>QbP000?l0000000000080[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh5d0oooP00<0<j7:000000000?l00P00000203>QbP80[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV
03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]
f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh5h0oooP0P00000010000?l000000?ooh00cXLX20:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV
00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh5l0oooP0P0000001P000?l0oooP000000000000[MSV03>QbPD0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV
0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]
f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>Q
bP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh680oooP00D0003o000000000000000003>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]
f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPHP3o
on001@000000003o0000o`000000<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1S0?ooh080000000<0
003o03>QbP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6H0oooP00<0003o0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>Q
bP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0
[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh6H0oooP00@0<j7:0000o`00000000000P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h6H0oooP00<0<j7:000000000?l00P0000000`2]f>H0<j7:0:gHiP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6H0oooP00D0<j7:00000000
0000003o0000000203>QbP@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPJ03oon02000000030000o`3oon00<j7:00@0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ`3oon000`000?l00000
000000030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP040:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh6/0oooP00@000000000o`00000000000`0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1[0?ooh080000000D0003o0000003oon00oooP03>Q
bP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1/0?oo
h080000000@0003o0?ooh03oon00<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPK`3oon0010000?l0oooP0000000000020:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
0`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0
[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1`0?ooh0060000o`00000000000000002]
f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV
0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPL03oon0010000000003o0000o`00000203>QbP@0
[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV
03>QbP030:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh740oooP0P0000000`000?l0oooP03>QbP040:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPM03oon000`000?l0<j7:0:gHiP030:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPM@3oon000`000?l0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPM@3oon00200cXLX0003o000000000000[MSV03>QbP2]f>H0<j7:102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1e0?ooh00303>QbP000000003o0080000000<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1e0?oo
h00803>QbP00000000000000o`000000<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7L0oooP0P000000
10000?l0<j7:0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7X0oooP00<0003o000000000000102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1j0?ooh004000000000?l00000000000<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV
00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPNP3oon02000000030000o`00
0000[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPN`3oon02000000050000o`2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP04
03>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO03oon000`0cXLX0
[MSV0000o`020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>Q
bP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh7`0oooP00@0<j7:0:gHiP2]f>H0003o0P0000050:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh7`0oooP00D0<j7:0:gHiP2]f>H000000000
o`02000000@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon001`3oon03
000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO03oon0303>Q
bP80000000<0003o0000000000000`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPP03oon02000000030000o`000000<j7:00<0<j7:0P2]f>H0100cXLX0[MSV
0:gHiP0cXLX30:gHiP0303>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100c
XLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>Q
bP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP03
03>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon210?ooh080000000D0003o0?ooh03oon00oooP03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8@0oooP00@0003o0?ooh03oon00<j7:0P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
0`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0
[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon250?ooh0030000o`3oon00<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQP3oon001@000?l000000000002]f>H0<j7:
0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV
03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon260?ooh005000000000?l000000000000cXLX0
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8H0oooP0P0000000`000?l0000003>QbP020:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPQ`3oon02000000050000o`0cXLX0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPRP3oon0010000?l0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2:0?ooh004
03>QbP000?l00000000000<0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8X0oooP00<0<j7:000000000?l00P0000020:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2:0?ooh00403>QbP00000000000000o`80000000@0[MSV03>QbP2]f>H0<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPS03oon02000000060000o`00
0000000003>QbP2]f>H0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?oo
h03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPS@3oon02000000050000o`000000<j7:0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8h0oooP0P00000010000?l0<j7:0:gHiP0cXLX3
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0
[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT@3oon00
0`000?l00000000000030:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPT@3oon0010000000003o0000000000020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPT@3oon0010000000003o0000000000020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPTP3oon000`000000003o
0:gHiP020000000403>QbP2]f>H0[MSV03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
T`3oon000`0cXLX0003o0000000200000080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh9<0oooP00<0<j7:000000000?l00P0000020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2E0?ooh003000000000?l0
<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h9L0oooP00@0003o0:gHiP00000000000`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2G0?oo
h00303>QbP000?l00000008000000P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2G0?ooh003
03>QbP000000003o008000000P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP100000070?ooh0030000003oon00oooP0?l0oooP
V@3oon000`000000003o0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh0080?ooh0030000003o
on00oooP0?l0oooPVP3oon001@0cXLX0003o0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0030000003oon00
oooP00L0oooP1000003o0?ooh9T0oooP00<0<j7:0000o`2]f>H00P0000020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?oo
h03oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0
oooP00<000000?ooh03oon00o`3oon2J0?ooh080<j7:00H0003o00000000000000000:gHiP0cXLX5
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03o
on0000001`3oon000`000000oooP0?ooh03o0?ooh9`0oooP00H000000000o`00000000000:gHiP0c
XLX50:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?oo
h0030000003oon00oooP0?l0oooPW@3oon000`000000003o0:gHiP02000000D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV
0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9h0oooP
00<0<j7:0000o`0000000P0000040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2N0?ooh00303>QbP000000003o008000001@0cXLX3
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
W`3oon02000000030000o`000000oooP00<0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:00oooP0P0000000`000?l0oooP0?ooh002
0?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV03>QbP050:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2S0?ooh0050000o`3oon00oooP0?ooh00cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:@0oooP00@0003o0?ooh03oon00<j7:
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:D0oooP00<0003o0?ooh00cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh:H0oooP00<0003o0000000000000P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:H0oooP00@000000000o`00
000000000P0cXLX50:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:H0oooP0P00
000010000?l000000?ooh00cXLX50:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPY`3oon020000
00030000o`3oon00<j7:00D0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]
f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000
603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Z0?ooh0030000o`00
0000000000@0[MSV00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZP3oon0010000?l0
00000000000000030:gHiP0303>QbP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP00@0
00000000o`0000000000100cXLX00`2]f>H0<j7:0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2[0?oo
h003000000000?l0oooP00<0oooP00<0<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]
f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[@3o
on001`000?l0oooP0?ooh03oon00<j7:0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0
[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[P3oon00
1P000?l0oooP0?ooh00cXLX0[MSV03>QbPD0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP04
03>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX4
0:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:l0oooP00D0003o0?oo
h00cXLX0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0
[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2`0?ooh0040000o`000000000003>QbPD0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;00oooP00@000000000o`00000000001@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP04
03>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP/03oon02000000030000o`000000000000@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP0P000000
0`000?l00000000000030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0
[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2b0?ooh080000000<0003o0000000cXLX0
0`0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP/`3oon02000000050000o`3oon00oooP0?ooh00cXLX00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP]P3oon0010000?l0oooP0?ooh00cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0
[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0070?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh0030000o`3oon00
<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2g0?ooh0030000o`3oon00<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP03
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2h0?ooh0030000o`0cXLX0[MSV0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:
102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh0050000o`2]
f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2i0?ooh00503>QbP000?l0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh00503>QbP2]f>H0003o0000000cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh00503>Q
bP00000000000000o`0000000P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2j0?ooh080000000D0003o000000000000000003>QbP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;/0oooP0P00000010000?l000000000000000020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh;d0oooP00@000000000o`00000000000P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n0?ooh003000000000?l0<j7:0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP`03oon0010000?l0[MSV0:gHiP0cXLX30:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon300?ooh00403>QbP000?l00000000000<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh<00oooP00<0<j7:0000o`0000000P0000020:gHiP0303>QbP2]f>H0[MSV0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh<00
oooP00<0<j7:000000000?l00P0000020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<80oooP00<000000000o`2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP``3oon001@0cXLX0003o0:gHiP2]f>H0<j7:
00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon330?ooh00503>QbP2]f>H0003o0000000cXLX0102]f>H0100cXLX0[MSV0:gHiP0c
XLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<<0oooP00D0<j7:
000000000000003o000000040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPa03oon02000000030000o`000000000000<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on350?ooh080000000<0003o0000000000000`0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPaP3oon02000000050000o`000000
oooP0?ooh00cXLX00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh<L0oooP0P00000010000?l0oooP0?ooh00cXLX20:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPbP3oon00
0`000?l0oooP03>QbP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPb`3oon001@000?l000000000002]f>H0<j7:00@0[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb`3oon001@000?l00000000000000000
<j7:00@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb`3oon001@00
0000003o000000000000<j7:00@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPc03oon0010000000003o0?ooh00cXLX40:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon030000
0?l0oooPcP3oon000`000?l0<j7:0:gHiP030:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?oo
h03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPc`3oon000`000?l0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<l0oooP00<0<j7:0000o`2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon3?0?ooh00303>QbP2]f>H0003o0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPc`3oon000`0cXLX0[MSV0000o`020000000303>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<l0oooP0P0cXLX01P000000003o000000000000
[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=40oooP0P00000010000?l000000:gHiP0c
XLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3B0?ooh080000000<0003o0000000cXLX00`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPdP3oon03000000030000o`0cXLX0[MSV0080[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh=<0oooP0P0000000`3oon00003o0:gHiP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon3F0?ooh00503>QbP000?l000000:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=H0oooP00D000000000o`000000
000003>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000
203oon000`000000oooP0?ooh03o0?ooh=H0oooP0P0000000`000?l000000?ooh00;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP
00<000000?ooh03oon00o`3oon3G0?ooh080000000<0003o0?ooh03oon002P3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3o
on3I0?ooh0030000o`3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4`3oon00
0`000000oooP0?ooh0050?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00
oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon020000
00P0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP0740oooP
00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP
00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooPo`00003Z000001P0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003L0?[`iP@000000P3jl>H800000080n_3V100000001`3jl>H00000000000000000
n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`iP0000000000000000P0n_3V
1@0000040?[`iPL0000000<0n_3V0000003jl>H00`0000090?[`iPD000000P3jl>H400000080n_3V
1@00000B0?[`iPH000001P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V000000000000
0000i03jl>H10?ooo`00g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H2000000<0n_3V
00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H010000000n_3V0?[`iP3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003j
l>H0n_3V00D0n_3V0P0000000`3jl>H000000000003U0?[`iP40oooo003M0?[`iP80000000<0n_3V
000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H010000002
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP800000303jl>H5000000D0n_3V0P00
00060?[`iPD000001P3jl>H300000>H0n_3V0@3oool00=d0n_3V1@0000040?[`iP8000000`3jl>H6
000000060?[`iP00000000000?[`iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V
0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00H0
n_3V0`00003V0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H04P3jl>H2000000P0n_3V00<00000
0?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`
iP@000000P3jl>H500000080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP0000000000
00L000002`3jl>H500000080n_3V100000020?[`iP<0000000<0n_3V0000000000004`3jl>H20000
00l0n_3V0`0000001@3jl>H00000000000000000n_3V00@00000g`3jl>H10?ooo`00g@3jl>H20000
0080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0H0?[`iP8000008@3jl>H40000
01P0n_3V00<000000?[`iP3jl>H0g`3jl>H10?ooo`00g03jl>H6000000@0n_3V0P00000_0?[`iPD0
00006`3jl>H300000240n_3V0P00000I0?[`iP030000003jl>H0n_3V0=h0n_3V0@3oool00?l0n_3V
N03jl>H00`000000n_3V0?[`iP3M0?[`iP40oooo003o0?[`iWD0n_3V00@000000?[`iP3jl>H00000
g`3jl>H10?ooo`00o`3jl>If0?[`iP800000h03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02886 .01472 L
.02886 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02886 .01472 L
.02886 .16187 L
s
1 .894 .882 r
.02886 .16187 m
.02886 .01481 L
.03688 .01481 L
.03688 .16187 L
F
.804 .522 .247 r
.02886 .16187 m
.02886 .01481 L
.03688 .01481 L
.03688 .16187 L
s
1 .894 .882 r
.03688 .16187 m
.03688 .01498 L
.04665 .01498 L
.04665 .16187 L
F
.804 .522 .247 r
.03688 .16187 m
.03688 .01498 L
.04665 .01498 L
.04665 .16187 L
s
1 .894 .882 r
.04665 .16187 m
.04665 .01524 L
.05337 .01524 L
.05337 .16187 L
F
.804 .522 .247 r
.04665 .16187 m
.04665 .01524 L
.05337 .01524 L
.05337 .16187 L
s
1 .894 .882 r
.05337 .16187 m
.05337 .01529 L
.06312 .01529 L
.06312 .16187 L
F
.804 .522 .247 r
.05337 .16187 m
.05337 .01529 L
.06312 .01529 L
.06312 .16187 L
s
1 .894 .882 r
.06312 .16187 m
.06312 .01589 L
.07187 .01589 L
.07187 .16187 L
F
.804 .522 .247 r
.06312 .16187 m
.06312 .01589 L
.07187 .01589 L
.07187 .16187 L
s
1 .894 .882 r
.07187 .16187 m
.07187 .0165 L
.07731 .0165 L
.07731 .16187 L
F
.804 .522 .247 r
.07187 .16187 m
.07187 .0165 L
.07731 .0165 L
.07731 .16187 L
s
1 .894 .882 r
.07731 .16187 m
.07731 .01676 L
.08552 .01676 L
.08552 .16187 L
F
.804 .522 .247 r
.07731 .16187 m
.07731 .01676 L
.08552 .01676 L
.08552 .16187 L
s
1 .894 .882 r
.08552 .16187 m
.08552 .01739 L
.08871 .01739 L
.08871 .16187 L
F
.804 .522 .247 r
.08552 .16187 m
.08552 .01739 L
.08871 .01739 L
.08871 .16187 L
s
1 .894 .882 r
.08871 .16187 m
.08871 .01765 L
.09783 .01765 L
.09783 .16187 L
F
.804 .522 .247 r
.08871 .16187 m
.08871 .01765 L
.09783 .01765 L
.09783 .16187 L
s
1 .894 .882 r
.09783 .16187 m
.09783 .0188 L
.10317 .0188 L
.10317 .16187 L
F
.804 .522 .247 r
.09783 .16187 m
.09783 .0188 L
.10317 .0188 L
.10317 .16187 L
s
1 .894 .882 r
.10317 .16187 m
.10317 .01921 L
.11015 .01921 L
.11015 .16187 L
F
.804 .522 .247 r
.10317 .16187 m
.10317 .01921 L
.11015 .01921 L
.11015 .16187 L
s
1 .894 .882 r
.11015 .16187 m
.11015 .0197 L
.11326 .0197 L
.11326 .16187 L
F
.804 .522 .247 r
.11015 .16187 m
.11015 .0197 L
.11326 .0197 L
.11326 .16187 L
s
1 .894 .882 r
.11326 .16187 m
.11326 .01997 L
.12009 .01997 L
.12009 .16187 L
F
.804 .522 .247 r
.11326 .16187 m
.11326 .01997 L
.12009 .01997 L
.12009 .16187 L
s
1 .894 .882 r
.12009 .16187 m
.12009 .0209 L
.12514 .0209 L
.12514 .16187 L
F
.804 .522 .247 r
.12009 .16187 m
.12009 .0209 L
.12514 .0209 L
.12514 .16187 L
s
1 .894 .882 r
.12514 .16187 m
.12514 .02248 L
.13482 .02248 L
.13482 .16187 L
F
.804 .522 .247 r
.12514 .16187 m
.12514 .02248 L
.13482 .02248 L
.13482 .16187 L
s
1 .894 .882 r
.13482 .16187 m
.13482 .02389 L
.14306 .02389 L
.14306 .16187 L
F
.804 .522 .247 r
.13482 .16187 m
.13482 .02389 L
.14306 .02389 L
.14306 .16187 L
s
1 .894 .882 r
.14306 .16187 m
.14306 .025 L
.15115 .025 L
.15115 .16187 L
F
.804 .522 .247 r
.14306 .16187 m
.14306 .025 L
.15115 .025 L
.15115 .16187 L
s
1 .894 .882 r
.15115 .16187 m
.15115 .02609 L
.15829 .02609 L
.15829 .16187 L
F
.804 .522 .247 r
.15115 .16187 m
.15115 .02609 L
.15829 .02609 L
.15829 .16187 L
s
1 .894 .882 r
.15829 .16187 m
.15829 .02778 L
.16718 .02778 L
.16718 .16187 L
F
.804 .522 .247 r
.15829 .16187 m
.15829 .02778 L
.16718 .02778 L
.16718 .16187 L
s
1 .894 .882 r
.16718 .16187 m
.16718 .02912 L
.17432 .02912 L
.17432 .16187 L
F
.804 .522 .247 r
.16718 .16187 m
.16718 .02912 L
.17432 .02912 L
.17432 .16187 L
s
1 .894 .882 r
.17432 .16187 m
.17432 .03099 L
.18395 .03099 L
.18395 .16187 L
F
.804 .522 .247 r
.17432 .16187 m
.17432 .03099 L
.18395 .03099 L
.18395 .16187 L
s
1 .894 .882 r
.18395 .16187 m
.18395 .03192 L
.19009 .03192 L
.19009 .16187 L
F
.804 .522 .247 r
.18395 .16187 m
.18395 .03192 L
.19009 .03192 L
.19009 .16187 L
s
1 .894 .882 r
.19009 .16187 m
.19009 .03295 L
.19669 .03295 L
.19669 .16187 L
F
.804 .522 .247 r
.19009 .16187 m
.19009 .03295 L
.19669 .03295 L
.19669 .16187 L
s
1 .894 .882 r
.19669 .16187 m
.19669 .03458 L
.2018 .03458 L
.2018 .16187 L
F
.804 .522 .247 r
.19669 .16187 m
.19669 .03458 L
.2018 .03458 L
.2018 .16187 L
s
1 .894 .882 r
.2018 .16187 m
.2018 .03632 L
.20646 .03632 L
.20646 .16187 L
F
.804 .522 .247 r
.2018 .16187 m
.2018 .03632 L
.20646 .03632 L
.20646 .16187 L
s
1 .894 .882 r
.20646 .16187 m
.20646 .03748 L
.21292 .03748 L
.21292 .16187 L
F
.804 .522 .247 r
.20646 .16187 m
.20646 .03748 L
.21292 .03748 L
.21292 .16187 L
s
1 .894 .882 r
.21292 .16187 m
.21292 .03885 L
.2229 .03885 L
.2229 .16187 L
F
.804 .522 .247 r
.21292 .16187 m
.21292 .03885 L
.2229 .03885 L
.2229 .16187 L
s
1 .894 .882 r
.2229 .16187 m
.2229 .04099 L
.22837 .04099 L
.22837 .16187 L
F
.804 .522 .247 r
.2229 .16187 m
.2229 .04099 L
.22837 .04099 L
.22837 .16187 L
s
1 .894 .882 r
.22837 .16187 m
.22837 .04283 L
.23438 .04283 L
.23438 .16187 L
F
.804 .522 .247 r
.22837 .16187 m
.22837 .04283 L
.23438 .04283 L
.23438 .16187 L
s
1 .894 .882 r
.23438 .16187 m
.23438 .0445 L
.23844 .0445 L
.23844 .16187 L
F
.804 .522 .247 r
.23438 .16187 m
.23438 .0445 L
.23844 .0445 L
.23844 .16187 L
s
1 .894 .882 r
.23844 .16187 m
.23844 .04469 L
.24324 .04469 L
.24324 .16187 L
F
.804 .522 .247 r
.23844 .16187 m
.23844 .04469 L
.24324 .04469 L
.24324 .16187 L
s
1 .894 .882 r
.24324 .16187 m
.24324 .04691 L
.24855 .04691 L
.24855 .16187 L
F
.804 .522 .247 r
.24324 .16187 m
.24324 .04691 L
.24855 .04691 L
.24855 .16187 L
s
1 .894 .882 r
.24855 .16187 m
.24855 .04818 L
.25555 .04818 L
.25555 .16187 L
F
.804 .522 .247 r
.24855 .16187 m
.24855 .04818 L
.25555 .04818 L
.25555 .16187 L
s
1 .894 .882 r
.25555 .16187 m
.25555 .05202 L
.26438 .05202 L
.26438 .16187 L
F
.804 .522 .247 r
.25555 .16187 m
.25555 .05202 L
.26438 .05202 L
.26438 .16187 L
s
1 .894 .882 r
.26438 .16187 m
.26438 .05351 L
.2723 .05351 L
.2723 .16187 L
F
.804 .522 .247 r
.26438 .16187 m
.26438 .05351 L
.2723 .05351 L
.2723 .16187 L
s
1 .894 .882 r
.2723 .16187 m
.2723 .05512 L
.27754 .05512 L
.27754 .16187 L
F
.804 .522 .247 r
.2723 .16187 m
.2723 .05512 L
.27754 .05512 L
.27754 .16187 L
s
1 .894 .882 r
.27754 .16187 m
.27754 .05677 L
.28073 .05677 L
.28073 .16187 L
F
.804 .522 .247 r
.27754 .16187 m
.27754 .05677 L
.28073 .05677 L
.28073 .16187 L
s
1 .894 .882 r
.28073 .16187 m
.28073 .05903 L
.28754 .05903 L
.28754 .16187 L
F
.804 .522 .247 r
.28073 .16187 m
.28073 .05903 L
.28754 .05903 L
.28754 .16187 L
s
1 .894 .882 r
.28754 .16187 m
.28754 .06176 L
.29589 .06176 L
.29589 .16187 L
F
.804 .522 .247 r
.28754 .16187 m
.28754 .06176 L
.29589 .06176 L
.29589 .16187 L
s
1 .894 .882 r
.29589 .16187 m
.29589 .06335 L
.30299 .06335 L
.30299 .16187 L
F
.804 .522 .247 r
.29589 .16187 m
.29589 .06335 L
.30299 .06335 L
.30299 .16187 L
s
1 .894 .882 r
.30299 .16187 m
.30299 .06612 L
.3082 .06612 L
.3082 .16187 L
F
.804 .522 .247 r
.30299 .16187 m
.30299 .06612 L
.3082 .06612 L
.3082 .16187 L
s
1 .894 .882 r
.3082 .16187 m
.3082 .07064 L
.31797 .07064 L
.31797 .16187 L
F
.804 .522 .247 r
.3082 .16187 m
.3082 .07064 L
.31797 .07064 L
.31797 .16187 L
s
1 .894 .882 r
.31797 .16187 m
.31797 .07394 L
.32753 .07394 L
.32753 .16187 L
F
.804 .522 .247 r
.31797 .16187 m
.31797 .07394 L
.32753 .07394 L
.32753 .16187 L
s
1 .894 .882 r
.32753 .16187 m
.32753 .07638 L
.33761 .07638 L
.33761 .16187 L
F
.804 .522 .247 r
.32753 .16187 m
.32753 .07638 L
.33761 .07638 L
.33761 .16187 L
s
1 .894 .882 r
.33761 .16187 m
.33761 .08006 L
.34328 .08006 L
.34328 .16187 L
F
.804 .522 .247 r
.33761 .16187 m
.33761 .08006 L
.34328 .08006 L
.34328 .16187 L
s
1 .894 .882 r
.34328 .16187 m
.34328 .08234 L
.34995 .08234 L
.34995 .16187 L
F
.804 .522 .247 r
.34328 .16187 m
.34328 .08234 L
.34995 .08234 L
.34995 .16187 L
s
1 .894 .882 r
.34995 .16187 m
.34995 .08534 L
.35594 .08534 L
.35594 .16187 L
F
.804 .522 .247 r
.34995 .16187 m
.34995 .08534 L
.35594 .08534 L
.35594 .16187 L
s
1 .894 .882 r
.35594 .16187 m
.35594 .08644 L
.36394 .08644 L
.36394 .16187 L
F
.804 .522 .247 r
.35594 .16187 m
.35594 .08644 L
.36394 .08644 L
.36394 .16187 L
s
1 .894 .882 r
.36394 .16187 m
.36394 .09097 L
.36799 .09097 L
.36799 .16187 L
F
.804 .522 .247 r
.36394 .16187 m
.36394 .09097 L
.36799 .09097 L
.36799 .16187 L
s
1 .894 .882 r
.36799 .16187 m
.36799 .09272 L
.37122 .09272 L
.37122 .16187 L
F
.804 .522 .247 r
.36799 .16187 m
.36799 .09272 L
.37122 .09272 L
.37122 .16187 L
s
1 .894 .882 r
.37122 .16187 m
.37122 .09373 L
.37734 .09373 L
.37734 .16187 L
F
.804 .522 .247 r
.37122 .16187 m
.37122 .09373 L
.37734 .09373 L
.37734 .16187 L
s
1 .894 .882 r
.37734 .16187 m
.37734 .09749 L
.3829 .09749 L
.3829 .16187 L
F
.804 .522 .247 r
.37734 .16187 m
.37734 .09749 L
.3829 .09749 L
.3829 .16187 L
s
1 .894 .882 r
.3829 .16187 m
.3829 .09864 L
.39105 .09864 L
.39105 .16187 L
F
.804 .522 .247 r
.3829 .16187 m
.3829 .09864 L
.39105 .09864 L
.39105 .16187 L
s
1 .894 .882 r
.39105 .16187 m
.39105 .10616 L
.40032 .10616 L
.40032 .16187 L
F
.804 .522 .247 r
.39105 .16187 m
.39105 .10616 L
.40032 .10616 L
.40032 .16187 L
s
1 .894 .882 r
.40032 .16187 m
.40032 .10712 L
.40467 .10712 L
.40467 .16187 L
F
.804 .522 .247 r
.40032 .16187 m
.40032 .10712 L
.40467 .10712 L
.40467 .16187 L
s
1 .894 .882 r
.40467 .16187 m
.40467 .10889 L
.40795 .10889 L
.40795 .16187 L
F
.804 .522 .247 r
.40467 .16187 m
.40467 .10889 L
.40795 .10889 L
.40795 .16187 L
s
1 .894 .882 r
.40795 .16187 m
.40795 .112 L
.41214 .112 L
.41214 .16187 L
F
.804 .522 .247 r
.40795 .16187 m
.40795 .112 L
.41214 .112 L
.41214 .16187 L
s
1 .894 .882 r
.41214 .16187 m
.41214 .11428 L
.41561 .11428 L
.41561 .16187 L
F
.804 .522 .247 r
.41214 .16187 m
.41214 .11428 L
.41561 .11428 L
.41561 .16187 L
s
1 .894 .882 r
.41561 .16187 m
.41561 .11666 L
.42215 .11666 L
.42215 .16187 L
F
.804 .522 .247 r
.41561 .16187 m
.41561 .11666 L
.42215 .11666 L
.42215 .16187 L
s
1 .894 .882 r
.42215 .16187 m
.42215 .12119 L
.43029 .12119 L
.43029 .16187 L
F
.804 .522 .247 r
.42215 .16187 m
.42215 .12119 L
.43029 .12119 L
.43029 .16187 L
s
1 .894 .882 r
.43029 .16187 m
.43029 .12294 L
.43432 .12294 L
.43432 .16187 L
F
.804 .522 .247 r
.43029 .16187 m
.43029 .12294 L
.43432 .12294 L
.43432 .16187 L
s
1 .894 .882 r
.43432 .16187 m
.43432 .12524 L
.44109 .12524 L
.44109 .16187 L
F
.804 .522 .247 r
.43432 .16187 m
.43432 .12524 L
.44109 .12524 L
.44109 .16187 L
s
1 .894 .882 r
.44109 .16187 m
.44109 .12786 L
.44939 .12786 L
.44939 .16187 L
F
.804 .522 .247 r
.44109 .16187 m
.44109 .12786 L
.44939 .12786 L
.44939 .16187 L
s
1 .894 .882 r
.44939 .16187 m
.44939 .13357 L
.45345 .13357 L
.45345 .16187 L
F
.804 .522 .247 r
.44939 .16187 m
.44939 .13357 L
.45345 .13357 L
.45345 .16187 L
s
1 .894 .882 r
.45345 .16187 m
.45345 .13467 L
.46237 .13467 L
.46237 .16187 L
F
.804 .522 .247 r
.45345 .16187 m
.45345 .13467 L
.46237 .13467 L
.46237 .16187 L
s
1 .894 .882 r
.46237 .16187 m
.46237 .14109 L
.46948 .14109 L
.46948 .16187 L
F
.804 .522 .247 r
.46237 .16187 m
.46237 .14109 L
.46948 .14109 L
.46948 .16187 L
s
1 .894 .882 r
.46948 .16187 m
.46948 .14466 L
.47832 .14466 L
.47832 .16187 L
F
.804 .522 .247 r
.46948 .16187 m
.46948 .14466 L
.47832 .14466 L
.47832 .16187 L
s
1 .894 .882 r
.47832 .16187 m
.47832 .14911 L
.48242 .14911 L
.48242 .16187 L
F
.804 .522 .247 r
.47832 .16187 m
.47832 .14911 L
.48242 .14911 L
.48242 .16187 L
s
1 .894 .882 r
.48242 .16187 m
.48242 .15275 L
.48869 .15275 L
.48869 .16187 L
F
.804 .522 .247 r
.48242 .16187 m
.48242 .15275 L
.48869 .15275 L
.48869 .16187 L
s
1 .894 .882 r
.48869 .16187 m
.48869 .15682 L
.49217 .15682 L
.49217 .16187 L
F
.804 .522 .247 r
.48869 .16187 m
.48869 .15682 L
.49217 .15682 L
.49217 .16187 L
s
1 .894 .882 r
.49217 .16187 m
.49217 .15914 L
.49804 .15914 L
.49804 .16187 L
F
.804 .522 .247 r
.49217 .16187 m
.49217 .15914 L
.49804 .15914 L
.49804 .16187 L
s
1 .894 .882 r
.49804 .16187 m
.49804 .16103 L
.50425 .16103 L
.50425 .16187 L
F
.804 .522 .247 r
.49804 .16187 m
.49804 .16103 L
.50425 .16103 L
.50425 .16187 L
s
.678 .847 .902 r
.50425 .16187 m
.50425 .16698 L
.5095 .16698 L
.5095 .16187 L
F
.2 .63 .79 r
.50425 .16187 m
.50425 .16698 L
.5095 .16698 L
.5095 .16187 L
s
.678 .847 .902 r
.5095 .16187 m
.5095 .16801 L
.51278 .16801 L
.51278 .16187 L
F
.2 .63 .79 r
.5095 .16187 m
.5095 .16801 L
.51278 .16801 L
.51278 .16187 L
s
.678 .847 .902 r
.51278 .16187 m
.51278 .17193 L
.52264 .17193 L
.52264 .16187 L
F
.2 .63 .79 r
.51278 .16187 m
.51278 .17193 L
.52264 .17193 L
.52264 .16187 L
s
.678 .847 .902 r
.52264 .16187 m
.52264 .17726 L
.52633 .17726 L
.52633 .16187 L
F
.2 .63 .79 r
.52264 .16187 m
.52264 .17726 L
.52633 .17726 L
.52633 .16187 L
s
.678 .847 .902 r
.52633 .16187 m
.52633 .18183 L
.53353 .18183 L
.53353 .16187 L
F
.2 .63 .79 r
.52633 .16187 m
.52633 .18183 L
.53353 .18183 L
.53353 .16187 L
s
.678 .847 .902 r
.53353 .16187 m
.53353 .18393 L
.53765 .18393 L
.53765 .16187 L
F
.2 .63 .79 r
.53353 .16187 m
.53353 .18393 L
.53765 .18393 L
.53765 .16187 L
s
.678 .847 .902 r
.53765 .16187 m
.53765 .18681 L
.54618 .18681 L
.54618 .16187 L
F
.2 .63 .79 r
.53765 .16187 m
.53765 .18681 L
.54618 .18681 L
.54618 .16187 L
s
.678 .847 .902 r
.54618 .16187 m
.54618 .19277 L
.54962 .19277 L
.54962 .16187 L
F
.2 .63 .79 r
.54618 .16187 m
.54618 .19277 L
.54962 .19277 L
.54962 .16187 L
s
.678 .847 .902 r
.54962 .16187 m
.54962 .19811 L
.55567 .19811 L
.55567 .16187 L
F
.2 .63 .79 r
.54962 .16187 m
.54962 .19811 L
.55567 .19811 L
.55567 .16187 L
s
.678 .847 .902 r
.55567 .16187 m
.55567 .19893 L
.55934 .19893 L
.55934 .16187 L
F
.2 .63 .79 r
.55567 .16187 m
.55567 .19893 L
.55934 .19893 L
.55934 .16187 L
s
.678 .847 .902 r
.55934 .16187 m
.55934 .20236 L
.56437 .20236 L
.56437 .16187 L
F
.2 .63 .79 r
.55934 .16187 m
.55934 .20236 L
.56437 .20236 L
.56437 .16187 L
s
.678 .847 .902 r
.56437 .16187 m
.56437 .2066 L
.56977 .2066 L
.56977 .16187 L
F
.2 .63 .79 r
.56437 .16187 m
.56437 .2066 L
.56977 .2066 L
.56977 .16187 L
s
.678 .847 .902 r
.56977 .16187 m
.56977 .2099 L
.57483 .2099 L
.57483 .16187 L
F
.2 .63 .79 r
.56977 .16187 m
.56977 .2099 L
.57483 .2099 L
.57483 .16187 L
s
.678 .847 .902 r
.57483 .16187 m
.57483 .21644 L
.58184 .21644 L
.58184 .16187 L
F
.2 .63 .79 r
.57483 .16187 m
.57483 .21644 L
.58184 .21644 L
.58184 .16187 L
s
.678 .847 .902 r
.58184 .16187 m
.58184 .21879 L
.58867 .21879 L
.58867 .16187 L
F
.2 .63 .79 r
.58184 .16187 m
.58184 .21879 L
.58867 .21879 L
.58867 .16187 L
s
.678 .847 .902 r
.58867 .16187 m
.58867 .22179 L
.59303 .22179 L
.59303 .16187 L
F
.2 .63 .79 r
.58867 .16187 m
.58867 .22179 L
.59303 .22179 L
.59303 .16187 L
s
.678 .847 .902 r
.59303 .16187 m
.59303 .22708 L
.59928 .22708 L
.59928 .16187 L
F
.2 .63 .79 r
.59303 .16187 m
.59303 .22708 L
.59928 .22708 L
.59928 .16187 L
s
.678 .847 .902 r
.59928 .16187 m
.59928 .23372 L
.60928 .23372 L
.60928 .16187 L
F
.2 .63 .79 r
.59928 .16187 m
.59928 .23372 L
.60928 .23372 L
.60928 .16187 L
s
.678 .847 .902 r
.60928 .16187 m
.60928 .23837 L
.61738 .23837 L
.61738 .16187 L
F
.2 .63 .79 r
.60928 .16187 m
.60928 .23837 L
.61738 .23837 L
.61738 .16187 L
s
.678 .847 .902 r
.61738 .16187 m
.61738 .24556 L
.62067 .24556 L
.62067 .16187 L
F
.2 .63 .79 r
.61738 .16187 m
.61738 .24556 L
.62067 .24556 L
.62067 .16187 L
s
.678 .847 .902 r
.62067 .16187 m
.62067 .24622 L
.63075 .24622 L
.63075 .16187 L
F
.2 .63 .79 r
.62067 .16187 m
.62067 .24622 L
.63075 .24622 L
.63075 .16187 L
s
.678 .847 .902 r
.63075 .16187 m
.63075 .25878 L
.64031 .25878 L
.64031 .16187 L
F
.2 .63 .79 r
.63075 .16187 m
.63075 .25878 L
.64031 .25878 L
.64031 .16187 L
s
.678 .847 .902 r
.64031 .16187 m
.64031 .26397 L
.64557 .26397 L
.64557 .16187 L
F
.2 .63 .79 r
.64031 .16187 m
.64031 .26397 L
.64557 .26397 L
.64557 .16187 L
s
.678 .847 .902 r
.64557 .16187 m
.64557 .27008 L
.65275 .27008 L
.65275 .16187 L
F
.2 .63 .79 r
.64557 .16187 m
.64557 .27008 L
.65275 .27008 L
.65275 .16187 L
s
.678 .847 .902 r
.65275 .16187 m
.65275 .27327 L
.66062 .27327 L
.66062 .16187 L
F
.2 .63 .79 r
.65275 .16187 m
.65275 .27327 L
.66062 .27327 L
.66062 .16187 L
s
.678 .847 .902 r
.66062 .16187 m
.66062 .2822 L
.66993 .2822 L
.66993 .16187 L
F
.2 .63 .79 r
.66062 .16187 m
.66062 .2822 L
.66993 .2822 L
.66993 .16187 L
s
.678 .847 .902 r
.66993 .16187 m
.66993 .28697 L
.67543 .28697 L
.67543 .16187 L
F
.2 .63 .79 r
.66993 .16187 m
.66993 .28697 L
.67543 .28697 L
.67543 .16187 L
s
.678 .847 .902 r
.67543 .16187 m
.67543 .29206 L
.68196 .29206 L
.68196 .16187 L
F
.2 .63 .79 r
.67543 .16187 m
.67543 .29206 L
.68196 .29206 L
.68196 .16187 L
s
.678 .847 .902 r
.68196 .16187 m
.68196 .29771 L
.68565 .29771 L
.68565 .16187 L
F
.2 .63 .79 r
.68196 .16187 m
.68196 .29771 L
.68565 .29771 L
.68565 .16187 L
s
.678 .847 .902 r
.68565 .16187 m
.68565 .30136 L
.69388 .30136 L
.69388 .16187 L
F
.2 .63 .79 r
.68565 .16187 m
.68565 .30136 L
.69388 .30136 L
.69388 .16187 L
s
.678 .847 .902 r
.69388 .16187 m
.69388 .30705 L
.70096 .30705 L
.70096 .16187 L
F
.2 .63 .79 r
.69388 .16187 m
.69388 .30705 L
.70096 .30705 L
.70096 .16187 L
s
.678 .847 .902 r
.70096 .16187 m
.70096 .31715 L
.70708 .31715 L
.70708 .16187 L
F
.2 .63 .79 r
.70096 .16187 m
.70096 .31715 L
.70708 .31715 L
.70708 .16187 L
s
.678 .847 .902 r
.70708 .16187 m
.70708 .32211 L
.71482 .32211 L
.71482 .16187 L
F
.2 .63 .79 r
.70708 .16187 m
.70708 .32211 L
.71482 .32211 L
.71482 .16187 L
s
.678 .847 .902 r
.71482 .16187 m
.71482 .32515 L
.72241 .32515 L
.72241 .16187 L
F
.2 .63 .79 r
.71482 .16187 m
.71482 .32515 L
.72241 .32515 L
.72241 .16187 L
s
.678 .847 .902 r
.72241 .16187 m
.72241 .33475 L
.72749 .33475 L
.72749 .16187 L
F
.2 .63 .79 r
.72241 .16187 m
.72241 .33475 L
.72749 .33475 L
.72749 .16187 L
s
.678 .847 .902 r
.72749 .16187 m
.72749 .33711 L
.73125 .33711 L
.73125 .16187 L
F
.2 .63 .79 r
.72749 .16187 m
.72749 .33711 L
.73125 .33711 L
.73125 .16187 L
s
.678 .847 .902 r
.73125 .16187 m
.73125 .3403 L
.73696 .3403 L
.73696 .16187 L
F
.2 .63 .79 r
.73125 .16187 m
.73125 .3403 L
.73696 .3403 L
.73696 .16187 L
s
.678 .847 .902 r
.73696 .16187 m
.73696 .34526 L
.74057 .34526 L
.74057 .16187 L
F
.2 .63 .79 r
.73696 .16187 m
.73696 .34526 L
.74057 .34526 L
.74057 .16187 L
s
.678 .847 .902 r
.74057 .16187 m
.74057 .35058 L
.74893 .35058 L
.74893 .16187 L
F
.2 .63 .79 r
.74057 .16187 m
.74057 .35058 L
.74893 .35058 L
.74893 .16187 L
s
.678 .847 .902 r
.74893 .16187 m
.74893 .35862 L
.75843 .35862 L
.75843 .16187 L
F
.2 .63 .79 r
.74893 .16187 m
.74893 .35862 L
.75843 .35862 L
.75843 .16187 L
s
.678 .847 .902 r
.75843 .16187 m
.75843 .37135 L
.768 .37135 L
.768 .16187 L
F
.2 .63 .79 r
.75843 .16187 m
.75843 .37135 L
.768 .37135 L
.768 .16187 L
s
.678 .847 .902 r
.768 .16187 m
.768 .37628 L
.77171 .37628 L
.77171 .16187 L
F
.2 .63 .79 r
.768 .16187 m
.768 .37628 L
.77171 .37628 L
.77171 .16187 L
s
.678 .847 .902 r
.77171 .16187 m
.77171 .37808 L
.775 .37808 L
.775 .16187 L
F
.2 .63 .79 r
.77171 .16187 m
.77171 .37808 L
.775 .37808 L
.775 .16187 L
s
.678 .847 .902 r
.775 .16187 m
.775 .3848 L
.78423 .3848 L
.78423 .16187 L
F
.2 .63 .79 r
.775 .16187 m
.775 .3848 L
.78423 .3848 L
.78423 .16187 L
s
.678 .847 .902 r
.78423 .16187 m
.78423 .39623 L
.79384 .39623 L
.79384 .16187 L
F
.2 .63 .79 r
.78423 .16187 m
.78423 .39623 L
.79384 .39623 L
.79384 .16187 L
s
.678 .847 .902 r
.79384 .16187 m
.79384 .40352 L
.79809 .40352 L
.79809 .16187 L
F
.2 .63 .79 r
.79384 .16187 m
.79384 .40352 L
.79809 .40352 L
.79809 .16187 L
s
.678 .847 .902 r
.79809 .16187 m
.79809 .40787 L
.80622 .40787 L
.80622 .16187 L
F
.2 .63 .79 r
.79809 .16187 m
.79809 .40787 L
.80622 .40787 L
.80622 .16187 L
s
.678 .847 .902 r
.80622 .16187 m
.80622 .4154 L
.81131 .4154 L
.81131 .16187 L
F
.2 .63 .79 r
.80622 .16187 m
.80622 .4154 L
.81131 .4154 L
.81131 .16187 L
s
.678 .847 .902 r
.81131 .16187 m
.81131 .41896 L
.81608 .41896 L
.81608 .16187 L
F
.2 .63 .79 r
.81131 .16187 m
.81131 .41896 L
.81608 .41896 L
.81608 .16187 L
s
.678 .847 .902 r
.81608 .16187 m
.81608 .42404 L
.82113 .42404 L
.82113 .16187 L
F
.2 .63 .79 r
.81608 .16187 m
.81608 .42404 L
.82113 .42404 L
.82113 .16187 L
s
.678 .847 .902 r
.82113 .16187 m
.82113 .42849 L
.82679 .42849 L
.82679 .16187 L
F
.2 .63 .79 r
.82113 .16187 m
.82113 .42849 L
.82679 .42849 L
.82679 .16187 L
s
.678 .847 .902 r
.82679 .16187 m
.82679 .43618 L
.83545 .43618 L
.83545 .16187 L
F
.2 .63 .79 r
.82679 .16187 m
.82679 .43618 L
.83545 .43618 L
.83545 .16187 L
s
.678 .847 .902 r
.83545 .16187 m
.83545 .44554 L
.83956 .44554 L
.83956 .16187 L
F
.2 .63 .79 r
.83545 .16187 m
.83545 .44554 L
.83956 .44554 L
.83956 .16187 L
s
.678 .847 .902 r
.83956 .16187 m
.83956 .4469 L
.84648 .4469 L
.84648 .16187 L
F
.2 .63 .79 r
.83956 .16187 m
.83956 .4469 L
.84648 .4469 L
.84648 .16187 L
s
.678 .847 .902 r
.84648 .16187 m
.84648 .45442 L
.85518 .45442 L
.85518 .16187 L
F
.2 .63 .79 r
.84648 .16187 m
.84648 .45442 L
.85518 .45442 L
.85518 .16187 L
s
.678 .847 .902 r
.85518 .16187 m
.85518 .46585 L
.86074 .46585 L
.86074 .16187 L
F
.2 .63 .79 r
.85518 .16187 m
.85518 .46585 L
.86074 .46585 L
.86074 .16187 L
s
.678 .847 .902 r
.86074 .16187 m
.86074 .47014 L
.86722 .47014 L
.86722 .16187 L
F
.2 .63 .79 r
.86074 .16187 m
.86074 .47014 L
.86722 .47014 L
.86722 .16187 L
s
.678 .847 .902 r
.86722 .16187 m
.86722 .48634 L
.87665 .48634 L
.87665 .16187 L
F
.2 .63 .79 r
.86722 .16187 m
.86722 .48634 L
.87665 .48634 L
.87665 .16187 L
s
.678 .847 .902 r
.87665 .16187 m
.87665 .48919 L
.8833 .48919 L
.8833 .16187 L
F
.2 .63 .79 r
.87665 .16187 m
.87665 .48919 L
.8833 .48919 L
.8833 .16187 L
s
.678 .847 .902 r
.8833 .16187 m
.8833 .49478 L
.88814 .49478 L
.88814 .16187 L
F
.2 .63 .79 r
.8833 .16187 m
.8833 .49478 L
.88814 .49478 L
.88814 .16187 L
s
.678 .847 .902 r
.88814 .16187 m
.88814 .50365 L
.89193 .50365 L
.89193 .16187 L
F
.2 .63 .79 r
.88814 .16187 m
.88814 .50365 L
.89193 .50365 L
.89193 .16187 L
s
.678 .847 .902 r
.89193 .16187 m
.89193 .51192 L
.90079 .51192 L
.90079 .16187 L
F
.2 .63 .79 r
.89193 .16187 m
.89193 .51192 L
.90079 .51192 L
.90079 .16187 L
s
.678 .847 .902 r
.90079 .16187 m
.90079 .51399 L
.90919 .51399 L
.90919 .16187 L
F
.2 .63 .79 r
.90079 .16187 m
.90079 .51399 L
.90919 .51399 L
.90919 .16187 L
s
.678 .847 .902 r
.90919 .16187 m
.90919 .52858 L
.91463 .52858 L
.91463 .16187 L
F
.2 .63 .79 r
.90919 .16187 m
.90919 .52858 L
.91463 .52858 L
.91463 .16187 L
s
.678 .847 .902 r
.91463 .16187 m
.91463 .53103 L
.91895 .53103 L
.91895 .16187 L
F
.2 .63 .79 r
.91463 .16187 m
.91463 .53103 L
.91895 .53103 L
.91895 .16187 L
s
.678 .847 .902 r
.91895 .16187 m
.91895 .53667 L
.92713 .53667 L
.92713 .16187 L
F
.2 .63 .79 r
.91895 .16187 m
.91895 .53667 L
.92713 .53667 L
.92713 .16187 L
s
.678 .847 .902 r
.92713 .16187 m
.92713 .55287 L
.93528 .55287 L
.93528 .16187 L
F
.2 .63 .79 r
.92713 .16187 m
.92713 .55287 L
.93528 .55287 L
.93528 .16187 L
s
.678 .847 .902 r
.93528 .16187 m
.93528 .55676 L
.94159 .55676 L
.94159 .16187 L
F
.2 .63 .79 r
.93528 .16187 m
.93528 .55676 L
.94159 .55676 L
.94159 .16187 L
s
.678 .847 .902 r
.94159 .16187 m
.94159 .56484 L
.94642 .56484 L
.94642 .16187 L
F
.2 .63 .79 r
.94159 .16187 m
.94159 .56484 L
.94642 .56484 L
.94642 .16187 L
s
.678 .847 .902 r
.94642 .16187 m
.94642 .56929 L
.95337 .56929 L
.95337 .16187 L
F
.2 .63 .79 r
.94642 .16187 m
.94642 .56929 L
.95337 .56929 L
.95337 .16187 L
s
.678 .847 .902 r
.95337 .16187 m
.95337 .57691 L
.95642 .57691 L
.95642 .16187 L
F
.2 .63 .79 r
.95337 .16187 m
.95337 .57691 L
.95642 .57691 L
.95642 .16187 L
s
.678 .847 .902 r
.95642 .16187 m
.95642 .5829 L
.96068 .5829 L
.96068 .16187 L
F
.2 .63 .79 r
.95642 .16187 m
.95642 .5829 L
.96068 .5829 L
.96068 .16187 L
s
.678 .847 .902 r
.96068 .16187 m
.96068 .5852 L
.96376 .5852 L
.96376 .16187 L
F
.2 .63 .79 r
.96068 .16187 m
.96068 .5852 L
.96376 .5852 L
.96376 .16187 L
s
.678 .847 .902 r
.96376 .16187 m
.96376 .59338 L
.9687 .59338 L
.9687 .16187 L
F
.2 .63 .79 r
.96376 .16187 m
.96376 .59338 L
.9687 .59338 L
.9687 .16187 L
s
.678 .847 .902 r
.9687 .16187 m
.9687 .59581 L
.97619 .59581 L
.97619 .16187 L
F
.2 .63 .79 r
.9687 .16187 m
.9687 .59581 L
.97619 .59581 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02572 .01472 Mdot
.03571 .01481 Mdot
.04392 .01498 Mdot
.05222 .01524 Mdot
.05357 .01529 Mdot
.06633 .01589 Mdot
.07631 .0165 Mdot
.07992 .01676 Mdot
.08796 .01739 Mdot
.09107 .01765 Mdot
.10313 .0188 Mdot
.10707 .01921 Mdot
.11147 .0197 Mdot
.11378 .01997 Mdot
.12143 .0209 Mdot
.13323 .02248 Mdot
.14274 .02389 Mdot
.14971 .025 Mdot
.15621 .02609 Mdot
.1657 .02778 Mdot
.17281 .02912 Mdot
.18217 .03099 Mdot
.18664 .03192 Mdot
.19143 .03295 Mdot
.19878 .03458 Mdot
.20628 .03632 Mdot
.2111 .03748 Mdot
.21666 .03885 Mdot
.22503 .04099 Mdot
.23194 .04283 Mdot
.23805 .0445 Mdot
.23872 .04469 Mdot
.24656 .04691 Mdot
.2509 .04818 Mdot
.26359 .05202 Mdot
.26832 .05351 Mdot
.27334 .05512 Mdot
.27836 .05677 Mdot
.28513 .05903 Mdot
.29307 .06176 Mdot
.29758 .06335 Mdot
.30526 .06612 Mdot
.31736 .07064 Mdot
.3259 .07394 Mdot
.33207 .07638 Mdot
.34113 .08006 Mdot
.34661 .08234 Mdot
.3537 .08534 Mdot
.35627 .08644 Mdot
.36661 .09097 Mdot
.37052 .09272 Mdot
.37276 .09373 Mdot
.38096 .09749 Mdot
.38343 .09864 Mdot
.3992 .10616 Mdot
.40117 .10712 Mdot
.40476 .10889 Mdot
.411 .112 Mdot
.4155 .11428 Mdot
.42017 .11666 Mdot
.42888 .12119 Mdot
.43219 .12294 Mdot
.4365 .12524 Mdot
.44137 .12786 Mdot
.45178 .13357 Mdot
.45375 .13467 Mdot
.46511 .14109 Mdot
.47129 .14466 Mdot
.47889 .14911 Mdot
.48501 .15275 Mdot
.49177 .15682 Mdot
.49557 .15914 Mdot
.49865 .16103 Mdot
.50821 .16698 Mdot
.50984 .16801 Mdot
.51602 .17193 Mdot
.52429 .17726 Mdot
.53128 .18183 Mdot
.53445 .18393 Mdot
.53879 .18681 Mdot
.54763 .19277 Mdot
.55542 .19811 Mdot
.5566 .19893 Mdot
.56154 .20236 Mdot
.56758 .2066 Mdot
.57224 .2099 Mdot
.58135 .21644 Mdot
.58459 .21879 Mdot
.5887 .22179 Mdot
.59587 .22708 Mdot
.60475 .23372 Mdot
.61088 .23837 Mdot
.62024 .24556 Mdot
.6211 .24622 Mdot
.63708 .25878 Mdot
.64356 .26397 Mdot
.65111 .27008 Mdot
.65503 .27327 Mdot
.66582 .2822 Mdot
.67152 .28697 Mdot
.67755 .29206 Mdot
.68418 .29771 Mdot
.68842 .30136 Mdot
.69499 .30705 Mdot
.70649 .31715 Mdot
.71206 .32211 Mdot
.71545 .32515 Mdot
.72607 .33475 Mdot
.72865 .33711 Mdot
.73214 .3403 Mdot
.73751 .34526 Mdot
.74322 .35058 Mdot
.75179 .35862 Mdot
.76514 .37135 Mdot
.77025 .37628 Mdot
.77211 .37808 Mdot
.77899 .3848 Mdot
.79056 .39623 Mdot
.79785 .40352 Mdot
.80217 .40787 Mdot
.80959 .4154 Mdot
.81307 .41896 Mdot
.81802 .42404 Mdot
.82232 .42849 Mdot
.8297 .43618 Mdot
.83861 .44554 Mdot
.83989 .4469 Mdot
.84696 .45442 Mdot
.85759 .46585 Mdot
.86155 .47014 Mdot
.87632 .48634 Mdot
.87888 .48919 Mdot
.88391 .49478 Mdot
.89182 .50365 Mdot
.89913 .51192 Mdot
.90095 .51399 Mdot
.91367 .52858 Mdot
.91579 .53103 Mdot
.92065 .53667 Mdot
.93446 .55287 Mdot
.93775 .55676 Mdot
.94453 .56484 Mdot
.94825 .56929 Mdot
.95458 .57691 Mdot
.95952 .5829 Mdot
.96141 .5852 Mdot
.96811 .59338 Mdot
.97009 .59581 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(148) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0211628) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.664142) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H400000080n_3V1P0000020?[`iP@0
00000P3jl>H500000?l0n_3VW03jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP8000001@3j
l>H2000000D0n_3V0P0000030?[`iP800000o`3jl>JO0?[`iP40oooo000P0?[`iP80000000<0n_3V
000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H010000002
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
000H0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P00
0000103jl>H000000000003jl>H6000000@0n_3V0P0000020?[`iPH000000`3jl>H200000?l0n_3V
WP3jl>H10?ooo`00803jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V
0000003jl>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`
iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP0000000000
00T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000D0n_3V000000000000n_3V00000002
0?[`iP8000001@3jl>H200000080n_3V00<000000?[`iP3jl>H00P0000050?[`iP800000o`3jl>JM
0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H20000
00060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00
000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V000000000000
2@3jl>H4000000<0n_3V100000030?[`iP040000003jl>H00000000000D0n_3V0P0000030?[`iP04
0000003jl>H00000000000H0n_3V0P00003o0?[`iY`0n_3V0@3oool00200n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@0
00000P3jl>H500000080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L0
00006@3jl>H2000000030?[`iP000000000000T0n_3V0P0000050?[`iP8000001@3jl>H010000000
n_3V0000000000050?[`iP8000000`3jl>H010000000n_3V0000000000030?[`iP80000000<0n_3V
000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`
iP030000003jl>H0n_3V02D0n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H20000
00D0n_3V0`0000030?[`iP@00000103jl>H3000000<0n_3V0P0000000`3jl>H000000000003o0?[`
iY`0n_3V0@3oool001l0n_3V1P0000040?[`iP800000;`3jl>H5000002P0n_3V0`00000<0?[`iP<0
0000103jl>H3000000@0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V0`00003o0?[`iYd0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40oooo00100?[`iP800000o`3jl>Ko0?[`iQL0
n_3V0@3oool00200n_3V1P0000001@3jl>H00000000000000000n_3V00<000000P3jl>H3000000<0
n_3V100000030?[`iP80000000@0n_3V000000000000n_3V1@0000030?[`iP`00000;`3jl>H30000
00@0n_3V0P0000050?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H30000
00D0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V00000000
00000P3jl>H200000080n_3V00@000000?[`iP00000000000`3jl>H01@000000n_3V000000000000
n_3V00<000000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000280n_3V1@000009
0?[`iP80000000<0n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H1
0?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H20000
00D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H20000
0300n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280
n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V1P0000000`3jl>H0
0000000000020?[`iP8000000P3jl>H2000000D0n_3V1@0000030?[`iP8000008P3jl>H5000000T0
n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000020?[`iP800000
00@0n_3V000000000000n_3V0`0000020?[`iP<0000000<0n_3V0000003jl>H0103jl>H2000000<0
n_3V0P00000`0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V100000030?[`iP@0
00000`3jl>H4000000<0n_3V100000060?[`iP800000o`3jl>JM0?[`iP40oooo000R0?[`iP800000
0`3jl>H500000080n_3V1@0000030?[`iP@000000`3jl>H2000000030?[`iP000000000000@00000
00<0n_3V0000000000000P3jl>H4000000@0n_3V0P00000`0?[`iP80000000<0n_3V000000000000
2@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000080?[`iP800000
o`3jl>JM0?[`iP40oooo000R0?[`iP8000002`3jl>H200000280n_3V0P00000`0?[`iP80000000<0
n_3V0000000000002P3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P00
00040?[`iP030000003jl>H0n_3V00800000o`3jl>JM0?[`iP40oooo000P0?[`iPH000002@3jl>H2
00000200n_3V1000000a0?[`iP<00000303jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3
000000@0n_3V0`0000020?[`iPD00000o`3jl>JM0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P000000
0`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`
iP040000003jl>H000000?[`iP8000000P3jl>H00`000000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT
0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P0000001@3jl>H000000?[`iP000000
n_3V00<000000P3jl>H00`000000n_3V0000000H0?[`iPD00000f`3jl>H4000000@0n_3V2`000004
0?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`000000
103jl>H000000000000000080?[`iP@0000000<0n_3V0000000000000P3jl>H400000080n_3V1@00
00001`3jl>H00000000000000000n_3V0000003jl>H00`00000H0?[`iP<00000103jl>H2000000D0
n_3V0`0000030?[`iPD000000P3jl>H6000000030?[`iP000000000000@000000P3jl>H3000000<0
n_3V1@0000030?[`iP<00000LP3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D00000
00@0n_3V00000000000000000P3jl>H2000000030?[`iP000000000000T0n_3V1@0000090?[`iP80
0000g`3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP04
0000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000
n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2
000000030?[`iP00000000000080n_3V0P0000070?[`iP8000001@3jl>H2000000<0n_3V0P000000
0`3jl>H00000000000020?[`iP8000001@3jl>H2000000030?[`iP00000000000740n_3V0@3oool0
0280n_3V0`00000Y0?[`iP800000gP3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H20000
00D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP02
00000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V00800000603jl>H2
000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000030?[`iP8000001P3jl>H2
000000D0n_3V0P0000030?[`iP80000000<0n_3V0000000000000`3jl>H2000000@0n_3V0P000000
0`3jl>H000000000001a0?[`iP40oooo000R0?[`iP<000006P3jl>H5000000/0n_3V0P00003M0?[`
iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H20000
00050?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P000000
0`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2
000000030?[`iP000000000000@0n_3V0P0000050?[`iP8000001@3jl>H2000000<0n_3V0P000000
0`3jl>H00000000000040?[`iP8000000`3jl>H2000000030?[`iP00000000000740n_3V0@3oool0
0240n_3V0P0000000`3jl>H000000000000Z0?[`iP800000g03jl>H2000000030?[`iP0000000000
00D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2
000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:
0?[`iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP00
0000n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3j
l>H2000000030?[`iP000000000000D0n_3V0P0000040?[`iP8000001@3jl>H2000000<0n_3V1000
00060?[`iP8000000`3jl>H300000780n_3V0@3oool00200n_3V0`000000103jl>H0000000000000
000V0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V1000
00020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V
100000040?[`iP@000000P3jl>H5000000/0n_3V0`0000000`3jl>H00000000000020?[`iP@00000
0P3jl>H3000000030?[`iP000000000000L000006@3jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H2000000D0n_3V
0P0000030?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
0000001a0?[`iP40oooo001=0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00
000000000100n_3V0P00000<0?[`iP8000008P3jl>H200000080n_3V0P00000^0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP@000000`3jl>H4000000@0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP00000000000740n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2
000000H0n_3V0P0000040?[`iP8000001P3jl>H2000001T0n_3V0`0000000`3jl>H0000000000002
000002h0n_3V0`00000;0?[`iP<00000103jl>H3000000D0n_3V0P0000050?[`iP8000001@3jl>H3
000000<0n_3V0`0000040?[`iP<00000LP3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H02000
00000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H01@000000n_3V0000003j
l>H000000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V
8P3jl>H10?ooo`00803jl>H3000000030?[`iP00000000000080000000@0n_3V0000003jl>H00000
0P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V01L0n_3V0`00003L0?[`iP@0
0000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@0
00000P3jl>H3000000030?[`iP000000000000H000006P3jl>H600000080n_3V100000030?[`iP<0
0000^P3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000D0n_3V000000000000
00000?[`iP04000000/0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H2000000@0
n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`
iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000;0?[`iPD000002`3j
l>H2000000D0n_3V0P0000030?[`iP80000000<0n_3V000000000000^@3jl>H10?ooo`008P3jl>H3
000002P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P000002
0?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P000002
0?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000K0?[`iP8000000P3jl>H6
00000080n_3V0P0000000`3jl>H000000000002i0?[`iP40oooo000R0?[`iP<000002@3jl>H00`00
0000n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V100000030?[`
iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`
iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H4000000d0n_3V1@00000;
0?[`iP8000000P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000000`3jl>H000000000002i
0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000009`3jl>H2000000030?[`iP0000000000
0=`0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V
0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P000002
0?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000006`3jl>H2000000<0n_3V00@0
00000?[`iP0000000000103jl>H300000;X0n_3V0@3oool00200n_3V0`000000103jl>H000000000
0000000V0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V
100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080
n_3V100000040?[`iP@000000P3jl>H5000000<0n_3V1@00000K0?[`iP8000000`3jl>H010000000
n_3V0000000000030?[`iP80000000<0n_3V000000000000^@3jl>H10?ooo`00C@3jl>H200000003
0?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2000003P0
n_3V100000040?[`iP<000000`3jl>H2000000030?[`iP00000000000;T0n_3V0@3oool004h0n_3V
0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H200000380n_3V
0P0000050?[`iP800000103jl>H300000;X0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iRH0oooP0P00001/0?ooh0800000103oon02000000@0
oooP0P00001[0?ooh0D00000J@3oon0500000080oooP0P0000040?ooh0800000J`3oon04000002<0
oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03o
on000000203oon0010000000oooP0?ooh000001/0?ooh0030000003oon00oooP06/0oooP00<00000
0?ooh03oon001`3oon0010000000oooP0?ooh000001Z0?ooh0030000003oon00oooP02@0oooP7P3j
l>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000
2`3oon000`000000oooP0?ooh01Z0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon00
2P3oon000`000000oooP0?ooh01Y0?ooh0030000003oon00oooP02<0oooP7P3jl>H10?ooo`007@3j
l>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002@3oon02000006d0
oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0080?ooh0800000K@3oon000`000000
oooP0?ooh00R0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh004
0000003oon00oooP000000T0oooP00<000000?ooh03oon00K03oon000`000000oooP0?ooh01[0?oo
h0030000003oon00oooP00P0oooP00<000000?ooh03oon00JP3oon0010000000oooP0?ooh000000S
0?ooh1h0n_3V0@3oool001d0n_3V9P3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon020000
06`0oooP0P00000:0?ooh0<00000J`3oon02000002@0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000
003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?oo
h0030000003oon00oooP00T0oooP0P0000030?ooh08000000P3oon0200000080oooP0`00003o0?oo
h<d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03o
on001P3oon000`000000oooP0?ooh0080?ooh0@0000000<0oooP0000000000002`0000030?ooh080
00000`3oon0400000080oooP0P00003o0?ooh;`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon04000000L0oooP00<000000000o`000?l0
60000?l8000000@0oooP1000003o0?ooh;00oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V2P3o
on04000000@0oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh080000000<0
cHDo0?oTh@3oi>400P0000020?oTh@80000000<0cHDo0?oTh@0000000P0000030?oTh@@0000000<0
cHDo00000000000020000?l00`000000cHDo0<f5?`0800000080oooP0P00003o0?ooh:`0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon00
0`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40
103=QCl0onCQ0?oTh@3=QCl40?oTh@060<f5?`00000000000?oTh@3=QCl0onCQ100000000`3oi>40
cHDo00000002000000X0003o1P0000030?ooh0800000o`3oon2V0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`8000000P3oi>40
0`3=QCl0onCQ00000005000000T0003o0`0000000`3oon000000000000020?ooh0800000o`3oon2N
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo
103oi>400`3=QCl0onCQ0<f5?`030?oTh@<000000P3oi>42000000040<f5?`3oi>40onCQ000000P0
003o1@0000020?ooh0800000o`3oon2G0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oT
h@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>40
0`3=QCl0onCQ0<f5?`030?oTh@80000000<0onCQ0000000000000`0000050000o`D0000000<0oooP
000000000000o`3oon2C0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oT
h@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3o
i>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ
0<f5?`040?oTh@030<f5?`3oi>40onCQ008000000P3oi>45000000D0003o10000000103oon000000
0000003oon0200000?l0oooPS03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=
QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo
0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@0000000000
0P3oi>42000000030<f5?`000?l0003o00<0003o1`00003o0?ooh8X0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5
?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo
00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00H0cHDo0?oTh@00000000000<f5?`0000050000o`<0
000000<0cHDo000000000000o`3oon260?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oT
h@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>40
0`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ0P0000000`3=QCl00000000000050000o`@0
000000<0oooP000000000000o`3oon200?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oT
h@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>40
0`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00<0cHDo0?oTh@3oi>400P0000000`3oi>40
0000000000040000o`D00000o`3oon1n0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oT
h@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>40
0`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=
QCl0000000000003000000D0003o00@000000<f5?`0000000000o`3oon1j0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oT
h@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ
0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo
0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl2000000030?oTh@000000000000800000
10000?l010000000oooP00000000003o0?ooh7H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5
?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl3
0?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3o
i>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl000000000003oi>43000000@0003o
0`00003o0?ooh7<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
00090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5
?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oT
h@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl2
0?oTh@030<f5?`3oi>40onCQ0080onCQ0P000000103=QCl000000000000000030000o`030000003=
QCl0000000<00000o`3oon1[0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo
0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40
onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo
0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3o
i>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40cHDo0?oTh@D0000010000?l3
00000?l0oooPK03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oT
h@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0
103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0
onCQ000000000000onCQ00<000000`000?l00`3=QCl0oooP0?ooh00200000?l0oooPI`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0
cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oT
h@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5
?`00000000000080000000<0onCQ0000o`000?l00P000?l300000?l0oooPI@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3o
i>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oT
h@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5
?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40
onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo00<0onCQ0P3=QCl2000000<0003o0`00003o0?ooh680oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`030?oT
h@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ
0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@04
0<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=
QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oTh@03
0<f5?`3oi>40onCQ00@000000`000?l200000?l0oooPH03oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ
00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>42
0<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0
cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`0500000080003o00@000000?ooh00000000000o`3oon1L0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>40
0`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0
onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ100000030000o`800000
00<0oooP000000000000o`3oon1H0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oT
h@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@04
0<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=
QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0
onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00D0cHDo0?oTh@00000000000<f5?`02000000<0003o1000003o0?ooh5H0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oT
h@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo
103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40
0`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401P3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@80000000@0cHDo000000000?l0003o1@00003o0?ooh5<0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0
onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3o
i>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=
QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3oi>400P0000030000o`<00000o`3oon1B0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=
QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5
?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oT
h@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl0
0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`0000030000o`<0oooP0P00003o0?ooh4d0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=
QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5
?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0
onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@80000000@0cHDo0000o`000?l0003o
0`00003o0?ooh4`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0
cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3o
i>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo
00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0
cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5
?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3o
i>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@03
0<f5?`3oi>40cHDo0080cHDo00@000000000o`000?l000000P3oon0200000?l0oooPB03oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0cHDo0?oTh@3=
QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5
?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oT
h@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl0
0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0<f5?`030?oTh@8000000`000?l5
00000?l0oooP@`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo
103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oT
h@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0<f5
?`040?oTh@040<f5?`3oi>40onCQ000000<0003o0`00003o0?ooh4@0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5
?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo
00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ
0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`03
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo00@0onCQ00@0cHDo0?oTh@3o
i>40onCQ0`0000020000o`040000003=QCl0000000000?l0oooP@@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo
00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl0
0`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40
onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oT
h@020?oTh@040<f5?`3oi>400000000000<0003o1000003o0?ooh3h0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5
?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo
00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ
0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`03
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@8000000`000?l400000?l0oooP>`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo
0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@04
0<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3o
i>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=
QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0000000000000P0000020000
o`<00000o`3oon0j0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@04
0<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40
onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5
?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@04
0<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=
QCl0onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5
?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40
0`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>40
103=QCl0onCQ0<f5?`3oi>4300000080003o0P00003o0?ooh3T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`03
0?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0
onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oT
h@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00<0onCQ00<0cHDo000000000000
0P000?l20<f5?`800000o`3oon0e0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oT
h@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@04
0<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=
QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=
QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0
onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3oi>4000000000003oi>400P000?l40000
0?l0oooP<`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3o
i>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@05
0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@04000000000?l0003o0000o`800000
o`3oon0b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3o
i>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oT
h@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3o
i>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ
0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0
onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0
onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ0`0000020000o`040000003=QCl00000
00000?l0oooP;P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oT
h@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0
103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0
cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40000000800000
0P000?l400000?l0oooP;03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3o
i>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0
onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oT
h@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103o
i>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40cHDo
0080000000@0onCQ000000000?l0003o0`0000020<f5?ol0oooP:@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo
00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl0
0`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40
onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oT
h@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oT
h@3=QCl30?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ00<0cHDo0000000000000`000?l00`3oi>40
cHDo0?ooh03o0?ooh2P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oT
h@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40
cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ
00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ
0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oT
h@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0<f5?`3=
QCl20?oTh@030<f5?`3oi>40onCQ0080000000<0onCQ0000o`000?l0o`3oon0Y0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon000`3=QCl0onCQ0<f5?`03
0?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0
onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oT
h@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40
cHDo0`3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo
0000o`000?l00`00003o0?ooh280oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oT
h@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0
103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=
QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0
cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5?`3oi>40cHDo0<f5?`80
onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>420<f5?`03000000000?l0003o00<00000o`3oon0R0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5
?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo103o
i>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5
?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=
QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0<f5?`04
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`03
0?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>40103=QCl0onCQ
0?oTh@3=QCl30?oTh@030<f5?`3oi>400000008000000P000?l400000?l0oooP7`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5
?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo
0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@04
0<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3o
i>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=
QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=
QCl0onCQ0?oTh@3=QCl30?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo
0`3oi>400`3=QCl0onCQ0?oTh@0400000080003o0`00003o0?ooh1h0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5
?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo
00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ
0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`03
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3o
i>40cHDo0`3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00H0
cHDo0?oTh@3oi>40onCQ0<f5?`3oi>4300000080003o0P00003o0?ooh1d0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ
0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40
cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0
onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oT
h@020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5
?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oT
h@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oT
h@3oi>40cHDo0`3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ
00T0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P0000020000o`800000o`3oon0K
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo
103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oT
h@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0<f5
?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5
?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>40103=QCl0
onCQ0?oTh@3=QCl30?oTh@0:0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0
00000P000?l00`000000oooP0?ooh03o0?ooh1P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5
?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl3
0?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3o
i>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40
103=QCl0onCQ0<f5?`3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00/0cHDo0?oTh@3oi>40
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`0400000080003o00<0oooP000000000000o`3o
on0F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40
onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80
cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40
onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5
?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo
0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>40103=
QCl0onCQ0?oTh@3=QCl30?oTh@0=0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`0200000080cHDo0P000?l200000?l0oooP5@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo
00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl0
0`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40
onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080
onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oT
h@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oT
h@3=QCl30?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>403@3=
QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40103=
QCl0onCQ0000000000020000o`800000o`3oon0C0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=
QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo
0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ
00@0cHDo0?oTh@3=QCl0cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@0=0<f5?`3oi>40onCQ
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ
00<000000P000?l300000?l0oooP403oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3o
i>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0
cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40
cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo
0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
onCQ0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5?`3o
i>40cHDo0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>403@3=QCl0onCQ0?oTh@3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>440000
00040000o`000000000000000?l0oooP3`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oT
h@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3o
i>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ
00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3o
i>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0
cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5
?`3oi>40cHDo0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>403@3=QCl0onCQ0?oTh@3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0?oTh@3oi>40
cHDo0?oTh@<000000P000?l00`000000cHDo0<f5?`3o0?ooh0d0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`03
0?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0
onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oT
h@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40
cHDo0`3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00d0cHDo
0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo
0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ0P0000020000o`030<f5?`00000000000?l0oooP
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00<0
cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=
QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ
00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00<0cHDo
0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ
0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0<f5?`040?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`030?oTh@04
0<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>40103=QCl0onCQ0?oTh@3=
QCl30?oTh@0=0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oT
h@000?l00`00003o0?ooh0P0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3o
i>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@05
0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ
00@0cHDo0?oTh@3oi>40cHDo0`3oi>403@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40
1@3=QCl0onCQ0?oTh@3oi>4000000080003o0P0000030<f5?ol0oooP1P3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40
cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=
QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3o
i>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo
00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ
0?oTh@3=QCl30?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40
3@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
1`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080
00000P000?l20?oTh@030<f5?`3oon00oooP0?l0oooP103oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ
00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>42
0<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0
cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl3
0?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>403@3=QCl0onCQ
0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ
0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@80000000<0
onCQ0000o`000?l00P00003o0?ooh0D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40
onCQ0080onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ
00@0cHDo0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@03
0<f5?`3oi>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5
?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`030?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@020?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0
onCQ0<f5?`3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00d0cHDo0?oTh@3oi>40onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5
?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo00<0onCQ00<000000000
o`0000000`00003o0?ooh080oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080
onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo
0?oTh@3oi>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3o
i>40cHDo00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0
onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40
onCQ0<f5?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@030<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@030<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0<f5
?`3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00d0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40
cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo00<0onCQ0P0000020000o`<00000
o`3oon010?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3o
i>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oT
h@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3o
i>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ
0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0
onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0
onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>40
103=QCl0onCQ0?oTh@3=QCl30?oTh@0=0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@07
0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`040?oTh@<000000P000?l00`000000cHDo0<f5?`3n
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0?oTh@80cHDo
103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ
0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oT
h@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0<f5
?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5
?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>40103=QCl0
onCQ0?oTh@3=QCl30?oTh@0=0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3o
i>40onCQ0?oTh@3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ008000000P000?l200000?d0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3oi>40
cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=QCl4
0?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40
cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3o
i>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo
00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo
00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@040<f5?`3o
i>40onCQ0<f5?`<0onCQ00d0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oT
h@3oi>40onCQ0<f5?`3oi>40cHDo00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`000000003o
0000000300000?X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0
cHDo0?oTh@3oi>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3o
i>40onCQ0P3=QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo
00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0
cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5
?`3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3o
i>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@03
0<f5?`3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@03
0<f5?`3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0<f5?`3=QCl2
0?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00d0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080
onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>4200000080003o0`00003i0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<0cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@02
0?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5
?`3oi>40onCQ0?oTh@80cHDo103oi>400`3=QCl0onCQ0<f5?`030?oTh@80cHDo0`3oi>400`3=QCl0
onCQ0<f5?`040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl4
0?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401P3=QCl0onCQ
0?oTh@3=QCl0onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0`3oi>400`3=QCl0onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3=
QCl0cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@0=0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ
0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`040?oTh@040<f5?`3oi>40onCQ
0<f5?`<0onCQ0`0000020000o`<00000m`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oT
h@3oi>400P3oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3o
i>40103=QCl0onCQ0?oTh@3oi>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ
00<0cHDo0?oTh@3=QCl0103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3o
i>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0
cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00<0cHDo0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5
?`3oi>40cHDo0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>403@3=QCl0onCQ0?oTh@3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40
cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0103oi>40103=QCl0
onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40cHDo0080000000<0003o0000000000000P00003e0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000
oooP0?ooh0090?ooh0030<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3o
i>420<f5?`@0onCQ00<0cHDo0?oTh@3=QCl00`3oi>420<f5?`<0onCQ00<0cHDo0?oTh@3=QCl0103o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo103oi>40103=QCl0
onCQ0?oTh@3=QCl40?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl20?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@030<f5?`3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@05
0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3=QCl00`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ
00@0cHDo0?oTh@3oi>40cHDo0`3oi>403@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40
1`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0103oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@03
0<f5?`3oi>40cHDo0080onCQ00<000000000o`000?l01000003c0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03o
on002@3oon000`3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080onCQ00@0cHDo0?oTh@3o
i>40cHDo103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40onCQ0P3=
QCl40?oTh@030<f5?`3oi>40cHDo00<0onCQ0P3=QCl30?oTh@030<f5?`3oi>40cHDo00@0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@040<f5?`3oi>40onCQ0<f5?`@0onCQ00@0cHDo0?oTh@3o
i>40cHDo103oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo
0P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0<f5?`030?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>401@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40
cHDo00@0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40
cHDo00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@040<f5
?`3oi>40onCQ0<f5?`<0onCQ00d0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo
0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0
onCQ0<f5?`020?oTh@030<f5?`00000000000080003o0`00003b0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP100000080?ooh>L0
00000P000?oX000000P0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP
0?ooh00000070?ooh0030000003oon00oooP0?00oooP0P0000001P000?l0<j7:000000000000[MSV
03>QbP@0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0
<j7:0080[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80
<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon00
0`000000oooP0?ooh03c0?ooh080003o0P0000000`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP04
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03c0?ooh080000000<0003o0000
00000000102]f>H00`0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0c
XLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03d0?ooh080
00000P000?l200000080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP03
03>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP03
0:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
m@3oon03000000030000o`00000000000080<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03g0?ooh08000000P000?l0103oon0000000000000cXLX20:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03h0?ooh080000000<0oooP0000o`0000000P0000020:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03k0?ooh004000000000?l0000000000080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gH
iP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H2
03>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]
f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?`0oooP
00@000000000o`000?l0[MSV0P0000000`2]f>H0<j7:0:gHiP020:gHiP0303>QbP2]f>H0<j7:0080
[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00oP3oon000`0cXLX0003o
000000020000000703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP00<000000000o`000?l00`0000020:gHiP03
03>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP03
0:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon010?ooh080000000@0003o00000000000000000P0cXLX02@2]f>H0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon020?ooh08000000P000?l01@00
0000oooP03>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon040?ooh080000000<0003o0?ooh00cXLX00P0000020:gHiP0503>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<00000o`3oon070?ooh080003o0`0000001P2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP03
0:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP<0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP203oon000`000000003o00000003000000040:gHiP0cXLX0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gH
iP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0T0oooP00<000000000o`000?l00`0000000`0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0:0?ooh00303>QbP000000003o00<0000000L0[MSV
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0<0?ooh003000000000?l0003o0080000000H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP3@3oon02000000030000o`00000000000080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh0h0oooP0P0000020000o`80000000<0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX0
1P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0l0oooP0`00
00000`000?l0000000000002000000<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX3
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0A0?ooh08000000P000?l300000080[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0B0?ooh0<00000
00<0003o0000000000000P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gH
iP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh1D0oooP00@000000000o`000?l0[MSV0P0000020:gHiP0303>QbP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1H0oooP00<0<j7:0:gHiP000?l0
0`000000102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80
<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0F0?oo
h080<j7:00<000000000o`000?l00P0000000`0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV
0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0I0?ooh080000000D0003o000000000000000003>QbP020:gHiP0303>QbP2]
f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`00003o0?ooh1X0oooP0P0000020000o`8000000P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0070?oo
h0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0K0?ooh0<0
000000D0003o0000002]f>H0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP04
03>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7@3oon02000000040000o`000000
000003>QbP@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0O0?ooh004000000000?l0003o000000@0[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80
<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0O0?oo
h0<0000000<0003o0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh200oooP0P0000001P0cXLX0003o00000000
0000[MSV03>QbP<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:
00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh280oooP00H0<j7:000000000?l0003o0000000cXLX30:gHiP0303>QbP2]f>H0<j7:00@0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0S0?ooh0<0000000<0003o000000000000
0P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>Q
bP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0
[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H2
03>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP903o
on03000000070000o`00000000000:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP9P3oon0200000080003o0P0cXLX00`2]f>H0<j7:0:gHiP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP9`3oon02000000050?ooh0000?l0<j7:0:gHiP0cXLX0
102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2/0oooP00<0003o000000000000102]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2/0oooP00@000000000o`000?l00000100c
XLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP03
03>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gH
iP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh2/0oooP0`0000001@000?l0oooP0?ooh03oon00<j7:00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP0c
XLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0/
0?ooh080000000D0oooP0000o`3oon00oooP03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<03oon020000o`0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0
[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP<P3oon001@000?l0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0c
XLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380
oooP00D0<j7:0000o`000000000003>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0b0?ooh00303>QbP000000003o00800000
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0c
XLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP<P3oon000`0cXLX00000000000020000o`80[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3@0oooP0P000000100cXLX0
003o0000000cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV03>QbP03
0:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0f0?ooh080000000D0003o0000002]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP=P3oon0300000080003o00<0[MSV03>QbP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP0P000000100cXLX0[MSV
0000o`0000030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
2P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV
0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0c
XLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>Q
bP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>@3oon00
100cXLX00000000000000?l2000000030:gHiP0cXLX0[MSV00<0[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP>P3oon03000000040000o`000000000003>QbP@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>Q
bP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0
[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H2
03>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>`3o
on0300000080003o00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:
00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0m0?ooh080
000000<0oooP0000o`2]f>H00`2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:0`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon100?ooh00803>QbP000?l0
00000000002]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh400oooP00<0<j7:000000000?l00P0000000`0cXLX0[MSV03>QbP03
0:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00L0
oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh400oooP
00P0<j7:000000000000003o0000000cXLX0[MSV03>QbP<0[MSV0P0cXLX30:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh480oooP0P00000010000?l00000
0000000cXLX30:gHiP80<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon140?ooh004000000000?l0003o000000<0[MSV0P0cXLX30:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4@0oooP0`00000010000?l0
00000000002]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX3
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPA@3oon03000000030000o`00000000000080<j7:0`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon170?ooh080000000@0003o0000000c
XLX0<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP03
0:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on180?ooh080000000<0003o0000000000000`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1:0?ooh004000000000?l0000000000080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPBP3oon02000000050000o`00
000000000:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1;0?ooh0800000
00@0003o000000000000<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:
00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1<0?ooh080
000000<0003o0000000cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:
00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0
oooPC@3oon0200000080003o00@000000:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh006
0?ooh0030000003oon00oooP0?l0oooPC`3oon02000000040000o`000000<j7:03>QbP80[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP
00<000000?ooh03oon001P3oon0400000?l0oooPCP3oon03000000030000o`3oon00<j7:0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP0303>QbP3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000
oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPD03oon02000000030?ooh0000?l0<j7:0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX3
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh5@0oooP00@0003o0:gH
iP00000000000`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0
[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?oo
h0800000203oon000`000000oooP0?ooh03o0?ooh5@0oooP00<0<j7:0000o`0000000P0000020:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1D0?ooh00303>QbP000000003o008000000P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPEP3oon000`000000003o
0:gHiP020000000403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H0
2@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1G0?ooh00303>QbP000?l00000008000000P2]f>H02P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF03oon000`000000003o0000
o`020000000;0:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh5T0oooP0P00000010000?l0000003>QbP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPFP3oon02000000030000o`3oon00<j7:0080[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1M0?ooh00;0000o`0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5h0oooP00X0003o0:gHiP00
000000000:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5h0oooP00<0<j7:0000o`00
00000P0000001@0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1N0?ooh00303>QbP000000
003o00<0000000@0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPH03oon000`000000003o000000020000000303>Q
bP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh640oooP00<000000000o`0000000P0000000`2]f>H0<j7:0:gHiP020:gHiP03
03>QbP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0c
XLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPHP3oon000`000000003o0000o`020000000503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0
2@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1S0?ooh080000000<0
003o0000000000000`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gH
iP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6@0oooP0P0000000`000?l000000:gHiP020:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPI@3oon02000000050000o`00000000000:gHiP0cXLX0102]f>H02@0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh005000000000?l000000000000cXLX0102]
f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh0800000
00<0003o0000000cXLX0102]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1X0?ooh080000000<0003o03>QbP2]f>H00`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX3
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1[0?ooh0030000o`00000000000080[MSV00T0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP04
03>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ`3oon0010000000003o00000000
000203>QbP<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1[0?ooh080000000@0003o
0000003oon00<j7:0`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6`0oooP0P000000
0`000?l0oooP03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP06
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK`3oon000`00
0?l0<j7:0:gHiP020:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL03oon002@000?l0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh700oooP00<0<j7:0000o`000?l00P000000102]
f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh700oooP0P0cXLX01`000000003o000000000000<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPLP3oon02000000050000o`00000000000:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL`3oon02000000040000
o`000000000003>QbP<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP08
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX3
0:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh7@0oooP0P0000000`000?l00000000000030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80
<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1e0?oo
h080000000<0003o0000002]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00P0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPMP3oon02000000050000o`00000000000:gHiP0c
XLX0102]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX0
1P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7P0oooP00D0
00000000o`000000000003>QbP040:gHiP0303>QbP2]f>H0<j7:00<0[MSV00P0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPN03oon02000000030000o`000000<j7:00@0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H0
200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1i0?ooh080000000<0003o03>QbP2]f>H00`2]f>H00`0cXLX0
[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP00<0003o0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP00<0<j7:0000
o`2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0c
XLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP
00<0<j7:0:gHiP000?l00P0000000`0cXLX0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7`0oooP00@0<j7:0:gHiP000000003o0P0000000`2]f>H0<j7:0:gHiP020:gHiP0803>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP09
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon030000
0?l0oooPO03oon0203>QbP80000000@0003o0000002]f>H0<j7:0`2]f>H0200cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP
00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7l0
oooP0P0000000`000?l0[MSV03>QbP030:gHiP0803>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX0
1P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh840oooP00@0
<j7:0000o`00000000000P2]f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon210?ooh00303>QbP000000
003o0080000000T0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon220?ooh080000000@0003o00000000
0000<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPP`3oon02000000030000o`00000000000080[MSV00D0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh8@0oooP0P0000002@000?l000000:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8D0oooP0P0000002000
0?l000000000000cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon270?ooh008000000000?l000000000002]f>H0<j7:0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8L0oooP0P000000
1P000?l000000000000cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPR03oon02000000050000o`00000000000:gHiP0cXLX00P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon290?ooh080000000@0003o0000002]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80
<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2:0?oo
h080000000<0003o0000000cXLX00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2;0?ooh080000000D0003o0000002]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon2;0?ooh0<0000000@0003o0000002]f>H0<j7:0`2]f>H00`0cXLX0[MSV03>QbP030:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03o
on001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
S03oon03000000030000o`000000<j7:00<0[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gH
iP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2=
0?ooh0<0000000<0003o03>QbP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8h0
oooP0P000000203oon00003o000000000000[MSV03>QbP2]f>H0<j7:0`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80
<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2A0?oo
h007000000000?l000000000000cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh940oooP00L000000000
o`000000000003>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPTP3oon001P000000003o0?ooh00cXLX0
[MSV03>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0
[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPU03oon0010000?l0<j7:0:gHiP0cXLX30:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9D0
oooP00<0003o0000000000000`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2E0?ooh004000000000?l0000000000080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV00T0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPU@3oon02000000030000o`00000000000080<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9H0oooP0P00000010000?l000000?oo
h00cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP0503>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPU`3oon02000000030000o`000000000000<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX3
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ00oooP100000070?ooh0030000003oon00oooP0?l0oooPV@3oon0010000000003o000000000002
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H2
03>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0030000003oon00oooP00P0oooP00<0
00000?ooh03oon00o`3oon2I0?ooh080000000<0003o0000000cXLX00P0cXLX20:gHiP0403>QbP2]
f>H0[MSV03>QbP<0[MSV00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HA0?ooh0030000003oon00oooP00L0oooP1000003o0?ooh9T0oooP00<000000000o`3o
on000P3oon00100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0
1@0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0
[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon001P3oon04
000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?oo
h03oon00o`3oon2L0?ooh0040000o`3oon00oooP03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP
00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh9d0oooP00<0003o0?ooh00c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon2N
0?ooh0050000o`0cXLX000000000000cXLX00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP03
0:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2O0?ooh0040000o`000000000000000080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP05
03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
W`3oon000`000000003o00000002000000030:gHiP0cXLX0[MSV0080[MSV00T0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPX03oon000`000000003o000000020000000503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H01@0c
XLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV
0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:40
oooP00D000000000o`000000000003>QbP030:gHiP0903>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:80oooP00@00000
0000o`3oon00<j7:0`2]f>H02@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2T0?ooh0030000o`0cXLX0[MSV0080[MSV
00T0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPY@3oon001@000?l0[MSV0:gHiP2]f>H0<j7:00<0[MSV00D0<j7:0:gH
iP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:
00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2U0?ooh005
03>QbP000?l0[MSV0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP00D0<j7:0:gHiP000?l0[MSV03>QbP030:gH
iP0503>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPY@3oon00100cXLX0[MSV0:gHiP000?l200000080[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh:D0oooP0`0cXLX02P000000003o000000000000[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gH
iP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00L0oooP0`00
000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:P0oooP0P000000
20000?l000000000000cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPZ@3oon002@000000003o000000000000<j7:0:gHiP0cXLX0[MSV03>QbP030:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Z0?ooh008000000000?l000000000002]
f>H0<j7:0:gHiP0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:
00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2[0?ooh007
000000000?l000000000000cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2[0?ooh080000000D0003o0000000cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2/0?ooh080000000@0003o03>QbP2]f>H0<j7:0`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP[`3oon000`000?l00000000000030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX3
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2_0?ooh004000000000?l0000000000080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:l0oooP0P0000001@000?l000000:gHiP2]f>H0<j7:
00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX30:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2`0?ooh080000000@0003o0:gHiP2]f>H0<j7:0`2]f>H01P0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh;40oooP00<0<j7:0:gHiP000?l00P0000030:gHiP0603>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
/@3oon00100cXLX0[MSV000000000?l200000080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX3
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh080<j7:
0P0000001@000?l000000000002]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2d0?ooh080000000@0003o0000000cXLX0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP
00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;D0
oooP0P0000000`000?l0oooP03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;L0oooP00<0003o0?ooh00cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2h0?ooh0070000o`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh0060000o`2]f>H0[MSV03>QbP2]f>H0
<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H203>Q
bP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^@3oon00
1P0cXLX0003o0:gHiP0cXLX0[MSV03>QbP<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh;T0oooP00H0<j7:0:gHiP000?l000000:gHiP0cXLX30:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh00603>QbP00000000000000
o`000000<j7:0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
^P3oon02000000030000o`000000000000<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:00<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh;/0oooP0P0000000`000?l00000000000020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2l0?ooh080000000D0003o000000000000[MSV
03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP060:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_@3oon02000000040000o`000000
<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n0?ooh080000000<0003o0?oo
h00cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX01P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<40oooP00<0003o03>QbP2]f>H0
0P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<40oooP00<0003o03>QbP2]f>H00P2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon0300000?l0oooP`P3oon001@000?l0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?oo
h0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon32
0?ooh00503>QbP000?l0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon320?ooh00303>Q
bP2]f>H0003o008000000P2]f>H00`0cXLX0[MSV03>QbP030:gHiP80<j7:00H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon320?ooh00403>QbP2]f>H000000000
o`80000000@0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP`P3oon0203>QbP80000000H0003o000000000000<j7:
0:gHiP0cXLX30:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon350?ooh003000000000?l000000080000000<0[MSV03>QbP2]f>H00P2]f>H203>Q
bP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPaP3oon00
1P000000003o000000000000[MSV03>QbP<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh<L0oooP00D000000000o`0cXLX0[MSV03>QbP030:gH
iP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon39
0?ooh0030000o`000000000000<0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<T0oooP00@000000000o`00000000000P2]f>H203>QbP060:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb@3oon0200000004
0000o`00000000000:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon3:0?ooh003000000000?l00000008000000P0cXLX01P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh</0oooP00@000000000o`0000000000
0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<`0
oooP00<000000000o`3oon000P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon030000
0?l0oooPcP3oon002@000?l000000000002]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>Q
bP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh<h0oooP00T000000000o`000000000003>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPcP3oon02000000070000o`000000<j7:0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon3?0?ooh080000000H0003o0000002]f>H0<j7:0:gHiP0c
XLX30:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3@0?ooh007000000000?l000000000000cXLX0[MSV
03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3@0?ooh080000000D0003o000000000000[MSV
03>QbP030:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3A0?ooh080000000@0003o0000002]f>H0<j7:
0`2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPdP3oon02000000030000o`2]f>H0<j7:00<0[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh=@0oooP00@0<j7:0000o`00000000000P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPe03oon000`0cXLX000000000o`02000000030:gHiP0cXLX0oooP00X0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3D0?oo
h00703>QbP00000000000000o`000000[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe@3oon02000000040000o`000000
<j7:03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P000008
0?ooh0030000003oon00oooP0?l0oooPeP3oon02000000030000o`3oon00oooP00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon00
0`000000oooP0?ooh03o0?ooh=T0oooP00<0003o0?ooh03oon002P3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon3I0?oo
h0030000o`3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4`3oon000`000000
oooP0?ooh0050?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0
oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP
00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP0740oooP00<00000
0?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<00000
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
o`00003Z000001P0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003L0?[`iP@000000P3jl>H800000080n_3V100000001`3jl>H00000000000000000n_3V0000
003jl>H0300000000`3jl>H0000000000004000000040?[`iP0000000000000000P0n_3V1@000004
0?[`iPL0000000<0n_3V0000003jl>H00`0000090?[`iPD000000P3jl>H400000080n_3V1@00000B
0?[`iPH000001P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V0000000000000000i03j
l>H10?ooo`00g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H2000000<0n_3V00L00000
0?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000002@3jl>H010000000n_3V0?[`iP3jl>H200000080
n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V
00D0n_3V0P0000000`3jl>H000000000003U0?[`iP40oooo003M0?[`iP80000000<0n_3V00000000
0000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP80
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP80
00000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP800000303jl>H5000000D0n_3V0P0000060?[`
iPD000001P3jl>H300000>H0n_3V0@3oool00=d0n_3V1@0000040?[`iP8000000`3jl>H600000006
0?[`iP00000000000?[`iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V0P000000
103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P00
00020?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00
003V0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2
000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`
iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H04P3jl>H2000000P0n_3V00<000000?[`iP3j
l>H01@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000
00<0n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@00000
0P3jl>H500000080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L00000
2`3jl>H500000080n_3V100000020?[`iP<0000000<0n_3V0000000000004`3jl>H2000000l0n_3V
0`0000001@3jl>H00000000000000000n_3V00@00000g`3jl>H10?ooo`00g@3jl>H200000080n_3V
0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0H0?[`iP8000008@3jl>H4000001P0n_3V
00<000000?[`iP3jl>H0g`3jl>H10?ooo`00g03jl>H6000000@0n_3V0P00000_0?[`iPD000006`3j
l>H300000240n_3V0P00000I0?[`iP030000003jl>H0n_3V0=h0n_3V0@3oool00?l0n_3VN03jl>H0
0`000000n_3V0?[`iP3M0?[`iP40oooo003o0?[`iWD0n_3V00@000000?[`iP3jl>H00000g`3jl>H1
0?ooo`00o`3jl>If0?[`iP800000h03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02806 .01472 L
.02806 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02806 .01472 L
.02806 .16187 L
s
1 .894 .882 r
.02806 .16187 m
.02806 .01474 L
.03273 .01474 L
.03273 .16187 L
F
.804 .522 .247 r
.02806 .16187 m
.02806 .01474 L
.03273 .01474 L
.03273 .16187 L
s
1 .894 .882 r
.03273 .16187 m
.03273 .01481 L
.03926 .01481 L
.03926 .16187 L
F
.804 .522 .247 r
.03273 .16187 m
.03273 .01481 L
.03926 .01481 L
.03926 .16187 L
s
1 .894 .882 r
.03926 .16187 m
.03926 .01492 L
.04216 .01492 L
.04216 .16187 L
F
.804 .522 .247 r
.03926 .16187 m
.03926 .01492 L
.04216 .01492 L
.04216 .16187 L
s
1 .894 .882 r
.04216 .16187 m
.04216 .01512 L
.04935 .01512 L
.04935 .16187 L
F
.804 .522 .247 r
.04216 .16187 m
.04216 .01512 L
.04935 .01512 L
.04935 .16187 L
s
1 .894 .882 r
.04935 .16187 m
.04935 .01526 L
.05336 .01526 L
.05336 .16187 L
F
.804 .522 .247 r
.04935 .16187 m
.04935 .01526 L
.05336 .01526 L
.05336 .16187 L
s
1 .894 .882 r
.05336 .16187 m
.05336 .01545 L
.06008 .01545 L
.06008 .16187 L
F
.804 .522 .247 r
.05336 .16187 m
.05336 .01545 L
.06008 .01545 L
.06008 .16187 L
s
1 .894 .882 r
.06008 .16187 m
.06008 .01566 L
.06642 .01566 L
.06642 .16187 L
F
.804 .522 .247 r
.06008 .16187 m
.06008 .01566 L
.06642 .01566 L
.06642 .16187 L
s
1 .894 .882 r
.06642 .16187 m
.06642 .01618 L
.07296 .01618 L
.07296 .16187 L
F
.804 .522 .247 r
.06642 .16187 m
.06642 .01618 L
.07296 .01618 L
.07296 .16187 L
s
1 .894 .882 r
.07296 .16187 m
.07296 .01637 L
.07713 .01637 L
.07713 .16187 L
F
.804 .522 .247 r
.07296 .16187 m
.07296 .01637 L
.07713 .01637 L
.07713 .16187 L
s
1 .894 .882 r
.07713 .16187 m
.07713 .01673 L
.07964 .01673 L
.07964 .16187 L
F
.804 .522 .247 r
.07713 .16187 m
.07713 .01673 L
.07964 .01673 L
.07964 .16187 L
s
1 .894 .882 r
.07964 .16187 m
.07964 .01675 L
.08588 .01675 L
.08588 .16187 L
F
.804 .522 .247 r
.07964 .16187 m
.07964 .01675 L
.08588 .01675 L
.08588 .16187 L
s
1 .894 .882 r
.08588 .16187 m
.08588 .0174 L
.08816 .0174 L
.08816 .16187 L
F
.804 .522 .247 r
.08588 .16187 m
.08588 .0174 L
.08816 .0174 L
.08816 .16187 L
s
1 .894 .882 r
.08816 .16187 m
.08816 .01753 L
.09094 .01753 L
.09094 .16187 L
F
.804 .522 .247 r
.08816 .16187 m
.08816 .01753 L
.09094 .01753 L
.09094 .16187 L
s
1 .894 .882 r
.09094 .16187 m
.09094 .01794 L
.09756 .01794 L
.09756 .16187 L
F
.804 .522 .247 r
.09094 .16187 m
.09094 .01794 L
.09756 .01794 L
.09756 .16187 L
s
1 .894 .882 r
.09756 .16187 m
.09756 .0183 L
.10432 .0183 L
.10432 .16187 L
F
.804 .522 .247 r
.09756 .16187 m
.09756 .0183 L
.10432 .0183 L
.10432 .16187 L
s
1 .894 .882 r
.10432 .16187 m
.10432 .01926 L
.10975 .01926 L
.10975 .16187 L
F
.804 .522 .247 r
.10432 .16187 m
.10432 .01926 L
.10975 .01926 L
.10975 .16187 L
s
1 .894 .882 r
.10975 .16187 m
.10975 .01993 L
.11455 .01993 L
.11455 .16187 L
F
.804 .522 .247 r
.10975 .16187 m
.10975 .01993 L
.11455 .01993 L
.11455 .16187 L
s
1 .894 .882 r
.11455 .16187 m
.11455 .02055 L
.1198 .02055 L
.1198 .16187 L
F
.804 .522 .247 r
.11455 .16187 m
.11455 .02055 L
.1198 .02055 L
.1198 .16187 L
s
1 .894 .882 r
.1198 .16187 m
.1198 .02099 L
.12451 .02099 L
.12451 .16187 L
F
.804 .522 .247 r
.1198 .16187 m
.1198 .02099 L
.12451 .02099 L
.12451 .16187 L
s
1 .894 .882 r
.12451 .16187 m
.12451 .0213 L
.13134 .0213 L
.13134 .16187 L
F
.804 .522 .247 r
.12451 .16187 m
.12451 .0213 L
.13134 .0213 L
.13134 .16187 L
s
1 .894 .882 r
.13134 .16187 m
.13134 .02255 L
.1349 .02255 L
.1349 .16187 L
F
.804 .522 .247 r
.13134 .16187 m
.13134 .02255 L
.1349 .02255 L
.1349 .16187 L
s
1 .894 .882 r
.1349 .16187 m
.1349 .02286 L
.14077 .02286 L
.14077 .16187 L
F
.804 .522 .247 r
.1349 .16187 m
.1349 .02286 L
.14077 .02286 L
.14077 .16187 L
s
1 .894 .882 r
.14077 .16187 m
.14077 .02411 L
.14451 .02411 L
.14451 .16187 L
F
.804 .522 .247 r
.14077 .16187 m
.14077 .02411 L
.14451 .02411 L
.14451 .16187 L
s
1 .894 .882 r
.14451 .16187 m
.14451 .02451 L
.14931 .02451 L
.14931 .16187 L
F
.804 .522 .247 r
.14451 .16187 m
.14451 .02451 L
.14931 .02451 L
.14931 .16187 L
s
1 .894 .882 r
.14931 .16187 m
.14931 .0253 L
.15561 .0253 L
.15561 .16187 L
F
.804 .522 .247 r
.14931 .16187 m
.14931 .0253 L
.15561 .0253 L
.15561 .16187 L
s
1 .894 .882 r
.15561 .16187 m
.15561 .02681 L
.16235 .02681 L
.16235 .16187 L
F
.804 .522 .247 r
.15561 .16187 m
.15561 .02681 L
.16235 .02681 L
.16235 .16187 L
s
1 .894 .882 r
.16235 .16187 m
.16235 .02725 L
.16541 .02725 L
.16541 .16187 L
F
.804 .522 .247 r
.16235 .16187 m
.16235 .02725 L
.16541 .02725 L
.16541 .16187 L
s
1 .894 .882 r
.16541 .16187 m
.16541 .02822 L
.17043 .02822 L
.17043 .16187 L
F
.804 .522 .247 r
.16541 .16187 m
.16541 .02822 L
.17043 .02822 L
.17043 .16187 L
s
1 .894 .882 r
.17043 .16187 m
.17043 .02909 L
.17493 .02909 L
.17493 .16187 L
F
.804 .522 .247 r
.17043 .16187 m
.17043 .02909 L
.17493 .02909 L
.17493 .16187 L
s
1 .894 .882 r
.17493 .16187 m
.17493 .02958 L
.17716 .02958 L
.17716 .16187 L
F
.804 .522 .247 r
.17493 .16187 m
.17493 .02958 L
.17716 .02958 L
.17716 .16187 L
s
1 .894 .882 r
.17716 .16187 m
.17716 .03067 L
.18129 .03067 L
.18129 .16187 L
F
.804 .522 .247 r
.17716 .16187 m
.17716 .03067 L
.18129 .03067 L
.18129 .16187 L
s
1 .894 .882 r
.18129 .16187 m
.18129 .03175 L
.18716 .03175 L
.18716 .16187 L
F
.804 .522 .247 r
.18129 .16187 m
.18129 .03175 L
.18716 .03175 L
.18716 .16187 L
s
1 .894 .882 r
.18716 .16187 m
.18716 .03212 L
.18972 .03212 L
.18972 .16187 L
F
.804 .522 .247 r
.18716 .16187 m
.18716 .03212 L
.18972 .03212 L
.18972 .16187 L
s
1 .894 .882 r
.18972 .16187 m
.18972 .03283 L
.19684 .03283 L
.19684 .16187 L
F
.804 .522 .247 r
.18972 .16187 m
.18972 .03283 L
.19684 .03283 L
.19684 .16187 L
s
1 .894 .882 r
.19684 .16187 m
.19684 .03511 L
.20213 .03511 L
.20213 .16187 L
F
.804 .522 .247 r
.19684 .16187 m
.19684 .03511 L
.20213 .03511 L
.20213 .16187 L
s
1 .894 .882 r
.20213 .16187 m
.20213 .03641 L
.20794 .03641 L
.20794 .16187 L
F
.804 .522 .247 r
.20213 .16187 m
.20213 .03641 L
.20794 .03641 L
.20794 .16187 L
s
1 .894 .882 r
.20794 .16187 m
.20794 .03779 L
.21512 .03779 L
.21512 .16187 L
F
.804 .522 .247 r
.20794 .16187 m
.20794 .03779 L
.21512 .03779 L
.21512 .16187 L
s
1 .894 .882 r
.21512 .16187 m
.21512 .03891 L
.21784 .03891 L
.21784 .16187 L
F
.804 .522 .247 r
.21512 .16187 m
.21512 .03891 L
.21784 .03891 L
.21784 .16187 L
s
1 .894 .882 r
.21784 .16187 m
.21784 .04023 L
.22377 .04023 L
.22377 .16187 L
F
.804 .522 .247 r
.21784 .16187 m
.21784 .04023 L
.22377 .04023 L
.22377 .16187 L
s
1 .894 .882 r
.22377 .16187 m
.22377 .0408 L
.22637 .0408 L
.22637 .16187 L
F
.804 .522 .247 r
.22377 .16187 m
.22377 .0408 L
.22637 .0408 L
.22637 .16187 L
s
1 .894 .882 r
.22637 .16187 m
.22637 .04237 L
.23097 .04237 L
.23097 .16187 L
F
.804 .522 .247 r
.22637 .16187 m
.22637 .04237 L
.23097 .04237 L
.23097 .16187 L
s
1 .894 .882 r
.23097 .16187 m
.23097 .04372 L
.23584 .04372 L
.23584 .16187 L
F
.804 .522 .247 r
.23097 .16187 m
.23097 .04372 L
.23584 .04372 L
.23584 .16187 L
s
1 .894 .882 r
.23584 .16187 m
.23584 .0441 L
.23928 .0441 L
.23928 .16187 L
F
.804 .522 .247 r
.23584 .16187 m
.23584 .0441 L
.23928 .0441 L
.23928 .16187 L
s
1 .894 .882 r
.23928 .16187 m
.23928 .04502 L
.24245 .04502 L
.24245 .16187 L
F
.804 .522 .247 r
.23928 .16187 m
.23928 .04502 L
.24245 .04502 L
.24245 .16187 L
s
1 .894 .882 r
.24245 .16187 m
.24245 .04591 L
.2457 .04591 L
.2457 .16187 L
F
.804 .522 .247 r
.24245 .16187 m
.24245 .04591 L
.2457 .04591 L
.2457 .16187 L
s
1 .894 .882 r
.2457 .16187 m
.2457 .048 L
.25211 .048 L
.25211 .16187 L
F
.804 .522 .247 r
.2457 .16187 m
.2457 .048 L
.25211 .048 L
.25211 .16187 L
s
1 .894 .882 r
.25211 .16187 m
.25211 .04923 L
.25921 .04923 L
.25921 .16187 L
F
.804 .522 .247 r
.25211 .16187 m
.25211 .04923 L
.25921 .04923 L
.25921 .16187 L
s
1 .894 .882 r
.25921 .16187 m
.25921 .052 L
.26497 .052 L
.26497 .16187 L
F
.804 .522 .247 r
.25921 .16187 m
.25921 .052 L
.26497 .052 L
.26497 .16187 L
s
1 .894 .882 r
.26497 .16187 m
.26497 .05361 L
.26933 .05361 L
.26933 .16187 L
F
.804 .522 .247 r
.26497 .16187 m
.26497 .05361 L
.26933 .05361 L
.26933 .16187 L
s
1 .894 .882 r
.26933 .16187 m
.26933 .05387 L
.2764 .05387 L
.2764 .16187 L
F
.804 .522 .247 r
.26933 .16187 m
.26933 .05387 L
.2764 .05387 L
.2764 .16187 L
s
1 .894 .882 r
.2764 .16187 m
.2764 .05649 L
.28265 .05649 L
.28265 .16187 L
F
.804 .522 .247 r
.2764 .16187 m
.2764 .05649 L
.28265 .05649 L
.28265 .16187 L
s
1 .894 .882 r
.28265 .16187 m
.28265 .05841 L
.28563 .05841 L
.28563 .16187 L
F
.804 .522 .247 r
.28265 .16187 m
.28265 .05841 L
.28563 .05841 L
.28563 .16187 L
s
1 .894 .882 r
.28563 .16187 m
.28563 .06004 L
.29288 .06004 L
.29288 .16187 L
F
.804 .522 .247 r
.28563 .16187 m
.28563 .06004 L
.29288 .06004 L
.29288 .16187 L
s
1 .894 .882 r
.29288 .16187 m
.29288 .06399 L
.29994 .06399 L
.29994 .16187 L
F
.804 .522 .247 r
.29288 .16187 m
.29288 .06399 L
.29994 .06399 L
.29994 .16187 L
s
1 .894 .882 r
.29994 .16187 m
.29994 .06473 L
.30428 .06473 L
.30428 .16187 L
F
.804 .522 .247 r
.29994 .16187 m
.29994 .06473 L
.30428 .06473 L
.30428 .16187 L
s
1 .894 .882 r
.30428 .16187 m
.30428 .0665 L
.30879 .0665 L
.30879 .16187 L
F
.804 .522 .247 r
.30428 .16187 m
.30428 .0665 L
.30879 .0665 L
.30879 .16187 L
s
1 .894 .882 r
.30879 .16187 m
.30879 .06786 L
.31571 .06786 L
.31571 .16187 L
F
.804 .522 .247 r
.30879 .16187 m
.30879 .06786 L
.31571 .06786 L
.31571 .16187 L
s
1 .894 .882 r
.31571 .16187 m
.31571 .07211 L
.32304 .07211 L
.32304 .16187 L
F
.804 .522 .247 r
.31571 .16187 m
.31571 .07211 L
.32304 .07211 L
.32304 .16187 L
s
1 .894 .882 r
.32304 .16187 m
.32304 .0742 L
.32949 .0742 L
.32949 .16187 L
F
.804 .522 .247 r
.32304 .16187 m
.32304 .0742 L
.32949 .0742 L
.32949 .16187 L
s
1 .894 .882 r
.32949 .16187 m
.32949 .07698 L
.33558 .07698 L
.33558 .16187 L
F
.804 .522 .247 r
.32949 .16187 m
.32949 .07698 L
.33558 .07698 L
.33558 .16187 L
s
1 .894 .882 r
.33558 .16187 m
.33558 .07941 L
.34273 .07941 L
.34273 .16187 L
F
.804 .522 .247 r
.33558 .16187 m
.33558 .07941 L
.34273 .07941 L
.34273 .16187 L
s
1 .894 .882 r
.34273 .16187 m
.34273 .081 L
.34956 .081 L
.34956 .16187 L
F
.804 .522 .247 r
.34273 .16187 m
.34273 .081 L
.34956 .081 L
.34956 .16187 L
s
1 .894 .882 r
.34956 .16187 m
.34956 .08454 L
.3523 .08454 L
.3523 .16187 L
F
.804 .522 .247 r
.34956 .16187 m
.34956 .08454 L
.3523 .08454 L
.3523 .16187 L
s
1 .894 .882 r
.3523 .16187 m
.3523 .08589 L
.35802 .08589 L
.35802 .16187 L
F
.804 .522 .247 r
.3523 .16187 m
.3523 .08589 L
.35802 .08589 L
.35802 .16187 L
s
1 .894 .882 r
.35802 .16187 m
.35802 .08868 L
.36278 .08868 L
.36278 .16187 L
F
.804 .522 .247 r
.35802 .16187 m
.35802 .08868 L
.36278 .08868 L
.36278 .16187 L
s
1 .894 .882 r
.36278 .16187 m
.36278 .08969 L
.36696 .08969 L
.36696 .16187 L
F
.804 .522 .247 r
.36278 .16187 m
.36278 .08969 L
.36696 .08969 L
.36696 .16187 L
s
1 .894 .882 r
.36696 .16187 m
.36696 .09295 L
.37367 .09295 L
.37367 .16187 L
F
.804 .522 .247 r
.36696 .16187 m
.36696 .09295 L
.37367 .09295 L
.37367 .16187 L
s
1 .894 .882 r
.37367 .16187 m
.37367 .09474 L
.37843 .09474 L
.37843 .16187 L
F
.804 .522 .247 r
.37367 .16187 m
.37367 .09474 L
.37843 .09474 L
.37843 .16187 L
s
1 .894 .882 r
.37843 .16187 m
.37843 .09723 L
.38216 .09723 L
.38216 .16187 L
F
.804 .522 .247 r
.37843 .16187 m
.37843 .09723 L
.38216 .09723 L
.38216 .16187 L
s
1 .894 .882 r
.38216 .16187 m
.38216 .09928 L
.38734 .09928 L
.38734 .16187 L
F
.804 .522 .247 r
.38216 .16187 m
.38216 .09928 L
.38734 .09928 L
.38734 .16187 L
s
1 .894 .882 r
.38734 .16187 m
.38734 .10139 L
.39434 .10139 L
.39434 .16187 L
F
.804 .522 .247 r
.38734 .16187 m
.38734 .10139 L
.39434 .10139 L
.39434 .16187 L
s
1 .894 .882 r
.39434 .16187 m
.39434 .10545 L
.40074 .10545 L
.40074 .16187 L
F
.804 .522 .247 r
.39434 .16187 m
.39434 .10545 L
.40074 .10545 L
.40074 .16187 L
s
1 .894 .882 r
.40074 .16187 m
.40074 .10922 L
.40752 .10922 L
.40752 .16187 L
F
.804 .522 .247 r
.40074 .16187 m
.40074 .10922 L
.40752 .10922 L
.40752 .16187 L
s
1 .894 .882 r
.40752 .16187 m
.40752 .11162 L
.41302 .11162 L
.41302 .16187 L
F
.804 .522 .247 r
.40752 .16187 m
.40752 .11162 L
.41302 .11162 L
.41302 .16187 L
s
1 .894 .882 r
.41302 .16187 m
.41302 .11316 L
.41599 .11316 L
.41599 .16187 L
F
.804 .522 .247 r
.41302 .16187 m
.41302 .11316 L
.41599 .11316 L
.41599 .16187 L
s
1 .894 .882 r
.41599 .16187 m
.41599 .11542 L
.42163 .11542 L
.42163 .16187 L
F
.804 .522 .247 r
.41599 .16187 m
.41599 .11542 L
.42163 .11542 L
.42163 .16187 L
s
1 .894 .882 r
.42163 .16187 m
.42163 .11868 L
.42856 .11868 L
.42856 .16187 L
F
.804 .522 .247 r
.42163 .16187 m
.42163 .11868 L
.42856 .11868 L
.42856 .16187 L
s
1 .894 .882 r
.42856 .16187 m
.42856 .1228 L
.43441 .1228 L
.43441 .16187 L
F
.804 .522 .247 r
.42856 .16187 m
.42856 .1228 L
.43441 .1228 L
.43441 .16187 L
s
1 .894 .882 r
.43441 .16187 m
.43441 .12654 L
.44044 .12654 L
.44044 .16187 L
F
.804 .522 .247 r
.43441 .16187 m
.43441 .12654 L
.44044 .12654 L
.44044 .16187 L
s
1 .894 .882 r
.44044 .16187 m
.44044 .12893 L
.44379 .12893 L
.44379 .16187 L
F
.804 .522 .247 r
.44044 .16187 m
.44044 .12893 L
.44379 .12893 L
.44379 .16187 L
s
1 .894 .882 r
.44379 .16187 m
.44379 .1294 L
.44602 .1294 L
.44602 .16187 L
F
.804 .522 .247 r
.44379 .16187 m
.44379 .1294 L
.44602 .1294 L
.44602 .16187 L
s
1 .894 .882 r
.44602 .16187 m
.44602 .13309 L
.45193 .13309 L
.45193 .16187 L
F
.804 .522 .247 r
.44602 .16187 m
.44602 .13309 L
.45193 .13309 L
.45193 .16187 L
s
1 .894 .882 r
.45193 .16187 m
.45193 .13445 L
.45891 .13445 L
.45891 .16187 L
F
.804 .522 .247 r
.45193 .16187 m
.45193 .13445 L
.45891 .13445 L
.45891 .16187 L
s
1 .894 .882 r
.45891 .16187 m
.45891 .13809 L
.46357 .13809 L
.46357 .16187 L
F
.804 .522 .247 r
.45891 .16187 m
.45891 .13809 L
.46357 .13809 L
.46357 .16187 L
s
1 .894 .882 r
.46357 .16187 m
.46357 .1411 L
.46606 .1411 L
.46606 .16187 L
F
.804 .522 .247 r
.46357 .16187 m
.46357 .1411 L
.46606 .1411 L
.46606 .16187 L
s
1 .894 .882 r
.46606 .16187 m
.46606 .14435 L
.47254 .14435 L
.47254 .16187 L
F
.804 .522 .247 r
.46606 .16187 m
.46606 .14435 L
.47254 .14435 L
.47254 .16187 L
s
1 .894 .882 r
.47254 .16187 m
.47254 .14679 L
.479 .14679 L
.479 .16187 L
F
.804 .522 .247 r
.47254 .16187 m
.47254 .14679 L
.479 .14679 L
.479 .16187 L
s
1 .894 .882 r
.479 .16187 m
.479 .15191 L
.48535 .15191 L
.48535 .16187 L
F
.804 .522 .247 r
.479 .16187 m
.479 .15191 L
.48535 .15191 L
.48535 .16187 L
s
1 .894 .882 r
.48535 .16187 m
.48535 .15576 L
.49046 .15576 L
.49046 .16187 L
F
.804 .522 .247 r
.48535 .16187 m
.48535 .15576 L
.49046 .15576 L
.49046 .16187 L
s
1 .894 .882 r
.49046 .16187 m
.49046 .15741 L
.49499 .15741 L
.49499 .16187 L
F
.804 .522 .247 r
.49046 .16187 m
.49046 .15741 L
.49499 .15741 L
.49499 .16187 L
s
.678 .847 .902 r
.49499 .16187 m
.49499 .16216 L
.50214 .16216 L
.50214 .16187 L
F
.2 .63 .79 r
.49499 .16187 m
.49499 .16216 L
.50214 .16216 L
.50214 .16187 L
s
.678 .847 .902 r
.50214 .16187 m
.50214 .16426 L
.50594 .16426 L
.50594 .16187 L
F
.2 .63 .79 r
.50214 .16187 m
.50214 .16426 L
.50594 .16426 L
.50594 .16187 L
s
.678 .847 .902 r
.50594 .16187 m
.50594 .16643 L
.50954 .16643 L
.50954 .16187 L
F
.2 .63 .79 r
.50594 .16187 m
.50594 .16643 L
.50954 .16643 L
.50954 .16187 L
s
.678 .847 .902 r
.50954 .16187 m
.50954 .17209 L
.5163 .17209 L
.5163 .16187 L
F
.2 .63 .79 r
.50954 .16187 m
.50954 .17209 L
.5163 .17209 L
.5163 .16187 L
s
.678 .847 .902 r
.5163 .16187 m
.5163 .17286 L
.51866 .17286 L
.51866 .16187 L
F
.2 .63 .79 r
.5163 .16187 m
.5163 .17286 L
.51866 .17286 L
.51866 .16187 L
s
.678 .847 .902 r
.51866 .16187 m
.51866 .17648 L
.52347 .17648 L
.52347 .16187 L
F
.2 .63 .79 r
.51866 .16187 m
.51866 .17648 L
.52347 .17648 L
.52347 .16187 L
s
.678 .847 .902 r
.52347 .16187 m
.52347 .17864 L
.5277 .17864 L
.5277 .16187 L
F
.2 .63 .79 r
.52347 .16187 m
.52347 .17864 L
.5277 .17864 L
.5277 .16187 L
s
.678 .847 .902 r
.5277 .16187 m
.5277 .18062 L
.53117 .18062 L
.53117 .16187 L
F
.2 .63 .79 r
.5277 .16187 m
.5277 .18062 L
.53117 .18062 L
.53117 .16187 L
s
.678 .847 .902 r
.53117 .16187 m
.53117 .18354 L
.53796 .18354 L
.53796 .16187 L
F
.2 .63 .79 r
.53117 .16187 m
.53117 .18354 L
.53796 .18354 L
.53796 .16187 L
s
.678 .847 .902 r
.53796 .16187 m
.53796 .18895 L
.54453 .18895 L
.54453 .16187 L
F
.2 .63 .79 r
.53796 .16187 m
.53796 .18895 L
.54453 .18895 L
.54453 .16187 L
s
.678 .847 .902 r
.54453 .16187 m
.54453 .19176 L
.54923 .19176 L
.54923 .16187 L
F
.2 .63 .79 r
.54453 .16187 m
.54453 .19176 L
.54923 .19176 L
.54923 .16187 L
s
.678 .847 .902 r
.54923 .16187 m
.54923 .19705 L
.55426 .19705 L
.55426 .16187 L
F
.2 .63 .79 r
.54923 .16187 m
.54923 .19705 L
.55426 .19705 L
.55426 .16187 L
s
.678 .847 .902 r
.55426 .16187 m
.55426 .19863 L
.55723 .19863 L
.55723 .16187 L
F
.2 .63 .79 r
.55426 .16187 m
.55426 .19863 L
.55723 .19863 L
.55723 .16187 L
s
.678 .847 .902 r
.55723 .16187 m
.55723 .20219 L
.56266 .20219 L
.56266 .16187 L
F
.2 .63 .79 r
.55723 .16187 m
.55723 .20219 L
.56266 .20219 L
.56266 .16187 L
s
.678 .847 .902 r
.56266 .16187 m
.56266 .20367 L
.56736 .20367 L
.56736 .16187 L
F
.2 .63 .79 r
.56266 .16187 m
.56266 .20367 L
.56736 .20367 L
.56736 .16187 L
s
.678 .847 .902 r
.56736 .16187 m
.56736 .20689 L
.57387 .20689 L
.57387 .16187 L
F
.2 .63 .79 r
.56736 .16187 m
.56736 .20689 L
.57387 .20689 L
.57387 .16187 L
s
.678 .847 .902 r
.57387 .16187 m
.57387 .21214 L
.57726 .21214 L
.57726 .16187 L
F
.2 .63 .79 r
.57387 .16187 m
.57387 .21214 L
.57726 .21214 L
.57726 .16187 L
s
.678 .847 .902 r
.57726 .16187 m
.57726 .21468 L
.58026 .21468 L
.58026 .16187 L
F
.2 .63 .79 r
.57726 .16187 m
.57726 .21468 L
.58026 .21468 L
.58026 .16187 L
s
.678 .847 .902 r
.58026 .16187 m
.58026 .21737 L
.58469 .21737 L
.58469 .16187 L
F
.2 .63 .79 r
.58026 .16187 m
.58026 .21737 L
.58469 .21737 L
.58469 .16187 L
s
.678 .847 .902 r
.58469 .16187 m
.58469 .21947 L
.58694 .21947 L
.58694 .16187 L
F
.2 .63 .79 r
.58469 .16187 m
.58469 .21947 L
.58694 .21947 L
.58694 .16187 L
s
.678 .847 .902 r
.58694 .16187 m
.58694 .22073 L
.59128 .22073 L
.59128 .16187 L
F
.2 .63 .79 r
.58694 .16187 m
.58694 .22073 L
.59128 .22073 L
.59128 .16187 L
s
.678 .847 .902 r
.59128 .16187 m
.59128 .22615 L
.59533 .22615 L
.59533 .16187 L
F
.2 .63 .79 r
.59128 .16187 m
.59128 .22615 L
.59533 .22615 L
.59533 .16187 L
s
.678 .847 .902 r
.59533 .16187 m
.59533 .2298 L
.60204 .2298 L
.60204 .16187 L
F
.2 .63 .79 r
.59533 .16187 m
.59533 .2298 L
.60204 .2298 L
.60204 .16187 L
s
.678 .847 .902 r
.60204 .16187 m
.60204 .23503 L
.60716 .23503 L
.60716 .16187 L
F
.2 .63 .79 r
.60204 .16187 m
.60204 .23503 L
.60716 .23503 L
.60716 .16187 L
s
.678 .847 .902 r
.60716 .16187 m
.60716 .23661 L
.61175 .23661 L
.61175 .16187 L
F
.2 .63 .79 r
.60716 .16187 m
.60716 .23661 L
.61175 .23661 L
.61175 .16187 L
s
.678 .847 .902 r
.61175 .16187 m
.61175 .23974 L
.61421 .23974 L
.61421 .16187 L
F
.2 .63 .79 r
.61175 .16187 m
.61175 .23974 L
.61421 .23974 L
.61421 .16187 L
s
.678 .847 .902 r
.61421 .16187 m
.61421 .2419 L
.61955 .2419 L
.61955 .16187 L
F
.2 .63 .79 r
.61421 .16187 m
.61421 .2419 L
.61955 .2419 L
.61955 .16187 L
s
.678 .847 .902 r
.61955 .16187 m
.61955 .24893 L
.62531 .24893 L
.62531 .16187 L
F
.2 .63 .79 r
.61955 .16187 m
.61955 .24893 L
.62531 .24893 L
.62531 .16187 L
s
.678 .847 .902 r
.62531 .16187 m
.62531 .25234 L
.62976 .25234 L
.62976 .16187 L
F
.2 .63 .79 r
.62531 .16187 m
.62531 .25234 L
.62976 .25234 L
.62976 .16187 L
s
.678 .847 .902 r
.62976 .16187 m
.62976 .2548 L
.63481 .2548 L
.63481 .16187 L
F
.2 .63 .79 r
.62976 .16187 m
.62976 .2548 L
.63481 .2548 L
.63481 .16187 L
s
.678 .847 .902 r
.63481 .16187 m
.63481 .25842 L
.63814 .25842 L
.63814 .16187 L
F
.2 .63 .79 r
.63481 .16187 m
.63481 .25842 L
.63814 .25842 L
.63814 .16187 L
s
.678 .847 .902 r
.63814 .16187 m
.63814 .26097 L
.64265 .26097 L
.64265 .16187 L
F
.2 .63 .79 r
.63814 .16187 m
.63814 .26097 L
.64265 .26097 L
.64265 .16187 L
s
.678 .847 .902 r
.64265 .16187 m
.64265 .26494 L
.64771 .26494 L
.64771 .16187 L
F
.2 .63 .79 r
.64265 .16187 m
.64265 .26494 L
.64771 .26494 L
.64771 .16187 L
s
.678 .847 .902 r
.64771 .16187 m
.64771 .27135 L
.6536 .27135 L
.6536 .16187 L
F
.2 .63 .79 r
.64771 .16187 m
.64771 .27135 L
.6536 .27135 L
.6536 .16187 L
s
.678 .847 .902 r
.6536 .16187 m
.6536 .27311 L
.65963 .27311 L
.65963 .16187 L
F
.2 .63 .79 r
.6536 .16187 m
.6536 .27311 L
.65963 .27311 L
.65963 .16187 L
s
.678 .847 .902 r
.65963 .16187 m
.65963 .27961 L
.66651 .27961 L
.66651 .16187 L
F
.2 .63 .79 r
.65963 .16187 m
.65963 .27961 L
.66651 .27961 L
.66651 .16187 L
s
.678 .847 .902 r
.66651 .16187 m
.66651 .28554 L
.67082 .28554 L
.67082 .16187 L
F
.2 .63 .79 r
.66651 .16187 m
.66651 .28554 L
.67082 .28554 L
.67082 .16187 L
s
.678 .847 .902 r
.67082 .16187 m
.67082 .28658 L
.67349 .28658 L
.67349 .16187 L
F
.2 .63 .79 r
.67082 .16187 m
.67082 .28658 L
.67349 .28658 L
.67349 .16187 L
s
.678 .847 .902 r
.67349 .16187 m
.67349 .28875 L
.67705 .28875 L
.67705 .16187 L
F
.2 .63 .79 r
.67349 .16187 m
.67349 .28875 L
.67705 .28875 L
.67705 .16187 L
s
.678 .847 .902 r
.67705 .16187 m
.67705 .2924 L
.67963 .2924 L
.67963 .16187 L
F
.2 .63 .79 r
.67705 .16187 m
.67705 .2924 L
.67963 .2924 L
.67963 .16187 L
s
.678 .847 .902 r
.67963 .16187 m
.67963 .2947 L
.68277 .2947 L
.68277 .16187 L
F
.2 .63 .79 r
.67963 .16187 m
.67963 .2947 L
.68277 .2947 L
.68277 .16187 L
s
.678 .847 .902 r
.68277 .16187 m
.68277 .2998 L
.68984 .2998 L
.68984 .16187 L
F
.2 .63 .79 r
.68277 .16187 m
.68277 .2998 L
.68984 .2998 L
.68984 .16187 L
s
.678 .847 .902 r
.68984 .16187 m
.68984 .30544 L
.69637 .30544 L
.69637 .16187 L
F
.2 .63 .79 r
.68984 .16187 m
.68984 .30544 L
.69637 .30544 L
.69637 .16187 L
s
.678 .847 .902 r
.69637 .16187 m
.69637 .31044 L
.69892 .31044 L
.69892 .16187 L
F
.2 .63 .79 r
.69637 .16187 m
.69637 .31044 L
.69892 .31044 L
.69892 .16187 L
s
.678 .847 .902 r
.69892 .16187 m
.69892 .31188 L
.70512 .31188 L
.70512 .16187 L
F
.2 .63 .79 r
.69892 .16187 m
.69892 .31188 L
.70512 .31188 L
.70512 .16187 L
s
.678 .847 .902 r
.70512 .16187 m
.70512 .31928 L
.71037 .31928 L
.71037 .16187 L
F
.2 .63 .79 r
.70512 .16187 m
.70512 .31928 L
.71037 .31928 L
.71037 .16187 L
s
.678 .847 .902 r
.71037 .16187 m
.71037 .32628 L
.71759 .32628 L
.71759 .16187 L
F
.2 .63 .79 r
.71037 .16187 m
.71037 .32628 L
.71759 .32628 L
.71759 .16187 L
s
.678 .847 .902 r
.71759 .16187 m
.71759 .32755 L
.72242 .32755 L
.72242 .16187 L
F
.2 .63 .79 r
.71759 .16187 m
.71759 .32755 L
.72242 .32755 L
.72242 .16187 L
s
.678 .847 .902 r
.72242 .16187 m
.72242 .33474 L
.72625 .33474 L
.72625 .16187 L
F
.2 .63 .79 r
.72242 .16187 m
.72242 .33474 L
.72625 .33474 L
.72625 .16187 L
s
.678 .847 .902 r
.72625 .16187 m
.72625 .33648 L
.73125 .33648 L
.73125 .16187 L
F
.2 .63 .79 r
.72625 .16187 m
.72625 .33648 L
.73125 .33648 L
.73125 .16187 L
s
.678 .847 .902 r
.73125 .16187 m
.73125 .34191 L
.73535 .34191 L
.73535 .16187 L
F
.2 .63 .79 r
.73125 .16187 m
.73125 .34191 L
.73535 .34191 L
.73535 .16187 L
s
.678 .847 .902 r
.73535 .16187 m
.73535 .3447 L
.74182 .3447 L
.74182 .16187 L
F
.2 .63 .79 r
.73535 .16187 m
.73535 .3447 L
.74182 .3447 L
.74182 .16187 L
s
.678 .847 .902 r
.74182 .16187 m
.74182 .35013 L
.74861 .35013 L
.74861 .16187 L
F
.2 .63 .79 r
.74182 .16187 m
.74182 .35013 L
.74861 .35013 L
.74861 .16187 L
s
.678 .847 .902 r
.74861 .16187 m
.74861 .36178 L
.75595 .36178 L
.75595 .16187 L
F
.2 .63 .79 r
.74861 .16187 m
.74861 .36178 L
.75595 .36178 L
.75595 .16187 L
s
.678 .847 .902 r
.75595 .16187 m
.75595 .36284 L
.75895 .36284 L
.75895 .16187 L
F
.2 .63 .79 r
.75595 .16187 m
.75595 .36284 L
.75895 .36284 L
.75895 .16187 L
s
.678 .847 .902 r
.75895 .16187 m
.75895 .36888 L
.76312 .36888 L
.76312 .16187 L
F
.2 .63 .79 r
.75895 .16187 m
.75895 .36888 L
.76312 .36888 L
.76312 .16187 L
s
.678 .847 .902 r
.76312 .16187 m
.76312 .37214 L
.76708 .37214 L
.76708 .16187 L
F
.2 .63 .79 r
.76312 .16187 m
.76312 .37214 L
.76708 .37214 L
.76708 .16187 L
s
.678 .847 .902 r
.76708 .16187 m
.76708 .37337 L
.77075 .37337 L
.77075 .16187 L
F
.2 .63 .79 r
.76708 .16187 m
.76708 .37337 L
.77075 .37337 L
.77075 .16187 L
s
.678 .847 .902 r
.77075 .16187 m
.77075 .38055 L
.77512 .38055 L
.77512 .16187 L
F
.2 .63 .79 r
.77075 .16187 m
.77075 .38055 L
.77512 .38055 L
.77512 .16187 L
s
.678 .847 .902 r
.77512 .16187 m
.77512 .38294 L
.77981 .38294 L
.77981 .16187 L
F
.2 .63 .79 r
.77512 .16187 m
.77512 .38294 L
.77981 .38294 L
.77981 .16187 L
s
.678 .847 .902 r
.77981 .16187 m
.77981 .39218 L
.78686 .39218 L
.78686 .16187 L
F
.2 .63 .79 r
.77981 .16187 m
.77981 .39218 L
.78686 .39218 L
.78686 .16187 L
s
.678 .847 .902 r
.78686 .16187 m
.78686 .39559 L
.79008 .39559 L
.79008 .16187 L
F
.2 .63 .79 r
.78686 .16187 m
.78686 .39559 L
.79008 .39559 L
.79008 .16187 L
s
.678 .847 .902 r
.79008 .16187 m
.79008 .39831 L
.79311 .39831 L
.79311 .16187 L
F
.2 .63 .79 r
.79008 .16187 m
.79008 .39831 L
.79311 .39831 L
.79311 .16187 L
s
.678 .847 .902 r
.79311 .16187 m
.79311 .39907 L
.79744 .39907 L
.79744 .16187 L
F
.2 .63 .79 r
.79311 .16187 m
.79311 .39907 L
.79744 .39907 L
.79744 .16187 L
s
.678 .847 .902 r
.79744 .16187 m
.79744 .40693 L
.80357 .40693 L
.80357 .16187 L
F
.2 .63 .79 r
.79744 .16187 m
.79744 .40693 L
.80357 .40693 L
.80357 .16187 L
s
.678 .847 .902 r
.80357 .16187 m
.80357 .41074 L
.80712 .41074 L
.80712 .16187 L
F
.2 .63 .79 r
.80357 .16187 m
.80357 .41074 L
.80712 .41074 L
.80712 .16187 L
s
.678 .847 .902 r
.80712 .16187 m
.80712 .41424 L
.81102 .41424 L
.81102 .16187 L
F
.2 .63 .79 r
.80712 .16187 m
.80712 .41424 L
.81102 .41424 L
.81102 .16187 L
s
.678 .847 .902 r
.81102 .16187 m
.81102 .41722 L
.81501 .41722 L
.81501 .16187 L
F
.2 .63 .79 r
.81102 .16187 m
.81102 .41722 L
.81501 .41722 L
.81501 .16187 L
s
.678 .847 .902 r
.81501 .16187 m
.81501 .42369 L
.82235 .42369 L
.82235 .16187 L
F
.2 .63 .79 r
.81501 .16187 m
.81501 .42369 L
.82235 .42369 L
.82235 .16187 L
s
.678 .847 .902 r
.82235 .16187 m
.82235 .43258 L
.82804 .43258 L
.82804 .16187 L
F
.2 .63 .79 r
.82235 .16187 m
.82235 .43258 L
.82804 .43258 L
.82804 .16187 L
s
.678 .847 .902 r
.82804 .16187 m
.82804 .43642 L
.83213 .43642 L
.83213 .16187 L
F
.2 .63 .79 r
.82804 .16187 m
.82804 .43642 L
.83213 .43642 L
.83213 .16187 L
s
.678 .847 .902 r
.83213 .16187 m
.83213 .44548 L
.83869 .44548 L
.83869 .16187 L
F
.2 .63 .79 r
.83213 .16187 m
.83213 .44548 L
.83869 .44548 L
.83869 .16187 L
s
.678 .847 .902 r
.83869 .16187 m
.83869 .44813 L
.84442 .44813 L
.84442 .16187 L
F
.2 .63 .79 r
.83869 .16187 m
.83869 .44813 L
.84442 .44813 L
.84442 .16187 L
s
.678 .847 .902 r
.84442 .16187 m
.84442 .45278 L
.84733 .45278 L
.84733 .16187 L
F
.2 .63 .79 r
.84442 .16187 m
.84442 .45278 L
.84733 .45278 L
.84733 .16187 L
s
.678 .847 .902 r
.84733 .16187 m
.84733 .46134 L
.85472 .46134 L
.85472 .16187 L
F
.2 .63 .79 r
.84733 .16187 m
.84733 .46134 L
.85472 .46134 L
.85472 .16187 L
s
.678 .847 .902 r
.85472 .16187 m
.85472 .46459 L
.85703 .46459 L
.85703 .16187 L
F
.2 .63 .79 r
.85472 .16187 m
.85472 .46459 L
.85703 .46459 L
.85703 .16187 L
s
.678 .847 .902 r
.85703 .16187 m
.85703 .46714 L
.86337 .46714 L
.86337 .16187 L
F
.2 .63 .79 r
.85703 .16187 m
.85703 .46714 L
.86337 .46714 L
.86337 .16187 L
s
.678 .847 .902 r
.86337 .16187 m
.86337 .4736 L
.86634 .4736 L
.86634 .16187 L
F
.2 .63 .79 r
.86337 .16187 m
.86337 .4736 L
.86634 .4736 L
.86634 .16187 L
s
.678 .847 .902 r
.86634 .16187 m
.86634 .48065 L
.87295 .48065 L
.87295 .16187 L
F
.2 .63 .79 r
.86634 .16187 m
.86634 .48065 L
.87295 .48065 L
.87295 .16187 L
s
.678 .847 .902 r
.87295 .16187 m
.87295 .48795 L
.87849 .48795 L
.87849 .16187 L
F
.2 .63 .79 r
.87295 .16187 m
.87295 .48795 L
.87849 .48795 L
.87849 .16187 L
s
.678 .847 .902 r
.87849 .16187 m
.87849 .4916 L
.88309 .4916 L
.88309 .16187 L
F
.2 .63 .79 r
.87849 .16187 m
.87849 .4916 L
.88309 .4916 L
.88309 .16187 L
s
.678 .847 .902 r
.88309 .16187 m
.88309 .49696 L
.88979 .49696 L
.88979 .16187 L
F
.2 .63 .79 r
.88309 .16187 m
.88309 .49696 L
.88979 .49696 L
.88979 .16187 L
s
.678 .847 .902 r
.88979 .16187 m
.88979 .50558 L
.89425 .50558 L
.89425 .16187 L
F
.2 .63 .79 r
.88979 .16187 m
.88979 .50558 L
.89425 .50558 L
.89425 .16187 L
s
.678 .847 .902 r
.89425 .16187 m
.89425 .50796 L
.89732 .50796 L
.89732 .16187 L
F
.2 .63 .79 r
.89425 .16187 m
.89425 .50796 L
.89732 .50796 L
.89732 .16187 L
s
.678 .847 .902 r
.89732 .16187 m
.89732 .51331 L
.90228 .51331 L
.90228 .16187 L
F
.2 .63 .79 r
.89732 .16187 m
.89732 .51331 L
.90228 .51331 L
.90228 .16187 L
s
.678 .847 .902 r
.90228 .16187 m
.90228 .51853 L
.90797 .51853 L
.90797 .16187 L
F
.2 .63 .79 r
.90228 .16187 m
.90228 .51853 L
.90797 .51853 L
.90797 .16187 L
s
.678 .847 .902 r
.90797 .16187 m
.90797 .52618 L
.91163 .52618 L
.91163 .16187 L
F
.2 .63 .79 r
.90797 .16187 m
.90797 .52618 L
.91163 .52618 L
.91163 .16187 L
s
.678 .847 .902 r
.91163 .16187 m
.91163 .52892 L
.91777 .52892 L
.91777 .16187 L
F
.2 .63 .79 r
.91163 .16187 m
.91163 .52892 L
.91777 .52892 L
.91777 .16187 L
s
.678 .847 .902 r
.91777 .16187 m
.91777 .54051 L
.92399 .54051 L
.92399 .16187 L
F
.2 .63 .79 r
.91777 .16187 m
.91777 .54051 L
.92399 .54051 L
.92399 .16187 L
s
.678 .847 .902 r
.92399 .16187 m
.92399 .54087 L
.92835 .54087 L
.92835 .16187 L
F
.2 .63 .79 r
.92399 .16187 m
.92399 .54087 L
.92835 .54087 L
.92835 .16187 L
s
.678 .847 .902 r
.92835 .16187 m
.92835 .55113 L
.93551 .55113 L
.93551 .16187 L
F
.2 .63 .79 r
.92835 .16187 m
.92835 .55113 L
.93551 .55113 L
.93551 .16187 L
s
.678 .847 .902 r
.93551 .16187 m
.93551 .55562 L
.93988 .55562 L
.93988 .16187 L
F
.2 .63 .79 r
.93551 .16187 m
.93551 .55562 L
.93988 .55562 L
.93988 .16187 L
s
.678 .847 .902 r
.93988 .16187 m
.93988 .564 L
.94616 .564 L
.94616 .16187 L
F
.2 .63 .79 r
.93988 .16187 m
.93988 .564 L
.94616 .564 L
.94616 .16187 L
s
.678 .847 .902 r
.94616 .16187 m
.94616 .5695 L
.95223 .5695 L
.95223 .16187 L
F
.2 .63 .79 r
.94616 .16187 m
.94616 .5695 L
.95223 .5695 L
.95223 .16187 L
s
.678 .847 .902 r
.95223 .16187 m
.95223 .57525 L
.95752 .57525 L
.95752 .16187 L
F
.2 .63 .79 r
.95223 .16187 m
.95223 .57525 L
.95752 .57525 L
.95752 .16187 L
s
.678 .847 .902 r
.95752 .16187 m
.95752 .58245 L
.96273 .58245 L
.96273 .16187 L
F
.2 .63 .79 r
.95752 .16187 m
.95752 .58245 L
.96273 .58245 L
.96273 .16187 L
s
.678 .847 .902 r
.96273 .16187 m
.96273 .58753 L
.96551 .58753 L
.96551 .16187 L
F
.2 .63 .79 r
.96273 .16187 m
.96273 .58753 L
.96551 .58753 L
.96551 .16187 L
s
.678 .847 .902 r
.96551 .16187 m
.96551 .59038 L
.97089 .59038 L
.97089 .16187 L
F
.2 .63 .79 r
.96551 .16187 m
.96551 .59038 L
.97089 .59038 L
.97089 .16187 L
s
.678 .847 .902 r
.97089 .16187 m
.97089 .59914 L
.97619 .59914 L
.97619 .16187 L
F
.2 .63 .79 r
.97089 .16187 m
.97089 .59914 L
.97619 .59914 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02619 .01472 Mdot
.02952 .01474 Mdot
.03576 .01481 Mdot
.04142 .01492 Mdot
.04875 .01512 Mdot
.05277 .01526 Mdot
.0574 .01545 Mdot
.06207 .01566 Mdot
.07135 .01618 Mdot
.07432 .01637 Mdot
.07947 .01673 Mdot
.07987 .01675 Mdot
.08815 .0174 Mdot
.0897 .01753 Mdot
.09435 .01794 Mdot
.09812 .0183 Mdot
.10748 .01926 Mdot
.11345 .01993 Mdot
.11861 .02055 Mdot
.12211 .02099 Mdot
.12454 .0213 Mdot
.1337 .02255 Mdot
.13586 .02286 Mdot
.14412 .02411 Mdot
.14665 .02451 Mdot
.15151 .0253 Mdot
.16032 .02681 Mdot
.1628 .02725 Mdot
.16806 .02822 Mdot
.17265 .02909 Mdot
.17515 .02958 Mdot
.18061 .03067 Mdot
.18584 .03175 Mdot
.1876 .03212 Mdot
.19091 .03283 Mdot
.20107 .03511 Mdot
.20666 .03641 Mdot
.21236 .03779 Mdot
.21689 .03891 Mdot
.22209 .04023 Mdot
.22428 .0408 Mdot
.23026 .04237 Mdot
.23524 .04372 Mdot
.23661 .0441 Mdot
.23989 .04502 Mdot
.24305 .04591 Mdot
.25027 .048 Mdot
.25445 .04923 Mdot
.26352 .052 Mdot
.26861 .05361 Mdot
.26944 .05387 Mdot
.27753 .05649 Mdot
.28331 .05841 Mdot
.2881 .06004 Mdot
.29935 .06399 Mdot
.30144 .06473 Mdot
.30629 .0665 Mdot
.30997 .06786 Mdot
.32121 .07211 Mdot
.32657 .0742 Mdot
.33356 .07698 Mdot
.33956 .07941 Mdot
.34341 .081 Mdot
.35184 .08454 Mdot
.35499 .08589 Mdot
.36141 .08868 Mdot
.36371 .08969 Mdot
.37102 .09295 Mdot
.37498 .09474 Mdot
.3804 .09723 Mdot
.3848 .09928 Mdot
.38927 .10139 Mdot
.39773 .10545 Mdot
.40543 .10922 Mdot
.41023 .11162 Mdot
.4133 .11316 Mdot
.41774 .11542 Mdot
.42407 .11868 Mdot
.43193 .1228 Mdot
.43893 .12654 Mdot
.44334 .12893 Mdot
.44419 .1294 Mdot
.45091 .13309 Mdot
.45335 .13445 Mdot
.45983 .13809 Mdot
.46512 .1411 Mdot
.47077 .14435 Mdot
.47494 .14679 Mdot
.48361 .15191 Mdot
.49002 .15576 Mdot
.49274 .15741 Mdot
.50047 .16216 Mdot
.50385 .16426 Mdot
.50733 .16643 Mdot
.51627 .17209 Mdot
.51746 .17286 Mdot
.52309 .17648 Mdot
.5264 .17864 Mdot
.52944 .18062 Mdot
.53386 .18354 Mdot
.54198 .18895 Mdot
.54613 .19176 Mdot
.55387 .19705 Mdot
.55618 .19863 Mdot
.5613 .20219 Mdot
.56342 .20367 Mdot
.56799 .20689 Mdot
.57538 .21214 Mdot
.57892 .21468 Mdot
.58264 .21737 Mdot
.58553 .21947 Mdot
.58725 .22073 Mdot
.59462 .22615 Mdot
.59952 .2298 Mdot
.60648 .23503 Mdot
.60856 .23661 Mdot
.61268 .23974 Mdot
.61549 .2419 Mdot
.62458 .24893 Mdot
.62893 .25234 Mdot
.63206 .2548 Mdot
.63663 .25842 Mdot
.63982 .26097 Mdot
.64477 .26494 Mdot
.65268 .27135 Mdot
.65483 .27311 Mdot
.66271 .27961 Mdot
.66983 .28554 Mdot
.67107 .28658 Mdot
.67364 .28875 Mdot
.67795 .2924 Mdot
.68066 .2947 Mdot
.68661 .2998 Mdot
.69314 .30544 Mdot
.69887 .31044 Mdot
.70051 .31188 Mdot
.70889 .31928 Mdot
.71672 .32628 Mdot
.71813 .32755 Mdot
.72606 .33474 Mdot
.72796 .33648 Mdot
.73388 .34191 Mdot
.7369 .3447 Mdot
.74275 .35013 Mdot
.75513 .36178 Mdot
.75624 .36284 Mdot
.76257 .36888 Mdot
.76596 .37214 Mdot
.76724 .37337 Mdot
.77464 .38055 Mdot
.77709 .38294 Mdot
.78648 .39218 Mdot
.78991 .39559 Mdot
.79265 .39831 Mdot
.79341 .39907 Mdot
.80123 .40693 Mdot
.80501 .41074 Mdot
.80845 .41424 Mdot
.81138 .41722 Mdot
.81768 .42369 Mdot
.82626 .43258 Mdot
.82994 .43642 Mdot
.83855 .44548 Mdot
.84106 .44813 Mdot
.84542 .45278 Mdot
.85341 .46134 Mdot
.85643 .46459 Mdot
.85878 .46714 Mdot
.86473 .4736 Mdot
.87115 .48065 Mdot
.87777 .48795 Mdot
.88106 .4916 Mdot
.88586 .49696 Mdot
.89353 .50558 Mdot
.89564 .50796 Mdot
.90035 .51331 Mdot
.90492 .51853 Mdot
.91159 .52618 Mdot
.91397 .52892 Mdot
.92394 .54051 Mdot
.92425 .54087 Mdot
.93299 .55113 Mdot
.93679 .55562 Mdot
.94383 .564 Mdot
.94843 .5695 Mdot
.95321 .57525 Mdot
.95916 .58245 Mdot
.96333 .58753 Mdot
.96566 .59038 Mdot
.9728 .59914 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(190) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0155108) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.668014) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000030?[`iPH0
00000P3jl>H400000?l0n_3VW03jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000050?[`iP800000o`3j
l>JM0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000020?[`iPH00000o`3j
l>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003j
l>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V00000000
00002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000020?[`iP03
0000003jl>H0n_3V00800000o`3jl>JM0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V
0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`
iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`
iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H
0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V100000040?[`iP<000000`3jl>H2
000000030?[`iP000000000000@0n_3V0P0000030?[`iP040000003jl>H0000000000?l0n_3VW@3j
l>H10?ooo`00803jl>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V10000000
0`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P000005
0?[`iP<0000000<0n_3V0000000000001`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H2
000000D0n_3V0P0000050?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
000000@0n_3V0P0000030?[`iP040000003jl>H0000000000?l0n_3VW@3jl>H10?ooo`00803jl>H2
00000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0U0?[`iP80000000<0n_3V
0000000000002P3jl>H2000000D0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000080n_3V100000040?[`iP<00000o`3jl>JM0?[`iP40oooo000O0?[`
iPH00000103jl>H2000002l0n_3V1@00000X0?[`iP<00000303jl>H3000000@0n_3V0`0000030?[`
iP<00000103jl>H3000000D0n_3V0P0000050?[`iP800000o`3jl>JM0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool003d0n_3V1000003o
0?[`i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3Vo`3jl>HG0?[`iP40oooo000P0?[`iPH0
000000D0n_3V00000000000000000?[`iP0300000080n_3V0`0000030?[`iP@000000`3jl>H20000
00040?[`iP00000000000?[`iPD000000`3jl>H<000002l0n_3V0`0000040?[`iP8000001@3jl>H3
000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP800000o`3jl>JN
0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`
iP040000003jl>H00000000000<0n_3V00D000000?[`iP00000000000?[`iP0300000080n_3V0P00
00040?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP00
0000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P000004
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000050?[`iP8000000P3jl>H2
00000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000`0?[`iP80000000<0n_3V
0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H20000
00030?[`iP00000000000080n_3V0P0000040?[`iPH0000000<0n_3V0000000000000P3jl>H20000
0080n_3V0P0000050?[`iPD000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000
000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`
iP<000000P3jl>H3000000030?[`iP000000n_3V00@0n_3V0P0000030?[`iP800000<03jl>H20000
00030?[`iP000000000000T0n_3V100000030?[`iP@000000`3jl>H4000000<0n_3V100000030?[`
iP@000001P3jl>H200000?l0n_3VW@3jl>H10?ooo`008P3jl>H2000000<0n_3V1@0000020?[`iPD0
00000`3jl>H4000000<0n_3V0P0000000`3jl>H0000000000004000000030?[`iP00000000000080
n_3V100000040?[`iP800000<03jl>H2000000030?[`iP000000000000T0n_3V0P0000050?[`iP80
00001@3jl>H2000000D0n_3V0P0000050?[`iP800000203jl>H200000?l0n_3VW@3jl>H10?ooo`00
8P3jl>H2000000/0n_3V0P00000R0?[`iP800000<03jl>H2000000030?[`iP000000000000X0n_3V
0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000103jl>H00`000000n_3V
0?[`iP0200000?l0n_3VW@3jl>H10?ooo`00803jl>H6000000T0n_3V0P00000P0?[`iP@00000<@3j
l>H3000000`0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<000000P3j
l>H500000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H02000
00000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H010000000n_3V0000003j
l>H200000080n_3V00<000000?[`iP3jl>H00`00003o0?[`i_l0n_3V903jl>H10?ooo`00803jl>H3
000000030?[`iP00000000000080000000D0n_3V0000003jl>H000000?[`iP0300000080n_3V00<0
00000?[`iP000000603jl>H500000=/0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P00
00030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000@0n_3V0000000000000000
203jl>H4000000030?[`iP00000000000080n_3V100000020?[`iPD0000000L0n_3V000000000000
00000?[`iP000000n_3V00<00000603jl>H3000000@0n_3V0P0000050?[`iP<000000`3jl>H60000
0080n_3V0`0000040?[`iP<000000`3jl>H600000080n_3V0`0000040?[`iP<00000LP3jl>H10?oo
o`008@3jl>H2000000030?[`iP000000000000D0000000@0n_3V00000000000000000P3jl>H20000
00030?[`iP000000000000T0n_3V1@0000090?[`iP800000g`3jl>H2000000@0n_3V0P0000020?[`
iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H2
00000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
00000`3jl>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00020?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P00
00000`3jl>H00000000000030?[`iP800000103jl>H2000000030?[`iP000000000000@0n_3V0P00
00030?[`iP030000003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`iP02000000@0n_3V0P00
00030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000740n_3V0@3o
ool00280n_3V0`00000Y0?[`iP800000gP3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2
000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000000000000?[`
iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V00800000603j
l>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000040?[`iP8000001P3j
l>H2000000D0n_3V0P0000040?[`iP8000000`3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H000000000001a0?[`iP40oooo000R0?[`iP<000006P3jl>H5000000/0n_3V0P00003M
0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P000006
0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2
000000050?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P00
00000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3j
l>H2000000030?[`iP000000000000@0n_3V0P0000060?[`iP8000001@3jl>H2000000@0n_3V0P00
00030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000740n_3V0@3o
ool00240n_3V0P0000000`3jl>H000000000000Z0?[`iP800000g03jl>H2000000030?[`iP000000
000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103j
l>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000
000:0?[`iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`
iP000000n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V000000000000
2@3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP030000003jl>H0n_3V00800000
0P3jl>H00`000000n_3V0?[`iP02000000@0n_3V0P0000030?[`iP80000000<0n_3V000000000000
0`3jl>H300000780n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP800000
00<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<00000
00@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@0
00000P3jl>H5000000/0n_3V0`0000000`3jl>H00000000000020?[`iP@000000P3jl>H300000003
0?[`iP000000000000L000006@3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H0
0000000000040?[`iP8000000`3jl>H4000000<0n_3V100000050?[`iP8000000`3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H000000000001a0?[`iP40oooo001=0?[`iP800000
00<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP800000
8P3jl>H200000080n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`
iP00000000000080n_3V100000030?[`iP8000001@3jl>H2000000D0n_3V100000030?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000740n_3V0@3oool004h0n_3V0`00
003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000001T0n_3V0`00
00000`3jl>H0000000000002000002h0n_3V0`00000;0?[`iP<000001@3jl>H2000000<0n_3V1@00
00020?[`iPD00000103jl>H2000000@0n_3V0`0000040?[`iP<00000LP3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP800000
00<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3j
l>H01@000000n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000
n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`iP000000000000800000
00@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V
01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H30000
0080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000H000006P3jl>H60000
00040?[`iP0000000000000000D0n_3V0`00002j0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000
000000001@0000001@3jl>H00000000000000000n_3V00@000002`3jl>H5000000T0n_3V0P000000
0`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H2
00000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`
iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80
00000P3jl>H2000000/0n_3V1@00000;0?[`iP8000001@3jl>H2000000<0n_3V0P0000000`3jl>H0
00000000002i0?[`iP40oooo000R0?[`iP<00000:03jl>H2000000030?[`iP00000000000=`0n_3V
0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V
0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V000000000000
0`3jl>H4000001/0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP00000000000;T0n_3V
0@3oool00280n_3V0`0000090?[`iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0
n_3V000000000000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P00
00040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00
000000000?[`iP@000003@3jl>H5000000/0n_3V0P0000040?[`iP@000000P3jl>H2000000030?[`
iP00000000000;T0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0
n_3V000000000000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0
n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP800000
0P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000K0?[`iP80
00000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000002i0?[`iP40
oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`iP00000000000=`0
n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`
iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@0000030?[`
iPD000006`3jl>H2000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
00000000^@3jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H0
00000000000@0?[`iP800000303jl>H2000003P0n_3V100000030?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000;T0n_3V0@3oool004h0n_3V0`00003L0?[`iPD00000
4@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H200000380n_3V0P0000040?[`iP<00000
103jl>H300000;X0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo000M0?[`iRH0oooP0P00001/0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D0
0000J@3oon0500000080oooP0P0000040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`00
7@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000203oon001000
0000oooP0?ooh000001/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon001`3oon00
10000000oooP0?ooh000001Z0?ooh0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU
0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002`3oon000`000000oooP
0?ooh01Z0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon002P3oon000`000000oooP
0?ooh01Y0?ooh0030000003oon00oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003o
on00oooP000006X0oooP00@000000?ooh03oon0000002@3oon02000006d0oooP00<000000?ooh03o
on00J`3oon000`000000oooP0?ooh0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0
n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP0000
00T0oooP00<000000?ooh03oon00K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP
00P0oooP00<000000?ooh03oon00JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool0
01d0n_3V9P3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?oo
h0<00000J`3oon02000002@0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o
00000>X00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP
00<000000?ooh03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP
00T0oooP10000000103oon0000000000003oon02000000030?ooh000000000000080000000<0oooP
000000000000o`3oon3;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?oo
h0030000003oon00oooP00H0oooP00<000000?ooh03oon00203oon0E00000080oooP1`0000020?oo
h0800000o`3oon2l0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh003
0000003oon00oooP00H0oooP100000070?ooh003000000000?l0003o01P0003o2`0000030?ooh080
0000o`3oon2`0?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iPX0oooP100000040?ooh0030000
003oon00oooP00H0oooP00<000000?ooh03oon002@3oon04000000040<f5?`00000000000<f5?`80
000000<0onCQ0000000000000P0000000`3oi>40000000000008000000P0003o100000000`3=QCl0
00000000000900000?l0oooPZ`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0
00000000003oi>40cHDo00L0000000<0onCQ0<f5?`0000000P00000:0000o`L000000P3oon030000
0?l0oooPY@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0
oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo00@0onCQ00000000000000000P3oi>400`3=QCl00000
00000002000000T0003o100000001@3oon000000000000000000oooP00800000o`3oon2M0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>43
0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl000000000000500000080onCQ00<0
00000000o`000?l01P000?l4000000040?ooh0000000000000000?l0oooPV03oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oT
h@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`00000000000000003oi>40100000050000o`T00000o`3oon2B0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo
0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0
onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl00000000000000000cHDo0080000000<0cHDo
000000000?l010000?l900000?l0oooPS@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`020?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80
onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080
onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40000000@000001@000?l70000
0?l0oooPRP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40
cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0
onCQ0<f5?`020?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo1P0000050000o`<0000000@0cHDo
0?ooh00000000000o`3oon250?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3o
i>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ
00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=
QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=
QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00`0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl5000000D0003o100000000`3oon0000000000003o0?ooh800oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=
QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo
0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>403`3=
QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@04
000000030?oTh@3=QCl0000000@0003o1@00003o0?ooh7h0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ
0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ
00<0cHDo0?oTh@0000000`0000050000o`@00000o`3oon1j0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3=QCl0onCQ
0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oT
h@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ0180cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oT
h@040<f5?`3oi>40onCQ0<f5?`80000000<0cHDo0000000000000P0000040000o`H00000o`3oon1d
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo
0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@03
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo
0080onCQ0180cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3o
i>401P0000040000o`D00000o`3oon1a0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0<000002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=
QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3o
i>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>400`3=QCl0onCQ0?oTh@020<f5?`030?oTh@000000000000D000000`000?l3000000030?ooh000
000000000?l0oooPJ`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0
cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ0180cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oT
h@3oi>400P3=QCl20?oTh@80cHDo00<0onCQ000000000000100000040000o`@00000o`3oon1[0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3o
i>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5
?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080
onCQ0180cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>40
0P3=QCl20?oTh@80cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>43000000030<f5?`000000003o0080
003o0P0000000`3=QCl000000000003o0?ooh6L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=
QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5
?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo
0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3o
i>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>400`0000040000o`@00000o`3oon1T0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5
?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ0180
cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl2
0?oTh@80cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl0
0P0000000`3oi>400000000000030000o`80000000<0oooP000000000000o`3oon1P0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5
?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ0180
cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl2
0?oTh@80cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl0
0`3oi>400`3=QCl0000000000002000000<0003o1@00003o0?ooh5d0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5
?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=
QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl2
0?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@040<f5
?`3oi>40cHDo0?oTh@80000000@0onCQ000000000?l0003o1@00003o0?ooh5/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3o
i>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0
onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ
0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>42000000<0003o0`00003o0?ooh5X0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=
QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo
0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=
QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80
onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`03
0?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@02000000<0003o00<0
cHDo0?ooh03oon000`00003o0?ooh5@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl0
0`3oi>400`3=QCl0onCQ0?oTh@020<f5?`80000000<0onCQ0000o`000?l01P00003o0?ooh580oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oT
h@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3o
i>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@02
0<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ
0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0
onCQ0P3=QCl30000o`D00000o`3oon1@0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@03
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ0180cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40
onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@80cHDo0P3oi>40103=QCl0onCQ0<f5
?`3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo
00<0onCQ00<0cHDo0?oTh@3oi>400P3=QCl30?oTh@030<f5?`3oi>40onCQ008000000`000?l30000
00030<f5?`3oon00oooP0?l0oooPC03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=
QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`02
0?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ
00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=QCl0
onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`03
0?oTh@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`800000
0`000?l0103=QCl0oooP00000000003o0?ooh4/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=
QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5
?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo
0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3o
i>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oT
h@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=
QCl20?oTh@80000000<0onCQ0000o`000?l01@00003o0?ooh4P0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`020?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo
0080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0
onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oT
h@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ
0<f5?`030?oTh@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5
?`80onCQ00D0cHDo0?oTh@3oi>40cHDo000000030000o`D00000o`3oon130?ooh0<00000603oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ
0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ
00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@04
0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40
cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl20?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400`0000030000o`<00000o`3oon140?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3o
i>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5
?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080
onCQ0180cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>40
0P3=QCl20?oTh@80cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0?oT
h@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3=QCl3
0?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@04
0<f5?`000000000000000080003o1@00003o0?ooh400oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0
cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5
?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo
0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P0000030000
o`<00000o`3oon0o0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo
0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ0180cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ
00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@80cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`05
0?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo00<0onCQ00<0cHDo
0?oTh@3oi>400P3=QCl30?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ
0?oTh@3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ0`0000030000o`030<f5?`0000000000
0?l0oooP?03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40
cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0
onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5
?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40
cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40
onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40
cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`00000000000080000000<0onCQ0000
o`000?l00`00003o0?ooh3X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5
?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5
?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo
0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80
cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>40
0`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5
?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl2
0?oTh@8000000P000?l400000?l0oooP=`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`020?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80
onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080
onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ
0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=
QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5
?`030?oTh@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80
onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3oi>40
onCQ0<f5?`<0onCQ0`0000020000o`<00000o`3oon0f0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5
?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ0180cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@04
0<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@80cHDo0P3oi>40103=
QCl0onCQ0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5
?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3=QCl30?oTh@060<f5?`3oi>40onCQ0<f5?`3o
i>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00@0
cHDo0?oTh@3oi>40cHDo0`3oi>420<f5?`<000000P000?l400000?l0oooP<`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oT
h@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3o
i>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>42
0<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ
00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0
onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ0P3=QCl20?oTh@030<f5?`000000000000<0
003o0`00003o0?ooh340oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=
QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3o
i>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo
00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=
QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3o
i>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oT
h@80cHDo0P3oi>400`3=QCl0onCQ0000000300000080003o1000003o0?ooh2h0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3o
i>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0
onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ
0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo
0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3o
i>40cHDo00<000000P000?l400000?l0oooP;03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`020?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo
0080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0
onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oT
h@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ
0<f5?`030?oTh@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5
?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3o
i>40onCQ0<f5?`<0onCQ0P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>4300000080
003o1000003o0?ooh2X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=
QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3o
i>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo
00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=
QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3o
i>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oT
h@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P000003
0000o`800000o`3oon0Y0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0
cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ0180cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80
onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@80cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5
?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo00<0onCQ00<0
cHDo0?oTh@3oi>400P3=QCl30?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0
onCQ0?oTh@3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3o
i>420<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ0080cHDo
0`0000020000o`040<f5?`3oon00000000000?l0oooP9@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@03
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ0180cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40
onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@80cHDo0P3oi>40103=QCl0onCQ0<f5
?`3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo
00<0onCQ00<0cHDo0?oTh@3oi>400P3=QCl30?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3o
i>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00@0cHDo0?oTh@3o
i>40cHDo0`3oi>420<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
onCQ0080cHDo0P3oi>42000000030?oTh@000?l0003o00<00000o`3oon0R0?ooh0<00000603oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ
0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ
00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@04
0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40
cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40
103=QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@050<f5?`3oi>40onCQ0<f5?`0000000P000?l300000?l0
oooP8P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@03
0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo
0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0onCQ
0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3o
i>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo
0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ
0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo
0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ0P3=QCl20?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ00D0cHDo
0?oTh@3oi>40cHDo0?oTh@0200000080003o1000003o0?ooh1l0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3o
i>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0
onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=
QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80
onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oT
h@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3o
i>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40
cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>40103=QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0000
000000000P000?l300000?l0oooP7P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=
QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`02
0?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ
00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=QCl0
onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`03
0?oTh@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ
00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ
0<f5?`<0onCQ0P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oT
h@020<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0000000200000080003o
0`00003o0?ooh1`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0
onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40
cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40
0`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0
onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0
onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40
onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@80
cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oT
h@040<f5?`3oi>40onCQ0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`0200000080003o0P00
003o0?ooh1/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ
0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo
0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=
QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ
0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ
0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo
0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@04
0<f5?`3oi>40onCQ0<f5?`80onCQ00H0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>4300000080003o0P00
003o0?ooh1T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ
0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo
0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=
QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ
0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ
0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo
0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@04
0<f5?`3oi>40onCQ0<f5?`80onCQ00P0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@<00000
0P000?l00`000000cHDo0?ooh03o0?ooh1H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl2
0?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oT
h@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40
cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=
QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl2
0?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ
0?oTh@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3oi>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00X0cHDo0?oTh@3oi>40onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0`0000020000o`800000o`3oon0E0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3=
QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0
cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ0180cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@80cHDo
0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>401@3=
QCl0onCQ0<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3=QCl30?oTh@060<f5?`3oi>40
onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>420<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5
?`020?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@090<f5
?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ0P0000001@3oi>4000000000o`00
0?l000000?l0oooP503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5
?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5
?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oT
h@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@030<f5?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl0
1@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oTh@030<f5
?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oT
h@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ
0P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80
onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>402@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`020?oTh@030<f5?`3oi>40onCQ00<000000P000?l200000?l0oooP4@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oT
h@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3o
i>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>42
0<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ
00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0
onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ0P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40
2@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5
?`80000000<0cHDo000000000?l00`00003o0?ooh0l0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0
cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5
?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo
0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=
QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3oi>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00T0cHDo0?oTh@3oi>40
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`00
000000000080003o0P00003o0?ooh0h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl0
0`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oT
h@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oT
h@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3o
i>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00T0cHDo0?oTh@3oi>40onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>4000000080
00000P000?l400000?l0oooP2P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon03000000T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00@0cHDo0?oT
h@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0<f5
?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5
?`3oi>40cHDo0080onCQ0180cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0
cHDo0?oTh@3oi>400P3=QCl20?oTh@80cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`050?oT
h@3=QCl0onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo00<0onCQ00<0cHDo0?oT
h@3oi>400P3=QCl30?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oT
h@3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>420<f5
?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@090<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl3000000030000o`00
0000000000800000o`3oon070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ
0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo
0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=
QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ
0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ
0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo
0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@04
0<f5?`3oi>40onCQ0<f5?`80onCQ00T0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo00<0onCQ00000000
00000P000?l400000?l0oooP1`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oT
h@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=
QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ
0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oT
h@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0
cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5
?`<0onCQ0P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@02
0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>402@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl0
0`3oi>40cHDo0000000200000080003o0`00003o0?ooh0H0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ
0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ
00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@04
0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40
cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40
103=QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00T0cHDo0?oTh@3o
i>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5
?`3oi>40onCQ0080cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>400`000000003o0000o`0200000?l0
oooP1@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@03
0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo
0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0onCQ
0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3o
i>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo
0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ
0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo
0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ0P3=QCl20?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ00@0cHDo
0?oTh@3oi>40cHDo0P3oi>402@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oT
h@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl0103oi>40cHDo0?oTh@3=
QCl30?oTh@80000000<0003o0000000000000P00003o0?ooh080oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3o
i>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0
onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=
QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80
onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oT
h@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3o
i>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40
cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>40103=QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00T0cHDo0?oT
h@3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@03
0<f5?`3oi>40onCQ0080cHDo00@0onCQ0<f5?`3oi>40cHDo0`3oi>400`3=QCl00000000000020000
o`@00000o`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40
cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0
onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5
?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40
cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40
onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40
cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ0P3=QCl2
0?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ00@0
cHDo0?oTh@3oi>40cHDo0P3oi>402@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl0103oi>40cHDo0?oT
h@3=QCl30?oTh@030<f5?`3oi>400000008000000P000?l300000?h0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5
?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=
QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl2
0?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5
?`3oi>40cHDo0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo
0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00T0cHDo
0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@030<f5?`3oi>40onCQ0080cHDo00@0onCQ0<f5?`3oi>40cHDo0`3oi>401@3=QCl0onCQ0<f5?`3=
QCl0onCQ008000000P000?l00`000000cHDo0?ooh03l0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00D0cHDo0?oTh@3=QCl0onCQ0<f5
?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>430<f5?`<0onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ0180cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@04
0<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@80cHDo0P3oi>40103=
QCl0onCQ0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>401@3=QCl0onCQ0<f5
?`3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>400P3=QCl30?oTh@060<f5?`3oi>40onCQ0<f5?`3o
i>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00@0
cHDo0?oTh@3oi>40cHDo0`3oi>420<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@03
0<f5?`3oi>40onCQ0080cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@090<f5?`3oi>40onCQ
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0
onCQ0?oTh@020<f5?`040?oTh@3=QCl0onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3=QCl0cHDo0P3oi>40
1@3=QCl00000000000000?l0cHDo00800000n`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`020?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo
0080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0
onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oT
h@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ
0<f5?`030?oTh@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5
?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3o
i>40onCQ0<f5?`<0onCQ0P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0?oTh@020<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>402@3=QCl0onCQ0?oTh@3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3o
i>400P3=QCl0103oi>40cHDo0?oTh@3=QCl30?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ00@0cHDo
0?oTh@3oi>40onCQ0P000?l200000?X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl0
0`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oT
h@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oT
h@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3o
i>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00T0cHDo0?oTh@3oi>40onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080
cHDo00@0onCQ0<f5?`3oi>40cHDo0`3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@040<f5?`3oi>40
onCQ0?oTh@8000000P000?l200000?P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon001@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0P3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@<0cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>404P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ0P3=QCl20?oTh@040<f5?`3oi>40cHDo
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl0
0`3oi>400`3=QCl0onCQ0?oTh@020<f5?`<0onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oT
h@040<f5?`3oi>40onCQ0<f5?`<0onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40103=QCl0onCQ0?oT
h@3=QCl30?oTh@80cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3o
i>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00T0cHDo0?oTh@3oi>40onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080
cHDo00@0onCQ0<f5?`3oi>40cHDo0`3oi>40103=QCl0onCQ0<f5?`3=QCl20?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00`00000010000?l0000000000000003f0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0050<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oT
h@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3o
i>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>42
0<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ
00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0
onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ0P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40
2@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl0103oi>40cHDo0?oTh@3=QCl30?oTh@040<f5?`3oi>40
cHDo0<f5?`80onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@8000000P000?l200000?D0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon000000
1`3oon000`000000oooP0?ooh0090?ooh0050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oT
h@040<f5?`3oi>40cHDo0<f5?`80onCQ0`3=QCl30?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00D0
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@0B0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=
QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>420<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ
0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`030?oT
h@030<f5?`3oi>40onCQ0080cHDo0`3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0
cHDo0?oTh@3oi>40cHDo0`3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5
?`<0onCQ0P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@02
0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>402@3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl0
103oi>40cHDo0?oTh@3=QCl30?oTh@040<f5?`3oi>40cHDo0<f5?`80onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@040<f5?`000000000000000080003o00<0oooP000000000000lP3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?oo
h0@00000203oon3W00000080003oj00000080?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ00
oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03`0?ooh080000000D0003o0000
00000000000003>QbP020:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0=03>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0503>Q
bP2]f>H0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
2@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080
[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
1@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080
[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@0
00000?ooh03oon0000001`3oon000`000000oooP0?ooh03a0?ooh08000000P000?l200000080[MSV
0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00d0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP02
03>QbP070:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0903>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0cXLX0
[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]
f>H00P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX3
0:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03o
on00lP3oon03000000040000o`000000[MSV0:gHiP80<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0=03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>Q
bP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00m03oon0200000080003o0`0000001P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV00d0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP030:gHiP0903>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gH
iP2]f>H0<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0
[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>Q
bP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03f0?ooh00303>QbP000000003o00<0000000D0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0=03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0
[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80
[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00m`3oon0200000080003o0`00
00000`0cXLX0[MSV03>QbP020:gHiP0=03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV
03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0
[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:
00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV
0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n03oon03000000060000o`000000
00000000002]f>H0<j7:0P2]f>H03@0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00T0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0c
XLX0[MSV0:gHiP0cXLX00`2]f>H203>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gH
iP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80
<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?/0oooP00<000000000o`0000000`00
00020:gHiP0=03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>Q
bP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o03oon000`000000003o0000o`040000000=03>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0
[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H02@0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0c
XLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0
[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV
03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o@3oon02000000030000o`0000000000008000000`2]f>H02@0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0
[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80
[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon000`000000003o0000
o`02000000<0[MSV00T0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H01@0c
XLX0[MSV0:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV
00T0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00D0<j7:0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00`2]f>H203>Q
bP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP0P3oon0010000000003o03>QbP2]f>H20000000903>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP07
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP030:gHiP0903>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0cXLX0[MSV0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80
<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0@0oooP0P00
0?l40000000703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>Q
bP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H02@0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX01@2]
f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>Q
bP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0
[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon050?ooh003000000000?l0000000<0000000H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gH
iP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0
<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP0`00003o0?ooh0H0oooP00<000000000o`000?l00P0000001P2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP030:gHiP0903>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0
<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP203oon0010000000003o03>QbP2]f>H20000000303>QbP2]f>H0
<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP030:gHiP0903>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0
<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0X0oooP0P000?l3000000050:gHiP0cXLX0[MSV
0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:
0`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gH
iP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0
<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0;0?ooh003000000000?l0000000<000000P2]f>H01@0cXLX0
[MSV0:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:00<0[MSV00T0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0
<j7:0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00`2]f>H203>QbP80
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:
0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP303oon000`000000003o0000o`03000000060:gHiP0cXLX0[MSV0:gHiP0c
XLX0[MSV0P0cXLX01`2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H02@0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX01@2]
f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>Q
bP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0
[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0=0?ooh080000000D0003o000000000000000003>QbP020:gHiP0503>QbP2]f>H0<j7:03>Q
bP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX30:gHiP0903>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0cXLX0[MSV0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80
<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0l0oooP00<0
00000000o`000?l00P0000020:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0cXLX0102]f>H0<j7:
0:gHiP0cXLX30:gHiP0903>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0
<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh100oooP0P0000000`000?l000000000000203>Q
bP040:gHiP0cXLX0<j7:0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0`2]f>H02@0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX01@2]
f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>Q
bP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0
[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0A0?ooh08000000P000?l00`3oon0000000000000203>QbP070:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP030:gHiP0903>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP2]
f>H0<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:
0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh180oooP0P0000000`3oon00003o00000002
0000000803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP0903>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0c
XLX0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>Q
bP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0c
XLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h1D0oooP00<000000000o`000?l00P0000001`2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80
<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:
0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0F0?ooh080000000T0003o000000000000000003>QbP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV
03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]
f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP03
03>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0G0?ooh08000000P000?l30000000303>QbP2]
f>H0<j7:00<0[MSV00T0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00D0<j7:0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV0:gHiP0c
XLX00`2]f>H203>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80
[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP603oon03000000060000o`00000000000000002]
f>H0<j7:0`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>Q
bP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh1X0oooP0P0000020000o`030000002]f>H0<j7:00<0[MSV00T0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP80
<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:
0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00`2]f>H203>QbP80[MSV
00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gH
iP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP
0?ooh0070?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0K0?ooh0<0000000<0003o0000000000000`2]f>H02@0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:
00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>Q
bP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0N0?ooh0040000
00000?l0000000000080[MSV00T0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV
0:gHiP0cXLX00`2]f>H203>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:
00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0c
XLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7P3oon0200000080003o0P0000002@0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0c
XLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0
[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV
00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0O0?ooh0<0000000/0003o000000000000[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:
00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>Q
bP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Q0?ooh0800000
00X0003o00000000000000000:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00D0<j7:0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00`2]f>H2
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP8P3oon0200000080003o0P0000001@0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:0:gHiP2]f>H0<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0
102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H2
03>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2@0oooP0P0000001`000?l0
00000000002]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:00D0[MSV
03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP0cXLX0
<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00`2]f>H203>QbP80[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:
0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
03>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP9@3oon02000000060000o`000000000003>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00D0<j7:0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00`2]f>H203>Q
bP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP9P3oon0200000080003o0P0000001P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gH
iP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0
<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0W0?ooh0<0000000<0003o0000000000000P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00D0<j7:0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX0
0`2]f>H203>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP:03oon03000000070000o`000000[MSV0:gHiP0cXLX0
[MSV03>QbP020:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00D0<j7:0:gHiP0cXLX0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX0
0`2]f>H203>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP:P3oon0200000080003o0P000000102]f>H0<j7:0:gH
iP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:00<0[MSV0P0c
XLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP06
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX0
0P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh2`0oooP00<0<j7:000000000?l00P0000000`0cXLX0[MSV0:gHiP02
03>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>Q
bP2]f>H0<j7:03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:00<0[MSV0P0cXLX20:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]
f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
2P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0
oooP;03oon00100cXLX00000000000000?l200000080[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:
00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>Q
bP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2h0oooP0P0000020000o`800000
0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0c
XLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0
[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV
00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0_0?ooh0<0000000H0003o000000000000<j7:0:gHiP0cXLX20:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP2]f>H203>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]
f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX3
0:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV
0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<03oon03
000000050000o`00000000000:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>Q
bP2]f>H0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP2]f>H0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP0P00000010000?l00000000000000002
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP050:gH
iP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP2]f>H203>QbP80[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:
0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
03>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP<`3oon0200000080003o0P0000001@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00D0<j7:0:gH
iP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP2]f>H203>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP=03oon03000000040000o`000000000003>QbP80[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080<j7:00D0[MSV03>Q
bP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0c
XLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0f0?ooh080000000<0003o0000
000000000P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>QbP2]f>H0<j7:03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80
<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP0P00
00020000o`80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV03>QbP0cXLX0[MSV0080
<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gH
iP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX3
0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0
[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H2
03>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0h0?ooh080
000000@0<j7:0000o`00000000000P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:00D0[MSV
03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV
03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0j0?ooh00303>QbP000000003o0080000000H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP05
0:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP2]f>H203>QbP80[MSV00<0<j7:
0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0
<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP>P3oon00100cXLX00000000000000?l20000000503>QbP2]f>H0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0[MSV0P0cXLX20:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh3`0oooP0P0000020000o`0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0c
XLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h3d0oooP0P0000001P3oon00003o000000000000<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP05
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>Q
bP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon100?ooh0050000
00000?l000000000002]f>H00P0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP2]f>H0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon0300000?l0oooP@03oon02000000030000o`000000[MSV0080<j7:00D0[MSV03>Q
bP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:
0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00L0oooP0`00
000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh440oooP0P000000
1@000?l000000000000cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:
0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080
[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon130?ooh005000000000?l000000000002]f>H00P0cXLX01@2]f>H0<j7:
0:gHiP2]f>H0<j7:00<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H2
03>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]
f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>Q
bP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4<0oooP0P0000020000o`050000
000cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP2]f>H203>QbP80[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:
0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
03>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPA03oon03000000050000o`00000000000:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP2]f>H2
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPA@3oon03000000040000o`000000000003>QbP80[MSV00@0<j7:
0:gHiP2]f>H0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:
0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4H0oooP0`0000000`000?l0000003>QbP02
0:gHiP0403>QbP2]f>H0[MSV0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0
[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:
00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV
0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon180?ooh080000000D0003o
0000002]f>H0[MSV03>QbP030:gHiP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0
[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:
00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV
0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon180?ooh0<0000000@0003o
000000000000<j7:0`2]f>H203>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV03>Q
bP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80
<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gH
iP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:
0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB@3oon03000000030000o`000000
000000<0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4/0oooP0P0000000`000?l000000:gHiP020:gH
iP80<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0
<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1<0?ooh080000000@0003o000000000000[MSV0P0cXLX20:gH
iP0303>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]
f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
2P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0
oooP00<000000?ooh03oon00o`3oon1>0?ooh004000000000?l0003o00000080<j7:0P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>Q
bP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03o
on001P3oon000`000000oooP0?ooh03o0?ooh4h0oooP0`0000000`000?l00000000000020:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP
0?ooh0060?ooh0@00000o`3oon1>0?ooh0<0000000L0003o000000000000[MSV03>QbP2]f>H0<j7:
00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX3
0:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon001P3oon040000
01P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03o
on00o`3oon1A0?ooh080000000H0003o000000000000<j7:0:gHiP0cXLX30:gHiP0503>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV
0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0c
XLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?oo
h580oooP0P0000001@000?l0000003>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon1C0?ooh080000000@0003o03>Q
bP2]f>H0<j7:0`2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0
<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPEP3oon000`000?l00000000000030:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0
<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1F0?ooh004000000000?l0000000000080[MSV00D0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]
f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0
102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H2
03>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5H0oooP0P0000002@000?l0
00000:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0c
XLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h5L0oooP0P0000020000o`80000000@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>Q
bP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1H0?ooh080<j7:00L000000000o`000000000003>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPFP3oon02000000050000o`00000000000:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:
0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1K0?ooh080000000@0003o0000002]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080
[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1L0?ooh080000000P0003o0:gHiP00000000000:gHiP0cXLX0[MSV03>Q
bP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh5h0oooP00<0<j7:0000o`0000000P0000000`0cXLX0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:
0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1N
0?ooh00303>QbP000000003o0080000000<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX30:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H2
03>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX2
0:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon1O0?ooh080000000D0003o0000000c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:
0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh600oooP0P00000010000?l000000000000cXLX20:gHiP0403>QbP2]f>H0[MSV03>Q
bP<0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80
[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1R0?ooh00300000000
0?l0003o0080000000D0[MSV03>QbP2]f>H0[MSV03>QbP030:gHiP80<j7:00X0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPHP3oon03000000040000o`000000000003>QbP80[MSV00@0<j7:
0:gHiP2]f>H0[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX3
0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0
[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H2
03>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1S0?ooh0<0
000000<0003o0000000cXLX00P2]f>H0100cXLX0[MSV0:gHiP2]f>H203>QbP0:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gH
iP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh6D0oooP0P0000001@000?l000000000002]f>H0<j7:00<0[MSV
0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0c
XLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh005000000000?l00000
0000000cXLX00`2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:
0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gH
iP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6L0oooP
0P0000000`000?l0000003>QbP030:gHiP80<j7:00X0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0
<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPJ03oon02000000030000o`0cXLX0[MSV0080[MSV0P0cXLX02P2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080
[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1[0?ooh0040000o`2]f>H0[MSV0:gHiP80<j7:00X0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPJ`3oon000`0cXLX0003o0:gHiP020000000;03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPJ`3oon000`0cXLX0[MSV0000o`030000000:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gH
iP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh6/0oooP0P0cXLX03P000000003o000000000000[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80
[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK@3oon020000000<0000o`000000[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80
[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0c
XLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPKP3oon020000000;0000o`00000000000:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:
0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000
o`3oon1`0?ooh003000000000?l0003o0080000000H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX30:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>Q
bP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh700oooP0`00000020000?l00000
0000000cXLX0[MSV03>QbP2]f>H0<j7:0`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPL@3oon03000000070000o`00000000000:gHiP0cXLX0[MSV03>QbP03
0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0
[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H2
03>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1c0?ooh080
000000H0003o0000002]f>H0<j7:0:gHiP0cXLX30:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0
<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1d0?ooh080000000D0003o000000000000[MSV03>QbP030:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>Q
bP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1f0?ooh0050000
00000?l000000000000cXLX00`2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gH
iP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPMP3oon02000000030000o`000000<j7:00<0[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7L0oooP0P0000000`000?l000000:gHiP020:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>Q
bP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1g0?ooh0<00000
00@0003o0:gHiP2]f>H0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0603>QbP2]f>H0<j7:
03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]
f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh7P0oooP0P000000100cXLX0003o0:gHiP2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80
[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0c
XLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPNP3oon000`0cXLX0[MSV0000o`020000000503>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX3
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1j0?ooh00403>QbP2]f>H000000000
o`80000000@0[MSV03>QbP2]f>H0<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>Q
bP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1j0?ooh080<j7:
0P0000001P000?l000000000000cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0c
XLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0
[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO@3o
on02000000050000o`00000000000:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>Q
bP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]
f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh7h0oooP0P0000001000
0?l000000000000cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>Q
bP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO`3oon02000000030000o`000000<j7:0080[MSV
00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX2
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPP03oon02000000060000o`0cXLX0[MSV0:gHiP0cXLX0[MSV0P0c
XLX00`2]f>H0<j7:0:gHiP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPP`3oon001@000?l000000000000cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gH
iP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8<0oooP
00D000000000o`00000000000:gHiP0203>QbP030:gHiP0cXLX0[MSV0080[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX3
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon230?ooh080000000<0003o00000000
00000P0cXLX00`2]f>H0<j7:0:gHiP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPQ03oon02000000060000o`000000000003>QbP2]f>H0<j7:0`2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:
0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8D0oooP0P000000
1@000?l000000000002]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080
[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon260?ooh080000000@0003o000000000000<j7:0`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>Q
bP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8L0oooP0P0000000`000?l00000
000000030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>Q
bP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
R03oon02000000030000o`000000[MSV0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:
0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon290?ooh080000000D0003o000000000000[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8/0oooP00D000000000o`0000000000
03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:
0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8/0oooP0P000000
0`000?l0000003>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX3
0:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPS03oon0200000007
0000o`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H2
03>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8l0oooP00H0003o0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX3
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2?0?ooh00603>QbP000?l0000003>Q
bP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPS`3oon02000000040000o`000000[MSV03>Q
bP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh8l0oooP0`0000000`000?l0000003>QbP020:gHiP0303>Q
bP2]f>H0[MSV0080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV
00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2@0?ooh080000000<0003o0000000000000P2]f>H00`0cXLX0[MSV0:gHiP02
03>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPT@3oon02000000050000o`000000[MSV0:gHiP0cXLX00P2]f>H203>QbP<0[MSV0P0cXLX20:gH
iP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPTP3oon02000000040000
o`2]f>H0[MSV03>QbP80[MSV0P0cXLX30:gHiP80<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh9@0oooP00@0<j7:0000o`00000000000P2]f>H203>QbP<0[MSV
0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU03oon00
0`0cXLX000000000o`0300000080<j7:0`2]f>H203>QbP80[MSV0P0cXLX30:gHiP0303>QbP2]f>H0
<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2D0?ooh00403>QbP00000000000000o`<0000000@0<j7:0:gH
iP2]f>H0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPUP3oon02000000040000o`000000000003>QbP<0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80
[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPV03oon0010000000003o0000000000030:gHiP80
<j7:0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon04000000L0oooP00<000000?ooh03oon00o`3o
on2I0?ooh004000000000?l0000000000080[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0c
XLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@
0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00o`3oon2I0?ooh080000000@0003o
0000002]f>H0[MSV0P0cXLX20:gHiP80<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0030000003oon00oooP
00L0oooP1000003o0?ooh9T0oooP00<000000000o`2]f>H00P2]f>H203>QbP80[MSV0P0cXLX30:gH
iP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP020:gHiP0303>QbP3oon00oooP00H0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V
4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPV`3oon000`0cXLX0003o
0:gHiP020000000303>QbP2]f>H0[MSV0080<j7:0`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00
oooP000000L0oooP00<000000?ooh03oon00o`3oon2K0?ooh080<j7:00@0003o0000000000000000
0P2]f>H203>QbP<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon2M
0?ooh003000000000?l000000080000000<0[MSV03>QbP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPWP3oon001@000000003o000000000000[MSV0080<j7:0`2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80
[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW`3oon0010000000003o00000000000203>QbP<0
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9l0oooP0P00000010000?l0000003>Q
bP0cXLX30:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2P0?ooh080000000<0003o
0000000000000`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPXP3oon0010000000
003o0000000000020:gHiP0303>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2R0?ooh0800000
00L0003o0000002]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2S0?ooh0800000
00H0003o000000000000<j7:0:gHiP0cXLX20:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY03oon000`0cXLX00000
0000o`02000000050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2T0?ooh00703>QbP0000000000
0000o`000000[MSV03>QbP020:gHiP0:03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPYP3oon02000000030000o`2]f>H0<j7:
0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`00003o0?ooh:P0oooP00<0<j7:0000o`0000000P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ03oon02000000040000o`000000
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPZ03oon02000000040000o`000000000003>QbP80[MSV00L0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ@3oon020000
00030000o`00000000000080[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0P0c
XLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPZP3oon020000000;0000o`00000000000:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2[0?ooh080
000000X0003o000000000000<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2/0?ooh080000000T0003o0000000cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2]0?ooh080000000P0003o03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/03oon00
1`000?l000000000002]f>H0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2`0?ooh007000000000?l000000000000cXLX0[MSV03>QbP020:gHiP80<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh;00oooP0P0000001@000?l000000000002]f>H0<j7:0080[MSV0P0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP/@3oon02000000040000o`000000[MSV03>QbP80[MSV0P0cXLX20:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP/P3oon02000000030000o`000000<j7:0080[MSV0P0cXLX20:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP
0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP/`3oon02000000040000o`000000[MSV0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP/`3o
on03000000030000o`2]f>H0[MSV0080<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]03oon020000000303>QbP000?l0
00000080<j7:0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;H0oooP00D000000000o`000000000003>QbP02
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP]P3oon02000000030000o`000000<j7:0080[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2g0?ooh080000000D0003o000000000000[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh00500000000
0?l000000000000cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP^@3oon02000000030000o`000000<j7:00<0[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP0P00
00000`000?l000000:gHiP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2j0?ooh080000000<0003o0000002]f>H00P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^`3oon02
000000070000o`2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP_@3oon001`0cXLX0003o0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;d0oooP00<0<j7:0:gHiP00
0?l00P0000001`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2m0?ooh00403>QbP2]f>H000000000o`80000000H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh;d0oooP0P0cXLX2000000030000o`000000<j7:0080[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2o0?ooh080000000<0003o0000
000cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP`03oon02000000070000o`0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03oon001`3oon03000001P0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP``3oon001P000?l0[MSV0:gHiP0c
XLX0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP``3oon001P0cXLX0003o0000000cXLX0
[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP``3oon02000000040000o`000000[MSV03>Q
bP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP``3oon03000000030000o`000000<j7:0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPa03oon02000000030000o`00000000000080[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPa@3oon02000000050000o`000000[MSV0:gHiP0cXLX00P2]f>H02P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon360?oo
h080000000@0003o0:gHiP2]f>H0<j7:0P2]f>H02P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX20:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon380?ooh00403>QbP000?l000000000
0080[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPb03oon000`0cXLX000000000o`020000000;0:gHiP0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0oooP0?ooh0090?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb@3oon02
000000040000o`000000000003>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh<X0oooP00<000000000o`0000000P0000020:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3;0?ooh004
000000000?l0000000000080[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh<`0oooP00`000000000o`00000000000:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP3oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh<d0oooP00/000000000o`000000000003>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00L0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<d0oooP0P0000002@000?l00000
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP3oon00oooP00T0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3>0?oo
h080000000P0003o03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh=40oooP00L0003o0000000cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh=00oooP00P000000000o`00000000000:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh=00oooP0P0000001P000?l000000000000cXLX0[MSV03>QbP80[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh=40oooP0P0000001@000?l000000000002]f>H0<j7:0080[MSV00<0
<j7:0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh=80oooP0P00000010000?l000000:gHiP0cXLX20:gHiP0303>QbP3o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon3C0?ooh080000000<0003o0000000cXLX00P2]f>H00`0cXLX0oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPd`3oon03000000050000o`0cXLX0[MSV0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=@0oooP0P0000001@3o
on00003o0:gHiP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon3G0?ooh0040000o`000000000003>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP
0?l0oooPe`3oon0010000000003o00000000000;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3G
0?ooh080000000<0003o0000003oon002P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon3G0?ooh080000000<0003o0?oo
h03oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HC0?ooh0030000003oon00oooP00D0
oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3V0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP
0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a
0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh009
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000
603oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=`0n_3V
100000020?[`iPP000000P3jl>H4000000070?[`iP00000000000000003jl>H000000?[`iP0<0000
00030?[`iP000000000000@0000000@0n_3V0000000000000000203jl>H5000000@0n_3V1`000000
0`3jl>H000000?[`iP03000000T0n_3V1@0000020?[`iP@000000P3jl>H500000180n_3V1P000006
0?[`iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H0000000000000003T0?[`iP40oooo003M
0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000`3jl>H01`000000n_3V00000000
0000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V0?[`iP8000000P3jl>H200000004
0?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01@3jl>H20000
00030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000000`3jl>H00000000000040?[`iP80
00000`3jl>H2000000D0n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000d0n_3V0P0000020?[`iP80
000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`
iP8000000P3jl>H200000080n_3V0P00000<0?[`iPD000001@3jl>H2000000H0n_3V1@0000060?[`
iP<00000iP3jl>H10?ooo`00g@3jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V00000000
0000n_3V0000003jl>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V0P00
00020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01P3jl>H300000>H0n_3V0@3o
ool00=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V
000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0`0000000`3jl>H000000?[`iP0B0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80
000000<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H200000080n_3V0P0000000`3jl>H00000
00000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`iPD00000
0P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000;0?[`iPD00000
0P3jl>H400000080n_3V0`0000000`3jl>H000000000000C0?[`iP8000003`3jl>H3000000050?[`
iP00000000000000003jl>H01000003O0?[`iP40oooo003M0?[`iP8000000P3jl>H2000003<0n_3V
0P0000030?[`iP030000003jl>H0n_3V01P0n_3V0P00000Q0?[`iP@00000603jl>H00`000000n_3V
0?[`iP3O0?[`iP40oooo003L0?[`iPH00000103jl>H2000002l0n_3V1@00000K0?[`iP<000008@3j
l>H2000001T0n_3V00<000000?[`iP3jl>H0gP3jl>H10?ooo`00o`3jl>Ih0?[`iP030000003jl>H0
n_3V0=d0n_3V0@3oool00?l0n_3VM@3jl>H010000000n_3V0?[`iP00003O0?[`iP40oooo003o0?[`
iWH0n_3V0P00003P0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02791 .01472 L
.02791 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02791 .01472 L
.02791 .16187 L
s
1 .894 .882 r
.02791 .16187 m
.02791 .01476 L
.03349 .01476 L
.03349 .16187 L
F
.804 .522 .247 r
.02791 .16187 m
.02791 .01476 L
.03349 .01476 L
.03349 .16187 L
s
1 .894 .882 r
.03349 .16187 m
.03349 .01483 L
.03756 .01483 L
.03756 .16187 L
F
.804 .522 .247 r
.03349 .16187 m
.03349 .01483 L
.03756 .01483 L
.03756 .16187 L
s
1 .894 .882 r
.03756 .16187 m
.03756 .01488 L
.04189 .01488 L
.04189 .16187 L
F
.804 .522 .247 r
.03756 .16187 m
.03756 .01488 L
.04189 .01488 L
.04189 .16187 L
s
1 .894 .882 r
.04189 .16187 m
.04189 .01501 L
.04652 .01501 L
.04652 .16187 L
F
.804 .522 .247 r
.04189 .16187 m
.04189 .01501 L
.04652 .01501 L
.04652 .16187 L
s
1 .894 .882 r
.04652 .16187 m
.04652 .01507 L
.04982 .01507 L
.04982 .16187 L
F
.804 .522 .247 r
.04652 .16187 m
.04652 .01507 L
.04982 .01507 L
.04982 .16187 L
s
1 .894 .882 r
.04982 .16187 m
.04982 .01521 L
.05221 .01521 L
.05221 .16187 L
F
.804 .522 .247 r
.04982 .16187 m
.04982 .01521 L
.05221 .01521 L
.05221 .16187 L
s
1 .894 .882 r
.05221 .16187 m
.05221 .01526 L
.0572 .01526 L
.0572 .16187 L
F
.804 .522 .247 r
.05221 .16187 m
.05221 .01526 L
.0572 .01526 L
.0572 .16187 L
s
1 .894 .882 r
.0572 .16187 m
.0572 .01553 L
.05998 .01553 L
.05998 .16187 L
F
.804 .522 .247 r
.0572 .16187 m
.0572 .01553 L
.05998 .01553 L
.05998 .16187 L
s
1 .894 .882 r
.05998 .16187 m
.05998 .0157 L
.06487 .0157 L
.06487 .16187 L
F
.804 .522 .247 r
.05998 .16187 m
.05998 .0157 L
.06487 .0157 L
.06487 .16187 L
s
1 .894 .882 r
.06487 .16187 m
.06487 .01585 L
.06944 .01585 L
.06944 .16187 L
F
.804 .522 .247 r
.06487 .16187 m
.06487 .01585 L
.06944 .01585 L
.06944 .16187 L
s
1 .894 .882 r
.06944 .16187 m
.06944 .01608 L
.07446 .01608 L
.07446 .16187 L
F
.804 .522 .247 r
.06944 .16187 m
.06944 .01608 L
.07446 .01608 L
.07446 .16187 L
s
1 .894 .882 r
.07446 .16187 m
.07446 .01664 L
.07977 .01664 L
.07977 .16187 L
F
.804 .522 .247 r
.07446 .16187 m
.07446 .01664 L
.07977 .01664 L
.07977 .16187 L
s
1 .894 .882 r
.07977 .16187 m
.07977 .01703 L
.08469 .01703 L
.08469 .16187 L
F
.804 .522 .247 r
.07977 .16187 m
.07977 .01703 L
.08469 .01703 L
.08469 .16187 L
s
1 .894 .882 r
.08469 .16187 m
.08469 .01745 L
.08901 .01745 L
.08901 .16187 L
F
.804 .522 .247 r
.08469 .16187 m
.08469 .01745 L
.08901 .01745 L
.08901 .16187 L
s
1 .894 .882 r
.08901 .16187 m
.08901 .01749 L
.0914 .01749 L
.0914 .16187 L
F
.804 .522 .247 r
.08901 .16187 m
.08901 .01749 L
.0914 .01749 L
.0914 .16187 L
s
1 .894 .882 r
.0914 .16187 m
.0914 .01791 L
.09551 .01791 L
.09551 .16187 L
F
.804 .522 .247 r
.0914 .16187 m
.0914 .01791 L
.09551 .01791 L
.09551 .16187 L
s
1 .894 .882 r
.09551 .16187 m
.09551 .01814 L
.09787 .01814 L
.09787 .16187 L
F
.804 .522 .247 r
.09551 .16187 m
.09551 .01814 L
.09787 .01814 L
.09787 .16187 L
s
1 .894 .882 r
.09787 .16187 m
.09787 .01852 L
.10067 .01852 L
.10067 .16187 L
F
.804 .522 .247 r
.09787 .16187 m
.09787 .01852 L
.10067 .01852 L
.10067 .16187 L
s
1 .894 .882 r
.10067 .16187 m
.10067 .01914 L
.10639 .01914 L
.10639 .16187 L
F
.804 .522 .247 r
.10067 .16187 m
.10067 .01914 L
.10639 .01914 L
.10639 .16187 L
s
1 .894 .882 r
.10639 .16187 m
.10639 .01917 L
.10922 .01917 L
.10922 .16187 L
F
.804 .522 .247 r
.10639 .16187 m
.10639 .01917 L
.10922 .01917 L
.10922 .16187 L
s
1 .894 .882 r
.10922 .16187 m
.10922 .01979 L
.11477 .01979 L
.11477 .16187 L
F
.804 .522 .247 r
.10922 .16187 m
.10922 .01979 L
.11477 .01979 L
.11477 .16187 L
s
1 .894 .882 r
.11477 .16187 m
.11477 .02032 L
.11746 .02032 L
.11746 .16187 L
F
.804 .522 .247 r
.11477 .16187 m
.11477 .02032 L
.11746 .02032 L
.11746 .16187 L
s
1 .894 .882 r
.11746 .16187 m
.11746 .02087 L
.12171 .02087 L
.12171 .16187 L
F
.804 .522 .247 r
.11746 .16187 m
.11746 .02087 L
.12171 .02087 L
.12171 .16187 L
s
1 .894 .882 r
.12171 .16187 m
.12171 .0212 L
.12627 .0212 L
.12627 .16187 L
F
.804 .522 .247 r
.12171 .16187 m
.12171 .0212 L
.12627 .0212 L
.12627 .16187 L
s
1 .894 .882 r
.12627 .16187 m
.12627 .02219 L
.13208 .02219 L
.13208 .16187 L
F
.804 .522 .247 r
.12627 .16187 m
.12627 .02219 L
.13208 .02219 L
.13208 .16187 L
s
1 .894 .882 r
.13208 .16187 m
.13208 .0229 L
.13652 .0229 L
.13652 .16187 L
F
.804 .522 .247 r
.13208 .16187 m
.13208 .0229 L
.13652 .0229 L
.13652 .16187 L
s
1 .894 .882 r
.13652 .16187 m
.13652 .02326 L
.14226 .02326 L
.14226 .16187 L
F
.804 .522 .247 r
.13652 .16187 m
.13652 .02326 L
.14226 .02326 L
.14226 .16187 L
s
1 .894 .882 r
.14226 .16187 m
.14226 .02454 L
.14803 .02454 L
.14803 .16187 L
F
.804 .522 .247 r
.14226 .16187 m
.14226 .02454 L
.14803 .02454 L
.14803 .16187 L
s
1 .894 .882 r
.14803 .16187 m
.14803 .02515 L
.15228 .02515 L
.15228 .16187 L
F
.804 .522 .247 r
.14803 .16187 m
.14803 .02515 L
.15228 .02515 L
.15228 .16187 L
s
1 .894 .882 r
.15228 .16187 m
.15228 .0256 L
.15609 .0256 L
.15609 .16187 L
F
.804 .522 .247 r
.15228 .16187 m
.15228 .0256 L
.15609 .0256 L
.15609 .16187 L
s
1 .894 .882 r
.15609 .16187 m
.15609 .02616 L
.15859 .02616 L
.15859 .16187 L
F
.804 .522 .247 r
.15609 .16187 m
.15609 .02616 L
.15859 .02616 L
.15859 .16187 L
s
1 .894 .882 r
.15859 .16187 m
.15859 .02655 L
.16333 .02655 L
.16333 .16187 L
F
.804 .522 .247 r
.15859 .16187 m
.15859 .02655 L
.16333 .02655 L
.16333 .16187 L
s
1 .894 .882 r
.16333 .16187 m
.16333 .02737 L
.16852 .02737 L
.16852 .16187 L
F
.804 .522 .247 r
.16333 .16187 m
.16333 .02737 L
.16852 .02737 L
.16852 .16187 L
s
1 .894 .882 r
.16852 .16187 m
.16852 .0284 L
.17359 .0284 L
.17359 .16187 L
F
.804 .522 .247 r
.16852 .16187 m
.16852 .0284 L
.17359 .0284 L
.17359 .16187 L
s
1 .894 .882 r
.17359 .16187 m
.17359 .02938 L
.1769 .02938 L
.1769 .16187 L
F
.804 .522 .247 r
.17359 .16187 m
.17359 .02938 L
.1769 .02938 L
.1769 .16187 L
s
1 .894 .882 r
.1769 .16187 m
.1769 .03027 L
.18216 .03027 L
.18216 .16187 L
F
.804 .522 .247 r
.1769 .16187 m
.1769 .03027 L
.18216 .03027 L
.18216 .16187 L
s
1 .894 .882 r
.18216 .16187 m
.18216 .03109 L
.18418 .03109 L
.18418 .16187 L
F
.804 .522 .247 r
.18216 .16187 m
.18216 .03109 L
.18418 .03109 L
.18418 .16187 L
s
1 .894 .882 r
.18418 .16187 m
.18418 .03149 L
.18667 .03149 L
.18667 .16187 L
F
.804 .522 .247 r
.18418 .16187 m
.18418 .03149 L
.18667 .03149 L
.18667 .16187 L
s
1 .894 .882 r
.18667 .16187 m
.18667 .03197 L
.18934 .03197 L
.18934 .16187 L
F
.804 .522 .247 r
.18667 .16187 m
.18667 .03197 L
.18934 .03197 L
.18934 .16187 L
s
1 .894 .882 r
.18934 .16187 m
.18934 .03294 L
.19223 .03294 L
.19223 .16187 L
F
.804 .522 .247 r
.18934 .16187 m
.18934 .03294 L
.19223 .03294 L
.19223 .16187 L
s
1 .894 .882 r
.19223 .16187 m
.19223 .03416 L
.19773 .03416 L
.19773 .16187 L
F
.804 .522 .247 r
.19223 .16187 m
.19223 .03416 L
.19773 .03416 L
.19773 .16187 L
s
1 .894 .882 r
.19773 .16187 m
.19773 .0347 L
.20325 .0347 L
.20325 .16187 L
F
.804 .522 .247 r
.19773 .16187 m
.19773 .0347 L
.20325 .0347 L
.20325 .16187 L
s
1 .894 .882 r
.20325 .16187 m
.20325 .03567 L
.20604 .03567 L
.20604 .16187 L
F
.804 .522 .247 r
.20325 .16187 m
.20325 .03567 L
.20604 .03567 L
.20604 .16187 L
s
1 .894 .882 r
.20604 .16187 m
.20604 .03653 L
.20785 .03653 L
.20785 .16187 L
F
.804 .522 .247 r
.20604 .16187 m
.20604 .03653 L
.20785 .03653 L
.20785 .16187 L
s
1 .894 .882 r
.20785 .16187 m
.20785 .03713 L
.21362 .03713 L
.21362 .16187 L
F
.804 .522 .247 r
.20785 .16187 m
.20785 .03713 L
.21362 .03713 L
.21362 .16187 L
s
1 .894 .882 r
.21362 .16187 m
.21362 .03872 L
.21821 .03872 L
.21821 .16187 L
F
.804 .522 .247 r
.21362 .16187 m
.21362 .03872 L
.21821 .03872 L
.21821 .16187 L
s
1 .894 .882 r
.21821 .16187 m
.21821 .03946 L
.22257 .03946 L
.22257 .16187 L
F
.804 .522 .247 r
.21821 .16187 m
.21821 .03946 L
.22257 .03946 L
.22257 .16187 L
s
1 .894 .882 r
.22257 .16187 m
.22257 .04048 L
.22564 .04048 L
.22564 .16187 L
F
.804 .522 .247 r
.22257 .16187 m
.22257 .04048 L
.22564 .04048 L
.22564 .16187 L
s
1 .894 .882 r
.22564 .16187 m
.22564 .04188 L
.23144 .04188 L
.23144 .16187 L
F
.804 .522 .247 r
.22564 .16187 m
.22564 .04188 L
.23144 .04188 L
.23144 .16187 L
s
1 .894 .882 r
.23144 .16187 m
.23144 .04302 L
.23334 .04302 L
.23334 .16187 L
F
.804 .522 .247 r
.23144 .16187 m
.23144 .04302 L
.23334 .04302 L
.23334 .16187 L
s
1 .894 .882 r
.23334 .16187 m
.23334 .04424 L
.23779 .04424 L
.23779 .16187 L
F
.804 .522 .247 r
.23334 .16187 m
.23334 .04424 L
.23779 .04424 L
.23779 .16187 L
s
1 .894 .882 r
.23779 .16187 m
.23779 .04475 L
.24092 .04475 L
.24092 .16187 L
F
.804 .522 .247 r
.23779 .16187 m
.23779 .04475 L
.24092 .04475 L
.24092 .16187 L
s
1 .894 .882 r
.24092 .16187 m
.24092 .04612 L
.24422 .04612 L
.24422 .16187 L
F
.804 .522 .247 r
.24092 .16187 m
.24092 .04612 L
.24422 .04612 L
.24422 .16187 L
s
1 .894 .882 r
.24422 .16187 m
.24422 .04666 L
.24814 .04666 L
.24814 .16187 L
F
.804 .522 .247 r
.24422 .16187 m
.24422 .04666 L
.24814 .04666 L
.24814 .16187 L
s
1 .894 .882 r
.24814 .16187 m
.24814 .04806 L
.25184 .04806 L
.25184 .16187 L
F
.804 .522 .247 r
.24814 .16187 m
.24814 .04806 L
.25184 .04806 L
.25184 .16187 L
s
1 .894 .882 r
.25184 .16187 m
.25184 .04885 L
.25606 .04885 L
.25606 .16187 L
F
.804 .522 .247 r
.25184 .16187 m
.25184 .04885 L
.25606 .04885 L
.25606 .16187 L
s
1 .894 .882 r
.25606 .16187 m
.25606 .05073 L
.26 .05073 L
.26 .16187 L
F
.804 .522 .247 r
.25606 .16187 m
.25606 .05073 L
.26 .05073 L
.26 .16187 L
s
1 .894 .882 r
.26 .16187 m
.26 .05131 L
.26468 .05131 L
.26468 .16187 L
F
.804 .522 .247 r
.26 .16187 m
.26 .05131 L
.26468 .05131 L
.26468 .16187 L
s
1 .894 .882 r
.26468 .16187 m
.26468 .05268 L
.26682 .05268 L
.26682 .16187 L
F
.804 .522 .247 r
.26468 .16187 m
.26468 .05268 L
.26682 .05268 L
.26682 .16187 L
s
1 .894 .882 r
.26682 .16187 m
.26682 .05454 L
.27161 .05454 L
.27161 .16187 L
F
.804 .522 .247 r
.26682 .16187 m
.26682 .05454 L
.27161 .05454 L
.27161 .16187 L
s
1 .894 .882 r
.27161 .16187 m
.27161 .05528 L
.27528 .05528 L
.27528 .16187 L
F
.804 .522 .247 r
.27161 .16187 m
.27161 .05528 L
.27528 .05528 L
.27528 .16187 L
s
1 .894 .882 r
.27528 .16187 m
.27528 .05588 L
.27922 .05588 L
.27922 .16187 L
F
.804 .522 .247 r
.27528 .16187 m
.27528 .05588 L
.27922 .05588 L
.27922 .16187 L
s
1 .894 .882 r
.27922 .16187 m
.27922 .05774 L
.28451 .05774 L
.28451 .16187 L
F
.804 .522 .247 r
.27922 .16187 m
.27922 .05774 L
.28451 .05774 L
.28451 .16187 L
s
1 .894 .882 r
.28451 .16187 m
.28451 .05916 L
.28816 .05916 L
.28816 .16187 L
F
.804 .522 .247 r
.28451 .16187 m
.28451 .05916 L
.28816 .05916 L
.28816 .16187 L
s
1 .894 .882 r
.28816 .16187 m
.28816 .0611 L
.29217 .0611 L
.29217 .16187 L
F
.804 .522 .247 r
.28816 .16187 m
.28816 .0611 L
.29217 .0611 L
.29217 .16187 L
s
1 .894 .882 r
.29217 .16187 m
.29217 .06266 L
.29641 .06266 L
.29641 .16187 L
F
.804 .522 .247 r
.29217 .16187 m
.29217 .06266 L
.29641 .06266 L
.29641 .16187 L
s
1 .894 .882 r
.29641 .16187 m
.29641 .06341 L
.30067 .06341 L
.30067 .16187 L
F
.804 .522 .247 r
.29641 .16187 m
.29641 .06341 L
.30067 .06341 L
.30067 .16187 L
s
1 .894 .882 r
.30067 .16187 m
.30067 .0653 L
.30426 .0653 L
.30426 .16187 L
F
.804 .522 .247 r
.30067 .16187 m
.30067 .0653 L
.30426 .0653 L
.30426 .16187 L
s
1 .894 .882 r
.30426 .16187 m
.30426 .06641 L
.30832 .06641 L
.30832 .16187 L
F
.804 .522 .247 r
.30426 .16187 m
.30426 .06641 L
.30832 .06641 L
.30832 .16187 L
s
1 .894 .882 r
.30832 .16187 m
.30832 .06778 L
.31381 .06778 L
.31381 .16187 L
F
.804 .522 .247 r
.30832 .16187 m
.30832 .06778 L
.31381 .06778 L
.31381 .16187 L
s
1 .894 .882 r
.31381 .16187 m
.31381 .06953 L
.31953 .06953 L
.31953 .16187 L
F
.804 .522 .247 r
.31381 .16187 m
.31381 .06953 L
.31953 .06953 L
.31953 .16187 L
s
1 .894 .882 r
.31953 .16187 m
.31953 .07189 L
.3218 .07189 L
.3218 .16187 L
F
.804 .522 .247 r
.31953 .16187 m
.31953 .07189 L
.3218 .07189 L
.3218 .16187 L
s
1 .894 .882 r
.3218 .16187 m
.3218 .07388 L
.32589 .07388 L
.32589 .16187 L
F
.804 .522 .247 r
.3218 .16187 m
.3218 .07388 L
.32589 .07388 L
.32589 .16187 L
s
1 .894 .882 r
.32589 .16187 m
.32589 .07524 L
.33123 .07524 L
.33123 .16187 L
F
.804 .522 .247 r
.32589 .16187 m
.32589 .07524 L
.33123 .07524 L
.33123 .16187 L
s
1 .894 .882 r
.33123 .16187 m
.33123 .07636 L
.33425 .07636 L
.33425 .16187 L
F
.804 .522 .247 r
.33123 .16187 m
.33123 .07636 L
.33425 .07636 L
.33425 .16187 L
s
1 .894 .882 r
.33425 .16187 m
.33425 .07748 L
.33922 .07748 L
.33922 .16187 L
F
.804 .522 .247 r
.33425 .16187 m
.33425 .07748 L
.33922 .07748 L
.33922 .16187 L
s
1 .894 .882 r
.33922 .16187 m
.33922 .07938 L
.34176 .07938 L
.34176 .16187 L
F
.804 .522 .247 r
.33922 .16187 m
.33922 .07938 L
.34176 .07938 L
.34176 .16187 L
s
1 .894 .882 r
.34176 .16187 m
.34176 .08064 L
.34493 .08064 L
.34493 .16187 L
F
.804 .522 .247 r
.34176 .16187 m
.34176 .08064 L
.34493 .08064 L
.34493 .16187 L
s
1 .894 .882 r
.34493 .16187 m
.34493 .08299 L
.35008 .08299 L
.35008 .16187 L
F
.804 .522 .247 r
.34493 .16187 m
.34493 .08299 L
.35008 .08299 L
.35008 .16187 L
s
1 .894 .882 r
.35008 .16187 m
.35008 .08464 L
.35258 .08464 L
.35258 .16187 L
F
.804 .522 .247 r
.35008 .16187 m
.35008 .08464 L
.35258 .08464 L
.35258 .16187 L
s
1 .894 .882 r
.35258 .16187 m
.35258 .08533 L
.35701 .08533 L
.35701 .16187 L
F
.804 .522 .247 r
.35258 .16187 m
.35258 .08533 L
.35701 .08533 L
.35701 .16187 L
s
1 .894 .882 r
.35701 .16187 m
.35701 .0886 L
.36132 .0886 L
.36132 .16187 L
F
.804 .522 .247 r
.35701 .16187 m
.35701 .0886 L
.36132 .0886 L
.36132 .16187 L
s
1 .894 .882 r
.36132 .16187 m
.36132 .08896 L
.36609 .08896 L
.36609 .16187 L
F
.804 .522 .247 r
.36132 .16187 m
.36132 .08896 L
.36609 .08896 L
.36609 .16187 L
s
1 .894 .882 r
.36609 .16187 m
.36609 .09202 L
.36962 .09202 L
.36962 .16187 L
F
.804 .522 .247 r
.36609 .16187 m
.36609 .09202 L
.36962 .09202 L
.36962 .16187 L
s
1 .894 .882 r
.36962 .16187 m
.36962 .09305 L
.37214 .09305 L
.37214 .16187 L
F
.804 .522 .247 r
.36962 .16187 m
.36962 .09305 L
.37214 .09305 L
.37214 .16187 L
s
1 .894 .882 r
.37214 .16187 m
.37214 .09429 L
.37426 .09429 L
.37426 .16187 L
F
.804 .522 .247 r
.37214 .16187 m
.37214 .09429 L
.37426 .09429 L
.37426 .16187 L
s
1 .894 .882 r
.37426 .16187 m
.37426 .09625 L
.37956 .09625 L
.37956 .16187 L
F
.804 .522 .247 r
.37426 .16187 m
.37426 .09625 L
.37956 .09625 L
.37956 .16187 L
s
1 .894 .882 r
.37956 .16187 m
.37956 .09826 L
.38528 .09826 L
.38528 .16187 L
F
.804 .522 .247 r
.37956 .16187 m
.37956 .09826 L
.38528 .09826 L
.38528 .16187 L
s
1 .894 .882 r
.38528 .16187 m
.38528 .10133 L
.38962 .10133 L
.38962 .16187 L
F
.804 .522 .247 r
.38528 .16187 m
.38528 .10133 L
.38962 .10133 L
.38962 .16187 L
s
1 .894 .882 r
.38962 .16187 m
.38962 .10165 L
.39333 .10165 L
.39333 .16187 L
F
.804 .522 .247 r
.38962 .16187 m
.38962 .10165 L
.39333 .10165 L
.39333 .16187 L
s
1 .894 .882 r
.39333 .16187 m
.39333 .10392 L
.39612 .10392 L
.39612 .16187 L
F
.804 .522 .247 r
.39333 .16187 m
.39333 .10392 L
.39612 .10392 L
.39612 .16187 L
s
1 .894 .882 r
.39612 .16187 m
.39612 .10633 L
.39999 .10633 L
.39999 .16187 L
F
.804 .522 .247 r
.39612 .16187 m
.39612 .10633 L
.39999 .10633 L
.39999 .16187 L
s
1 .894 .882 r
.39999 .16187 m
.39999 .107 L
.40202 .107 L
.40202 .16187 L
F
.804 .522 .247 r
.39999 .16187 m
.39999 .107 L
.40202 .107 L
.40202 .16187 L
s
1 .894 .882 r
.40202 .16187 m
.40202 .10912 L
.40607 .10912 L
.40607 .16187 L
F
.804 .522 .247 r
.40202 .16187 m
.40202 .10912 L
.40607 .10912 L
.40607 .16187 L
s
1 .894 .882 r
.40607 .16187 m
.40607 .11002 L
.40897 .11002 L
.40897 .16187 L
F
.804 .522 .247 r
.40607 .16187 m
.40607 .11002 L
.40897 .11002 L
.40897 .16187 L
s
1 .894 .882 r
.40897 .16187 m
.40897 .11166 L
.41232 .11166 L
.41232 .16187 L
F
.804 .522 .247 r
.40897 .16187 m
.40897 .11166 L
.41232 .11166 L
.41232 .16187 L
s
1 .894 .882 r
.41232 .16187 m
.41232 .11359 L
.41609 .11359 L
.41609 .16187 L
F
.804 .522 .247 r
.41232 .16187 m
.41232 .11359 L
.41609 .11359 L
.41609 .16187 L
s
1 .894 .882 r
.41609 .16187 m
.41609 .11497 L
.42064 .11497 L
.42064 .16187 L
F
.804 .522 .247 r
.41609 .16187 m
.41609 .11497 L
.42064 .11497 L
.42064 .16187 L
s
1 .894 .882 r
.42064 .16187 m
.42064 .1171 L
.42635 .1171 L
.42635 .16187 L
F
.804 .522 .247 r
.42064 .16187 m
.42064 .1171 L
.42635 .1171 L
.42635 .16187 L
s
1 .894 .882 r
.42635 .16187 m
.42635 .1205 L
.43056 .1205 L
.43056 .16187 L
F
.804 .522 .247 r
.42635 .16187 m
.42635 .1205 L
.43056 .1205 L
.43056 .16187 L
s
1 .894 .882 r
.43056 .16187 m
.43056 .12269 L
.43353 .12269 L
.43353 .16187 L
F
.804 .522 .247 r
.43056 .16187 m
.43056 .12269 L
.43353 .12269 L
.43353 .16187 L
s
1 .894 .882 r
.43353 .16187 m
.43353 .12519 L
.43666 .12519 L
.43666 .16187 L
F
.804 .522 .247 r
.43353 .16187 m
.43353 .12519 L
.43666 .12519 L
.43666 .16187 L
s
1 .894 .882 r
.43666 .16187 m
.43666 .12587 L
.43897 .12587 L
.43897 .16187 L
F
.804 .522 .247 r
.43666 .16187 m
.43666 .12587 L
.43897 .12587 L
.43897 .16187 L
s
1 .894 .882 r
.43897 .16187 m
.43897 .12748 L
.44243 .12748 L
.44243 .16187 L
F
.804 .522 .247 r
.43897 .16187 m
.43897 .12748 L
.44243 .12748 L
.44243 .16187 L
s
1 .894 .882 r
.44243 .16187 m
.44243 .12876 L
.4468 .12876 L
.4468 .16187 L
F
.804 .522 .247 r
.44243 .16187 m
.44243 .12876 L
.4468 .12876 L
.4468 .16187 L
s
1 .894 .882 r
.4468 .16187 m
.4468 .13324 L
.45144 .13324 L
.45144 .16187 L
F
.804 .522 .247 r
.4468 .16187 m
.4468 .13324 L
.45144 .13324 L
.45144 .16187 L
s
1 .894 .882 r
.45144 .16187 m
.45144 .13392 L
.45482 .13392 L
.45482 .16187 L
F
.804 .522 .247 r
.45144 .16187 m
.45144 .13392 L
.45482 .13392 L
.45482 .16187 L
s
1 .894 .882 r
.45482 .16187 m
.45482 .13745 L
.46057 .13745 L
.46057 .16187 L
F
.804 .522 .247 r
.45482 .16187 m
.45482 .13745 L
.46057 .13745 L
.46057 .16187 L
s
1 .894 .882 r
.46057 .16187 m
.46057 .13951 L
.46419 .13951 L
.46419 .16187 L
F
.804 .522 .247 r
.46057 .16187 m
.46057 .13951 L
.46419 .13951 L
.46419 .16187 L
s
1 .894 .882 r
.46419 .16187 m
.46419 .14074 L
.46845 .14074 L
.46845 .16187 L
F
.804 .522 .247 r
.46419 .16187 m
.46419 .14074 L
.46845 .14074 L
.46845 .16187 L
s
1 .894 .882 r
.46845 .16187 m
.46845 .1442 L
.47235 .1442 L
.47235 .16187 L
F
.804 .522 .247 r
.46845 .16187 m
.46845 .1442 L
.47235 .1442 L
.47235 .16187 L
s
1 .894 .882 r
.47235 .16187 m
.47235 .14542 L
.47414 .14542 L
.47414 .16187 L
F
.804 .522 .247 r
.47235 .16187 m
.47235 .14542 L
.47414 .14542 L
.47414 .16187 L
s
1 .894 .882 r
.47414 .16187 m
.47414 .14811 L
.47925 .14811 L
.47925 .16187 L
F
.804 .522 .247 r
.47414 .16187 m
.47414 .14811 L
.47925 .14811 L
.47925 .16187 L
s
1 .894 .882 r
.47925 .16187 m
.47925 .14934 L
.48154 .14934 L
.48154 .16187 L
F
.804 .522 .247 r
.47925 .16187 m
.47925 .14934 L
.48154 .14934 L
.48154 .16187 L
s
1 .894 .882 r
.48154 .16187 m
.48154 .15082 L
.48441 .15082 L
.48441 .16187 L
F
.804 .522 .247 r
.48154 .16187 m
.48154 .15082 L
.48441 .15082 L
.48441 .16187 L
s
1 .894 .882 r
.48441 .16187 m
.48441 .15296 L
.48816 .15296 L
.48816 .16187 L
F
.804 .522 .247 r
.48441 .16187 m
.48441 .15296 L
.48816 .15296 L
.48816 .16187 L
s
1 .894 .882 r
.48816 .16187 m
.48816 .15506 L
.49298 .15506 L
.49298 .16187 L
F
.804 .522 .247 r
.48816 .16187 m
.48816 .15506 L
.49298 .15506 L
.49298 .16187 L
s
1 .894 .882 r
.49298 .16187 m
.49298 .15812 L
.49705 .15812 L
.49705 .16187 L
F
.804 .522 .247 r
.49298 .16187 m
.49298 .15812 L
.49705 .15812 L
.49705 .16187 L
s
.678 .847 .902 r
.49705 .16187 m
.49705 .16272 L
.50285 .16272 L
.50285 .16187 L
F
.2 .63 .79 r
.49705 .16187 m
.49705 .16272 L
.50285 .16272 L
.50285 .16187 L
s
.678 .847 .902 r
.50285 .16187 m
.50285 .16477 L
.505 .16477 L
.505 .16187 L
F
.2 .63 .79 r
.50285 .16187 m
.50285 .16477 L
.505 .16477 L
.505 .16187 L
s
.678 .847 .902 r
.505 .16187 m
.505 .16613 L
.5078 .16613 L
.5078 .16187 L
F
.2 .63 .79 r
.505 .16187 m
.505 .16613 L
.5078 .16613 L
.5078 .16187 L
s
.678 .847 .902 r
.5078 .16187 m
.5078 .16692 L
.51316 .16692 L
.51316 .16187 L
F
.2 .63 .79 r
.5078 .16187 m
.5078 .16692 L
.51316 .16692 L
.51316 .16187 L
s
.678 .847 .902 r
.51316 .16187 m
.51316 .1709 L
.51499 .1709 L
.51499 .16187 L
F
.2 .63 .79 r
.51316 .16187 m
.51316 .1709 L
.51499 .1709 L
.51499 .16187 L
s
.678 .847 .902 r
.51499 .16187 m
.51499 .17264 L
.51876 .17264 L
.51876 .16187 L
F
.2 .63 .79 r
.51499 .16187 m
.51499 .17264 L
.51876 .17264 L
.51876 .16187 L
s
.678 .847 .902 r
.51876 .16187 m
.51876 .17469 L
.52442 .17469 L
.52442 .16187 L
F
.2 .63 .79 r
.51876 .16187 m
.51876 .17469 L
.52442 .17469 L
.52442 .16187 L
s
.678 .847 .902 r
.52442 .16187 m
.52442 .1777 L
.5284 .1777 L
.5284 .16187 L
F
.2 .63 .79 r
.52442 .16187 m
.52442 .1777 L
.5284 .1777 L
.5284 .16187 L
s
.678 .847 .902 r
.5284 .16187 m
.5284 .18078 L
.53375 .18078 L
.53375 .16187 L
F
.2 .63 .79 r
.5284 .16187 m
.5284 .18078 L
.53375 .18078 L
.53375 .16187 L
s
.678 .847 .902 r
.53375 .16187 m
.53375 .18357 L
.53581 .18357 L
.53581 .16187 L
F
.2 .63 .79 r
.53375 .16187 m
.53375 .18357 L
.53581 .18357 L
.53581 .16187 L
s
.678 .847 .902 r
.53581 .16187 m
.53581 .18511 L
.53885 .18511 L
.53885 .16187 L
F
.2 .63 .79 r
.53581 .16187 m
.53581 .18511 L
.53885 .18511 L
.53885 .16187 L
s
.678 .847 .902 r
.53885 .16187 m
.53885 .18752 L
.54402 .18752 L
.54402 .16187 L
F
.2 .63 .79 r
.53885 .16187 m
.53885 .18752 L
.54402 .18752 L
.54402 .16187 L
s
.678 .847 .902 r
.54402 .16187 m
.54402 .19274 L
.54774 .19274 L
.54774 .16187 L
F
.2 .63 .79 r
.54402 .16187 m
.54402 .19274 L
.54774 .19274 L
.54774 .16187 L
s
.678 .847 .902 r
.54774 .16187 m
.54774 .19343 L
.54987 .19343 L
.54987 .16187 L
F
.2 .63 .79 r
.54774 .16187 m
.54774 .19343 L
.54987 .19343 L
.54987 .16187 L
s
.678 .847 .902 r
.54987 .16187 m
.54987 .19664 L
.55513 .19664 L
.55513 .16187 L
F
.2 .63 .79 r
.54987 .16187 m
.54987 .19664 L
.55513 .19664 L
.55513 .16187 L
s
.678 .847 .902 r
.55513 .16187 m
.55513 .19813 L
.55779 .19813 L
.55779 .16187 L
F
.2 .63 .79 r
.55513 .16187 m
.55513 .19813 L
.55779 .19813 L
.55779 .16187 L
s
.678 .847 .902 r
.55779 .16187 m
.55779 .20143 L
.56343 .20143 L
.56343 .16187 L
F
.2 .63 .79 r
.55779 .16187 m
.55779 .20143 L
.56343 .20143 L
.56343 .16187 L
s
.678 .847 .902 r
.56343 .16187 m
.56343 .20406 L
.56552 .20406 L
.56552 .16187 L
F
.2 .63 .79 r
.56343 .16187 m
.56343 .20406 L
.56552 .20406 L
.56552 .16187 L
s
.678 .847 .902 r
.56552 .16187 m
.56552 .20522 L
.56743 .20522 L
.56743 .16187 L
F
.2 .63 .79 r
.56552 .16187 m
.56552 .20522 L
.56743 .20522 L
.56743 .16187 L
s
.678 .847 .902 r
.56743 .16187 m
.56743 .20665 L
.56954 .20665 L
.56954 .16187 L
F
.2 .63 .79 r
.56743 .16187 m
.56743 .20665 L
.56954 .20665 L
.56954 .16187 L
s
.678 .847 .902 r
.56954 .16187 m
.56954 .2091 L
.57407 .2091 L
.57407 .16187 L
F
.2 .63 .79 r
.56954 .16187 m
.56954 .2091 L
.57407 .2091 L
.57407 .16187 L
s
.678 .847 .902 r
.57407 .16187 m
.57407 .21122 L
.57824 .21122 L
.57824 .16187 L
F
.2 .63 .79 r
.57407 .16187 m
.57407 .21122 L
.57824 .21122 L
.57824 .16187 L
s
.678 .847 .902 r
.57824 .16187 m
.57824 .2161 L
.58115 .2161 L
.58115 .16187 L
F
.2 .63 .79 r
.57824 .16187 m
.57824 .2161 L
.58115 .2161 L
.58115 .16187 L
s
.678 .847 .902 r
.58115 .16187 m
.58115 .21877 L
.58502 .21877 L
.58502 .16187 L
F
.2 .63 .79 r
.58115 .16187 m
.58115 .21877 L
.58502 .21877 L
.58502 .16187 L
s
.678 .847 .902 r
.58502 .16187 m
.58502 .22111 L
.58958 .22111 L
.58958 .16187 L
F
.2 .63 .79 r
.58502 .16187 m
.58502 .22111 L
.58958 .22111 L
.58958 .16187 L
s
.678 .847 .902 r
.58958 .16187 m
.58958 .22287 L
.59336 .22287 L
.59336 .16187 L
F
.2 .63 .79 r
.58958 .16187 m
.58958 .22287 L
.59336 .22287 L
.59336 .16187 L
s
.678 .847 .902 r
.59336 .16187 m
.59336 .22556 L
.5952 .22556 L
.5952 .16187 L
F
.2 .63 .79 r
.59336 .16187 m
.59336 .22556 L
.5952 .22556 L
.5952 .16187 L
s
.678 .847 .902 r
.5952 .16187 m
.5952 .22925 L
.59955 .22925 L
.59955 .16187 L
F
.2 .63 .79 r
.5952 .16187 m
.5952 .22925 L
.59955 .22925 L
.59955 .16187 L
s
.678 .847 .902 r
.59955 .16187 m
.59955 .23293 L
.60403 .23293 L
.60403 .16187 L
F
.2 .63 .79 r
.59955 .16187 m
.59955 .23293 L
.60403 .23293 L
.60403 .16187 L
s
.678 .847 .902 r
.60403 .16187 m
.60403 .23396 L
.60579 .23396 L
.60579 .16187 L
F
.2 .63 .79 r
.60403 .16187 m
.60403 .23396 L
.60579 .23396 L
.60579 .16187 L
s
.678 .847 .902 r
.60579 .16187 m
.60579 .23599 L
.6078 .23599 L
.6078 .16187 L
F
.2 .63 .79 r
.60579 .16187 m
.60579 .23599 L
.6078 .23599 L
.6078 .16187 L
s
.678 .847 .902 r
.6078 .16187 m
.6078 .23713 L
.60991 .23713 L
.60991 .16187 L
F
.2 .63 .79 r
.6078 .16187 m
.6078 .23713 L
.60991 .23713 L
.60991 .16187 L
s
.678 .847 .902 r
.60991 .16187 m
.60991 .24024 L
.61487 .24024 L
.61487 .16187 L
F
.2 .63 .79 r
.60991 .16187 m
.60991 .24024 L
.61487 .24024 L
.61487 .16187 L
s
.678 .847 .902 r
.61487 .16187 m
.61487 .2436 L
.62041 .2436 L
.62041 .16187 L
F
.2 .63 .79 r
.61487 .16187 m
.61487 .2436 L
.62041 .2436 L
.62041 .16187 L
s
.678 .847 .902 r
.62041 .16187 m
.62041 .24881 L
.62521 .24881 L
.62521 .16187 L
F
.2 .63 .79 r
.62041 .16187 m
.62041 .24881 L
.62521 .24881 L
.62521 .16187 L
s
.678 .847 .902 r
.62521 .16187 m
.62521 .25049 L
.62798 .25049 L
.62798 .16187 L
F
.2 .63 .79 r
.62521 .16187 m
.62521 .25049 L
.62798 .25049 L
.62798 .16187 L
s
.678 .847 .902 r
.62798 .16187 m
.62798 .25331 L
.63097 .25331 L
.63097 .16187 L
F
.2 .63 .79 r
.62798 .16187 m
.62798 .25331 L
.63097 .25331 L
.63097 .16187 L
s
.678 .847 .902 r
.63097 .16187 m
.63097 .25439 L
.63612 .25439 L
.63612 .16187 L
F
.2 .63 .79 r
.63097 .16187 m
.63097 .25439 L
.63612 .25439 L
.63612 .16187 L
s
.678 .847 .902 r
.63612 .16187 m
.63612 .25881 L
.6415 .25881 L
.6415 .16187 L
F
.2 .63 .79 r
.63612 .16187 m
.63612 .25881 L
.6415 .25881 L
.6415 .16187 L
s
.678 .847 .902 r
.6415 .16187 m
.6415 .26287 L
.64336 .26287 L
.64336 .16187 L
F
.2 .63 .79 r
.6415 .16187 m
.6415 .26287 L
.64336 .26287 L
.64336 .16187 L
s
.678 .847 .902 r
.64336 .16187 m
.64336 .26458 L
.64653 .26458 L
.64653 .16187 L
F
.2 .63 .79 r
.64336 .16187 m
.64336 .26458 L
.64653 .26458 L
.64653 .16187 L
s
.678 .847 .902 r
.64653 .16187 m
.64653 .26967 L
.65134 .26967 L
.65134 .16187 L
F
.2 .63 .79 r
.64653 .16187 m
.64653 .26967 L
.65134 .26967 L
.65134 .16187 L
s
.678 .847 .902 r
.65134 .16187 m
.65134 .27083 L
.65657 .27083 L
.65657 .16187 L
F
.2 .63 .79 r
.65134 .16187 m
.65134 .27083 L
.65657 .27083 L
.65657 .16187 L
s
.678 .847 .902 r
.65657 .16187 m
.65657 .27575 L
.66215 .27575 L
.66215 .16187 L
F
.2 .63 .79 r
.65657 .16187 m
.65657 .27575 L
.66215 .27575 L
.66215 .16187 L
s
.678 .847 .902 r
.66215 .16187 m
.66215 .28268 L
.66662 .28268 L
.66662 .16187 L
F
.2 .63 .79 r
.66215 .16187 m
.66215 .28268 L
.66662 .28268 L
.66662 .16187 L
s
.678 .847 .902 r
.66662 .16187 m
.66662 .28454 L
.66901 .28454 L
.66901 .16187 L
F
.2 .63 .79 r
.66662 .16187 m
.66662 .28454 L
.66901 .28454 L
.66901 .16187 L
s
.678 .847 .902 r
.66901 .16187 m
.66901 .28562 L
.67308 .28562 L
.67308 .16187 L
F
.2 .63 .79 r
.66901 .16187 m
.66901 .28562 L
.67308 .28562 L
.67308 .16187 L
s
.678 .847 .902 r
.67308 .16187 m
.67308 .28939 L
.67654 .28939 L
.67654 .16187 L
F
.2 .63 .79 r
.67308 .16187 m
.67308 .28939 L
.67654 .28939 L
.67654 .16187 L
s
.678 .847 .902 r
.67654 .16187 m
.67654 .29289 L
.68227 .29289 L
.68227 .16187 L
F
.2 .63 .79 r
.67654 .16187 m
.67654 .29289 L
.68227 .29289 L
.68227 .16187 L
s
.678 .847 .902 r
.68227 .16187 m
.68227 .29869 L
.68671 .29869 L
.68671 .16187 L
F
.2 .63 .79 r
.68227 .16187 m
.68227 .29869 L
.68671 .29869 L
.68671 .16187 L
s
.678 .847 .902 r
.68671 .16187 m
.68671 .30323 L
.69068 .30323 L
.69068 .16187 L
F
.2 .63 .79 r
.68671 .16187 m
.68671 .30323 L
.69068 .30323 L
.69068 .16187 L
s
.678 .847 .902 r
.69068 .16187 m
.69068 .3057 L
.69563 .3057 L
.69563 .16187 L
F
.2 .63 .79 r
.69068 .16187 m
.69068 .3057 L
.69563 .3057 L
.69563 .16187 L
s
.678 .847 .902 r
.69563 .16187 m
.69563 .30872 L
.69863 .30872 L
.69863 .16187 L
F
.2 .63 .79 r
.69563 .16187 m
.69563 .30872 L
.69863 .30872 L
.69863 .16187 L
s
.678 .847 .902 r
.69863 .16187 m
.69863 .31061 L
.70307 .31061 L
.70307 .16187 L
F
.2 .63 .79 r
.69863 .16187 m
.69863 .31061 L
.70307 .31061 L
.70307 .16187 L
s
.678 .847 .902 r
.70307 .16187 m
.70307 .31414 L
.70677 .31414 L
.70677 .16187 L
F
.2 .63 .79 r
.70307 .16187 m
.70307 .31414 L
.70677 .31414 L
.70677 .16187 L
s
.678 .847 .902 r
.70677 .16187 m
.70677 .32095 L
.71136 .32095 L
.71136 .16187 L
F
.2 .63 .79 r
.70677 .16187 m
.70677 .32095 L
.71136 .32095 L
.71136 .16187 L
s
.678 .847 .902 r
.71136 .16187 m
.71136 .32403 L
.71523 .32403 L
.71523 .16187 L
F
.2 .63 .79 r
.71136 .16187 m
.71136 .32403 L
.71523 .32403 L
.71523 .16187 L
s
.678 .847 .902 r
.71523 .16187 m
.71523 .32744 L
.71996 .32744 L
.71996 .16187 L
F
.2 .63 .79 r
.71523 .16187 m
.71523 .32744 L
.71996 .32744 L
.71996 .16187 L
s
.678 .847 .902 r
.71996 .16187 m
.71996 .32992 L
.72468 .32992 L
.72468 .16187 L
F
.2 .63 .79 r
.71996 .16187 m
.71996 .32992 L
.72468 .32992 L
.72468 .16187 L
s
.678 .847 .902 r
.72468 .16187 m
.72468 .33471 L
.72825 .33471 L
.72825 .16187 L
F
.2 .63 .79 r
.72468 .16187 m
.72468 .33471 L
.72825 .33471 L
.72825 .16187 L
s
.678 .847 .902 r
.72825 .16187 m
.72825 .33675 L
.73088 .33675 L
.73088 .16187 L
F
.2 .63 .79 r
.72825 .16187 m
.72825 .33675 L
.73088 .33675 L
.73088 .16187 L
s
.678 .847 .902 r
.73088 .16187 m
.73088 .34152 L
.73629 .34152 L
.73629 .16187 L
F
.2 .63 .79 r
.73088 .16187 m
.73088 .34152 L
.73629 .34152 L
.73629 .16187 L
s
.678 .847 .902 r
.73629 .16187 m
.73629 .34885 L
.74147 .34885 L
.74147 .16187 L
F
.2 .63 .79 r
.73629 .16187 m
.73629 .34885 L
.74147 .34885 L
.74147 .16187 L
s
.678 .847 .902 r
.74147 .16187 m
.74147 .34896 L
.74492 .34896 L
.74492 .16187 L
F
.2 .63 .79 r
.74147 .16187 m
.74147 .34896 L
.74492 .34896 L
.74492 .16187 L
s
.678 .847 .902 r
.74492 .16187 m
.74492 .35564 L
.75021 .35564 L
.75021 .16187 L
F
.2 .63 .79 r
.74492 .16187 m
.74492 .35564 L
.75021 .35564 L
.75021 .16187 L
s
.678 .847 .902 r
.75021 .16187 m
.75021 .35852 L
.75256 .35852 L
.75256 .16187 L
F
.2 .63 .79 r
.75021 .16187 m
.75021 .35852 L
.75256 .35852 L
.75256 .16187 L
s
.678 .847 .902 r
.75256 .16187 m
.75256 .36401 L
.75834 .36401 L
.75834 .16187 L
F
.2 .63 .79 r
.75256 .16187 m
.75256 .36401 L
.75834 .36401 L
.75834 .16187 L
s
.678 .847 .902 r
.75834 .16187 m
.75834 .36747 L
.76205 .36747 L
.76205 .16187 L
F
.2 .63 .79 r
.75834 .16187 m
.75834 .36747 L
.76205 .36747 L
.76205 .16187 L
s
.678 .847 .902 r
.76205 .16187 m
.76205 .37022 L
.76461 .37022 L
.76461 .16187 L
F
.2 .63 .79 r
.76205 .16187 m
.76205 .37022 L
.76461 .37022 L
.76461 .16187 L
s
.678 .847 .902 r
.76461 .16187 m
.76461 .37523 L
.7704 .37523 L
.7704 .16187 L
F
.2 .63 .79 r
.76461 .16187 m
.76461 .37523 L
.7704 .37523 L
.7704 .16187 L
s
.678 .847 .902 r
.7704 .16187 m
.7704 .37853 L
.77387 .37853 L
.77387 .16187 L
F
.2 .63 .79 r
.7704 .16187 m
.7704 .37853 L
.77387 .37853 L
.77387 .16187 L
s
.678 .847 .902 r
.77387 .16187 m
.77387 .3805 L
.77586 .3805 L
.77586 .16187 L
F
.2 .63 .79 r
.77387 .16187 m
.77387 .3805 L
.77586 .3805 L
.77586 .16187 L
s
.678 .847 .902 r
.77586 .16187 m
.77586 .38278 L
.77852 .38278 L
.77852 .16187 L
F
.2 .63 .79 r
.77586 .16187 m
.77586 .38278 L
.77852 .38278 L
.77852 .16187 L
s
.678 .847 .902 r
.77852 .16187 m
.77852 .38464 L
.78162 .38464 L
.78162 .16187 L
F
.2 .63 .79 r
.77852 .16187 m
.77852 .38464 L
.78162 .38464 L
.78162 .16187 L
s
.678 .847 .902 r
.78162 .16187 m
.78162 .39078 L
.78695 .39078 L
.78695 .16187 L
F
.2 .63 .79 r
.78162 .16187 m
.78162 .39078 L
.78695 .39078 L
.78695 .16187 L
s
.678 .847 .902 r
.78695 .16187 m
.78695 .39493 L
.78982 .39493 L
.78982 .16187 L
F
.2 .63 .79 r
.78695 .16187 m
.78695 .39493 L
.78982 .39493 L
.78982 .16187 L
s
.678 .847 .902 r
.78982 .16187 m
.78982 .40084 L
.79531 .40084 L
.79531 .16187 L
F
.2 .63 .79 r
.78982 .16187 m
.78982 .40084 L
.79531 .40084 L
.79531 .16187 L
s
.678 .847 .902 r
.79531 .16187 m
.79531 .40548 L
.7998 .40548 L
.7998 .16187 L
F
.2 .63 .79 r
.79531 .16187 m
.79531 .40548 L
.7998 .40548 L
.7998 .16187 L
s
.678 .847 .902 r
.7998 .16187 m
.7998 .40767 L
.80318 .40767 L
.80318 .16187 L
F
.2 .63 .79 r
.7998 .16187 m
.7998 .40767 L
.80318 .40767 L
.80318 .16187 L
s
.678 .847 .902 r
.80318 .16187 m
.80318 .41278 L
.8073 .41278 L
.8073 .16187 L
F
.2 .63 .79 r
.80318 .16187 m
.80318 .41278 L
.8073 .41278 L
.8073 .16187 L
s
.678 .847 .902 r
.8073 .16187 m
.8073 .41389 L
.81066 .41389 L
.81066 .16187 L
F
.2 .63 .79 r
.8073 .16187 m
.8073 .41389 L
.81066 .41389 L
.81066 .16187 L
s
.678 .847 .902 r
.81066 .16187 m
.81066 .41886 L
.81626 .41886 L
.81626 .16187 L
F
.2 .63 .79 r
.81066 .16187 m
.81066 .41886 L
.81626 .41886 L
.81626 .16187 L
s
.678 .847 .902 r
.81626 .16187 m
.81626 .42442 L
.82073 .42442 L
.82073 .16187 L
F
.2 .63 .79 r
.81626 .16187 m
.81626 .42442 L
.82073 .42442 L
.82073 .16187 L
s
.678 .847 .902 r
.82073 .16187 m
.82073 .42817 L
.82304 .42817 L
.82304 .16187 L
F
.2 .63 .79 r
.82073 .16187 m
.82073 .42817 L
.82304 .42817 L
.82304 .16187 L
s
.678 .847 .902 r
.82304 .16187 m
.82304 .42984 L
.82552 .42984 L
.82552 .16187 L
F
.2 .63 .79 r
.82304 .16187 m
.82304 .42984 L
.82552 .42984 L
.82552 .16187 L
s
.678 .847 .902 r
.82552 .16187 m
.82552 .4337 L
.82745 .4337 L
.82745 .16187 L
F
.2 .63 .79 r
.82552 .16187 m
.82552 .4337 L
.82745 .4337 L
.82745 .16187 L
s
.678 .847 .902 r
.82745 .16187 m
.82745 .43647 L
.83258 .43647 L
.83258 .16187 L
F
.2 .63 .79 r
.82745 .16187 m
.82745 .43647 L
.83258 .43647 L
.83258 .16187 L
s
.678 .847 .902 r
.83258 .16187 m
.83258 .44188 L
.83726 .44188 L
.83726 .16187 L
F
.2 .63 .79 r
.83258 .16187 m
.83258 .44188 L
.83726 .44188 L
.83726 .16187 L
s
.678 .847 .902 r
.83726 .16187 m
.83726 .44582 L
.84028 .44582 L
.84028 .16187 L
F
.2 .63 .79 r
.83726 .16187 m
.83726 .44582 L
.84028 .44582 L
.84028 .16187 L
s
.678 .847 .902 r
.84028 .16187 m
.84028 .44909 L
.8457 .44909 L
.8457 .16187 L
F
.2 .63 .79 r
.84028 .16187 m
.84028 .44909 L
.8457 .44909 L
.8457 .16187 L
s
.678 .847 .902 r
.8457 .16187 m
.8457 .45663 L
.85087 .45663 L
.85087 .16187 L
F
.2 .63 .79 r
.8457 .16187 m
.8457 .45663 L
.85087 .45663 L
.85087 .16187 L
s
.678 .847 .902 r
.85087 .16187 m
.85087 .46097 L
.8536 .46097 L
.8536 .16187 L
F
.2 .63 .79 r
.85087 .16187 m
.85087 .46097 L
.8536 .46097 L
.8536 .16187 L
s
.678 .847 .902 r
.8536 .16187 m
.8536 .46341 L
.8558 .46341 L
.8558 .16187 L
F
.2 .63 .79 r
.8536 .16187 m
.8536 .46341 L
.8558 .46341 L
.8558 .16187 L
s
.678 .847 .902 r
.8558 .16187 m
.8558 .46701 L
.86126 .46701 L
.86126 .16187 L
F
.2 .63 .79 r
.8558 .16187 m
.8558 .46701 L
.86126 .46701 L
.86126 .16187 L
s
.678 .847 .902 r
.86126 .16187 m
.86126 .46991 L
.86472 .46991 L
.86472 .16187 L
F
.2 .63 .79 r
.86126 .16187 m
.86126 .46991 L
.86472 .46991 L
.86472 .16187 L
s
.678 .847 .902 r
.86472 .16187 m
.86472 .4748 L
.8672 .4748 L
.8672 .16187 L
F
.2 .63 .79 r
.86472 .16187 m
.86472 .4748 L
.8672 .4748 L
.8672 .16187 L
s
.678 .847 .902 r
.8672 .16187 m
.8672 .47859 L
.87257 .47859 L
.87257 .16187 L
F
.2 .63 .79 r
.8672 .16187 m
.8672 .47859 L
.87257 .47859 L
.87257 .16187 L
s
.678 .847 .902 r
.87257 .16187 m
.87257 .48413 L
.87668 .48413 L
.87668 .16187 L
F
.2 .63 .79 r
.87257 .16187 m
.87257 .48413 L
.87668 .48413 L
.87668 .16187 L
s
.678 .847 .902 r
.87668 .16187 m
.87668 .48838 L
.88064 .48838 L
.88064 .16187 L
F
.2 .63 .79 r
.87668 .16187 m
.87668 .48838 L
.88064 .48838 L
.88064 .16187 L
s
.678 .847 .902 r
.88064 .16187 m
.88064 .49502 L
.88608 .49502 L
.88608 .16187 L
F
.2 .63 .79 r
.88064 .16187 m
.88064 .49502 L
.88608 .49502 L
.88608 .16187 L
s
.678 .847 .902 r
.88608 .16187 m
.88608 .49984 L
.8918 .49984 L
.8918 .16187 L
F
.2 .63 .79 r
.88608 .16187 m
.88608 .49984 L
.8918 .49984 L
.8918 .16187 L
s
.678 .847 .902 r
.8918 .16187 m
.8918 .50624 L
.89724 .50624 L
.89724 .16187 L
F
.2 .63 .79 r
.8918 .16187 m
.8918 .50624 L
.89724 .50624 L
.89724 .16187 L
s
.678 .847 .902 r
.89724 .16187 m
.89724 .51171 L
.89957 .51171 L
.89957 .16187 L
F
.2 .63 .79 r
.89724 .16187 m
.89724 .51171 L
.89957 .51171 L
.89957 .16187 L
s
.678 .847 .902 r
.89957 .16187 m
.89957 .5149 L
.90264 .5149 L
.90264 .16187 L
F
.2 .63 .79 r
.89957 .16187 m
.89957 .5149 L
.90264 .5149 L
.90264 .16187 L
s
.678 .847 .902 r
.90264 .16187 m
.90264 .51672 L
.90674 .51672 L
.90674 .16187 L
F
.2 .63 .79 r
.90264 .16187 m
.90264 .51672 L
.90674 .51672 L
.90674 .16187 L
s
.678 .847 .902 r
.90674 .16187 m
.90674 .52069 L
.91242 .52069 L
.91242 .16187 L
F
.2 .63 .79 r
.90674 .16187 m
.90674 .52069 L
.91242 .52069 L
.91242 .16187 L
s
.678 .847 .902 r
.91242 .16187 m
.91242 .52822 L
.91611 .52822 L
.91611 .16187 L
F
.2 .63 .79 r
.91242 .16187 m
.91242 .52822 L
.91611 .52822 L
.91611 .16187 L
s
.678 .847 .902 r
.91611 .16187 m
.91611 .53184 L
.91862 .53184 L
.91862 .16187 L
F
.2 .63 .79 r
.91611 .16187 m
.91611 .53184 L
.91862 .53184 L
.91862 .16187 L
s
.678 .847 .902 r
.91862 .16187 m
.91862 .53799 L
.92199 .53799 L
.92199 .16187 L
F
.2 .63 .79 r
.91862 .16187 m
.91862 .53799 L
.92199 .53799 L
.92199 .16187 L
s
.678 .847 .902 r
.92199 .16187 m
.92199 .53872 L
.92749 .53872 L
.92749 .16187 L
F
.2 .63 .79 r
.92199 .16187 m
.92199 .53872 L
.92749 .53872 L
.92749 .16187 L
s
.678 .847 .902 r
.92749 .16187 m
.92749 .54859 L
.93187 .54859 L
.93187 .16187 L
F
.2 .63 .79 r
.92749 .16187 m
.92749 .54859 L
.93187 .54859 L
.93187 .16187 L
s
.678 .847 .902 r
.93187 .16187 m
.93187 .55244 L
.93554 .55244 L
.93554 .16187 L
F
.2 .63 .79 r
.93187 .16187 m
.93187 .55244 L
.93554 .55244 L
.93554 .16187 L
s
.678 .847 .902 r
.93554 .16187 m
.93554 .55515 L
.93764 .55515 L
.93764 .16187 L
F
.2 .63 .79 r
.93554 .16187 m
.93554 .55515 L
.93764 .55515 L
.93764 .16187 L
s
.678 .847 .902 r
.93764 .16187 m
.93764 .55829 L
.93946 .55829 L
.93946 .16187 L
F
.2 .63 .79 r
.93764 .16187 m
.93764 .55829 L
.93946 .55829 L
.93946 .16187 L
s
.678 .847 .902 r
.93946 .16187 m
.93946 .5595 L
.9445 .5595 L
.9445 .16187 L
F
.2 .63 .79 r
.93946 .16187 m
.93946 .5595 L
.9445 .5595 L
.9445 .16187 L
s
.678 .847 .902 r
.9445 .16187 m
.9445 .56739 L
.9472 .56739 L
.9472 .16187 L
F
.2 .63 .79 r
.9445 .16187 m
.9445 .56739 L
.9472 .56739 L
.9472 .16187 L
s
.678 .847 .902 r
.9472 .16187 m
.9472 .57226 L
.95292 .57226 L
.95292 .16187 L
F
.2 .63 .79 r
.9472 .16187 m
.9472 .57226 L
.95292 .57226 L
.95292 .16187 L
s
.678 .847 .902 r
.95292 .16187 m
.95292 .57555 L
.95511 .57555 L
.95511 .16187 L
F
.2 .63 .79 r
.95292 .16187 m
.95292 .57555 L
.95511 .57555 L
.95511 .16187 L
s
.678 .847 .902 r
.95511 .16187 m
.95511 .57795 L
.95845 .57795 L
.95845 .16187 L
F
.2 .63 .79 r
.95511 .16187 m
.95511 .57795 L
.95845 .57795 L
.95845 .16187 L
s
.678 .847 .902 r
.95845 .16187 m
.95845 .58245 L
.96041 .58245 L
.96041 .16187 L
F
.2 .63 .79 r
.95845 .16187 m
.95845 .58245 L
.96041 .58245 L
.96041 .16187 L
s
.678 .847 .902 r
.96041 .16187 m
.96041 .58456 L
.96251 .58456 L
.96251 .16187 L
F
.2 .63 .79 r
.96041 .16187 m
.96041 .58456 L
.96251 .58456 L
.96251 .16187 L
s
.678 .847 .902 r
.96251 .16187 m
.96251 .59044 L
.96642 .59044 L
.96642 .16187 L
F
.2 .63 .79 r
.96251 .16187 m
.96251 .59044 L
.96642 .59044 L
.96642 .16187 L
s
.678 .847 .902 r
.96642 .16187 m
.96642 .59594 L
.97163 .59594 L
.97163 .16187 L
F
.2 .63 .79 r
.96642 .16187 m
.96642 .59594 L
.97163 .59594 L
.97163 .16187 L
s
.678 .847 .902 r
.97163 .16187 m
.97163 .59978 L
.97399 .59978 L
.97399 .16187 L
F
.2 .63 .79 r
.97163 .16187 m
.97163 .59978 L
.97399 .59978 L
.97399 .16187 L
s
.678 .847 .902 r
.97399 .16187 m
.97399 .60282 L
.97619 .60282 L
.97619 .16187 L
F
.2 .63 .79 r
.97399 .16187 m
.97399 .60282 L
.97619 .60282 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02637 .01472 Mdot
.03184 .01476 Mdot
.03685 .01483 Mdot
.03988 .01488 Mdot
.04496 .01501 Mdot
.04728 .01507 Mdot
.05134 .01521 Mdot
.05289 .01526 Mdot
.05927 .01553 Mdot
.06284 .0157 Mdot
.06563 .01585 Mdot
.0697 .01608 Mdot
.07832 .01664 Mdot
.0836 .01703 Mdot
.08873 .01745 Mdot
.0892 .01749 Mdot
.09394 .01791 Mdot
.09643 .01814 Mdot
.10034 .01852 Mdot
.10636 .01914 Mdot
.10663 .01917 Mdot
.11223 .01979 Mdot
.11674 .02032 Mdot
.12122 .02087 Mdot
.12381 .0212 Mdot
.13113 .02219 Mdot
.13611 .0229 Mdot
.13853 .02326 Mdot
.14687 .02454 Mdot
.15061 .02515 Mdot
.15331 .0256 Mdot
.15662 .02616 Mdot
.15885 .02655 Mdot
.16344 .02737 Mdot
.16904 .0284 Mdot
.17412 .02938 Mdot
.17862 .03027 Mdot
.18265 .03109 Mdot
.18459 .03149 Mdot
.18688 .03197 Mdot
.1914 .03294 Mdot
.19692 .03416 Mdot
.19931 .0347 Mdot
.20349 .03567 Mdot
.20717 .03653 Mdot
.20964 .03713 Mdot
.21615 .03872 Mdot
.21907 .03946 Mdot
.22309 .04048 Mdot
.22839 .04188 Mdot
.23267 .04302 Mdot
.23712 .04424 Mdot
.23895 .04475 Mdot
.24379 .04612 Mdot
.24569 .04666 Mdot
.25049 .04806 Mdot
.25317 .04885 Mdot
.2594 .05073 Mdot
.26127 .05131 Mdot
.2657 .05268 Mdot
.27155 .05454 Mdot
.27383 .05528 Mdot
.27569 .05588 Mdot
.28131 .05774 Mdot
.28552 .05916 Mdot
.29117 .0611 Mdot
.29564 .06266 Mdot
.29774 .06341 Mdot
.303 .0653 Mdot
.30605 .06641 Mdot
.30978 .06778 Mdot
.31446 .06953 Mdot
.32063 .07189 Mdot
.32576 .07388 Mdot
.32921 .07524 Mdot
.33203 .07636 Mdot
.33482 .07748 Mdot
.33947 .07938 Mdot
.34254 .08064 Mdot
.34817 .08299 Mdot
.35208 .08464 Mdot
.35369 .08533 Mdot
.36122 .0886 Mdot
.36206 .08896 Mdot
.36896 .09202 Mdot
.37125 .09305 Mdot
.37399 .09429 Mdot
.37828 .09625 Mdot
.38262 .09826 Mdot
.38915 .10133 Mdot
.38982 .10165 Mdot
.39457 .10392 Mdot
.39955 .10633 Mdot
.40091 .107 Mdot
.40522 .10912 Mdot
.40704 .11002 Mdot
.41032 .11166 Mdot
.41415 .11359 Mdot
.41685 .11497 Mdot
.42103 .1171 Mdot
.42756 .1205 Mdot
.43171 .12269 Mdot
.43641 .12519 Mdot
.43767 .12587 Mdot
.44066 .12748 Mdot
.44302 .12876 Mdot
.45118 .13324 Mdot
.4524 .13392 Mdot
.45871 .13745 Mdot
.46234 .13951 Mdot
.46449 .14074 Mdot
.4705 .1442 Mdot
.47261 .14542 Mdot
.47719 .14811 Mdot
.47928 .14934 Mdot
.48177 .15082 Mdot
.48536 .15296 Mdot
.48886 .15506 Mdot
.4939 .15812 Mdot
.50138 .16272 Mdot
.50468 .16477 Mdot
.50685 .16613 Mdot
.50811 .16692 Mdot
.5144 .1709 Mdot
.51712 .17264 Mdot
.52031 .17469 Mdot
.52497 .1777 Mdot
.52968 .18078 Mdot
.53391 .18357 Mdot
.53623 .18511 Mdot
.53985 .18752 Mdot
.54757 .19274 Mdot
.5486 .19343 Mdot
.55328 .19664 Mdot
.55545 .19813 Mdot
.56021 .20143 Mdot
.56398 .20406 Mdot
.56562 .20522 Mdot
.56765 .20665 Mdot
.57112 .2091 Mdot
.5741 .21122 Mdot
.58088 .2161 Mdot
.58456 .21877 Mdot
.58777 .22111 Mdot
.59016 .22287 Mdot
.59381 .22556 Mdot
.59878 .22925 Mdot
.6037 .23293 Mdot
.60506 .23396 Mdot
.60775 .23599 Mdot
.60925 .23713 Mdot
.61332 .24024 Mdot
.61771 .2436 Mdot
.62442 .24881 Mdot
.62658 .25049 Mdot
.63017 .25331 Mdot
.63154 .25439 Mdot
.63712 .25881 Mdot
.64219 .26287 Mdot
.64432 .26458 Mdot
.65062 .26967 Mdot
.65204 .27083 Mdot
.65804 .27575 Mdot
.66641 .28268 Mdot
.66863 .28454 Mdot
.66992 .28562 Mdot
.6744 .28939 Mdot
.67854 .29289 Mdot
.68533 .29869 Mdot
.69059 .30323 Mdot
.69344 .3057 Mdot
.6969 .30872 Mdot
.69907 .31061 Mdot
.70308 .31414 Mdot
.71076 .32095 Mdot
.7142 .32403 Mdot
.718 .32744 Mdot
.72075 .32992 Mdot
.72603 .33471 Mdot
.72826 .33675 Mdot
.73346 .34152 Mdot
.74138 .34885 Mdot
.74149 .34896 Mdot
.74863 .35564 Mdot
.75169 .35852 Mdot
.75747 .36401 Mdot
.7611 .36747 Mdot
.76397 .37022 Mdot
.76916 .37523 Mdot
.77257 .37853 Mdot
.77459 .3805 Mdot
.77692 .38278 Mdot
.77883 .38464 Mdot
.78507 .39078 Mdot
.78926 .39493 Mdot
.79518 .40084 Mdot
.7998 .40548 Mdot
.80198 .40767 Mdot
.80702 .41278 Mdot
.8081 .41389 Mdot
.81297 .41886 Mdot
.81838 .42442 Mdot
.82201 .42817 Mdot
.82362 .42984 Mdot
.82733 .4337 Mdot
.82998 .43647 Mdot
.83514 .44188 Mdot
.83888 .44582 Mdot
.84196 .44909 Mdot
.84903 .45663 Mdot
.85307 .46097 Mdot
.85533 .46341 Mdot
.85866 .46701 Mdot
.86133 .46991 Mdot
.86582 .4748 Mdot
.86928 .47859 Mdot
.87432 .48413 Mdot
.87816 .48838 Mdot
.88412 .49502 Mdot
.88843 .49984 Mdot
.89411 .50624 Mdot
.89894 .51171 Mdot
.90175 .5149 Mdot
.90335 .51672 Mdot
.90681 .52069 Mdot
.91336 .52822 Mdot
.9165 .53184 Mdot
.92178 .53799 Mdot
.92241 .53872 Mdot
.93083 .54859 Mdot
.9341 .55244 Mdot
.93639 .55515 Mdot
.93904 .55829 Mdot
.94006 .5595 Mdot
.94666 .56739 Mdot
.95072 .57226 Mdot
.95345 .57555 Mdot
.95544 .57795 Mdot
.95915 .58245 Mdot
.96089 .58456 Mdot
.96571 .59044 Mdot
.9702 .59594 Mdot
.97332 .59978 Mdot
.97578 .60282 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(244) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0121857) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666345) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP@0
00000`3jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H00`000000n_3V0?[`iP02000000@0n_3V0P0000030?[`iP030000003j
l>H0n_3V00800000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2
000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000001@3jl>H2000000030?[`iP000000000000@000001@3j
l>H200000?l0n_3VW03jl>H10?ooo`00803jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V
000000000000n_3V0000003jl>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`
iP00000000000?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H200000003
0?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP000000000000D0n_3V0P000000103jl>H000000?[`iP3jl>H20000
00H0n_3V0P00003o0?[`iY`0n_3V0@3oool00200n_3V0P0000020?[`iP8000000`3jl>H2000000<0
n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`000004
0?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P00
00000`3jl>H00000000000090?[`iP@000000`3jl>H4000000<0n_3V100000040?[`iP<000000`3j
l>H010000000n_3V0000000000030?[`iP030000003jl>H0n_3V00800000o`3jl>JL0?[`iP40oooo
000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP00
0000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`00
00000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3j
l>H2000000D0n_3V0P0000080?[`iP8000000P3jl>H010000000n_3V0000000000030?[`iP@00000
o`3jl>JM0?[`iP40oooo000P0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003j
l>H0n_3V02D0n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2000000D0n_3V0P00
00040?[`iP030000003jl>H0n_3V008000000`3jl>H3000000<0n_3V0P00003o0?[`iYl0n_3V0@3o
ool001l0n_3V1P0000040?[`iP800000;`3jl>H5000002P0n_3V0`00000<0?[`iP<00000103jl>H3
000000@0n_3V0`0000030?[`iP<000001@3jl>H2000000<0n_3V1@00003o0?[`iY`0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3j
l>H400000?l0n_3Vo`3jl>HH0?[`iP40oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool0
0200n_3V1P0000001@3jl>H00000000000000000n_3V00<000000P3jl>H3000000<0n_3V10000003
0?[`iP80000000@0n_3V000000000000n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P00
00050?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P00
003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2
00000080n_3V00@000000?[`iP00000000000`3jl>H01@000000n_3V000000000000n_3V00<00000
0P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000280n_3V1@0000090?[`iP800000
00<0n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3j
l>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H2000000D0n_3V0P00
00020?[`iP8000000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P00
00000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P000004
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V1P0000000`3jl>H0000000000002
0?[`iP8000000P3jl>H2000000D0n_3V1@0000030?[`iP8000008P3jl>H5000000T0n_3V0P000000
0`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`
iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000020?[`iP80000000@0n_3V0000
00000000n_3V0`0000020?[`iP<0000000<0n_3V0000003jl>H0103jl>H2000000<0n_3V0P00000`
0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4
000000<0n_3V100000060?[`iP800000o`3jl>JM0?[`iP40oooo000R0?[`iP8000000`3jl>H50000
0080n_3V1@0000030?[`iP@000000`3jl>H2000000030?[`iP000000000000@0000000<0n_3V0000
000000000P3jl>H4000000@0n_3V0P00000`0?[`iP80000000<0n_3V0000000000002@3jl>H20000
00D0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000080?[`iP800000o`3jl>JM0?[`
iP40oooo000R0?[`iP8000002`3jl>H200000280n_3V0P00000`0?[`iP80000000<0n_3V00000000
00002P3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000040?[`iP03
0000003jl>H0n_3V00800000o`3jl>JM0?[`iP40oooo000P0?[`iPH000002@3jl>H200000200n_3V
1000000a0?[`iP<00000303jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V
0`0000020?[`iPD00000o`3jl>JM0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H00000
0?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP040000003j
l>H000000?[`iP8000000P3jl>H00`000000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`iP40oooo
000P0?[`iP<0000000<0n_3V0000000000000P0000001@3jl>H000000?[`iP000000n_3V00<00000
0P3jl>H00`000000n_3V0000000H0?[`iPD00000f`3jl>H4000000@0n_3V2`0000040?[`iP<00000
0P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`000000103jl>H00000
0000000000080?[`iP@0000000<0n_3V0000000000000P3jl>H400000080n_3V1@0000001`3jl>H0
0000000000000000n_3V0000003jl>H00`00000H0?[`iP<00000103jl>H2000000D0n_3V0`000003
0?[`iPH0000000<0n_3V0000000000000`0000020?[`iPH000000P3jl>H3000000@0n_3V0`000005
0?[`iP800000LP3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000@0n_3V0000
0000000000000P3jl>H2000000030?[`iP000000000000T0n_3V1@0000090?[`iP800000g`3jl>H2
000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0
n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP800000
0P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP8000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V00800000
2@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2000000030?[`
iP000000000000@0n_3V0P0000030?[`iP8000001`3jl>H2000000<0n_3V0P0000000`3jl>H00000
000000020?[`iP030000003jl>H0n_3V00800000103jl>H200000780n_3V0@3oool00280n_3V0`00
000Y0?[`iP800000gP3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P00
00060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
00000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V
0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V00800000603jl>H2000000030?[`
iP000000000000T0n_3V0P0000000`3jl>H00000000000040?[`iP800000103jl>H2000000H0n_3V
0P0000030?[`iP80000000<0n_3V0000000000001@3jl>H2000000@0n_3V0P00001b0?[`iP40oooo
000R0?[`iP<000006P3jl>H5000000/0n_3V0P00003M0?[`iP@000000`3jl>H500000080n_3V0P00
00050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P00
00020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H0
0P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V
1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000000000@0n_3V
0P0000050?[`iP8000001@3jl>H2000000<0n_3V0P0000000`3jl>H00000000000050?[`iP800000
103jl>H200000780n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000Z0?[`iP800000g03j
l>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V
0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V
0P0000000`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP80
00000P3jl>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP80
000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000000000@0n_3V0P0000060?[`iP80
0000103jl>H2000000@0n_3V0`0000030?[`iP030000003jl>H0n_3V008000001@3jl>H200000740
n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V00000000
0000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V00000000
0000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H50000
00/0n_3V0`0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000030?[`iP0000000000
00L000006@3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000040?[`
iP8000000`3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V0000
000000000P3jl>H4000000H0n_3V0P00001a0?[`iP40oooo001=0?[`iP80000000<0n_3V00000000
0000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP8000008P3jl>H200000080
n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V100000030?[`iP80000000<0n_3V0000000000000P3jl>H4000000<0n_3V0P0000000`3jl>H0
0000000000020?[`iP8000001@3jl>H00`000000n_3V0?[`iP0200000740n_3V0@3oool004h0n_3V
0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000001T0n_3V
0`0000000`3jl>H0000000000002000002h0n_3V0`00000;0?[`iP<000001@3jl>H2000000@0n_3V
0`0000050?[`iP800000103jl>H3000000<0n_3V1@0000020?[`iPD00000L@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80
000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`00
9`3jl>H01@000000n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`00
0000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`iP00000000000080
000000@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0
n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H3
00000080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000H000006P3jl>H5
000000<0n_3V100000030?[`iP@00000^@3jl>H10?ooo`008@3jl>H2000000030?[`iP0000000000
00D0000000D0n_3V00000000000000000?[`iP04000000/0n_3V1@0000090?[`iP80000000<0n_3V
000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P000002
0?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V
0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080
n_3V0P00000;0?[`iPD000002@3jl>H2000000L0n_3V0P0000050?[`iP800000^P3jl>H10?ooo`00
8P3jl>H3000002P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V
0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V
0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000J0?[`iP800000
0`3jl>H6000000030?[`iP000000000000@00000^@3jl>H10?ooo`008P3jl>H3000000T0n_3V00<0
00000?[`iP3jl>H03P3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP@000000`3j
l>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3j
l>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V1000000=0?[`iPD00000
2`3jl>H200000080n_3V00<000000?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V00800000
^P3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002L0n_3V0P0000000`3jl>H000000000
003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`
iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000001`0n_3V0P0000020?[`iP04
0000003jl>H00000000000<0n_3V00@000000?[`iP0000000000^P3jl>H10?ooo`00803jl>H30000
00040?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V
0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003jl>H500000080n_3V1000
00030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000000`3jl>H5000001T0n_3V0P00
00000`3jl>H00000000000020?[`iP040000003jl>H00000000000<0n_3V00@000000?[`iP000000
0000^P3jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000
0000000@0?[`iP800000303jl>H2000003P0n_3V0P0000000`3jl>H00000000000030?[`iP<00000
103jl>H300000;X0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P00
00040?[`iP8000001P3jl>H200000340n_3V0`0000050?[`iP8000001@3jl>H200000;X0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iRH0oooP
0P00001/0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000J@3oon0500000080oooP
0P0000040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003o
on00oooP000006X0oooP00@000000?ooh03oon000000203oon0010000000oooP0?ooh000001/0?oo
h0030000003oon00oooP06/0oooP00<000000?ooh03oon001`3oon0010000000oooP0?ooh000001Z
0?ooh0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP
000006X0oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?ooh01Z0?ooh0030000003o
on00oooP06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?ooh01Y0?ooh0030000003o
on00oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@0
00000?ooh03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00J`3oon000`000000oooP
0?ooh0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V0@3oool001d0n_3V9@3o
on0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03o
on00K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03o
on00JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0n_3V9P3oon02000006`0
oooP0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000002@0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3o
on000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3o
on000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP00X0oooP100000001@3oon00
0000000000000000oooP00D000000P3oon0200000?l0oooPbP3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP00T0
oooP600000020?ooh0@0000000<0oooP000000000000o`3oon2l0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP100000080?ooh1X0003o
3@0000000`3oon0000000000003o0?ooh;00oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V2P3o
on04000000@0oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh0030<f5?`00
000000000080000000D0onCQ00000000000000000<f5?`05000000030?oTh@3=QCl0000000P00000
20000?l:000000030?ooh0000000000000<00000o`3oon2[0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon002@3o
on001`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ
0<f5?`3oi>400P3=QCl6000000030<f5?`3oi>40000000<0000000@0onCQ00000000000000002P00
0?l7000000030?ooh0000000000000<00000o`3oon2T0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh0070<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5
?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo
000000000000100000000`3oi>40000000000002000000T0003o1@0000000`3oon00000000000003
00000?l0oooPW@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3o
i>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oT
h@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P000000
0`3=QCl0000000000003000000030<f5?`000000000000P0003o2000003o0?ooh9P0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3o
i>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01P3oi>40cHDo0?oTh@3o
i>40cHDo0?oTh@D0000000@0onCQ00000000000000001@000?l6000000030?ooh000000000000?l0
oooPTP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo
0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5
?`3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`05
0?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`0000000000
00D000001@000?l:00000?l0oooPS03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oT
h@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ1`0000050000o`L00000o`3oon2:0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>42
0<f5?`80onCQ00D0cHDo0?oTh@00000000000?oTh@03000000D0003o2000003o0?ooh8@0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
1`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5
?`3oi>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oT
h@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo1P0000050000o`H00000o`3oon210?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oT
h@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5
?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl5000000@0003o
1P00003o0?ooh7d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon001`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0
onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ
0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>44
0<f5?`030?oTh@3=QCl0onCQ00H000001@000?l3000000030?ooh000000000000?l0oooPN03oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40
cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo
0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0
onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00P0onCQ0<f5?`3o
i>40onCQ0<f5?`3oi>40cHDo0?oTh@H0000010000?l600000?l0oooPM03oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0070<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5
?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0
103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oT
h@030<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0000000000004000000@0003o1@00003o0?ooh740oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0070<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@02
0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=
QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl2
0?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0?oTh@3=QCl2000000030<f5?`0000000000
008000000`000?l3000000030?ooh000000000000?l0oooPJ`3oon03000001P0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5
?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@D0000010000?l300000?l0oooPK03o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3o
i>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=
QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5
?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080
cHDo0P3oi>420<f5?`030?oTh@000000000000@000000`000?l400000?l0oooPJ03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0070<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=
QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo0P3oi>42
0<f5?`040?oTh@3=QCl0onCQ0<f5?`80000000@0cHDo000000000000000010000?l2000000030?oo
h000000000000?l0oooPH`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@07
0<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5
?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo
0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@06
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl2
0?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0
onCQ0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5
?`3oi>401P0000030000o`@00000o`3oon1Q0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5
?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=
QCl01P3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`H000000`000?l400000?l0oooPGP3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0070<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oT
h@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=
QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo0P3oi>42
0<f5?`030?oTh@3=QCl0onCQ0080cHDo00T0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>400P000000103oi>4000000000000000020000o`@00000o`3oon1L0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo
0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`04
0?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ
00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0
onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5
?`80onCQ100000030000o`H00000o`3oon1G0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5
?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=
QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3o
i>40cHDo00000002000000<0003o1000003o0?ooh5H0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@050<f5
?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3=
QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oT
h@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5
?`040?oTh@3=QCl0onCQ0?oTh@@000000P000?l600000?l0oooPDP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0070<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80
onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103o
i>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@03
0<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`030?oT
h@3=QCl0onCQ0080cHDo00T0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl2
0?oTh@80cHDo00L0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo00<000000`000?l500000?l0oooP
D03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5
?`3oi>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3o
i>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oT
h@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ
0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ
0080cHDo0P3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00T0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00X0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0`0000030000o`@00000o`3oon1>0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=
QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0
cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5
?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oT
h@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3o
i>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=
QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@@000000`00
0?l400000?l0oooPB`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5
?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3o
i>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oT
h@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ
0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00T0onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00`0onCQ0<f5?`3oi>40onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl00000008000000P00
0?l400000?l0oooPB@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03
000000T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0
cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0
onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3o
i>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3o
i>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0`0000030000o`@00000
o`3oon140?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on001`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ
0<f5?`3oi>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5
?`020?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo
0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0
onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5
?`80onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0080cHDo0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0`0000030000o`<0
0000o`3oon140?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oT
h@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80
cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=
QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ
0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oT
h@80cHDo100000020000o`D00000o`3oon100?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5
?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=
QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303o
i>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5
?`3oi>40onCQ0<f5?`020?oTh@80cHDo00<0onCQ0<f5?`0000000`0000030000o`@00000o`3oon0n
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo
0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ
0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40
cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>40
0P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00D0
onCQ0<f5?`3oi>40onCQ0<f5?`04000000<0003o1000003o0?ooh3/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl2
0?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0
onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>40
0`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3o
i>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo
0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>420<f5
?`030?oTh@000000000000<000000P000?l300000?l0oooP>P3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0070<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ
00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103oi>40
cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@030<f5
?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`030?oTh@3=
QCl0onCQ0080cHDo00T0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oT
h@80cHDo00`0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5
?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0onCQ0?oTh@80cHDo00<0
onCQ0<f5?`3oi>400P3=QCl300000080003o00@000000?ooh00000000000o`3oon0g0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>42
0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oT
h@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3o
i>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0`0000020000o`<00000o`3oon0f0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oT
h@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5
?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo
0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=
QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ
0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3oi>40cHDo0000
00020000o`D00000o`3oon0b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=
QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5
?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5
?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oT
h@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ
0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80
onCQ0P3=QCl00`3oi>40cHDo0?oTh@02000000<0003o0`00003o0?ooh340oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=
QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0
0`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080
cHDo0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>42
0<f5?`030?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400`00
00020000o`<00000o`3oon0_0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=
QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ
00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5
?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5
?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oT
h@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ
0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80
onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@@000000P000?l300000?l0oooP;@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh007
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo
0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080
onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ
0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo0P3o
i>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00T0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>400P3=QCl20?oTh@80cHDo00`0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0
onCQ0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00@0onCQ0<f5?`3oi>40cHDo
0P3oi>420<f5?`040?oTh@000000000000000080003o1@00003o0?ooh2T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=
QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0
0`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080
cHDo0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>42
0<f5?`030?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=
QCl00`3oi>40cHDo0<f5?`03000000<0003o0`00003o0?ooh2P0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0onCQ
0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=
QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3oi>40
cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo0P3o
i>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=
QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>420<f5?`03
0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl01@3o
i>40cHDo0<f5?`3oi>40cHDo00@000000P000?l200000?l0oooP9`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo
0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3o
i>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=
QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>40
0P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0
303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ
0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo
0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3=
QCl0onCQ0<f5?`020?oTh@040<f5?`000000000000000080003o0`00003o0?ooh280oooP0`00000H
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0070<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80
onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103o
i>40cHDo0<f5?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@03
0<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`030?oT
h@3=QCl0onCQ0080cHDo00T0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl2
0?oTh@80cHDo00`0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>42
0<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0onCQ0?oTh@80cHDo
00<0onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`05
0?oTh@3=QCl0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`0300000080003o0`00003o0?oo
h280oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon001`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=
QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3o
i>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oT
h@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oT
h@020<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0
103oi>40cHDo0?oTh@3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`040?oTh@3=
QCl0onCQ0<f5?`80onCQ0P3=QCl01@3oi>40cHDo0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=
QCl0onCQ100000020000o`@00000o`3oon0O0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5
?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=
QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303o
i>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5
?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo0?oT
h@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3=QCl0
onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo100000020000o`@00000o`3oon0M0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oT
h@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5
?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo
0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=
QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ
0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oT
h@3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oT
h@80cHDo00<0onCQ0<f5?`3=QCl00`0000020000o`<00000o`3oon0L0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo
0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`04
0?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ
00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0
onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5
?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=
QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo
00D0onCQ0<f5?`3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5
?`3=QCl0onCQ100000020000o`<00000o`3oon0J0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo
0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3o
i>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=
QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>40
0P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0
303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ
0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo
0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3=
QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl0103oi>40cHDo0000000000020000o`80000000<0cHDo0?ooh03oon00o`3oon0F0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>42
0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oT
h@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3o
i>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl2
0?oTh@80cHDo00D0onCQ0<f5?`3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@0300000080003o0P00003o0?ooh1L0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon001`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0
onCQ0<f5?`3oi>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40
cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=
QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@02
0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103o
i>40cHDo0?oTh@3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`040?oTh@3=QCl0
onCQ0<f5?`80onCQ0P3=QCl01@3oi>40cHDo0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0
onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400`000002
0000o`800000o`3oon0E0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0
cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl2
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80
onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3o
i>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5
?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ
0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3=QCl0onCQ0<f5?`020?oT
h@040<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>400`0000020000o`<00000o`3oon0B0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3o
i>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oT
h@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oT
h@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0
cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ
0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80
onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80
cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=QCl0
0`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00D0
onCQ0<f5?`3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=
QCl0onCQ0P3=QCl01P3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ100000020000o`800000o`3o
on0A0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0
cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0
onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3o
i>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3o
i>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo
00@0onCQ0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40
cHDo0?oTh@3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40
cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01P3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`80onCQ00<0cHDo0?oTh@0000000`00000010000?l0000000000000003o0?ooh0l0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3o
i>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3o
i>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80
cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ
0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0080cHDo0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oT
h@3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`040?oTh@3=QCl0onCQ0<f5?`80
onCQ0P3=QCl01@3oi>40cHDo0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl0
103oi>40cHDo0<f5?`3oi>420<f5?`060?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0
onCQ0<f5?`3=QCl300000080003o0P00003o0?ooh0h0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@050<f5
?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3=
QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo
0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ
0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oT
h@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5
?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3o
i>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>420<f5?`030?oTh@3=
QCl0onCQ0080cHDo0P3oi>420<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl01@3oi>40cHDo
0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>42
0<f5?`060?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>401P3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5
?`<000000P000?l00`3oon0000000000003o0?ooh0/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`0000090?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oT
h@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ
0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
1@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00T0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00`0onCQ0<f5
?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ
0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0onCQ0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=
QCl20?oTh@80cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`050?oTh@3=QCl0cHDo0?oTh@3=
QCl00P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00H0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40cHDo0<f5?`3oi>400P3=QCl01@3oi>40
00000000003=QCl0003o00<00000o`3oon080?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
1`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5
?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>40
1P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo
0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo
0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40
cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo0P3o
i>420<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl01@3oi>40cHDo0<f5?`3oi>40cHDo0080
onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`060?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3o
i>40cHDo000000020000o`<00000o`3oon080?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5
?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl0
0P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=
QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303o
i>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5
?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo0?oT
h@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3=QCl0
onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0
1P3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0cHDo0?oTh@020<f5?`05
0?oTh@3=QCl0onCQ0<f5?`3oi>400P0000020000o`@00000o`3oon050?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo
0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`04
0?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`02
0?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ
00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0
onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5
?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=
QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo
00D0onCQ0<f5?`3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5
?`3=QCl0onCQ0P3=QCl01P3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0
cHDo0?oTh@020<f5?`070?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@0200000080003o0`00003o
0?ooh0@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon001`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5
?`3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=
QCl0onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl0
1@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`09
0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo
0?oTh@020<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=
QCl0103oi>40cHDo0?oTh@3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`040?oT
h@3=QCl0onCQ0<f5?`80onCQ0P3=QCl01@3oi>40cHDo0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oT
h@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`060?oTh@3=QCl0onCQ0<f5?`3oi>40
cHDo0P3oi>401@3=QCl0onCQ0<f5?`3=QCl0onCQ0080cHDo00P0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`<0000000<0003o0000000000000P00003o0?ooh080oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl2
0?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0
onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>40
0`3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3o
i>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo
0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>420<f5
?`030?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl0
1@3oi>40cHDo0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo
0<f5?`3oi>420<f5?`060?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0<f5?`3=
QCl0onCQ0080cHDo00P0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ0P0000020000
o`<00000o`3oon010?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00L0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo
0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080
onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oT
h@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ
103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40
onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`02
0?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=
QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3=QCl0onCQ0<f5?`020?oTh@04
0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01P3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0cHDo0?oTh@020<f5?`080?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00@0onCQ000000000?l0003o0`00003n0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00L0
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0080cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3o
i>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>42
0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oT
h@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@020<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3o
i>40onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl2
0?oTh@80cHDo00D0onCQ0<f5?`3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01P3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo
0?oTh@3=QCl0cHDo0?oTh@020<f5?`080?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oT
h@80cHDo00@0onCQ0<f5?`00000000000P000?l300000?`0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@05
0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5
?`3=QCl0cHDo0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3=QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0080onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3oi>40cHDo
0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>42
0<f5?`0<0?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl0
1@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>420<f5?`030?oT
h@3=QCl0onCQ0080cHDo0P3oi>420<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl01@3oi>40
cHDo0<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3o
i>420<f5?`060?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0<f5?`3=QCl0onCQ
0080cHDo00P0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo
0?oTh@03000000030000o`000000000000800000nP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`020?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo
0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5
?`3=QCl20?oTh@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0
onCQ0<f5?`020?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@030<f5?`3oi>40
cHDo0080onCQ0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl00P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`030?oTh@3=QCl0onCQ
0080cHDo00T0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo
00`0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`050?oT
h@3=QCl0onCQ0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0onCQ0?oTh@80cHDo00<0onCQ0<f5
?`3oi>400P3=QCl20?oTh@80cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`050?oTh@3=QCl0
cHDo0?oTh@3=QCl00P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80
cHDo00H0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40cHDo0<f5?`3oi>400P3=
QCl0203oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0onCQ
0080cHDo0P0000020000o`@00000n03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0070<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@070<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`80onCQ00D0cHDo0?oTh@3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oT
h@80cHDo0P3oi>420<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@060<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080onCQ
0P3=QCl20?oTh@@0cHDo00T0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
1@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00T0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo00`0onCQ0<f5
?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ
0?oTh@3=QCl00P3oi>420<f5?`040?oTh@3=QCl0onCQ0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=
QCl20?oTh@80cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`050?oTh@3=QCl0cHDo0?oTh@3=
QCl00P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00H0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40cHDo0<f5?`3oi>400P3=QCl0203oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00@0
onCQ00000000000000000P000?l300000?L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl00P3oi>401`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@050<f5?`3oi>40
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo
0P3oi>420<f5?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=
QCl00P3oi>401P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`02
0?oTh@80cHDo0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080
onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5
?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`0<0?oT
h@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo
0?oTh@3oi>40cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>420<f5?`030?oTh@3=QCl0onCQ
0080cHDo0P3oi>420<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl01@3oi>40cHDo0<f5?`3o
i>40cHDo0080onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`06
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0<f5?`3=QCl0onCQ0080cHDo00P0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5
?`80onCQ0P3=QCl2000000040000o`000000000000000?H0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP00T0oooP00L0cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0080
cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5
?`040?oTh@3=QCl0cHDo0<f5?`80onCQ0P3=QCl20?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5
?`020?oTh@030<f5?`3oi>40cHDo0080onCQ00H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`80
onCQ00<0cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ103=QCl02@3oi>40cHDo0?oTh@3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl20?oTh@80cHDo
00<0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@02
0<f5?`80onCQ0P3=QCl0303oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3oi>40onCQ
0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80
cHDo00D0onCQ0<f5?`3=QCl0onCQ0<f5?`020?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ
0<f5?`3=QCl0onCQ0P3=QCl01P3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=
QCl0cHDo0?oTh@020<f5?`080?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo
00<0onCQ0<f5?`3oi>400P3=QCl20?oTh@<0cHDo00@0onCQ000000000?l0003o0P00003e0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0
oooP00<000000?ooh03oon002@3oon001`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>40
1`3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=
QCl00P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>420<f5
?`80onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3=QCl00P3oi>40
1P3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`020?oTh@80cHDo
0P3oi>440<f5?`090?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo
0?oTh@3oi>40cHDo0?oTh@020<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo0P3oi>420<f5?`0<0?oTh@3=QCl0onCQ
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3oi>40
cHDo0080onCQ0P3=QCl0103oi>40cHDo0?oTh@3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo0P3o
i>420<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl01@3oi>40cHDo0<f5?`3oi>40cHDo0080
onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`060?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0<f5?`3=QCl0onCQ0080cHDo00P0onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`80onCQ0`3=
QCl0103oi>40cHDo0000000000020000o`030?ooh000000000000?80oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon04000000P0oooP
i`0000020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003o
on00oooP000000L0oooP00<000000?ooh03oon00k`3oon00100cXLX00000000000000?l300000005
0:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP2]f>H0[MSV0`0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP80[MSV00D0<j7:0:gHiP2]
f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0
<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gH
iP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]
f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@00000
0?ooh03oon0000001`3oon000`000000oooP0?ooh03a0?ooh08000000P000?l200000080<j7:00P0
[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP80[MSV0P0cXLX20:gHiP@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP2]
f>H303>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0200c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?oo
h03oon00l`3oon02000000060000o`00000000000000002]f>H0<j7:0P2]f>H0100cXLX0[MSV03>Q
bP2]f>H203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H403>QbP03
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX0102]f>H0<j7:0:gHiP2]f>H3
03>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0c
XLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP06
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:
0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV
1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00m03oon0200000080003o0`0000020:gHiP0403>Q
bP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP80[MSV0P0cXLX20:gH
iP@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP040:gHiP0cXLX0
[MSV0:gHiP<0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0200cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00<0
<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:
00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>Q
bP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV
0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80
<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03f0?ooh080000000T0003o00000000
000000000:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
0P2]f>H203>QbP80[MSV100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV0:gHiP<0
<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX20:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX0
102]f>H0<j7:0:gHiP0cXLX20:gHiP<0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0803>QbP2]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:
03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?L0oooP0P00
00020000o`80000000@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:0P2]f>H203>QbP80[MSV100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV0:gH
iP<0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX20:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0c
XLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP<0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0803>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0
<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?T0oooP
0P0000001P000?l00000000000000000<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP80[MSV0P0cXLX20:gHiP@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP2]
f>H303>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0200c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03j0?oo
h080000000<0003o0000000000000P00000203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX2
0:gHiP80<j7:0P2]f>H403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0[MSV0`0c
XLX0102]f>H0<j7:0:gHiP2]f>H303>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0
<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o03oon000`00
0000003o0000o`04000000050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H4
03>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX0102]f>H0<j7:0:gH
iP2]f>H303>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>Q
bP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP03
0:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]
f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>Q
bP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o@3oon02000000030000o`0000000000
0080000000@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:0P2]f>H403>QbP030:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP80[MSV
00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gH
iP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:
0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080
[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>Q
bP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]
f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon000`000000003o0000o`040000000403>QbP2]f>H0<j7:
03>QbP80[MSV0P0cXLX20:gHiP@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP2]
f>H303>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0200c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h080oooP00<000000000o`0000000`0000000`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H403>Q
bP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX0102]f>H0<j7:0:gHiP2]
f>H303>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80
[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gH
iP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gH
iP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0
<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80
[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon030?ooh003000000000?l0003o0080
000000<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV100cXLX00`2]f>H0<j7:0:gHiP0203>QbP04
0:gHiP0cXLX0[MSV0:gHiP<0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX20:gHiP0503>QbP2]f>H0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP<0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX2
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]
f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0
[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP1@3oon0010000000003o03>QbP2]f>H200000080[MSV0P0cXLX20:gHiP@0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP040:gHiP0cXLX0[MSV
0:gHiP<0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0200cXLX0[MSV03>QbP0cXLX0[MSV03>Q
bP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0
[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:
0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP1`3oon020000o`<0000000<0[MSV03>QbP0cXLX0
0P2]f>H403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX0102]f>H0
<j7:0:gHiP2]f>H303>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:
0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H3
03>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:
0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]
f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbPT0oooP0`00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0P0oooP00<000000000o`0000000`00
00000`0cXLX0[MSV0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0[MSV
0`0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>Q
bP040:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0c
XLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon09
0?ooh003000000000?l0003o00<000000P2]f>H403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV
03>QbP2]f>H0[MSV0`0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP80[MSV00D0<j7:0:gHiP2]f>H0
<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:
0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV
00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP06
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H3
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0:0?ooh080000000<0003o0000000000000P00000403>QbP030:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP80[MSV00D0
<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP03
03>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]
f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV
0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:
03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80
[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0
<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0;0?ooh08000000P000?l400000080<j7:00<0[MSV03>QbP2]
f>H00P0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:0P2]f>H0
1@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H303>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0200cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
5P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX2
0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]
f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0c
XLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:
0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gH
iP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0h0oooP00<000000000o`0000000`000000100cXLX0[MSV
03>QbP2]f>H203>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX2
0:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP<0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
03>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>Q
bP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0
[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:
00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3`3oon000`000000003o0000o`020000000403>Q
bP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX0102]f>H0<j7:0:gHiP2]f>H3
03>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0c
XLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP06
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:
0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV
1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@0?ooh080000000H0003o000000000000
000003>QbP2]f>H203>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0c
XLX20:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP<0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:
03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]
f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0
<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4@3oon0200000080003o0P0000001@2]f>H0
<j7:03>QbP2]f>H0<j7:0080[MSV0`0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP80[MSV00D0<j7:
0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H2
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0c
XLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>Q
bP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV
00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:
0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0B0?ooh0<0000000<0003o0000000000000P0cXLX0102]f>H0<j7:
0:gHiP2]f>H303>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0200cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100c
XLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh1@0oooP0P0000020000o`0403>QbP000000000003>QbP80[MSV0`0cXLX0102]f>H0<j7:
0:gHiP2]f>H303>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>Q
bP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gH
iP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H2
03>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0E0?ooh080000000<0oooP
0000o`0000000P0000020:gHiP<0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX20:gHiP0503>QbP2]
f>H0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP<0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0c
XLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:
0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]
f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP603oon000`000000003o0000o`02000000060:gHiP0cXLX0<j7:03>Q
bP2]f>H0<j7:0P2]f>H303>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0c
XLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0
<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0I0?ooh0800000
00<0003o0000000000000`0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP80[MSV00D0<j7:0:gHiP2]
f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0
<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gH
iP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]
f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o
0?ooh1X0oooP0P0000020000o`050000000cXLX0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00D0
<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP03
03>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]
f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV
0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:
03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80
[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0
<j7:0:gHiP2]f>H303>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh1/0oooP0`0000001@000?l000000000002]f>H0<j7:0080[MSV0`0cXLX20:gH
iP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP<0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>Q
bP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP02
0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV
03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0c
XLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>Q
bP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0
[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP703oon03000000040000o`000000000003>QbP80[MSV
0`0cXLX20:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gH
iP<0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV
0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0
<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0
1P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80
[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>Q
bP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gH
iPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7@3oon0300000080003o0P000000102]
f>H0<j7:03>QbP0cXLX20:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP<0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0803>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0c
XLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80
<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]
f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV
0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7`3oon03000000040000
o`000000000000000080<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>Q
bP2]f>H0<j7:0P2]f>H303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0200cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gH
iP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0c
XLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX2
0:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh240oooP0P000000
1@000?l00000000000000000<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP040:gH
iP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]
f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0R0?ooh080
00000P000?l3000000060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP<0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0803>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX0
0`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0
[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0c
XLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP903oon02000000050000o`00
000000000000000cXLX00P2]f>H0200cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H3
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0200cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]
f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>Q
bP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP02
0:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0
[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H5
03>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2D0oooP0P00000010000?l0000000000000
00020:gHiP0803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP<0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0F03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV
0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80
<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gH
iP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>Q
bP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP9P3oon0200000080003o0P0000000`2]f>H0<j7:0:gHiP0203>Q
bP040:gHiP0cXLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0c
XLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0X
0?ooh080000000D0003o000000000000<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0c
XLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP06
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:
0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV
1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Y0?ooh080000000@0003o000000000000
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP<0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0803>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>Q
bP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV
00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP:P3oon0200000080003o0P0000001@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX2
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80
[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:
0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]
f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H3
03>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0
102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0[0?ooh0<0000000L0003o000000000000[MSV03>Q
bP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0
<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh2d0oooP0P0000001P000?l00000
000000000000[MSV03>QbP80[MSV0`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0
<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbPT0oooP0`00000H
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2h0oooP0P0000020000
o`80000000<0<j7:0:gHiP2]f>H00`0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00P0<j7:0:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0
<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0_0?oo
h0<0000000<0003o0000000cXLX00P2]f>H303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0200c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h300oooP0`00000010000?l000000000002]f>H303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
200cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0
[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh340oooP0`0000000`000?l000000000000303>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
200cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0
[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh3<0oooP0P0000020000o`80000000H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0803>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0
<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
=03oon03000000030000o`00000000000080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0200cXLX0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H2
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0c
XLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3H0oooP
0P0000001`000?l000000000002]f>H0<j7:0:gHiP0cXLX00P2]f>H0200cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV
00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0
<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H2
03>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gH
iP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP0P0000020000
o`80000000H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
01H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:
0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080
[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>Q
bP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]
f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0h0?ooh0<0000000@0003o000000000000<j7:0P2]f>H0
200cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0
[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh3T0oooP00H0<j7:000000000000003o0000000cXLX20:gHiP0803>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0c
XLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80
<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]
f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV
0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>P3oon03000000060000
o`00000000000:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX2
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]
f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0
[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP>`3oon0300000080003o00<0000003>QbP2]f>H00P0cXLX0102]f>H0<j7:
0:gHiP0cXLX20:gHiP0F03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0
[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]
f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV
03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX2
0:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?@3oon03000000030000o`0cXLX0
[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H05P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>Q
bP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3h0
oooP0P0000000`3oon00003o0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX2
0:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gH
iP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
003o0?ooh440oooP00P0<j7:0000o`000000<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV01H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX2
0:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gH
iP2]f>H303>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh440oooP0P0000001P000?l000000000000cXLX0[MSV03>QbP80[MSV01H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gH
iP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]
f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon110?ooh0<0000000D0003o000000000000[MSV03>QbP020:gHiP0F03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0c
XLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:
0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]
f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP@P3oon0300000080003o01X0000003>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX2
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]
f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0
[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPA03oon030000000J0000o`000000[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100c
XLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh4D0oooP0`0000006@000?l000000:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0
<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon160?oo
h0<0000001P0003o0000000cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0
[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:
0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4L0oooP0`0000005`000?l0<j7:
000000000000[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV
0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80
<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gH
iP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>Q
bP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPB03oon02000000030?ooh0000?l00000008000000180<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h4/0oooP01H000000000o`000000000003>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0
<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gH
iP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0c
XLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1<0?ooh00E000000000?l000000000002]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0
<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
C@3oon000`000000003o000000020000000?0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80
[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gH
iP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>Q
bP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX2
0:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV
03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@
0?ooh0D000001P3oon000`000000oooP0?ooh03o0?ooh4d0oooP0P0000020000o`80000000h0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV
0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80
[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03o
on00o`3oon1>0?ooh0<000000100003o000000000000[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H2
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0c
XLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>Q
bP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV
00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:
0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP
00<000000?ooh03oon001P3oon0400000?l0oooPC`3oon020000000?0000o`000000000003>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0P2]f>H00`0cXLX0
[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]
f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV
03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX2
0:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX80?ooh0@00000603oon0N0?[`iP40oooo000M
0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh540oooP0P000000
3P000?l000000000002]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]
f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000
oooP0?ooh03o0?ooh580oooP0P0000003@000?l000000000000cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gH
iP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]
f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P000008
0?ooh0030000003oon00oooP0?l0oooPD`3oon020000000<0000o`000000<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H2
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0c
XLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>Q
bP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV
00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:
0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1D0?ooh080000000/0003o03>QbP00000000000:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV
00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0
[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gH
iP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh5L0oooP00X0003o000000000000000003>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0
<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1G0?oo
h003000000000?l000000080000000D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P0cXLX20:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0
[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:
0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5P0oooP00<000000000o`000?l0
0`0000000`2]f>H0<j7:0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP80<j7:
0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80
[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gH
iP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV
0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh5T0oooP0P0000001P000?l00000000000000000<j7:0:gHiP80<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV
0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80
[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPFP3oon0200000005
0000o`000000000003>QbP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX2
0:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gH
iP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1L0?ooh005000000000?l000000000002]f>H00P0cXLX20:gHiP0303>Q
bP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP03
0:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]
f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>Q
bP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1L0?ooh080000000D0003o0000
00000000000003>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H203>QbP80[MSV00@0<j7:
0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1M0?ooh080000000@0003o00000000000000000P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80
[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gH
iP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>Q
bP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX2
0:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV
03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPG`3oon000`000000003o00000002000000040:gHiP0cXLX0
[MSV0:gHiP80<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gH
iP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gH
iP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0
<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80
[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh600oooP00<000000000o`0000000P0000000`0cXLX0
[MSV0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]
f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV
03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX2
0:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Q0?ooh003000000000?l00000008000000P2]f>H2
03>QbP80[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>Q
bP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0
[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:
00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPHP3oon0010000000003o0000o`0000020:gHiP80
<j7:0P2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:
0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]
f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H3
03>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0
102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1S0?ooh080000000<0003o0:gHiP2]f>H00P0cXLX2
0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]
f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0c
XLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:
0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gH
iP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6D0oooP00D0<j7:0000o`000000000003>QbP020:gHiP80
<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>Q
bP80[MSV00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:
0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H0
2P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0
[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh6D0oooP00<0<j7:000000000?l00P0000020:gHiP80<j7:0P2]f>H0
100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh6H0oooP0P00000010000?l000000:gHiP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0c
XLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W
0?ooh080000000D0003o0:gHiP000000000003>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV
0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80
[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ@3oon000`0cXLX0
003o0000000200000080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H303>QbP030:gHiP0cXLX0<j7:
0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]
f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H3
03>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0
102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Y0?ooh00303>QbP000000003o008000000P2]f>H0
100cXLX0[MSV03>QbP0cXLX20:gHiP<0<j7:00<0[MSV03>QbP0cXLX00P2]f>H203>QbP80[MSV00H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh6/0oooP00L000000000o`00000000000:gHiP0cXLX0[MSV0080<j7:0P2]f>H303>Q
bP030:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gH
iP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H2
03>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1[0?ooh080000000D0003o
00000000000000000:gHiP0203>QbP80[MSV0`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]
f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0
[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPK03oon02000000040000o`000000000000000080<j7:0P2]f>H303>QbP03
0:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]
f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>Q
bP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1]0?ooh00303>QbP000000003o
00<0000000<0<j7:0:gHiP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80
[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPK`3oon000`000000003o0000000200000080[MSV0`0cXLX00`2]f>H0<j7:03>QbP02
0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV
03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0c
XLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>Q
bP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0
[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0<00000o`3oon1`0?ooh003000000000?l0003o0080000000D0[MSV03>QbP0cXLX0<j7:
0:gHiP0203>QbP80[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gH
iP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0
<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80
[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh740oooP0P0000000`000?l000000:gHiP0303>QbP03
0:gHiP0cXLX0<j7:0080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]
f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>Q
bP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1b0?ooh080000000<0003o0000
000000000P0cXLX00`2]f>H0<j7:03>QbP020:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0
[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP03
03>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL`3oon00
0`0cXLX000000000o`020000000403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX20:gHiP0603>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1d0?ooh080000000@0003o000000000000[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01P0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV
00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPM@3oon02000000030000o`00000000000080<j7:0P2]f>H203>QbP80[MSV00H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7H0oooP0P00000010000?l000000000000cXLX20:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
M`3oon02000000030000o`00000000000080[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]
f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1h0?ooh080
000000@0003o0000002]f>H0[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gH
iP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H2
03>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1i0?ooh080000000<0003o
0000000000000P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0603>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gH
iP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0c
XLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1k0?ooh005000000000?l000000000000cXLX0
0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]
f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPN`3oon02000000030000o`00000000000080[MSV00H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h7`0oooP0P0000002P000?l000000000002]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:
0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7d0oooP0P0000002@000?l00000
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP80[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gH
iP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0c
XLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV
0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon030000
0?l0oooPOP3oon02000000080000o`00000000000:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV
00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0c
XLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]
f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPO`3oon000`0cXLX000000000o`020000000403>QbP2]
f>H0<j7:0:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO`3o
on002@0cXLX00000000000000?l0000003>QbP2]f>H0<j7:0:gHiP0203>QbP80[MSV00H0<j7:0:gH
iP0cXLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0
<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0c
XLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP04
0:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh840oooP0P0000001@000?l000000:gHiP0cXLX0[MSV
0080<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80
[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPPP3oon0200000004
0000o`00000000000:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00L0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPPP3oon03000000030000o`00000000000080<j7:0P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0
[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPP`3oon03000000040000o`000000000003>QbP80[MSV00H0<j7:0:gHiP0c
XLX0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:
0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gH
iP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh8D0oooP0P0000000`000?l00000000000020:gHiP0603>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gH
iP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0c
XLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon260?ooh080000000H0003o000000000000[MSV
03>QbP2]f>H203>QbP0;0:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:
0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV
1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon270?ooh080000000D0003o000000000000
<j7:0:gHiP0203>QbP0;0:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:
0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV
1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon280?ooh080000000@0003o000000000000
[MSV0P0cXLX02`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:
00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPR@3oon02000000030000o`000000[MSV0080<j7:
00/0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP<0<j7:0P2]
f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0c
XLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8X0oooP0P0000001P000?l000000000000cXLX0[MSV03>QbP80
[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPS03oon001P000000003o000000000000[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV
03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2<0?ooh080000000@0003o0000
00000000<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H303>QbP80[MSV
00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:
0:gHiP2]f>H303>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh8d0oooP0P0000000`000?l00000000000020:gHiP0703>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gH
iP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8d0oooP0`0000002`00
0?l000000000002]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]
f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPSP3oon030000000:0000o`000000000003>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]
f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV
0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT03oon02000000090000
o`000000<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPT@3oon002P000000003o000000000000[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gH
iP<0<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP07
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV
0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>Q
bP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh940oooP0P00000020000?l00000000000000000
[MSV03>QbP2]f>H0<j7:0P2]f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0
<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2B0?ooh0800000
00L0003o000000000000000003>QbP2]f>H0<j7:0080[MSV0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPU03oon000`000000003o00000002000000040:gHiP0cXLX0[MSV0:gHiP<0<j7:0P2]f>H0
2P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0
[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh9D0oooP00<000000000o`0000000P0000000`0cXLX0[MSV0:gHiP03
03>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0
102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2F0?ooh005000000000?l000000000000cXLX00P2]
f>H303>QbP80[MSV00X0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gH
iP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0c
XLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2G0?ooh004000000000?l0000000000080[MSV
0`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:
00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU`3oon02000000040000o`000000[MSV0:gHiP<0
<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0c
XLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP04
0:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V403oon04000000L0oooP00<000000?ooh03oon00o`3oon2H0?ooh080000000<0003o00000000
00000`0cXLX20:gHiP0:03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]
f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0
<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>H@0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00o`3oon2J0?ooh004
000000000?l0000000000080<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gH
iP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V4@3oon000`000000oooP0?ooh0070?ooh0@00000o`3oon2I0?oo
h004000000000?l0000000000080<j7:0P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0c
XLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX2
0:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:203oon04000001P0oooP7P3j
l>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon2K
0?ooh005000000000?l000000000000cXLX00P2]f>H02P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gH
iP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000
003oon00oooP0?l0oooPW03oon000`000000003o00000002000000030:gHiP0cXLX0[MSV0080<j7:
00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<00000
0?ooh03oon00o`3oon2L0?ooh080000000H0003o000000000000000003>QbP2]f>H203>QbP060:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2M
0?ooh080000000D0003o000000000000<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]
f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>Q
bP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2O0?ooh005000000000?l00000
0000002]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]
f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPW`3oon02000000030000o`00000000000080<j7:00H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gH
iP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:00oooP0P00
00002P000?l00000000000000000[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0c
XLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh:40oooP0P0000002@000?l00000000000000000<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0c
XLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX2
0:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:<0oooP00T00000
0000o`000000000003>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H3
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2T0?ooh008000000000?l000000000002]f>H0<j7:0:gHiP0cXLX20:gHiP0703>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0c
XLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP04
0:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:@0oooP0P0000001P000?l000000:gHiP0cXLX0[MSV
03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0
[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0c
XLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon02000000050000o`00
000000000:gHiP0cXLX00P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]
f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2W0?ooh005
000000000?l000000000000cXLX00P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh:L0oooP0P000000
0`000?l00000000000020:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gH
iP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2@3oon03000001P0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ03oon02000000050000o`00
000000000:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP060:gHiP0cXLX0[MSV0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:
0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:T0oooP00H000000000o`000000
00000:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00H0[MSV03>QbP2]f>H0[MSV03>Q
bP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gH
iPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZP3oon000`000000003o0:gHiP020000
0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01P2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP80<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]
f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2[0?ooh00303>QbP000?l000000080000000D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV
0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh:/0oooP00<0<j7:000000000?l00P0000001@2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP[@3oon0020000000003o000000000000<j7:0:gHiP0cXLX0[MSV0P0cXLX01P2]f>H0<j7:
0:gHiP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]
f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2^0?ooh00700000000
0?l000000000002]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV0P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gH
iP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh:h0oooP0P0000001@000?l000000:gHiP0cXLX0[MSV0080
<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
[`3oon02000000040000o`000000<j7:0:gHiP80<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:
00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/03oon02000000030000o`000000[MSV0080<j7:
00H0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/03o
on03000000060000o`000000000003>QbP2]f>H0<j7:0P2]f>H02`0cXLX0[MSV03>QbP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:
0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2a0?ooh0<0000000D0003o000000000000[MSV03>QbP020:gHiP0;
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80<j7:
0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;<0oooP0P00000010000?l00000
0:gHiP0cXLX20:gHiP0;03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP]03oon02000000030000
o`000000<j7:0080[MSV00/0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX90?ooh0<00000
603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2d0?ooh0<0000000H0
003o0000002]f>H0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP03
03>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]@3oon02
000000060000o`00000000000:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;H0oooP0P0000001@000?l000000000000cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2g0?ooh080000000@0003o0000000cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh;P0oooP0P0000000`000?l000000000000203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
^P3oon0030000000003o000000000000<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP<0<j7:
0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh0800000
00X0003o0000000cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0`0cXLX20:gHiP80<j7:0P2]
f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;/0oooP00/000000000o`0000000000
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV
03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP^`3oon02000000090000o`000000[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2l0?ooh080000000P0003o000000000000[MSV03>QbP2]f>H0<j7:0:gHiP<0<j7:0P2]
f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n0?ooh00800000000
0?l000000000000cXLX0[MSV03>QbP2]f>H303>QbP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>Q
bP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP_P3oon02000000060000o`000000<j7:0:gHiP0cXLX0[MSV0`0c
XLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;l0oooP0P00
00001@000?l0<j7:0:gHiP0cXLX0[MSV00<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:
0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon310?ooh0050000o`0cXLX0[MSV03>QbP2]f>H00`0cXLX20:gHiP80
<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP`P3oon0010000?l000000000002]f>H303>Q
bP80[MSV0P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX90?ooh0<00000603oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon320?ooh004000000000?l00000
000000<0<j7:0P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon32
0?ooh080000000<0003o0000000000000P0cXLX20:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0
[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh<<0oooP0P00000010000?l000000000000cXLX20:gHiP80<j7:0P2]
f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<@0oooP0P0000000`000?l000000000
00020:gHiP80<j7:0P2]f>H503>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<D0oooP00@0
00000000o`00000000000P2]f>H203>QbP80[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon360?ooh005000000000?l000000000002]f>H00P0cXLX20:gHiPD0<j7:00@0[MSV03>QbP2]
f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPaP3oon02000000030000o`00000000000080<j7:0P2]f>H503>QbP04
0:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh<L0oooP0P00000010000?l0000003>QbP0cXLX20:gH
iPD0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb03oon02000000030000o`0000000000
0080[MSV1@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3:0?ooh005000000000?l00000
0000002]f>H01@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3:0?ooh005000000000?l0
00000000002]f>H01@0cXLX0102]f>H0<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3;0?ooh00400000000
0?l00000000000D0<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPc03oon0010000000003o
00000000000403>QbP040:gHiP0cXLX0[MSV0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPc03oon02000000030000o`000000000000<0
<j7:00@0[MSV03>QbP2]f>H0[MSV0`0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon3=0?ooh080000000<0003o0000000cXLX00P0cXLX0102]f>H0
<j7:0:gHiP2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon3>0?ooh080000000H0003o0000000cXLX0<j7:0:gHiP0cXLX2
0:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh<h0oooP0`0000001@000?l0000003>QbP2]f>H0<j7:0080[MSV0`0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPc`3oon02000000050000o`00000000000:gHiP0cXLX00P2]f>H303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3@0?oo
h080000000@0003o000000000000<j7:0P2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3A0?ooh080000000<0003o0000
000cXLX00P2]f>H303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon3B0?ooh080000000@0003o0000002]f>H0[MSV0`0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPd`3oon02000000030000o`000000[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=<0oooP0`0000000`000?l00000
0000000203>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon3D0?ooh0<0000000@0003o000000000000<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=D0oooP00<0
<j7:000000000?l00P0000000`0cXLX0oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh=L0oooP00@00000
0000o`00000000002`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon00
10000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPe`3oon02000000030000o`00
0000oooP00X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<00000
0?ooh03oon001P3oon0400000?l0oooPe`3oon02000000030000o`000000oooP00H0oooP1000000H
0?ooh1h0n_3V0@3oool001d0n_3V4`3oon000`000000oooP0?ooh0050?ooh0030000003oon00oooP
0?l0oooPf03oon04000000X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00
oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh=T0oooP0P00000;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000
oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`000000oooP0?oo
h01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00
oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?oo
h03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X0
0000603oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=`0
n_3V100000020?[`iPP000000P3jl>H4000000070?[`iP00000000000000003jl>H000000?[`iP0<
000000030?[`iP000000000000@0000000@0n_3V0000000000000000203jl>H5000000@0n_3V1`00
00000`3jl>H000000?[`iP03000000T0n_3V1@0000020?[`iP@000000P3jl>H500000180n_3V1P00
00060?[`iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H0000000000000003T0?[`iP40oooo
003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000`3jl>H01`000000n_3V0000
00000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V0?[`iP8000000P3jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01@3jl>H2
000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000000`3jl>H00000000000040?[`
iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000d0n_3V0P0000020?[`
iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P00000<0?[`iPD000001@3jl>H2000000H0n_3V1@000006
0?[`iP<00000iP3jl>H10?ooo`00g@3jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V0000
00000000n_3V0000003jl>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP00
000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V
0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01P3jl>H300000>H0n_3V
0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0
n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V00000000
0000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0`0000000`3jl>H000000?[`iP0B0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`
iP80000000<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H200000080n_3V0P0000000`3jl>H0
000000000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`iPD0
00000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000;0?[`iPD0
00000P3jl>H400000080n_3V0`0000000`3jl>H000000000000C0?[`iP8000003`3jl>H300000005
0?[`iP00000000000000003jl>H01000003O0?[`iP40oooo003M0?[`iP8000000P3jl>H2000003<0
n_3V0P0000030?[`iP030000003jl>H0n_3V01P0n_3V0P00000Q0?[`iP@00000603jl>H00`000000
n_3V0?[`iP3O0?[`iP40oooo003L0?[`iPH00000103jl>H2000002l0n_3V1@00000K0?[`iP<00000
8@3jl>H2000001T0n_3V00<000000?[`iP3jl>H0gP3jl>H10?ooo`00o`3jl>Ih0?[`iP030000003j
l>H0n_3V0=d0n_3V0@3oool00?l0n_3VM@3jl>H010000000n_3V0?[`iP00003O0?[`iP40oooo003o
0?[`iWH0n_3V0P00003P0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02645 .01472 L
.02645 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02645 .01472 L
.02645 .16187 L
s
1 .894 .882 r
.02645 .16187 m
.02645 .01472 L
.03103 .01472 L
.03103 .16187 L
F
.804 .522 .247 r
.02645 .16187 m
.02645 .01472 L
.03103 .01472 L
.03103 .16187 L
s
1 .894 .882 r
.03103 .16187 m
.03103 .01476 L
.03244 .01476 L
.03244 .16187 L
F
.804 .522 .247 r
.03103 .16187 m
.03103 .01476 L
.03244 .01476 L
.03244 .16187 L
s
1 .894 .882 r
.03244 .16187 m
.03244 .0148 L
.03588 .0148 L
.03588 .16187 L
F
.804 .522 .247 r
.03244 .16187 m
.03244 .0148 L
.03588 .0148 L
.03588 .16187 L
s
1 .894 .882 r
.03588 .16187 m
.03588 .01482 L
.03849 .01482 L
.03849 .16187 L
F
.804 .522 .247 r
.03588 .16187 m
.03588 .01482 L
.03849 .01482 L
.03849 .16187 L
s
1 .894 .882 r
.03849 .16187 m
.03849 .01488 L
.04224 .01488 L
.04224 .16187 L
F
.804 .522 .247 r
.03849 .16187 m
.03849 .01488 L
.04224 .01488 L
.04224 .16187 L
s
1 .894 .882 r
.04224 .16187 m
.04224 .01501 L
.04637 .01501 L
.04637 .16187 L
F
.804 .522 .247 r
.04224 .16187 m
.04224 .01501 L
.04637 .01501 L
.04637 .16187 L
s
1 .894 .882 r
.04637 .16187 m
.04637 .01512 L
.05002 .01512 L
.05002 .16187 L
F
.804 .522 .247 r
.04637 .16187 m
.04637 .01512 L
.05002 .01512 L
.05002 .16187 L
s
1 .894 .882 r
.05002 .16187 m
.05002 .01522 L
.05238 .01522 L
.05238 .16187 L
F
.804 .522 .247 r
.05002 .16187 m
.05002 .01522 L
.05238 .01522 L
.05238 .16187 L
s
1 .894 .882 r
.05238 .16187 m
.05238 .01526 L
.0569 .01526 L
.0569 .16187 L
F
.804 .522 .247 r
.05238 .16187 m
.05238 .01526 L
.0569 .01526 L
.0569 .16187 L
s
1 .894 .882 r
.0569 .16187 m
.0569 .01549 L
.05908 .01549 L
.05908 .16187 L
F
.804 .522 .247 r
.0569 .16187 m
.0569 .01549 L
.05908 .01549 L
.05908 .16187 L
s
1 .894 .882 r
.05908 .16187 m
.05908 .01554 L
.06144 .01554 L
.06144 .16187 L
F
.804 .522 .247 r
.05908 .16187 m
.05908 .01554 L
.06144 .01554 L
.06144 .16187 L
s
1 .894 .882 r
.06144 .16187 m
.06144 .01573 L
.06455 .01573 L
.06455 .16187 L
F
.804 .522 .247 r
.06144 .16187 m
.06144 .01573 L
.06455 .01573 L
.06455 .16187 L
s
1 .894 .882 r
.06455 .16187 m
.06455 .01592 L
.06869 .01592 L
.06869 .16187 L
F
.804 .522 .247 r
.06455 .16187 m
.06455 .01592 L
.06869 .01592 L
.06869 .16187 L
s
1 .894 .882 r
.06869 .16187 m
.06869 .01615 L
.07151 .01615 L
.07151 .16187 L
F
.804 .522 .247 r
.06869 .16187 m
.06869 .01615 L
.07151 .01615 L
.07151 .16187 L
s
1 .894 .882 r
.07151 .16187 m
.07151 .01622 L
.0751 .01622 L
.0751 .16187 L
F
.804 .522 .247 r
.07151 .16187 m
.07151 .01622 L
.0751 .01622 L
.0751 .16187 L
s
1 .894 .882 r
.0751 .16187 m
.0751 .01643 L
.07742 .01643 L
.07742 .16187 L
F
.804 .522 .247 r
.0751 .16187 m
.0751 .01643 L
.07742 .01643 L
.07742 .16187 L
s
1 .894 .882 r
.07742 .16187 m
.07742 .01669 L
.08125 .01669 L
.08125 .16187 L
F
.804 .522 .247 r
.07742 .16187 m
.07742 .01669 L
.08125 .01669 L
.08125 .16187 L
s
1 .894 .882 r
.08125 .16187 m
.08125 .01692 L
.08292 .01692 L
.08292 .16187 L
F
.804 .522 .247 r
.08125 .16187 m
.08125 .01692 L
.08292 .01692 L
.08292 .16187 L
s
1 .894 .882 r
.08292 .16187 m
.08292 .01699 L
.08577 .01699 L
.08577 .16187 L
F
.804 .522 .247 r
.08292 .16187 m
.08292 .01699 L
.08577 .01699 L
.08577 .16187 L
s
1 .894 .882 r
.08577 .16187 m
.08577 .0174 L
.08868 .0174 L
.08868 .16187 L
F
.804 .522 .247 r
.08577 .16187 m
.08577 .0174 L
.08868 .0174 L
.08868 .16187 L
s
1 .894 .882 r
.08868 .16187 m
.08868 .01753 L
.09018 .01753 L
.09018 .16187 L
F
.804 .522 .247 r
.08868 .16187 m
.08868 .01753 L
.09018 .01753 L
.09018 .16187 L
s
1 .894 .882 r
.09018 .16187 m
.09018 .0176 L
.09275 .0176 L
.09275 .16187 L
F
.804 .522 .247 r
.09018 .16187 m
.09018 .0176 L
.09275 .0176 L
.09275 .16187 L
s
1 .894 .882 r
.09275 .16187 m
.09275 .01783 L
.0962 .01783 L
.0962 .16187 L
F
.804 .522 .247 r
.09275 .16187 m
.09275 .01783 L
.0962 .01783 L
.0962 .16187 L
s
1 .894 .882 r
.0962 .16187 m
.0962 .01816 L
.09784 .01816 L
.09784 .16187 L
F
.804 .522 .247 r
.0962 .16187 m
.0962 .01816 L
.09784 .01816 L
.09784 .16187 L
s
1 .894 .882 r
.09784 .16187 m
.09784 .01836 L
.09935 .01836 L
.09935 .16187 L
F
.804 .522 .247 r
.09784 .16187 m
.09784 .01836 L
.09935 .01836 L
.09935 .16187 L
s
1 .894 .882 r
.09935 .16187 m
.09935 .0185 L
.10189 .0185 L
.10189 .16187 L
F
.804 .522 .247 r
.09935 .16187 m
.09935 .0185 L
.10189 .0185 L
.10189 .16187 L
s
1 .894 .882 r
.10189 .16187 m
.10189 .0187 L
.10327 .0187 L
.10327 .16187 L
F
.804 .522 .247 r
.10189 .16187 m
.10189 .0187 L
.10327 .0187 L
.10327 .16187 L
s
1 .894 .882 r
.10327 .16187 m
.10327 .01883 L
.1069 .01883 L
.1069 .16187 L
F
.804 .522 .247 r
.10327 .16187 m
.10327 .01883 L
.1069 .01883 L
.1069 .16187 L
s
1 .894 .882 r
.1069 .16187 m
.1069 .01926 L
.10924 .01926 L
.10924 .16187 L
F
.804 .522 .247 r
.1069 .16187 m
.1069 .01926 L
.10924 .01926 L
.10924 .16187 L
s
1 .894 .882 r
.10924 .16187 m
.10924 .01968 L
.11224 .01968 L
.11224 .16187 L
F
.804 .522 .247 r
.10924 .16187 m
.10924 .01968 L
.11224 .01968 L
.11224 .16187 L
s
1 .894 .882 r
.11224 .16187 m
.11224 .01994 L
.11457 .01994 L
.11457 .16187 L
F
.804 .522 .247 r
.11224 .16187 m
.11224 .01994 L
.11457 .01994 L
.11457 .16187 L
s
1 .894 .882 r
.11457 .16187 m
.11457 .02017 L
.11721 .02017 L
.11721 .16187 L
F
.804 .522 .247 r
.11457 .16187 m
.11457 .02017 L
.11721 .02017 L
.11721 .16187 L
s
1 .894 .882 r
.11721 .16187 m
.11721 .02043 L
.11962 .02043 L
.11962 .16187 L
F
.804 .522 .247 r
.11721 .16187 m
.11721 .02043 L
.11962 .02043 L
.11962 .16187 L
s
1 .894 .882 r
.11962 .16187 m
.11962 .02068 L
.12182 .02068 L
.12182 .16187 L
F
.804 .522 .247 r
.11962 .16187 m
.11962 .02068 L
.12182 .02068 L
.12182 .16187 L
s
1 .894 .882 r
.12182 .16187 m
.12182 .02117 L
.12638 .02117 L
.12638 .16187 L
F
.804 .522 .247 r
.12182 .16187 m
.12182 .02117 L
.12638 .02117 L
.12638 .16187 L
s
1 .894 .882 r
.12638 .16187 m
.12638 .02196 L
.1305 .02196 L
.1305 .16187 L
F
.804 .522 .247 r
.12638 .16187 m
.12638 .02196 L
.1305 .02196 L
.1305 .16187 L
s
1 .894 .882 r
.1305 .16187 m
.1305 .02235 L
.13336 .02235 L
.13336 .16187 L
F
.804 .522 .247 r
.1305 .16187 m
.1305 .02235 L
.13336 .02235 L
.13336 .16187 L
s
1 .894 .882 r
.13336 .16187 m
.13336 .02265 L
.13733 .02265 L
.13733 .16187 L
F
.804 .522 .247 r
.13336 .16187 m
.13336 .02265 L
.13733 .02265 L
.13733 .16187 L
s
1 .894 .882 r
.13733 .16187 m
.13733 .02317 L
.13968 .02317 L
.13968 .16187 L
F
.804 .522 .247 r
.13733 .16187 m
.13733 .02317 L
.13968 .02317 L
.13968 .16187 L
s
1 .894 .882 r
.13968 .16187 m
.13968 .02375 L
.14285 .02375 L
.14285 .16187 L
F
.804 .522 .247 r
.13968 .16187 m
.13968 .02375 L
.14285 .02375 L
.14285 .16187 L
s
1 .894 .882 r
.14285 .16187 m
.14285 .02402 L
.14648 .02402 L
.14648 .16187 L
F
.804 .522 .247 r
.14285 .16187 m
.14285 .02402 L
.14648 .02402 L
.14648 .16187 L
s
1 .894 .882 r
.14648 .16187 m
.14648 .02491 L
.15016 .02491 L
.15016 .16187 L
F
.804 .522 .247 r
.14648 .16187 m
.14648 .02491 L
.15016 .02491 L
.15016 .16187 L
s
1 .894 .882 r
.15016 .16187 m
.15016 .02524 L
.15424 .02524 L
.15424 .16187 L
F
.804 .522 .247 r
.15016 .16187 m
.15016 .02524 L
.15424 .02524 L
.15424 .16187 L
s
1 .894 .882 r
.15424 .16187 m
.15424 .02599 L
.15588 .02599 L
.15588 .16187 L
F
.804 .522 .247 r
.15424 .16187 m
.15424 .02599 L
.15588 .02599 L
.15588 .16187 L
s
1 .894 .882 r
.15588 .16187 m
.15588 .02635 L
.15939 .02635 L
.15939 .16187 L
F
.804 .522 .247 r
.15588 .16187 m
.15588 .02635 L
.15939 .02635 L
.15939 .16187 L
s
1 .894 .882 r
.15939 .16187 m
.15939 .02692 L
.16187 .02692 L
.16187 .16187 L
F
.804 .522 .247 r
.15939 .16187 m
.15939 .02692 L
.16187 .02692 L
.16187 .16187 L
s
1 .894 .882 r
.16187 .16187 m
.16187 .02714 L
.16388 .02714 L
.16388 .16187 L
F
.804 .522 .247 r
.16187 .16187 m
.16187 .02714 L
.16388 .02714 L
.16388 .16187 L
s
1 .894 .882 r
.16388 .16187 m
.16388 .02758 L
.16526 .02758 L
.16526 .16187 L
F
.804 .522 .247 r
.16388 .16187 m
.16388 .02758 L
.16526 .02758 L
.16526 .16187 L
s
1 .894 .882 r
.16526 .16187 m
.16526 .02829 L
.16863 .02829 L
.16863 .16187 L
F
.804 .522 .247 r
.16526 .16187 m
.16526 .02829 L
.16863 .02829 L
.16863 .16187 L
s
1 .894 .882 r
.16863 .16187 m
.16863 .02858 L
.17317 .02858 L
.17317 .16187 L
F
.804 .522 .247 r
.16863 .16187 m
.16863 .02858 L
.17317 .02858 L
.17317 .16187 L
s
1 .894 .882 r
.17317 .16187 m
.17317 .02955 L
.17517 .02955 L
.17517 .16187 L
F
.804 .522 .247 r
.17317 .16187 m
.17317 .02955 L
.17517 .02955 L
.17517 .16187 L
s
1 .894 .882 r
.17517 .16187 m
.17517 .02981 L
.17751 .02981 L
.17751 .16187 L
F
.804 .522 .247 r
.17517 .16187 m
.17517 .02981 L
.17751 .02981 L
.17751 .16187 L
s
1 .894 .882 r
.17751 .16187 m
.17751 .03038 L
.17992 .03038 L
.17992 .16187 L
F
.804 .522 .247 r
.17751 .16187 m
.17751 .03038 L
.17992 .03038 L
.17992 .16187 L
s
1 .894 .882 r
.17992 .16187 m
.17992 .0309 L
.18283 .0309 L
.18283 .16187 L
F
.804 .522 .247 r
.17992 .16187 m
.17992 .0309 L
.18283 .0309 L
.18283 .16187 L
s
1 .894 .882 r
.18283 .16187 m
.18283 .03143 L
.1871 .03143 L
.1871 .16187 L
F
.804 .522 .247 r
.18283 .16187 m
.18283 .03143 L
.1871 .03143 L
.1871 .16187 L
s
1 .894 .882 r
.1871 .16187 m
.1871 .03215 L
.19138 .03215 L
.19138 .16187 L
F
.804 .522 .247 r
.1871 .16187 m
.1871 .03215 L
.19138 .03215 L
.19138 .16187 L
s
1 .894 .882 r
.19138 .16187 m
.19138 .03346 L
.19597 .03346 L
.19597 .16187 L
F
.804 .522 .247 r
.19138 .16187 m
.19138 .03346 L
.19597 .03346 L
.19597 .16187 L
s
1 .894 .882 r
.19597 .16187 m
.19597 .03423 L
.19806 .03423 L
.19806 .16187 L
F
.804 .522 .247 r
.19597 .16187 m
.19597 .03423 L
.19806 .03423 L
.19806 .16187 L
s
1 .894 .882 r
.19806 .16187 m
.19806 .03537 L
.20236 .03537 L
.20236 .16187 L
F
.804 .522 .247 r
.19806 .16187 m
.19806 .03537 L
.20236 .03537 L
.20236 .16187 L
s
1 .894 .882 r
.20236 .16187 m
.20236 .03555 L
.2039 .03555 L
.2039 .16187 L
F
.804 .522 .247 r
.20236 .16187 m
.20236 .03555 L
.2039 .03555 L
.2039 .16187 L
s
1 .894 .882 r
.2039 .16187 m
.2039 .03642 L
.207 .03642 L
.207 .16187 L
F
.804 .522 .247 r
.2039 .16187 m
.2039 .03642 L
.207 .03642 L
.207 .16187 L
s
1 .894 .882 r
.207 .16187 m
.207 .03672 L
.20971 .03672 L
.20971 .16187 L
F
.804 .522 .247 r
.207 .16187 m
.207 .03672 L
.20971 .03672 L
.20971 .16187 L
s
1 .894 .882 r
.20971 .16187 m
.20971 .03771 L
.21304 .03771 L
.21304 .16187 L
F
.804 .522 .247 r
.20971 .16187 m
.20971 .03771 L
.21304 .03771 L
.21304 .16187 L
s
1 .894 .882 r
.21304 .16187 m
.21304 .03849 L
.216 .03849 L
.216 .16187 L
F
.804 .522 .247 r
.21304 .16187 m
.21304 .03849 L
.216 .03849 L
.216 .16187 L
s
1 .894 .882 r
.216 .16187 m
.216 .0394 L
.22007 .0394 L
.22007 .16187 L
F
.804 .522 .247 r
.216 .16187 m
.216 .0394 L
.22007 .0394 L
.22007 .16187 L
s
1 .894 .882 r
.22007 .16187 m
.22007 .04029 L
.22369 .04029 L
.22369 .16187 L
F
.804 .522 .247 r
.22007 .16187 m
.22007 .04029 L
.22369 .04029 L
.22369 .16187 L
s
1 .894 .882 r
.22369 .16187 m
.22369 .04109 L
.22753 .04109 L
.22753 .16187 L
F
.804 .522 .247 r
.22369 .16187 m
.22369 .04109 L
.22753 .04109 L
.22753 .16187 L
s
1 .894 .882 r
.22753 .16187 m
.22753 .04227 L
.23022 .04227 L
.23022 .16187 L
F
.804 .522 .247 r
.22753 .16187 m
.22753 .04227 L
.23022 .04227 L
.23022 .16187 L
s
1 .894 .882 r
.23022 .16187 m
.23022 .04245 L
.23215 .04245 L
.23215 .16187 L
F
.804 .522 .247 r
.23022 .16187 m
.23022 .04245 L
.23215 .04245 L
.23215 .16187 L
s
1 .894 .882 r
.23215 .16187 m
.23215 .04356 L
.23467 .04356 L
.23467 .16187 L
F
.804 .522 .247 r
.23215 .16187 m
.23215 .04356 L
.23467 .04356 L
.23467 .16187 L
s
1 .894 .882 r
.23467 .16187 m
.23467 .04384 L
.23788 .04384 L
.23788 .16187 L
F
.804 .522 .247 r
.23467 .16187 m
.23467 .04384 L
.23788 .04384 L
.23788 .16187 L
s
1 .894 .882 r
.23788 .16187 m
.23788 .0447 L
.24057 .0447 L
.24057 .16187 L
F
.804 .522 .247 r
.23788 .16187 m
.23788 .0447 L
.24057 .0447 L
.24057 .16187 L
s
1 .894 .882 r
.24057 .16187 m
.24057 .04541 L
.24372 .04541 L
.24372 .16187 L
F
.804 .522 .247 r
.24057 .16187 m
.24057 .04541 L
.24372 .04541 L
.24372 .16187 L
s
1 .894 .882 r
.24372 .16187 m
.24372 .04661 L
.2463 .04661 L
.2463 .16187 L
F
.804 .522 .247 r
.24372 .16187 m
.24372 .04661 L
.2463 .04661 L
.2463 .16187 L
s
1 .894 .882 r
.2463 .16187 m
.2463 .04712 L
.24888 .04712 L
.24888 .16187 L
F
.804 .522 .247 r
.2463 .16187 m
.2463 .04712 L
.24888 .04712 L
.24888 .16187 L
s
1 .894 .882 r
.24888 .16187 m
.24888 .04801 L
.25061 .04801 L
.25061 .16187 L
F
.804 .522 .247 r
.24888 .16187 m
.24888 .04801 L
.25061 .04801 L
.25061 .16187 L
s
1 .894 .882 r
.25061 .16187 m
.25061 .04842 L
.25272 .04842 L
.25272 .16187 L
F
.804 .522 .247 r
.25061 .16187 m
.25061 .04842 L
.25272 .04842 L
.25272 .16187 L
s
1 .894 .882 r
.25272 .16187 m
.25272 .0488 L
.25698 .0488 L
.25698 .16187 L
F
.804 .522 .247 r
.25272 .16187 m
.25272 .0488 L
.25698 .0488 L
.25698 .16187 L
s
1 .894 .882 r
.25698 .16187 m
.25698 .05002 L
.25989 .05002 L
.25989 .16187 L
F
.804 .522 .247 r
.25698 .16187 m
.25698 .05002 L
.25989 .05002 L
.25989 .16187 L
s
1 .894 .882 r
.25989 .16187 m
.25989 .05131 L
.26192 .05131 L
.26192 .16187 L
F
.804 .522 .247 r
.25989 .16187 m
.25989 .05131 L
.26192 .05131 L
.26192 .16187 L
s
1 .894 .882 r
.26192 .16187 m
.26192 .05151 L
.26403 .05151 L
.26403 .16187 L
F
.804 .522 .247 r
.26192 .16187 m
.26192 .05151 L
.26403 .05151 L
.26403 .16187 L
s
1 .894 .882 r
.26403 .16187 m
.26403 .05267 L
.26758 .05267 L
.26758 .16187 L
F
.804 .522 .247 r
.26403 .16187 m
.26403 .05267 L
.26758 .05267 L
.26758 .16187 L
s
1 .894 .882 r
.26758 .16187 m
.26758 .05334 L
.27078 .05334 L
.27078 .16187 L
F
.804 .522 .247 r
.26758 .16187 m
.26758 .05334 L
.27078 .05334 L
.27078 .16187 L
s
1 .894 .882 r
.27078 .16187 m
.27078 .05446 L
.27265 .05446 L
.27265 .16187 L
F
.804 .522 .247 r
.27078 .16187 m
.27078 .05446 L
.27265 .05446 L
.27265 .16187 L
s
1 .894 .882 r
.27265 .16187 m
.27265 .05502 L
.27625 .05502 L
.27625 .16187 L
F
.804 .522 .247 r
.27265 .16187 m
.27265 .05502 L
.27625 .05502 L
.27625 .16187 L
s
1 .894 .882 r
.27625 .16187 m
.27625 .05614 L
.27846 .05614 L
.27846 .16187 L
F
.804 .522 .247 r
.27625 .16187 m
.27625 .05614 L
.27846 .05614 L
.27846 .16187 L
s
1 .894 .882 r
.27846 .16187 m
.27846 .05732 L
.28291 .05732 L
.28291 .16187 L
F
.804 .522 .247 r
.27846 .16187 m
.27846 .05732 L
.28291 .05732 L
.28291 .16187 L
s
1 .894 .882 r
.28291 .16187 m
.28291 .05893 L
.28642 .05893 L
.28642 .16187 L
F
.804 .522 .247 r
.28291 .16187 m
.28291 .05893 L
.28642 .05893 L
.28642 .16187 L
s
1 .894 .882 r
.28642 .16187 m
.28642 .06003 L
.29054 .06003 L
.29054 .16187 L
F
.804 .522 .247 r
.28642 .16187 m
.28642 .06003 L
.29054 .06003 L
.29054 .16187 L
s
1 .894 .882 r
.29054 .16187 m
.29054 .06141 L
.29372 .06141 L
.29372 .16187 L
F
.804 .522 .247 r
.29054 .16187 m
.29054 .06141 L
.29372 .06141 L
.29372 .16187 L
s
1 .894 .882 r
.29372 .16187 m
.29372 .06263 L
.29571 .06263 L
.29571 .16187 L
F
.804 .522 .247 r
.29372 .16187 m
.29372 .06263 L
.29571 .06263 L
.29571 .16187 L
s
1 .894 .882 r
.29571 .16187 m
.29571 .06321 L
.2979 .06321 L
.2979 .16187 L
F
.804 .522 .247 r
.29571 .16187 m
.29571 .06321 L
.2979 .06321 L
.2979 .16187 L
s
1 .894 .882 r
.2979 .16187 m
.2979 .06376 L
.30147 .06376 L
.30147 .16187 L
F
.804 .522 .247 r
.2979 .16187 m
.2979 .06376 L
.30147 .06376 L
.30147 .16187 L
s
1 .894 .882 r
.30147 .16187 m
.30147 .0651 L
.30351 .0651 L
.30351 .16187 L
F
.804 .522 .247 r
.30147 .16187 m
.30147 .0651 L
.30351 .0651 L
.30351 .16187 L
s
1 .894 .882 r
.30351 .16187 m
.30351 .06622 L
.30688 .06622 L
.30688 .16187 L
F
.804 .522 .247 r
.30351 .16187 m
.30351 .06622 L
.30688 .06622 L
.30688 .16187 L
s
1 .894 .882 r
.30688 .16187 m
.30688 .06723 L
.31097 .06723 L
.31097 .16187 L
F
.804 .522 .247 r
.30688 .16187 m
.30688 .06723 L
.31097 .06723 L
.31097 .16187 L
s
1 .894 .882 r
.31097 .16187 m
.31097 .0689 L
.31277 .0689 L
.31277 .16187 L
F
.804 .522 .247 r
.31097 .16187 m
.31097 .0689 L
.31277 .0689 L
.31277 .16187 L
s
1 .894 .882 r
.31277 .16187 m
.31277 .07011 L
.31682 .07011 L
.31682 .16187 L
F
.804 .522 .247 r
.31277 .16187 m
.31277 .07011 L
.31682 .07011 L
.31682 .16187 L
s
1 .894 .882 r
.31682 .16187 m
.31682 .07061 L
.31898 .07061 L
.31898 .16187 L
F
.804 .522 .247 r
.31682 .16187 m
.31682 .07061 L
.31898 .07061 L
.31898 .16187 L
s
1 .894 .882 r
.31898 .16187 m
.31898 .07199 L
.32272 .07199 L
.32272 .16187 L
F
.804 .522 .247 r
.31898 .16187 m
.31898 .07199 L
.32272 .07199 L
.32272 .16187 L
s
1 .894 .882 r
.32272 .16187 m
.32272 .07347 L
.327 .07347 L
.327 .16187 L
F
.804 .522 .247 r
.32272 .16187 m
.32272 .07347 L
.327 .07347 L
.327 .16187 L
s
1 .894 .882 r
.327 .16187 m
.327 .07562 L
.33138 .07562 L
.33138 .16187 L
F
.804 .522 .247 r
.327 .16187 m
.327 .07562 L
.33138 .07562 L
.33138 .16187 L
s
1 .894 .882 r
.33138 .16187 m
.33138 .0764 L
.33523 .0764 L
.33523 .16187 L
F
.804 .522 .247 r
.33138 .16187 m
.33138 .0764 L
.33523 .0764 L
.33523 .16187 L
s
1 .894 .882 r
.33523 .16187 m
.33523 .07869 L
.33831 .07869 L
.33831 .16187 L
F
.804 .522 .247 r
.33523 .16187 m
.33523 .07869 L
.33831 .07869 L
.33831 .16187 L
s
1 .894 .882 r
.33831 .16187 m
.33831 .07957 L
.34185 .07957 L
.34185 .16187 L
F
.804 .522 .247 r
.33831 .16187 m
.33831 .07957 L
.34185 .07957 L
.34185 .16187 L
s
1 .894 .882 r
.34185 .16187 m
.34185 .0806 L
.34407 .0806 L
.34407 .16187 L
F
.804 .522 .247 r
.34185 .16187 m
.34185 .0806 L
.34407 .0806 L
.34407 .16187 L
s
1 .894 .882 r
.34407 .16187 m
.34407 .08139 L
.34609 .08139 L
.34609 .16187 L
F
.804 .522 .247 r
.34407 .16187 m
.34407 .08139 L
.34609 .08139 L
.34609 .16187 L
s
1 .894 .882 r
.34609 .16187 m
.34609 .08272 L
.34868 .08272 L
.34868 .16187 L
F
.804 .522 .247 r
.34609 .16187 m
.34609 .08272 L
.34868 .08272 L
.34868 .16187 L
s
1 .894 .882 r
.34868 .16187 m
.34868 .08389 L
.35322 .08389 L
.35322 .16187 L
F
.804 .522 .247 r
.34868 .16187 m
.34868 .08389 L
.35322 .08389 L
.35322 .16187 L
s
1 .894 .882 r
.35322 .16187 m
.35322 .08545 L
.35781 .08545 L
.35781 .16187 L
F
.804 .522 .247 r
.35322 .16187 m
.35322 .08545 L
.35781 .08545 L
.35781 .16187 L
s
1 .894 .882 r
.35781 .16187 m
.35781 .08783 L
.35996 .08783 L
.35996 .16187 L
F
.804 .522 .247 r
.35781 .16187 m
.35781 .08783 L
.35996 .08783 L
.35996 .16187 L
s
1 .894 .882 r
.35996 .16187 m
.35996 .08805 L
.36364 .08805 L
.36364 .16187 L
F
.804 .522 .247 r
.35996 .16187 m
.35996 .08805 L
.36364 .08805 L
.36364 .16187 L
s
1 .894 .882 r
.36364 .16187 m
.36364 .09041 L
.36543 .09041 L
.36543 .16187 L
F
.804 .522 .247 r
.36364 .16187 m
.36364 .09041 L
.36543 .09041 L
.36543 .16187 L
s
1 .894 .882 r
.36543 .16187 m
.36543 .0913 L
.36822 .0913 L
.36822 .16187 L
F
.804 .522 .247 r
.36543 .16187 m
.36543 .0913 L
.36822 .0913 L
.36822 .16187 L
s
1 .894 .882 r
.36822 .16187 m
.36822 .09229 L
.36976 .09229 L
.36976 .16187 L
F
.804 .522 .247 r
.36822 .16187 m
.36822 .09229 L
.36976 .09229 L
.36976 .16187 L
s
1 .894 .882 r
.36976 .16187 m
.36976 .09281 L
.37262 .09281 L
.37262 .16187 L
F
.804 .522 .247 r
.36976 .16187 m
.36976 .09281 L
.37262 .09281 L
.37262 .16187 L
s
1 .894 .882 r
.37262 .16187 m
.37262 .0946 L
.37543 .0946 L
.37543 .16187 L
F
.804 .522 .247 r
.37262 .16187 m
.37262 .0946 L
.37543 .0946 L
.37543 .16187 L
s
1 .894 .882 r
.37543 .16187 m
.37543 .09514 L
.37756 .09514 L
.37756 .16187 L
F
.804 .522 .247 r
.37543 .16187 m
.37543 .09514 L
.37756 .09514 L
.37756 .16187 L
s
1 .894 .882 r
.37756 .16187 m
.37756 .09626 L
.38032 .09626 L
.38032 .16187 L
F
.804 .522 .247 r
.37756 .16187 m
.37756 .09626 L
.38032 .09626 L
.38032 .16187 L
s
1 .894 .882 r
.38032 .16187 m
.38032 .09874 L
.38368 .09874 L
.38368 .16187 L
F
.804 .522 .247 r
.38032 .16187 m
.38032 .09874 L
.38368 .09874 L
.38368 .16187 L
s
1 .894 .882 r
.38368 .16187 m
.38368 .09958 L
.38607 .09958 L
.38607 .16187 L
F
.804 .522 .247 r
.38368 .16187 m
.38368 .09958 L
.38607 .09958 L
.38607 .16187 L
s
1 .894 .882 r
.38607 .16187 m
.38607 .10039 L
.38874 .10039 L
.38874 .16187 L
F
.804 .522 .247 r
.38607 .16187 m
.38607 .10039 L
.38874 .10039 L
.38874 .16187 L
s
1 .894 .882 r
.38874 .16187 m
.38874 .10118 L
.39072 .10118 L
.39072 .16187 L
F
.804 .522 .247 r
.38874 .16187 m
.38874 .10118 L
.39072 .10118 L
.39072 .16187 L
s
1 .894 .882 r
.39072 .16187 m
.39072 .10303 L
.39493 .10303 L
.39493 .16187 L
F
.804 .522 .247 r
.39072 .16187 m
.39072 .10303 L
.39493 .10303 L
.39493 .16187 L
s
1 .894 .882 r
.39493 .16187 m
.39493 .10445 L
.39763 .10445 L
.39763 .16187 L
F
.804 .522 .247 r
.39493 .16187 m
.39493 .10445 L
.39763 .10445 L
.39763 .16187 L
s
1 .894 .882 r
.39763 .16187 m
.39763 .10636 L
.40051 .10636 L
.40051 .16187 L
F
.804 .522 .247 r
.39763 .16187 m
.39763 .10636 L
.40051 .10636 L
.40051 .16187 L
s
1 .894 .882 r
.40051 .16187 m
.40051 .10794 L
.40323 .10794 L
.40323 .16187 L
F
.804 .522 .247 r
.40051 .16187 m
.40051 .10794 L
.40323 .10794 L
.40323 .16187 L
s
1 .894 .882 r
.40323 .16187 m
.40323 .10894 L
.40573 .10894 L
.40573 .16187 L
F
.804 .522 .247 r
.40323 .16187 m
.40323 .10894 L
.40573 .10894 L
.40573 .16187 L
s
1 .894 .882 r
.40573 .16187 m
.40573 .11088 L
.40948 .11088 L
.40948 .16187 L
F
.804 .522 .247 r
.40573 .16187 m
.40573 .11088 L
.40948 .11088 L
.40948 .16187 L
s
1 .894 .882 r
.40948 .16187 m
.40948 .11167 L
.41152 .11167 L
.41152 .16187 L
F
.804 .522 .247 r
.40948 .16187 m
.40948 .11167 L
.41152 .11167 L
.41152 .16187 L
s
1 .894 .882 r
.41152 .16187 m
.41152 .11302 L
.4136 .11302 L
.4136 .16187 L
F
.804 .522 .247 r
.41152 .16187 m
.41152 .11302 L
.4136 .11302 L
.4136 .16187 L
s
1 .894 .882 r
.4136 .16187 m
.4136 .11353 L
.4181 .11353 L
.4181 .16187 L
F
.804 .522 .247 r
.4136 .16187 m
.4136 .11353 L
.4181 .11353 L
.4181 .16187 L
s
1 .894 .882 r
.4181 .16187 m
.4181 .11649 L
.4219 .11649 L
.4219 .16187 L
F
.804 .522 .247 r
.4181 .16187 m
.4181 .11649 L
.4219 .11649 L
.4219 .16187 L
s
1 .894 .882 r
.4219 .16187 m
.4219 .11782 L
.42395 .11782 L
.42395 .16187 L
F
.804 .522 .247 r
.4219 .16187 m
.4219 .11782 L
.42395 .11782 L
.42395 .16187 L
s
1 .894 .882 r
.42395 .16187 m
.42395 .12084 L
.42846 .12084 L
.42846 .16187 L
F
.804 .522 .247 r
.42395 .16187 m
.42395 .12084 L
.42846 .12084 L
.42846 .16187 L
s
1 .894 .882 r
.42846 .16187 m
.42846 .12108 L
.43066 .12108 L
.43066 .16187 L
F
.804 .522 .247 r
.42846 .16187 m
.42846 .12108 L
.43066 .12108 L
.43066 .16187 L
s
1 .894 .882 r
.43066 .16187 m
.43066 .12302 L
.43405 .12302 L
.43405 .16187 L
F
.804 .522 .247 r
.43066 .16187 m
.43066 .12302 L
.43405 .12302 L
.43405 .16187 L
s
1 .894 .882 r
.43405 .16187 m
.43405 .12509 L
.43789 .12509 L
.43789 .16187 L
F
.804 .522 .247 r
.43405 .16187 m
.43405 .12509 L
.43789 .12509 L
.43789 .16187 L
s
1 .894 .882 r
.43789 .16187 m
.43789 .12616 L
.44224 .12616 L
.44224 .16187 L
F
.804 .522 .247 r
.43789 .16187 m
.43789 .12616 L
.44224 .12616 L
.44224 .16187 L
s
1 .894 .882 r
.44224 .16187 m
.44224 .12996 L
.44617 .12996 L
.44617 .16187 L
F
.804 .522 .247 r
.44224 .16187 m
.44224 .12996 L
.44617 .12996 L
.44617 .16187 L
s
1 .894 .882 r
.44617 .16187 m
.44617 .1313 L
.44812 .1313 L
.44812 .16187 L
F
.804 .522 .247 r
.44617 .16187 m
.44617 .1313 L
.44812 .1313 L
.44812 .16187 L
s
1 .894 .882 r
.44812 .16187 m
.44812 .13218 L
.45122 .13218 L
.45122 .16187 L
F
.804 .522 .247 r
.44812 .16187 m
.44812 .13218 L
.45122 .13218 L
.45122 .16187 L
s
1 .894 .882 r
.45122 .16187 m
.45122 .13459 L
.45418 .13459 L
.45418 .16187 L
F
.804 .522 .247 r
.45122 .16187 m
.45122 .13459 L
.45418 .13459 L
.45418 .16187 L
s
1 .894 .882 r
.45418 .16187 m
.45418 .13575 L
.45612 .13575 L
.45612 .16187 L
F
.804 .522 .247 r
.45418 .16187 m
.45418 .13575 L
.45612 .13575 L
.45612 .16187 L
s
1 .894 .882 r
.45612 .16187 m
.45612 .13607 L
.46028 .13607 L
.46028 .16187 L
F
.804 .522 .247 r
.45612 .16187 m
.45612 .13607 L
.46028 .13607 L
.46028 .16187 L
s
1 .894 .882 r
.46028 .16187 m
.46028 .13932 L
.46208 .13932 L
.46208 .16187 L
F
.804 .522 .247 r
.46028 .16187 m
.46028 .13932 L
.46208 .13932 L
.46208 .16187 L
s
1 .894 .882 r
.46208 .16187 m
.46208 .14038 L
.46444 .14038 L
.46444 .16187 L
F
.804 .522 .247 r
.46208 .16187 m
.46208 .14038 L
.46444 .14038 L
.46444 .16187 L
s
1 .894 .882 r
.46444 .16187 m
.46444 .1411 L
.46677 .1411 L
.46677 .16187 L
F
.804 .522 .247 r
.46444 .16187 m
.46444 .1411 L
.46677 .1411 L
.46677 .16187 L
s
1 .894 .882 r
.46677 .16187 m
.46677 .14328 L
.4696 .14328 L
.4696 .16187 L
F
.804 .522 .247 r
.46677 .16187 m
.46677 .14328 L
.4696 .14328 L
.4696 .16187 L
s
1 .894 .882 r
.4696 .16187 m
.4696 .14424 L
.47312 .14424 L
.47312 .16187 L
F
.804 .522 .247 r
.4696 .16187 m
.4696 .14424 L
.47312 .14424 L
.47312 .16187 L
s
1 .894 .882 r
.47312 .16187 m
.47312 .14796 L
.47734 .14796 L
.47734 .16187 L
F
.804 .522 .247 r
.47312 .16187 m
.47312 .14796 L
.47734 .14796 L
.47734 .16187 L
s
1 .894 .882 r
.47734 .16187 m
.47734 .14988 L
.48175 .14988 L
.48175 .16187 L
F
.804 .522 .247 r
.47734 .16187 m
.47734 .14988 L
.48175 .14988 L
.48175 .16187 L
s
1 .894 .882 r
.48175 .16187 m
.48175 .15289 L
.48543 .15289 L
.48543 .16187 L
F
.804 .522 .247 r
.48175 .16187 m
.48175 .15289 L
.48543 .15289 L
.48543 .16187 L
s
1 .894 .882 r
.48543 .16187 m
.48543 .15447 L
.48828 .15447 L
.48828 .16187 L
F
.804 .522 .247 r
.48543 .16187 m
.48543 .15447 L
.48828 .15447 L
.48828 .16187 L
s
1 .894 .882 r
.48828 .16187 m
.48828 .1551 L
.4918 .1551 L
.4918 .16187 L
F
.804 .522 .247 r
.48828 .16187 m
.48828 .1551 L
.4918 .1551 L
.4918 .16187 L
s
1 .894 .882 r
.4918 .16187 m
.4918 .15836 L
.49631 .15836 L
.49631 .16187 L
F
.804 .522 .247 r
.4918 .16187 m
.4918 .15836 L
.49631 .15836 L
.49631 .16187 L
s
1 .894 .882 r
.49631 .16187 m
.49631 .16095 L
.50077 .16095 L
.50077 .16187 L
F
.804 .522 .247 r
.49631 .16187 m
.49631 .16095 L
.50077 .16095 L
.50077 .16187 L
s
.678 .847 .902 r
.50077 .16187 m
.50077 .16316 L
.50296 .16316 L
.50296 .16187 L
F
.2 .63 .79 r
.50077 .16187 m
.50077 .16316 L
.50296 .16316 L
.50296 .16187 L
s
.678 .847 .902 r
.50296 .16187 m
.50296 .16424 L
.50655 .16424 L
.50655 .16187 L
F
.2 .63 .79 r
.50296 .16187 m
.50296 .16424 L
.50655 .16424 L
.50655 .16187 L
s
.678 .847 .902 r
.50655 .16187 m
.50655 .16701 L
.51024 .16701 L
.51024 .16187 L
F
.2 .63 .79 r
.50655 .16187 m
.50655 .16701 L
.51024 .16701 L
.51024 .16187 L
s
.678 .847 .902 r
.51024 .16187 m
.51024 .16981 L
.51269 .16981 L
.51269 .16187 L
F
.2 .63 .79 r
.51024 .16187 m
.51024 .16981 L
.51269 .16981 L
.51269 .16187 L
s
.678 .847 .902 r
.51269 .16187 m
.51269 .16989 L
.51562 .16989 L
.51562 .16187 L
F
.2 .63 .79 r
.51269 .16187 m
.51269 .16989 L
.51562 .16989 L
.51562 .16187 L
s
.678 .847 .902 r
.51562 .16187 m
.51562 .17209 L
.51946 .17209 L
.51946 .16187 L
F
.2 .63 .79 r
.51562 .16187 m
.51562 .17209 L
.51946 .17209 L
.51946 .16187 L
s
.678 .847 .902 r
.51946 .16187 m
.51946 .17611 L
.52381 .17611 L
.52381 .16187 L
F
.2 .63 .79 r
.51946 .16187 m
.51946 .17611 L
.52381 .17611 L
.52381 .16187 L
s
.678 .847 .902 r
.52381 .16187 m
.52381 .17723 L
.52568 .17723 L
.52568 .16187 L
F
.2 .63 .79 r
.52381 .16187 m
.52381 .17723 L
.52568 .17723 L
.52568 .16187 L
s
.678 .847 .902 r
.52568 .16187 m
.52568 .18011 L
.5301 .18011 L
.5301 .16187 L
F
.2 .63 .79 r
.52568 .16187 m
.52568 .18011 L
.5301 .18011 L
.5301 .16187 L
s
.678 .847 .902 r
.5301 .16187 m
.5301 .1816 L
.53236 .1816 L
.53236 .16187 L
F
.2 .63 .79 r
.5301 .16187 m
.5301 .1816 L
.53236 .1816 L
.53236 .16187 L
s
.678 .847 .902 r
.53236 .16187 m
.53236 .18488 L
.53614 .18488 L
.53614 .16187 L
F
.2 .63 .79 r
.53236 .16187 m
.53236 .18488 L
.53614 .18488 L
.53614 .16187 L
s
.678 .847 .902 r
.53614 .16187 m
.53614 .18536 L
.53845 .18536 L
.53845 .16187 L
F
.2 .63 .79 r
.53614 .16187 m
.53614 .18536 L
.53845 .18536 L
.53845 .16187 L
s
.678 .847 .902 r
.53845 .16187 m
.53845 .1885 L
.54244 .1885 L
.54244 .16187 L
F
.2 .63 .79 r
.53845 .16187 m
.53845 .1885 L
.54244 .1885 L
.54244 .16187 L
s
.678 .847 .902 r
.54244 .16187 m
.54244 .1911 L
.54694 .1911 L
.54694 .16187 L
F
.2 .63 .79 r
.54244 .16187 m
.54244 .1911 L
.54694 .1911 L
.54694 .16187 L
s
.678 .847 .902 r
.54694 .16187 m
.54694 .19353 L
.54977 .19353 L
.54977 .16187 L
F
.2 .63 .79 r
.54694 .16187 m
.54694 .19353 L
.54977 .19353 L
.54977 .16187 L
s
.678 .847 .902 r
.54977 .16187 m
.54977 .19546 L
.55383 .19546 L
.55383 .16187 L
F
.2 .63 .79 r
.54977 .16187 m
.54977 .19546 L
.55383 .19546 L
.55383 .16187 L
s
.678 .847 .902 r
.55383 .16187 m
.55383 .19757 L
.55569 .19757 L
.55569 .16187 L
F
.2 .63 .79 r
.55383 .16187 m
.55383 .19757 L
.55569 .19757 L
.55569 .16187 L
s
.678 .847 .902 r
.55569 .16187 m
.55569 .19909 L
.55733 .19909 L
.55733 .16187 L
F
.2 .63 .79 r
.55569 .16187 m
.55569 .19909 L
.55733 .19909 L
.55733 .16187 L
s
.678 .847 .902 r
.55733 .16187 m
.55733 .2015 L
.56034 .2015 L
.56034 .16187 L
F
.2 .63 .79 r
.55733 .16187 m
.55733 .2015 L
.56034 .2015 L
.56034 .16187 L
s
.678 .847 .902 r
.56034 .16187 m
.56034 .20213 L
.5621 .20213 L
.5621 .16187 L
F
.2 .63 .79 r
.56034 .16187 m
.56034 .20213 L
.5621 .20213 L
.5621 .16187 L
s
.678 .847 .902 r
.5621 .16187 m
.5621 .20421 L
.5657 .20421 L
.5657 .16187 L
F
.2 .63 .79 r
.5621 .16187 m
.5621 .20421 L
.5657 .20421 L
.5657 .16187 L
s
.678 .847 .902 r
.5657 .16187 m
.5657 .20626 L
.56841 .20626 L
.56841 .16187 L
F
.2 .63 .79 r
.5657 .16187 m
.5657 .20626 L
.56841 .20626 L
.56841 .16187 L
s
.678 .847 .902 r
.56841 .16187 m
.56841 .20814 L
.57151 .20814 L
.57151 .16187 L
F
.2 .63 .79 r
.56841 .16187 m
.56841 .20814 L
.57151 .20814 L
.57151 .16187 L
s
.678 .847 .902 r
.57151 .16187 m
.57151 .21072 L
.57339 .21072 L
.57339 .16187 L
F
.2 .63 .79 r
.57151 .16187 m
.57151 .21072 L
.57339 .21072 L
.57339 .16187 L
s
.678 .847 .902 r
.57339 .16187 m
.57339 .21266 L
.57619 .21266 L
.57619 .16187 L
F
.2 .63 .79 r
.57339 .16187 m
.57339 .21266 L
.57619 .21266 L
.57619 .16187 L
s
.678 .847 .902 r
.57619 .16187 m
.57619 .21345 L
.57989 .21345 L
.57989 .16187 L
F
.2 .63 .79 r
.57619 .16187 m
.57619 .21345 L
.57989 .21345 L
.57989 .16187 L
s
.678 .847 .902 r
.57989 .16187 m
.57989 .21821 L
.58389 .21821 L
.58389 .16187 L
F
.2 .63 .79 r
.57989 .16187 m
.57989 .21821 L
.58389 .21821 L
.58389 .16187 L
s
.678 .847 .902 r
.58389 .16187 m
.58389 .21829 L
.58791 .21829 L
.58791 .16187 L
F
.2 .63 .79 r
.58389 .16187 m
.58389 .21829 L
.58791 .21829 L
.58791 .16187 L
s
.678 .847 .902 r
.58791 .16187 m
.58791 .22427 L
.59237 .22427 L
.59237 .16187 L
F
.2 .63 .79 r
.58791 .16187 m
.58791 .22427 L
.59237 .22427 L
.59237 .16187 L
s
.678 .847 .902 r
.59237 .16187 m
.59237 .22485 L
.59682 .22485 L
.59682 .16187 L
F
.2 .63 .79 r
.59237 .16187 m
.59237 .22485 L
.59682 .22485 L
.59682 .16187 L
s
.678 .847 .902 r
.59682 .16187 m
.59682 .22865 L
.60107 .22865 L
.60107 .16187 L
F
.2 .63 .79 r
.59682 .16187 m
.59682 .22865 L
.60107 .22865 L
.60107 .16187 L
s
.678 .847 .902 r
.60107 .16187 m
.60107 .233 L
.60459 .233 L
.60459 .16187 L
F
.2 .63 .79 r
.60107 .16187 m
.60107 .233 L
.60459 .233 L
.60459 .16187 L
s
.678 .847 .902 r
.60459 .16187 m
.60459 .23388 L
.606 .23388 L
.606 .16187 L
F
.2 .63 .79 r
.60459 .16187 m
.60459 .23388 L
.606 .23388 L
.606 .16187 L
s
.678 .847 .902 r
.606 .16187 m
.606 .23669 L
.60957 .23669 L
.60957 .16187 L
F
.2 .63 .79 r
.606 .16187 m
.606 .23669 L
.60957 .23669 L
.60957 .16187 L
s
.678 .847 .902 r
.60957 .16187 m
.60957 .23785 L
.61142 .23785 L
.61142 .16187 L
F
.2 .63 .79 r
.60957 .16187 m
.60957 .23785 L
.61142 .23785 L
.61142 .16187 L
s
.678 .847 .902 r
.61142 .16187 m
.61142 .23991 L
.614 .23991 L
.614 .16187 L
F
.2 .63 .79 r
.61142 .16187 m
.61142 .23991 L
.614 .23991 L
.614 .16187 L
s
.678 .847 .902 r
.614 .16187 m
.614 .2416 L
.61601 .2416 L
.61601 .16187 L
F
.2 .63 .79 r
.614 .16187 m
.614 .2416 L
.61601 .2416 L
.61601 .16187 L
s
.678 .847 .902 r
.61601 .16187 m
.61601 .2427 L
.61968 .2427 L
.61968 .16187 L
F
.2 .63 .79 r
.61601 .16187 m
.61601 .2427 L
.61968 .2427 L
.61968 .16187 L
s
.678 .847 .902 r
.61968 .16187 m
.61968 .24709 L
.62329 .24709 L
.62329 .16187 L
F
.2 .63 .79 r
.61968 .16187 m
.61968 .24709 L
.62329 .24709 L
.62329 .16187 L
s
.678 .847 .902 r
.62329 .16187 m
.62329 .24824 L
.6264 .24824 L
.6264 .16187 L
F
.2 .63 .79 r
.62329 .16187 m
.62329 .24824 L
.6264 .24824 L
.6264 .16187 L
s
.678 .847 .902 r
.6264 .16187 m
.6264 .25048 L
.62793 .25048 L
.62793 .16187 L
F
.2 .63 .79 r
.6264 .16187 m
.6264 .25048 L
.62793 .25048 L
.62793 .16187 L
s
.678 .847 .902 r
.62793 .16187 m
.62793 .25273 L
.63133 .25273 L
.63133 .16187 L
F
.2 .63 .79 r
.62793 .16187 m
.62793 .25273 L
.63133 .25273 L
.63133 .16187 L
s
.678 .847 .902 r
.63133 .16187 m
.63133 .25533 L
.6333 .25533 L
.6333 .16187 L
F
.2 .63 .79 r
.63133 .16187 m
.63133 .25533 L
.6333 .25533 L
.6333 .16187 L
s
.678 .847 .902 r
.6333 .16187 m
.6333 .25716 L
.63603 .25716 L
.63603 .16187 L
F
.2 .63 .79 r
.6333 .16187 m
.6333 .25716 L
.63603 .25716 L
.63603 .16187 L
s
.678 .847 .902 r
.63603 .16187 m
.63603 .25901 L
.63855 .25901 L
.63855 .16187 L
F
.2 .63 .79 r
.63603 .16187 m
.63603 .25901 L
.63855 .25901 L
.63855 .16187 L
s
.678 .847 .902 r
.63855 .16187 m
.63855 .26148 L
.64062 .26148 L
.64062 .16187 L
F
.2 .63 .79 r
.63855 .16187 m
.63855 .26148 L
.64062 .26148 L
.64062 .16187 L
s
.678 .847 .902 r
.64062 .16187 m
.64062 .26237 L
.64409 .26237 L
.64409 .16187 L
F
.2 .63 .79 r
.64062 .16187 m
.64062 .26237 L
.64409 .26237 L
.64409 .16187 L
s
.678 .847 .902 r
.64409 .16187 m
.64409 .26553 L
.6463 .26553 L
.6463 .16187 L
F
.2 .63 .79 r
.64409 .16187 m
.64409 .26553 L
.6463 .26553 L
.6463 .16187 L
s
.678 .847 .902 r
.6463 .16187 m
.6463 .26814 L
.65063 .26814 L
.65063 .16187 L
F
.2 .63 .79 r
.6463 .16187 m
.6463 .26814 L
.65063 .26814 L
.65063 .16187 L
s
.678 .847 .902 r
.65063 .16187 m
.65063 .27124 L
.65358 .27124 L
.65358 .16187 L
F
.2 .63 .79 r
.65063 .16187 m
.65063 .27124 L
.65358 .27124 L
.65358 .16187 L
s
.678 .847 .902 r
.65358 .16187 m
.65358 .27308 L
.65763 .27308 L
.65763 .16187 L
F
.2 .63 .79 r
.65358 .16187 m
.65358 .27308 L
.65763 .27308 L
.65763 .16187 L
s
.678 .847 .902 r
.65763 .16187 m
.65763 .27687 L
.66042 .27687 L
.66042 .16187 L
F
.2 .63 .79 r
.65763 .16187 m
.65763 .27687 L
.66042 .27687 L
.66042 .16187 L
s
.678 .847 .902 r
.66042 .16187 m
.66042 .28003 L
.66488 .28003 L
.66488 .16187 L
F
.2 .63 .79 r
.66042 .16187 m
.66042 .28003 L
.66488 .28003 L
.66488 .16187 L
s
.678 .847 .902 r
.66488 .16187 m
.66488 .2828 L
.66797 .2828 L
.66797 .16187 L
F
.2 .63 .79 r
.66488 .16187 m
.66488 .2828 L
.66797 .2828 L
.66797 .16187 L
s
.678 .847 .902 r
.66797 .16187 m
.66797 .28408 L
.67236 .28408 L
.67236 .16187 L
F
.2 .63 .79 r
.66797 .16187 m
.66797 .28408 L
.67236 .28408 L
.67236 .16187 L
s
.678 .847 .902 r
.67236 .16187 m
.67236 .29049 L
.67622 .29049 L
.67622 .16187 L
F
.2 .63 .79 r
.67236 .16187 m
.67236 .29049 L
.67622 .29049 L
.67622 .16187 L
s
.678 .847 .902 r
.67622 .16187 m
.67622 .29231 L
.68064 .29231 L
.68064 .16187 L
F
.2 .63 .79 r
.67622 .16187 m
.67622 .29231 L
.68064 .29231 L
.68064 .16187 L
s
.678 .847 .902 r
.68064 .16187 m
.68064 .29748 L
.68475 .29748 L
.68475 .16187 L
F
.2 .63 .79 r
.68064 .16187 m
.68064 .29748 L
.68475 .29748 L
.68475 .16187 L
s
.678 .847 .902 r
.68475 .16187 m
.68475 .30052 L
.68868 .30052 L
.68868 .16187 L
F
.2 .63 .79 r
.68475 .16187 m
.68475 .30052 L
.68868 .30052 L
.68868 .16187 L
s
.678 .847 .902 r
.68868 .16187 m
.68868 .30225 L
.69133 .30225 L
.69133 .16187 L
F
.2 .63 .79 r
.68868 .16187 m
.68868 .30225 L
.69133 .30225 L
.69133 .16187 L
s
.678 .847 .902 r
.69133 .16187 m
.69133 .30657 L
.69511 .30657 L
.69511 .16187 L
F
.2 .63 .79 r
.69133 .16187 m
.69133 .30657 L
.69511 .30657 L
.69511 .16187 L
s
.678 .847 .902 r
.69511 .16187 m
.69511 .3082 L
.69693 .3082 L
.69693 .16187 L
F
.2 .63 .79 r
.69511 .16187 m
.69511 .3082 L
.69693 .3082 L
.69693 .16187 L
s
.678 .847 .902 r
.69693 .16187 m
.69693 .31021 L
.69864 .31021 L
.69864 .16187 L
F
.2 .63 .79 r
.69693 .16187 m
.69693 .31021 L
.69864 .31021 L
.69864 .16187 L
s
.678 .847 .902 r
.69864 .16187 m
.69864 .31083 L
.70277 .31083 L
.70277 .16187 L
F
.2 .63 .79 r
.69864 .16187 m
.69864 .31083 L
.70277 .31083 L
.70277 .16187 L
s
.678 .847 .902 r
.70277 .16187 m
.70277 .31614 L
.70639 .31614 L
.70639 .16187 L
F
.2 .63 .79 r
.70277 .16187 m
.70277 .31614 L
.70639 .31614 L
.70639 .16187 L
s
.678 .847 .902 r
.70639 .16187 m
.70639 .31764 L
.7094 .31764 L
.7094 .16187 L
F
.2 .63 .79 r
.70639 .16187 m
.70639 .31764 L
.7094 .31764 L
.7094 .16187 L
s
.678 .847 .902 r
.7094 .16187 m
.7094 .32079 L
.71372 .32079 L
.71372 .16187 L
F
.2 .63 .79 r
.7094 .16187 m
.7094 .32079 L
.71372 .32079 L
.71372 .16187 L
s
.678 .847 .902 r
.71372 .16187 m
.71372 .32491 L
.7165 .32491 L
.7165 .16187 L
F
.2 .63 .79 r
.71372 .16187 m
.71372 .32491 L
.7165 .32491 L
.7165 .16187 L
s
.678 .847 .902 r
.7165 .16187 m
.7165 .32649 L
.71898 .32649 L
.71898 .16187 L
F
.2 .63 .79 r
.7165 .16187 m
.7165 .32649 L
.71898 .32649 L
.71898 .16187 L
s
.678 .847 .902 r
.71898 .16187 m
.71898 .32893 L
.7213 .32893 L
.7213 .16187 L
F
.2 .63 .79 r
.71898 .16187 m
.71898 .32893 L
.7213 .32893 L
.7213 .16187 L
s
.678 .847 .902 r
.7213 .16187 m
.7213 .33042 L
.72353 .33042 L
.72353 .16187 L
F
.2 .63 .79 r
.7213 .16187 m
.7213 .33042 L
.72353 .33042 L
.72353 .16187 L
s
.678 .847 .902 r
.72353 .16187 m
.72353 .33401 L
.72548 .33401 L
.72548 .16187 L
F
.2 .63 .79 r
.72353 .16187 m
.72353 .33401 L
.72548 .33401 L
.72548 .16187 L
s
.678 .847 .902 r
.72548 .16187 m
.72548 .33575 L
.72822 .33575 L
.72822 .16187 L
F
.2 .63 .79 r
.72548 .16187 m
.72548 .33575 L
.72822 .33575 L
.72822 .16187 L
s
.678 .847 .902 r
.72822 .16187 m
.72822 .33904 L
.73218 .33904 L
.73218 .16187 L
F
.2 .63 .79 r
.72822 .16187 m
.72822 .33904 L
.73218 .33904 L
.73218 .16187 L
s
.678 .847 .902 r
.73218 .16187 m
.73218 .34213 L
.73494 .34213 L
.73494 .16187 L
F
.2 .63 .79 r
.73218 .16187 m
.73218 .34213 L
.73494 .34213 L
.73494 .16187 L
s
.678 .847 .902 r
.73494 .16187 m
.73494 .34377 L
.73869 .34377 L
.73869 .16187 L
F
.2 .63 .79 r
.73494 .16187 m
.73494 .34377 L
.73869 .34377 L
.73869 .16187 L
s
.678 .847 .902 r
.73869 .16187 m
.73869 .349 L
.74157 .349 L
.74157 .16187 L
F
.2 .63 .79 r
.73869 .16187 m
.73869 .349 L
.74157 .349 L
.74157 .16187 L
s
.678 .847 .902 r
.74157 .16187 m
.74157 .34925 L
.74381 .34925 L
.74381 .16187 L
F
.2 .63 .79 r
.74157 .16187 m
.74157 .34925 L
.74381 .34925 L
.74381 .16187 L
s
.678 .847 .902 r
.74381 .16187 m
.74381 .353 L
.74677 .353 L
.74677 .16187 L
F
.2 .63 .79 r
.74381 .16187 m
.74381 .353 L
.74677 .353 L
.74677 .16187 L
s
.678 .847 .902 r
.74677 .16187 m
.74677 .35554 L
.75125 .35554 L
.75125 .16187 L
F
.2 .63 .79 r
.74677 .16187 m
.74677 .35554 L
.75125 .35554 L
.75125 .16187 L
s
.678 .847 .902 r
.75125 .16187 m
.75125 .35989 L
.7543 .35989 L
.7543 .16187 L
F
.2 .63 .79 r
.75125 .16187 m
.75125 .35989 L
.7543 .35989 L
.7543 .16187 L
s
.678 .847 .902 r
.7543 .16187 m
.7543 .36179 L
.75703 .36179 L
.75703 .16187 L
F
.2 .63 .79 r
.7543 .16187 m
.7543 .36179 L
.75703 .36179 L
.75703 .16187 L
s
.678 .847 .902 r
.75703 .16187 m
.75703 .367 L
.76064 .367 L
.76064 .16187 L
F
.2 .63 .79 r
.75703 .16187 m
.75703 .367 L
.76064 .367 L
.76064 .16187 L
s
.678 .847 .902 r
.76064 .16187 m
.76064 .36733 L
.76384 .36733 L
.76384 .16187 L
F
.2 .63 .79 r
.76064 .16187 m
.76064 .36733 L
.76384 .36733 L
.76384 .16187 L
s
.678 .847 .902 r
.76384 .16187 m
.76384 .37307 L
.76771 .37307 L
.76771 .16187 L
F
.2 .63 .79 r
.76384 .16187 m
.76384 .37307 L
.76771 .37307 L
.76771 .16187 L
s
.678 .847 .902 r
.76771 .16187 m
.76771 .37526 L
.76999 .37526 L
.76999 .16187 L
F
.2 .63 .79 r
.76771 .16187 m
.76771 .37526 L
.76999 .37526 L
.76999 .16187 L
s
.678 .847 .902 r
.76999 .16187 m
.76999 .37605 L
.77328 .37605 L
.77328 .16187 L
F
.2 .63 .79 r
.76999 .16187 m
.76999 .37605 L
.77328 .37605 L
.77328 .16187 L
s
.678 .847 .902 r
.77328 .16187 m
.77328 .38256 L
.77694 .38256 L
.77694 .16187 L
F
.2 .63 .79 r
.77328 .16187 m
.77328 .38256 L
.77694 .38256 L
.77694 .16187 L
s
.678 .847 .902 r
.77694 .16187 m
.77694 .38293 L
.77856 .38293 L
.77856 .16187 L
F
.2 .63 .79 r
.77694 .16187 m
.77694 .38293 L
.77856 .38293 L
.77856 .16187 L
s
.678 .847 .902 r
.77856 .16187 m
.77856 .38603 L
.78242 .38603 L
.78242 .16187 L
F
.2 .63 .79 r
.77856 .16187 m
.77856 .38603 L
.78242 .38603 L
.78242 .16187 L
s
.678 .847 .902 r
.78242 .16187 m
.78242 .39074 L
.78598 .39074 L
.78598 .16187 L
F
.2 .63 .79 r
.78242 .16187 m
.78242 .39074 L
.78598 .39074 L
.78598 .16187 L
s
.678 .847 .902 r
.78598 .16187 m
.78598 .39259 L
.78824 .39259 L
.78824 .16187 L
F
.2 .63 .79 r
.78598 .16187 m
.78598 .39259 L
.78824 .39259 L
.78824 .16187 L
s
.678 .847 .902 r
.78824 .16187 m
.78824 .39729 L
.79197 .39729 L
.79197 .16187 L
F
.2 .63 .79 r
.78824 .16187 m
.78824 .39729 L
.79197 .39729 L
.79197 .16187 L
s
.678 .847 .902 r
.79197 .16187 m
.79197 .39805 L
.79489 .39805 L
.79489 .16187 L
F
.2 .63 .79 r
.79197 .16187 m
.79197 .39805 L
.79489 .39805 L
.79489 .16187 L
s
.678 .847 .902 r
.79489 .16187 m
.79489 .40253 L
.79759 .40253 L
.79759 .16187 L
F
.2 .63 .79 r
.79489 .16187 m
.79489 .40253 L
.79759 .40253 L
.79759 .16187 L
s
.678 .847 .902 r
.79759 .16187 m
.79759 .40413 L
.79928 .40413 L
.79928 .16187 L
F
.2 .63 .79 r
.79759 .16187 m
.79759 .40413 L
.79928 .40413 L
.79928 .16187 L
s
.678 .847 .902 r
.79928 .16187 m
.79928 .40565 L
.80164 .40565 L
.80164 .16187 L
F
.2 .63 .79 r
.79928 .16187 m
.79928 .40565 L
.80164 .40565 L
.80164 .16187 L
s
.678 .847 .902 r
.80164 .16187 m
.80164 .40915 L
.80519 .40915 L
.80519 .16187 L
F
.2 .63 .79 r
.80164 .16187 m
.80164 .40915 L
.80519 .40915 L
.80519 .16187 L
s
.678 .847 .902 r
.80519 .16187 m
.80519 .41106 L
.80973 .41106 L
.80973 .16187 L
F
.2 .63 .79 r
.80519 .16187 m
.80519 .41106 L
.80973 .41106 L
.80973 .16187 L
s
.678 .847 .902 r
.80973 .16187 m
.80973 .41622 L
.81226 .41622 L
.81226 .16187 L
F
.2 .63 .79 r
.80973 .16187 m
.80973 .41622 L
.81226 .41622 L
.81226 .16187 L
s
.678 .847 .902 r
.81226 .16187 m
.81226 .4194 L
.81633 .4194 L
.81633 .16187 L
F
.2 .63 .79 r
.81226 .16187 m
.81226 .4194 L
.81633 .4194 L
.81633 .16187 L
s
.678 .847 .902 r
.81633 .16187 m
.81633 .42342 L
.81901 .42342 L
.81901 .16187 L
F
.2 .63 .79 r
.81633 .16187 m
.81633 .42342 L
.81901 .42342 L
.81901 .16187 L
s
.678 .847 .902 r
.81901 .16187 m
.81901 .42614 L
.82197 .42614 L
.82197 .16187 L
F
.2 .63 .79 r
.81901 .16187 m
.81901 .42614 L
.82197 .42614 L
.82197 .16187 L
s
.678 .847 .902 r
.82197 .16187 m
.82197 .43052 L
.82461 .43052 L
.82461 .16187 L
F
.2 .63 .79 r
.82197 .16187 m
.82197 .43052 L
.82461 .43052 L
.82461 .16187 L
s
.678 .847 .902 r
.82461 .16187 m
.82461 .43258 L
.827 .43258 L
.827 .16187 L
F
.2 .63 .79 r
.82461 .16187 m
.82461 .43258 L
.827 .43258 L
.827 .16187 L
s
.678 .847 .902 r
.827 .16187 m
.827 .43382 L
.83156 .43382 L
.83156 .16187 L
F
.2 .63 .79 r
.827 .16187 m
.827 .43382 L
.83156 .43382 L
.83156 .16187 L
s
.678 .847 .902 r
.83156 .16187 m
.83156 .43961 L
.83549 .43961 L
.83549 .16187 L
F
.2 .63 .79 r
.83156 .16187 m
.83156 .43961 L
.83549 .43961 L
.83549 .16187 L
s
.678 .847 .902 r
.83549 .16187 m
.83549 .44554 L
.83952 .44554 L
.83952 .16187 L
F
.2 .63 .79 r
.83549 .16187 m
.83549 .44554 L
.83952 .44554 L
.83952 .16187 L
s
.678 .847 .902 r
.83952 .16187 m
.83952 .44945 L
.84263 .44945 L
.84263 .16187 L
F
.2 .63 .79 r
.83952 .16187 m
.83952 .44945 L
.84263 .44945 L
.84263 .16187 L
s
.678 .847 .902 r
.84263 .16187 m
.84263 .45154 L
.84628 .45154 L
.84628 .16187 L
F
.2 .63 .79 r
.84263 .16187 m
.84263 .45154 L
.84628 .45154 L
.84628 .16187 L
s
.678 .847 .902 r
.84628 .16187 m
.84628 .45446 L
.8483 .45446 L
.8483 .16187 L
F
.2 .63 .79 r
.84628 .16187 m
.84628 .45446 L
.8483 .45446 L
.8483 .16187 L
s
.678 .847 .902 r
.8483 .16187 m
.8483 .45743 L
.85005 .45743 L
.85005 .16187 L
F
.2 .63 .79 r
.8483 .16187 m
.8483 .45743 L
.85005 .45743 L
.85005 .16187 L
s
.678 .847 .902 r
.85005 .16187 m
.85005 .46021 L
.85291 .46021 L
.85291 .16187 L
F
.2 .63 .79 r
.85005 .16187 m
.85005 .46021 L
.85291 .46021 L
.85291 .16187 L
s
.678 .847 .902 r
.85291 .16187 m
.85291 .46086 L
.8573 .46086 L
.8573 .16187 L
F
.2 .63 .79 r
.85291 .16187 m
.85291 .46086 L
.8573 .46086 L
.8573 .16187 L
s
.678 .847 .902 r
.8573 .16187 m
.8573 .4676 L
.86035 .4676 L
.86035 .16187 L
F
.2 .63 .79 r
.8573 .16187 m
.8573 .4676 L
.86035 .4676 L
.86035 .16187 L
s
.678 .847 .902 r
.86035 .16187 m
.86035 .47077 L
.86443 .47077 L
.86443 .16187 L
F
.2 .63 .79 r
.86035 .16187 m
.86035 .47077 L
.86443 .47077 L
.86443 .16187 L
s
.678 .847 .902 r
.86443 .16187 m
.86443 .47694 L
.86816 .47694 L
.86816 .16187 L
F
.2 .63 .79 r
.86443 .16187 m
.86443 .47694 L
.86816 .47694 L
.86816 .16187 L
s
.678 .847 .902 r
.86816 .16187 m
.86816 .48005 L
.87099 .48005 L
.87099 .16187 L
F
.2 .63 .79 r
.86816 .16187 m
.86816 .48005 L
.87099 .48005 L
.87099 .16187 L
s
.678 .847 .902 r
.87099 .16187 m
.87099 .48217 L
.87272 .48217 L
.87272 .16187 L
F
.2 .63 .79 r
.87099 .16187 m
.87099 .48217 L
.87272 .48217 L
.87272 .16187 L
s
.678 .847 .902 r
.87272 .16187 m
.87272 .4862 L
.87649 .4862 L
.87649 .16187 L
F
.2 .63 .79 r
.87272 .16187 m
.87272 .4862 L
.87649 .4862 L
.87649 .16187 L
s
.678 .847 .902 r
.87649 .16187 m
.87649 .48837 L
.87923 .48837 L
.87923 .16187 L
F
.2 .63 .79 r
.87649 .16187 m
.87649 .48837 L
.87923 .48837 L
.87923 .16187 L
s
.678 .847 .902 r
.87923 .16187 m
.87923 .49113 L
.88311 .49113 L
.88311 .16187 L
F
.2 .63 .79 r
.87923 .16187 m
.87923 .49113 L
.88311 .49113 L
.88311 .16187 L
s
.678 .847 .902 r
.88311 .16187 m
.88311 .49561 L
.88488 .49561 L
.88488 .16187 L
F
.2 .63 .79 r
.88311 .16187 m
.88311 .49561 L
.88488 .49561 L
.88488 .16187 L
s
.678 .847 .902 r
.88488 .16187 m
.88488 .4978 L
.8875 .4978 L
.8875 .16187 L
F
.2 .63 .79 r
.88488 .16187 m
.88488 .4978 L
.8875 .4978 L
.8875 .16187 L
s
.678 .847 .902 r
.8875 .16187 m
.8875 .49989 L
.89077 .49989 L
.89077 .16187 L
F
.2 .63 .79 r
.8875 .16187 m
.8875 .49989 L
.89077 .49989 L
.89077 .16187 L
s
.678 .847 .902 r
.89077 .16187 m
.89077 .50524 L
.89333 .50524 L
.89333 .16187 L
F
.2 .63 .79 r
.89077 .16187 m
.89077 .50524 L
.89333 .50524 L
.89333 .16187 L
s
.678 .847 .902 r
.89333 .16187 m
.89333 .50735 L
.89674 .50735 L
.89674 .16187 L
F
.2 .63 .79 r
.89333 .16187 m
.89333 .50735 L
.89674 .50735 L
.89674 .16187 L
s
.678 .847 .902 r
.89674 .16187 m
.89674 .51329 L
.90131 .51329 L
.90131 .16187 L
F
.2 .63 .79 r
.89674 .16187 m
.89674 .51329 L
.90131 .51329 L
.90131 .16187 L
s
.678 .847 .902 r
.90131 .16187 m
.90131 .51597 L
.90356 .51597 L
.90356 .16187 L
F
.2 .63 .79 r
.90131 .16187 m
.90131 .51597 L
.90356 .51597 L
.90356 .16187 L
s
.678 .847 .902 r
.90356 .16187 m
.90356 .51953 L
.90616 .51953 L
.90616 .16187 L
F
.2 .63 .79 r
.90356 .16187 m
.90356 .51953 L
.90616 .51953 L
.90616 .16187 L
s
.678 .847 .902 r
.90616 .16187 m
.90616 .52067 L
.91023 .52067 L
.91023 .16187 L
F
.2 .63 .79 r
.90616 .16187 m
.90616 .52067 L
.91023 .52067 L
.91023 .16187 L
s
.678 .847 .902 r
.91023 .16187 m
.91023 .52464 L
.91214 .52464 L
.91214 .16187 L
F
.2 .63 .79 r
.91023 .16187 m
.91023 .52464 L
.91214 .52464 L
.91214 .16187 L
s
.678 .847 .902 r
.91214 .16187 m
.91214 .52991 L
.91588 .52991 L
.91588 .16187 L
F
.2 .63 .79 r
.91214 .16187 m
.91214 .52991 L
.91588 .52991 L
.91588 .16187 L
s
.678 .847 .902 r
.91588 .16187 m
.91588 .53283 L
.91942 .53283 L
.91942 .16187 L
F
.2 .63 .79 r
.91588 .16187 m
.91588 .53283 L
.91942 .53283 L
.91942 .16187 L
s
.678 .847 .902 r
.91942 .16187 m
.91942 .53842 L
.92284 .53842 L
.92284 .16187 L
F
.2 .63 .79 r
.91942 .16187 m
.91942 .53842 L
.92284 .53842 L
.92284 .16187 L
s
.678 .847 .902 r
.92284 .16187 m
.92284 .53953 L
.92439 .53953 L
.92439 .16187 L
F
.2 .63 .79 r
.92284 .16187 m
.92284 .53953 L
.92439 .53953 L
.92439 .16187 L
s
.678 .847 .902 r
.92439 .16187 m
.92439 .54342 L
.92663 .54342 L
.92663 .16187 L
F
.2 .63 .79 r
.92439 .16187 m
.92439 .54342 L
.92663 .54342 L
.92663 .16187 L
s
.678 .847 .902 r
.92663 .16187 m
.92663 .54542 L
.93038 .54542 L
.93038 .16187 L
F
.2 .63 .79 r
.92663 .16187 m
.92663 .54542 L
.93038 .54542 L
.93038 .16187 L
s
.678 .847 .902 r
.93038 .16187 m
.93038 .54841 L
.93212 .54841 L
.93212 .16187 L
F
.2 .63 .79 r
.93038 .16187 m
.93038 .54841 L
.93212 .54841 L
.93212 .16187 L
s
.678 .847 .902 r
.93212 .16187 m
.93212 .55189 L
.93418 .55189 L
.93418 .16187 L
F
.2 .63 .79 r
.93212 .16187 m
.93212 .55189 L
.93418 .55189 L
.93418 .16187 L
s
.678 .847 .902 r
.93418 .16187 m
.93418 .55259 L
.93729 .55259 L
.93729 .16187 L
F
.2 .63 .79 r
.93418 .16187 m
.93418 .55259 L
.93729 .55259 L
.93729 .16187 L
s
.678 .847 .902 r
.93729 .16187 m
.93729 .55767 L
.93957 .55767 L
.93957 .16187 L
F
.2 .63 .79 r
.93729 .16187 m
.93729 .55767 L
.93957 .55767 L
.93957 .16187 L
s
.678 .847 .902 r
.93957 .16187 m
.93957 .55939 L
.94097 .55939 L
.94097 .16187 L
F
.2 .63 .79 r
.93957 .16187 m
.93957 .55939 L
.94097 .55939 L
.94097 .16187 L
s
.678 .847 .902 r
.94097 .16187 m
.94097 .56339 L
.94385 .56339 L
.94385 .16187 L
F
.2 .63 .79 r
.94097 .16187 m
.94097 .56339 L
.94385 .56339 L
.94385 .16187 L
s
.678 .847 .902 r
.94385 .16187 m
.94385 .56487 L
.94559 .56487 L
.94559 .16187 L
F
.2 .63 .79 r
.94385 .16187 m
.94385 .56487 L
.94559 .56487 L
.94559 .16187 L
s
.678 .847 .902 r
.94559 .16187 m
.94559 .56673 L
.94859 .56673 L
.94859 .16187 L
F
.2 .63 .79 r
.94559 .16187 m
.94559 .56673 L
.94859 .56673 L
.94859 .16187 L
s
.678 .847 .902 r
.94859 .16187 m
.94859 .57177 L
.9528 .57177 L
.9528 .16187 L
F
.2 .63 .79 r
.94859 .16187 m
.94859 .57177 L
.9528 .57177 L
.9528 .16187 L
s
.678 .847 .902 r
.9528 .16187 m
.9528 .57507 L
.95444 .57507 L
.95444 .16187 L
F
.2 .63 .79 r
.9528 .16187 m
.9528 .57507 L
.95444 .57507 L
.95444 .16187 L
s
.678 .847 .902 r
.95444 .16187 m
.95444 .57715 L
.95751 .57715 L
.95751 .16187 L
F
.2 .63 .79 r
.95444 .16187 m
.95444 .57715 L
.95751 .57715 L
.95751 .16187 L
s
.678 .847 .902 r
.95751 .16187 m
.95751 .58092 L
.95932 .58092 L
.95932 .16187 L
F
.2 .63 .79 r
.95751 .16187 m
.95751 .58092 L
.95932 .58092 L
.95932 .16187 L
s
.678 .847 .902 r
.95932 .16187 m
.95932 .58501 L
.9615 .58501 L
.9615 .16187 L
F
.2 .63 .79 r
.95932 .16187 m
.95932 .58501 L
.9615 .58501 L
.9615 .16187 L
s
.678 .847 .902 r
.9615 .16187 m
.9615 .58604 L
.96316 .58604 L
.96316 .16187 L
F
.2 .63 .79 r
.9615 .16187 m
.9615 .58604 L
.96316 .58604 L
.96316 .16187 L
s
.678 .847 .902 r
.96316 .16187 m
.96316 .58866 L
.96535 .58866 L
.96535 .16187 L
F
.2 .63 .79 r
.96316 .16187 m
.96316 .58866 L
.96535 .58866 L
.96535 .16187 L
s
.678 .847 .902 r
.96535 .16187 m
.96535 .59163 L
.96915 .59163 L
.96915 .16187 L
F
.2 .63 .79 r
.96535 .16187 m
.96535 .59163 L
.96915 .59163 L
.96915 .16187 L
s
.678 .847 .902 r
.96915 .16187 m
.96915 .59709 L
.97185 .59709 L
.97185 .16187 L
F
.2 .63 .79 r
.96915 .16187 m
.96915 .59709 L
.97185 .59709 L
.97185 .16187 L
s
.678 .847 .902 r
.97185 .16187 m
.97185 .59986 L
.97619 .59986 L
.97619 .16187 L
F
.2 .63 .79 r
.97185 .16187 m
.97185 .59986 L
.97619 .59986 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02518 .01472 Mdot
.02683 .01472 Mdot
.03212 .01476 Mdot
.03543 .0148 Mdot
.03653 .01482 Mdot
.03978 .01488 Mdot
.04496 .01501 Mdot
.04877 .01512 Mdot
.0517 .01522 Mdot
.05266 .01526 Mdot
.05832 .01549 Mdot
.05953 .01554 Mdot
.0633 .01573 Mdot
.06686 .01592 Mdot
.07085 .01615 Mdot
.0719 .01622 Mdot
.07527 .01643 Mdot
.07904 .01669 Mdot
.08211 .01692 Mdot
.08298 .01699 Mdot
.08816 .0174 Mdot
.08968 .01753 Mdot
.09045 .0176 Mdot
.09309 .01783 Mdot
.0967 .01816 Mdot
.09872 .01836 Mdot
.10019 .0185 Mdot
.10221 .0187 Mdot
.10347 .01883 Mdot
.10746 .01926 Mdot
.11126 .01968 Mdot
.11357 .01994 Mdot
.11548 .02017 Mdot
.11764 .02043 Mdot
.11967 .02068 Mdot
.12355 .02117 Mdot
.12946 .02196 Mdot
.13228 .02235 Mdot
.13436 .02265 Mdot
.13797 .02317 Mdot
.14182 .02375 Mdot
.14357 .02402 Mdot
.14918 .02491 Mdot
.15117 .02524 Mdot
.15564 .02599 Mdot
.15774 .02635 Mdot
.16095 .02692 Mdot
.16217 .02714 Mdot
.16464 .02758 Mdot
.16844 .02829 Mdot
.16999 .02858 Mdot
.17501 .02955 Mdot
.17633 .02981 Mdot
.1792 .03038 Mdot
.18175 .0309 Mdot
.18432 .03143 Mdot
.18774 .03215 Mdot
.19378 .03346 Mdot
.19724 .03423 Mdot
.20223 .03537 Mdot
.20298 .03555 Mdot
.2067 .03642 Mdot
.20797 .03672 Mdot
.21205 .03771 Mdot
.2152 .03849 Mdot
.21886 .0394 Mdot
.22232 .04029 Mdot
.22543 .04109 Mdot
.22989 .04227 Mdot
.23056 .04245 Mdot
.23466 .04356 Mdot
.23564 .04384 Mdot
.23876 .0447 Mdot
.2413 .04541 Mdot
.24551 .04661 Mdot
.24728 .04712 Mdot
.25032 .04801 Mdot
.25173 .04842 Mdot
.25301 .0488 Mdot
.25707 .05002 Mdot
.26127 .05131 Mdot
.26193 .05151 Mdot
.26566 .05267 Mdot
.26777 .05334 Mdot
.2713 .05446 Mdot
.27302 .05502 Mdot
.27647 .05614 Mdot
.28005 .05732 Mdot
.28484 .05893 Mdot
.28807 .06003 Mdot
.29207 .06141 Mdot
.29552 .06263 Mdot
.29718 .06321 Mdot
.29871 .06376 Mdot
.30246 .0651 Mdot
.30554 .06622 Mdot
.30829 .06723 Mdot
.31276 .0689 Mdot
.31597 .07011 Mdot
.3173 .07061 Mdot
.3209 .07199 Mdot
.32471 .07347 Mdot
.33018 .07562 Mdot
.33212 .0764 Mdot
.33779 .07869 Mdot
.33994 .07957 Mdot
.34244 .0806 Mdot
.34434 .08139 Mdot
.34752 .08272 Mdot
.3503 .08389 Mdot
.35397 .08545 Mdot
.35948 .08783 Mdot
.35998 .08805 Mdot
.36535 .09041 Mdot
.36734 .0913 Mdot
.36956 .09229 Mdot
.37071 .09281 Mdot
.37468 .0946 Mdot
.37586 .09514 Mdot
.3783 .09626 Mdot
.38364 .09874 Mdot
.38544 .09958 Mdot
.38716 .10039 Mdot
.38883 .10118 Mdot
.39273 .10303 Mdot
.39566 .10445 Mdot
.3996 .10636 Mdot
.40283 .10794 Mdot
.40485 .10894 Mdot
.40877 .11088 Mdot
.41033 .11167 Mdot
.41302 .11302 Mdot
.41403 .11353 Mdot
.41983 .11649 Mdot
.42242 .11782 Mdot
.42821 .12084 Mdot
.42866 .12108 Mdot
.43234 .12302 Mdot
.43623 .12509 Mdot
.43821 .12616 Mdot
.44522 .12996 Mdot
.44767 .1313 Mdot
.44926 .13218 Mdot
.4536 .13459 Mdot
.45568 .13575 Mdot
.45625 .13607 Mdot
.46201 .13932 Mdot
.46387 .14038 Mdot
.46513 .1411 Mdot
.46892 .14328 Mdot
.47057 .14424 Mdot
.47694 .14796 Mdot
.4802 .14988 Mdot
.48524 .15289 Mdot
.48788 .15447 Mdot
.48893 .1551 Mdot
.49429 .15836 Mdot
.49851 .16095 Mdot
.5021 .16316 Mdot
.50382 .16424 Mdot
.50826 .16701 Mdot
.51268 .16981 Mdot
.51281 .16989 Mdot
.51626 .17209 Mdot
.52252 .17611 Mdot
.52424 .17723 Mdot
.52865 .18011 Mdot
.53092 .1816 Mdot
.53589 .18488 Mdot
.5366 .18536 Mdot
.5413 .1885 Mdot
.54516 .1911 Mdot
.54874 .19353 Mdot
.55156 .19546 Mdot
.55464 .19757 Mdot
.55684 .19909 Mdot
.56031 .2015 Mdot
.56121 .20213 Mdot
.56418 .20421 Mdot
.5671 .20626 Mdot
.56977 .20814 Mdot
.57339 .21072 Mdot
.57611 .21266 Mdot
.57721 .21345 Mdot
.58379 .21821 Mdot
.5839 .21829 Mdot
.59207 .22427 Mdot
.59285 .22485 Mdot
.59798 .22865 Mdot
.60378 .233 Mdot
.60496 .23388 Mdot
.60866 .23669 Mdot
.6102 .23785 Mdot
.61289 .23991 Mdot
.6151 .2416 Mdot
.61653 .2427 Mdot
.62221 .24709 Mdot
.62369 .24824 Mdot
.62657 .25048 Mdot
.62943 .25273 Mdot
.63273 .25533 Mdot
.63504 .25716 Mdot
.63737 .25901 Mdot
.64046 .26148 Mdot
.64157 .26237 Mdot
.6455 .26553 Mdot
.64873 .26814 Mdot
.65254 .27124 Mdot
.65479 .27308 Mdot
.65941 .27687 Mdot
.66322 .28003 Mdot
.66655 .2828 Mdot
.66808 .28408 Mdot
.6757 .29049 Mdot
.67785 .29231 Mdot
.68391 .29748 Mdot
.68745 .30052 Mdot
.68946 .30225 Mdot
.69444 .30657 Mdot
.6963 .3082 Mdot
.69861 .31021 Mdot
.69931 .31083 Mdot
.70534 .31614 Mdot
.70704 .31764 Mdot
.71058 .32079 Mdot
.71519 .32491 Mdot
.71694 .32649 Mdot
.71966 .32893 Mdot
.7213 .33042 Mdot
.72526 .33401 Mdot
.72717 .33575 Mdot
.73076 .33904 Mdot
.73412 .34213 Mdot
.73589 .34377 Mdot
.74153 .349 Mdot
.7418 .34925 Mdot
.74581 .353 Mdot
.74852 .35554 Mdot
.75314 .35989 Mdot
.75514 .36179 Mdot
.7606 .367 Mdot
.76095 .36733 Mdot
.76692 .37307 Mdot
.76919 .37526 Mdot
.77001 .37605 Mdot
.7767 .38256 Mdot
.77708 .38293 Mdot
.78024 .38603 Mdot
.78502 .39074 Mdot
.78689 .39259 Mdot
.79163 .39729 Mdot
.79239 .39805 Mdot
.79686 .40253 Mdot
.79846 .40413 Mdot
.79997 .40565 Mdot
.80343 .40915 Mdot
.80532 .41106 Mdot
.81039 .41622 Mdot
.8135 .4194 Mdot
.81741 .42342 Mdot
.82005 .42614 Mdot
.82427 .43052 Mdot
.82626 .43258 Mdot
.82745 .43382 Mdot
.83298 .43961 Mdot
.83861 .44554 Mdot
.84229 .44945 Mdot
.84426 .45154 Mdot
.847 .45446 Mdot
.84977 .45743 Mdot
.85236 .46021 Mdot
.85297 .46086 Mdot
.85921 .4676 Mdot
.86213 .47077 Mdot
.86777 .47694 Mdot
.87061 .48005 Mdot
.87254 .48217 Mdot
.87619 .4862 Mdot
.87815 .48837 Mdot
.88063 .49113 Mdot
.88465 .49561 Mdot
.88661 .4978 Mdot
.88848 .49989 Mdot
.89323 .50524 Mdot
.89509 .50735 Mdot
.90034 .51329 Mdot
.90268 .51597 Mdot
.9058 .51953 Mdot
.9068 .52067 Mdot
.91026 .52464 Mdot
.91483 .52991 Mdot
.91734 .53283 Mdot
.92215 .53842 Mdot
.9231 .53953 Mdot
.92643 .54342 Mdot
.92814 .54542 Mdot
.93068 .54841 Mdot
.93364 .55189 Mdot
.93422 .55259 Mdot
.93851 .55767 Mdot
.93996 .55939 Mdot
.94332 .56339 Mdot
.94456 .56487 Mdot
.94611 .56673 Mdot
.95032 .57177 Mdot
.95306 .57507 Mdot
.95478 .57715 Mdot
.95789 .58092 Mdot
.96126 .58501 Mdot
.96211 .58604 Mdot
.96425 .58866 Mdot
.96669 .59163 Mdot
.97114 .59709 Mdot
.97339 .59986 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(314) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00963758) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666668) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<0
0000103jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V
000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H010000002
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
000H0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000o`3j
l>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003j
l>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V00000000
00002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP800000
0P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP00
0000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V10000003
0?[`iP@000000`3jl>H4000000<0n_3V100000040?[`iP<00000o`3jl>JM0?[`iP40oooo000P0?[`
iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP0000000000
00D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3j
l>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H20000
00D0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000000`3jl>H000000000003o0?[`
iY`0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3j
l>H09@3jl>H2000000030?[`iP000000000000X0n_3V0P0000050?[`iP8000001@3jl>H2000000D0
n_3V0P0000050?[`iP800000103jl>H2000000030?[`iP00000000000?l0n_3VW03jl>H10?ooo`00
7`3jl>H6000000@0n_3V0P00000_0?[`iPD00000:03jl>H3000000`0n_3V0`0000040?[`iP<00000
103jl>H3000000@0n_3V0`0000040?[`iP<000000`3jl>H300000?l0n_3VW@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@0
0000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803j
l>H6000000050?[`iP00000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V
0P000000103jl>H000000000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0
n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0
n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000
0P3jl>H010000000n_3V0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`
iP800000103jl>H200000080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3j
l>H00000000000030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP80
0000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080
n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H200000003
0?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V
0P0000000`3jl>H00000000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V
0P0000020?[`iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`
iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P00
00000`3jl>H00000000000020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000
003jl>H300000080n_3V0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V
0P0000000`3jl>H00000000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@00000
0`3jl>H4000000H0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3j
l>H5000000<0n_3V100000030?[`iP80000000<0n_3V000000000000100000000`3jl>H000000000
00020?[`iP@00000103jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3j
l>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3o
ool00280n_3V0P00000;0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:
0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<00000
0?[`iP3jl>H00P00003o0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H40000
0340n_3V0`00000<0?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H30000
0080n_3V1@00003o0?[`iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V
00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP00
0000n_3V0P0000020?[`iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200
n_3V0`0000000`3jl>H0000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`
iP030000003jl>H0000001P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`
iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000
000000P0n_3V100000000`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP000000
00000000003jl>H000000?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000@0n_3V
0`0000030?[`iP<000001@3jl>H3000000@0n_3V0`0000050?[`iP800000103jl>H3000000@0n_3V
0`00001[0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@000000103jl>H000000000
000000020?[`iP80000000<0n_3V0000000000002@3jl>H5000000T0n_3V0P00003O0?[`iP800000
103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0
n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`
iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V0000
000000000P3jl>H00`000000n_3V0?[`iP02000000@0n_3V0P0000030?[`iP030000003jl>H0n_3V
008000000P3jl>H2000000030?[`iP000000000006X0n_3V0@3oool00280n_3V0`00000Y0?[`iP80
0000gP3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H0
00000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP0000000000
00T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H20000
0080n_3V0P0000000`3jl>H00000000000050?[`iP800000103jl>H2000000H0n_3V0P0000020?[`
iP80000000<0n_3V000000000000JP3jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP80
0000g@3jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0
n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`
iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP0000000000
00T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000`3jl>H40000
0080n_3V0P0000000`3jl>H00000000000050?[`iP800000103jl>H2000000H0n_3V0P0000020?[`
iP80000000<0n_3V000000000000JP3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002X0
n_3V0P00003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H0
00000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0`000000103jl>H000000000003jl>H2
00000080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02
000001P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP@00000103jl>H3
000000H0n_3V0P0000020?[`iP030000003jl>H0n_3V008000000`3jl>H3000006/0n_3V0@3oool0
0200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H2
000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@00
00020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`00
00000`3jl>H00000000000020?[`iP@000000P3jl>H3000000030?[`iP000000000000L000006@3j
l>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000080?[`iP8000001@3j
l>H200000080n_3V100000030?[`iP80000000<0n_3V000000000000JP3jl>H10?ooo`00C@3jl>H2
000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2
00000280n_3V0P0000020?[`iP800000;P3jl>H2000000030?[`iP000000000000T0n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
000000<0n_3V0P0000040?[`iP030000003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`iP02
00000080n_3V0P0000050?[`iP80000000<0n_3V000000000000JP3jl>H10?ooo`00CP3jl>H30000
0=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000006@3jl>H30000
00030?[`iP000000000000800000;P3jl>H3000000/0n_3V0`0000040?[`iP<00000103jl>H30000
00D0n_3V0`0000030?[`iP<000000`3jl>H500000080n_3V1@0000030?[`iP<00000J`3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V
0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H1
0?ooo`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H000000P3j
l>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`iP000000
00000080000000@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000
003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH00000
0`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000H00000
6`3jl>H3000000<0n_3V1P0000020?[`iP@00000^@3jl>H10?ooo`008@3jl>H2000000030?[`iP00
0000000000D0000000D0n_3V00000000000000000?[`iP04000000/0n_3V1@0000090?[`iP800000
00<0n_3V000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V
0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3j
l>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2
00000080n_3V0P00000;0?[`iPD000002@3jl>H00`000000n_3V0?[`iP02000000@0n_3V0P000005
0?[`iP800000^P3jl>H10?ooo`008P3jl>H3000002P0n_3V0P0000000`3jl>H000000000003L0?[`
iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`
iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP0000000000
00<0n_3V1000000L0?[`iP800000103jl>H200000080n_3V1P00002i0?[`iP40oooo000R0?[`iP<0
00002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0
n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H40000
00d0n_3V1@00000<0?[`iP800000103jl>H200000080n_3V00<000000?[`iP3jl>H00P00002j0?[`
iP40oooo000Q0?[`iP80000000<0n_3V0000000000009`3jl>H2000000030?[`iP00000000000=`0
n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000006P3jl>H3000000D0n_3V0P000003
0?[`iP040000003jl>H0000000000;X0n_3V0@3oool00200n_3V0`000000103jl>H0000000000000
000V0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V1000
00020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V
100000040?[`iP@000000P3jl>H5000000<0n_3V1@00000L0?[`iP800000103jl>H2000000<0n_3V
00@000000?[`iP0000000000^P3jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V
0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2000003P0n_3V00<000000?[`iP3jl>H0
0P0000020?[`iP@00000103jl>H300000;X0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3j
l>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H200000340n_3V0`0000050?[`iP8000001@3j
l>H200000;X0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo000M0?[`iRH0oooP0P00001/0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000
J@3oon0500000080oooP0P0000040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3j
l>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000203oon0010000000
oooP0?ooh000001/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon001`3oon001000
0000oooP0?ooh000001Z0?ooh0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?oo
h0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?oo
h01Z0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?oo
h01Y0?ooh0030000003oon00oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00
oooP000006X0oooP00@000000?ooh03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00
J`3oon000`000000oooP0?ooh0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V
0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0
oooP00<000000?ooh03oon00K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0
oooP00<000000?ooh03oon00JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0
n_3V9P3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<0
0000J`3oon02000002@0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o0000
0>X00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
00000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<0
00000?ooh03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP00T0
oooP2@0000000`3oon00000000000003000000040?ooh0000000000000000?l0oooPbP3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh003
0000003oon00oooP00P0oooP7`000000103oon00000000000000003o0?ooh;/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon04000000L0
oooP00<000000000o`000?l060000?lB00000?l0oooP[P3oon04000001P0oooP7P3jl>H10?ooo`00
7@3jl>H:0?ooh0@00000103oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP00T0oooP
2@0000000`3=QCl0000000000003000000030?oTh@000000000000P0000020000?l@00000?l0oooP
Z`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?oo
h0060?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oT
h@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3=QCl;000000040<f5?`0000000000
000000X0003o3`00003o0?ooh:80oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ40oooP0P0000080?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>42
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3o
i>400P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`/000002@000?l:00000?l0oooPWP3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080
cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ
0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40
cHDo0<f5?`050<f5?`030?oTh@000000000000P0000020000?l900000?l0oooPU`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo
00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5
?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo
0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40cHDo2P0000050000o`X0
0000o`3oon2A0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5
?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo
0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ200000050000o`T00000o`3oon2=0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0
1`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`03
0?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ
0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0000000H000001@00
0?l5000000030?ooh000000000000?l0oooPR@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ
0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0
cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`H000001@000?l800000?l0oooPQ03oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080
cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ
0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40
cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5
?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ
0P3=QCl6000000D0003o1`00003o0?ooh800oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@02
0<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5
?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ000000000000cHDo1000
00040000o`H00000o`3oon1m0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=
QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103o
i>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0
1@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`04
0?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ1P000005
0000o`D00000o`3oon1i0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0
onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40
cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3o
i>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oT
h@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3o
i>40cHDo00000006000000@0003o1P00003o0?ooh7@0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oT
h@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo
0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40
cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40
cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40
cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`0000001@0000040000o`@0
0000o`3oon1b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000
2@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5
?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo
00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3o
i>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=
QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo
00D0onCQ0<f5?`3=QCl0onCQ0<f5?`07000000<0003o1P00003o0?ooh6/0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0
onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=
QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oT
h@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oT
h@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ1@3=QCl0103oi>40cHDo0?oT
h@3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl02@3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`06000000@0003o1@00003o0?ooh6X0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40
cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3o
i>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3o
i>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3o
i>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@<0cHDo00<0onCQ0<f5?`0000001@0000030000o`@00000o`3oon1X0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=
QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40
cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=
QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo
00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>45
0<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=
QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401P000004
0000o`D00000o`3oon1S0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0
onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40
cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3o
i>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oT
h@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3o
i>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>400`3=QCl7000000<0003o1000003o0?ooh640oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oT
h@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo
0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl0
1@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40
cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0
onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=
QCl0onCQ00D000000`000?l300000?l0oooPG`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ
0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0
cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ1@3=QCl0103oi>40cHDo0?oTh@3=QCl2
0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0203oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400P3=QCl60000
0080003o1@00003o0?ooh5/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5
?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oT
h@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`05
0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0
onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`03
0?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0
onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0
100000030000o`H00000o`3oon1G0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oT
h@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0
103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5
?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=
QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5
?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@030<f5?`060?oTh@3=QCl0
cHDo0<f5?`3oi>40cHDo100000030000o`@00000o`3oon1F0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5
?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ
0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0
onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0
onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0
onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@03
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl00`3oi>4000000000000300000080003o1P00
003o0?ooh580oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo
0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo
0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0
onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=
QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0
cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=
QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@02
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400`0000030000o`H00000o`3oon1?0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0
103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo
0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0
cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0
onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5
?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3o
i>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=
QCl0onCQ00<0cHDo0`0000030000o`D00000o`3oon1=0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3o
i>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5
?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ
0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ
0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@030<f5
?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0
onCQ0000000000000P0000030000o`@00000o`3oon1;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3o
i>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5
?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ
0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ
0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@030<f5
?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00@0
onCQ0<f5?`3=QCl0onCQ100000020000o`@00000o`3oon190?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@02
0<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5
?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3o
i>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ
0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo
0<f5?`3oi>40cHDo0?oTh@80cHDo0P0000030000o`D00000o`3oon130?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oT
h@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo
0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40
cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40
cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40
cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40
cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo
00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3o
i>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`0000000P0000030000o`@00000o`3o
on130?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40
0P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>46
0<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=
QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oT
h@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`02
0<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5
?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl0
1@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`04
0?oTh@3=QCl0cHDo0<f5?`@000000P000?l500000?l0oooP@03oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5?`3=
QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oT
h@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`03
0?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0cHDo
0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ1@3=QCl0103oi>40cHDo
0?oTh@3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0203oi>40cHDo0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>40
0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5
?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@040<f5
?`0000000000000000<0003o1000003o0?ooh3h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80
cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oT
h@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo
0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo
0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo
0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0
onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40
cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5
?`3oi>43000000<0003o0P00003o0?ooh3d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@02
0<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5
?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3o
i>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ
0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo
0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>401@3=QCl0onCQ0<f5?`3o
i>40cHDo00D000000P000?l200000?l0oooP>`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ
0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0
cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ1@3=QCl0103oi>40cHDo0?oTh@3=QCl2
0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0203oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`060?oTh@3=
QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@040<f5?`3oi>40cHDo
0?oTh@80cHDo00<0onCQ0000000000000`0000020000o`<00000o`3oon0h0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103o
i>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5
?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo
00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ
0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`04
0?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40
cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=QCl0
onCQ00@0cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80
onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl400000080003o1@00003o
0?ooh3@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oT
h@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oT
h@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ
0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0
onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo
0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo
0080cHDo00<0onCQ0000000000000P0000020000o`@00000o`3oon0c0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40
cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=
QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0
cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5
?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oT
h@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo
0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ
00@0cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ
00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0onCQ0?oT
h@<000000`000?l400000?l0oooP<03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01@3o
i>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo
00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080
cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=
QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ1@3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80
cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0203oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=
QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`060?oTh@3=QCl0cHDo
0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80
cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0?oTh@3oi>430<f5?`<000000P000?l30000
0?l0oooP;`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0
onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0
onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3o
i>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5
?`3oi>450<f5?`80onCQ1@3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl0203oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5
?`3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080
cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=
QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl0103oi>40cHDo0?oTh@3oi>440<f5?`040?oTh@000000000000000080003o1@00003o
0?ooh2/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oT
h@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oT
h@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ
0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0
onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo
0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo
0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo0?oTh@0300000080003o1000003o
0?ooh2X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oT
h@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oT
h@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ
0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0
onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo
0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo
0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo0?oTh@020<f5?`<000000`000?l3
00000?l0oooP:03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=
QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=
QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5
?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo
0<f5?`3oi>450<f5?`80onCQ1@3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00<0onCQ0<f5
?`3=QCl00P3=QCl0203oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ
0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5
?`3=QCl00P3=QCl0103oi>40cHDo0?oTh@3oi>440<f5?`030?oTh@3=QCl0onCQ00<0cHDo00<0onCQ
0<f5?`0000000P0000020000o`<00000o`3oon0V0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<000002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ
0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`04
0?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5
?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo
00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=
QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3o
i>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5
?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo0?oTh@03
0<f5?`030?oTh@3=QCl0cHDo00@000000P000?l200000?l0oooP8`3oon03000001P0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>42
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3o
i>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5
?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5
?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5
?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@030<f5?`05
0?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00H0onCQ
0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ00@0cHDo0?oTh@3=
QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0onCQ0?oTh@@0cHDo00<0onCQ
0<f5?`3oi>400`3=QCl01P3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`<000000P000?l300000?l0oooP
8P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080
cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=
QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo
0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>45
0<f5?`80onCQ1@3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl0203oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0
onCQ00D0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0
onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103o
i>40cHDo0<f5?`3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl0103oi>40cHDo0?oTh@3oi>440<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@020<f5?`040?oTh@000000000000000080003o1000003o0?ooh1l0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`04
0?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0
cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=
QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3o
i>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo
00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oT
h@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo
0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3o
i>40onCQ103=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl0
0`3oi>40cHDo0000000300000080003o0`00003o0?ooh1h0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40
cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3o
i>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3o
i>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3o
i>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl0
1P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0
onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl0
0`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5
?`3=QCl400000080003o0P00003o0?ooh1d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@02
0<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5
?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3o
i>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ
0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo
0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3o
i>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo
0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
0080cHDo0`0000020000o`@00000o`3oon0I0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>40
0P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3o
i>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5?`80
onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00H0onCQ0<f5
?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ00@0cHDo0?oTh@3=QCl0
onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0onCQ0?oTh@@0cHDo00<0onCQ0<f5
?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@020<f5?`030?oTh@3=QCl00000008000000P000?l300000?l0oooP603oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00@0onCQ
0<f5?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0
cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`05
0<f5?`030?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=
QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ1@3=QCl0103o
i>40cHDo0?oTh@3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0203oi>40cHDo0<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00D0cHDo00<0onCQ0<f5
?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oT
h@040<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oT
h@040<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0?oTh@3o
i>440<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3=QCl300000080003o0`00003o0?oo
h1H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@02
0<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0
cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ
1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080
cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`05
0?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0
onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080
cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo
0<f5?`3oi>400P3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@0400000080003o0P00003o0?ooh1D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@02
0<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5
?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3o
i>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ
0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo
0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3o
i>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo
0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
0080cHDo00P0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`<000000P000?l300000?l0oooP
4P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080
cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=
QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo
0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>45
0<f5?`80onCQ1@3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl0203oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0
onCQ00D0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0
onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103o
i>40cHDo0<f5?`3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl0103oi>40cHDo0?oTh@3oi>440<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@020<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0
onCQ0<f5?`3oi>400P3=QCl400000080003o0P00003o0?ooh140oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0
cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3o
i>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl0
0`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5
?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5
?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ
00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=
QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=
QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=
QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00<0onCQ
0<f5?`0000000`0000000`000?l000000<f5?`0200000?l0oooP3P3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5
?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo
0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5
?`030?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0
cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ1@3=QCl0103oi>40
cHDo0?oTh@3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0203oi>40cHDo0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3o
i>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@04
0<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@04
0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0?oTh@3oi>44
0<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103o
i>40cHDo0<f5?`3oi>4300000080003o1000003o0?ooh0`0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40
cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3o
i>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3o
i>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3o
i>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl0
1P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0
onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl0
0`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0<f5
?`3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00T0onCQ0<f5
?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@0000000P000?l300000?l0oooP2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP0P3=QCl0103oi>40cHDo0<f5
?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ
0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0
onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0
onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0
onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@03
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo
00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ00@0cHDo
0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0onCQ0?oTh@@0cHDo
00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3=
QCl0cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=
QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0080000000<0003o0000000000000P00003o0?oo
h0L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080
cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ
0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40
cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5
?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ
1@3=QCl0103oi>40cHDo0?oTh@3=QCl20?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0203oi>40
cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00D0cHDo
00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3o
i>40cHDo0?oTh@040<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5
?`3=QCl20?oTh@040<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40
cHDo0?oTh@3oi>440<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@02
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3o
i>400P3=QCl02P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>4200000080003o
0`00003o0?ooh0P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40
cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0
cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=
QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5
?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=
QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5
?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=
QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00L0onCQ0<f5
?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0P3=QCl200000080003o1000003o0?ooh0D0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo
0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40
cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3o
i>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3o
i>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3o
i>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl0
1P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0
onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl0
0`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0<f5
?`3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00X0onCQ0<f5
?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl300000080003o0`00003o0?ooh0@0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5
?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo
00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3o
i>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=
QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo
00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oT
h@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ
0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo
00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5
?`3oi>400P3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oT
h@3=QCl0onCQ0080cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=
QCl00`3oi>40cHDo0?oTh@02000000030000o`000000000000800000o`3oon020?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0
103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo
0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0
cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0
onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5
?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3o
i>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=
QCl0onCQ00@0cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5
?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0
onCQ0?oTh@@0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo
00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@02
0<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00@0onCQ0<f5
?`3oi>40onCQ0P0000020000o`<00000o`3oon010?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>42
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3o
i>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5
?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5
?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5
?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@030<f5?`05
0?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00H0onCQ
0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ00@0cHDo0?oTh@3=
QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0onCQ0?oTh@@0cHDo00<0onCQ
0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`0:0?oTh@3=QCl0cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030000
0080003o0`00003n0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ
0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo
0<f5?`3oi>460<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40
cHDo0?oTh@3=QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=
QCl0cHDo0?oTh@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40
cHDo0<f5?`020<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3o
i>400P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3o
i>420<f5?`040?oTh@3=QCl0cHDo0<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40
cHDo0<f5?`020<f5?`040?oTh@3=QCl0onCQ0?oTh@@0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`070?oTh@3=
QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@<0cHDo00L0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>40cHDo00<000000P000?l30000
0?`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@02
0<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0
cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ
1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080
cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`05
0?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0
onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080
cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo
0<f5?`3oi>400P3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo
0?oTh@3=QCl0onCQ0080cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0`3=QCl01P3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@<0cHDo00@0onCQ000000000000003o1000003j
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=
QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>460<f5
?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0
onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@D0
cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5
?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3o
i>401@3=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3o
i>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oT
h@3=QCl0cHDo0<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5
?`040?oTh@3=QCl0onCQ0?oTh@@0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5?`3=
QCl0onCQ0080cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3o
i>40cHDo0?oTh@020<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0
cHDo00H0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>430<f5?`040?oTh@3=QCl0000000000080003o1000
003h0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40
0P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>46
0<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=
QCl0onCQ0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oT
h@D0cHDo0P3oi>450<f5?`040?oTh@3=QCl0onCQ0<f5?`80onCQ0P3=QCl00`3oi>40cHDo0<f5?`02
0<f5?`080?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5
?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl0
1@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`04
0?oTh@3=QCl0cHDo0<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`02
0<f5?`040?oTh@3=QCl0onCQ0?oTh@@0cHDo00<0onCQ0<f5?`3oi>400`3=QCl01@3oi>40cHDo0<f5
?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5
?`3oi>40cHDo0?oTh@020<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@<0cHDo00H0onCQ0<f5?`3oi>40onCQ0<f5?`3oi>430<f5?`040?oTh@3=QCl0onCQ0<f5?`800000
0P000?l300000?L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40
cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0
cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=
QCl0onCQ0<f5?`3oi>400P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5
?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=
QCl0cHDo0080cHDo00P0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5
?`3=QCl0cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0cHDo0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=
QCl0cHDo0080cHDo00@0onCQ0<f5?`3oi>40onCQ103=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>400P3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00L0onCQ0<f5
?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0`3=QCl01P3oi>40cHDo0?oTh@3oi>40cHDo0?oTh@<0cHDo00H0onCQ0<f5?`3oi>40
cHDo0?oTh@3=QCl2000000030000o`000000000000800000m@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3oon020<f5?`04
0?oTh@3=QCl0cHDo0?oTh@80cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0
cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo00<0onCQ0<f5?`3=
QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01P3o
i>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl20?oTh@D0cHDo
00@0onCQ0<f5?`3oi>40cHDo0P3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00P0onCQ0<f5?`3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@050<f5?`030?oT
h@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>40103=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0cHDo
0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3o
i>40onCQ103=QCl00`3oi>40cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl0
1@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080
cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01P3oi>40cHDo
0?oTh@3oi>40cHDo0?oTh@<0cHDo00L0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ008000000P00
0?l400000?<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@00000
0?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh080cHDo00@0onCQ0<f5?`3=QCl0onCQ
0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0
onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=
QCl0cHDo0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=
QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`80onCQ1@3=QCl0103oi>40cHDo0?oTh@3=
QCl20?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0203oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400`3=QCl0
1@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`060?oT
h@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3=QCl20?oTh@040<f5?`3oi>40
cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0?oTh@3oi>440<f5?`030?oT
h@3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`050?oTh@3=QCl0cHDo0<f5
?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl02P3oi>40cHDo0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`060?oTh@3=QCl0onCQ0?oTh@3=QCl0onCQ
0`3=QCl01`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>4000000000o`000?l3
00000?80oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?oo
h03oon0000001`3oon04000000P0oooPi`0000020000onP00000203oon04000001P0oooP7P3jl>H1
0?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00l03oon02
000000040000o`0000000000000000<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX20:gHiP<0<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0
[MSV0`0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H01P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon00
00001`3oon000`000000oooP0?ooh03a0?ooh08000000P000?l200000080<j7:00<0[MSV03>QbP2]
f>H00P0cXLX20:gHiP<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]
f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ40oooP0P0000080?ooh0030000003oon00oooP0?80oooP0`0000001`000?l00000000000000000
[MSV03>QbP2]f>H00P0cXLX20:gHiP<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP09
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0
100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00m03oon0200000080003o0P000000100cXLX0[MSV
03>QbP0cXLX20:gHiP<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]
f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00mP3oon02000000040000o`00000000000:gHiP80<j7:0P2]f>H3
03>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0c
XLX0<j7:0:gHiP<0<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00H0<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0303>QbP080:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV
03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?L0oooP0P0000020000o`<000000P2]f>H303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00d0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00H0<j7:00<0[MSV03>QbP2]
f>H00`0cXLX00`2]f>H0<j7:03>QbP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0
<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0
[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>Q
bP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?P0oooP0`0000001@000?l00000
000000000000[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]
f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00nP3oon02000000030000o`0000000000008000000P0cXLX01@2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]
f>H303>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0603>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0202]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]
f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP02
03>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03k
0?ooh08000000P000?l30000000603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:
03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00H0<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0
<j7:03>QbP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP0=0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:
00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:
00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?d0oooP0P0000000`000?l00000000000020000000403>Q
bP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H303>Q
bP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0603>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0202]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP04
0:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0c
XLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03n0?ooh080
00000P000?l3000000030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0
<j7:03>QbP2]f>H303>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0603>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0202]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0
[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0
<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gH
iP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh080oooP00<000000000o`0000000P0000001@0cXLX0[MSV03>QbP0cXLX0[MSV
00D0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]
f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon030?ooh003000000000?l0003o00<000000P0cXLX00`2]
f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00d0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00H0<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP0=
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]
f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX0
2@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080
<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:
00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP103oon02000000030000o`0000000000
0080000000<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP0=0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0603>QbP030:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:
0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP1@3oon0200000080003o0`00000503>Q
bP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00H0<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP03
03>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP0=0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>Q
bP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]
f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>Q
bP0cXLX0[MSV03>QbP090?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon070?ooh080000000<0003o0000000000000P00000303>QbP040:gHiP0cXLX0<j7:
0:gHiP<0<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00H0<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0303>QbP080:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:
00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP2@3oon000`000000003o0000o`0300000080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX0
3@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01P0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>Q
bP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0:0?oo
h080000000<0003o0000000000000P000000102]f>H0<j7:03>QbP2]f>H303>QbP0=0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0603>QbP030:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:
0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0`0oooP00<000000000
o`000?l0100000000`0cXLX0[MSV03>QbP0203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0603>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]
f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP05
0:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh0d0oooP0P0000000`000?l00000000000020000000A
0:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H01P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0?0?ooh003000000000?l0003o00<000000`0cXLX03@2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>Q
bP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0c
XLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0A0?ooh003000000000?l000000080
00000P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H01P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0B0?ooh003000000000?l0003o0080000000h0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPH0<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0
<j7:03>QbP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP0=0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:
00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:
00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4`3oon020000000@0000o`00000000000000000c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPH0<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0c
XLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0c
XLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP03
03>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon0200000080
003o0P0000002`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00H0<j7:
00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP03
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100c
XLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP5@3o
on030000000=0000o`00000000000000002]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0603>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0202]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]
f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP02
03>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh1H0oooP0`0000020000o`80000000P0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPH0
<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0303>QbP080:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>Q
bP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:
00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV
03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0
100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
6@3oon020000000:0000o`000000<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPH0<j7:00<0
[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gH
iP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP07
0:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV
03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0c
XLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX2
0:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0J0?ooh08000000P000?l3
0000000403>QbP2]f>H0<j7:0:gHiPH0<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP0=0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP04
03>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV
03>QbP0cXLX0[MSV03>QbP090?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0M0?ooh003000000000?l000000080000000<0[MSV03>QbP2]f>H01P0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>Q
bP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0M0?oo
h080000000H0003o000000000000000003>QbP2]f>H603>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0
[MSV03>QbP0cXLX00`0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX03@2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]
f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP03
03>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gH
iP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV
03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0
[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP04
03>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1h0oooP0P0000020000o`80000000<0[MSV
03>QbP0cXLX0100cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0P0?ooh080000000@0003o00000000000000001@0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80
<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0
<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H3
03>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gH
iP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Q0?ooh080000000@0003o0000
000000000000100cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0S0?ooh003000000000?l0003o008000000`0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>Q
bP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0c
XLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0T0?ooh080000000<0003o00000000
00000P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0U0?ooh080000000L0003o000000000000<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]
f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP05
0:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh2H0oooP0P0000020000o`80000000<0<j7:0:gHiP0c
XLX00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0
<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0
[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>Q
bP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP9`3oon03000000040000
o`00000000000:gHiP<0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
1`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gH
iP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0
<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2P0oooP
0`00000010000?l0000000000000000203>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0Y0?ooh0<000000P000?l20000000303>QbP2]f>H0<j7:00@0<j7:00P0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV
0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0/0?ooh080000000@0003o000000000000[MSV1@0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0c
XLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP;@3oon02000000030000o`00
0000000000D0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00d0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
1P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0
[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]
f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX0
1@2]f>H0<j7:03>QbP2]f>H0<j7:00T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh2h0oooP0P0000020000o`8000000`0cXLX0202]f>H0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gH
iP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h2l0oooP0`0000000`000?l000000000000203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0c
XLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0c
XLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP03
03>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<03oon0300000005
0000o`000000000003>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00d0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV
03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0c
XLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100c
XLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0b0?ooh080000000@0003o0000000000000000
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0c0?ooh08000000P000?l20000000603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0
<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3@0oooP0`00000020000?l00000
0000002]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gH
iP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>Q
bP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX0
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh3D0oooP0`0000001`000?l000000000000cXLX0[MSV03>QbP2]f>H00P0cXLX03@2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>Q
bP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0c
XLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>Q
bP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP05
0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>Q
bP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3H0oooP0`0000020000o`040000002]f>H0<j7:
0:gHiP80<j7:00d0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>Q
bP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H2
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0
<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0h0?ooh0<0000000@0
003o000000000000[MSV0P0cXLX03@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP04
0:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0c
XLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3T0
oooP0`0000000`000?l000000000000203>QbP0=0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:
00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP>P3oon030000000A0000o`000000000003>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV
03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:
0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0
0`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H2
03>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh3`0oooP0P0000020000o`0>0000002]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:
00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP?@3oon030000000>0000o`00000000000:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP03
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100c
XLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?P3o
on030000000=0000o`000000000003>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0
<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0
[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>Q
bP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0o0?ooh0<0000000`0003o000000000000
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP03
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0c
XLX0[MSV03>QbP090?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon110?ooh080000000/0003o000000000000<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0c
XLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0c
XLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP03
03>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@P3oon020000000:
0000o`000000<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]
f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:
0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0
<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon130?ooh08000000P000?l2000000050:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0
<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gH
iP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4H0oooP00P00000
0000o`000000000003>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon160?ooh080000000H0003o000000000000[MSV03>QbP2]f>H203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:
00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:
00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPA`3oon02000000050000o`000000[MSV03>QbP2]
f>H00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:
0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4P0oooP0P0000001000
0?l000000000002]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP03
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100c
XLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPBP3o
on000`000000003o000000020000000303>QbP2]f>H0<j7:0080<j7:00H0[MSV03>QbP0cXLX0[MSV
03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H3
03>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080
<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP05
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPBP3oon02000000050000o`00000000000000002]f>H00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV
0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1;0?ooh080000000@0003o00000000000000000`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP80<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>Q
bP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1=0?oo
h003000000000?l00000008000000P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0
[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>Q
bP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H2
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0
<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0oooPCP3o
on000`000000003o0000o`020000000703>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0c
XLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0c
XLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP03
03>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03o
on00o`3oon1?0?ooh080000000@0003o00000000000000000P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0c
XLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gH
iP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>Q
bP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gH
iP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000003o0?oo
h4l0oooP0P00000020000?l00000000000000000<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:
03>QbP0303>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0
<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX0203oon04000001P0oooP7P3jl>H10?ooo`00
7@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1A0?ooh0800000
00L0003o000000000000<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]
f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh580oooP0P0000001P00
0?l000000000002]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P00
00080?ooh0030000003oon00oooP0?l0oooPE03oon001P000000003o000000000000<j7:0:gHiP80
<j7:00<0[MSV03>QbP0cXLX00`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0
[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80
[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1D0?ooh080
000000@0003o00000000000000000P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0<j7:
0:gHiP0cXLX0[MSV0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]
f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>Q
bP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:
0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh5D0oooP0P0000001P000?l00000000000000000<j7:0:gHiPD0<j7:00H0
[MSV03>QbP0cXLX0[MSV03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0c
XLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gH
iP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV
03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0
[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPEP3oon02000000050000o`00000000000000002]f>H0
1@0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP09
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0
100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1H0?ooh003000000000?l0003o00800000
1@0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP09
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0
100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1I0?ooh080000000<0003o000000000000
100cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP09
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0
100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1J0?ooh080000000<0003o000000000000
0`0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP09
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0
100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1K0?ooh080000000<0003o000000000000
0P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP09
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0
100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1L0?ooh080000000D0003o000000000000
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100c
XLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1M0?ooh080000000@0003o000000000000[MSV
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP04
03>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV
03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPGP3oon02000000080000o`00000000000000000cXLX0[MSV
03>QbP2]f>H303>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3o
on1O0?ooh080000000L0003o00000000000000000:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>Q
bP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H2
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0
<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00T0oooP0`00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh600oooP0P0000001P000?l000000000
00000000<j7:0:gHiP<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1R0?ooh003000000000?l0003o0080000000L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100c
XLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPHP3o
on03000000030000o`000000[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]
f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1S0?ooh0<0000000<0003o0000000000000P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
1`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gH
iP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0
<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6H0oooP
00P000000000o`000000000003>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP03
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0c
XLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPIP3oon02000000060000o`00000000000:gHiP0cXLX0[MSV0P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>Q
bP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0c
XLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh080000000D0003o00000000
0000<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
1`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gH
iP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0
<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6P0oooP
0P00000010000?l000000000002]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gH
iP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>Q
bP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX0
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh6T0oooP0P0000001P000?l00000000000000000<j7:0:gHiP80<j7:00H0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gH
iP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPJP3oon02000000050000o`00000000000000002]f>H00P0cXLX01P2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:
00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:
03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1/0?ooh003000000000?l00000008000000P0cXLX01P2]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1]0?ooh004000000000?l0000000000080<j7:00H0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPKP3oon000`000000003o00000002000000060:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV0P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP02
03>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6l0oooP00<000000000o`0000000P00000203>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV
03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:
03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]
f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV
00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh6l0oooP0P0000020000o`060000
000cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100c
XLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX02@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPL03oon03000000060000o`000000<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0
<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gH
iP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh780oooP0P000000
1@000?l000000000000cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:
0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0
<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1b0?ooh0<0000000@0003o000000000000[MSV0P0cXLX01`2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0c
XLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7<0oooP0`00
00000`000?l000000:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP03
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0c
XLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPM@3oon02000000050000o`000000000003>QbP2]f>H00`0cXLX00`2]
f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX0
2@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080
<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:
00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPM`3oon001@000000003o000000000000
[MSV00<0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gH
iP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7L0oooP0P000000
0`000?l000000000000303>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1g
0?ooh0<0000000<0003o0000000000000P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP03
03>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80
<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>Q
bP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPN03oon03000000070000o`000000000003>QbP2]f>H0<j7:0:gHiP0403>QbP030:gH
iP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPNP3oon02000000060000o`00000000000:gHiP0cXLX0[MSV100cXLX00`2]
f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>Q
bP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:
0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh7/0oooP0P0000001@000?l000000000000cXLX0[MSV00@0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]
f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1l0?ooh080000000@0003o0000000cXLX0[MSV100cXLX00`2]f>H0<j7:0:gH
iP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>Q
bP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX0
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh7d0oooP0P0000000`000?l000000000000403>QbP030:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100c
XLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon1n0?ooh080000000<0
003o0000000000000`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:
00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV
03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02@3oon03000001P0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPOP3oon03000000030000o`00000000000080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1o0?ooh0<0000000L0003o000000000000<j7:0:gHiP0cXLX0[MSV0080
<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP05
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPP@3oon02000000060000o`00000000000:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]
f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:
0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon220?ooh080000000D0003o
000000000000<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8<0oooP0P00000010000?l000000000002]f>H203>QbP040:gH
iP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0
<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8@0oooP
0P0000000`000?l000000000000203>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00T0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0c
XLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gH
iP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh8D0oooP0P0000001@000?l0000003>QbP0cXLX0[MSV0080
<j7:00d0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>Q
bP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon260?oo
h080000000@0003o000000000000[MSV0P0cXLX03@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8P0oooP00@000000000o`00000000000P0cXLX03@2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8P0oooP0P0000001@000?l0
00000000000cXLX0[MSV00<0<j7:00T0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0c
XLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8T0
oooP0P00000010000?l000000000002]f>H303>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0c
XLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:
00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2:0?ooh080000000<0003o0000000000000`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPR`3oon02000000030000o`000000<j7:0080<j7:00T0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on0300000?l0oooPS03oon020000000=0000o`000000<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP090?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2<0?ooh0<0000000`0003o0000000cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP05
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPS@3oon030000000;0000o`000000000003>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0c
XLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8h0
oooP0`0000002P000?l000000000002]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP03
03>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPS`3oon0300000009
0000o`000000[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0
100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2@0?ooh080000000T0003o03>QbP000000
00000:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh9<0oooP00P0003o000000000000000003>QbP2]f>H0<j7:0:gH
iP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2C
0?ooh008000000000?l000000000000cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV0080
<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:
00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU03oon001`000000003o000000000000
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0
0`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H2
03>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh9D0oooP00H000000000o`000000000003>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV
0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]
f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0
<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU@3oon02000000040000o`000000
00000:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2F0?ooh080000000<0003o0000000000000P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP05
0:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh9L0oooP0P0000001`000?l000000000000cXLX0[MSV
03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H2
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0
<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ00oooP100000070?ooh0030000003oon00oooP0?l0oooPV03o
on02000000060000o`00000000000:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00<000000?oo
h03oon00203oon000`000000oooP0?ooh03o0?ooh9T0oooP0P0000001@000?l000000000000cXLX0
[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]
f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HA0?ooh0030000003oon00oooP00L0oooP1000003o0?ooh9T0oooP00<0
00000000o`0000000P000000202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0`0cXLX01@2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gH
iP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX0203oon04
000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?oo
h03oon00o`3oon2K0?ooh003000000000?l00000008000000P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]
f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@00000
0?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh9`0oooP00@000000000o`0000000000
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0c
XLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPW03oon0200000009
0000o`000000<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H2
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0
<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2M0?ooh080000000P0
003o000000000000[MSV03>QbP2]f>H0<j7:0:gHiP<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gH
iP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2O0?ooh003000000000?l00000
0080000000<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>Q
bP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9l0oooP0P0000001P000?l00000000000000000
<j7:0:gHiP<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2P0?ooh080000000D0003o000000000000<j7:0:gHiP0303>QbP050:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV
03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0
100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
XP3oon000`000000003o0:gHiP02000000<0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0
100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2S0?ooh00303>QbP000?l0000000800000
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H2
03>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh:<0oooP00<0<j7:000000000?l00P00000203>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>Q
bP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon002P000000003o
000000000000<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]
f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2U0?ooh080000000P0003o000000000000[MSV03>QbP2]f>H0<j7:0:gHiP80
<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:H0oooP0P0000001`000?l00000
0000000cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2W0?ooh080
000000H0003o000000000000[MSV03>QbP2]f>H203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:00T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:P0oooP0P0000001@000?l000000000000cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>Q
bP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:
0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh:T0oooP00<000000000o`0000000P000000102]f>H0<j7:03>QbP2]f>H2
03>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:
00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZP3oon000`000000003o0000000200000080<j7:
00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV
03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:/0oooP00<000000000o`0000000P00
00001`0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:
0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2/0?ooh006000000000?l0
00000000000cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP00D000000000
o`00000000000:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>Q
bP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[@3oon02000000030000
o`00000000000080<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gH
iP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2^0?ooh080000000L0003o0000
00000000<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0
<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[`3oon02000000060000o`00000000000:gH
iP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:
03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2`0?ooh080000000D0003o000000000000<j7:0:gHiP0203>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh;40oooP0P00000010000?l0000003>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;80oooP0P0000000`000?l0
00000:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0
<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;<0oooP0P0000001@000?l000000000000cXLX0[MSV0080<j7:00@0
[MSV03>QbP0cXLX0[MSV0`0cXLX0102]f>H0<j7:03>QbP2]f>H603>QbP80[MSV00<0<j7:0:gHiP0c
XLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh;<0oooP0`00000010000?l000000000002]f>H203>Q
bP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00@0[MSV03>QbP0cXLX0[MSV1P0cXLX20:gHiP0303>QbP2]
f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP090?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2d0?ooh0<0000000<0003o0000002]f>H00P0c
XLX0102]f>H0<j7:03>QbP2]f>H303>QbP040:gHiP0cXLX0<j7:0:gHiPH0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;H0oooP00@000000000o`00
000000000P0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP040:gHiP0cXLX0<j7:0:gHiPH0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;H0oooP0P00
00001@000?l000000000000cXLX0[MSV0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gH
iP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh;L0oooP0P00000010000?l0000003>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX0
1@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2h0?ooh080000000<0003o0000002]f>H00P0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0100cXLX20:gHiP0303>QbP2]
f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^03oon03000000050000o`00
0000000003>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H603>QbP80[MSV00<0<j7:0:gHiP0c
XLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh0<0000000@0003o00000000
0000[MSV0`0cXLX0102]f>H0<j7:03>QbP2]f>H603>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX0
1@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2k0?ooh005000000000?l000000000002]f>H00`0c
XLX0102]f>H0<j7:03>QbP2]f>H603>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:
03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2l0?ooh004000000000?l00000000000<0<j7:00@0[MSV03>QbP0c
XLX0[MSV1P0cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP_03oon02000000030000o`00000000000080<j7:00@0[MSV03>QbP0cXLX0[MSV1P0cXLX2
0:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_@3oon02
000000050000o`000000000003>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0
<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n0?ooh080000000@0
003o000000000000[MSV0P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0
100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2o0?ooh080000000<0003o0000002]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:
03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon300?ooh004000000000?l0000000000080<j7:00<0[MSV03>QbP0c
XLX0100cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon300?ooh080
000000D0003o000000000000<j7:0:gHiP0603>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]
f>H0<j7:03>QbP2]f>H0<j7:00T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh<40oooP0P00000010000?l000000000002]f>H603>QbP80[MSV00<0<j7:
0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon320?ooh080000000<0003o
0000000000001P0cXLX20:gHiP0303>QbP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>Q
bP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP``3oon02000000030000o`000000000000D0<j7:0P2]f>H00`0cXLX0[MSV03>QbP04
03>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<@0oooP0P0000000`000?l0000003>QbP04
03>QbP80[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon35
0?ooh004000000000?l00000000000@0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<H0oooP00@000000000o`00000000000`0cXLX20:gHiP0303>Q
bP2]f>H0<j7:00@0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPaP3oon02000000030000
o`00000000000080<j7:0P2]f>H00`0cXLX0[MSV03>QbP0403>QbP050:gHiP0cXLX0<j7:0:gHiP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<L0oooP0P00000010000?l000000000000cXLX20:gHiP0303>QbP2]f>H0<j7:00@0
<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb03oon02000000030000o`00000000000080
[MSV00<0<j7:0:gHiP0cXLX0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?ooh080
000000H0003o000000000000[MSV03>QbP2]f>H503>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<X0oooP00L000000000o`00000000000:gHiP0cXLX0[MSV00D0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPb`3oon001P000000003o000000000000<j7:0:gHiPD0<j7:00D0[MSV03>Q
bP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPc03oon001@000000003o000000000000[MSV00D0<j7:00D0[MSV
03>QbP0cXLX0[MSV03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<00000o`3oon3<0?ooh080000000<0003o0000000000001@0cXLX01@2]f>H0<j7:03>QbP2]
f>H0<j7:00T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<d0oooP0P0000000`000?l000000000000403>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<h0oooP0P0000000`000?l000000000000303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<l0oooP0P0000000`000?l000000000000203>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh=00oooP00@000000000o`00000000000P0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on3A0?ooh006000000000?l000000000000cXLX0[MSV0P0cXLX00`2]f>H0<j7:0?ooh00:0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
d@3oon02000000040000o`00000000000:gHiP80<j7:00<0[MSV03>QbP3oon002P3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=80oooP
0P0000000`000?l000000000000203>QbP030:gHiP0cXLX0oooP00X0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3C0?ooh080000000H0
003o000000000000<j7:0:gHiP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe03oon02000000050000o`000000<j7:0:gHiP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh=D0oooP0P00000010000?l000000:gHiP0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPeP3oon001@000000003o
000000000000<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP
0P0000080?ooh0030000003oon00oooP0?l0oooPeP3oon02000000030000o`000000000000/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon000000
1`3oon000`000000oooP0?ooh03o0?ooh=L0oooP0P0000000`000?l000000?ooh00:0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000
003o0?ooh=L0oooP0P0000000`000?l0oooP0?ooh0060?ooh0@00000603oon0N0?[`iP40oooo000M
0?[`iQ<0oooP00<000000?ooh03oon001@3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon00
0`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP
0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H400000080n_3V200000020?[`iP@0000000L0n_3V0000
0000000000000?[`iP000000n_3V00`0000000<0n_3V00000000000010000000103jl>H000000000
000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V00<000002@3jl>H500000080n_3V
100000020?[`iPD000004P3jl>H6000000H0n_3V00<000000?[`iP3jl>H0103jl>H3000000040?[`
iP000000000000000>@0n_3V0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V
0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP0400000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000T0n_3V00@000000?[`
iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`
iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`iP800000203j
l>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H2
000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000
n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000`0n_3V1@00
00050?[`iP8000001P3jl>H5000000H0n_3V0`00003V0?[`iP40oooo003M0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`iP800000203jl>H00`000000
n_3V0?[`iP060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H000000?[`iP800000103jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002P3jl>H30000
00@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2
000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0180n_3V0P000008
0?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003U0?[`iP40oooo003M0?[`
iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP0000000000
00D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3j
l>H0000000000007000000/0n_3V1@0000020?[`iP@000000P3jl>H3000000030?[`iP0000000000
01<0n_3V0P00000?0?[`iP<0000000D0n_3V00000000000000000?[`iP0400000=l0n_3V0@3oool0
0=d0n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H0603jl>H20000
0240n_3V1000000H0?[`iP030000003jl>H0n_3V0=l0n_3V0@3oool00=`0n_3V1P0000040?[`iP80
0000;`3jl>H5000001/0n_3V0`00000Q0?[`iP8000006@3jl>H00`000000n_3V0?[`iP3N0?[`iP40
oooo003o0?[`iWP0n_3V00<000000?[`iP3jl>H0g@3jl>H10?ooo`00o`3jl>Ie0?[`iP040000003j
l>H0n_3V00000=l0n_3V0@3oool00?l0n_3VMP3jl>H200000>00n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.0268 .01472 L
.0268 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.0268 .01472 L
.0268 .16187 L
s
1 .894 .882 r
.0268 .16187 m
.0268 .01473 L
.03017 .01473 L
.03017 .16187 L
F
.804 .522 .247 r
.0268 .16187 m
.0268 .01473 L
.03017 .01473 L
.03017 .16187 L
s
1 .894 .882 r
.03017 .16187 m
.03017 .01475 L
.03355 .01475 L
.03355 .16187 L
F
.804 .522 .247 r
.03017 .16187 m
.03017 .01475 L
.03355 .01475 L
.03355 .16187 L
s
1 .894 .882 r
.03355 .16187 m
.03355 .01478 L
.03506 .01478 L
.03506 .16187 L
F
.804 .522 .247 r
.03355 .16187 m
.03355 .01478 L
.03506 .01478 L
.03506 .16187 L
s
1 .894 .882 r
.03506 .16187 m
.03506 .01482 L
.03826 .01482 L
.03826 .16187 L
F
.804 .522 .247 r
.03506 .16187 m
.03506 .01482 L
.03826 .01482 L
.03826 .16187 L
s
1 .894 .882 r
.03826 .16187 m
.03826 .0149 L
.04064 .0149 L
.04064 .16187 L
F
.804 .522 .247 r
.03826 .16187 m
.03826 .0149 L
.04064 .0149 L
.04064 .16187 L
s
1 .894 .882 r
.04064 .16187 m
.04064 .01492 L
.04359 .01492 L
.04359 .16187 L
F
.804 .522 .247 r
.04064 .16187 m
.04064 .01492 L
.04359 .01492 L
.04359 .16187 L
s
1 .894 .882 r
.04359 .16187 m
.04359 .01498 L
.04575 .01498 L
.04575 .16187 L
F
.804 .522 .247 r
.04359 .16187 m
.04359 .01498 L
.04575 .01498 L
.04575 .16187 L
s
1 .894 .882 r
.04575 .16187 m
.04575 .0151 L
.04892 .0151 L
.04892 .16187 L
F
.804 .522 .247 r
.04575 .16187 m
.04575 .0151 L
.04892 .0151 L
.04892 .16187 L
s
1 .894 .882 r
.04892 .16187 m
.04892 .01513 L
.04998 .01513 L
.04998 .16187 L
F
.804 .522 .247 r
.04892 .16187 m
.04892 .01513 L
.04998 .01513 L
.04998 .16187 L
s
1 .894 .882 r
.04998 .16187 m
.04998 .0152 L
.05224 .0152 L
.05224 .16187 L
F
.804 .522 .247 r
.04998 .16187 m
.04998 .0152 L
.05224 .0152 L
.05224 .16187 L
s
1 .894 .882 r
.05224 .16187 m
.05224 .01533 L
.05486 .01533 L
.05486 .16187 L
F
.804 .522 .247 r
.05224 .16187 m
.05224 .01533 L
.05486 .01533 L
.05486 .16187 L
s
1 .894 .882 r
.05486 .16187 m
.05486 .01541 L
.05702 .01541 L
.05702 .16187 L
F
.804 .522 .247 r
.05486 .16187 m
.05486 .01541 L
.05702 .01541 L
.05702 .16187 L
s
1 .894 .882 r
.05702 .16187 m
.05702 .01555 L
.06012 .01555 L
.06012 .16187 L
F
.804 .522 .247 r
.05702 .16187 m
.05702 .01555 L
.06012 .01555 L
.06012 .16187 L
s
1 .894 .882 r
.06012 .16187 m
.06012 .01558 L
.06137 .01558 L
.06137 .16187 L
F
.804 .522 .247 r
.06012 .16187 m
.06012 .01558 L
.06137 .01558 L
.06137 .16187 L
s
1 .894 .882 r
.06137 .16187 m
.06137 .01564 L
.06361 .01564 L
.06361 .16187 L
F
.804 .522 .247 r
.06137 .16187 m
.06137 .01564 L
.06361 .01564 L
.06361 .16187 L
s
1 .894 .882 r
.06361 .16187 m
.06361 .01577 L
.0655 .01577 L
.0655 .16187 L
F
.804 .522 .247 r
.06361 .16187 m
.06361 .01577 L
.0655 .01577 L
.0655 .16187 L
s
1 .894 .882 r
.0655 .16187 m
.0655 .0159 L
.06807 .0159 L
.06807 .16187 L
F
.804 .522 .247 r
.0655 .16187 m
.0655 .0159 L
.06807 .0159 L
.06807 .16187 L
s
1 .894 .882 r
.06807 .16187 m
.06807 .01604 L
.06958 .01604 L
.06958 .16187 L
F
.804 .522 .247 r
.06807 .16187 m
.06807 .01604 L
.06958 .01604 L
.06958 .16187 L
s
1 .894 .882 r
.06958 .16187 m
.06958 .01609 L
.07091 .01609 L
.07091 .16187 L
F
.804 .522 .247 r
.06958 .16187 m
.06958 .01609 L
.07091 .01609 L
.07091 .16187 L
s
1 .894 .882 r
.07091 .16187 m
.07091 .01616 L
.07404 .01616 L
.07404 .16187 L
F
.804 .522 .247 r
.07091 .16187 m
.07091 .01616 L
.07404 .01616 L
.07404 .16187 L
s
1 .894 .882 r
.07404 .16187 m
.07404 .01646 L
.07574 .01646 L
.07574 .16187 L
F
.804 .522 .247 r
.07404 .16187 m
.07404 .01646 L
.07574 .01646 L
.07574 .16187 L
s
1 .894 .882 r
.07574 .16187 m
.07574 .01658 L
.0779 .01658 L
.0779 .16187 L
F
.804 .522 .247 r
.07574 .16187 m
.07574 .01658 L
.0779 .01658 L
.0779 .16187 L
s
1 .894 .882 r
.0779 .16187 m
.0779 .01672 L
.08082 .01672 L
.08082 .16187 L
F
.804 .522 .247 r
.0779 .16187 m
.0779 .01672 L
.08082 .01672 L
.08082 .16187 L
s
1 .894 .882 r
.08082 .16187 m
.08082 .01689 L
.08202 .01689 L
.08202 .16187 L
F
.804 .522 .247 r
.08082 .16187 m
.08082 .01689 L
.08202 .01689 L
.08202 .16187 L
s
1 .894 .882 r
.08202 .16187 m
.08202 .01698 L
.08387 .01698 L
.08387 .16187 L
F
.804 .522 .247 r
.08202 .16187 m
.08202 .01698 L
.08387 .01698 L
.08387 .16187 L
s
1 .894 .882 r
.08387 .16187 m
.08387 .01714 L
.08618 .01714 L
.08618 .16187 L
F
.804 .522 .247 r
.08387 .16187 m
.08387 .01714 L
.08618 .01714 L
.08618 .16187 L
s
1 .894 .882 r
.08618 .16187 m
.08618 .01732 L
.08866 .01732 L
.08866 .16187 L
F
.804 .522 .247 r
.08618 .16187 m
.08618 .01732 L
.08866 .01732 L
.08866 .16187 L
s
1 .894 .882 r
.08866 .16187 m
.08866 .01749 L
.09018 .01749 L
.09018 .16187 L
F
.804 .522 .247 r
.08866 .16187 m
.08866 .01749 L
.09018 .01749 L
.09018 .16187 L
s
1 .894 .882 r
.09018 .16187 m
.09018 .0177 L
.09317 .0177 L
.09317 .16187 L
F
.804 .522 .247 r
.09018 .16187 m
.09018 .0177 L
.09317 .0177 L
.09317 .16187 L
s
1 .894 .882 r
.09317 .16187 m
.09317 .01788 L
.09606 .01788 L
.09606 .16187 L
F
.804 .522 .247 r
.09317 .16187 m
.09317 .01788 L
.09606 .01788 L
.09606 .16187 L
s
1 .894 .882 r
.09606 .16187 m
.09606 .01814 L
.09744 .01814 L
.09744 .16187 L
F
.804 .522 .247 r
.09606 .16187 m
.09606 .01814 L
.09744 .01814 L
.09744 .16187 L
s
1 .894 .882 r
.09744 .16187 m
.09744 .01835 L
.09931 .01835 L
.09931 .16187 L
F
.804 .522 .247 r
.09744 .16187 m
.09744 .01835 L
.09931 .01835 L
.09931 .16187 L
s
1 .894 .882 r
.09931 .16187 m
.09931 .01847 L
.1023 .01847 L
.1023 .16187 L
F
.804 .522 .247 r
.09931 .16187 m
.09931 .01847 L
.1023 .01847 L
.1023 .16187 L
s
1 .894 .882 r
.1023 .16187 m
.1023 .01882 L
.10399 .01882 L
.10399 .16187 L
F
.804 .522 .247 r
.1023 .16187 m
.1023 .01882 L
.10399 .01882 L
.10399 .16187 L
s
1 .894 .882 r
.10399 .16187 m
.10399 .01899 L
.10627 .01899 L
.10627 .16187 L
F
.804 .522 .247 r
.10399 .16187 m
.10399 .01899 L
.10627 .01899 L
.10627 .16187 L
s
1 .894 .882 r
.10627 .16187 m
.10627 .01944 L
.10951 .01944 L
.10951 .16187 L
F
.804 .522 .247 r
.10627 .16187 m
.10627 .01944 L
.10951 .01944 L
.10951 .16187 L
s
1 .894 .882 r
.10951 .16187 m
.10951 .0196 L
.11293 .0196 L
.11293 .16187 L
F
.804 .522 .247 r
.10951 .16187 m
.10951 .0196 L
.11293 .0196 L
.11293 .16187 L
s
1 .894 .882 r
.11293 .16187 m
.11293 .01994 L
.11443 .01994 L
.11443 .16187 L
F
.804 .522 .247 r
.11293 .16187 m
.11293 .01994 L
.11443 .01994 L
.11443 .16187 L
s
1 .894 .882 r
.11443 .16187 m
.11443 .02009 L
.11553 .02009 L
.11553 .16187 L
F
.804 .522 .247 r
.11443 .16187 m
.11443 .02009 L
.11553 .02009 L
.11553 .16187 L
s
1 .894 .882 r
.11553 .16187 m
.11553 .02036 L
.11794 .02036 L
.11794 .16187 L
F
.804 .522 .247 r
.11553 .16187 m
.11553 .02036 L
.11794 .02036 L
.11794 .16187 L
s
1 .894 .882 r
.11794 .16187 m
.11794 .02067 L
.11985 .02067 L
.11985 .16187 L
F
.804 .522 .247 r
.11794 .16187 m
.11794 .02067 L
.11985 .02067 L
.11985 .16187 L
s
1 .894 .882 r
.11985 .16187 m
.11985 .02109 L
.12337 .02109 L
.12337 .16187 L
F
.804 .522 .247 r
.11985 .16187 m
.11985 .02109 L
.12337 .02109 L
.12337 .16187 L
s
1 .894 .882 r
.12337 .16187 m
.12337 .02124 L
.12665 .02124 L
.12665 .16187 L
F
.804 .522 .247 r
.12337 .16187 m
.12337 .02124 L
.12665 .02124 L
.12665 .16187 L
s
1 .894 .882 r
.12665 .16187 m
.12665 .02182 L
.12946 .02182 L
.12946 .16187 L
F
.804 .522 .247 r
.12665 .16187 m
.12665 .02182 L
.12946 .02182 L
.12946 .16187 L
s
1 .894 .882 r
.12946 .16187 m
.12946 .02212 L
.13073 .02212 L
.13073 .16187 L
F
.804 .522 .247 r
.12946 .16187 m
.12946 .02212 L
.13073 .02212 L
.13073 .16187 L
s
1 .894 .882 r
.13073 .16187 m
.13073 .02217 L
.13315 .02217 L
.13315 .16187 L
F
.804 .522 .247 r
.13073 .16187 m
.13073 .02217 L
.13315 .02217 L
.13315 .16187 L
s
1 .894 .882 r
.13315 .16187 m
.13315 .02261 L
.13457 .02261 L
.13457 .16187 L
F
.804 .522 .247 r
.13315 .16187 m
.13315 .02261 L
.13457 .02261 L
.13457 .16187 L
s
1 .894 .882 r
.13457 .16187 m
.13457 .02302 L
.13724 .02302 L
.13724 .16187 L
F
.804 .522 .247 r
.13457 .16187 m
.13457 .02302 L
.13724 .02302 L
.13724 .16187 L
s
1 .894 .882 r
.13724 .16187 m
.13724 .02328 L
.14019 .02328 L
.14019 .16187 L
F
.804 .522 .247 r
.13724 .16187 m
.13724 .02328 L
.14019 .02328 L
.14019 .16187 L
s
1 .894 .882 r
.14019 .16187 m
.14019 .02362 L
.14135 .02362 L
.14135 .16187 L
F
.804 .522 .247 r
.14019 .16187 m
.14019 .02362 L
.14135 .02362 L
.14135 .16187 L
s
1 .894 .882 r
.14135 .16187 m
.14135 .02379 L
.14382 .02379 L
.14382 .16187 L
F
.804 .522 .247 r
.14135 .16187 m
.14135 .02379 L
.14382 .02379 L
.14382 .16187 L
s
1 .894 .882 r
.14382 .16187 m
.14382 .02424 L
.14603 .02424 L
.14603 .16187 L
F
.804 .522 .247 r
.14382 .16187 m
.14382 .02424 L
.14603 .02424 L
.14603 .16187 L
s
1 .894 .882 r
.14603 .16187 m
.14603 .02442 L
.14951 .02442 L
.14951 .16187 L
F
.804 .522 .247 r
.14603 .16187 m
.14603 .02442 L
.14951 .02442 L
.14951 .16187 L
s
1 .894 .882 r
.14951 .16187 m
.14951 .02511 L
.15131 .02511 L
.15131 .16187 L
F
.804 .522 .247 r
.14951 .16187 m
.14951 .02511 L
.15131 .02511 L
.15131 .16187 L
s
1 .894 .882 r
.15131 .16187 m
.15131 .02527 L
.15346 .02527 L
.15346 .16187 L
F
.804 .522 .247 r
.15131 .16187 m
.15131 .02527 L
.15346 .02527 L
.15346 .16187 L
s
1 .894 .882 r
.15346 .16187 m
.15346 .02583 L
.15486 .02583 L
.15486 .16187 L
F
.804 .522 .247 r
.15346 .16187 m
.15346 .02583 L
.15486 .02583 L
.15486 .16187 L
s
1 .894 .882 r
.15486 .16187 m
.15486 .02608 L
.1564 .02608 L
.1564 .16187 L
F
.804 .522 .247 r
.15486 .16187 m
.15486 .02608 L
.1564 .02608 L
.1564 .16187 L
s
1 .894 .882 r
.1564 .16187 m
.1564 .02629 L
.15756 .02629 L
.15756 .16187 L
F
.804 .522 .247 r
.1564 .16187 m
.1564 .02629 L
.15756 .02629 L
.15756 .16187 L
s
1 .894 .882 r
.15756 .16187 m
.15756 .02669 L
.16096 .02669 L
.16096 .16187 L
F
.804 .522 .247 r
.15756 .16187 m
.15756 .02669 L
.16096 .02669 L
.16096 .16187 L
s
1 .894 .882 r
.16096 .16187 m
.16096 .02693 L
.16265 .02693 L
.16265 .16187 L
F
.804 .522 .247 r
.16096 .16187 m
.16096 .02693 L
.16265 .02693 L
.16265 .16187 L
s
1 .894 .882 r
.16265 .16187 m
.16265 .02738 L
.16431 .02738 L
.16431 .16187 L
F
.804 .522 .247 r
.16265 .16187 m
.16265 .02738 L
.16431 .02738 L
.16431 .16187 L
s
1 .894 .882 r
.16431 .16187 m
.16431 .02777 L
.16749 .02777 L
.16749 .16187 L
F
.804 .522 .247 r
.16431 .16187 m
.16431 .02777 L
.16749 .02777 L
.16749 .16187 L
s
1 .894 .882 r
.16749 .16187 m
.16749 .02828 L
.17085 .02828 L
.17085 .16187 L
F
.804 .522 .247 r
.16749 .16187 m
.16749 .02828 L
.17085 .02828 L
.17085 .16187 L
s
1 .894 .882 r
.17085 .16187 m
.17085 .02894 L
.17366 .02894 L
.17366 .16187 L
F
.804 .522 .247 r
.17085 .16187 m
.17085 .02894 L
.17366 .02894 L
.17366 .16187 L
s
1 .894 .882 r
.17366 .16187 m
.17366 .0297 L
.17693 .0297 L
.17693 .16187 L
F
.804 .522 .247 r
.17366 .16187 m
.17366 .0297 L
.17693 .0297 L
.17693 .16187 L
s
1 .894 .882 r
.17693 .16187 m
.17693 .03028 L
.18012 .03028 L
.18012 .16187 L
F
.804 .522 .247 r
.17693 .16187 m
.17693 .03028 L
.18012 .03028 L
.18012 .16187 L
s
1 .894 .882 r
.18012 .16187 m
.18012 .03058 L
.18125 .03058 L
.18125 .16187 L
F
.804 .522 .247 r
.18012 .16187 m
.18012 .03058 L
.18125 .03058 L
.18125 .16187 L
s
1 .894 .882 r
.18125 .16187 m
.18125 .03096 L
.18231 .03096 L
.18231 .16187 L
F
.804 .522 .247 r
.18125 .16187 m
.18125 .03096 L
.18231 .03096 L
.18231 .16187 L
s
1 .894 .882 r
.18231 .16187 m
.18231 .03147 L
.18537 .03147 L
.18537 .16187 L
F
.804 .522 .247 r
.18231 .16187 m
.18231 .03147 L
.18537 .03147 L
.18537 .16187 L
s
1 .894 .882 r
.18537 .16187 m
.18537 .03182 L
.1872 .03182 L
.1872 .16187 L
F
.804 .522 .247 r
.18537 .16187 m
.18537 .03182 L
.1872 .03182 L
.1872 .16187 L
s
1 .894 .882 r
.1872 .16187 m
.1872 .03229 L
.19044 .03229 L
.19044 .16187 L
F
.804 .522 .247 r
.1872 .16187 m
.1872 .03229 L
.19044 .03229 L
.19044 .16187 L
s
1 .894 .882 r
.19044 .16187 m
.19044 .03308 L
.19236 .03308 L
.19236 .16187 L
F
.804 .522 .247 r
.19044 .16187 m
.19044 .03308 L
.19236 .03308 L
.19236 .16187 L
s
1 .894 .882 r
.19236 .16187 m
.19236 .03321 L
.19352 .03321 L
.19352 .16187 L
F
.804 .522 .247 r
.19236 .16187 m
.19236 .03321 L
.19352 .03321 L
.19352 .16187 L
s
1 .894 .882 r
.19352 .16187 m
.19352 .0337 L
.19524 .0337 L
.19524 .16187 L
F
.804 .522 .247 r
.19352 .16187 m
.19352 .0337 L
.19524 .0337 L
.19524 .16187 L
s
1 .894 .882 r
.19524 .16187 m
.19524 .03381 L
.19708 .03381 L
.19708 .16187 L
F
.804 .522 .247 r
.19524 .16187 m
.19524 .03381 L
.19708 .03381 L
.19708 .16187 L
s
1 .894 .882 r
.19708 .16187 m
.19708 .03442 L
.20031 .03442 L
.20031 .16187 L
F
.804 .522 .247 r
.19708 .16187 m
.19708 .03442 L
.20031 .03442 L
.20031 .16187 L
s
1 .894 .882 r
.20031 .16187 m
.20031 .03499 L
.20152 .03499 L
.20152 .16187 L
F
.804 .522 .247 r
.20031 .16187 m
.20031 .03499 L
.20152 .03499 L
.20152 .16187 L
s
1 .894 .882 r
.20152 .16187 m
.20152 .03544 L
.20497 .03544 L
.20497 .16187 L
F
.804 .522 .247 r
.20152 .16187 m
.20152 .03544 L
.20497 .03544 L
.20497 .16187 L
s
1 .894 .882 r
.20497 .16187 m
.20497 .03604 L
.20819 .03604 L
.20819 .16187 L
F
.804 .522 .247 r
.20497 .16187 m
.20497 .03604 L
.20819 .03604 L
.20819 .16187 L
s
1 .894 .882 r
.20819 .16187 m
.20819 .03706 L
.21108 .03706 L
.21108 .16187 L
F
.804 .522 .247 r
.20819 .16187 m
.20819 .03706 L
.21108 .03706 L
.21108 .16187 L
s
1 .894 .882 r
.21108 .16187 m
.21108 .03777 L
.21426 .03777 L
.21426 .16187 L
F
.804 .522 .247 r
.21108 .16187 m
.21108 .03777 L
.21426 .03777 L
.21426 .16187 L
s
1 .894 .882 r
.21426 .16187 m
.21426 .03862 L
.21761 .03862 L
.21761 .16187 L
F
.804 .522 .247 r
.21426 .16187 m
.21426 .03862 L
.21761 .03862 L
.21761 .16187 L
s
1 .894 .882 r
.21761 .16187 m
.21761 .03945 L
.22096 .03945 L
.22096 .16187 L
F
.804 .522 .247 r
.21761 .16187 m
.21761 .03945 L
.22096 .03945 L
.22096 .16187 L
s
1 .894 .882 r
.22096 .16187 m
.22096 .04017 L
.22322 .04017 L
.22322 .16187 L
F
.804 .522 .247 r
.22096 .16187 m
.22096 .04017 L
.22322 .04017 L
.22322 .16187 L
s
1 .894 .882 r
.22322 .16187 m
.22322 .04109 L
.22581 .04109 L
.22581 .16187 L
F
.804 .522 .247 r
.22322 .16187 m
.22322 .04109 L
.22581 .04109 L
.22581 .16187 L
s
1 .894 .882 r
.22581 .16187 m
.22581 .0412 L
.22703 .0412 L
.22703 .16187 L
F
.804 .522 .247 r
.22581 .16187 m
.22581 .0412 L
.22703 .0412 L
.22703 .16187 L
s
1 .894 .882 r
.22703 .16187 m
.22703 .04167 L
.23054 .04167 L
.23054 .16187 L
F
.804 .522 .247 r
.22703 .16187 m
.22703 .04167 L
.23054 .04167 L
.23054 .16187 L
s
1 .894 .882 r
.23054 .16187 m
.23054 .04248 L
.23352 .04248 L
.23352 .16187 L
F
.804 .522 .247 r
.23054 .16187 m
.23054 .04248 L
.23352 .04248 L
.23352 .16187 L
s
1 .894 .882 r
.23352 .16187 m
.23352 .04341 L
.23636 .04341 L
.23636 .16187 L
F
.804 .522 .247 r
.23352 .16187 m
.23352 .04341 L
.23636 .04341 L
.23636 .16187 L
s
1 .894 .882 r
.23636 .16187 m
.23636 .04424 L
.23793 .04424 L
.23793 .16187 L
F
.804 .522 .247 r
.23636 .16187 m
.23636 .04424 L
.23793 .04424 L
.23793 .16187 L
s
1 .894 .882 r
.23793 .16187 m
.23793 .04458 L
.24136 .04458 L
.24136 .16187 L
F
.804 .522 .247 r
.23793 .16187 m
.23793 .04458 L
.24136 .04458 L
.24136 .16187 L
s
1 .894 .882 r
.24136 .16187 m
.24136 .0457 L
.24433 .0457 L
.24433 .16187 L
F
.804 .522 .247 r
.24136 .16187 m
.24136 .0457 L
.24433 .0457 L
.24433 .16187 L
s
1 .894 .882 r
.24433 .16187 m
.24433 .04673 L
.24765 .04673 L
.24765 .16187 L
F
.804 .522 .247 r
.24433 .16187 m
.24433 .04673 L
.24765 .04673 L
.24765 .16187 L
s
1 .894 .882 r
.24765 .16187 m
.24765 .04727 L
.25092 .04727 L
.25092 .16187 L
F
.804 .522 .247 r
.24765 .16187 m
.24765 .04727 L
.25092 .04727 L
.25092 .16187 L
s
1 .894 .882 r
.25092 .16187 m
.25092 .04847 L
.25217 .04847 L
.25217 .16187 L
F
.804 .522 .247 r
.25092 .16187 m
.25092 .04847 L
.25217 .04847 L
.25217 .16187 L
s
1 .894 .882 r
.25217 .16187 m
.25217 .04887 L
.25428 .04887 L
.25428 .16187 L
F
.804 .522 .247 r
.25217 .16187 m
.25217 .04887 L
.25428 .04887 L
.25428 .16187 L
s
1 .894 .882 r
.25428 .16187 m
.25428 .04942 L
.25749 .04942 L
.25749 .16187 L
F
.804 .522 .247 r
.25428 .16187 m
.25428 .04942 L
.25749 .04942 L
.25749 .16187 L
s
1 .894 .882 r
.25749 .16187 m
.25749 .05035 L
.26009 .05035 L
.26009 .16187 L
F
.804 .522 .247 r
.25749 .16187 m
.25749 .05035 L
.26009 .05035 L
.26009 .16187 L
s
1 .894 .882 r
.26009 .16187 m
.26009 .05157 L
.26303 .05157 L
.26303 .16187 L
F
.804 .522 .247 r
.26009 .16187 m
.26009 .05157 L
.26303 .05157 L
.26303 .16187 L
s
1 .894 .882 r
.26303 .16187 m
.26303 .05199 L
.26544 .05199 L
.26544 .16187 L
F
.804 .522 .247 r
.26303 .16187 m
.26303 .05199 L
.26544 .05199 L
.26544 .16187 L
s
1 .894 .882 r
.26544 .16187 m
.26544 .05262 L
.2685 .05262 L
.2685 .16187 L
F
.804 .522 .247 r
.26544 .16187 m
.26544 .05262 L
.2685 .05262 L
.2685 .16187 L
s
1 .894 .882 r
.2685 .16187 m
.2685 .05439 L
.27117 .05439 L
.27117 .16187 L
F
.804 .522 .247 r
.2685 .16187 m
.2685 .05439 L
.27117 .05439 L
.27117 .16187 L
s
1 .894 .882 r
.27117 .16187 m
.27117 .05511 L
.27442 .05511 L
.27442 .16187 L
F
.804 .522 .247 r
.27117 .16187 m
.27117 .05511 L
.27442 .05511 L
.27442 .16187 L
s
1 .894 .882 r
.27442 .16187 m
.27442 .05625 L
.27747 .05625 L
.27747 .16187 L
F
.804 .522 .247 r
.27442 .16187 m
.27442 .05625 L
.27747 .05625 L
.27747 .16187 L
s
1 .894 .882 r
.27747 .16187 m
.27747 .05718 L
.28087 .05718 L
.28087 .16187 L
F
.804 .522 .247 r
.27747 .16187 m
.27747 .05718 L
.28087 .05718 L
.28087 .16187 L
s
1 .894 .882 r
.28087 .16187 m
.28087 .05809 L
.28372 .05809 L
.28372 .16187 L
F
.804 .522 .247 r
.28087 .16187 m
.28087 .05809 L
.28372 .05809 L
.28372 .16187 L
s
1 .894 .882 r
.28372 .16187 m
.28372 .05882 L
.28715 .05882 L
.28715 .16187 L
F
.804 .522 .247 r
.28372 .16187 m
.28372 .05882 L
.28715 .05882 L
.28715 .16187 L
s
1 .894 .882 r
.28715 .16187 m
.28715 .05996 L
.289 .05996 L
.289 .16187 L
F
.804 .522 .247 r
.28715 .16187 m
.28715 .05996 L
.289 .05996 L
.289 .16187 L
s
1 .894 .882 r
.289 .16187 m
.289 .06086 L
.29087 .06086 L
.29087 .16187 L
F
.804 .522 .247 r
.289 .16187 m
.289 .06086 L
.29087 .06086 L
.29087 .16187 L
s
1 .894 .882 r
.29087 .16187 m
.29087 .06145 L
.29355 .06145 L
.29355 .16187 L
F
.804 .522 .247 r
.29087 .16187 m
.29087 .06145 L
.29355 .06145 L
.29355 .16187 L
s
1 .894 .882 r
.29355 .16187 m
.29355 .06201 L
.29699 .06201 L
.29699 .16187 L
F
.804 .522 .247 r
.29355 .16187 m
.29355 .06201 L
.29699 .06201 L
.29699 .16187 L
s
1 .894 .882 r
.29699 .16187 m
.29699 .06343 L
.2994 .06343 L
.2994 .16187 L
F
.804 .522 .247 r
.29699 .16187 m
.29699 .06343 L
.2994 .06343 L
.2994 .16187 L
s
1 .894 .882 r
.2994 .16187 m
.2994 .06454 L
.30195 .06454 L
.30195 .16187 L
F
.804 .522 .247 r
.2994 .16187 m
.2994 .06454 L
.30195 .06454 L
.30195 .16187 L
s
1 .894 .882 r
.30195 .16187 m
.30195 .06493 L
.30412 .06493 L
.30412 .16187 L
F
.804 .522 .247 r
.30195 .16187 m
.30195 .06493 L
.30412 .06493 L
.30412 .16187 L
s
1 .894 .882 r
.30412 .16187 m
.30412 .06607 L
.30519 .06607 L
.30519 .16187 L
F
.804 .522 .247 r
.30412 .16187 m
.30412 .06607 L
.30519 .06607 L
.30519 .16187 L
s
1 .894 .882 r
.30519 .16187 m
.30519 .06611 L
.30815 .06611 L
.30815 .16187 L
F
.804 .522 .247 r
.30519 .16187 m
.30519 .06611 L
.30815 .06611 L
.30815 .16187 L
s
1 .894 .882 r
.30815 .16187 m
.30815 .06729 L
.31091 .06729 L
.31091 .16187 L
F
.804 .522 .247 r
.30815 .16187 m
.30815 .06729 L
.31091 .06729 L
.31091 .16187 L
s
1 .894 .882 r
.31091 .16187 m
.31091 .06909 L
.31334 .06909 L
.31334 .16187 L
F
.804 .522 .247 r
.31091 .16187 m
.31091 .06909 L
.31334 .06909 L
.31334 .16187 L
s
1 .894 .882 r
.31334 .16187 m
.31334 .06936 L
.31669 .06936 L
.31669 .16187 L
F
.804 .522 .247 r
.31334 .16187 m
.31334 .06936 L
.31669 .06936 L
.31669 .16187 L
s
1 .894 .882 r
.31669 .16187 m
.31669 .07076 L
.3186 .07076 L
.3186 .16187 L
F
.804 .522 .247 r
.31669 .16187 m
.31669 .07076 L
.3186 .07076 L
.3186 .16187 L
s
1 .894 .882 r
.3186 .16187 m
.3186 .07213 L
.32167 .07213 L
.32167 .16187 L
F
.804 .522 .247 r
.3186 .16187 m
.3186 .07213 L
.32167 .07213 L
.32167 .16187 L
s
1 .894 .882 r
.32167 .16187 m
.32167 .07323 L
.32503 .07323 L
.32503 .16187 L
F
.804 .522 .247 r
.32167 .16187 m
.32167 .07323 L
.32503 .07323 L
.32503 .16187 L
s
1 .894 .882 r
.32503 .16187 m
.32503 .07388 L
.3265 .07388 L
.3265 .16187 L
F
.804 .522 .247 r
.32503 .16187 m
.32503 .07388 L
.3265 .07388 L
.3265 .16187 L
s
1 .894 .882 r
.3265 .16187 m
.3265 .07456 L
.32952 .07456 L
.32952 .16187 L
F
.804 .522 .247 r
.3265 .16187 m
.3265 .07456 L
.32952 .07456 L
.32952 .16187 L
s
1 .894 .882 r
.32952 .16187 m
.32952 .07572 L
.33059 .07572 L
.33059 .16187 L
F
.804 .522 .247 r
.32952 .16187 m
.32952 .07572 L
.33059 .07572 L
.33059 .16187 L
s
1 .894 .882 r
.33059 .16187 m
.33059 .07632 L
.33234 .07632 L
.33234 .16187 L
F
.804 .522 .247 r
.33059 .16187 m
.33059 .07632 L
.33234 .07632 L
.33234 .16187 L
s
1 .894 .882 r
.33234 .16187 m
.33234 .07707 L
.33408 .07707 L
.33408 .16187 L
F
.804 .522 .247 r
.33234 .16187 m
.33234 .07707 L
.33408 .07707 L
.33408 .16187 L
s
1 .894 .882 r
.33408 .16187 m
.33408 .07796 L
.33759 .07796 L
.33759 .16187 L
F
.804 .522 .247 r
.33408 .16187 m
.33408 .07796 L
.33759 .07796 L
.33759 .16187 L
s
1 .894 .882 r
.33759 .16187 m
.33759 .07871 L
.33878 .07871 L
.33878 .16187 L
F
.804 .522 .247 r
.33759 .16187 m
.33759 .07871 L
.33878 .07871 L
.33878 .16187 L
s
1 .894 .882 r
.33878 .16187 m
.33878 .07933 L
.3412 .07933 L
.3412 .16187 L
F
.804 .522 .247 r
.33878 .16187 m
.33878 .07933 L
.3412 .07933 L
.3412 .16187 L
s
1 .894 .882 r
.3412 .16187 m
.3412 .08055 L
.34305 .08055 L
.34305 .16187 L
F
.804 .522 .247 r
.3412 .16187 m
.3412 .08055 L
.34305 .08055 L
.34305 .16187 L
s
1 .894 .882 r
.34305 .16187 m
.34305 .08103 L
.34576 .08103 L
.34576 .16187 L
F
.804 .522 .247 r
.34305 .16187 m
.34305 .08103 L
.34576 .08103 L
.34576 .16187 L
s
1 .894 .882 r
.34576 .16187 m
.34576 .08248 L
.3486 .08248 L
.3486 .16187 L
F
.804 .522 .247 r
.34576 .16187 m
.34576 .08248 L
.3486 .08248 L
.3486 .16187 L
s
1 .894 .882 r
.3486 .16187 m
.3486 .08422 L
.35188 .08422 L
.35188 .16187 L
F
.804 .522 .247 r
.3486 .16187 m
.3486 .08422 L
.35188 .08422 L
.35188 .16187 L
s
1 .894 .882 r
.35188 .16187 m
.35188 .085 L
.35381 .085 L
.35381 .16187 L
F
.804 .522 .247 r
.35188 .16187 m
.35188 .085 L
.35381 .085 L
.35381 .16187 L
s
1 .894 .882 r
.35381 .16187 m
.35381 .08586 L
.35517 .08586 L
.35517 .16187 L
F
.804 .522 .247 r
.35381 .16187 m
.35381 .08586 L
.35517 .08586 L
.35517 .16187 L
s
1 .894 .882 r
.35517 .16187 m
.35517 .08646 L
.35652 .08646 L
.35652 .16187 L
F
.804 .522 .247 r
.35517 .16187 m
.35517 .08646 L
.35652 .08646 L
.35652 .16187 L
s
1 .894 .882 r
.35652 .16187 m
.35652 .08724 L
.35869 .08724 L
.35869 .16187 L
F
.804 .522 .247 r
.35652 .16187 m
.35652 .08724 L
.35869 .08724 L
.35869 .16187 L
s
1 .894 .882 r
.35869 .16187 m
.35869 .08798 L
.3606 .08798 L
.3606 .16187 L
F
.804 .522 .247 r
.35869 .16187 m
.35869 .08798 L
.3606 .08798 L
.3606 .16187 L
s
1 .894 .882 r
.3606 .16187 m
.3606 .08901 L
.36253 .08901 L
.36253 .16187 L
F
.804 .522 .247 r
.3606 .16187 m
.3606 .08901 L
.36253 .08901 L
.36253 .16187 L
s
1 .894 .882 r
.36253 .16187 m
.36253 .08985 L
.36465 .08985 L
.36465 .16187 L
F
.804 .522 .247 r
.36253 .16187 m
.36253 .08985 L
.36465 .08985 L
.36465 .16187 L
s
1 .894 .882 r
.36465 .16187 m
.36465 .0912 L
.36791 .0912 L
.36791 .16187 L
F
.804 .522 .247 r
.36465 .16187 m
.36465 .0912 L
.36791 .0912 L
.36791 .16187 L
s
1 .894 .882 r
.36791 .16187 m
.36791 .09192 L
.37 .09192 L
.37 .16187 L
F
.804 .522 .247 r
.36791 .16187 m
.36791 .09192 L
.37 .09192 L
.37 .16187 L
s
1 .894 .882 r
.37 .16187 m
.37 .09263 L
.37108 .09263 L
.37108 .16187 L
F
.804 .522 .247 r
.37 .16187 m
.37 .09263 L
.37108 .09263 L
.37108 .16187 L
s
1 .894 .882 r
.37108 .16187 m
.37108 .09399 L
.37365 .09399 L
.37365 .16187 L
F
.804 .522 .247 r
.37108 .16187 m
.37108 .09399 L
.37365 .09399 L
.37365 .16187 L
s
1 .894 .882 r
.37365 .16187 m
.37365 .0942 L
.37708 .0942 L
.37708 .16187 L
F
.804 .522 .247 r
.37365 .16187 m
.37365 .0942 L
.37708 .0942 L
.37708 .16187 L
s
1 .894 .882 r
.37708 .16187 m
.37708 .0964 L
.37877 .0964 L
.37877 .16187 L
F
.804 .522 .247 r
.37708 .16187 m
.37708 .0964 L
.37877 .0964 L
.37877 .16187 L
s
1 .894 .882 r
.37877 .16187 m
.37877 .09718 L
.38034 .09718 L
.38034 .16187 L
F
.804 .522 .247 r
.37877 .16187 m
.37877 .09718 L
.38034 .09718 L
.38034 .16187 L
s
1 .894 .882 r
.38034 .16187 m
.38034 .09724 L
.38291 .09724 L
.38291 .16187 L
F
.804 .522 .247 r
.38034 .16187 m
.38034 .09724 L
.38291 .09724 L
.38291 .16187 L
s
1 .894 .882 r
.38291 .16187 m
.38291 .09875 L
.38565 .09875 L
.38565 .16187 L
F
.804 .522 .247 r
.38291 .16187 m
.38291 .09875 L
.38565 .09875 L
.38565 .16187 L
s
1 .894 .882 r
.38565 .16187 m
.38565 .09977 L
.38911 .09977 L
.38911 .16187 L
F
.804 .522 .247 r
.38565 .16187 m
.38565 .09977 L
.38911 .09977 L
.38911 .16187 L
s
1 .894 .882 r
.38911 .16187 m
.38911 .10163 L
.39071 .10163 L
.39071 .16187 L
F
.804 .522 .247 r
.38911 .16187 m
.38911 .10163 L
.39071 .10163 L
.39071 .16187 L
s
1 .894 .882 r
.39071 .16187 m
.39071 .10302 L
.39314 .10302 L
.39314 .16187 L
F
.804 .522 .247 r
.39071 .16187 m
.39071 .10302 L
.39314 .10302 L
.39314 .16187 L
s
1 .894 .882 r
.39314 .16187 m
.39314 .10326 L
.39452 .10326 L
.39452 .16187 L
F
.804 .522 .247 r
.39314 .16187 m
.39314 .10326 L
.39452 .10326 L
.39452 .16187 L
s
1 .894 .882 r
.39452 .16187 m
.39452 .10447 L
.3972 .10447 L
.3972 .16187 L
F
.804 .522 .247 r
.39452 .16187 m
.39452 .10447 L
.3972 .10447 L
.3972 .16187 L
s
1 .894 .882 r
.3972 .16187 m
.3972 .10549 L
.39961 .10549 L
.39961 .16187 L
F
.804 .522 .247 r
.3972 .16187 m
.3972 .10549 L
.39961 .10549 L
.39961 .16187 L
s
1 .894 .882 r
.39961 .16187 m
.39961 .10696 L
.40272 .10696 L
.40272 .16187 L
F
.804 .522 .247 r
.39961 .16187 m
.39961 .10696 L
.40272 .10696 L
.40272 .16187 L
s
1 .894 .882 r
.40272 .16187 m
.40272 .10811 L
.40434 .10811 L
.40434 .16187 L
F
.804 .522 .247 r
.40272 .16187 m
.40272 .10811 L
.40434 .10811 L
.40434 .16187 L
s
1 .894 .882 r
.40434 .16187 m
.40434 .1095 L
.40616 .1095 L
.40616 .16187 L
F
.804 .522 .247 r
.40434 .16187 m
.40434 .1095 L
.40616 .1095 L
.40616 .16187 L
s
1 .894 .882 r
.40616 .16187 m
.40616 .11004 L
.40827 .11004 L
.40827 .16187 L
F
.804 .522 .247 r
.40616 .16187 m
.40616 .11004 L
.40827 .11004 L
.40827 .16187 L
s
1 .894 .882 r
.40827 .16187 m
.40827 .11141 L
.41109 .11141 L
.41109 .16187 L
F
.804 .522 .247 r
.40827 .16187 m
.40827 .11141 L
.41109 .11141 L
.41109 .16187 L
s
1 .894 .882 r
.41109 .16187 m
.41109 .11286 L
.41407 .11286 L
.41407 .16187 L
F
.804 .522 .247 r
.41109 .16187 m
.41109 .11286 L
.41407 .11286 L
.41407 .16187 L
s
1 .894 .882 r
.41407 .16187 m
.41407 .11411 L
.4175 .11411 L
.4175 .16187 L
F
.804 .522 .247 r
.41407 .16187 m
.41407 .11411 L
.4175 .11411 L
.4175 .16187 L
s
1 .894 .882 r
.4175 .16187 m
.4175 .11569 L
.41874 .11569 L
.41874 .16187 L
F
.804 .522 .247 r
.4175 .16187 m
.4175 .11569 L
.41874 .11569 L
.41874 .16187 L
s
1 .894 .882 r
.41874 .16187 m
.41874 .11666 L
.42049 .11666 L
.42049 .16187 L
F
.804 .522 .247 r
.41874 .16187 m
.41874 .11666 L
.42049 .11666 L
.42049 .16187 L
s
1 .894 .882 r
.42049 .16187 m
.42049 .11814 L
.42374 .11814 L
.42374 .16187 L
F
.804 .522 .247 r
.42049 .16187 m
.42049 .11814 L
.42374 .11814 L
.42374 .16187 L
s
1 .894 .882 r
.42374 .16187 m
.42374 .11966 L
.42613 .11966 L
.42613 .16187 L
F
.804 .522 .247 r
.42374 .16187 m
.42374 .11966 L
.42613 .11966 L
.42613 .16187 L
s
1 .894 .882 r
.42613 .16187 m
.42613 .11996 L
.42736 .11996 L
.42736 .16187 L
F
.804 .522 .247 r
.42613 .16187 m
.42613 .11996 L
.42736 .11996 L
.42736 .16187 L
s
1 .894 .882 r
.42736 .16187 m
.42736 .12173 L
.43006 .12173 L
.43006 .16187 L
F
.804 .522 .247 r
.42736 .16187 m
.42736 .12173 L
.43006 .12173 L
.43006 .16187 L
s
1 .894 .882 r
.43006 .16187 m
.43006 .12313 L
.43341 .12313 L
.43341 .16187 L
F
.804 .522 .247 r
.43006 .16187 m
.43006 .12313 L
.43341 .12313 L
.43341 .16187 L
s
1 .894 .882 r
.43341 .16187 m
.43341 .12362 L
.43517 .12362 L
.43517 .16187 L
F
.804 .522 .247 r
.43341 .16187 m
.43341 .12362 L
.43517 .12362 L
.43517 .16187 L
s
1 .894 .882 r
.43517 .16187 m
.43517 .12514 L
.43835 .12514 L
.43835 .16187 L
F
.804 .522 .247 r
.43517 .16187 m
.43517 .12514 L
.43835 .12514 L
.43835 .16187 L
s
1 .894 .882 r
.43835 .16187 m
.43835 .12682 L
.43955 .12682 L
.43955 .16187 L
F
.804 .522 .247 r
.43835 .16187 m
.43835 .12682 L
.43955 .12682 L
.43955 .16187 L
s
1 .894 .882 r
.43955 .16187 m
.43955 .12729 L
.44121 .12729 L
.44121 .16187 L
F
.804 .522 .247 r
.43955 .16187 m
.43955 .12729 L
.44121 .12729 L
.44121 .16187 L
s
1 .894 .882 r
.44121 .16187 m
.44121 .12874 L
.44303 .12874 L
.44303 .16187 L
F
.804 .522 .247 r
.44121 .16187 m
.44121 .12874 L
.44303 .12874 L
.44303 .16187 L
s
1 .894 .882 r
.44303 .16187 m
.44303 .13011 L
.44567 .13011 L
.44567 .16187 L
F
.804 .522 .247 r
.44303 .16187 m
.44303 .13011 L
.44567 .13011 L
.44567 .16187 L
s
1 .894 .882 r
.44567 .16187 m
.44567 .13033 L
.44797 .13033 L
.44797 .16187 L
F
.804 .522 .247 r
.44567 .16187 m
.44567 .13033 L
.44797 .13033 L
.44797 .16187 L
s
1 .894 .882 r
.44797 .16187 m
.44797 .13178 L
.44932 .13178 L
.44932 .16187 L
F
.804 .522 .247 r
.44797 .16187 m
.44797 .13178 L
.44932 .13178 L
.44932 .16187 L
s
1 .894 .882 r
.44932 .16187 m
.44932 .13298 L
.45198 .13298 L
.45198 .16187 L
F
.804 .522 .247 r
.44932 .16187 m
.44932 .13298 L
.45198 .13298 L
.45198 .16187 L
s
1 .894 .882 r
.45198 .16187 m
.45198 .13417 L
.45326 .13417 L
.45326 .16187 L
F
.804 .522 .247 r
.45198 .16187 m
.45198 .13417 L
.45326 .13417 L
.45326 .16187 L
s
1 .894 .882 r
.45326 .16187 m
.45326 .13547 L
.45598 .13547 L
.45598 .16187 L
F
.804 .522 .247 r
.45326 .16187 m
.45326 .13547 L
.45598 .13547 L
.45598 .16187 L
s
1 .894 .882 r
.45598 .16187 m
.45598 .13619 L
.45923 .13619 L
.45923 .16187 L
F
.804 .522 .247 r
.45598 .16187 m
.45598 .13619 L
.45923 .13619 L
.45923 .16187 L
s
1 .894 .882 r
.45923 .16187 m
.45923 .13841 L
.46114 .13841 L
.46114 .16187 L
F
.804 .522 .247 r
.45923 .16187 m
.45923 .13841 L
.46114 .13841 L
.46114 .16187 L
s
1 .894 .882 r
.46114 .16187 m
.46114 .1392 L
.46384 .1392 L
.46384 .16187 L
F
.804 .522 .247 r
.46114 .16187 m
.46114 .1392 L
.46384 .1392 L
.46384 .16187 L
s
1 .894 .882 r
.46384 .16187 m
.46384 .14068 L
.46726 .14068 L
.46726 .16187 L
F
.804 .522 .247 r
.46384 .16187 m
.46384 .14068 L
.46726 .14068 L
.46726 .16187 L
s
1 .894 .882 r
.46726 .16187 m
.46726 .14279 L
.46859 .14279 L
.46859 .16187 L
F
.804 .522 .247 r
.46726 .16187 m
.46726 .14279 L
.46859 .14279 L
.46859 .16187 L
s
1 .894 .882 r
.46859 .16187 m
.46859 .14344 L
.4706 .14344 L
.4706 .16187 L
F
.804 .522 .247 r
.46859 .16187 m
.46859 .14344 L
.4706 .14344 L
.4706 .16187 L
s
1 .894 .882 r
.4706 .16187 m
.4706 .14516 L
.47311 .14516 L
.47311 .16187 L
F
.804 .522 .247 r
.4706 .16187 m
.4706 .14516 L
.47311 .14516 L
.47311 .16187 L
s
1 .894 .882 r
.47311 .16187 m
.47311 .14627 L
.47584 .14627 L
.47584 .16187 L
F
.804 .522 .247 r
.47311 .16187 m
.47311 .14627 L
.47584 .14627 L
.47584 .16187 L
s
1 .894 .882 r
.47584 .16187 m
.47584 .14809 L
.47745 .14809 L
.47745 .16187 L
F
.804 .522 .247 r
.47584 .16187 m
.47584 .14809 L
.47745 .14809 L
.47745 .16187 L
s
1 .894 .882 r
.47745 .16187 m
.47745 .14894 L
.48059 .14894 L
.48059 .16187 L
F
.804 .522 .247 r
.47745 .16187 m
.47745 .14894 L
.48059 .14894 L
.48059 .16187 L
s
1 .894 .882 r
.48059 .16187 m
.48059 .15053 L
.48294 .15053 L
.48294 .16187 L
F
.804 .522 .247 r
.48059 .16187 m
.48059 .15053 L
.48294 .15053 L
.48294 .16187 L
s
1 .894 .882 r
.48294 .16187 m
.48294 .15177 L
.48402 .15177 L
.48402 .16187 L
F
.804 .522 .247 r
.48294 .16187 m
.48294 .15177 L
.48402 .15177 L
.48402 .16187 L
s
1 .894 .882 r
.48402 .16187 m
.48402 .15224 L
.48581 .15224 L
.48581 .16187 L
F
.804 .522 .247 r
.48402 .16187 m
.48402 .15224 L
.48581 .15224 L
.48581 .16187 L
s
1 .894 .882 r
.48581 .16187 m
.48581 .15372 L
.48825 .15372 L
.48825 .16187 L
F
.804 .522 .247 r
.48581 .16187 m
.48581 .15372 L
.48825 .15372 L
.48825 .16187 L
s
1 .894 .882 r
.48825 .16187 m
.48825 .15621 L
.49094 .15621 L
.49094 .16187 L
F
.804 .522 .247 r
.48825 .16187 m
.48825 .15621 L
.49094 .15621 L
.49094 .16187 L
s
1 .894 .882 r
.49094 .16187 m
.49094 .15733 L
.49435 .15733 L
.49435 .16187 L
F
.804 .522 .247 r
.49094 .16187 m
.49094 .15733 L
.49435 .15733 L
.49435 .16187 L
s
1 .894 .882 r
.49435 .16187 m
.49435 .15884 L
.49553 .15884 L
.49553 .16187 L
F
.804 .522 .247 r
.49435 .16187 m
.49435 .15884 L
.49553 .15884 L
.49553 .16187 L
s
1 .894 .882 r
.49553 .16187 m
.49553 .15949 L
.49721 .15949 L
.49721 .16187 L
F
.804 .522 .247 r
.49553 .16187 m
.49553 .15949 L
.49721 .15949 L
.49721 .16187 L
s
1 .894 .882 r
.49721 .16187 m
.49721 .16083 L
.49833 .16083 L
.49833 .16187 L
F
.804 .522 .247 r
.49721 .16187 m
.49721 .16083 L
.49833 .16083 L
.49833 .16187 L
s
1 .894 .882 r
.49833 .16187 m
.49833 .16135 L
.50049 .16135 L
.50049 .16187 L
F
.804 .522 .247 r
.49833 .16187 m
.49833 .16135 L
.50049 .16135 L
.50049 .16187 L
s
.678 .847 .902 r
.50049 .16187 m
.50049 .16257 L
.50386 .16257 L
.50386 .16187 L
F
.2 .63 .79 r
.50049 .16187 m
.50049 .16257 L
.50386 .16257 L
.50386 .16187 L
s
.678 .847 .902 r
.50386 .16187 m
.50386 .16559 L
.50639 .16559 L
.50639 .16187 L
F
.2 .63 .79 r
.50386 .16187 m
.50386 .16559 L
.50639 .16559 L
.50639 .16187 L
s
.678 .847 .902 r
.50639 .16187 m
.50639 .16651 L
.50975 .16651 L
.50975 .16187 L
F
.2 .63 .79 r
.50639 .16187 m
.50639 .16651 L
.50975 .16651 L
.50975 .16187 L
s
.678 .847 .902 r
.50975 .16187 m
.50975 .16923 L
.51273 .16923 L
.51273 .16187 L
F
.2 .63 .79 r
.50975 .16187 m
.50975 .16923 L
.51273 .16923 L
.51273 .16187 L
s
.678 .847 .902 r
.51273 .16187 m
.51273 .16987 L
.5139 .16987 L
.5139 .16187 L
F
.2 .63 .79 r
.51273 .16187 m
.51273 .16987 L
.5139 .16987 L
.5139 .16187 L
s
.678 .847 .902 r
.5139 .16187 m
.5139 .17082 L
.51558 .17082 L
.51558 .16187 L
F
.2 .63 .79 r
.5139 .16187 m
.5139 .17082 L
.51558 .17082 L
.51558 .16187 L
s
.678 .847 .902 r
.51558 .16187 m
.51558 .17173 L
.51731 .17173 L
.51731 .16187 L
F
.2 .63 .79 r
.51558 .16187 m
.51558 .17173 L
.51731 .17173 L
.51731 .16187 L
s
.678 .847 .902 r
.51731 .16187 m
.51731 .17378 L
.52039 .17378 L
.52039 .16187 L
F
.2 .63 .79 r
.51731 .16187 m
.51731 .17378 L
.52039 .17378 L
.52039 .16187 L
s
.678 .847 .902 r
.52039 .16187 m
.52039 .17568 L
.52376 .17568 L
.52376 .16187 L
F
.2 .63 .79 r
.52039 .16187 m
.52039 .17568 L
.52376 .17568 L
.52376 .16187 L
s
.678 .847 .902 r
.52376 .16187 m
.52376 .17885 L
.52696 .17885 L
.52696 .16187 L
F
.2 .63 .79 r
.52376 .16187 m
.52376 .17885 L
.52696 .17885 L
.52696 .16187 L
s
.678 .847 .902 r
.52696 .16187 m
.52696 .1798 L
.5297 .1798 L
.5297 .16187 L
F
.2 .63 .79 r
.52696 .16187 m
.52696 .1798 L
.5297 .1798 L
.5297 .16187 L
s
.678 .847 .902 r
.5297 .16187 m
.5297 .18095 L
.53111 .18095 L
.53111 .16187 L
F
.2 .63 .79 r
.5297 .16187 m
.5297 .18095 L
.53111 .18095 L
.53111 .16187 L
s
.678 .847 .902 r
.53111 .16187 m
.53111 .18285 L
.53392 .18285 L
.53392 .16187 L
F
.2 .63 .79 r
.53111 .16187 m
.53111 .18285 L
.53392 .18285 L
.53392 .16187 L
s
.678 .847 .902 r
.53392 .16187 m
.53392 .18399 L
.53504 .18399 L
.53504 .16187 L
F
.2 .63 .79 r
.53392 .16187 m
.53392 .18399 L
.53504 .18399 L
.53504 .16187 L
s
.678 .847 .902 r
.53504 .16187 m
.53504 .18447 L
.5365 .18447 L
.5365 .16187 L
F
.2 .63 .79 r
.53504 .16187 m
.53504 .18447 L
.5365 .18447 L
.5365 .16187 L
s
.678 .847 .902 r
.5365 .16187 m
.5365 .18599 L
.53788 .18599 L
.53788 .16187 L
F
.2 .63 .79 r
.5365 .16187 m
.5365 .18599 L
.53788 .18599 L
.53788 .16187 L
s
.678 .847 .902 r
.53788 .16187 m
.53788 .18694 L
.53996 .18694 L
.53996 .16187 L
F
.2 .63 .79 r
.53788 .16187 m
.53788 .18694 L
.53996 .18694 L
.53996 .16187 L
s
.678 .847 .902 r
.53996 .16187 m
.53996 .18793 L
.54217 .18793 L
.54217 .16187 L
F
.2 .63 .79 r
.53996 .16187 m
.53996 .18793 L
.54217 .18793 L
.54217 .16187 L
s
.678 .847 .902 r
.54217 .16187 m
.54217 .18942 L
.54446 .18942 L
.54446 .16187 L
F
.2 .63 .79 r
.54217 .16187 m
.54217 .18942 L
.54446 .18942 L
.54446 .16187 L
s
.678 .847 .902 r
.54446 .16187 m
.54446 .19091 L
.54596 .19091 L
.54596 .16187 L
F
.2 .63 .79 r
.54446 .16187 m
.54446 .19091 L
.54596 .19091 L
.54596 .16187 L
s
.678 .847 .902 r
.54596 .16187 m
.54596 .19284 L
.54791 .19284 L
.54791 .16187 L
F
.2 .63 .79 r
.54596 .16187 m
.54596 .19284 L
.54791 .19284 L
.54791 .16187 L
s
.678 .847 .902 r
.54791 .16187 m
.54791 .1939 L
.5495 .1939 L
.5495 .16187 L
F
.2 .63 .79 r
.54791 .16187 m
.54791 .1939 L
.5495 .1939 L
.5495 .16187 L
s
.678 .847 .902 r
.5495 .16187 m
.5495 .19439 L
.55173 .19439 L
.55173 .16187 L
F
.2 .63 .79 r
.5495 .16187 m
.5495 .19439 L
.55173 .19439 L
.55173 .16187 L
s
.678 .847 .902 r
.55173 .16187 m
.55173 .19733 L
.55459 .19733 L
.55459 .16187 L
F
.2 .63 .79 r
.55173 .16187 m
.55173 .19733 L
.55459 .19733 L
.55459 .16187 L
s
.678 .847 .902 r
.55459 .16187 m
.55459 .19859 L
.55671 .19859 L
.55671 .16187 L
F
.2 .63 .79 r
.55459 .16187 m
.55459 .19859 L
.55671 .19859 L
.55671 .16187 L
s
.678 .847 .902 r
.55671 .16187 m
.55671 .19904 L
.5593 .19904 L
.5593 .16187 L
F
.2 .63 .79 r
.55671 .16187 m
.55671 .19904 L
.5593 .19904 L
.5593 .16187 L
s
.678 .847 .902 r
.5593 .16187 m
.5593 .2023 L
.56169 .2023 L
.56169 .16187 L
F
.2 .63 .79 r
.5593 .16187 m
.5593 .2023 L
.56169 .2023 L
.56169 .16187 L
s
.678 .847 .902 r
.56169 .16187 m
.56169 .20298 L
.5651 .20298 L
.5651 .16187 L
F
.2 .63 .79 r
.56169 .16187 m
.56169 .20298 L
.5651 .20298 L
.5651 .16187 L
s
.678 .847 .902 r
.5651 .16187 m
.5651 .2058 L
.56711 .2058 L
.56711 .16187 L
F
.2 .63 .79 r
.5651 .16187 m
.5651 .2058 L
.56711 .2058 L
.56711 .16187 L
s
.678 .847 .902 r
.56711 .16187 m
.56711 .20736 L
.56907 .20736 L
.56907 .16187 L
F
.2 .63 .79 r
.56711 .16187 m
.56711 .20736 L
.56907 .20736 L
.56907 .16187 L
s
.678 .847 .902 r
.56907 .16187 m
.56907 .20866 L
.57079 .20866 L
.57079 .16187 L
F
.2 .63 .79 r
.56907 .16187 m
.56907 .20866 L
.57079 .20866 L
.57079 .16187 L
s
.678 .847 .902 r
.57079 .16187 m
.57079 .20956 L
.57218 .20956 L
.57218 .16187 L
F
.2 .63 .79 r
.57079 .16187 m
.57079 .20956 L
.57218 .20956 L
.57218 .16187 L
s
.678 .847 .902 r
.57218 .16187 m
.57218 .21022 L
.57435 .21022 L
.57435 .16187 L
F
.2 .63 .79 r
.57218 .16187 m
.57218 .21022 L
.57435 .21022 L
.57435 .16187 L
s
.678 .847 .902 r
.57435 .16187 m
.57435 .21282 L
.57663 .21282 L
.57663 .16187 L
F
.2 .63 .79 r
.57435 .16187 m
.57435 .21282 L
.57663 .21282 L
.57663 .16187 L
s
.678 .847 .902 r
.57663 .16187 m
.57663 .21373 L
.57913 .21373 L
.57913 .16187 L
F
.2 .63 .79 r
.57663 .16187 m
.57663 .21373 L
.57913 .21373 L
.57913 .16187 L
s
.678 .847 .902 r
.57913 .16187 m
.57913 .21618 L
.58264 .21618 L
.58264 .16187 L
F
.2 .63 .79 r
.57913 .16187 m
.57913 .21618 L
.58264 .21618 L
.58264 .16187 L
s
.678 .847 .902 r
.58264 .16187 m
.58264 .21869 L
.58553 .21869 L
.58553 .16187 L
F
.2 .63 .79 r
.58264 .16187 m
.58264 .21869 L
.58553 .21869 L
.58553 .16187 L
s
.678 .847 .902 r
.58553 .16187 m
.58553 .21997 L
.58775 .21997 L
.58775 .16187 L
F
.2 .63 .79 r
.58553 .16187 m
.58553 .21997 L
.58775 .21997 L
.58775 .16187 L
s
.678 .847 .902 r
.58775 .16187 m
.58775 .22146 L
.58986 .22146 L
.58986 .16187 L
F
.2 .63 .79 r
.58775 .16187 m
.58775 .22146 L
.58986 .22146 L
.58986 .16187 L
s
.678 .847 .902 r
.58986 .16187 m
.58986 .22443 L
.59304 .22443 L
.59304 .16187 L
F
.2 .63 .79 r
.58986 .16187 m
.58986 .22443 L
.59304 .22443 L
.59304 .16187 L
s
.678 .847 .902 r
.59304 .16187 m
.59304 .22512 L
.5949 .22512 L
.5949 .16187 L
F
.2 .63 .79 r
.59304 .16187 m
.59304 .22512 L
.5949 .22512 L
.5949 .16187 L
s
.678 .847 .902 r
.5949 .16187 m
.5949 .22643 L
.59598 .22643 L
.59598 .16187 L
F
.2 .63 .79 r
.5949 .16187 m
.5949 .22643 L
.59598 .22643 L
.59598 .16187 L
s
.678 .847 .902 r
.59598 .16187 m
.59598 .2272 L
.59932 .2272 L
.59932 .16187 L
F
.2 .63 .79 r
.59598 .16187 m
.59598 .2272 L
.59932 .2272 L
.59932 .16187 L
s
.678 .847 .902 r
.59932 .16187 m
.59932 .23064 L
.60206 .23064 L
.60206 .16187 L
F
.2 .63 .79 r
.59932 .16187 m
.59932 .23064 L
.60206 .23064 L
.60206 .16187 L
s
.678 .847 .902 r
.60206 .16187 m
.60206 .2322 L
.60549 .2322 L
.60549 .16187 L
F
.2 .63 .79 r
.60206 .16187 m
.60206 .2322 L
.60549 .2322 L
.60549 .16187 L
s
.678 .847 .902 r
.60549 .16187 m
.60549 .2348 L
.6085 .2348 L
.6085 .16187 L
F
.2 .63 .79 r
.60549 .16187 m
.60549 .2348 L
.6085 .2348 L
.6085 .16187 L
s
.678 .847 .902 r
.6085 .16187 m
.6085 .23787 L
.61067 .23787 L
.61067 .16187 L
F
.2 .63 .79 r
.6085 .16187 m
.6085 .23787 L
.61067 .23787 L
.61067 .16187 L
s
.678 .847 .902 r
.61067 .16187 m
.61067 .23974 L
.61408 .23974 L
.61408 .16187 L
F
.2 .63 .79 r
.61067 .16187 m
.61067 .23974 L
.61408 .23974 L
.61408 .16187 L
s
.678 .847 .902 r
.61408 .16187 m
.61408 .24169 L
.61644 .24169 L
.61644 .16187 L
F
.2 .63 .79 r
.61408 .16187 m
.61408 .24169 L
.61644 .24169 L
.61644 .16187 L
s
.678 .847 .902 r
.61644 .16187 m
.61644 .24287 L
.61794 .24287 L
.61794 .16187 L
F
.2 .63 .79 r
.61644 .16187 m
.61644 .24287 L
.61794 .24287 L
.61794 .16187 L
s
.678 .847 .902 r
.61794 .16187 m
.61794 .24605 L
.62125 .24605 L
.62125 .16187 L
F
.2 .63 .79 r
.61794 .16187 m
.61794 .24605 L
.62125 .24605 L
.62125 .16187 L
s
.678 .847 .902 r
.62125 .16187 m
.62125 .24735 L
.62477 .24735 L
.62477 .16187 L
F
.2 .63 .79 r
.62125 .16187 m
.62125 .24735 L
.62477 .24735 L
.62477 .16187 L
s
.678 .847 .902 r
.62477 .16187 m
.62477 .24997 L
.62618 .24997 L
.62618 .16187 L
F
.2 .63 .79 r
.62477 .16187 m
.62477 .24997 L
.62618 .24997 L
.62618 .16187 L
s
.678 .847 .902 r
.62618 .16187 m
.62618 .25117 L
.62924 .25117 L
.62924 .16187 L
F
.2 .63 .79 r
.62618 .16187 m
.62618 .25117 L
.62924 .25117 L
.62924 .16187 L
s
.678 .847 .902 r
.62924 .16187 m
.62924 .25269 L
.63189 .25269 L
.63189 .16187 L
F
.2 .63 .79 r
.62924 .16187 m
.62924 .25269 L
.63189 .25269 L
.63189 .16187 L
s
.678 .847 .902 r
.63189 .16187 m
.63189 .25635 L
.63508 .25635 L
.63508 .16187 L
F
.2 .63 .79 r
.63189 .16187 m
.63189 .25635 L
.63508 .25635 L
.63508 .16187 L
s
.678 .847 .902 r
.63508 .16187 m
.63508 .25845 L
.63784 .25845 L
.63784 .16187 L
F
.2 .63 .79 r
.63508 .16187 m
.63508 .25845 L
.63784 .25845 L
.63784 .16187 L
s
.678 .847 .902 r
.63784 .16187 m
.63784 .26019 L
.63968 .26019 L
.63968 .16187 L
F
.2 .63 .79 r
.63784 .16187 m
.63784 .26019 L
.63968 .26019 L
.63968 .16187 L
s
.678 .847 .902 r
.63968 .16187 m
.63968 .26149 L
.64088 .26149 L
.64088 .16187 L
F
.2 .63 .79 r
.63968 .16187 m
.63968 .26149 L
.64088 .26149 L
.64088 .16187 L
s
.678 .847 .902 r
.64088 .16187 m
.64088 .26217 L
.64409 .26217 L
.64409 .16187 L
F
.2 .63 .79 r
.64088 .16187 m
.64088 .26217 L
.64409 .26217 L
.64409 .16187 L
s
.678 .847 .902 r
.64409 .16187 m
.64409 .267 L
.6475 .267 L
.6475 .16187 L
F
.2 .63 .79 r
.64409 .16187 m
.64409 .267 L
.6475 .267 L
.6475 .16187 L
s
.678 .847 .902 r
.6475 .16187 m
.6475 .26776 L
.65064 .26776 L
.65064 .16187 L
F
.2 .63 .79 r
.6475 .16187 m
.6475 .26776 L
.65064 .26776 L
.65064 .16187 L
s
.678 .847 .902 r
.65064 .16187 m
.65064 .27061 L
.65326 .27061 L
.65326 .16187 L
F
.2 .63 .79 r
.65064 .16187 m
.65064 .27061 L
.65326 .27061 L
.65326 .16187 L
s
.678 .847 .902 r
.65326 .16187 m
.65326 .27216 L
.65434 .27216 L
.65434 .16187 L
F
.2 .63 .79 r
.65326 .16187 m
.65326 .27216 L
.65434 .27216 L
.65434 .16187 L
s
.678 .847 .902 r
.65434 .16187 m
.65434 .27453 L
.65695 .27453 L
.65695 .16187 L
F
.2 .63 .79 r
.65434 .16187 m
.65434 .27453 L
.65695 .27453 L
.65695 .16187 L
s
.678 .847 .902 r
.65695 .16187 m
.65695 .27527 L
.66007 .27527 L
.66007 .16187 L
F
.2 .63 .79 r
.65695 .16187 m
.65695 .27527 L
.66007 .27527 L
.66007 .16187 L
s
.678 .847 .902 r
.66007 .16187 m
.66007 .27839 L
.66288 .27839 L
.66288 .16187 L
F
.2 .63 .79 r
.66007 .16187 m
.66007 .27839 L
.66288 .27839 L
.66288 .16187 L
s
.678 .847 .902 r
.66288 .16187 m
.66288 .28113 L
.66474 .28113 L
.66474 .16187 L
F
.2 .63 .79 r
.66288 .16187 m
.66288 .28113 L
.66474 .28113 L
.66474 .16187 L
s
.678 .847 .902 r
.66474 .16187 m
.66474 .28277 L
.66746 .28277 L
.66746 .16187 L
F
.2 .63 .79 r
.66474 .16187 m
.66474 .28277 L
.66746 .28277 L
.66746 .16187 L
s
.678 .847 .902 r
.66746 .16187 m
.66746 .28446 L
.66862 .28446 L
.66862 .16187 L
F
.2 .63 .79 r
.66746 .16187 m
.66746 .28446 L
.66862 .28446 L
.66862 .16187 L
s
.678 .847 .902 r
.66862 .16187 m
.66862 .28541 L
.67031 .28541 L
.67031 .16187 L
F
.2 .63 .79 r
.66862 .16187 m
.66862 .28541 L
.67031 .28541 L
.67031 .16187 L
s
.678 .847 .902 r
.67031 .16187 m
.67031 .28645 L
.6723 .28645 L
.6723 .16187 L
F
.2 .63 .79 r
.67031 .16187 m
.67031 .28645 L
.6723 .28645 L
.6723 .16187 L
s
.678 .847 .902 r
.6723 .16187 m
.6723 .28782 L
.67371 .28782 L
.67371 .16187 L
F
.2 .63 .79 r
.6723 .16187 m
.6723 .28782 L
.67371 .28782 L
.67371 .16187 L
s
.678 .847 .902 r
.67371 .16187 m
.67371 .29075 L
.6769 .29075 L
.6769 .16187 L
F
.2 .63 .79 r
.67371 .16187 m
.67371 .29075 L
.6769 .29075 L
.6769 .16187 L
s
.678 .847 .902 r
.6769 .16187 m
.6769 .2927 L
.67881 .2927 L
.67881 .16187 L
F
.2 .63 .79 r
.6769 .16187 m
.6769 .2927 L
.67881 .2927 L
.67881 .16187 L
s
.678 .847 .902 r
.67881 .16187 m
.67881 .29471 L
.6808 .29471 L
.6808 .16187 L
F
.2 .63 .79 r
.67881 .16187 m
.67881 .29471 L
.6808 .29471 L
.6808 .16187 L
s
.678 .847 .902 r
.6808 .16187 m
.6808 .29514 L
.68186 .29514 L
.68186 .16187 L
F
.2 .63 .79 r
.6808 .16187 m
.6808 .29514 L
.68186 .29514 L
.68186 .16187 L
s
.678 .847 .902 r
.68186 .16187 m
.68186 .29603 L
.68304 .29603 L
.68304 .16187 L
F
.2 .63 .79 r
.68186 .16187 m
.68186 .29603 L
.68304 .29603 L
.68304 .16187 L
s
.678 .847 .902 r
.68304 .16187 m
.68304 .29837 L
.68584 .29837 L
.68584 .16187 L
F
.2 .63 .79 r
.68304 .16187 m
.68304 .29837 L
.68584 .29837 L
.68584 .16187 L
s
.678 .847 .902 r
.68584 .16187 m
.68584 .29967 L
.68816 .29967 L
.68816 .16187 L
F
.2 .63 .79 r
.68584 .16187 m
.68584 .29967 L
.68816 .29967 L
.68816 .16187 L
s
.678 .847 .902 r
.68816 .16187 m
.68816 .30237 L
.68998 .30237 L
.68998 .16187 L
F
.2 .63 .79 r
.68816 .16187 m
.68816 .30237 L
.68998 .30237 L
.68998 .16187 L
s
.678 .847 .902 r
.68998 .16187 m
.68998 .30459 L
.69286 .30459 L
.69286 .16187 L
F
.2 .63 .79 r
.68998 .16187 m
.68998 .30459 L
.69286 .30459 L
.69286 .16187 L
s
.678 .847 .902 r
.69286 .16187 m
.69286 .30524 L
.69551 .30524 L
.69551 .16187 L
F
.2 .63 .79 r
.69286 .16187 m
.69286 .30524 L
.69551 .30524 L
.69551 .16187 L
s
.678 .847 .902 r
.69551 .16187 m
.69551 .3078 L
.69815 .3078 L
.69815 .16187 L
F
.2 .63 .79 r
.69551 .16187 m
.69551 .3078 L
.69815 .3078 L
.69815 .16187 L
s
.678 .847 .902 r
.69815 .16187 m
.69815 .31123 L
.70008 .31123 L
.70008 .16187 L
F
.2 .63 .79 r
.69815 .16187 m
.69815 .31123 L
.70008 .31123 L
.70008 .16187 L
s
.678 .847 .902 r
.70008 .16187 m
.70008 .31298 L
.70335 .31298 L
.70335 .16187 L
F
.2 .63 .79 r
.70008 .16187 m
.70008 .31298 L
.70335 .31298 L
.70335 .16187 L
s
.678 .847 .902 r
.70335 .16187 m
.70335 .31494 L
.70444 .31494 L
.70444 .16187 L
F
.2 .63 .79 r
.70335 .16187 m
.70335 .31494 L
.70444 .31494 L
.70444 .16187 L
s
.678 .847 .902 r
.70444 .16187 m
.70444 .31709 L
.70705 .31709 L
.70705 .16187 L
F
.2 .63 .79 r
.70444 .16187 m
.70444 .31709 L
.70705 .31709 L
.70705 .16187 L
s
.678 .847 .902 r
.70705 .16187 m
.70705 .32017 L
.7099 .32017 L
.7099 .16187 L
F
.2 .63 .79 r
.70705 .16187 m
.70705 .32017 L
.7099 .32017 L
.7099 .16187 L
s
.678 .847 .902 r
.7099 .16187 m
.7099 .32057 L
.71111 .32057 L
.71111 .16187 L
F
.2 .63 .79 r
.7099 .16187 m
.7099 .32057 L
.71111 .32057 L
.71111 .16187 L
s
.678 .847 .902 r
.71111 .16187 m
.71111 .32154 L
.71292 .32154 L
.71292 .16187 L
F
.2 .63 .79 r
.71111 .16187 m
.71111 .32154 L
.71292 .32154 L
.71292 .16187 L
s
.678 .847 .902 r
.71292 .16187 m
.71292 .32428 L
.71472 .32428 L
.71472 .16187 L
F
.2 .63 .79 r
.71292 .16187 m
.71292 .32428 L
.71472 .32428 L
.71472 .16187 L
s
.678 .847 .902 r
.71472 .16187 m
.71472 .32486 L
.71592 .32486 L
.71592 .16187 L
F
.2 .63 .79 r
.71472 .16187 m
.71472 .32486 L
.71592 .32486 L
.71592 .16187 L
s
.678 .847 .902 r
.71592 .16187 m
.71592 .32599 L
.71703 .32599 L
.71703 .16187 L
F
.2 .63 .79 r
.71592 .16187 m
.71592 .32599 L
.71703 .32599 L
.71703 .16187 L
s
.678 .847 .902 r
.71703 .16187 m
.71703 .32714 L
.7182 .32714 L
.7182 .16187 L
F
.2 .63 .79 r
.71703 .16187 m
.71703 .32714 L
.7182 .32714 L
.7182 .16187 L
s
.678 .847 .902 r
.7182 .16187 m
.7182 .32932 L
.72155 .32932 L
.72155 .16187 L
F
.2 .63 .79 r
.7182 .16187 m
.7182 .32932 L
.72155 .32932 L
.72155 .16187 L
s
.678 .847 .902 r
.72155 .16187 m
.72155 .33116 L
.72486 .33116 L
.72486 .16187 L
F
.2 .63 .79 r
.72155 .16187 m
.72155 .33116 L
.72486 .33116 L
.72486 .16187 L
s
.678 .847 .902 r
.72486 .16187 m
.72486 .33457 L
.72631 .33457 L
.72631 .16187 L
F
.2 .63 .79 r
.72486 .16187 m
.72486 .33457 L
.72631 .33457 L
.72631 .16187 L
s
.678 .847 .902 r
.72631 .16187 m
.72631 .33702 L
.72909 .33702 L
.72909 .16187 L
F
.2 .63 .79 r
.72631 .16187 m
.72631 .33702 L
.72909 .33702 L
.72909 .16187 L
s
.678 .847 .902 r
.72909 .16187 m
.72909 .3389 L
.73151 .3389 L
.73151 .16187 L
F
.2 .63 .79 r
.72909 .16187 m
.72909 .3389 L
.73151 .3389 L
.73151 .16187 L
s
.678 .847 .902 r
.73151 .16187 m
.73151 .3422 L
.73482 .3422 L
.73482 .16187 L
F
.2 .63 .79 r
.73151 .16187 m
.73151 .3422 L
.73482 .3422 L
.73482 .16187 L
s
.678 .847 .902 r
.73482 .16187 m
.73482 .34325 L
.73614 .34325 L
.73614 .16187 L
F
.2 .63 .79 r
.73482 .16187 m
.73482 .34325 L
.73614 .34325 L
.73614 .16187 L
s
.678 .847 .902 r
.73614 .16187 m
.73614 .3444 L
.73965 .3444 L
.73965 .16187 L
F
.2 .63 .79 r
.73614 .16187 m
.73614 .3444 L
.73965 .3444 L
.73965 .16187 L
s
.678 .847 .902 r
.73965 .16187 m
.73965 .34763 L
.74081 .34763 L
.74081 .16187 L
F
.2 .63 .79 r
.73965 .16187 m
.73965 .34763 L
.74081 .34763 L
.74081 .16187 L
s
.678 .847 .902 r
.74081 .16187 m
.74081 .34838 L
.74336 .34838 L
.74336 .16187 L
F
.2 .63 .79 r
.74081 .16187 m
.74081 .34838 L
.74336 .34838 L
.74336 .16187 L
s
.678 .847 .902 r
.74336 .16187 m
.74336 .35186 L
.74532 .35186 L
.74532 .16187 L
F
.2 .63 .79 r
.74336 .16187 m
.74336 .35186 L
.74532 .35186 L
.74532 .16187 L
s
.678 .847 .902 r
.74532 .16187 m
.74532 .35273 L
.74724 .35273 L
.74724 .16187 L
F
.2 .63 .79 r
.74532 .16187 m
.74532 .35273 L
.74724 .35273 L
.74724 .16187 L
s
.678 .847 .902 r
.74724 .16187 m
.74724 .35478 L
.74929 .35478 L
.74929 .16187 L
F
.2 .63 .79 r
.74724 .16187 m
.74724 .35478 L
.74929 .35478 L
.74929 .16187 L
s
.678 .847 .902 r
.74929 .16187 m
.74929 .35655 L
.75096 .35655 L
.75096 .16187 L
F
.2 .63 .79 r
.74929 .16187 m
.74929 .35655 L
.75096 .35655 L
.75096 .16187 L
s
.678 .847 .902 r
.75096 .16187 m
.75096 .35808 L
.75318 .35808 L
.75318 .16187 L
F
.2 .63 .79 r
.75096 .16187 m
.75096 .35808 L
.75318 .35808 L
.75318 .16187 L
s
.678 .847 .902 r
.75318 .16187 m
.75318 .36088 L
.75508 .36088 L
.75508 .16187 L
F
.2 .63 .79 r
.75318 .16187 m
.75318 .36088 L
.75508 .36088 L
.75508 .16187 L
s
.678 .847 .902 r
.75508 .16187 m
.75508 .36305 L
.75804 .36305 L
.75804 .16187 L
F
.2 .63 .79 r
.75508 .16187 m
.75508 .36305 L
.75804 .36305 L
.75804 .16187 L
s
.678 .847 .902 r
.75804 .16187 m
.75804 .36497 L
.76038 .36497 L
.76038 .16187 L
F
.2 .63 .79 r
.75804 .16187 m
.75804 .36497 L
.76038 .36497 L
.76038 .16187 L
s
.678 .847 .902 r
.76038 .16187 m
.76038 .36829 L
.76245 .36829 L
.76245 .16187 L
F
.2 .63 .79 r
.76038 .16187 m
.76038 .36829 L
.76245 .36829 L
.76245 .16187 L
s
.678 .847 .902 r
.76245 .16187 m
.76245 .36916 L
.7636 .36916 L
.7636 .16187 L
F
.2 .63 .79 r
.76245 .16187 m
.76245 .36916 L
.7636 .36916 L
.7636 .16187 L
s
.678 .847 .902 r
.7636 .16187 m
.7636 .37115 L
.76581 .37115 L
.76581 .16187 L
F
.2 .63 .79 r
.7636 .16187 m
.7636 .37115 L
.76581 .37115 L
.76581 .16187 L
s
.678 .847 .902 r
.76581 .16187 m
.76581 .37379 L
.76802 .37379 L
.76802 .16187 L
F
.2 .63 .79 r
.76581 .16187 m
.76581 .37379 L
.76802 .37379 L
.76802 .16187 L
s
.678 .847 .902 r
.76802 .16187 m
.76802 .37478 L
.77004 .37478 L
.77004 .16187 L
F
.2 .63 .79 r
.76802 .16187 m
.76802 .37478 L
.77004 .37478 L
.77004 .16187 L
s
.678 .847 .902 r
.77004 .16187 m
.77004 .37882 L
.77355 .37882 L
.77355 .16187 L
F
.2 .63 .79 r
.77004 .16187 m
.77004 .37882 L
.77355 .37882 L
.77355 .16187 L
s
.678 .847 .902 r
.77355 .16187 m
.77355 .37957 L
.77593 .37957 L
.77593 .16187 L
F
.2 .63 .79 r
.77355 .16187 m
.77355 .37957 L
.77593 .37957 L
.77593 .16187 L
s
.678 .847 .902 r
.77593 .16187 m
.77593 .38339 L
.77835 .38339 L
.77835 .16187 L
F
.2 .63 .79 r
.77593 .16187 m
.77593 .38339 L
.77835 .38339 L
.77835 .16187 L
s
.678 .847 .902 r
.77835 .16187 m
.77835 .3852 L
.77998 .3852 L
.77998 .16187 L
F
.2 .63 .79 r
.77835 .16187 m
.77835 .3852 L
.77998 .3852 L
.77998 .16187 L
s
.678 .847 .902 r
.77998 .16187 m
.77998 .38752 L
.78177 .38752 L
.78177 .16187 L
F
.2 .63 .79 r
.77998 .16187 m
.77998 .38752 L
.78177 .38752 L
.78177 .16187 L
s
.678 .847 .902 r
.78177 .16187 m
.78177 .38894 L
.78526 .38894 L
.78526 .16187 L
F
.2 .63 .79 r
.78177 .16187 m
.78177 .38894 L
.78526 .38894 L
.78526 .16187 L
s
.678 .847 .902 r
.78526 .16187 m
.78526 .39321 L
.78789 .39321 L
.78789 .16187 L
F
.2 .63 .79 r
.78526 .16187 m
.78526 .39321 L
.78789 .39321 L
.78789 .16187 L
s
.678 .847 .902 r
.78789 .16187 m
.78789 .39392 L
.78927 .39392 L
.78927 .16187 L
F
.2 .63 .79 r
.78789 .16187 m
.78789 .39392 L
.78927 .39392 L
.78927 .16187 L
s
.678 .847 .902 r
.78927 .16187 m
.78927 .3965 L
.79107 .3965 L
.79107 .16187 L
F
.2 .63 .79 r
.78927 .16187 m
.78927 .3965 L
.79107 .3965 L
.79107 .16187 L
s
.678 .847 .902 r
.79107 .16187 m
.79107 .39691 L
.79445 .39691 L
.79445 .16187 L
F
.2 .63 .79 r
.79107 .16187 m
.79107 .39691 L
.79445 .39691 L
.79445 .16187 L
s
.678 .847 .902 r
.79445 .16187 m
.79445 .40107 L
.7956 .40107 L
.7956 .16187 L
F
.2 .63 .79 r
.79445 .16187 m
.79445 .40107 L
.7956 .40107 L
.7956 .16187 L
s
.678 .847 .902 r
.7956 .16187 m
.7956 .40308 L
.79854 .40308 L
.79854 .16187 L
F
.2 .63 .79 r
.7956 .16187 m
.7956 .40308 L
.79854 .40308 L
.79854 .16187 L
s
.678 .847 .902 r
.79854 .16187 m
.79854 .40682 L
.80195 .40682 L
.80195 .16187 L
F
.2 .63 .79 r
.79854 .16187 m
.79854 .40682 L
.80195 .40682 L
.80195 .16187 L
s
.678 .847 .902 r
.80195 .16187 m
.80195 .40964 L
.80434 .40964 L
.80434 .16187 L
F
.2 .63 .79 r
.80195 .16187 m
.80195 .40964 L
.80434 .40964 L
.80434 .16187 L
s
.678 .847 .902 r
.80434 .16187 m
.80434 .41205 L
.80734 .41205 L
.80734 .16187 L
F
.2 .63 .79 r
.80434 .16187 m
.80434 .41205 L
.80734 .41205 L
.80734 .16187 L
s
.678 .847 .902 r
.80734 .16187 m
.80734 .41402 L
.80912 .41402 L
.80912 .16187 L
F
.2 .63 .79 r
.80734 .16187 m
.80734 .41402 L
.80912 .41402 L
.80912 .16187 L
s
.678 .847 .902 r
.80912 .16187 m
.80912 .41554 L
.81169 .41554 L
.81169 .16187 L
F
.2 .63 .79 r
.80912 .16187 m
.80912 .41554 L
.81169 .41554 L
.81169 .16187 L
s
.678 .847 .902 r
.81169 .16187 m
.81169 .41863 L
.81465 .41863 L
.81465 .16187 L
F
.2 .63 .79 r
.81169 .16187 m
.81169 .41863 L
.81465 .41863 L
.81465 .16187 L
s
.678 .847 .902 r
.81465 .16187 m
.81465 .4214 L
.81636 .4214 L
.81636 .16187 L
F
.2 .63 .79 r
.81465 .16187 m
.81465 .4214 L
.81636 .4214 L
.81636 .16187 L
s
.678 .847 .902 r
.81636 .16187 m
.81636 .42481 L
.8196 .42481 L
.8196 .16187 L
F
.2 .63 .79 r
.81636 .16187 m
.81636 .42481 L
.8196 .42481 L
.8196 .16187 L
s
.678 .847 .902 r
.8196 .16187 m
.8196 .42794 L
.82208 .42794 L
.82208 .16187 L
F
.2 .63 .79 r
.8196 .16187 m
.8196 .42794 L
.82208 .42794 L
.82208 .16187 L
s
.678 .847 .902 r
.82208 .16187 m
.82208 .42966 L
.82389 .42966 L
.82389 .16187 L
F
.2 .63 .79 r
.82208 .16187 m
.82208 .42966 L
.82389 .42966 L
.82389 .16187 L
s
.678 .847 .902 r
.82389 .16187 m
.82389 .43208 L
.82692 .43208 L
.82692 .16187 L
F
.2 .63 .79 r
.82389 .16187 m
.82389 .43208 L
.82692 .43208 L
.82692 .16187 L
s
.678 .847 .902 r
.82692 .16187 m
.82692 .43423 L
.82919 .43423 L
.82919 .16187 L
F
.2 .63 .79 r
.82692 .16187 m
.82692 .43423 L
.82919 .43423 L
.82919 .16187 L
s
.678 .847 .902 r
.82919 .16187 m
.82919 .43585 L
.83169 .43585 L
.83169 .16187 L
F
.2 .63 .79 r
.82919 .16187 m
.82919 .43585 L
.83169 .43585 L
.83169 .16187 L
s
.678 .847 .902 r
.83169 .16187 m
.83169 .44048 L
.83465 .44048 L
.83465 .16187 L
F
.2 .63 .79 r
.83169 .16187 m
.83169 .44048 L
.83465 .44048 L
.83465 .16187 L
s
.678 .847 .902 r
.83465 .16187 m
.83465 .44303 L
.83631 .44303 L
.83631 .16187 L
F
.2 .63 .79 r
.83465 .16187 m
.83465 .44303 L
.83631 .44303 L
.83631 .16187 L
s
.678 .847 .902 r
.83631 .16187 m
.83631 .44449 L
.83801 .44449 L
.83801 .16187 L
F
.2 .63 .79 r
.83631 .16187 m
.83631 .44449 L
.83801 .44449 L
.83801 .16187 L
s
.678 .847 .902 r
.83801 .16187 m
.83801 .44507 L
.83978 .44507 L
.83978 .16187 L
F
.2 .63 .79 r
.83801 .16187 m
.83801 .44507 L
.83978 .44507 L
.83978 .16187 L
s
.678 .847 .902 r
.83978 .16187 m
.83978 .44775 L
.84278 .44775 L
.84278 .16187 L
F
.2 .63 .79 r
.83978 .16187 m
.83978 .44775 L
.84278 .44775 L
.84278 .16187 L
s
.678 .847 .902 r
.84278 .16187 m
.84278 .45022 L
.84533 .45022 L
.84533 .16187 L
F
.2 .63 .79 r
.84278 .16187 m
.84278 .45022 L
.84533 .45022 L
.84533 .16187 L
s
.678 .847 .902 r
.84533 .16187 m
.84533 .45345 L
.84671 .45345 L
.84671 .16187 L
F
.2 .63 .79 r
.84533 .16187 m
.84533 .45345 L
.84671 .45345 L
.84671 .16187 L
s
.678 .847 .902 r
.84671 .16187 m
.84671 .45496 L
.85021 .45496 L
.85021 .16187 L
F
.2 .63 .79 r
.84671 .16187 m
.84671 .45496 L
.85021 .45496 L
.85021 .16187 L
s
.678 .847 .902 r
.85021 .16187 m
.85021 .45875 L
.85335 .45875 L
.85335 .16187 L
F
.2 .63 .79 r
.85021 .16187 m
.85021 .45875 L
.85335 .45875 L
.85335 .16187 L
s
.678 .847 .902 r
.85335 .16187 m
.85335 .46195 L
.85582 .46195 L
.85582 .16187 L
F
.2 .63 .79 r
.85335 .16187 m
.85335 .46195 L
.85582 .46195 L
.85582 .16187 L
s
.678 .847 .902 r
.85582 .16187 m
.85582 .46585 L
.85778 .46585 L
.85778 .16187 L
F
.2 .63 .79 r
.85582 .16187 m
.85582 .46585 L
.85778 .46585 L
.85778 .16187 L
s
.678 .847 .902 r
.85778 .16187 m
.85778 .46662 L
.85893 .46662 L
.85893 .16187 L
F
.2 .63 .79 r
.85778 .16187 m
.85778 .46662 L
.85893 .46662 L
.85893 .16187 L
s
.678 .847 .902 r
.85893 .16187 m
.85893 .46814 L
.86073 .46814 L
.86073 .16187 L
F
.2 .63 .79 r
.85893 .16187 m
.85893 .46814 L
.86073 .46814 L
.86073 .16187 L
s
.678 .847 .902 r
.86073 .16187 m
.86073 .47122 L
.86373 .47122 L
.86373 .16187 L
F
.2 .63 .79 r
.86073 .16187 m
.86073 .47122 L
.86373 .47122 L
.86373 .16187 L
s
.678 .847 .902 r
.86373 .16187 m
.86373 .47306 L
.86498 .47306 L
.86498 .16187 L
F
.2 .63 .79 r
.86373 .16187 m
.86373 .47306 L
.86498 .47306 L
.86498 .16187 L
s
.678 .847 .902 r
.86498 .16187 m
.86498 .47438 L
.86707 .47438 L
.86707 .16187 L
F
.2 .63 .79 r
.86498 .16187 m
.86498 .47438 L
.86707 .47438 L
.86707 .16187 L
s
.678 .847 .902 r
.86707 .16187 m
.86707 .47636 L
.86944 .47636 L
.86944 .16187 L
F
.2 .63 .79 r
.86707 .16187 m
.86707 .47636 L
.86944 .47636 L
.86944 .16187 L
s
.678 .847 .902 r
.86944 .16187 m
.86944 .47912 L
.87179 .47912 L
.87179 .16187 L
F
.2 .63 .79 r
.86944 .16187 m
.86944 .47912 L
.87179 .47912 L
.87179 .16187 L
s
.678 .847 .902 r
.87179 .16187 m
.87179 .48246 L
.87333 .48246 L
.87333 .16187 L
F
.2 .63 .79 r
.87179 .16187 m
.87179 .48246 L
.87333 .48246 L
.87333 .16187 L
s
.678 .847 .902 r
.87333 .16187 m
.87333 .4842 L
.87647 .4842 L
.87647 .16187 L
F
.2 .63 .79 r
.87333 .16187 m
.87333 .4842 L
.87647 .4842 L
.87647 .16187 L
s
.678 .847 .902 r
.87647 .16187 m
.87647 .48708 L
.87809 .48708 L
.87809 .16187 L
F
.2 .63 .79 r
.87647 .16187 m
.87647 .48708 L
.87809 .48708 L
.87809 .16187 L
s
.678 .847 .902 r
.87809 .16187 m
.87809 .48992 L
.88093 .48992 L
.88093 .16187 L
F
.2 .63 .79 r
.87809 .16187 m
.87809 .48992 L
.88093 .48992 L
.88093 .16187 L
s
.678 .847 .902 r
.88093 .16187 m
.88093 .49224 L
.88372 .49224 L
.88372 .16187 L
F
.2 .63 .79 r
.88093 .16187 m
.88093 .49224 L
.88372 .49224 L
.88372 .16187 L
s
.678 .847 .902 r
.88372 .16187 m
.88372 .49505 L
.88543 .49505 L
.88543 .16187 L
F
.2 .63 .79 r
.88372 .16187 m
.88372 .49505 L
.88543 .49505 L
.88543 .16187 L
s
.678 .847 .902 r
.88543 .16187 m
.88543 .49794 L
.88761 .49794 L
.88761 .16187 L
F
.2 .63 .79 r
.88543 .16187 m
.88543 .49794 L
.88761 .49794 L
.88761 .16187 L
s
.678 .847 .902 r
.88761 .16187 m
.88761 .50033 L
.88984 .50033 L
.88984 .16187 L
F
.2 .63 .79 r
.88761 .16187 m
.88761 .50033 L
.88984 .50033 L
.88984 .16187 L
s
.678 .847 .902 r
.88984 .16187 m
.88984 .50261 L
.892 .50261 L
.892 .16187 L
F
.2 .63 .79 r
.88984 .16187 m
.88984 .50261 L
.892 .50261 L
.892 .16187 L
s
.678 .847 .902 r
.892 .16187 m
.892 .50451 L
.89546 .50451 L
.89546 .16187 L
F
.2 .63 .79 r
.892 .16187 m
.892 .50451 L
.89546 .50451 L
.89546 .16187 L
s
.678 .847 .902 r
.89546 .16187 m
.89546 .50866 L
.89817 .50866 L
.89817 .16187 L
F
.2 .63 .79 r
.89546 .16187 m
.89546 .50866 L
.89817 .50866 L
.89817 .16187 L
s
.678 .847 .902 r
.89817 .16187 m
.89817 .51254 L
.90138 .51254 L
.90138 .16187 L
F
.2 .63 .79 r
.89817 .16187 m
.89817 .51254 L
.90138 .51254 L
.90138 .16187 L
s
.678 .847 .902 r
.90138 .16187 m
.90138 .5165 L
.90321 .5165 L
.90321 .16187 L
F
.2 .63 .79 r
.90138 .16187 m
.90138 .5165 L
.90321 .5165 L
.90321 .16187 L
s
.678 .847 .902 r
.90321 .16187 m
.90321 .52038 L
.90671 .52038 L
.90671 .16187 L
F
.2 .63 .79 r
.90321 .16187 m
.90321 .52038 L
.90671 .52038 L
.90671 .16187 L
s
.678 .847 .902 r
.90671 .16187 m
.90671 .5207 L
.90981 .5207 L
.90981 .16187 L
F
.2 .63 .79 r
.90671 .16187 m
.90671 .5207 L
.90981 .5207 L
.90981 .16187 L
s
.678 .847 .902 r
.90981 .16187 m
.90981 .52456 L
.9116 .52456 L
.9116 .16187 L
F
.2 .63 .79 r
.90981 .16187 m
.90981 .52456 L
.9116 .52456 L
.9116 .16187 L
s
.678 .847 .902 r
.9116 .16187 m
.9116 .52645 L
.91499 .52645 L
.91499 .16187 L
F
.2 .63 .79 r
.9116 .16187 m
.9116 .52645 L
.91499 .52645 L
.91499 .16187 L
s
.678 .847 .902 r
.91499 .16187 m
.91499 .53206 L
.9184 .53206 L
.9184 .16187 L
F
.2 .63 .79 r
.91499 .16187 m
.91499 .53206 L
.9184 .53206 L
.9184 .16187 L
s
.678 .847 .902 r
.9184 .16187 m
.9184 .53572 L
.92076 .53572 L
.92076 .16187 L
F
.2 .63 .79 r
.9184 .16187 m
.9184 .53572 L
.92076 .53572 L
.92076 .16187 L
s
.678 .847 .902 r
.92076 .16187 m
.92076 .53843 L
.92308 .53843 L
.92308 .16187 L
F
.2 .63 .79 r
.92076 .16187 m
.92076 .53843 L
.92308 .53843 L
.92308 .16187 L
s
.678 .847 .902 r
.92308 .16187 m
.92308 .542 L
.92628 .542 L
.92628 .16187 L
F
.2 .63 .79 r
.92308 .16187 m
.92308 .542 L
.92628 .542 L
.92628 .16187 L
s
.678 .847 .902 r
.92628 .16187 m
.92628 .54402 L
.92865 .54402 L
.92865 .16187 L
F
.2 .63 .79 r
.92628 .16187 m
.92628 .54402 L
.92865 .54402 L
.92865 .16187 L
s
.678 .847 .902 r
.92865 .16187 m
.92865 .54824 L
.93217 .54824 L
.93217 .16187 L
F
.2 .63 .79 r
.92865 .16187 m
.92865 .54824 L
.93217 .54824 L
.93217 .16187 L
s
.678 .847 .902 r
.93217 .16187 m
.93217 .5521 L
.93567 .5521 L
.93567 .16187 L
F
.2 .63 .79 r
.93217 .16187 m
.93217 .5521 L
.93567 .5521 L
.93567 .16187 L
s
.678 .847 .902 r
.93567 .16187 m
.93567 .55432 L
.93839 .55432 L
.93839 .16187 L
F
.2 .63 .79 r
.93567 .16187 m
.93567 .55432 L
.93839 .55432 L
.93839 .16187 L
s
.678 .847 .902 r
.93839 .16187 m
.93839 .56061 L
.94114 .56061 L
.94114 .16187 L
F
.2 .63 .79 r
.93839 .16187 m
.93839 .56061 L
.94114 .56061 L
.94114 .16187 L
s
.678 .847 .902 r
.94114 .16187 m
.94114 .56156 L
.9441 .56156 L
.9441 .16187 L
F
.2 .63 .79 r
.94114 .16187 m
.94114 .56156 L
.9441 .56156 L
.9441 .16187 L
s
.678 .847 .902 r
.9441 .16187 m
.9441 .56628 L
.94582 .56628 L
.94582 .16187 L
F
.2 .63 .79 r
.9441 .16187 m
.9441 .56628 L
.94582 .56628 L
.94582 .16187 L
s
.678 .847 .902 r
.94582 .16187 m
.94582 .5695 L
.94927 .5695 L
.94927 .16187 L
F
.2 .63 .79 r
.94582 .16187 m
.94582 .5695 L
.94927 .5695 L
.94927 .16187 L
s
.678 .847 .902 r
.94927 .16187 m
.94927 .57226 L
.95138 .57226 L
.95138 .16187 L
F
.2 .63 .79 r
.94927 .16187 m
.94927 .57226 L
.95138 .57226 L
.95138 .16187 L
s
.678 .847 .902 r
.95138 .16187 m
.95138 .57441 L
.95321 .57441 L
.95321 .16187 L
F
.2 .63 .79 r
.95138 .16187 m
.95138 .57441 L
.95321 .57441 L
.95321 .16187 L
s
.678 .847 .902 r
.95321 .16187 m
.95321 .57668 L
.95623 .57668 L
.95623 .16187 L
F
.2 .63 .79 r
.95321 .16187 m
.95321 .57668 L
.95623 .57668 L
.95623 .16187 L
s
.678 .847 .902 r
.95623 .16187 m
.95623 .57966 L
.95858 .57966 L
.95858 .16187 L
F
.2 .63 .79 r
.95623 .16187 m
.95623 .57966 L
.95858 .57966 L
.95858 .16187 L
s
.678 .847 .902 r
.95858 .16187 m
.95858 .58312 L
.96075 .58312 L
.96075 .16187 L
F
.2 .63 .79 r
.95858 .16187 m
.95858 .58312 L
.96075 .58312 L
.96075 .16187 L
s
.678 .847 .902 r
.96075 .16187 m
.96075 .58544 L
.96339 .58544 L
.96339 .16187 L
F
.2 .63 .79 r
.96075 .16187 m
.96075 .58544 L
.96339 .58544 L
.96339 .16187 L
s
.678 .847 .902 r
.96339 .16187 m
.96339 .59138 L
.96673 .59138 L
.96673 .16187 L
F
.2 .63 .79 r
.96339 .16187 m
.96339 .59138 L
.96673 .59138 L
.96673 .16187 L
s
.678 .847 .902 r
.96673 .16187 m
.96673 .59226 L
.96831 .59226 L
.96831 .16187 L
F
.2 .63 .79 r
.96673 .16187 m
.96673 .59226 L
.96831 .59226 L
.96831 .16187 L
s
.678 .847 .902 r
.96831 .16187 m
.96831 .59515 L
.97051 .59515 L
.97051 .16187 L
F
.2 .63 .79 r
.96831 .16187 m
.96831 .59515 L
.97051 .59515 L
.97051 .16187 L
s
.678 .847 .902 r
.97051 .16187 m
.97051 .59741 L
.97358 .59741 L
.97358 .16187 L
F
.2 .63 .79 r
.97051 .16187 m
.97051 .59741 L
.97358 .59741 L
.97358 .16187 L
s
.678 .847 .902 r
.97358 .16187 m
.97358 .60239 L
.97619 .60239 L
.97619 .16187 L
F
.2 .63 .79 r
.97358 .16187 m
.97358 .60239 L
.97619 .60239 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.0246 .01472 Mdot
.02852 .01473 Mdot
.03115 .01475 Mdot
.03372 .01478 Mdot
.03632 .01482 Mdot
.04059 .0149 Mdot
.04151 .01492 Mdot
.04386 .01498 Mdot
.04804 .0151 Mdot
.04923 .01513 Mdot
.05117 .0152 Mdot
.05449 .01533 Mdot
.05649 .01541 Mdot
.05972 .01555 Mdot
.06038 .01558 Mdot
.06151 .01564 Mdot
.06404 .01577 Mdot
.06658 .0159 Mdot
.06892 .01604 Mdot
.06977 .01609 Mdot
.07097 .01616 Mdot
.07566 .01646 Mdot
.07736 .01658 Mdot
.0794 .01672 Mdot
.08172 .01689 Mdot
.08285 .01698 Mdot
.08493 .01714 Mdot
.08717 .01732 Mdot
.0892 .01749 Mdot
.09158 .0177 Mdot
.09365 .01788 Mdot
.09644 .01814 Mdot
.09862 .01835 Mdot
.09983 .01847 Mdot
.10339 .01882 Mdot
.10494 .01899 Mdot
.10913 .01944 Mdot
.11055 .0196 Mdot
.11358 .01994 Mdot
.11482 .02009 Mdot
.11711 .02036 Mdot
.11963 .02067 Mdot
.12289 .02109 Mdot
.12405 .02124 Mdot
.12845 .02182 Mdot
.13064 .02212 Mdot
.13101 .02217 Mdot
.13413 .02261 Mdot
.13693 .02302 Mdot
.13866 .02328 Mdot
.14095 .02362 Mdot
.14208 .02379 Mdot
.14499 .02424 Mdot
.14608 .02442 Mdot
.15039 .02511 Mdot
.15136 .02527 Mdot
.15471 .02583 Mdot
.15616 .02608 Mdot
.15739 .02629 Mdot
.15964 .02669 Mdot
.16098 .02693 Mdot
.16354 .02738 Mdot
.16563 .02777 Mdot
.16836 .02828 Mdot
.17185 .02894 Mdot
.17578 .0297 Mdot
.17869 .03028 Mdot
.18018 .03058 Mdot
.18201 .03096 Mdot
.18451 .03147 Mdot
.18617 .03182 Mdot
.18836 .03229 Mdot
.19203 .03308 Mdot
.19263 .03321 Mdot
.19487 .0337 Mdot
.19536 .03381 Mdot
.19806 .03442 Mdot
.20058 .03499 Mdot
.20253 .03544 Mdot
.20509 .03604 Mdot
.20937 .03706 Mdot
.2123 .03777 Mdot
.21575 .03862 Mdot
.21904 .03945 Mdot
.22186 .04017 Mdot
.22541 .04109 Mdot
.22584 .0412 Mdot
.22762 .04167 Mdot
.23067 .04248 Mdot
.23409 .04341 Mdot
.23711 .04424 Mdot
.23832 .04458 Mdot
.24233 .0457 Mdot
.24593 .04673 Mdot
.24778 .04727 Mdot
.25186 .04847 Mdot
.25321 .04887 Mdot
.25505 .04942 Mdot
.25815 .05035 Mdot
.26213 .05157 Mdot
.26349 .05199 Mdot
.26549 .05262 Mdot
.27107 .05439 Mdot
.27331 .05511 Mdot
.2768 .05625 Mdot
.27963 .05718 Mdot
.28234 .05809 Mdot
.28452 .05882 Mdot
.28785 .05996 Mdot
.29047 .06086 Mdot
.29218 .06145 Mdot
.29377 .06201 Mdot
.29781 .06343 Mdot
.30089 .06454 Mdot
.30198 .06493 Mdot
.30513 .06607 Mdot
.30522 .06611 Mdot
.30844 .06729 Mdot
.31329 .06909 Mdot
.31399 .06936 Mdot
.31768 .07076 Mdot
.32125 .07213 Mdot
.3241 .07323 Mdot
.32576 .07388 Mdot
.32748 .07456 Mdot
.33042 .07572 Mdot
.33192 .07632 Mdot
.3338 .07707 Mdot
.33599 .07796 Mdot
.33784 .07871 Mdot
.33937 .07933 Mdot
.34232 .08055 Mdot
.34349 .08103 Mdot
.34697 .08248 Mdot
.35107 .08422 Mdot
.35292 .085 Mdot
.35493 .08586 Mdot
.3563 .08646 Mdot
.35812 .08724 Mdot
.35981 .08798 Mdot
.36217 .08901 Mdot
.36409 .08985 Mdot
.36713 .0912 Mdot
.36873 .09192 Mdot
.37032 .09263 Mdot
.37332 .09399 Mdot
.37379 .0942 Mdot
.37859 .0964 Mdot
.38029 .09718 Mdot
.38041 .09724 Mdot
.38367 .09875 Mdot
.38584 .09977 Mdot
.38979 .10163 Mdot
.3927 .10302 Mdot
.39319 .10326 Mdot
.39572 .10447 Mdot
.39782 .10549 Mdot
.40083 .10696 Mdot
.40318 .10811 Mdot
.406 .1095 Mdot
.40708 .11004 Mdot
.40982 .11141 Mdot
.4127 .11286 Mdot
.41517 .11411 Mdot
.41827 .11569 Mdot
.42017 .11666 Mdot
.42303 .11814 Mdot
.42595 .11966 Mdot
.42653 .11996 Mdot
.42991 .12173 Mdot
.43254 .12313 Mdot
.43346 .12362 Mdot
.43632 .12514 Mdot
.43945 .12682 Mdot
.44032 .12729 Mdot
.44299 .12874 Mdot
.44551 .13011 Mdot
.4459 .13033 Mdot
.44855 .13178 Mdot
.45072 .13298 Mdot
.45285 .13417 Mdot
.45519 .13547 Mdot
.45646 .13619 Mdot
.46041 .13841 Mdot
.4618 .1392 Mdot
.46438 .14068 Mdot
.46807 .14279 Mdot
.46918 .14344 Mdot
.47216 .14516 Mdot
.47405 .14627 Mdot
.47717 .14809 Mdot
.47861 .14894 Mdot
.48128 .15053 Mdot
.48337 .15177 Mdot
.48417 .15224 Mdot
.48663 .15372 Mdot
.49077 .15621 Mdot
.4926 .15733 Mdot
.49508 .15884 Mdot
.49614 .15949 Mdot
.49832 .16083 Mdot
.49916 .16135 Mdot
.50113 .16257 Mdot
.50598 .16559 Mdot
.50745 .16651 Mdot
.51177 .16923 Mdot
.51278 .16987 Mdot
.51428 .17082 Mdot
.51571 .17173 Mdot
.5189 .17378 Mdot
.52186 .17568 Mdot
.52673 .17885 Mdot
.52819 .1798 Mdot
.52994 .18095 Mdot
.53282 .18285 Mdot
.53455 .18399 Mdot
.53526 .18447 Mdot
.53756 .18599 Mdot
.53897 .18694 Mdot
.54045 .18793 Mdot
.54267 .18942 Mdot
.54488 .19091 Mdot
.54773 .19284 Mdot
.54928 .1939 Mdot
.55 .19439 Mdot
.55429 .19733 Mdot
.55611 .19859 Mdot
.55676 .19904 Mdot
.56146 .2023 Mdot
.56243 .20298 Mdot
.56645 .2058 Mdot
.56866 .20736 Mdot
.5705 .20866 Mdot
.57176 .20956 Mdot
.57269 .21022 Mdot
.57632 .21282 Mdot
.5776 .21373 Mdot
.581 .21618 Mdot
.58445 .21869 Mdot
.58621 .21997 Mdot
.58824 .22146 Mdot
.59229 .22443 Mdot
.59323 .22512 Mdot
.59499 .22643 Mdot
.59603 .2272 Mdot
.60064 .23064 Mdot
.60273 .2322 Mdot
.60617 .2348 Mdot
.61023 .23787 Mdot
.61267 .23974 Mdot
.61522 .24169 Mdot
.61676 .24287 Mdot
.62087 .24605 Mdot
.62255 .24735 Mdot
.62591 .24997 Mdot
.62745 .25117 Mdot
.62938 .25269 Mdot
.63402 .25635 Mdot
.63666 .25845 Mdot
.63885 .26019 Mdot
.64048 .26149 Mdot
.64132 .26217 Mdot
.64732 .267 Mdot
.64827 .26776 Mdot
.65177 .27061 Mdot
.65367 .27216 Mdot
.65655 .27453 Mdot
.65745 .27527 Mdot
.66124 .27839 Mdot
.66454 .28113 Mdot
.66651 .28277 Mdot
.66854 .28446 Mdot
.66967 .28541 Mdot
.67092 .28645 Mdot
.67254 .28782 Mdot
.67602 .29075 Mdot
.67831 .2927 Mdot
.68067 .29471 Mdot
.68118 .29514 Mdot
.68222 .29603 Mdot
.68495 .29837 Mdot
.68646 .29967 Mdot
.68959 .30237 Mdot
.69216 .30459 Mdot
.69291 .30524 Mdot
.69586 .3078 Mdot
.69978 .31123 Mdot
.70177 .31298 Mdot
.70399 .31494 Mdot
.70642 .31709 Mdot
.70989 .32017 Mdot
.71033 .32057 Mdot
.71142 .32154 Mdot
.71448 .32428 Mdot
.71514 .32486 Mdot
.71639 .32599 Mdot
.71767 .32714 Mdot
.72008 .32932 Mdot
.72212 .33116 Mdot
.72587 .33457 Mdot
.72856 .33702 Mdot
.73061 .3389 Mdot
.7342 .3422 Mdot
.73533 .34325 Mdot
.73658 .3444 Mdot
.74006 .34763 Mdot
.74087 .34838 Mdot
.7446 .35186 Mdot
.74553 .35273 Mdot
.74771 .35478 Mdot
.74959 .35655 Mdot
.75122 .35808 Mdot
.75417 .36088 Mdot
.75646 .36305 Mdot
.75847 .36497 Mdot
.76195 .36829 Mdot
.76286 .36916 Mdot
.76493 .37115 Mdot
.76767 .37379 Mdot
.7687 .37478 Mdot
.77286 .37882 Mdot
.77364 .37957 Mdot
.77755 .38339 Mdot
.77939 .3852 Mdot
.78176 .38752 Mdot
.7832 .38894 Mdot
.78752 .39321 Mdot
.78823 .39392 Mdot
.79083 .3965 Mdot
.79125 .39691 Mdot
.79541 .40107 Mdot
.79741 .40308 Mdot
.80113 .40682 Mdot
.80392 .40964 Mdot
.8063 .41205 Mdot
.80823 .41402 Mdot
.80973 .41554 Mdot
.81275 .41863 Mdot
.81545 .4214 Mdot
.81876 .42481 Mdot
.82179 .42794 Mdot
.82345 .42966 Mdot
.82578 .43208 Mdot
.82784 .43423 Mdot
.82939 .43585 Mdot
.83381 .44048 Mdot
.83623 .44303 Mdot
.83761 .44449 Mdot
.83816 .44507 Mdot
.8407 .44775 Mdot
.84302 .45022 Mdot
.84605 .45345 Mdot
.84747 .45496 Mdot
.85101 .45875 Mdot
.85398 .46195 Mdot
.85759 .46585 Mdot
.85831 .46662 Mdot
.8597 .46814 Mdot
.86254 .47122 Mdot
.86423 .47306 Mdot
.86544 .47438 Mdot
.86725 .47636 Mdot
.86976 .47912 Mdot
.8728 .48246 Mdot
.87438 .4842 Mdot
.87698 .48708 Mdot
.87955 .48992 Mdot
.88164 .49224 Mdot
.88415 .49505 Mdot
.88674 .49794 Mdot
.88886 .50033 Mdot
.89089 .50261 Mdot
.89258 .50451 Mdot
.89626 .50866 Mdot
.89967 .51254 Mdot
.90315 .5165 Mdot
.90654 .52038 Mdot
.90683 .5207 Mdot
.91018 .52456 Mdot
.91183 .52645 Mdot
.91669 .53206 Mdot
.91984 .53572 Mdot
.92216 .53843 Mdot
.92521 .542 Mdot
.92694 .54402 Mdot
.93054 .54824 Mdot
.93381 .5521 Mdot
.93569 .55432 Mdot
.94099 .56061 Mdot
.94179 .56156 Mdot
.94574 .56628 Mdot
.94843 .5695 Mdot
.95072 .57226 Mdot
.95251 .57441 Mdot
.95439 .57668 Mdot
.95685 .57966 Mdot
.95971 .58312 Mdot
.96161 .58544 Mdot
.96648 .59138 Mdot
.9672 .59226 Mdot
.96956 .59515 Mdot
.97139 .59741 Mdot
.97544 .60239 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(403) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0074004) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666155) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000<0n_3V1P0000020?[`iP<0
0000103jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V000000000000103jl>H2000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`iP030000003j
l>H0n_3V00800000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2
000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V000000000000103jl>H2000000H0n_3V0P0000050?[`iP800000o`3j
l>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003j
l>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V00000000
00002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V000000000000103jl>H2000000H0n_3V0P0000050?[`iP800000o`3jl>JL0?[`iP40
oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4
000000<0n_3V100000030?[`iP@000001@3jl>H2000000<0n_3V00<000000?[`iP3jl>H00P000002
0?[`iP030000003jl>H0n_3V00800000o`3jl>JL0?[`iP40oooo000P0?[`iP8000000P3jl>H20000
00030?[`iP000000000000800000103jl>H4000000030?[`iP000000000000D000000P3jl>H40000
0080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H00000000000070000
01T0n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P0000070?[`
iP8000000`3jl>H4000000<0n_3V1000003o0?[`iYd0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0
n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V100000030?[`iP8000001@3jl>H200000?l0
n_3VW`3jl>H10?ooo`007`3jl>H6000000@0n_3V0P00000_0?[`iPD00000:03jl>H3000000`0n_3V
0`0000040?[`iP<00000103jl>H3000000@0n_3V0P0000030?[`iPD000000P3jl>H500000?l0n_3V
W03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V
5`3jl>H10?ooo`00803jl>H6000000050?[`iP00000000000000003jl>H00`0000020?[`iP<00000
0`3jl>H4000000<0n_3V0P000000103jl>H000000000003jl>H5000000<0n_3V3000000_0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<0
00001@3jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP8000000P3jl>H010000000n_3V0000000000030?[`iP050000003jl>H000000000
003jl>H00`0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP8000008P3jl>H50000
00T0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`
iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP80
00001@3jl>H200000080n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP80
0000<03jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`00
8P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H6000000030?[`
iP00000000000080n_3V0P0000020?[`iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD00000
2@3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3j
l>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H200000080n_3V0P00
0000103jl>H000000000003jl>H300000080n_3V0`0000000`3jl>H000000?[`iP040?[`iP800000
0`3jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP@000000`3jl>H4000000<0n_3V
100000030?[`iP@000000`3jl>H4000000H0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00
00030?[`iPD000000P3jl>H5000000<0n_3V100000030?[`iP80000000<0n_3V0000000000001000
00000`3jl>H00000000000020?[`iP@00000103jl>H200000300n_3V0P0000000`3jl>H000000000
00090?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000P0n_3V0P00
003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;0?[`iP8000008P3jl>H200000300n_3V0P000000
0`3jl>H000000000000:0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2
000000@0n_3V00<000000?[`iP3jl>H00P00003o0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`
iP800000803jl>H400000340n_3V0`00000<0?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`
iP<00000103jl>H300000080n_3V1@00003o0?[`iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H20000
00030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0
n_3V00@000000?[`iP000000n_3V0P0000020?[`iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`
iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0000000000002000000050?[`iP000000n_3V0000
003jl>H00`0000020?[`iP030000003jl>H0000001P0n_3V1@00003K0?[`iP@00000103jl>H;0000
00@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H30000
00040?[`iP0000000000000000P0n_3V100000000`3jl>H00000000000020?[`iP@000000P3jl>H5
000000070?[`iP00000000000000003jl>H000000?[`iP03000001P0n_3V0`0000040?[`iP800000
1@3jl>H3000000@0n_3V0`0000050?[`iP800000103jl>H4000000<0n_3V0`0000040?[`iP<00000
103jl>H400000740n_3V0@3oool00240n_3V0P0000000`3jl>H0000000000005000000040?[`iP00
0000000000000080n_3V0P0000000`3jl>H00000000000090?[`iPD000002@3jl>H200000=l0n_3V
0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V
0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H200000080n_3V0P0000000`3j
l>H00000000000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP020000
00T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H2000000D0n_3V0P0000030?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00001b0?[`
iP40oooo000R0?[`iP<00000:@3jl>H200000=h0n_3V0P0000040?[`iP8000000P3jl>H200000080
n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000
003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP020000
01P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000@0n_3V0P0000020?[`iPH000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P000000103jl>H000000000003jl>H600000740n_3V0@3oool00280n_3V0`00000J0?[`
iPD000002`3jl>H200000=d0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`
iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3j
l>H000000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P000002
0?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P000000
0`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
000000@0n_3V0P0000020?[`iP030000003jl>H0n_3V008000000`3jl>H2000000030?[`iP000000
00000080n_3V0P0000001@3jl>H000000000003jl>H000000080n_3V0P00001b0?[`iP40oooo000Q
0?[`iP80000000<0n_3V000000000000:P3jl>H200000=`0n_3V0P0000000`3jl>H0000000000005
0?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P00
00060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3j
l>H3000000040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H00000
0?[`iP02000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V
00@000000?[`iP00000000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP040000003jl>H0000000000780n_3V0@3oool00200n_3V0`000000103jl>H0
000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP0000000000
0080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H5
00000080n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`0000000`3jl>H0000000000002
0?[`iP@000000P3jl>H3000000030?[`iP000000000000L000006@3jl>H2000000030?[`iP000000
000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H2
00000080n_3V00@000000?[`iP00000000000`3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000020?[`iP040000003jl>H0000000000780n_3V0@3oool004d0n_3V0P00
00000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403jl>H2000000`0n_3V0P00
000R0?[`iP8000000P3jl>H2000002h0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P00
00030?[`iP<000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00030?[`iP<00000LP3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2
000000@0n_3V0P0000060?[`iP8000006@3jl>H3000000030?[`iP000000000000800000;P3jl>H3
000000/0n_3V0`0000040?[`iP<000000`3jl>H5000000@0n_3V0P0000040?[`iP<00000103jl>H3
000000D0n_3V0P00001b0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00
000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`iP0000000P3j
l>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo
000P0?[`iP<0000000<0n_3V0000000000000P000000103jl>H000000?[`iP0000020?[`iP040000
003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V100000040?[`iP/0
0000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0
000000<0n_3V0000000000001P00000K0?[`iP@000000`3jl>H3000000@0n_3V0`00002j0?[`iP40
oooo000Q0?[`iP80000000<0n_3V0000000000001@0000001@3jl>H00000000000000000n_3V00@0
00002`3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080
n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`
iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP8000000P3jl>H2000000/0n_3V1@00000;0?[`iP8000000`3j
l>H2000000030?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P00002i0?[`iP40oooo000R
0?[`iP<00000:03jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H2
00000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H4000001P0n_3V1P000002
0?[`iP80000000<0n_3V0000000000001@3jl>H200000;T0n_3V0@3oool00280n_3V0`0000090?[`
iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H40000
00<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP@000003@3jl>H5
000000P0n_3V00<000000?[`iP3jl>H00P0000030?[`iP80000000<0n_3V0000000000001@3jl>H2
00000;T0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0n_3V0000
00000000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000
003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000I0?[`iP040000003j
l>H00000000000<0n_3V0P0000000`3jl>H00000000000030?[`iP<00000^P3jl>H10?ooo`00803j
l>H3000000040?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP800000
00<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003jl>H500000080
n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000000`3jl>H5000001T0
n_3V00@000000?[`iP00000000000`3jl>H2000000030?[`iP000000000000D0n_3V0P00002i0?[`
iP40oooo001=0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100
n_3V0P00000<0?[`iP800000>@3jl>H3000000<0n_3V0P0000000`3jl>H00000000000020?[`iP03
0000003jl>H0n_3V00800000^@3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP800000
1P3jl>H2000000@0n_3V0P0000060?[`iP800000<P3jl>H2000000@0n_3V0`0000040?[`iP<00000
^P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0
n_3V9P3oon02000006`0oooP0P0000040?ooh0800000103oon02000006/0oooP1@00001Y0?ooh0D0
00000P3oon02000000@0oooP0P00001[0?ooh0@000008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP
00@000000?ooh03oon000000JP3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP
000006`0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0070?ooh0040000003oon00
oooP000006X0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iRD0oooP00@00000
0?ooh03oon000000JP3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP06X0oooP
00<000000?ooh03oon00J`3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP06T0oooP
00<000000?ooh03oon008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon000000
JP3oon0010000000oooP0?ooh00000090?ooh0800000K@3oon000`000000oooP0?ooh01[0?ooh003
0000003oon00oooP00P0oooP0P00001]0?ooh0030000003oon00oooP0280oooP7P3jl>H10?ooo`00
7@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002@3oon000`00
0000oooP0?ooh01/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon00203oon000`00
0000oooP0?ooh01Z0?ooh0040000003oon00oooP000002<0oooP7P3jl>H10?ooo`007@3jl>HV0?oo
h0800000K03oon02000000X0oooP0`00001[0?ooh0800000K03oon02000000X0oooP0`00001[0?oo
h0800000903oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP
0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon002@3oon0C0000
0?l0oooPbP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000
oooP0?ooh0060?ooh0030000003oon00oooP00P0oooP6@0000000`3oon0000000000000600000?l0
oooP_03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP
0?ooh0060?ooh0@000001`3oon000`000000003o0000o`0H0000oa800000o`3oon2^0?ooh0@00000
603oon0N0?[`iP40oooo000M0?[`iPX0oooP100000040?ooh0030000003oon00oooP00H0oooP00<0
00000?ooh03oon002@3oon0J000000P0003o4000003o0?ooh:/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh009
0?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00@0cHDo1P00
00000`3=QCl0000000000007000000X0003o3`00003o0?ooh:80oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP00T0oooP0P3=QCl0
1@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5
?`020<f5?``000002@000?l<00000?l0oooPW03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oT
h@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5
?`050<f5?`030?oTh@3=QCl0000000T0000020000?l900000?l0oooPU`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ
0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=
QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>400000
00000009000000D0003o2@00003o0?ooh980oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40
103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl0
1@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl01P3=QCl8000000D0
003o2@00003o0?ooh8d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40
cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl0103oi>40cHDo0<f5?`3=QCl7
000000D0003o2@00003o0?ooh8P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl0
0`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl0
1@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5
?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@H000001@000?l900000?l0oooPP`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0
onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl0
0`3=QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40
cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3o
i>40cHDo0<f5?`06000000D0003o1`00003o0?ooh800oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5
?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl0
0`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ
0P3=QCl00`3oi>40000000000005000000@0003o2000003o0?ooh7/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=
QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo
00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=
QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5
?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@030<f5?`H000001@000?l600000?l0oooPN03oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ
0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=
QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ
0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3o
i>40cHDo0?oTh@05000000@0003o1P00003o0?ooh7@0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5
?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl0
0`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ
0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl00`3oi>40
000000000004000000@0003o1@00003o0?ooh740oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP0`0000090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`03
0?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`05
0?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo
00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=
QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@80
cHDo1@0000030000o`@00000o`3oon1]0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40
cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5
?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oT
h@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`H0
000010000?l500000?l0oooPJP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`03
0?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`05
0?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo
00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=
QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0
cHDo00@0onCQ0<f5?`3=QCl0cHDo1P0000030000o`D00000o`3oon1W0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40
cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5
?`030?oTh@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0
cHDo00P0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=
QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080
cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo
00D0000010000?l2000000030?ooh000000000000?l0oooPH`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ0<f5?`3o
i>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3o
i>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`08
0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5
?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`04
0?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01@3oi>40cHDo0<f5?`3oi>40
cHDo00L000000`000?l500000?l0oooPH03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@04
0<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`05
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=
QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`03
0?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo
0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=
QCl0000000@000000`000?l400000?l0oooPGP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oT
h@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5
?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oT
h@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5
?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0
cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`040?oT
h@3=QCl0cHDo0<f5?`80000000@0cHDo00000000000000000P000?l500000?l0oooPF`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080
cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5
?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0
0`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40
cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103o
i>40cHDo0<f5?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl4000000<0003o1@00
003o0?ooh5P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5
?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5
?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oT
h@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=
QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0
cHDo00<0onCQ0<f5?`3=QCl0100000030000o`D00000o`3oon1E0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo
0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`03
0?oTh@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo
00P0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0
cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo
00@0onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oT
h@@0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`050?oTh@3=QCl0cHDo0?oTh@3=QCl01@00
00020000o`D00000o`3oon1C0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0
onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo00D0cHDo00D0
onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl0
0`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5
?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=
QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`0000000`0000030000
o`@00000o`3oon1A0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5
?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo00D0cHDo00D0onCQ0<f5
?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0
103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40
103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl00`3o
i>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>400000
0000000000030000o`H00000o`3oon1<0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0
cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo00D0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5
?`3=QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0
onCQ0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0
onCQ103=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0onCQ0<f5
?`3=QCl0cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl00`3oi>40cHDo0<f5?`04000000<0003o1000003o0?ooh4/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0
onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0
onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0
203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=
QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0
103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ
103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3o
i>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00<0cHDo100000020000o`D00000o`3oon180?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon020<f5?`05
0?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo
00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ
0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0
onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3o
i>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5
?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ
0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00<0onCQ000000000000
0P0000030000o`D00000o`3oon130?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo
0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`04
0?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@04
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oT
h@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
cHDo00@0cHDo00D0onCQ0<f5?`3=QCl0onCQ0<f5?`03000000<0003o1000003o0?ooh4<0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon02
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=
QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo
00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80
cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ
0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0
onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=
QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00L0onCQ0<f5
?`3=QCl0onCQ0<f5?`3oi>40cHDo00@000000P000?l500000?l0oooP@03oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ
0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=
QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo
0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40
cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@02
0<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0<f5
?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5
?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=QCl02P3oi>40cHDo0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>43000000<0003o1000003o0?ooh3h0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oT
h@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0
cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5
?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ
0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40
0P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=
QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl4000000<0003o1000003o0?ooh3/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0
cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0
onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ
0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0
onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl00`3oi>4000000000000300000080003o
1000003o0?ooh3T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo
0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`04
0?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@04
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oT
h@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ00<000000P000?l400000?l0oooP=`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ0<f5
?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0
0`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo0<f5
?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo
0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5
?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0<f5?`3o
i>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`03
0?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=QCl02P3oi>40cHDo0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl300000080
003o1@00003o0?ooh3@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40
cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5
?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oT
h@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`03
0?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0
onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=
QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl0
1@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00<0onCQ0<f5?`0000000P0000020000o`@00000o`3o
on0c0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=
QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo
0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3o
i>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5
?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`04
0?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`040<f5
?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=
QCl0cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0<f5?`<000000`000?l300000?l0oooP<@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ
0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=
QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ
0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3o
i>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0
103oi>40cHDo0<f5?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0103oi>40cHDo
0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=QCl02P3oi>40
cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3o
i>400P3=QCl00`3oi>40cHDo0<f5?`030<f5?`@000000P000?l400000?l0oooP;P3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo
00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=
QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3o
i>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0
103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo
0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40
cHDo0<f5?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5?`3o
i>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=QCl02P3oi>40cHDo0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=
QCl00`3oi>40cHDo0<f5?`050<f5?`@000000P000?l400000?l0oooP;03oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ
0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=
QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo
0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40
cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@02
0<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0<f5
?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5
?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=QCl02P3oi>40cHDo0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl00`3o
i>40cHDo0<f5?`060<f5?`030?oTh@3=QCl00000008000000P000?l500000?l0oooP:@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080
cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5
?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0
0`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40
cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103o
i>40cHDo0<f5?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5
?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=QCl02P3oi>40cHDo
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40
0P3=QCl00`3oi>40cHDo0<f5?`060<f5?`040?oTh@3=QCl0cHDo0?oTh@<000000`000?l300000?l0
oooP:03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0
cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5
?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5
?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0
onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0
103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=
QCl02P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0
cHDo0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`060<f5?`040?oTh@3=QCl0cHDo0?oTh@<0cHDo
0`0000020000o`@00000o`3oon0U0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0<000002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo
0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`04
0?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@04
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oT
h@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3o
i>440<f5?`@000000P000?l300000?l0oooP8P3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0
onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo00D0cHDo00D0
onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl0
0`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5
?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=
QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3o
i>40cHDo0<f5?`040<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo00H0cHDo00@0onCQ0<f5
?`3=QCl0onCQ1@3=QCl00`3oi>40cHDo0000000200000080003o1000003o0?ooh240oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0
cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0
onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ
0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0
onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080
cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`040?oTh@3=QCl0cHDo
0<f5?`<000000P000?l300000?l0oooP803oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@04
0<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`05
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=
QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`03
0?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo
0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080
cHDo00<0onCQ0<f5?`3=QCl0103=QCl02P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`060<f5?`04
0?oTh@3=QCl0cHDo0?oTh@D0cHDo00H0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl300000080003o0`00
003o0?ooh1h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5
?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5
?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oT
h@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=
QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0
cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo
00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3oi>45
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl400000080003o1000003o0?ooh1/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon02
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=
QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo
00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80
cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ
0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0
onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=
QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ0<f5
?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
0080cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`050?oTh@3=QCl0
cHDo0<f5?`3oi>40103=QCl400000080003o1000003o0?ooh1T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0
onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0
onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0
203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=
QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0
103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ
103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3o
i>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00<0onCQ0<f5
?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401P3=
QCl0103oi>4000000000000000020000o`@00000o`3oon0G0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oT
h@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oT
h@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0
cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo
0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0
onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`040<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`030?oTh@3=QCl0
cHDo00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00H0cHDo
00<0onCQ0<f5?`0000000`0000020000o`<00000o`3oon0F0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oT
h@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oT
h@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0
cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo
0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0
onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`040<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`030?oTh@3=QCl0
cHDo00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00H0cHDo
00@0onCQ0<f5?`3=QCl0onCQ100000020000o`<00000o`3oon0D0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo
0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`03
0?oTh@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo
00P0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0
cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo
00@0onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oT
h@@0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0
onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`040<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`030?oTh@3=
QCl0cHDo00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00H0
cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>4000000000000000020000o`800000o`3oon0C
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl0
0`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@030<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo0<f5
?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3oi>40
cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5?`02
0<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`040?oT
h@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`040<f5?`0:
0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5
?`0300000080003o0P00003o0?ooh140oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=
QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=
QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo
0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3o
i>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3o
i>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5
?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103o
i>40cHDo0<f5?`3oi>450<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401P3=QCl0103oi>40cHDo0<f5
?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@@0000000<0003o0000000000000P00003o0?ooh0h0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`03
0?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo
0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=
QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080
cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ
0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0
onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=
QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>401P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo
0?oTh@80cHDo0`0000020000o`<00000o`3oon0=0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0
onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0
cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0
onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80
cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5
?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0
onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl00`3oi>40cHDo0<f5?`040<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3o
i>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo00H0
cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00H0cHDo00@0onCQ
0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>430<f5?`040?oTh@000000000000000080
003o0`00003o0?ooh0/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`0000090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0
cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5
?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5
?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0
onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0
103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=
QCl02P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0
cHDo0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`060<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo
00D0onCQ0<f5?`3=QCl0cHDo0?oTh@060<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5
?`3=QCl0onCQ0`3=QCl00`3oi>40cHDo0<f5?`03000000030000o`000000000000800000o`3oon07
0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5
?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0
cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0
onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ
0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0
onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=
QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080
cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`050?oTh@3=QCl0cHDo
0<f5?`3oi>401P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@<0cHDo
00<0onCQ0<f5?`3=QCl00P3=QCl200000080003o1000003o0?ooh0L0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=
QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo
00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=
QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5
?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=
QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0
onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0
0`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00<0onCQ
0<f5?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40
1P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@<0cHDo00<0onCQ0<f5
?`3=QCl00P3=QCl0103oi>4000000000000000020000o`@00000o`3oon050?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3o
i>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`03
0<f5?`030?oTh@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=
QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oT
h@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ
0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0
cHDo0?oTh@@0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80
cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`040<f5?`0:0?oTh@3=QCl0cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`03
0?oTh@3=QCl0cHDo00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl01@3oi>40cHDo0<f5?`3=QCl0
onCQ00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>430<f5?`030?oT
h@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0cHDo0P0000020000o`@00000o`3oon030?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40
cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5
?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>42
0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oT
h@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40cHDo0<f5?`020<f5?`04
0?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`040?oTh@3=QCl0
cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`040<f5?`0:0?oTh@3=
QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@020<f5?`030?oTh@3=QCl0cHDo00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>43
0<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40000000000000
0?l400000?l0oooP0P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=
QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo
00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ
00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0
onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3o
i>400`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5
?`3=QCl0103=QCl02P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`05
0?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`060<f5?`040?oTh@3=QCl0cHDo
0?oTh@D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@060<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00@0onCQ0<f5?`3=QCl0onCQ0`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo0080
cHDo00@0onCQ0<f5?`00000000000P000?l400000?l0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5
?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5
?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl0
0`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ
0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40
cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl0
1@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo
0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo
0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl0
1P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401P3=QCl0103o
i>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@<0cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0<f5?`8000000P000?l400000?d0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo0<f5?`0=0<f5?`030?oT
h@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0
cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@3=QCl0cHDo0?oT
h@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@040<f5?`050?oTh@3=QCl0
onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oTh@3=QCl0cHDo0080cHDo
00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00@0onCQ0<f5
?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00@0cHDo00X0onCQ
0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3oi>40cHDo0<f5?`3=QCl0
onCQ0080cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>401P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oT
h@<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`020<f5?`050?oTh@3=QCl0cHDo
0<f5?`3oi>400`0000020000o`<00000o03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@04
0<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`05
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=
QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`03
0?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo
0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080
cHDo00<0onCQ0<f5?`3=QCl0103=QCl02P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`060<f5?`04
0?oTh@3=QCl0cHDo0?oTh@D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@060<f5?`040?oTh@3=QCl0
cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oT
h@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`<0000000<0003o00000000
00000P00003j0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3=
QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo00D0cHDo00D0onCQ0<f5?`3=
QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0103o
i>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40103=
QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl00`3oi>40
cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@03
0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5
?`040<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@<0cHDo00D0onCQ
0<f5?`3=QCl0cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ
1@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00H0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103o
i>40cHDo0<f5?`3oi>430<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0
1@3oi>40cHDo0<f5?`3=QCl0onCQ00@0cHDo0P0000020000o`<00000n@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh080cHDo00D0onCQ
0<f5?`3oi>40cHDo0?oTh@040<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5?`3=QCl00`3=
QCl00`3oi>40cHDo0<f5?`050<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl00`3oi>40cHDo
0<f5?`080<f5?`030?oTh@3=QCl0cHDo00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0103oi>40
cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ00@0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@02
0<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0103oi>40cHDo0<f5
?`3oi>440<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5
?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=QCl02P3oi>40cHDo0<f5?`3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>430<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>400P3=QCl00`3o
i>40cHDo0<f5?`060<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@060<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0`3=QCl00`3oi>40
cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo0080cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@060<f5
?`8000000P000?l300000?L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3o
i>40cHDo0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`03
0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo
0?oTh@040<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5
?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=
QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oT
h@3=QCl0cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=
QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103oi>40cHDo
0<f5?`3oi>450<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401P3=QCl0103oi>40cHDo0<f5?`3oi>42
0<f5?`040?oTh@3=QCl0cHDo0?oTh@<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5
?`020<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl3000000030000o`000000000000800000
m@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<0
00000?ooh03oon002@3oon020<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>40103=QCl00`3oi>40cHDo
0<f5?`0=0<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00<0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`030<f5?`04
0?oTh@3=QCl0cHDo0?oTh@80cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@04
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>440<f5?`030?oT
h@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0onCQ103=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
cHDo00@0cHDo00X0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0`3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0103oi>40cHDo0<f5?`3o
i>450<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`04
0?oTh@3=QCl0cHDo0?oTh@<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`020<f5
?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl0103oi>40cHDo0000000000020000o`@00000l`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP00T0oooP0P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ00@0cHDo
00<0onCQ0<f5?`3=QCl03@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo00D0cHDo
00D0onCQ0<f5?`3=QCl0cHDo0?oTh@030<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=
QCl00`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ
0<f5?`3oi>40103=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ
103=QCl00`3oi>40cHDo0<f5?`020<f5?`040?oTh@3=QCl0cHDo0?oTh@@0cHDo00D0onCQ0<f5?`3=
QCl0cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0
0`3oi>40cHDo0<f5?`040<f5?`0:0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@<0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo00H0cHDo00@0onCQ
0<f5?`3=QCl0onCQ1@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00H0cHDo00@0onCQ0<f5?`3=QCl0
onCQ0P3=QCl0103oi>40cHDo0<f5?`3oi>430<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5
?`3=QCl00P3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00@0onCQ0<f5?`3=QCl0cHDo0P00
00020000o`<00000lP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon00
10000000oooP0?ooh00000070?ooh0@00000203oon3W00000080003oj00000080?ooh0@00000603o
on0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?oo
h03^0?ooh0@0000000@0003o0000000000000000100cXLX0102]f>H0<j7:03>QbP2]f>H803>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0703>QbP030:gHiP0cXLX0[MSV
00L0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0c
XLX02`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0c
XLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:
0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100c
XLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP0?00oooP0`0000020000o`<000000P0cXLX0102]f>H0<j7:03>Q
bP2]f>H803>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0703>QbP03
0:gHiP0cXLX0[MSV00L0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0c
XLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>Q
bP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV
03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV
03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV
03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon020000
00P0oooP00<000000?ooh03oon00lP3oon03000000060000o`00000000000000000cXLX0[MSV0P0c
XLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:
0:gHiP0703>QbP030:gHiP0cXLX0[MSV00L0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0
<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:
00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0
<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:
0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV
03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03c0?ooh0<000000P000?l2000000040:gHiP0cXLX0<j7:0:gH
iPP0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00L0<j7:00<0[MSV
03>QbP2]f>H01`0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]
f>H0<j7:03>QbP0;03>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]
f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>Q
bP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?H0oooP0P0000001P000?l00000000000000000<j7:0:gHiPP0<j7:00<0[MSV03>QbP0c
XLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00L0<j7:00<0[MSV03>QbP2]f>H01`0cXLX0102]
f>H0<j7:03>QbP2]f>H303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP03
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0c
XLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:
00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?L0oooP0P000002
0000o`80000000<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H01`0cXLX00`2]f>H0<j7:0:gHiP0703>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX0
0`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:
03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0
<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>Q
bP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0
[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n03oon03000000040000o`0000000000000000L0
<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00L0<j7:00<0[MSV03>Q
bP2]f>H01`0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0
<j7:03>QbP0;03>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>Q
bP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]
f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gH
iP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?X0oooP0P0000000`000?l0000000000002000000D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV00L0<j7:00<0[MSV03>QbP2]f>H01`0cXLX0102]f>H0<j7:03>Q
bP2]f>H303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP030:gHiP0cXLX0
[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>Q
bP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?/0oooP0P0000020000o`<00000
100cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H01`0cXLX00`2]f>H0
<j7:0:gHiP0703>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gH
iP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0
<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:
0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0
[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o@3oon02000000030000o`0000000000008000000P0cXLX00`2]f>H0<j7:03>QbP0303>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H01`0cXLX00`2]f>H0<j7:0:gHiP0703>QbP040:gHiP0cXLX0
<j7:0:gHiP<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>Q
bP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX0
0`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0
<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0
100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00oP3oon0200000080003o1000
00000`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H01`0cXLX00`2]f>H0<j7:
0:gHiP0703>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0c
XLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:
00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gH
iPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:
03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon010?ooh080000000<0003o0000000000000P00000503>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H01`0cXLX00`2]f>H0<j7:0:gHiP0703>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0
<j7:03>QbP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>Q
bP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP05
03>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gH
iP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>Q
bP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon020?ooh08000000P000?l3000000@0<j7:00D0[MSV
03>QbP0cXLX0<j7:0:gHiP0703>QbP030:gHiP0cXLX0[MSV00L0<j7:00@0[MSV03>QbP0cXLX0[MSV
0`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>Q
bP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:0:gHiP04
03>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gH
iP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP03
0:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:
00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP03
0:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0@0oooP0P0000000`000?l00000
0000000200000080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0703>QbP030:gHiP0cXLX0[MSV00L0
<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX0
2`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX0
0`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP1P3oon000`00
0000003o0000o`030000000303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]
f>H0<j7:0:gHiP0703>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP03
0:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:
00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0
<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh0L0oooP0P0000000`000?l0000000000002000000<0<j7:00<0[MSV03>QbP0cXLX01@0cXLX0
0`2]f>H0<j7:0:gHiP0703>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0c
XLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon090?ooh003000000000?l0003o00<000000P0cXLX00`2]f>H0<j7:03>Q
bP0503>QbP030:gHiP0cXLX0[MSV00L0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX01`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0
<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0
[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:
00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>Q
bP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0X0oooP0P0000001P000?l00000000000000000<j7:0:gH
iPL0<j7:00<0[MSV03>QbP2]f>H01`0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0c
XLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0
102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:
03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:
03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP303oon000`000000003o0000o`03000000L0<j7:00<0[MSV
03>QbP2]f>H01`0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]
f>H0<j7:03>QbP0;03>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]
f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>Q
bP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP3@3oon02000000030000o`0000000000008000001@0cXLX00`2]f>H0<j7:0:gH
iP0703>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0
<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0
<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0
<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0>0?ooh08000000P000?l3000000@0<j7:00<0[MSV03>QbP2]f>H01`0cXLX0102]f>H0<j7:
03>QbP2]f>H303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP030:gHiP0c
XLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:
00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80
<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:
00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV
03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:
00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3`3oon0300000003
0000o`0000000000008000000P0cXLX00`2]f>H0<j7:0:gHiP0703>QbP040:gHiP0cXLX0<j7:0:gH
iP<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0c
XLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0
100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0
<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]
f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
0`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>Q
bP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0B0?ooh003000000000?l0003o
00<0000000@0<j7:0:gHiP0cXLX0[MSV1`0cXLX0102]f>H0<j7:03>QbP2]f>H303>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0c
XLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX0
0`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0c
XLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0
<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0
<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP4`3oon02000000070000o`00000000000000002]f>H0
<j7:0:gHiP0703>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gH
iP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0
<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:
0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0
[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0D0?ooh08000000P000?l3000000030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>Q
bP0cXLX0[MSV0`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0
<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>Q
bP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H2
03>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gH
iP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>Q
bP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1H0oooP0P000000
0`000?l0000000000002000000H0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gH
iP80<j7:00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:
00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV
03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0
[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh1L0oooP0P0000020000o`<000001@0cXLX0102]f>H0<j7:03>Q
bP2]f>H303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP030:gHiP0cXLX0
[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>Q
bP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP6@3oon02000000030000
o`000000000000D0<j7:00@0[MSV03>QbP0cXLX0[MSV0`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0
[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0
100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0c
XLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>Q
bP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0
oooP6P3oon0200000080003o0P00000303>QbP040:gHiP0cXLX0<j7:0:gHiP<0<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:
03>QbP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP03
0:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>Q
bP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP02
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0c
XLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0c
XLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0<j7:00T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh1/0oooP0`0000001P000?l00000000000000000<j7:0:gHiP80<j7:00/0
[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP030:gHiP0c
XLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:
00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80
<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:
00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV
03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:
00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP703oon0300000005
0000o`00000000000000002]f>H00P0cXLX02`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0c
XLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0N0?ooh08000000P000?l200000080<j7:00/0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00@0[MSV
03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0c
XLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX0
0`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gH
iP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7`3oon03000000050000o`000000000003>Q
bP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP03
0:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP03
03>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh200oooP0`0000001000
0?l0000000000000000303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP03
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0c
XLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:
00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP8P3oon02
00000080003o0P00000203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP03
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0c
XLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:
00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP8`3oon03
0000000;0000o`000000000003>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX02`0cXLX0
0`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0
<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>Q
bP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0
<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2D0oooP
0P0000002P000?l000000000002]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0c
XLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP030:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0
<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gH
iP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0
<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0
[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0
<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP9P3oon020000
0080003o0P0000001@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100c
XLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:
03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0
<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]
f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0W0?ooh0<0000000L0003o00000000
0000<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP2]
f>H203>QbP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>Q
bP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gH
iP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP04
0:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0
<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0
<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0X0?ooh0<0000000H0003o000000000000000003>QbP2]f>H2
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>Q
bP0;03>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gH
iP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>Q
bP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP:P3oon0200000080003o0P000000102]f>H0<j7:03>QbP2]f>H503>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0
<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0
[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:
00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>Q
bP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh2/0oooP0`0000000`000?l000000000000203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0;03>QbP03
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0c
XLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:
00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0/0?ooh0<0000000D0003o
000000000000<j7:0:gHiP0503>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX0
2`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX0
0`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02@3oon03
000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;P3oon020000
0080003o00<000000:gHiP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0
<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0
<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0
<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0_0?ooh0<0000000<0003o000000000000100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP03
0:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:
00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0
<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0`0?ooh0<0000000<0003o0000000000000`0cXLX0102]f>H0<j7:03>QbP2]
f>H203>QbP030:gHiP0cXLX0<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>Q
bP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gH
iP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP04
0:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0
<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0
<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0b0?ooh080000000H0003o000000000000000003>QbP2]f>H2
03>QbP040:gHiP0cXLX0<j7:0:gHiPd0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>Q
bP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gH
iP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP04
0:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0
<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0
<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0c0?ooh08000000P000?l2000000040:gHiP0cXLX0<j7:0:gH
iP80<j7:00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:
00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV
03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0
[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh3@0oooP0`0000000`000?l000000:gHiP0203>QbP040:gHiP0c
XLX0<j7:0:gHiPd0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0
<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:
0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0
[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0e0?ooh0<0000000D0003o00000000000000000:gHiP0203>QbP030:gHiP0cXLX0
<j7:00/0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0
<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0
<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0f0?ooh0<000000P000?l200000080<j7:00<0[MSV03>QbP0cXLX02`0cXLX00`2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP03
0:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP03
03>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3P0oooP0`0000001@00
0?l0000003>QbP0cXLX0[MSV00d0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP06
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gH
iP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0i0?ooh0<0000000@0003o0000000cXLX0[MSV3@0cXLX00`2]f>H0
<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>Q
bP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H2
03>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gH
iP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>Q
bP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3X0oooP0`000000
0`000?l000000000000=03>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>Q
bP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:
03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>Q
bP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0
<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP>`3oon0300000080003o00<0000003>QbP0cXLX02P0cXLX00`2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP03
0:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP03
03>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3`0oooP100000000`00
0?l0000003>QbP0:03>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]
f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>Q
bP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP?P3oon03000000030000o`000000000000T0<j7:00<0[MSV03>QbP2]f>H0100c
XLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:
03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0
<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]
f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh3l0oooP0`0000000`000?l000000000000803>QbP03
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0c
XLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:
00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP090?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon100?ooh0<0000000<0003o
0000000000001`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV
03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100c
XLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0
[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]
f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh480oooP0P0000000`000?l000000000000603>QbP030:gHiP0cXLX0[MSV00@0<j7:
00<0[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0c
XLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>Q
bP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV
03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100c
XLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP07
0:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV
03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@`3oon0200000080003o00<0000003>Q
bP0cXLX00`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV
1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0
100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh4@0oooP0`0000000`000?l0000003>QbP0303>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP0cXLX01P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0c
XLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX0
0`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gH
iP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPA@3oon03000000030000o`000000<j7:0080
<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0
[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
3P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon16
0?ooh0<0000000L0003o000000000000<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0
<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]
f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>Q
bP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>Q
bP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPA`3oon03000000060000o`00000000000000000cXLX0[MSV100c
XLX00`2]f>H0<j7:03>QbP0603>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:
03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0
<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]
f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon180?ooh0<0000000D0003o00000000
000000000:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP04
03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]
f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:
03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP03
0:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:
03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP0`00
000010000?l0000000000000000403>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX0
0`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h4/0oooP0P00000010000?l0000000000000000303>QbP030:gHiP0cXLX0<j7:00H0<j7:00D0[MSV
03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100c
XLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0
[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]
f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh4`0oooP0P00000010000?l0000000000000000203>QbP030:gHiP0cXLX0<j7:00H0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>Q
bP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV
03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0
[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05
000000H0oooP00<000000?ooh03oon00o`3oon1>0?ooh003000000000?l0003o0080000000<0<j7:
0:gHiP0cXLX01`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX01P0c
XLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX0
1@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]
f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0c
XLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1>0?ooh0<00000
00@0003o000000000000[MSV200cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV
03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0
100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP1000003o0?ooh4h0oooP0`000000
10000?l0000000000000000703>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:
03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0
<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]
f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00P0oooP1000000H0?ooh1h0n_3V0@3oool001d0
n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPD@3oon0200000004
0000o`0000000000000000H0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0
<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gH
iP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
1`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPDP3o
on02000000040000o`0000000000000000D0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP03
0:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP03
03>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon1C0?oo
h080000000@0003o0000000000000000100cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>Q
bP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPE@3oon000`000000003o
00000002000000<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0
<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:
00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0
<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0
<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5H0oooP00<000000000o`0000000P00000203>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0c
XLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1G0?ooh003000000000?l000000080000000<0<j7:0:gHiP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100c
XLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0
[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]
f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh5L0oooP0P0000020000o`80000000D0[MSV03>QbP0cXLX0<j7:0:gHiP0403>QbP03
0:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP03
03>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5P0oooP0`0000001000
0?l0000000000000000203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX0
0`2]f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0c
XLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0
<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0
<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPFP3oon02000000060000o`00000000000000000cXLX0
[MSV100cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:00@0<j7:00@0[MSV03>QbP0c
XLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV
03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0c
XLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV
03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1K0?oo
h080000000D0003o00000000000000000:gHiP0403>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV
03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0
[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh5d0oooP00D000000000o`00000000000:gHiP0403>QbP030:gH
iP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP03
0:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>Q
bP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0
<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5h0oooP00<000000000o`00
00000P00000303>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0100cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX0
0`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h5h0oooP0P00000010000?l0000000000000000203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV
03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0
[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on0300000?l0oooPG`3oon02000000060000o`00000000000000000cXLX0[MSV200cXLX00`2]f>H0
<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]
f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>Q
bP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>Q
bP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP090?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1Q0?ooh003000000000?l000000080000000<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0
102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:
03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:
03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPHP3oon000`000000003o0000o`02000000P0<j7:00<0[MSV
03>QbP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0
[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh6<0oooP0P0000000`000?l000000000000703>QbP030:gHiP0c
XLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gH
iP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1T0?ooh080000000<0003o0000000000001P0cXLX00`2]f>H0<j7:
03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0
<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]
f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP02
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]
f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPI@3oon02000000040000o`0000000000000000@0<j7:00<0[MSV03>Q
bP0cXLX0100cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV
03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0
[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh6H0oooP0P00000010000?l0000000000000000303>QbP030:gHiP0c
XLX0<j7:00@0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gH
iP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1W0?ooh080000000<0003o0000000000000`0cXLX00`2]f>H0<j7:
03>QbP0403>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0
<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]
f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP02
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]
f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPJ03oon02000000060000o`00000000000000000cXLX0[MSV1P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV
1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0
100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh6T0oooP0P0000001@000?l00000000000000000[MSV00H0<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX0
0`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Z0?ooh080
000000@0003o000000000000[MSV1P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0
<j7:00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0c
XLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6/0oooP0P0000000`000?l0000000000006
03>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>Q
bP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPK03oon02000000030000o`000000000000D0<j7:00@0[MSV03>QbP0cXLX0[MSV
0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0c
XLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]
f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0c
XLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1]0?ooh0800000
00@0003o00000000000000000`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP030:gHiP0cXLX0<j7:
00D0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0
<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0
<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6h0oooP0P00000010000?l00000000000000002
03>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H0<j7:03>Q
bP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3o
on1_0?ooh08000000P000?l010000000<j7:03>QbP2]f>H203>QbP040:gHiP0cXLX0<j7:0:gHiPL0
<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:
0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV
03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX02@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPL03oon03000000040000o`00000000000:gHiP80<j7:00@0[MSV03>Q
bP0cXLX0[MSV1`0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0
100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL@3oon03000000030000o`000000
00000080<j7:00@0[MSV03>QbP0cXLX0[MSV1`0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gH
iP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0
<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gH
iP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPLP3o
on03000000050000o`000000<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gH
iP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1c0?ooh0<0000000@0003o000000000000[MSV0P0cXLX00`2]f>H0
<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]
f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1d0?ooh0<0000000<0003o00000000
00000P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX0
0`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1e0?ooh0<0
000000D0003o000000000000<j7:0:gHiP0703>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV
03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0c
XLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV
03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1f0?oo
h0<0000000@0003o000000000000[MSV1`0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0c
XLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:
00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPN03oon02
000000030000o`000000000000L0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gH
iP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>Q
bP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7T0oooP0P000000
0`000?l000000000000603>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0c
XLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:
03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1j0?ooh080000000<0003o
0000000cXLX01@0cXLX0102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0
100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPN`3oon02000000030000o`000000
000000@0<j7:00@0[MSV03>QbP0cXLX0[MSV1@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0c
XLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP0P0000000`000?l0000000000003
03>QbP040:gHiP0cXLX0<j7:0:gHiPD0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gH
iP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>Q
bP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1l0?ooh0<0000000<0003o0000000000000P0cXLX0
102]f>H0<j7:03>QbP2]f>H503>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:
03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:
03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<00000o`3oon1m0?ooh0<0000000D0003o000000000000<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7l0oooP0P00000010000?l000000000002]f>H203>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0
[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
3P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon20
0?ooh080000000<0003o0000000000000P0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0
<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0
[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0
<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP@3oon020000
00050000o`000000000003>QbP2]f>H01@0cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0
<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0
<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh880oooP0P00000010000?l000000000002]f>H5
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP04
03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPP`3oon02000000030000o`000000[MSV00D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]
f>H0<j7:03>QbP0203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon240?ooh080000000<0003o00000000
0000100cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]
f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh8@0oooP0`0000000`000?l000000000000303>QbP030:gHiP0cXLX0<j7:00<0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0c
XLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP03
03>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQ@3oon03000000030000o`00
000000000080<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon270?ooh080000000D0003o000000000000<j7:0:gHiP0503>QbP030:gHiP0c
XLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8P0oooP0P00000010000?l000000000002]
f>H503>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gH
iP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>Q
bP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8T0oooP0P000000
0`000?l000000000000503>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX0
0`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h8X0oooP0P0000000`000?l000000000000403>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>Q
bP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh8/0oooP0P0000000`000?l000000000000303>QbP030:gHiP0cXLX0<j7:0080
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>Q
bP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon0300000?l0oooPS03oon02000000030000o`00000000000080<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0
<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0
<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP090?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2=0?ooh080000000D0003o000000000000<j7:0:gHiP0403>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2>0?ooh080000000@0003o000000000000[MSV100cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV00h0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPS`3oon02000000030000o`000000000000@0<j7:00D0[MSV03>QbP0cXLX0<j7:
0:gHiP0>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100c
XLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh900oooP0P0000000`000?l000000000000303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03P0c
XLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV
03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2@0?oo
h080000000<0003o0000000000000`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:00<0[MSV
03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:
00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT@3oon0200000003
0000o`00000000000080<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0>03>QbP030:gHiP0cXLX0<j7:
00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP03
0:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9<0oooP00H000000000o`000000
000003>QbP2]f>H303>QbP030:gHiP0cXLX0<j7:00`0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]
f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0c
XLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT`3oon02000000040000o`00000000000:gHiP<0
<j7:00<0[MSV03>QbP0cXLX0300cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2D0?ooh080000000<0003o0000000000000`0cXLX00`2]f>H0<j7:03>Q
bP0<03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX0
0`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h9D0oooP0P0000001P000?l00000000000000000<j7:0:gHiPh0<j7:00<0[MSV03>QbP0cXLX0100c
XLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP07
0:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV
03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPUP3oon02000000050000o`0000000000
0000002]f>H03P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2G0?ooh080000000@0003o000000000000[MSV3P0cXLX00`2]f>H0<j7:03>QbP0403>Q
bP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0
[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ00oooP100000070?ooh0030000003oon00oooP0?l0oooPV@3oon0010000000003o
00000000000>03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0
100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?oo
h0080?ooh0030000003oon00oooP0?l0oooPV@3oon02000000030000o`000000000000d0<j7:00<0
[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0
<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0030000003oon00oooP00L0oooP1000003o0?oo
h9T0oooP00<000000000o`0000000P00000<03>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>Q
bP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX0203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000
003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon2K0?ooh003000000000?l0000000800000
2`0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3o
on000`000000oooP0?ooh03o0?ooh9`0oooP00<000000000o`0000000P00000:03>QbP030:gHiP0c
XLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon2M0?oo
h003000000000?l00000008000002@0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2N0?ooh003000000000?l0000000800000200cXLX00`2]f>H0<j7:
03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2O0?ooh003000000000?l0
0000008000001`0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2P0?ooh003000000000?l00000008000001P0cXLX00`2]f>H0<j7:03>QbP0403>QbP03
0:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV
03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:
03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Q0?ooh003000000000?l00000008000001@0c
XLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV
03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Q0?oo
h080000000<0003o0000000000001@0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2R0?ooh080000000@0003o00000000000000000`0cXLX00`2]f>H0
<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0
100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2S0?ooh080000000@0
003o00000000000000000P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2T0?ooh080000000<0003o0000000000000P0cXLX00`2]f>H0<j7:03>QbP04
03>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2V0?ooh006000000000?l000000000
000cXLX0[MSV1P0cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:
00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPYP3oon0200000004
0000o`00000000000:gHiPH0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0
<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPY`3oon02000000030000
o`000000000000H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>Q
bP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02@3oon03000001P0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ03oon02000000030000o`000000
<j7:00D0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:T0oooP00@000000000o`00
000000001@0cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ@3oon02000000040000
o`0000000000000000<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:
03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP0P00
000010000?l0000000000000000203>QbP030:gHiP0cXLX0<j7:0080<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0
[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2[
0?ooh080000000<0003o0000000000000P0cXLX00`2]f>H0<j7:03>QbP0203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>Q
bP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP[@3oon001P000000003o000000000000<j7:0:gHiP@0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2]0?ooh080
000000@0003o000000000000[MSV100cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP03
0:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:h0oooP0P0000000`000?l00000
0000000403>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:
03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP[`3oon02000000030000o`000000000000<0<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2`0?ooh080000000<0003o0000000cXLX00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:
03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP0P00
00002`000?l0000003>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV
03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:
03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh0<0000000X0003o0000000cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0
100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh;80oooP0`0000002@000?l000000:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2c0?ooh0<0000000P0003o0000000cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV
03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00T0oooP0`00000H
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;@0oooP0`0000001`00
0?l000000:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]
f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh;D0oooP0P0000001`000?l000000000000cXLX0[MSV03>QbP2]f>H00`0cXLX01`2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;H0oooP0P0000001P000?l000000000002]
f>H0<j7:0:gHiP<0<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>Q
bP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh080
000000D0003o000000000000<j7:0:gHiP0303>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gH
iP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP^03oon02000000040000o`00000000000:gHiP<0<j7:00L0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2h0?ooh0<0000000<0003o0000002]f>H00`0cXLX01`2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh;T0oooP0`0000000`000?l0000003>QbP0203>QbP07
0:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV
03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^`3oon0010000000003o000000000002
03>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^`3oon02000000050000o`00
0000000003>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_03oon02000000040000o`00
000000000:gHiP<0<j7:00<0[MSV03>QbP2]f>H0100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;d0oooP0P0000000`000?l000000000
000303>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n0?ooh080000000<0003o0000000000000P0cXLX0
0`2]f>H0<j7:0:gHiP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP_`3oon02000000070000o`000000000003>QbP2]f>H0<j7:0:gH
iP0403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP`03oon0020000000003o000000000000<j7:0:gHiP0cXLX0[MSV100cXLX00`2]f>H0
<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP`03oon02000000060000
o`00000000000:gHiP0cXLX0[MSV100cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX02@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP`@3oon02000000050000o`000000000003>QbP2]f>H0100cXLX00`2]
f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<80
oooP0P00000010000?l000000000002]f>H403>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP``3oon02000000030000o`000000000000@0
<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon340?ooh080000000<0003o0000000000000`0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<D0oooP00@000000000o`0000000000
0`0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh<H0oooP00@000000000o`00000000000P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<L0oooP00H000000000o`0000000000
03>QbP2]f>H603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<L0oooP
0P00000010000?l000000000002]f>H603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<P0oooP0P0000000`000?l000000000000603>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<T0oooP0P0000000`000?l000000000000503>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<X0oooP00<000000000o`0000000P000004
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh</0oooP00@000000000
o`0000000000100cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3<0?oo
h004000000000?l00000000000<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon3<0?oo
h080000000<0003o0000000000000P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00T0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<d0
oooP0P0000001@000?l000000000000cXLX0[MSV00@0<j7:00<0[MSV03>QbP0cXLX02`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<h0
oooP0P00000010000?l000000000002]f>H403>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3?0?ooh080
000000<0003o0000002]f>H0100cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd03oon0010000000003o
00000000000403>QbP030:gHiP0cXLX0<j7:00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3@0?ooh080000000<0003o000000000000
0`0cXLX00`2]f>H0<j7:03>QbP0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPd@3oon02000000030000o`000000<j7:0080<j7:00<0
[MSV03>QbP0cXLX02`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh=80oooP0P0000001@000?l000000000000cXLX0[MSV0080<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh=@0oooP00D000000000o`00000000000:gHiP0203>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3D0?ooh080000000<0003o
0000002]f>H00P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPe03oon03000000040000o`000000<j7:03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3E0?oo
h080000000@0003o000000000000<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon3F0?ooh080000000<0003o0000
000000002`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000
oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPe`3oon02000000030000o`0000000000
00X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03o
on001P3oon0400000?l0oooPe`3oon02000000030000o`000000oooP00H0oooP1000000H0?ooh1h0
n_3V0@3oool001d0n_3V4`3oon000`000000oooP0?ooh0050?ooh0030000003oon00oooP0?l0oooP
f@3oon02000000/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@0
00000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H400000080n_3V2000
00020?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V00000000
000010000000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V
00<000002@3jl>H500000080n_3V100000020?[`iPD000004P3jl>H6000000H0n_3V00<000000?[`
iP3jl>H0103jl>H3000000040?[`iP000000000000000>@0n_3V0@3oool00=d0n_3V0P0000020?[`
iP8000000`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`
iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V00000000
0000i@3jl>H10?ooo`00g@3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP800000
1@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H00000
0000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000`0n_3V1@0000050?[`iP8000001P3jl>H5000000H0n_3V0`00003V0?[`iP40
oooo003M0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`
iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P000000
0`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F
0?[`iP800000203jl>H00`000000n_3V0?[`iP060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H20000
0080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H0
00000?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`
iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`
iP000000n_3V0180n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H00000
0000003U0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103j
l>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3j
l>H2000000D0n_3V0`0000000`3jl>H0000000000007000000/0n_3V1@0000020?[`iP@000000P3j
l>H3000000030?[`iP000000000001<0n_3V0P00000?0?[`iP<0000000D0n_3V0000000000000000
0?[`iP0400000=l0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<0
00000?[`iP3jl>H0603jl>H200000240n_3V1000000H0?[`iP030000003jl>H0n_3V0=l0n_3V0@3o
ool00=`0n_3V1P0000040?[`iP800000;`3jl>H5000001/0n_3V0`00000Q0?[`iP8000006@3jl>H0
0`000000n_3V0?[`iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<000000?[`iP3jl>H0g@3jl>H10?oo
o`00o`3jl>Ie0?[`iP040000003jl>H0n_3V00000=l0n_3V0@3oool00?l0n_3VMP3jl>H200000>00
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02513 .01472 L
.02513 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02513 .01472 L
.02513 .16187 L
s
1 .894 .882 r
.02513 .16187 m
.02513 .01472 L
.02612 .01472 L
.02612 .16187 L
F
.804 .522 .247 r
.02513 .16187 m
.02513 .01472 L
.02612 .01472 L
.02612 .16187 L
s
1 .894 .882 r
.02612 .16187 m
.02612 .01472 L
.02833 .01472 L
.02833 .16187 L
F
.804 .522 .247 r
.02612 .16187 m
.02612 .01472 L
.02833 .01472 L
.02833 .16187 L
s
1 .894 .882 r
.02833 .16187 m
.02833 .01473 L
.02939 .01473 L
.02939 .16187 L
F
.804 .522 .247 r
.02833 .16187 m
.02833 .01473 L
.02939 .01473 L
.02939 .16187 L
s
1 .894 .882 r
.02939 .16187 m
.02939 .01475 L
.03137 .01475 L
.03137 .16187 L
F
.804 .522 .247 r
.02939 .16187 m
.02939 .01475 L
.03137 .01475 L
.03137 .16187 L
s
1 .894 .882 r
.03137 .16187 m
.03137 .01476 L
.03381 .01476 L
.03381 .16187 L
F
.804 .522 .247 r
.03137 .16187 m
.03137 .01476 L
.03381 .01476 L
.03381 .16187 L
s
1 .894 .882 r
.03381 .16187 m
.03381 .0148 L
.03494 .0148 L
.03494 .16187 L
F
.804 .522 .247 r
.03381 .16187 m
.03381 .0148 L
.03494 .0148 L
.03494 .16187 L
s
1 .894 .882 r
.03494 .16187 m
.03494 .01481 L
.03707 .01481 L
.03707 .16187 L
F
.804 .522 .247 r
.03494 .16187 m
.03494 .01481 L
.03707 .01481 L
.03707 .16187 L
s
1 .894 .882 r
.03707 .16187 m
.03707 .01485 L
.03903 .01485 L
.03903 .16187 L
F
.804 .522 .247 r
.03707 .16187 m
.03707 .01485 L
.03903 .01485 L
.03903 .16187 L
s
1 .894 .882 r
.03903 .16187 m
.03903 .01488 L
.04157 .01488 L
.04157 .16187 L
F
.804 .522 .247 r
.03903 .16187 m
.03903 .01488 L
.04157 .01488 L
.04157 .16187 L
s
1 .894 .882 r
.04157 .16187 m
.04157 .01498 L
.04427 .01498 L
.04427 .16187 L
F
.804 .522 .247 r
.04157 .16187 m
.04157 .01498 L
.04427 .01498 L
.04427 .16187 L
s
1 .894 .882 r
.04427 .16187 m
.04427 .01499 L
.04648 .01499 L
.04648 .16187 L
F
.804 .522 .247 r
.04427 .16187 m
.04427 .01499 L
.04648 .01499 L
.04648 .16187 L
s
1 .894 .882 r
.04648 .16187 m
.04648 .01505 L
.04893 .01505 L
.04893 .16187 L
F
.804 .522 .247 r
.04648 .16187 m
.04648 .01505 L
.04893 .01505 L
.04893 .16187 L
s
1 .894 .882 r
.04893 .16187 m
.04893 .01516 L
.05011 .01516 L
.05011 .16187 L
F
.804 .522 .247 r
.04893 .16187 m
.04893 .01516 L
.05011 .01516 L
.05011 .16187 L
s
1 .894 .882 r
.05011 .16187 m
.05011 .0152 L
.05156 .0152 L
.05156 .16187 L
F
.804 .522 .247 r
.05011 .16187 m
.05011 .0152 L
.05156 .0152 L
.05156 .16187 L
s
1 .894 .882 r
.05156 .16187 m
.05156 .01523 L
.053 .01523 L
.053 .16187 L
F
.804 .522 .247 r
.05156 .16187 m
.05156 .01523 L
.053 .01523 L
.053 .16187 L
s
1 .894 .882 r
.053 .16187 m
.053 .01532 L
.05492 .01532 L
.05492 .16187 L
F
.804 .522 .247 r
.053 .16187 m
.053 .01532 L
.05492 .01532 L
.05492 .16187 L
s
1 .894 .882 r
.05492 .16187 m
.05492 .01536 L
.05704 .01536 L
.05704 .16187 L
F
.804 .522 .247 r
.05492 .16187 m
.05492 .01536 L
.05704 .01536 L
.05704 .16187 L
s
1 .894 .882 r
.05704 .16187 m
.05704 .01553 L
.05984 .01553 L
.05984 .16187 L
F
.804 .522 .247 r
.05704 .16187 m
.05704 .01553 L
.05984 .01553 L
.05984 .16187 L
s
1 .894 .882 r
.05984 .16187 m
.05984 .01557 L
.06143 .01557 L
.06143 .16187 L
F
.804 .522 .247 r
.05984 .16187 m
.05984 .01557 L
.06143 .01557 L
.06143 .16187 L
s
1 .894 .882 r
.06143 .16187 m
.06143 .01568 L
.06275 .01568 L
.06275 .16187 L
F
.804 .522 .247 r
.06143 .16187 m
.06143 .01568 L
.06275 .01568 L
.06275 .16187 L
s
1 .894 .882 r
.06275 .16187 m
.06275 .01573 L
.06375 .01573 L
.06375 .16187 L
F
.804 .522 .247 r
.06275 .16187 m
.06275 .01573 L
.06375 .01573 L
.06375 .16187 L
s
1 .894 .882 r
.06375 .16187 m
.06375 .01582 L
.06598 .01582 L
.06598 .16187 L
F
.804 .522 .247 r
.06375 .16187 m
.06375 .01582 L
.06598 .01582 L
.06598 .16187 L
s
1 .894 .882 r
.06598 .16187 m
.06598 .01597 L
.06814 .01597 L
.06814 .16187 L
F
.804 .522 .247 r
.06598 .16187 m
.06598 .01597 L
.06814 .01597 L
.06814 .16187 L
s
1 .894 .882 r
.06814 .16187 m
.06814 .01601 L
.069 .01601 L
.069 .16187 L
F
.804 .522 .247 r
.06814 .16187 m
.06814 .01601 L
.069 .01601 L
.069 .16187 L
s
1 .894 .882 r
.069 .16187 m
.069 .01607 L
.06985 .01607 L
.06985 .16187 L
F
.804 .522 .247 r
.069 .16187 m
.069 .01607 L
.06985 .01607 L
.06985 .16187 L
s
1 .894 .882 r
.06985 .16187 m
.06985 .01612 L
.07073 .01612 L
.07073 .16187 L
F
.804 .522 .247 r
.06985 .16187 m
.06985 .01612 L
.07073 .01612 L
.07073 .16187 L
s
1 .894 .882 r
.07073 .16187 m
.07073 .01617 L
.07268 .01617 L
.07268 .16187 L
F
.804 .522 .247 r
.07073 .16187 m
.07073 .01617 L
.07268 .01617 L
.07268 .16187 L
s
1 .894 .882 r
.07268 .16187 m
.07268 .01631 L
.07441 .01631 L
.07441 .16187 L
F
.804 .522 .247 r
.07268 .16187 m
.07268 .01631 L
.07441 .01631 L
.07441 .16187 L
s
1 .894 .882 r
.07441 .16187 m
.07441 .01639 L
.07568 .01639 L
.07568 .16187 L
F
.804 .522 .247 r
.07441 .16187 m
.07441 .01639 L
.07568 .01639 L
.07568 .16187 L
s
1 .894 .882 r
.07568 .16187 m
.07568 .01655 L
.07827 .01655 L
.07827 .16187 L
F
.804 .522 .247 r
.07568 .16187 m
.07568 .01655 L
.07827 .01655 L
.07827 .16187 L
s
1 .894 .882 r
.07827 .16187 m
.07827 .01676 L
.08093 .01676 L
.08093 .16187 L
F
.804 .522 .247 r
.07827 .16187 m
.07827 .01676 L
.08093 .01676 L
.08093 .16187 L
s
1 .894 .882 r
.08093 .16187 m
.08093 .01697 L
.08355 .01697 L
.08355 .16187 L
F
.804 .522 .247 r
.08093 .16187 m
.08093 .01697 L
.08355 .01697 L
.08355 .16187 L
s
1 .894 .882 r
.08355 .16187 m
.08355 .01714 L
.08512 .01714 L
.08512 .16187 L
F
.804 .522 .247 r
.08355 .16187 m
.08355 .01714 L
.08512 .01714 L
.08512 .16187 L
s
1 .894 .882 r
.08512 .16187 m
.08512 .01729 L
.08786 .01729 L
.08786 .16187 L
F
.804 .522 .247 r
.08512 .16187 m
.08512 .01729 L
.08786 .01729 L
.08786 .16187 L
s
1 .894 .882 r
.08786 .16187 m
.08786 .01745 L
.08917 .01745 L
.08917 .16187 L
F
.804 .522 .247 r
.08786 .16187 m
.08786 .01745 L
.08917 .01745 L
.08917 .16187 L
s
1 .894 .882 r
.08917 .16187 m
.08917 .01755 L
.09019 .01755 L
.09019 .16187 L
F
.804 .522 .247 r
.08917 .16187 m
.08917 .01755 L
.09019 .01755 L
.09019 .16187 L
s
1 .894 .882 r
.09019 .16187 m
.09019 .01768 L
.09144 .01768 L
.09144 .16187 L
F
.804 .522 .247 r
.09019 .16187 m
.09019 .01768 L
.09144 .01768 L
.09144 .16187 L
s
1 .894 .882 r
.09144 .16187 m
.09144 .01785 L
.09358 .01785 L
.09358 .16187 L
F
.804 .522 .247 r
.09144 .16187 m
.09144 .01785 L
.09358 .01785 L
.09358 .16187 L
s
1 .894 .882 r
.09358 .16187 m
.09358 .01794 L
.0963 .01794 L
.0963 .16187 L
F
.804 .522 .247 r
.09358 .16187 m
.09358 .01794 L
.0963 .01794 L
.0963 .16187 L
s
1 .894 .882 r
.0963 .16187 m
.0963 .01831 L
.09825 .01831 L
.09825 .16187 L
F
.804 .522 .247 r
.0963 .16187 m
.0963 .01831 L
.09825 .01831 L
.09825 .16187 L
s
1 .894 .882 r
.09825 .16187 m
.09825 .01845 L
.10023 .01845 L
.10023 .16187 L
F
.804 .522 .247 r
.09825 .16187 m
.09825 .01845 L
.10023 .01845 L
.10023 .16187 L
s
1 .894 .882 r
.10023 .16187 m
.10023 .01852 L
.10241 .01852 L
.10241 .16187 L
F
.804 .522 .247 r
.10023 .16187 m
.10023 .01852 L
.10241 .01852 L
.10241 .16187 L
s
1 .894 .882 r
.10241 .16187 m
.10241 .01876 L
.1044 .01876 L
.1044 .16187 L
F
.804 .522 .247 r
.10241 .16187 m
.10241 .01876 L
.1044 .01876 L
.1044 .16187 L
s
1 .894 .882 r
.1044 .16187 m
.1044 .01897 L
.10588 .01897 L
.10588 .16187 L
F
.804 .522 .247 r
.1044 .16187 m
.1044 .01897 L
.10588 .01897 L
.10588 .16187 L
s
1 .894 .882 r
.10588 .16187 m
.10588 .0191 L
.10771 .0191 L
.10771 .16187 L
F
.804 .522 .247 r
.10588 .16187 m
.10588 .0191 L
.10771 .0191 L
.10771 .16187 L
s
1 .894 .882 r
.10771 .16187 m
.10771 .01943 L
.11052 .01943 L
.11052 .16187 L
F
.804 .522 .247 r
.10771 .16187 m
.10771 .01943 L
.11052 .01943 L
.11052 .16187 L
s
1 .894 .882 r
.11052 .16187 m
.11052 .01968 L
.11319 .01968 L
.11319 .16187 L
F
.804 .522 .247 r
.11052 .16187 m
.11052 .01968 L
.11319 .01968 L
.11319 .16187 L
s
1 .894 .882 r
.11319 .16187 m
.11319 .02005 L
.11466 .02005 L
.11466 .16187 L
F
.804 .522 .247 r
.11319 .16187 m
.11319 .02005 L
.11466 .02005 L
.11466 .16187 L
s
1 .894 .882 r
.11466 .16187 m
.11466 .02017 L
.1165 .02017 L
.1165 .16187 L
F
.804 .522 .247 r
.11466 .16187 m
.11466 .02017 L
.1165 .02017 L
.1165 .16187 L
s
1 .894 .882 r
.1165 .16187 m
.1165 .02062 L
.11928 .02062 L
.11928 .16187 L
F
.804 .522 .247 r
.1165 .16187 m
.1165 .02062 L
.11928 .02062 L
.11928 .16187 L
s
1 .894 .882 r
.11928 .16187 m
.11928 .02064 L
.12086 .02064 L
.12086 .16187 L
F
.804 .522 .247 r
.11928 .16187 m
.11928 .02064 L
.12086 .02064 L
.12086 .16187 L
s
1 .894 .882 r
.12086 .16187 m
.12086 .02098 L
.12345 .02098 L
.12345 .16187 L
F
.804 .522 .247 r
.12086 .16187 m
.12086 .02098 L
.12345 .02098 L
.12345 .16187 L
s
1 .894 .882 r
.12345 .16187 m
.12345 .0212 L
.12487 .0212 L
.12487 .16187 L
F
.804 .522 .247 r
.12345 .16187 m
.12345 .0212 L
.12487 .0212 L
.12487 .16187 L
s
1 .894 .882 r
.12487 .16187 m
.12487 .0214 L
.12592 .0214 L
.12592 .16187 L
F
.804 .522 .247 r
.12487 .16187 m
.12487 .0214 L
.12592 .0214 L
.12592 .16187 L
s
1 .894 .882 r
.12592 .16187 m
.12592 .02158 L
.12768 .02158 L
.12768 .16187 L
F
.804 .522 .247 r
.12592 .16187 m
.12592 .02158 L
.12768 .02158 L
.12768 .16187 L
s
1 .894 .882 r
.12768 .16187 m
.12768 .022 L
.1305 .022 L
.1305 .16187 L
F
.804 .522 .247 r
.12768 .16187 m
.12768 .022 L
.1305 .022 L
.1305 .16187 L
s
1 .894 .882 r
.1305 .16187 m
.1305 .02223 L
.1332 .02223 L
.1332 .16187 L
F
.804 .522 .247 r
.1305 .16187 m
.1305 .02223 L
.1332 .02223 L
.1332 .16187 L
s
1 .894 .882 r
.1332 .16187 m
.1332 .02261 L
.13435 .02261 L
.13435 .16187 L
F
.804 .522 .247 r
.1332 .16187 m
.1332 .02261 L
.13435 .02261 L
.13435 .16187 L
s
1 .894 .882 r
.13435 .16187 m
.13435 .02279 L
.13566 .02279 L
.13566 .16187 L
F
.804 .522 .247 r
.13435 .16187 m
.13435 .02279 L
.13566 .02279 L
.13566 .16187 L
s
1 .894 .882 r
.13566 .16187 m
.13566 .02285 L
.13832 .02285 L
.13832 .16187 L
F
.804 .522 .247 r
.13566 .16187 m
.13566 .02285 L
.13832 .02285 L
.13832 .16187 L
s
1 .894 .882 r
.13832 .16187 m
.13832 .02335 L
.14061 .02335 L
.14061 .16187 L
F
.804 .522 .247 r
.13832 .16187 m
.13832 .02335 L
.14061 .02335 L
.14061 .16187 L
s
1 .894 .882 r
.14061 .16187 m
.14061 .02384 L
.14247 .02384 L
.14247 .16187 L
F
.804 .522 .247 r
.14061 .16187 m
.14061 .02384 L
.14247 .02384 L
.14247 .16187 L
s
1 .894 .882 r
.14247 .16187 m
.14247 .02396 L
.14391 .02396 L
.14391 .16187 L
F
.804 .522 .247 r
.14247 .16187 m
.14247 .02396 L
.14391 .02396 L
.14391 .16187 L
s
1 .894 .882 r
.14391 .16187 m
.14391 .02409 L
.14547 .02409 L
.14547 .16187 L
F
.804 .522 .247 r
.14391 .16187 m
.14391 .02409 L
.14547 .02409 L
.14547 .16187 L
s
1 .894 .882 r
.14547 .16187 m
.14547 .02444 L
.14664 .02444 L
.14664 .16187 L
F
.804 .522 .247 r
.14547 .16187 m
.14547 .02444 L
.14664 .02444 L
.14664 .16187 L
s
1 .894 .882 r
.14664 .16187 m
.14664 .02487 L
.14916 .02487 L
.14916 .16187 L
F
.804 .522 .247 r
.14664 .16187 m
.14664 .02487 L
.14916 .02487 L
.14916 .16187 L
s
1 .894 .882 r
.14916 .16187 m
.14916 .02504 L
.15146 .02504 L
.15146 .16187 L
F
.804 .522 .247 r
.14916 .16187 m
.14916 .02504 L
.15146 .02504 L
.15146 .16187 L
s
1 .894 .882 r
.15146 .16187 m
.15146 .02542 L
.1524 .02542 L
.1524 .16187 L
F
.804 .522 .247 r
.15146 .16187 m
.15146 .02542 L
.1524 .02542 L
.1524 .16187 L
s
1 .894 .882 r
.1524 .16187 m
.1524 .02566 L
.15459 .02566 L
.15459 .16187 L
F
.804 .522 .247 r
.1524 .16187 m
.1524 .02566 L
.15459 .02566 L
.15459 .16187 L
s
1 .894 .882 r
.15459 .16187 m
.15459 .026 L
.15715 .026 L
.15715 .16187 L
F
.804 .522 .247 r
.15459 .16187 m
.15459 .026 L
.15715 .026 L
.15715 .16187 L
s
1 .894 .882 r
.15715 .16187 m
.15715 .02627 L
.15962 .02627 L
.15962 .16187 L
F
.804 .522 .247 r
.15715 .16187 m
.15715 .02627 L
.15962 .02627 L
.15962 .16187 L
s
1 .894 .882 r
.15962 .16187 m
.15962 .02706 L
.16194 .02706 L
.16194 .16187 L
F
.804 .522 .247 r
.15962 .16187 m
.15962 .02706 L
.16194 .02706 L
.16194 .16187 L
s
1 .894 .882 r
.16194 .16187 m
.16194 .02713 L
.16314 .02713 L
.16314 .16187 L
F
.804 .522 .247 r
.16194 .16187 m
.16194 .02713 L
.16314 .02713 L
.16314 .16187 L
s
1 .894 .882 r
.16314 .16187 m
.16314 .02753 L
.16578 .02753 L
.16578 .16187 L
F
.804 .522 .247 r
.16314 .16187 m
.16314 .02753 L
.16578 .02753 L
.16578 .16187 L
s
1 .894 .882 r
.16578 .16187 m
.16578 .02811 L
.16752 .02811 L
.16752 .16187 L
F
.804 .522 .247 r
.16578 .16187 m
.16578 .02811 L
.16752 .02811 L
.16752 .16187 L
s
1 .894 .882 r
.16752 .16187 m
.16752 .02834 L
.17009 .02834 L
.17009 .16187 L
F
.804 .522 .247 r
.16752 .16187 m
.16752 .02834 L
.17009 .02834 L
.17009 .16187 L
s
1 .894 .882 r
.17009 .16187 m
.17009 .02907 L
.17272 .02907 L
.17272 .16187 L
F
.804 .522 .247 r
.17009 .16187 m
.17009 .02907 L
.17272 .02907 L
.17272 .16187 L
s
1 .894 .882 r
.17272 .16187 m
.17272 .02911 L
.17516 .02911 L
.17516 .16187 L
F
.804 .522 .247 r
.17272 .16187 m
.17272 .02911 L
.17516 .02911 L
.17516 .16187 L
s
1 .894 .882 r
.17516 .16187 m
.17516 .0299 L
.17799 .0299 L
.17799 .16187 L
F
.804 .522 .247 r
.17516 .16187 m
.17516 .0299 L
.17799 .0299 L
.17799 .16187 L
s
1 .894 .882 r
.17799 .16187 m
.17799 .03053 L
.18059 .03053 L
.18059 .16187 L
F
.804 .522 .247 r
.17799 .16187 m
.17799 .03053 L
.18059 .03053 L
.18059 .16187 L
s
1 .894 .882 r
.18059 .16187 m
.18059 .03101 L
.18337 .03101 L
.18337 .16187 L
F
.804 .522 .247 r
.18059 .16187 m
.18059 .03101 L
.18337 .03101 L
.18337 .16187 L
s
1 .894 .882 r
.18337 .16187 m
.18337 .03133 L
.18552 .03133 L
.18552 .16187 L
F
.804 .522 .247 r
.18337 .16187 m
.18337 .03133 L
.18552 .03133 L
.18552 .16187 L
s
1 .894 .882 r
.18552 .16187 m
.18552 .03208 L
.18789 .03208 L
.18789 .16187 L
F
.804 .522 .247 r
.18552 .16187 m
.18552 .03208 L
.18789 .03208 L
.18789 .16187 L
s
1 .894 .882 r
.18789 .16187 m
.18789 .0326 L
.19067 .0326 L
.19067 .16187 L
F
.804 .522 .247 r
.18789 .16187 m
.18789 .0326 L
.19067 .0326 L
.19067 .16187 L
s
1 .894 .882 r
.19067 .16187 m
.19067 .03285 L
.19202 .03285 L
.19202 .16187 L
F
.804 .522 .247 r
.19067 .16187 m
.19067 .03285 L
.19202 .03285 L
.19202 .16187 L
s
1 .894 .882 r
.19202 .16187 m
.19202 .03314 L
.19316 .03314 L
.19316 .16187 L
F
.804 .522 .247 r
.19202 .16187 m
.19202 .03314 L
.19316 .03314 L
.19316 .16187 L
s
1 .894 .882 r
.19316 .16187 m
.19316 .03345 L
.19495 .03345 L
.19495 .16187 L
F
.804 .522 .247 r
.19316 .16187 m
.19316 .03345 L
.19495 .03345 L
.19495 .16187 L
s
1 .894 .882 r
.19495 .16187 m
.19495 .03401 L
.19702 .03401 L
.19702 .16187 L
F
.804 .522 .247 r
.19495 .16187 m
.19495 .03401 L
.19702 .03401 L
.19702 .16187 L
s
1 .894 .882 r
.19702 .16187 m
.19702 .03432 L
.19805 .03432 L
.19805 .16187 L
F
.804 .522 .247 r
.19702 .16187 m
.19702 .03432 L
.19805 .03432 L
.19805 .16187 L
s
1 .894 .882 r
.19805 .16187 m
.19805 .03453 L
.19952 .03453 L
.19952 .16187 L
F
.804 .522 .247 r
.19805 .16187 m
.19805 .03453 L
.19952 .03453 L
.19952 .16187 L
s
1 .894 .882 r
.19952 .16187 m
.19952 .03527 L
.20186 .03527 L
.20186 .16187 L
F
.804 .522 .247 r
.19952 .16187 m
.19952 .03527 L
.20186 .03527 L
.20186 .16187 L
s
1 .894 .882 r
.20186 .16187 m
.20186 .03567 L
.20384 .03567 L
.20384 .16187 L
F
.804 .522 .247 r
.20186 .16187 m
.20186 .03567 L
.20384 .03567 L
.20384 .16187 L
s
1 .894 .882 r
.20384 .16187 m
.20384 .03614 L
.20554 .03614 L
.20554 .16187 L
F
.804 .522 .247 r
.20384 .16187 m
.20384 .03614 L
.20554 .03614 L
.20554 .16187 L
s
1 .894 .882 r
.20554 .16187 m
.20554 .03653 L
.20729 .03653 L
.20729 .16187 L
F
.804 .522 .247 r
.20554 .16187 m
.20554 .03653 L
.20729 .03653 L
.20729 .16187 L
s
1 .894 .882 r
.20729 .16187 m
.20729 .03715 L
.21 .03715 L
.21 .16187 L
F
.804 .522 .247 r
.20729 .16187 m
.20729 .03715 L
.21 .03715 L
.21 .16187 L
s
1 .894 .882 r
.21 .16187 m
.21 .03776 L
.21252 .03776 L
.21252 .16187 L
F
.804 .522 .247 r
.21 .16187 m
.21 .03776 L
.21252 .03776 L
.21252 .16187 L
s
1 .894 .882 r
.21252 .16187 m
.21252 .03809 L
.21387 .03809 L
.21387 .16187 L
F
.804 .522 .247 r
.21252 .16187 m
.21252 .03809 L
.21387 .03809 L
.21387 .16187 L
s
1 .894 .882 r
.21387 .16187 m
.21387 .03838 L
.21583 .03838 L
.21583 .16187 L
F
.804 .522 .247 r
.21387 .16187 m
.21387 .03838 L
.21583 .03838 L
.21583 .16187 L
s
1 .894 .882 r
.21583 .16187 m
.21583 .03907 L
.21766 .03907 L
.21766 .16187 L
F
.804 .522 .247 r
.21583 .16187 m
.21583 .03907 L
.21766 .03907 L
.21766 .16187 L
s
1 .894 .882 r
.21766 .16187 m
.21766 .0394 L
.22045 .0394 L
.22045 .16187 L
F
.804 .522 .247 r
.21766 .16187 m
.21766 .0394 L
.22045 .0394 L
.22045 .16187 L
s
1 .894 .882 r
.22045 .16187 m
.22045 .04016 L
.22201 .04016 L
.22201 .16187 L
F
.804 .522 .247 r
.22045 .16187 m
.22045 .04016 L
.22201 .04016 L
.22201 .16187 L
s
1 .894 .882 r
.22201 .16187 m
.22201 .04048 L
.22438 .04048 L
.22438 .16187 L
F
.804 .522 .247 r
.22201 .16187 m
.22201 .04048 L
.22438 .04048 L
.22438 .16187 L
s
1 .894 .882 r
.22438 .16187 m
.22438 .04099 L
.22623 .04099 L
.22623 .16187 L
F
.804 .522 .247 r
.22438 .16187 m
.22438 .04099 L
.22623 .04099 L
.22623 .16187 L
s
1 .894 .882 r
.22623 .16187 m
.22623 .0415 L
.22728 .0415 L
.22728 .16187 L
F
.804 .522 .247 r
.22623 .16187 m
.22623 .0415 L
.22728 .0415 L
.22728 .16187 L
s
1 .894 .882 r
.22728 .16187 m
.22728 .04171 L
.2289 .04171 L
.2289 .16187 L
F
.804 .522 .247 r
.22728 .16187 m
.22728 .04171 L
.2289 .04171 L
.2289 .16187 L
s
1 .894 .882 r
.2289 .16187 m
.2289 .04208 L
.22997 .04208 L
.22997 .16187 L
F
.804 .522 .247 r
.2289 .16187 m
.2289 .04208 L
.22997 .04208 L
.22997 .16187 L
s
1 .894 .882 r
.22997 .16187 m
.22997 .04265 L
.2323 .04265 L
.2323 .16187 L
F
.804 .522 .247 r
.22997 .16187 m
.22997 .04265 L
.2323 .04265 L
.2323 .16187 L
s
1 .894 .882 r
.2323 .16187 m
.2323 .04292 L
.23341 .04292 L
.23341 .16187 L
F
.804 .522 .247 r
.2323 .16187 m
.2323 .04292 L
.23341 .04292 L
.23341 .16187 L
s
1 .894 .882 r
.23341 .16187 m
.23341 .04325 L
.23454 .04325 L
.23454 .16187 L
F
.804 .522 .247 r
.23341 .16187 m
.23341 .04325 L
.23454 .04325 L
.23454 .16187 L
s
1 .894 .882 r
.23454 .16187 m
.23454 .04429 L
.23732 .04429 L
.23732 .16187 L
F
.804 .522 .247 r
.23454 .16187 m
.23454 .04429 L
.23732 .04429 L
.23732 .16187 L
s
1 .894 .882 r
.23732 .16187 m
.23732 .0444 L
.23871 .0444 L
.23871 .16187 L
F
.804 .522 .247 r
.23732 .16187 m
.23732 .0444 L
.23871 .0444 L
.23871 .16187 L
s
1 .894 .882 r
.23871 .16187 m
.23871 .04488 L
.24061 .04488 L
.24061 .16187 L
F
.804 .522 .247 r
.23871 .16187 m
.23871 .04488 L
.24061 .04488 L
.24061 .16187 L
s
1 .894 .882 r
.24061 .16187 m
.24061 .04535 L
.24156 .04535 L
.24156 .16187 L
F
.804 .522 .247 r
.24061 .16187 m
.24061 .04535 L
.24156 .04535 L
.24156 .16187 L
s
1 .894 .882 r
.24156 .16187 m
.24156 .04588 L
.24372 .04588 L
.24372 .16187 L
F
.804 .522 .247 r
.24156 .16187 m
.24156 .04588 L
.24372 .04588 L
.24372 .16187 L
s
1 .894 .882 r
.24372 .16187 m
.24372 .04626 L
.24562 .04626 L
.24562 .16187 L
F
.804 .522 .247 r
.24372 .16187 m
.24372 .04626 L
.24562 .04626 L
.24562 .16187 L
s
1 .894 .882 r
.24562 .16187 m
.24562 .04708 L
.24839 .04708 L
.24839 .16187 L
F
.804 .522 .247 r
.24562 .16187 m
.24562 .04708 L
.24839 .04708 L
.24839 .16187 L
s
1 .894 .882 r
.24839 .16187 m
.24839 .04777 L
.25048 .04777 L
.25048 .16187 L
F
.804 .522 .247 r
.24839 .16187 m
.24839 .04777 L
.25048 .04777 L
.25048 .16187 L
s
1 .894 .882 r
.25048 .16187 m
.25048 .04833 L
.25175 .04833 L
.25175 .16187 L
F
.804 .522 .247 r
.25048 .16187 m
.25048 .04833 L
.25175 .04833 L
.25175 .16187 L
s
1 .894 .882 r
.25175 .16187 m
.25175 .04867 L
.25379 .04867 L
.25379 .16187 L
F
.804 .522 .247 r
.25175 .16187 m
.25175 .04867 L
.25379 .04867 L
.25379 .16187 L
s
1 .894 .882 r
.25379 .16187 m
.25379 .04925 L
.25489 .04925 L
.25489 .16187 L
F
.804 .522 .247 r
.25379 .16187 m
.25379 .04925 L
.25489 .04925 L
.25489 .16187 L
s
1 .894 .882 r
.25489 .16187 m
.25489 .04971 L
.25649 .04971 L
.25649 .16187 L
F
.804 .522 .247 r
.25489 .16187 m
.25489 .04971 L
.25649 .04971 L
.25649 .16187 L
s
1 .894 .882 r
.25649 .16187 m
.25649 .05002 L
.25864 .05002 L
.25864 .16187 L
F
.804 .522 .247 r
.25649 .16187 m
.25649 .05002 L
.25864 .05002 L
.25864 .16187 L
s
1 .894 .882 r
.25864 .16187 m
.25864 .05065 L
.25971 .05065 L
.25971 .16187 L
F
.804 .522 .247 r
.25864 .16187 m
.25864 .05065 L
.25971 .05065 L
.25971 .16187 L
s
1 .894 .882 r
.25971 .16187 m
.25971 .0509 L
.26087 .0509 L
.26087 .16187 L
F
.804 .522 .247 r
.25971 .16187 m
.25971 .0509 L
.26087 .0509 L
.26087 .16187 L
s
1 .894 .882 r
.26087 .16187 m
.26087 .05141 L
.26176 .05141 L
.26176 .16187 L
F
.804 .522 .247 r
.26087 .16187 m
.26087 .05141 L
.26176 .05141 L
.26176 .16187 L
s
1 .894 .882 r
.26176 .16187 m
.26176 .05213 L
.2644 .05213 L
.2644 .16187 L
F
.804 .522 .247 r
.26176 .16187 m
.26176 .05213 L
.2644 .05213 L
.2644 .16187 L
s
1 .894 .882 r
.2644 .16187 m
.2644 .05234 L
.26646 .05234 L
.26646 .16187 L
F
.804 .522 .247 r
.2644 .16187 m
.2644 .05234 L
.26646 .05234 L
.26646 .16187 L
s
1 .894 .882 r
.26646 .16187 m
.26646 .05308 L
.26742 .05308 L
.26742 .16187 L
F
.804 .522 .247 r
.26646 .16187 m
.26646 .05308 L
.26742 .05308 L
.26742 .16187 L
s
1 .894 .882 r
.26742 .16187 m
.26742 .05359 L
.26954 .05359 L
.26954 .16187 L
F
.804 .522 .247 r
.26742 .16187 m
.26742 .05359 L
.26954 .05359 L
.26954 .16187 L
s
1 .894 .882 r
.26954 .16187 m
.26954 .05436 L
.27195 .05436 L
.27195 .16187 L
F
.804 .522 .247 r
.26954 .16187 m
.26954 .05436 L
.27195 .05436 L
.27195 .16187 L
s
1 .894 .882 r
.27195 .16187 m
.27195 .05512 L
.27454 .05512 L
.27454 .16187 L
F
.804 .522 .247 r
.27195 .16187 m
.27195 .05512 L
.27454 .05512 L
.27454 .16187 L
s
1 .894 .882 r
.27454 .16187 m
.27454 .05597 L
.27723 .05597 L
.27723 .16187 L
F
.804 .522 .247 r
.27454 .16187 m
.27454 .05597 L
.27723 .05597 L
.27723 .16187 L
s
1 .894 .882 r
.27723 .16187 m
.27723 .05667 L
.27907 .05667 L
.27907 .16187 L
F
.804 .522 .247 r
.27723 .16187 m
.27723 .05667 L
.27907 .05667 L
.27907 .16187 L
s
1 .894 .882 r
.27907 .16187 m
.27907 .0575 L
.28156 .0575 L
.28156 .16187 L
F
.804 .522 .247 r
.27907 .16187 m
.27907 .0575 L
.28156 .0575 L
.28156 .16187 L
s
1 .894 .882 r
.28156 .16187 m
.28156 .05802 L
.28361 .05802 L
.28361 .16187 L
F
.804 .522 .247 r
.28156 .16187 m
.28156 .05802 L
.28361 .05802 L
.28361 .16187 L
s
1 .894 .882 r
.28361 .16187 m
.28361 .0586 L
.28526 .0586 L
.28526 .16187 L
F
.804 .522 .247 r
.28361 .16187 m
.28361 .0586 L
.28526 .0586 L
.28526 .16187 L
s
1 .894 .882 r
.28526 .16187 m
.28526 .05964 L
.287 .05964 L
.287 .16187 L
F
.804 .522 .247 r
.28526 .16187 m
.28526 .05964 L
.287 .05964 L
.287 .16187 L
s
1 .894 .882 r
.287 .16187 m
.287 .06006 L
.28819 .06006 L
.28819 .16187 L
F
.804 .522 .247 r
.287 .16187 m
.287 .06006 L
.28819 .06006 L
.28819 .16187 L
s
1 .894 .882 r
.28819 .16187 m
.28819 .06041 L
.28918 .06041 L
.28918 .16187 L
F
.804 .522 .247 r
.28819 .16187 m
.28819 .06041 L
.28918 .06041 L
.28918 .16187 L
s
1 .894 .882 r
.28918 .16187 m
.28918 .06078 L
.29092 .06078 L
.29092 .16187 L
F
.804 .522 .247 r
.28918 .16187 m
.28918 .06078 L
.29092 .06078 L
.29092 .16187 L
s
1 .894 .882 r
.29092 .16187 m
.29092 .06137 L
.29341 .06137 L
.29341 .16187 L
F
.804 .522 .247 r
.29092 .16187 m
.29092 .06137 L
.29341 .06137 L
.29341 .16187 L
s
1 .894 .882 r
.29341 .16187 m
.29341 .06212 L
.29618 .06212 L
.29618 .16187 L
F
.804 .522 .247 r
.29341 .16187 m
.29341 .06212 L
.29618 .06212 L
.29618 .16187 L
s
1 .894 .882 r
.29618 .16187 m
.29618 .06323 L
.29798 .06323 L
.29798 .16187 L
F
.804 .522 .247 r
.29618 .16187 m
.29618 .06323 L
.29798 .06323 L
.29798 .16187 L
s
1 .894 .882 r
.29798 .16187 m
.29798 .06401 L
.29947 .06401 L
.29947 .16187 L
F
.804 .522 .247 r
.29798 .16187 m
.29798 .06401 L
.29947 .06401 L
.29947 .16187 L
s
1 .894 .882 r
.29947 .16187 m
.29947 .06446 L
.30122 .06446 L
.30122 .16187 L
F
.804 .522 .247 r
.29947 .16187 m
.29947 .06446 L
.30122 .06446 L
.30122 .16187 L
s
1 .894 .882 r
.30122 .16187 m
.30122 .06517 L
.30268 .06517 L
.30268 .16187 L
F
.804 .522 .247 r
.30122 .16187 m
.30122 .06517 L
.30268 .06517 L
.30268 .16187 L
s
1 .894 .882 r
.30268 .16187 m
.30268 .06526 L
.30428 .06526 L
.30428 .16187 L
F
.804 .522 .247 r
.30268 .16187 m
.30268 .06526 L
.30428 .06526 L
.30428 .16187 L
s
1 .894 .882 r
.30428 .16187 m
.30428 .06609 L
.30546 .06609 L
.30546 .16187 L
F
.804 .522 .247 r
.30428 .16187 m
.30428 .06609 L
.30546 .06609 L
.30546 .16187 L
s
1 .894 .882 r
.30546 .16187 m
.30546 .06674 L
.30717 .06674 L
.30717 .16187 L
F
.804 .522 .247 r
.30546 .16187 m
.30546 .06674 L
.30717 .06674 L
.30717 .16187 L
s
1 .894 .882 r
.30717 .16187 m
.30717 .06691 L
.30885 .06691 L
.30885 .16187 L
F
.804 .522 .247 r
.30717 .16187 m
.30717 .06691 L
.30885 .06691 L
.30885 .16187 L
s
1 .894 .882 r
.30885 .16187 m
.30885 .06746 L
.31123 .06746 L
.31123 .16187 L
F
.804 .522 .247 r
.30885 .16187 m
.30885 .06746 L
.31123 .06746 L
.31123 .16187 L
s
1 .894 .882 r
.31123 .16187 m
.31123 .06842 L
.3123 .06842 L
.3123 .16187 L
F
.804 .522 .247 r
.31123 .16187 m
.31123 .06842 L
.3123 .06842 L
.3123 .16187 L
s
1 .894 .882 r
.3123 .16187 m
.3123 .06903 L
.31474 .06903 L
.31474 .16187 L
F
.804 .522 .247 r
.3123 .16187 m
.3123 .06903 L
.31474 .06903 L
.31474 .16187 L
s
1 .894 .882 r
.31474 .16187 m
.31474 .07009 L
.31685 .07009 L
.31685 .16187 L
F
.804 .522 .247 r
.31474 .16187 m
.31474 .07009 L
.31685 .07009 L
.31685 .16187 L
s
1 .894 .882 r
.31685 .16187 m
.31685 .07094 L
.3195 .07094 L
.3195 .16187 L
F
.804 .522 .247 r
.31685 .16187 m
.31685 .07094 L
.3195 .07094 L
.3195 .16187 L
s
1 .894 .882 r
.3195 .16187 m
.3195 .07179 L
.32073 .07179 L
.32073 .16187 L
F
.804 .522 .247 r
.3195 .16187 m
.3195 .07179 L
.32073 .07179 L
.32073 .16187 L
s
1 .894 .882 r
.32073 .16187 m
.32073 .07242 L
.32218 .07242 L
.32218 .16187 L
F
.804 .522 .247 r
.32073 .16187 m
.32073 .07242 L
.32218 .07242 L
.32218 .16187 L
s
1 .894 .882 r
.32218 .16187 m
.32218 .0734 L
.32465 .0734 L
.32465 .16187 L
F
.804 .522 .247 r
.32218 .16187 m
.32218 .0734 L
.32465 .0734 L
.32465 .16187 L
s
1 .894 .882 r
.32465 .16187 m
.32465 .07357 L
.3261 .07357 L
.3261 .16187 L
F
.804 .522 .247 r
.32465 .16187 m
.32465 .07357 L
.3261 .07357 L
.3261 .16187 L
s
1 .894 .882 r
.3261 .16187 m
.3261 .07454 L
.32853 .07454 L
.32853 .16187 L
F
.804 .522 .247 r
.3261 .16187 m
.3261 .07454 L
.32853 .07454 L
.32853 .16187 L
s
1 .894 .882 r
.32853 .16187 m
.32853 .07591 L
.33108 .07591 L
.33108 .16187 L
F
.804 .522 .247 r
.32853 .16187 m
.32853 .07591 L
.33108 .07591 L
.33108 .16187 L
s
1 .894 .882 r
.33108 .16187 m
.33108 .07683 L
.33322 .07683 L
.33322 .16187 L
F
.804 .522 .247 r
.33108 .16187 m
.33108 .07683 L
.33322 .07683 L
.33322 .16187 L
s
1 .894 .882 r
.33322 .16187 m
.33322 .07697 L
.33454 .07697 L
.33454 .16187 L
F
.804 .522 .247 r
.33322 .16187 m
.33322 .07697 L
.33454 .07697 L
.33454 .16187 L
s
1 .894 .882 r
.33454 .16187 m
.33454 .07796 L
.33608 .07796 L
.33608 .16187 L
F
.804 .522 .247 r
.33454 .16187 m
.33454 .07796 L
.33608 .07796 L
.33608 .16187 L
s
1 .894 .882 r
.33608 .16187 m
.33608 .07818 L
.33699 .07818 L
.33699 .16187 L
F
.804 .522 .247 r
.33608 .16187 m
.33608 .07818 L
.33699 .07818 L
.33699 .16187 L
s
1 .894 .882 r
.33699 .16187 m
.33699 .07904 L
.33921 .07904 L
.33921 .16187 L
F
.804 .522 .247 r
.33699 .16187 m
.33699 .07904 L
.33921 .07904 L
.33921 .16187 L
s
1 .894 .882 r
.33921 .16187 m
.33921 .0799 L
.34157 .0799 L
.34157 .16187 L
F
.804 .522 .247 r
.33921 .16187 m
.33921 .0799 L
.34157 .0799 L
.34157 .16187 L
s
1 .894 .882 r
.34157 .16187 m
.34157 .08061 L
.34248 .08061 L
.34248 .16187 L
F
.804 .522 .247 r
.34157 .16187 m
.34157 .08061 L
.34248 .08061 L
.34248 .16187 L
s
1 .894 .882 r
.34248 .16187 m
.34248 .0813 L
.34449 .0813 L
.34449 .16187 L
F
.804 .522 .247 r
.34248 .16187 m
.34248 .0813 L
.34449 .0813 L
.34449 .16187 L
s
1 .894 .882 r
.34449 .16187 m
.34449 .08196 L
.3461 .08196 L
.3461 .16187 L
F
.804 .522 .247 r
.34449 .16187 m
.34449 .08196 L
.3461 .08196 L
.3461 .16187 L
s
1 .894 .882 r
.3461 .16187 m
.3461 .08248 L
.34772 .08248 L
.34772 .16187 L
F
.804 .522 .247 r
.3461 .16187 m
.3461 .08248 L
.34772 .08248 L
.34772 .16187 L
s
1 .894 .882 r
.34772 .16187 m
.34772 .08306 L
.35029 .08306 L
.35029 .16187 L
F
.804 .522 .247 r
.34772 .16187 m
.34772 .08306 L
.35029 .08306 L
.35029 .16187 L
s
1 .894 .882 r
.35029 .16187 m
.35029 .08436 L
.35145 .08436 L
.35145 .16187 L
F
.804 .522 .247 r
.35029 .16187 m
.35029 .08436 L
.35145 .08436 L
.35145 .16187 L
s
1 .894 .882 r
.35145 .16187 m
.35145 .08511 L
.35423 .08511 L
.35423 .16187 L
F
.804 .522 .247 r
.35145 .16187 m
.35145 .08511 L
.35423 .08511 L
.35423 .16187 L
s
1 .894 .882 r
.35423 .16187 m
.35423 .08601 L
.35631 .08601 L
.35631 .16187 L
F
.804 .522 .247 r
.35423 .16187 m
.35423 .08601 L
.35631 .08601 L
.35631 .16187 L
s
1 .894 .882 r
.35631 .16187 m
.35631 .08647 L
.35866 .08647 L
.35866 .16187 L
F
.804 .522 .247 r
.35631 .16187 m
.35631 .08647 L
.35866 .08647 L
.35866 .16187 L
s
1 .894 .882 r
.35866 .16187 m
.35866 .08791 L
.36023 .08791 L
.36023 .16187 L
F
.804 .522 .247 r
.35866 .16187 m
.35866 .08791 L
.36023 .08791 L
.36023 .16187 L
s
1 .894 .882 r
.36023 .16187 m
.36023 .0882 L
.36175 .0882 L
.36175 .16187 L
F
.804 .522 .247 r
.36023 .16187 m
.36023 .0882 L
.36175 .0882 L
.36175 .16187 L
s
1 .894 .882 r
.36175 .16187 m
.36175 .08884 L
.36403 .08884 L
.36403 .16187 L
F
.804 .522 .247 r
.36175 .16187 m
.36175 .08884 L
.36403 .08884 L
.36403 .16187 L
s
1 .894 .882 r
.36403 .16187 m
.36403 .0901 L
.36602 .0901 L
.36602 .16187 L
F
.804 .522 .247 r
.36403 .16187 m
.36403 .0901 L
.36602 .0901 L
.36602 .16187 L
s
1 .894 .882 r
.36602 .16187 m
.36602 .09103 L
.36699 .09103 L
.36699 .16187 L
F
.804 .522 .247 r
.36602 .16187 m
.36602 .09103 L
.36699 .09103 L
.36699 .16187 L
s
1 .894 .882 r
.36699 .16187 m
.36699 .09123 L
.36889 .09123 L
.36889 .16187 L
F
.804 .522 .247 r
.36699 .16187 m
.36699 .09123 L
.36889 .09123 L
.36889 .16187 L
s
1 .894 .882 r
.36889 .16187 m
.36889 .09259 L
.37057 .09259 L
.37057 .16187 L
F
.804 .522 .247 r
.36889 .16187 m
.36889 .09259 L
.37057 .09259 L
.37057 .16187 L
s
1 .894 .882 r
.37057 .16187 m
.37057 .09356 L
.37297 .09356 L
.37297 .16187 L
F
.804 .522 .247 r
.37057 .16187 m
.37057 .09356 L
.37297 .09356 L
.37297 .16187 L
s
1 .894 .882 r
.37297 .16187 m
.37297 .0943 L
.37424 .0943 L
.37424 .16187 L
F
.804 .522 .247 r
.37297 .16187 m
.37297 .0943 L
.37424 .0943 L
.37424 .16187 L
s
1 .894 .882 r
.37424 .16187 m
.37424 .09455 L
.37685 .09455 L
.37685 .16187 L
F
.804 .522 .247 r
.37424 .16187 m
.37424 .09455 L
.37685 .09455 L
.37685 .16187 L
s
1 .894 .882 r
.37685 .16187 m
.37685 .09591 L
.37806 .09591 L
.37806 .16187 L
F
.804 .522 .247 r
.37685 .16187 m
.37685 .09591 L
.37806 .09591 L
.37806 .16187 L
s
1 .894 .882 r
.37806 .16187 m
.37806 .09679 L
.37979 .09679 L
.37979 .16187 L
F
.804 .522 .247 r
.37806 .16187 m
.37806 .09679 L
.37979 .09679 L
.37979 .16187 L
s
1 .894 .882 r
.37979 .16187 m
.37979 .09712 L
.381 .09712 L
.381 .16187 L
F
.804 .522 .247 r
.37979 .16187 m
.37979 .09712 L
.381 .09712 L
.381 .16187 L
s
1 .894 .882 r
.381 .16187 m
.381 .09773 L
.38223 .09773 L
.38223 .16187 L
F
.804 .522 .247 r
.381 .16187 m
.381 .09773 L
.38223 .09773 L
.38223 .16187 L
s
1 .894 .882 r
.38223 .16187 m
.38223 .0988 L
.38394 .0988 L
.38394 .16187 L
F
.804 .522 .247 r
.38223 .16187 m
.38223 .0988 L
.38394 .0988 L
.38394 .16187 L
s
1 .894 .882 r
.38394 .16187 m
.38394 .09951 L
.38561 .09951 L
.38561 .16187 L
F
.804 .522 .247 r
.38394 .16187 m
.38394 .09951 L
.38561 .09951 L
.38561 .16187 L
s
1 .894 .882 r
.38561 .16187 m
.38561 .10012 L
.38765 .10012 L
.38765 .16187 L
F
.804 .522 .247 r
.38561 .16187 m
.38561 .10012 L
.38765 .10012 L
.38765 .16187 L
s
1 .894 .882 r
.38765 .16187 m
.38765 .10134 L
.39012 .10134 L
.39012 .16187 L
F
.804 .522 .247 r
.38765 .16187 m
.38765 .10134 L
.39012 .10134 L
.39012 .16187 L
s
1 .894 .882 r
.39012 .16187 m
.39012 .10196 L
.39107 .10196 L
.39107 .16187 L
F
.804 .522 .247 r
.39012 .16187 m
.39012 .10196 L
.39107 .10196 L
.39107 .16187 L
s
1 .894 .882 r
.39107 .16187 m
.39107 .10278 L
.39302 .10278 L
.39302 .16187 L
F
.804 .522 .247 r
.39107 .16187 m
.39107 .10278 L
.39302 .10278 L
.39302 .16187 L
s
1 .894 .882 r
.39302 .16187 m
.39302 .10361 L
.39475 .10361 L
.39475 .16187 L
F
.804 .522 .247 r
.39302 .16187 m
.39302 .10361 L
.39475 .10361 L
.39475 .16187 L
s
1 .894 .882 r
.39475 .16187 m
.39475 .10523 L
.39729 .10523 L
.39729 .16187 L
F
.804 .522 .247 r
.39475 .16187 m
.39475 .10523 L
.39729 .10523 L
.39729 .16187 L
s
1 .894 .882 r
.39729 .16187 m
.39729 .10597 L
.39901 .10597 L
.39901 .16187 L
F
.804 .522 .247 r
.39729 .16187 m
.39729 .10597 L
.39901 .10597 L
.39901 .16187 L
s
1 .894 .882 r
.39901 .16187 m
.39901 .10674 L
.40145 .10674 L
.40145 .16187 L
F
.804 .522 .247 r
.39901 .16187 m
.39901 .10674 L
.40145 .10674 L
.40145 .16187 L
s
1 .894 .882 r
.40145 .16187 m
.40145 .10771 L
.40246 .10771 L
.40246 .16187 L
F
.804 .522 .247 r
.40145 .16187 m
.40145 .10771 L
.40246 .10771 L
.40246 .16187 L
s
1 .894 .882 r
.40246 .16187 m
.40246 .10862 L
.40434 .10862 L
.40434 .16187 L
F
.804 .522 .247 r
.40246 .16187 m
.40246 .10862 L
.40434 .10862 L
.40434 .16187 L
s
1 .894 .882 r
.40434 .16187 m
.40434 .10967 L
.40662 .10967 L
.40662 .16187 L
F
.804 .522 .247 r
.40434 .16187 m
.40434 .10967 L
.40662 .10967 L
.40662 .16187 L
s
1 .894 .882 r
.40662 .16187 m
.40662 .10998 L
.40794 .10998 L
.40794 .16187 L
F
.804 .522 .247 r
.40662 .16187 m
.40662 .10998 L
.40794 .10998 L
.40794 .16187 L
s
1 .894 .882 r
.40794 .16187 m
.40794 .11053 L
.40883 .11053 L
.40883 .16187 L
F
.804 .522 .247 r
.40794 .16187 m
.40794 .11053 L
.40883 .11053 L
.40883 .16187 L
s
1 .894 .882 r
.40883 .16187 m
.40883 .11209 L
.41166 .11209 L
.41166 .16187 L
F
.804 .522 .247 r
.40883 .16187 m
.40883 .11209 L
.41166 .11209 L
.41166 .16187 L
s
1 .894 .882 r
.41166 .16187 m
.41166 .11239 L
.41311 .11239 L
.41311 .16187 L
F
.804 .522 .247 r
.41166 .16187 m
.41166 .11239 L
.41311 .11239 L
.41311 .16187 L
s
1 .894 .882 r
.41311 .16187 m
.41311 .11352 L
.41487 .11352 L
.41487 .16187 L
F
.804 .522 .247 r
.41311 .16187 m
.41311 .11352 L
.41487 .11352 L
.41487 .16187 L
s
1 .894 .882 r
.41487 .16187 m
.41487 .11436 L
.41734 .11436 L
.41734 .16187 L
F
.804 .522 .247 r
.41487 .16187 m
.41487 .11436 L
.41734 .11436 L
.41734 .16187 L
s
1 .894 .882 r
.41734 .16187 m
.41734 .1156 L
.41842 .1156 L
.41842 .16187 L
F
.804 .522 .247 r
.41734 .16187 m
.41734 .1156 L
.41842 .1156 L
.41842 .16187 L
s
1 .894 .882 r
.41842 .16187 m
.41842 .11606 L
.41951 .11606 L
.41951 .16187 L
F
.804 .522 .247 r
.41842 .16187 m
.41842 .11606 L
.41951 .11606 L
.41951 .16187 L
s
1 .894 .882 r
.41951 .16187 m
.41951 .11665 L
.4204 .11665 L
.4204 .16187 L
F
.804 .522 .247 r
.41951 .16187 m
.41951 .11665 L
.4204 .11665 L
.4204 .16187 L
s
1 .894 .882 r
.4204 .16187 m
.4204 .1168 L
.42252 .1168 L
.42252 .16187 L
F
.804 .522 .247 r
.4204 .16187 m
.4204 .1168 L
.42252 .1168 L
.42252 .16187 L
s
1 .894 .882 r
.42252 .16187 m
.42252 .11833 L
.4252 .11833 L
.4252 .16187 L
F
.804 .522 .247 r
.42252 .16187 m
.42252 .11833 L
.4252 .11833 L
.4252 .16187 L
s
1 .894 .882 r
.4252 .16187 m
.4252 .11999 L
.42744 .11999 L
.42744 .16187 L
F
.804 .522 .247 r
.4252 .16187 m
.4252 .11999 L
.42744 .11999 L
.42744 .16187 L
s
1 .894 .882 r
.42744 .16187 m
.42744 .12141 L
.4295 .12141 L
.4295 .16187 L
F
.804 .522 .247 r
.42744 .16187 m
.42744 .12141 L
.4295 .12141 L
.4295 .16187 L
s
1 .894 .882 r
.4295 .16187 m
.4295 .12179 L
.43044 .12179 L
.43044 .16187 L
F
.804 .522 .247 r
.4295 .16187 m
.4295 .12179 L
.43044 .12179 L
.43044 .16187 L
s
1 .894 .882 r
.43044 .16187 m
.43044 .12241 L
.4315 .12241 L
.4315 .16187 L
F
.804 .522 .247 r
.43044 .16187 m
.43044 .12241 L
.4315 .12241 L
.4315 .16187 L
s
1 .894 .882 r
.4315 .16187 m
.4315 .12284 L
.43365 .12284 L
.43365 .16187 L
F
.804 .522 .247 r
.4315 .16187 m
.4315 .12284 L
.43365 .12284 L
.43365 .16187 L
s
1 .894 .882 r
.43365 .16187 m
.43365 .12388 L
.43461 .12388 L
.43461 .16187 L
F
.804 .522 .247 r
.43365 .16187 m
.43365 .12388 L
.43461 .12388 L
.43461 .16187 L
s
1 .894 .882 r
.43461 .16187 m
.43461 .12425 L
.43666 .12425 L
.43666 .16187 L
F
.804 .522 .247 r
.43461 .16187 m
.43461 .12425 L
.43666 .12425 L
.43666 .16187 L
s
1 .894 .882 r
.43666 .16187 m
.43666 .12585 L
.43804 .12585 L
.43804 .16187 L
F
.804 .522 .247 r
.43666 .16187 m
.43666 .12585 L
.43804 .12585 L
.43804 .16187 L
s
1 .894 .882 r
.43804 .16187 m
.43804 .1263 L
.43932 .1263 L
.43932 .16187 L
F
.804 .522 .247 r
.43804 .16187 m
.43804 .1263 L
.43932 .1263 L
.43932 .16187 L
s
1 .894 .882 r
.43932 .16187 m
.43932 .12732 L
.44069 .12732 L
.44069 .16187 L
F
.804 .522 .247 r
.43932 .16187 m
.43932 .12732 L
.44069 .12732 L
.44069 .16187 L
s
1 .894 .882 r
.44069 .16187 m
.44069 .12762 L
.44258 .12762 L
.44258 .16187 L
F
.804 .522 .247 r
.44069 .16187 m
.44069 .12762 L
.44258 .12762 L
.44258 .16187 L
s
1 .894 .882 r
.44258 .16187 m
.44258 .12951 L
.44493 .12951 L
.44493 .16187 L
F
.804 .522 .247 r
.44258 .16187 m
.44258 .12951 L
.44493 .12951 L
.44493 .16187 L
s
1 .894 .882 r
.44493 .16187 m
.44493 .13028 L
.44677 .13028 L
.44677 .16187 L
F
.804 .522 .247 r
.44493 .16187 m
.44493 .13028 L
.44677 .13028 L
.44677 .16187 L
s
1 .894 .882 r
.44677 .16187 m
.44677 .13106 L
.44768 .13106 L
.44768 .16187 L
F
.804 .522 .247 r
.44677 .16187 m
.44677 .13106 L
.44768 .13106 L
.44768 .16187 L
s
1 .894 .882 r
.44768 .16187 m
.44768 .13231 L
.44953 .13231 L
.44953 .16187 L
F
.804 .522 .247 r
.44768 .16187 m
.44768 .13231 L
.44953 .13231 L
.44953 .16187 L
s
1 .894 .882 r
.44953 .16187 m
.44953 .13357 L
.4519 .13357 L
.4519 .16187 L
F
.804 .522 .247 r
.44953 .16187 m
.44953 .13357 L
.4519 .13357 L
.4519 .16187 L
s
1 .894 .882 r
.4519 .16187 m
.4519 .13392 L
.45315 .13392 L
.45315 .16187 L
F
.804 .522 .247 r
.4519 .16187 m
.4519 .13392 L
.45315 .13392 L
.45315 .16187 L
s
1 .894 .882 r
.45315 .16187 m
.45315 .13544 L
.45515 .13544 L
.45515 .16187 L
F
.804 .522 .247 r
.45315 .16187 m
.45315 .13544 L
.45515 .13544 L
.45515 .16187 L
s
1 .894 .882 r
.45515 .16187 m
.45515 .13628 L
.45737 .13628 L
.45737 .16187 L
F
.804 .522 .247 r
.45515 .16187 m
.45515 .13628 L
.45737 .13628 L
.45737 .16187 L
s
1 .894 .882 r
.45737 .16187 m
.45737 .13699 L
.45952 .13699 L
.45952 .16187 L
F
.804 .522 .247 r
.45737 .16187 m
.45737 .13699 L
.45952 .13699 L
.45952 .16187 L
s
1 .894 .882 r
.45952 .16187 m
.45952 .13841 L
.46052 .13841 L
.46052 .16187 L
F
.804 .522 .247 r
.45952 .16187 m
.45952 .13841 L
.46052 .13841 L
.46052 .16187 L
s
1 .894 .882 r
.46052 .16187 m
.46052 .13879 L
.46249 .13879 L
.46249 .16187 L
F
.804 .522 .247 r
.46052 .16187 m
.46052 .13879 L
.46249 .13879 L
.46249 .16187 L
s
1 .894 .882 r
.46249 .16187 m
.46249 .13995 L
.46345 .13995 L
.46345 .16187 L
F
.804 .522 .247 r
.46249 .16187 m
.46249 .13995 L
.46345 .13995 L
.46345 .16187 L
s
1 .894 .882 r
.46345 .16187 m
.46345 .14136 L
.46577 .14136 L
.46577 .16187 L
F
.804 .522 .247 r
.46345 .16187 m
.46345 .14136 L
.46577 .14136 L
.46577 .16187 L
s
1 .894 .882 r
.46577 .16187 m
.46577 .14171 L
.46738 .14171 L
.46738 .16187 L
F
.804 .522 .247 r
.46577 .16187 m
.46577 .14171 L
.46738 .14171 L
.46738 .16187 L
s
1 .894 .882 r
.46738 .16187 m
.46738 .14299 L
.47013 .14299 L
.47013 .16187 L
F
.804 .522 .247 r
.46738 .16187 m
.46738 .14299 L
.47013 .14299 L
.47013 .16187 L
s
1 .894 .882 r
.47013 .16187 m
.47013 .14404 L
.47101 .14404 L
.47101 .16187 L
F
.804 .522 .247 r
.47013 .16187 m
.47013 .14404 L
.47101 .14404 L
.47101 .16187 L
s
1 .894 .882 r
.47101 .16187 m
.47101 .14475 L
.47311 .14475 L
.47311 .16187 L
F
.804 .522 .247 r
.47101 .16187 m
.47101 .14475 L
.47311 .14475 L
.47311 .16187 L
s
1 .894 .882 r
.47311 .16187 m
.47311 .14575 L
.47543 .14575 L
.47543 .16187 L
F
.804 .522 .247 r
.47311 .16187 m
.47311 .14575 L
.47543 .14575 L
.47543 .16187 L
s
1 .894 .882 r
.47543 .16187 m
.47543 .14715 L
.47807 .14715 L
.47807 .16187 L
F
.804 .522 .247 r
.47543 .16187 m
.47543 .14715 L
.47807 .14715 L
.47807 .16187 L
s
1 .894 .882 r
.47807 .16187 m
.47807 .1487 L
.47975 .1487 L
.47975 .16187 L
F
.804 .522 .247 r
.47807 .16187 m
.47807 .1487 L
.47975 .1487 L
.47975 .16187 L
s
1 .894 .882 r
.47975 .16187 m
.47975 .15008 L
.48133 .15008 L
.48133 .16187 L
F
.804 .522 .247 r
.47975 .16187 m
.47975 .15008 L
.48133 .15008 L
.48133 .16187 L
s
1 .894 .882 r
.48133 .16187 m
.48133 .15131 L
.48322 .15131 L
.48322 .16187 L
F
.804 .522 .247 r
.48133 .16187 m
.48133 .15131 L
.48322 .15131 L
.48322 .16187 L
s
1 .894 .882 r
.48322 .16187 m
.48322 .15204 L
.48534 .15204 L
.48534 .16187 L
F
.804 .522 .247 r
.48322 .16187 m
.48322 .15204 L
.48534 .15204 L
.48534 .16187 L
s
1 .894 .882 r
.48534 .16187 m
.48534 .15445 L
.48797 .15445 L
.48797 .16187 L
F
.804 .522 .247 r
.48534 .16187 m
.48534 .15445 L
.48797 .15445 L
.48797 .16187 L
s
1 .894 .882 r
.48797 .16187 m
.48797 .15543 L
.49006 .15543 L
.49006 .16187 L
F
.804 .522 .247 r
.48797 .16187 m
.48797 .15543 L
.49006 .15543 L
.49006 .16187 L
s
1 .894 .882 r
.49006 .16187 m
.49006 .15589 L
.49096 .15589 L
.49096 .16187 L
F
.804 .522 .247 r
.49006 .16187 m
.49006 .15589 L
.49096 .15589 L
.49096 .16187 L
s
1 .894 .882 r
.49096 .16187 m
.49096 .15732 L
.49303 .15732 L
.49303 .16187 L
F
.804 .522 .247 r
.49096 .16187 m
.49096 .15732 L
.49303 .15732 L
.49303 .16187 L
s
1 .894 .882 r
.49303 .16187 m
.49303 .15855 L
.49466 .15855 L
.49466 .16187 L
F
.804 .522 .247 r
.49303 .16187 m
.49303 .15855 L
.49466 .15855 L
.49466 .16187 L
s
1 .894 .882 r
.49466 .16187 m
.49466 .15979 L
.49722 .15979 L
.49722 .16187 L
F
.804 .522 .247 r
.49466 .16187 m
.49466 .15979 L
.49722 .15979 L
.49722 .16187 L
s
1 .894 .882 r
.49722 .16187 m
.49722 .16139 L
.49972 .16139 L
.49972 .16187 L
F
.804 .522 .247 r
.49722 .16187 m
.49722 .16139 L
.49972 .16139 L
.49972 .16187 L
s
.678 .847 .902 r
.49972 .16187 m
.49972 .16215 L
.50065 .16215 L
.50065 .16187 L
F
.2 .63 .79 r
.49972 .16187 m
.49972 .16215 L
.50065 .16215 L
.50065 .16187 L
s
.678 .847 .902 r
.50065 .16187 m
.50065 .16269 L
.5029 .16269 L
.5029 .16187 L
F
.2 .63 .79 r
.50065 .16187 m
.50065 .16269 L
.5029 .16269 L
.5029 .16187 L
s
.678 .847 .902 r
.5029 .16187 m
.5029 .16408 L
.50417 .16408 L
.50417 .16187 L
F
.2 .63 .79 r
.5029 .16187 m
.5029 .16408 L
.50417 .16408 L
.50417 .16187 L
s
.678 .847 .902 r
.50417 .16187 m
.50417 .16582 L
.50652 .16582 L
.50652 .16187 L
F
.2 .63 .79 r
.50417 .16187 m
.50417 .16582 L
.50652 .16582 L
.50652 .16187 L
s
.678 .847 .902 r
.50652 .16187 m
.50652 .16652 L
.50833 .16652 L
.50833 .16187 L
F
.2 .63 .79 r
.50652 .16187 m
.50652 .16652 L
.50833 .16652 L
.50833 .16187 L
s
.678 .847 .902 r
.50833 .16187 m
.50833 .16795 L
.51048 .16795 L
.51048 .16187 L
F
.2 .63 .79 r
.50833 .16187 m
.50833 .16795 L
.51048 .16795 L
.51048 .16187 L
s
.678 .847 .902 r
.51048 .16187 m
.51048 .1691 L
.51228 .1691 L
.51228 .16187 L
F
.2 .63 .79 r
.51048 .16187 m
.51048 .1691 L
.51228 .1691 L
.51228 .16187 L
s
.678 .847 .902 r
.51228 .16187 m
.51228 .17023 L
.51387 .17023 L
.51387 .16187 L
F
.2 .63 .79 r
.51228 .16187 m
.51228 .17023 L
.51387 .17023 L
.51387 .16187 L
s
.678 .847 .902 r
.51387 .16187 m
.51387 .17075 L
.51577 .17075 L
.51577 .16187 L
F
.2 .63 .79 r
.51387 .16187 m
.51387 .17075 L
.51577 .17075 L
.51577 .16187 L
s
.678 .847 .902 r
.51577 .16187 m
.51577 .17253 L
.51789 .17253 L
.51789 .16187 L
F
.2 .63 .79 r
.51577 .16187 m
.51577 .17253 L
.51789 .17253 L
.51789 .16187 L
s
.678 .847 .902 r
.51789 .16187 m
.51789 .17379 L
.52044 .17379 L
.52044 .16187 L
F
.2 .63 .79 r
.51789 .16187 m
.51789 .17379 L
.52044 .17379 L
.52044 .16187 L
s
.678 .847 .902 r
.52044 .16187 m
.52044 .17565 L
.52257 .17565 L
.52257 .16187 L
F
.2 .63 .79 r
.52044 .16187 m
.52044 .17565 L
.52257 .17565 L
.52257 .16187 L
s
.678 .847 .902 r
.52257 .16187 m
.52257 .17629 L
.52467 .17629 L
.52467 .16187 L
F
.2 .63 .79 r
.52257 .16187 m
.52257 .17629 L
.52467 .17629 L
.52467 .16187 L
s
.678 .847 .902 r
.52467 .16187 m
.52467 .17791 L
.52598 .17791 L
.52598 .16187 L
F
.2 .63 .79 r
.52467 .16187 m
.52467 .17791 L
.52598 .17791 L
.52598 .16187 L
s
.678 .847 .902 r
.52598 .16187 m
.52598 .17944 L
.5278 .17944 L
.5278 .16187 L
F
.2 .63 .79 r
.52598 .16187 m
.52598 .17944 L
.5278 .17944 L
.5278 .16187 L
s
.678 .847 .902 r
.5278 .16187 m
.5278 .18023 L
.52889 .18023 L
.52889 .16187 L
F
.2 .63 .79 r
.5278 .16187 m
.5278 .18023 L
.52889 .18023 L
.52889 .16187 L
s
.678 .847 .902 r
.52889 .16187 m
.52889 .18178 L
.53171 .18178 L
.53171 .16187 L
F
.2 .63 .79 r
.52889 .16187 m
.52889 .18178 L
.53171 .18178 L
.53171 .16187 L
s
.678 .847 .902 r
.53171 .16187 m
.53171 .18265 L
.53323 .18265 L
.53323 .16187 L
F
.2 .63 .79 r
.53171 .16187 m
.53171 .18265 L
.53323 .18265 L
.53323 .16187 L
s
.678 .847 .902 r
.53323 .16187 m
.53323 .18344 L
.53582 .18344 L
.53582 .16187 L
F
.2 .63 .79 r
.53323 .16187 m
.53323 .18344 L
.53582 .18344 L
.53582 .16187 L
s
.678 .847 .902 r
.53582 .16187 m
.53582 .18536 L
.53686 .18536 L
.53686 .16187 L
F
.2 .63 .79 r
.53582 .16187 m
.53582 .18536 L
.53686 .18536 L
.53686 .16187 L
s
.678 .847 .902 r
.53686 .16187 m
.53686 .18556 L
.53847 .18556 L
.53847 .16187 L
F
.2 .63 .79 r
.53686 .16187 m
.53686 .18556 L
.53847 .18556 L
.53847 .16187 L
s
.678 .847 .902 r
.53847 .16187 m
.53847 .18763 L
.54121 .18763 L
.54121 .16187 L
F
.2 .63 .79 r
.53847 .16187 m
.53847 .18763 L
.54121 .18763 L
.54121 .16187 L
s
.678 .847 .902 r
.54121 .16187 m
.54121 .18868 L
.54209 .18868 L
.54209 .16187 L
F
.2 .63 .79 r
.54121 .16187 m
.54121 .18868 L
.54209 .18868 L
.54209 .16187 L
s
.678 .847 .902 r
.54209 .16187 m
.54209 .18992 L
.54348 .18992 L
.54348 .16187 L
F
.2 .63 .79 r
.54209 .16187 m
.54209 .18992 L
.54348 .18992 L
.54348 .16187 L
s
.678 .847 .902 r
.54348 .16187 m
.54348 .1902 L
.54501 .1902 L
.54501 .16187 L
F
.2 .63 .79 r
.54348 .16187 m
.54348 .1902 L
.54501 .1902 L
.54501 .16187 L
s
.678 .847 .902 r
.54501 .16187 m
.54501 .19124 L
.54635 .19124 L
.54635 .16187 L
F
.2 .63 .79 r
.54501 .16187 m
.54501 .19124 L
.54635 .19124 L
.54635 .16187 L
s
.678 .847 .902 r
.54635 .16187 m
.54635 .1934 L
.54881 .1934 L
.54881 .16187 L
F
.2 .63 .79 r
.54635 .16187 m
.54635 .1934 L
.54881 .1934 L
.54881 .16187 L
s
.678 .847 .902 r
.54881 .16187 m
.54881 .19361 L
.55069 .19361 L
.55069 .16187 L
F
.2 .63 .79 r
.54881 .16187 m
.54881 .19361 L
.55069 .19361 L
.55069 .16187 L
s
.678 .847 .902 r
.55069 .16187 m
.55069 .1961 L
.55327 .1961 L
.55327 .16187 L
F
.2 .63 .79 r
.55069 .16187 m
.55069 .1961 L
.55327 .1961 L
.55327 .16187 L
s
.678 .847 .902 r
.55327 .16187 m
.55327 .19747 L
.55531 .19747 L
.55531 .16187 L
F
.2 .63 .79 r
.55327 .16187 m
.55327 .19747 L
.55531 .19747 L
.55531 .16187 L
s
.678 .847 .902 r
.55531 .16187 m
.55531 .19833 L
.55683 .19833 L
.55683 .16187 L
F
.2 .63 .79 r
.55531 .16187 m
.55531 .19833 L
.55683 .19833 L
.55683 .16187 L
s
.678 .847 .902 r
.55683 .16187 m
.55683 .19936 L
.55796 .19936 L
.55796 .16187 L
F
.2 .63 .79 r
.55683 .16187 m
.55683 .19936 L
.55796 .19936 L
.55796 .16187 L
s
.678 .847 .902 r
.55796 .16187 m
.55796 .20045 L
.5595 .20045 L
.5595 .16187 L
F
.2 .63 .79 r
.55796 .16187 m
.55796 .20045 L
.5595 .20045 L
.5595 .16187 L
s
.678 .847 .902 r
.5595 .16187 m
.5595 .20102 L
.56226 .20102 L
.56226 .16187 L
F
.2 .63 .79 r
.5595 .16187 m
.5595 .20102 L
.56226 .20102 L
.56226 .16187 L
s
.678 .847 .902 r
.56226 .16187 m
.56226 .20398 L
.56408 .20398 L
.56408 .16187 L
F
.2 .63 .79 r
.56226 .16187 m
.56226 .20398 L
.56408 .20398 L
.56408 .16187 L
s
.678 .847 .902 r
.56408 .16187 m
.56408 .20506 L
.56593 .20506 L
.56593 .16187 L
F
.2 .63 .79 r
.56408 .16187 m
.56408 .20506 L
.56593 .20506 L
.56593 .16187 L
s
.678 .847 .902 r
.56593 .16187 m
.56593 .20613 L
.56821 .20613 L
.56821 .16187 L
F
.2 .63 .79 r
.56593 .16187 m
.56593 .20613 L
.56821 .20613 L
.56821 .16187 L
s
.678 .847 .902 r
.56821 .16187 m
.56821 .20797 L
.57053 .20797 L
.57053 .16187 L
F
.2 .63 .79 r
.56821 .16187 m
.56821 .20797 L
.57053 .20797 L
.57053 .16187 L
s
.678 .847 .902 r
.57053 .16187 m
.57053 .21066 L
.57337 .21066 L
.57337 .16187 L
F
.2 .63 .79 r
.57053 .16187 m
.57053 .21066 L
.57337 .21066 L
.57337 .16187 L
s
.678 .847 .902 r
.57337 .16187 m
.57337 .21158 L
.57499 .21158 L
.57499 .16187 L
F
.2 .63 .79 r
.57337 .16187 m
.57337 .21158 L
.57499 .21158 L
.57499 .16187 L
s
.678 .847 .902 r
.57499 .16187 m
.57499 .21288 L
.57729 .21288 L
.57729 .16187 L
F
.2 .63 .79 r
.57499 .16187 m
.57499 .21288 L
.57729 .21288 L
.57729 .16187 L
s
.678 .847 .902 r
.57729 .16187 m
.57729 .21356 L
.57894 .21356 L
.57894 .16187 L
F
.2 .63 .79 r
.57729 .16187 m
.57729 .21356 L
.57894 .21356 L
.57894 .16187 L
s
.678 .847 .902 r
.57894 .16187 m
.57894 .21533 L
.58005 .21533 L
.58005 .16187 L
F
.2 .63 .79 r
.57894 .16187 m
.57894 .21533 L
.58005 .21533 L
.58005 .16187 L
s
.678 .847 .902 r
.58005 .16187 m
.58005 .21652 L
.58148 .21652 L
.58148 .16187 L
F
.2 .63 .79 r
.58005 .16187 m
.58005 .21652 L
.58148 .21652 L
.58148 .16187 L
s
.678 .847 .902 r
.58148 .16187 m
.58148 .21719 L
.58303 .21719 L
.58303 .16187 L
F
.2 .63 .79 r
.58148 .16187 m
.58148 .21719 L
.58303 .21719 L
.58303 .16187 L
s
.678 .847 .902 r
.58303 .16187 m
.58303 .21826 L
.58478 .21826 L
.58478 .16187 L
F
.2 .63 .79 r
.58303 .16187 m
.58303 .21826 L
.58478 .21826 L
.58478 .16187 L
s
.678 .847 .902 r
.58478 .16187 m
.58478 .21922 L
.58587 .21922 L
.58587 .16187 L
F
.2 .63 .79 r
.58478 .16187 m
.58478 .21922 L
.58587 .21922 L
.58587 .16187 L
s
.678 .847 .902 r
.58587 .16187 m
.58587 .21975 L
.58677 .21975 L
.58677 .16187 L
F
.2 .63 .79 r
.58587 .16187 m
.58587 .21975 L
.58677 .21975 L
.58677 .16187 L
s
.678 .847 .902 r
.58677 .16187 m
.58677 .22061 L
.58763 .22061 L
.58763 .16187 L
F
.2 .63 .79 r
.58677 .16187 m
.58677 .22061 L
.58763 .22061 L
.58763 .16187 L
s
.678 .847 .902 r
.58763 .16187 m
.58763 .22121 L
.5889 .22121 L
.5889 .16187 L
F
.2 .63 .79 r
.58763 .16187 m
.58763 .22121 L
.5889 .22121 L
.5889 .16187 L
s
.678 .847 .902 r
.5889 .16187 m
.5889 .22246 L
.59038 .22246 L
.59038 .16187 L
F
.2 .63 .79 r
.5889 .16187 m
.5889 .22246 L
.59038 .22246 L
.59038 .16187 L
s
.678 .847 .902 r
.59038 .16187 m
.59038 .22304 L
.59225 .22304 L
.59225 .16187 L
F
.2 .63 .79 r
.59038 .16187 m
.59038 .22304 L
.59225 .22304 L
.59225 .16187 L
s
.678 .847 .902 r
.59225 .16187 m
.59225 .22495 L
.59337 .22495 L
.59337 .16187 L
F
.2 .63 .79 r
.59225 .16187 m
.59225 .22495 L
.59337 .22495 L
.59337 .16187 L
s
.678 .847 .902 r
.59337 .16187 m
.59337 .22618 L
.59546 .22618 L
.59546 .16187 L
F
.2 .63 .79 r
.59337 .16187 m
.59337 .22618 L
.59546 .22618 L
.59546 .16187 L
s
.678 .847 .902 r
.59546 .16187 m
.59546 .22718 L
.59826 .22718 L
.59826 .16187 L
F
.2 .63 .79 r
.59546 .16187 m
.59546 .22718 L
.59826 .22718 L
.59826 .16187 L
s
.678 .847 .902 r
.59826 .16187 m
.59826 .22963 L
.59985 .22963 L
.59985 .16187 L
F
.2 .63 .79 r
.59826 .16187 m
.59826 .22963 L
.59985 .22963 L
.59985 .16187 L
s
.678 .847 .902 r
.59985 .16187 m
.59985 .23027 L
.60228 .23027 L
.60228 .16187 L
F
.2 .63 .79 r
.59985 .16187 m
.59985 .23027 L
.60228 .23027 L
.60228 .16187 L
s
.678 .847 .902 r
.60228 .16187 m
.60228 .23281 L
.60445 .23281 L
.60445 .16187 L
F
.2 .63 .79 r
.60228 .16187 m
.60228 .23281 L
.60445 .23281 L
.60445 .16187 L
s
.678 .847 .902 r
.60445 .16187 m
.60445 .23393 L
.6063 .23393 L
.6063 .16187 L
F
.2 .63 .79 r
.60445 .16187 m
.60445 .23393 L
.6063 .23393 L
.6063 .16187 L
s
.678 .847 .902 r
.6063 .16187 m
.6063 .23672 L
.60888 .23672 L
.60888 .16187 L
F
.2 .63 .79 r
.6063 .16187 m
.6063 .23672 L
.60888 .23672 L
.60888 .16187 L
s
.678 .847 .902 r
.60888 .16187 m
.60888 .23737 L
.60988 .23737 L
.60988 .16187 L
F
.2 .63 .79 r
.60888 .16187 m
.60888 .23737 L
.60988 .23737 L
.60988 .16187 L
s
.678 .847 .902 r
.60988 .16187 m
.60988 .23763 L
.61259 .23763 L
.61259 .16187 L
F
.2 .63 .79 r
.60988 .16187 m
.60988 .23763 L
.61259 .23763 L
.61259 .16187 L
s
.678 .847 .902 r
.61259 .16187 m
.61259 .24014 L
.61444 .24014 L
.61444 .16187 L
F
.2 .63 .79 r
.61259 .16187 m
.61259 .24014 L
.61444 .24014 L
.61444 .16187 L
s
.678 .847 .902 r
.61444 .16187 m
.61444 .24135 L
.61625 .24135 L
.61625 .16187 L
F
.2 .63 .79 r
.61444 .16187 m
.61444 .24135 L
.61625 .24135 L
.61625 .16187 L
s
.678 .847 .902 r
.61625 .16187 m
.61625 .24257 L
.6178 .24257 L
.6178 .16187 L
F
.2 .63 .79 r
.61625 .16187 m
.61625 .24257 L
.6178 .24257 L
.6178 .16187 L
s
.678 .847 .902 r
.6178 .16187 m
.6178 .24511 L
.61972 .24511 L
.61972 .16187 L
F
.2 .63 .79 r
.6178 .16187 m
.6178 .24511 L
.61972 .24511 L
.61972 .16187 L
s
.678 .847 .902 r
.61972 .16187 m
.61972 .24582 L
.62131 .24582 L
.62131 .16187 L
F
.2 .63 .79 r
.61972 .16187 m
.61972 .24582 L
.62131 .24582 L
.62131 .16187 L
s
.678 .847 .902 r
.62131 .16187 m
.62131 .24657 L
.62255 .24657 L
.62255 .16187 L
F
.2 .63 .79 r
.62131 .16187 m
.62131 .24657 L
.62255 .24657 L
.62255 .16187 L
s
.678 .847 .902 r
.62255 .16187 m
.62255 .24767 L
.6234 .24767 L
.6234 .16187 L
F
.2 .63 .79 r
.62255 .16187 m
.62255 .24767 L
.6234 .24767 L
.6234 .16187 L
s
.678 .847 .902 r
.6234 .16187 m
.6234 .2484 L
.62442 .2484 L
.62442 .16187 L
F
.2 .63 .79 r
.6234 .16187 m
.6234 .2484 L
.62442 .2484 L
.62442 .16187 L
s
.678 .847 .902 r
.62442 .16187 m
.62442 .24899 L
.62578 .24899 L
.62578 .16187 L
F
.2 .63 .79 r
.62442 .16187 m
.62442 .24899 L
.62578 .24899 L
.62578 .16187 L
s
.678 .847 .902 r
.62578 .16187 m
.62578 .25001 L
.62697 .25001 L
.62697 .16187 L
F
.2 .63 .79 r
.62578 .16187 m
.62578 .25001 L
.62697 .25001 L
.62697 .16187 L
s
.678 .847 .902 r
.62697 .16187 m
.62697 .25107 L
.62981 .25107 L
.62981 .16187 L
F
.2 .63 .79 r
.62697 .16187 m
.62697 .25107 L
.62981 .25107 L
.62981 .16187 L
s
.678 .847 .902 r
.62981 .16187 m
.62981 .25358 L
.6324 .25358 L
.6324 .16187 L
F
.2 .63 .79 r
.62981 .16187 m
.62981 .25358 L
.6324 .25358 L
.6324 .16187 L
s
.678 .847 .902 r
.6324 .16187 m
.6324 .25657 L
.63514 .25657 L
.63514 .16187 L
F
.2 .63 .79 r
.6324 .16187 m
.6324 .25657 L
.63514 .25657 L
.63514 .16187 L
s
.678 .847 .902 r
.63514 .16187 m
.63514 .25749 L
.63731 .25749 L
.63731 .16187 L
F
.2 .63 .79 r
.63514 .16187 m
.63514 .25749 L
.63731 .25749 L
.63731 .16187 L
s
.678 .847 .902 r
.63731 .16187 m
.63731 .2599 L
.63988 .2599 L
.63988 .16187 L
F
.2 .63 .79 r
.63731 .16187 m
.63731 .2599 L
.63988 .2599 L
.63988 .16187 L
s
.678 .847 .902 r
.63988 .16187 m
.63988 .26172 L
.64124 .26172 L
.64124 .16187 L
F
.2 .63 .79 r
.63988 .16187 m
.63988 .26172 L
.64124 .26172 L
.64124 .16187 L
s
.678 .847 .902 r
.64124 .16187 m
.64124 .26321 L
.64401 .26321 L
.64401 .16187 L
F
.2 .63 .79 r
.64124 .16187 m
.64124 .26321 L
.64401 .26321 L
.64401 .16187 L
s
.678 .847 .902 r
.64401 .16187 m
.64401 .2649 L
.64545 .2649 L
.64545 .16187 L
F
.2 .63 .79 r
.64401 .16187 m
.64401 .2649 L
.64545 .2649 L
.64545 .16187 L
s
.678 .847 .902 r
.64545 .16187 m
.64545 .26576 L
.64644 .26576 L
.64644 .16187 L
F
.2 .63 .79 r
.64545 .16187 m
.64545 .26576 L
.64644 .26576 L
.64644 .16187 L
s
.678 .847 .902 r
.64644 .16187 m
.64644 .26642 L
.64848 .26642 L
.64848 .16187 L
F
.2 .63 .79 r
.64644 .16187 m
.64644 .26642 L
.64848 .26642 L
.64848 .16187 L
s
.678 .847 .902 r
.64848 .16187 m
.64848 .26821 L
.65026 .26821 L
.65026 .16187 L
F
.2 .63 .79 r
.64848 .16187 m
.64848 .26821 L
.65026 .26821 L
.65026 .16187 L
s
.678 .847 .902 r
.65026 .16187 m
.65026 .27016 L
.65197 .27016 L
.65197 .16187 L
F
.2 .63 .79 r
.65026 .16187 m
.65026 .27016 L
.65197 .27016 L
.65197 .16187 L
s
.678 .847 .902 r
.65197 .16187 m
.65197 .27228 L
.6548 .27228 L
.6548 .16187 L
F
.2 .63 .79 r
.65197 .16187 m
.65197 .27228 L
.6548 .27228 L
.6548 .16187 L
s
.678 .847 .902 r
.6548 .16187 m
.6548 .27321 L
.65697 .27321 L
.65697 .16187 L
F
.2 .63 .79 r
.6548 .16187 m
.6548 .27321 L
.65697 .27321 L
.65697 .16187 L
s
.678 .847 .902 r
.65697 .16187 m
.65697 .27684 L
.65976 .27684 L
.65976 .16187 L
F
.2 .63 .79 r
.65697 .16187 m
.65697 .27684 L
.65976 .27684 L
.65976 .16187 L
s
.678 .847 .902 r
.65976 .16187 m
.65976 .27801 L
.6625 .27801 L
.6625 .16187 L
F
.2 .63 .79 r
.65976 .16187 m
.65976 .27801 L
.6625 .27801 L
.6625 .16187 L
s
.678 .847 .902 r
.6625 .16187 m
.6625 .28047 L
.66463 .28047 L
.66463 .16187 L
F
.2 .63 .79 r
.6625 .16187 m
.6625 .28047 L
.66463 .28047 L
.66463 .16187 L
s
.678 .847 .902 r
.66463 .16187 m
.66463 .2813 L
.66575 .2813 L
.66575 .16187 L
F
.2 .63 .79 r
.66463 .16187 m
.66463 .2813 L
.66575 .2813 L
.66575 .16187 L
s
.678 .847 .902 r
.66575 .16187 m
.66575 .28268 L
.6678 .28268 L
.6678 .16187 L
F
.2 .63 .79 r
.66575 .16187 m
.66575 .28268 L
.6678 .28268 L
.6678 .16187 L
s
.678 .847 .902 r
.6678 .16187 m
.6678 .2842 L
.67016 .2842 L
.67016 .16187 L
F
.2 .63 .79 r
.6678 .16187 m
.6678 .2842 L
.67016 .2842 L
.67016 .16187 L
s
.678 .847 .902 r
.67016 .16187 m
.67016 .286 L
.67229 .286 L
.67229 .16187 L
F
.2 .63 .79 r
.67016 .16187 m
.67016 .286 L
.67229 .286 L
.67229 .16187 L
s
.678 .847 .902 r
.67229 .16187 m
.67229 .2881 L
.67324 .2881 L
.67324 .16187 L
F
.2 .63 .79 r
.67229 .16187 m
.67229 .2881 L
.67324 .2881 L
.67324 .16187 L
s
.678 .847 .902 r
.67324 .16187 m
.67324 .28861 L
.67478 .28861 L
.67478 .16187 L
F
.2 .63 .79 r
.67324 .16187 m
.67324 .28861 L
.67478 .28861 L
.67478 .16187 L
s
.678 .847 .902 r
.67478 .16187 m
.67478 .28976 L
.67681 .28976 L
.67681 .16187 L
F
.2 .63 .79 r
.67478 .16187 m
.67478 .28976 L
.67681 .28976 L
.67681 .16187 L
s
.678 .847 .902 r
.67681 .16187 m
.67681 .2932 L
.67894 .2932 L
.67894 .16187 L
F
.2 .63 .79 r
.67681 .16187 m
.67681 .2932 L
.67894 .2932 L
.67894 .16187 L
s
.678 .847 .902 r
.67894 .16187 m
.67894 .29359 L
.68015 .29359 L
.68015 .16187 L
F
.2 .63 .79 r
.67894 .16187 m
.67894 .29359 L
.68015 .29359 L
.68015 .16187 L
s
.678 .847 .902 r
.68015 .16187 m
.68015 .29492 L
.68181 .29492 L
.68181 .16187 L
F
.2 .63 .79 r
.68015 .16187 m
.68015 .29492 L
.68181 .29492 L
.68181 .16187 L
s
.678 .847 .902 r
.68181 .16187 m
.68181 .29771 L
.68451 .29771 L
.68451 .16187 L
F
.2 .63 .79 r
.68181 .16187 m
.68181 .29771 L
.68451 .29771 L
.68451 .16187 L
s
.678 .847 .902 r
.68451 .16187 m
.68451 .29907 L
.68692 .29907 L
.68692 .16187 L
F
.2 .63 .79 r
.68451 .16187 m
.68451 .29907 L
.68692 .29907 L
.68692 .16187 L
s
.678 .847 .902 r
.68692 .16187 m
.68692 .30166 L
.68962 .30166 L
.68962 .16187 L
F
.2 .63 .79 r
.68692 .16187 m
.68692 .30166 L
.68962 .30166 L
.68962 .16187 L
s
.678 .847 .902 r
.68962 .16187 m
.68962 .30383 L
.69135 .30383 L
.69135 .16187 L
F
.2 .63 .79 r
.68962 .16187 m
.68962 .30383 L
.69135 .30383 L
.69135 .16187 L
s
.678 .847 .902 r
.69135 .16187 m
.69135 .3046 L
.69346 .3046 L
.69346 .16187 L
F
.2 .63 .79 r
.69135 .16187 m
.69135 .3046 L
.69346 .3046 L
.69346 .16187 L
s
.678 .847 .902 r
.69346 .16187 m
.69346 .30609 L
.69575 .30609 L
.69575 .16187 L
F
.2 .63 .79 r
.69346 .16187 m
.69346 .30609 L
.69575 .30609 L
.69575 .16187 L
s
.678 .847 .902 r
.69575 .16187 m
.69575 .30851 L
.69726 .30851 L
.69726 .16187 L
F
.2 .63 .79 r
.69575 .16187 m
.69575 .30851 L
.69726 .30851 L
.69726 .16187 L
s
.678 .847 .902 r
.69726 .16187 m
.69726 .31091 L
.70005 .31091 L
.70005 .16187 L
F
.2 .63 .79 r
.69726 .16187 m
.69726 .31091 L
.70005 .31091 L
.70005 .16187 L
s
.678 .847 .902 r
.70005 .16187 m
.70005 .3124 L
.70131 .3124 L
.70131 .16187 L
F
.2 .63 .79 r
.70005 .16187 m
.70005 .3124 L
.70131 .3124 L
.70131 .16187 L
s
.678 .847 .902 r
.70131 .16187 m
.70131 .31366 L
.70361 .31366 L
.70361 .16187 L
F
.2 .63 .79 r
.70131 .16187 m
.70131 .31366 L
.70361 .31366 L
.70361 .16187 L
s
.678 .847 .902 r
.70361 .16187 m
.70361 .31564 L
.7058 .31564 L
.7058 .16187 L
F
.2 .63 .79 r
.70361 .16187 m
.70361 .31564 L
.7058 .31564 L
.7058 .16187 L
s
.678 .847 .902 r
.7058 .16187 m
.7058 .31723 L
.70666 .31723 L
.70666 .16187 L
F
.2 .63 .79 r
.7058 .16187 m
.7058 .31723 L
.70666 .31723 L
.70666 .16187 L
s
.678 .847 .902 r
.70666 .16187 m
.70666 .31786 L
.70802 .31786 L
.70802 .16187 L
F
.2 .63 .79 r
.70666 .16187 m
.70666 .31786 L
.70802 .31786 L
.70802 .16187 L
s
.678 .847 .902 r
.70802 .16187 m
.70802 .31938 L
.70905 .31938 L
.70905 .16187 L
F
.2 .63 .79 r
.70802 .16187 m
.70802 .31938 L
.70905 .31938 L
.70905 .16187 L
s
.678 .847 .902 r
.70905 .16187 m
.70905 .32017 L
.71097 .32017 L
.71097 .16187 L
F
.2 .63 .79 r
.70905 .16187 m
.70905 .32017 L
.71097 .32017 L
.71097 .16187 L
s
.678 .847 .902 r
.71097 .16187 m
.71097 .32201 L
.71263 .32201 L
.71263 .16187 L
F
.2 .63 .79 r
.71097 .16187 m
.71097 .32201 L
.71263 .32201 L
.71263 .16187 L
s
.678 .847 .902 r
.71263 .16187 m
.71263 .32308 L
.71448 .32308 L
.71448 .16187 L
F
.2 .63 .79 r
.71263 .16187 m
.71263 .32308 L
.71448 .32308 L
.71448 .16187 L
s
.678 .847 .902 r
.71448 .16187 m
.71448 .3256 L
.71622 .3256 L
.71622 .16187 L
F
.2 .63 .79 r
.71448 .16187 m
.71448 .3256 L
.71622 .3256 L
.71622 .16187 L
s
.678 .847 .902 r
.71622 .16187 m
.71622 .32719 L
.71805 .32719 L
.71805 .16187 L
F
.2 .63 .79 r
.71622 .16187 m
.71622 .32719 L
.71805 .32719 L
.71805 .16187 L
s
.678 .847 .902 r
.71805 .16187 m
.71805 .32787 L
.71902 .32787 L
.71902 .16187 L
F
.2 .63 .79 r
.71805 .16187 m
.71805 .32787 L
.71902 .32787 L
.71902 .16187 L
s
.678 .847 .902 r
.71902 .16187 m
.71902 .32897 L
.7217 .32897 L
.7217 .16187 L
F
.2 .63 .79 r
.71902 .16187 m
.71902 .32897 L
.7217 .32897 L
.7217 .16187 L
s
.678 .847 .902 r
.7217 .16187 m
.7217 .33271 L
.72415 .33271 L
.72415 .16187 L
F
.2 .63 .79 r
.7217 .16187 m
.7217 .33271 L
.72415 .33271 L
.72415 .16187 L
s
.678 .847 .902 r
.72415 .16187 m
.72415 .33365 L
.72562 .33365 L
.72562 .16187 L
F
.2 .63 .79 r
.72415 .16187 m
.72415 .33365 L
.72562 .33365 L
.72562 .16187 L
s
.678 .847 .902 r
.72562 .16187 m
.72562 .33628 L
.72778 .33628 L
.72778 .16187 L
F
.2 .63 .79 r
.72562 .16187 m
.72562 .33628 L
.72778 .33628 L
.72778 .16187 L
s
.678 .847 .902 r
.72778 .16187 m
.72778 .33727 L
.73061 .33727 L
.73061 .16187 L
F
.2 .63 .79 r
.72778 .16187 m
.72778 .33727 L
.73061 .33727 L
.73061 .16187 L
s
.678 .847 .902 r
.73061 .16187 m
.73061 .33918 L
.7315 .33918 L
.7315 .16187 L
F
.2 .63 .79 r
.73061 .16187 m
.73061 .33918 L
.7315 .33918 L
.7315 .16187 L
s
.678 .847 .902 r
.7315 .16187 m
.7315 .34091 L
.73312 .34091 L
.73312 .16187 L
F
.2 .63 .79 r
.7315 .16187 m
.7315 .34091 L
.73312 .34091 L
.73312 .16187 L
s
.678 .847 .902 r
.73312 .16187 m
.73312 .34123 L
.7344 .34123 L
.7344 .16187 L
F
.2 .63 .79 r
.73312 .16187 m
.73312 .34123 L
.7344 .34123 L
.7344 .16187 L
s
.678 .847 .902 r
.7344 .16187 m
.7344 .34381 L
.73597 .34381 L
.73597 .16187 L
F
.2 .63 .79 r
.7344 .16187 m
.7344 .34381 L
.73597 .34381 L
.73597 .16187 L
s
.678 .847 .902 r
.73597 .16187 m
.73597 .34406 L
.73743 .34406 L
.73743 .16187 L
F
.2 .63 .79 r
.73597 .16187 m
.73597 .34406 L
.73743 .34406 L
.73743 .16187 L
s
.678 .847 .902 r
.73743 .16187 m
.73743 .34536 L
.73839 .34536 L
.73839 .16187 L
F
.2 .63 .79 r
.73743 .16187 m
.73743 .34536 L
.73839 .34536 L
.73839 .16187 L
s
.678 .847 .902 r
.73839 .16187 m
.73839 .34639 L
.73973 .34639 L
.73973 .16187 L
F
.2 .63 .79 r
.73839 .16187 m
.73839 .34639 L
.73973 .34639 L
.73973 .16187 L
s
.678 .847 .902 r
.73973 .16187 m
.73973 .34749 L
.74089 .34749 L
.74089 .16187 L
F
.2 .63 .79 r
.73973 .16187 m
.73973 .34749 L
.74089 .34749 L
.74089 .16187 L
s
.678 .847 .902 r
.74089 .16187 m
.74089 .34958 L
.74289 .34958 L
.74289 .16187 L
F
.2 .63 .79 r
.74089 .16187 m
.74089 .34958 L
.74289 .34958 L
.74289 .16187 L
s
.678 .847 .902 r
.74289 .16187 m
.74289 .35126 L
.74451 .35126 L
.74451 .16187 L
F
.2 .63 .79 r
.74289 .16187 m
.74289 .35126 L
.74451 .35126 L
.74451 .16187 L
s
.678 .847 .902 r
.74451 .16187 m
.74451 .35221 L
.74585 .35221 L
.74585 .16187 L
F
.2 .63 .79 r
.74451 .16187 m
.74451 .35221 L
.74585 .35221 L
.74585 .16187 L
s
.678 .847 .902 r
.74585 .16187 m
.74585 .35475 L
.7485 .35475 L
.7485 .16187 L
F
.2 .63 .79 r
.74585 .16187 m
.74585 .35475 L
.7485 .35475 L
.7485 .16187 L
s
.678 .847 .902 r
.7485 .16187 m
.7485 .35669 L
.75033 .35669 L
.75033 .16187 L
F
.2 .63 .79 r
.7485 .16187 m
.7485 .35669 L
.75033 .35669 L
.75033 .16187 L
s
.678 .847 .902 r
.75033 .16187 m
.75033 .35778 L
.75287 .35778 L
.75287 .16187 L
F
.2 .63 .79 r
.75033 .16187 m
.75033 .35778 L
.75287 .35778 L
.75287 .16187 L
s
.678 .847 .902 r
.75287 .16187 m
.75287 .36145 L
.7554 .36145 L
.7554 .16187 L
F
.2 .63 .79 r
.75287 .16187 m
.75287 .36145 L
.7554 .36145 L
.7554 .16187 L
s
.678 .847 .902 r
.7554 .16187 m
.7554 .36268 L
.75704 .36268 L
.75704 .16187 L
F
.2 .63 .79 r
.7554 .16187 m
.7554 .36268 L
.75704 .36268 L
.75704 .16187 L
s
.678 .847 .902 r
.75704 .16187 m
.75704 .36435 L
.75799 .36435 L
.75799 .16187 L
F
.2 .63 .79 r
.75704 .16187 m
.75704 .36435 L
.75799 .36435 L
.75799 .16187 L
s
.678 .847 .902 r
.75799 .16187 m
.75799 .36511 L
.75956 .36511 L
.75956 .16187 L
F
.2 .63 .79 r
.75799 .16187 m
.75799 .36511 L
.75956 .36511 L
.75956 .16187 L
s
.678 .847 .902 r
.75956 .16187 m
.75956 .36672 L
.76197 .36672 L
.76197 .16187 L
F
.2 .63 .79 r
.75956 .16187 m
.75956 .36672 L
.76197 .36672 L
.76197 .16187 L
s
.678 .847 .902 r
.76197 .16187 m
.76197 .36859 L
.76379 .36859 L
.76379 .16187 L
F
.2 .63 .79 r
.76197 .16187 m
.76197 .36859 L
.76379 .36859 L
.76379 .16187 L
s
.678 .847 .902 r
.76379 .16187 m
.76379 .37129 L
.76513 .37129 L
.76513 .16187 L
F
.2 .63 .79 r
.76379 .16187 m
.76379 .37129 L
.76513 .37129 L
.76513 .16187 L
s
.678 .847 .902 r
.76513 .16187 m
.76513 .37218 L
.76608 .37218 L
.76608 .16187 L
F
.2 .63 .79 r
.76513 .16187 m
.76513 .37218 L
.76608 .37218 L
.76608 .16187 L
s
.678 .847 .902 r
.76608 .16187 m
.76608 .37261 L
.76719 .37261 L
.76719 .16187 L
F
.2 .63 .79 r
.76608 .16187 m
.76608 .37261 L
.76719 .37261 L
.76719 .16187 L
s
.678 .847 .902 r
.76719 .16187 m
.76719 .37472 L
.76902 .37472 L
.76902 .16187 L
F
.2 .63 .79 r
.76719 .16187 m
.76719 .37472 L
.76902 .37472 L
.76902 .16187 L
s
.678 .847 .902 r
.76902 .16187 m
.76902 .37588 L
.77033 .37588 L
.77033 .16187 L
F
.2 .63 .79 r
.76902 .16187 m
.76902 .37588 L
.77033 .37588 L
.77033 .16187 L
s
.678 .847 .902 r
.77033 .16187 m
.77033 .37661 L
.77251 .37661 L
.77251 .16187 L
F
.2 .63 .79 r
.77033 .16187 m
.77033 .37661 L
.77251 .37661 L
.77251 .16187 L
s
.678 .847 .902 r
.77251 .16187 m
.77251 .37927 L
.77518 .37927 L
.77518 .16187 L
F
.2 .63 .79 r
.77251 .16187 m
.77251 .37927 L
.77518 .37927 L
.77518 .16187 L
s
.678 .847 .902 r
.77518 .16187 m
.77518 .38196 L
.7763 .38196 L
.7763 .16187 L
F
.2 .63 .79 r
.77518 .16187 m
.77518 .38196 L
.7763 .38196 L
.7763 .16187 L
s
.678 .847 .902 r
.7763 .16187 m
.7763 .38337 L
.779 .38337 L
.779 .16187 L
F
.2 .63 .79 r
.7763 .16187 m
.7763 .38337 L
.779 .38337 L
.779 .16187 L
s
.678 .847 .902 r
.779 .16187 m
.779 .38669 L
.78107 .38669 L
.78107 .16187 L
F
.2 .63 .79 r
.779 .16187 m
.779 .38669 L
.78107 .38669 L
.78107 .16187 L
s
.678 .847 .902 r
.78107 .16187 m
.78107 .38696 L
.78326 .38696 L
.78326 .16187 L
F
.2 .63 .79 r
.78107 .16187 m
.78107 .38696 L
.78326 .38696 L
.78326 .16187 L
s
.678 .847 .902 r
.78326 .16187 m
.78326 .3908 L
.78606 .3908 L
.78606 .16187 L
F
.2 .63 .79 r
.78326 .16187 m
.78326 .3908 L
.78606 .3908 L
.78606 .16187 L
s
.678 .847 .902 r
.78606 .16187 m
.78606 .39303 L
.78761 .39303 L
.78761 .16187 L
F
.2 .63 .79 r
.78606 .16187 m
.78606 .39303 L
.78761 .39303 L
.78761 .16187 L
s
.678 .847 .902 r
.78761 .16187 m
.78761 .39365 L
.78892 .39365 L
.78892 .16187 L
F
.2 .63 .79 r
.78761 .16187 m
.78761 .39365 L
.78892 .39365 L
.78892 .16187 L
s
.678 .847 .902 r
.78892 .16187 m
.78892 .3958 L
.79062 .3958 L
.79062 .16187 L
F
.2 .63 .79 r
.78892 .16187 m
.78892 .3958 L
.79062 .3958 L
.79062 .16187 L
s
.678 .847 .902 r
.79062 .16187 m
.79062 .39726 L
.79164 .39726 L
.79164 .16187 L
F
.2 .63 .79 r
.79062 .16187 m
.79062 .39726 L
.79164 .39726 L
.79164 .16187 L
s
.678 .847 .902 r
.79164 .16187 m
.79164 .39767 L
.7942 .39767 L
.7942 .16187 L
F
.2 .63 .79 r
.79164 .16187 m
.79164 .39767 L
.7942 .39767 L
.7942 .16187 L
s
.678 .847 .902 r
.7942 .16187 m
.7942 .39993 L
.79582 .39993 L
.79582 .16187 L
F
.2 .63 .79 r
.7942 .16187 m
.7942 .39993 L
.79582 .39993 L
.79582 .16187 L
s
.678 .847 .902 r
.79582 .16187 m
.79582 .40341 L
.79783 .40341 L
.79783 .16187 L
F
.2 .63 .79 r
.79582 .16187 m
.79582 .40341 L
.79783 .40341 L
.79783 .16187 L
s
.678 .847 .902 r
.79783 .16187 m
.79783 .40473 L
.80006 .40473 L
.80006 .16187 L
F
.2 .63 .79 r
.79783 .16187 m
.79783 .40473 L
.80006 .40473 L
.80006 .16187 L
s
.678 .847 .902 r
.80006 .16187 m
.80006 .40651 L
.80252 .40651 L
.80252 .16187 L
F
.2 .63 .79 r
.80006 .16187 m
.80006 .40651 L
.80252 .40651 L
.80252 .16187 L
s
.678 .847 .902 r
.80252 .16187 m
.80252 .40881 L
.80343 .40881 L
.80343 .16187 L
F
.2 .63 .79 r
.80252 .16187 m
.80252 .40881 L
.80343 .40881 L
.80343 .16187 L
s
.678 .847 .902 r
.80343 .16187 m
.80343 .41074 L
.80587 .41074 L
.80587 .16187 L
F
.2 .63 .79 r
.80343 .16187 m
.80343 .41074 L
.80587 .41074 L
.80587 .16187 L
s
.678 .847 .902 r
.80587 .16187 m
.80587 .41212 L
.80714 .41212 L
.80714 .16187 L
F
.2 .63 .79 r
.80587 .16187 m
.80587 .41212 L
.80714 .41212 L
.80714 .16187 L
s
.678 .847 .902 r
.80714 .16187 m
.80714 .4136 L
.80912 .4136 L
.80912 .16187 L
F
.2 .63 .79 r
.80714 .16187 m
.80714 .4136 L
.80912 .4136 L
.80912 .16187 L
s
.678 .847 .902 r
.80912 .16187 m
.80912 .41698 L
.81192 .41698 L
.81192 .16187 L
F
.2 .63 .79 r
.80912 .16187 m
.80912 .41698 L
.81192 .41698 L
.81192 .16187 L
s
.678 .847 .902 r
.81192 .16187 m
.81192 .41849 L
.81411 .41849 L
.81411 .16187 L
F
.2 .63 .79 r
.81192 .16187 m
.81192 .41849 L
.81411 .41849 L
.81411 .16187 L
s
.678 .847 .902 r
.81411 .16187 m
.81411 .42143 L
.81639 .42143 L
.81639 .16187 L
F
.2 .63 .79 r
.81411 .16187 m
.81411 .42143 L
.81639 .42143 L
.81639 .16187 L
s
.678 .847 .902 r
.81639 .16187 m
.81639 .42351 L
.81791 .42351 L
.81791 .16187 L
F
.2 .63 .79 r
.81639 .16187 m
.81639 .42351 L
.81791 .42351 L
.81791 .16187 L
s
.678 .847 .902 r
.81791 .16187 m
.81791 .42486 L
.8194 .42486 L
.8194 .16187 L
F
.2 .63 .79 r
.81791 .16187 m
.81791 .42486 L
.8194 .42486 L
.8194 .16187 L
s
.678 .847 .902 r
.8194 .16187 m
.8194 .42549 L
.82175 .42549 L
.82175 .16187 L
F
.2 .63 .79 r
.8194 .16187 m
.8194 .42549 L
.82175 .42549 L
.82175 .16187 L
s
.678 .847 .902 r
.82175 .16187 m
.82175 .42957 L
.82377 .42957 L
.82377 .16187 L
F
.2 .63 .79 r
.82175 .16187 m
.82175 .42957 L
.82377 .42957 L
.82377 .16187 L
s
.678 .847 .902 r
.82377 .16187 m
.82377 .43048 L
.82545 .43048 L
.82545 .16187 L
F
.2 .63 .79 r
.82377 .16187 m
.82377 .43048 L
.82545 .43048 L
.82545 .16187 L
s
.678 .847 .902 r
.82545 .16187 m
.82545 .43333 L
.8277 .43333 L
.8277 .16187 L
F
.2 .63 .79 r
.82545 .16187 m
.82545 .43333 L
.8277 .43333 L
.8277 .16187 L
s
.678 .847 .902 r
.8277 .16187 m
.8277 .43511 L
.82873 .43511 L
.82873 .16187 L
F
.2 .63 .79 r
.8277 .16187 m
.8277 .43511 L
.82873 .43511 L
.82873 .16187 L
s
.678 .847 .902 r
.82873 .16187 m
.82873 .43547 L
.83079 .43547 L
.83079 .16187 L
F
.2 .63 .79 r
.82873 .16187 m
.82873 .43547 L
.83079 .43547 L
.83079 .16187 L
s
.678 .847 .902 r
.83079 .16187 m
.83079 .43778 L
.83177 .43778 L
.83177 .16187 L
F
.2 .63 .79 r
.83079 .16187 m
.83079 .43778 L
.83177 .43778 L
.83177 .16187 L
s
.678 .847 .902 r
.83177 .16187 m
.83177 .43912 L
.83357 .43912 L
.83357 .16187 L
F
.2 .63 .79 r
.83177 .16187 m
.83177 .43912 L
.83357 .43912 L
.83357 .16187 L
s
.678 .847 .902 r
.83357 .16187 m
.83357 .4408 L
.83575 .4408 L
.83575 .16187 L
F
.2 .63 .79 r
.83357 .16187 m
.83357 .4408 L
.83575 .4408 L
.83575 .16187 L
s
.678 .847 .902 r
.83575 .16187 m
.83575 .44289 L
.83764 .44289 L
.83764 .16187 L
F
.2 .63 .79 r
.83575 .16187 m
.83575 .44289 L
.83764 .44289 L
.83764 .16187 L
s
.678 .847 .902 r
.83764 .16187 m
.83764 .44493 L
.83891 .44493 L
.83891 .16187 L
F
.2 .63 .79 r
.83764 .16187 m
.83764 .44493 L
.83891 .44493 L
.83891 .16187 L
s
.678 .847 .902 r
.83891 .16187 m
.83891 .44626 L
.83995 .44626 L
.83995 .16187 L
F
.2 .63 .79 r
.83891 .16187 m
.83891 .44626 L
.83995 .44626 L
.83995 .16187 L
s
.678 .847 .902 r
.83995 .16187 m
.83995 .44727 L
.84096 .44727 L
.84096 .16187 L
F
.2 .63 .79 r
.83995 .16187 m
.83995 .44727 L
.84096 .44727 L
.84096 .16187 L
s
.678 .847 .902 r
.84096 .16187 m
.84096 .44973 L
.84348 .44973 L
.84348 .16187 L
F
.2 .63 .79 r
.84096 .16187 m
.84096 .44973 L
.84348 .44973 L
.84348 .16187 L
s
.678 .847 .902 r
.84348 .16187 m
.84348 .45071 L
.84513 .45071 L
.84513 .16187 L
F
.2 .63 .79 r
.84348 .16187 m
.84348 .45071 L
.84513 .45071 L
.84513 .16187 L
s
.678 .847 .902 r
.84513 .16187 m
.84513 .45323 L
.84611 .45323 L
.84611 .16187 L
F
.2 .63 .79 r
.84513 .16187 m
.84513 .45323 L
.84611 .45323 L
.84611 .16187 L
s
.678 .847 .902 r
.84611 .16187 m
.84611 .45449 L
.84753 .45449 L
.84753 .16187 L
F
.2 .63 .79 r
.84611 .16187 m
.84611 .45449 L
.84753 .45449 L
.84753 .16187 L
s
.678 .847 .902 r
.84753 .16187 m
.84753 .45558 L
.84963 .45558 L
.84963 .16187 L
F
.2 .63 .79 r
.84753 .16187 m
.84753 .45558 L
.84963 .45558 L
.84963 .16187 L
s
.678 .847 .902 r
.84963 .16187 m
.84963 .45905 L
.85215 .45905 L
.85215 .16187 L
F
.2 .63 .79 r
.84963 .16187 m
.84963 .45905 L
.85215 .45905 L
.85215 .16187 L
s
.678 .847 .902 r
.85215 .16187 m
.85215 .46 L
.85319 .46 L
.85319 .16187 L
F
.2 .63 .79 r
.85215 .16187 m
.85215 .46 L
.85319 .46 L
.85319 .16187 L
s
.678 .847 .902 r
.85319 .16187 m
.85319 .46183 L
.85527 .46183 L
.85527 .16187 L
F
.2 .63 .79 r
.85319 .16187 m
.85319 .46183 L
.85527 .46183 L
.85527 .16187 L
s
.678 .847 .902 r
.85527 .16187 m
.85527 .46519 L
.85793 .46519 L
.85793 .16187 L
F
.2 .63 .79 r
.85527 .16187 m
.85527 .46519 L
.85793 .46519 L
.85793 .16187 L
s
.678 .847 .902 r
.85793 .16187 m
.85793 .46807 L
.85978 .46807 L
.85978 .16187 L
F
.2 .63 .79 r
.85793 .16187 m
.85793 .46807 L
.85978 .46807 L
.85978 .16187 L
s
.678 .847 .902 r
.85978 .16187 m
.85978 .46928 L
.86218 .46928 L
.86218 .16187 L
F
.2 .63 .79 r
.85978 .16187 m
.85978 .46928 L
.86218 .46928 L
.86218 .16187 L
s
.678 .847 .902 r
.86218 .16187 m
.86218 .47171 L
.86475 .47171 L
.86475 .16187 L
F
.2 .63 .79 r
.86218 .16187 m
.86218 .47171 L
.86475 .47171 L
.86475 .16187 L
s
.678 .847 .902 r
.86475 .16187 m
.86475 .47501 L
.86626 .47501 L
.86626 .16187 L
F
.2 .63 .79 r
.86475 .16187 m
.86475 .47501 L
.86626 .47501 L
.86626 .16187 L
s
.678 .847 .902 r
.86626 .16187 m
.86626 .476 L
.86728 .476 L
.86728 .16187 L
F
.2 .63 .79 r
.86626 .16187 m
.86626 .476 L
.86728 .476 L
.86728 .16187 L
s
.678 .847 .902 r
.86728 .16187 m
.86728 .47719 L
.86828 .47719 L
.86828 .16187 L
F
.2 .63 .79 r
.86728 .16187 m
.86728 .47719 L
.86828 .47719 L
.86828 .16187 L
s
.678 .847 .902 r
.86828 .16187 m
.86828 .47843 L
.87068 .47843 L
.87068 .16187 L
F
.2 .63 .79 r
.86828 .16187 m
.86828 .47843 L
.87068 .47843 L
.87068 .16187 L
s
.678 .847 .902 r
.87068 .16187 m
.87068 .48188 L
.87297 .48188 L
.87297 .16187 L
F
.2 .63 .79 r
.87068 .16187 m
.87068 .48188 L
.87297 .48188 L
.87297 .16187 L
s
.678 .847 .902 r
.87297 .16187 m
.87297 .48284 L
.87387 .48284 L
.87387 .16187 L
F
.2 .63 .79 r
.87297 .16187 m
.87297 .48284 L
.87387 .48284 L
.87387 .16187 L
s
.678 .847 .902 r
.87387 .16187 m
.87387 .48436 L
.87591 .48436 L
.87591 .16187 L
F
.2 .63 .79 r
.87387 .16187 m
.87387 .48436 L
.87591 .48436 L
.87591 .16187 L
s
.678 .847 .902 r
.87591 .16187 m
.87591 .48602 L
.87699 .48602 L
.87699 .16187 L
F
.2 .63 .79 r
.87591 .16187 m
.87591 .48602 L
.87699 .48602 L
.87699 .16187 L
s
.678 .847 .902 r
.87699 .16187 m
.87699 .4878 L
.87825 .4878 L
.87825 .16187 L
F
.2 .63 .79 r
.87699 .16187 m
.87699 .4878 L
.87825 .4878 L
.87825 .16187 L
s
.678 .847 .902 r
.87825 .16187 m
.87825 .49089 L
.88072 .49089 L
.88072 .16187 L
F
.2 .63 .79 r
.87825 .16187 m
.87825 .49089 L
.88072 .49089 L
.88072 .16187 L
s
.678 .847 .902 r
.88072 .16187 m
.88072 .49319 L
.88258 .49319 L
.88258 .16187 L
F
.2 .63 .79 r
.88072 .16187 m
.88072 .49319 L
.88258 .49319 L
.88258 .16187 L
s
.678 .847 .902 r
.88258 .16187 m
.88258 .49413 L
.8835 .49413 L
.8835 .16187 L
F
.2 .63 .79 r
.88258 .16187 m
.88258 .49413 L
.8835 .49413 L
.8835 .16187 L
s
.678 .847 .902 r
.8835 .16187 m
.8835 .49587 L
.88509 .49587 L
.88509 .16187 L
F
.2 .63 .79 r
.8835 .16187 m
.8835 .49587 L
.88509 .49587 L
.88509 .16187 L
s
.678 .847 .902 r
.88509 .16187 m
.88509 .49774 L
.88677 .49774 L
.88677 .16187 L
F
.2 .63 .79 r
.88509 .16187 m
.88509 .49774 L
.88677 .49774 L
.88677 .16187 L
s
.678 .847 .902 r
.88677 .16187 m
.88677 .4984 L
.88849 .4984 L
.88849 .16187 L
F
.2 .63 .79 r
.88677 .16187 m
.88677 .4984 L
.88849 .4984 L
.88849 .16187 L
s
.678 .847 .902 r
.88849 .16187 m
.88849 .50035 L
.89084 .50035 L
.89084 .16187 L
F
.2 .63 .79 r
.88849 .16187 m
.88849 .50035 L
.89084 .50035 L
.89084 .16187 L
s
.678 .847 .902 r
.89084 .16187 m
.89084 .50419 L
.89317 .50419 L
.89317 .16187 L
F
.2 .63 .79 r
.89084 .16187 m
.89084 .50419 L
.89317 .50419 L
.89317 .16187 L
s
.678 .847 .902 r
.89317 .16187 m
.89317 .50568 L
.89518 .50568 L
.89518 .16187 L
F
.2 .63 .79 r
.89317 .16187 m
.89317 .50568 L
.89518 .50568 L
.89518 .16187 L
s
.678 .847 .902 r
.89518 .16187 m
.89518 .50781 L
.89672 .50781 L
.89672 .16187 L
F
.2 .63 .79 r
.89518 .16187 m
.89518 .50781 L
.89672 .50781 L
.89672 .16187 L
s
.678 .847 .902 r
.89672 .16187 m
.89672 .51026 L
.89784 .51026 L
.89784 .16187 L
F
.2 .63 .79 r
.89672 .16187 m
.89672 .51026 L
.89784 .51026 L
.89784 .16187 L
s
.678 .847 .902 r
.89784 .16187 m
.89784 .51328 L
.90036 .51328 L
.90036 .16187 L
F
.2 .63 .79 r
.89784 .16187 m
.89784 .51328 L
.90036 .51328 L
.90036 .16187 L
s
.678 .847 .902 r
.90036 .16187 m
.90036 .51367 L
.90137 .51367 L
.90137 .16187 L
F
.2 .63 .79 r
.90036 .16187 m
.90036 .51367 L
.90137 .51367 L
.90137 .16187 L
s
.678 .847 .902 r
.90137 .16187 m
.90137 .51629 L
.90337 .51629 L
.90337 .16187 L
F
.2 .63 .79 r
.90137 .16187 m
.90137 .51629 L
.90337 .51629 L
.90337 .16187 L
s
.678 .847 .902 r
.90337 .16187 m
.90337 .51758 L
.90476 .51758 L
.90476 .16187 L
F
.2 .63 .79 r
.90337 .16187 m
.90337 .51758 L
.90476 .51758 L
.90476 .16187 L
s
.678 .847 .902 r
.90476 .16187 m
.90476 .51865 L
.90663 .51865 L
.90663 .16187 L
F
.2 .63 .79 r
.90476 .16187 m
.90476 .51865 L
.90663 .51865 L
.90663 .16187 L
s
.678 .847 .902 r
.90663 .16187 m
.90663 .52261 L
.90947 .52261 L
.90947 .16187 L
F
.2 .63 .79 r
.90663 .16187 m
.90663 .52261 L
.90947 .52261 L
.90947 .16187 L
s
.678 .847 .902 r
.90947 .16187 m
.90947 .52388 L
.91132 .52388 L
.91132 .16187 L
F
.2 .63 .79 r
.90947 .16187 m
.90947 .52388 L
.91132 .52388 L
.91132 .16187 L
s
.678 .847 .902 r
.91132 .16187 m
.91132 .52622 L
.91316 .52622 L
.91316 .16187 L
F
.2 .63 .79 r
.91132 .16187 m
.91132 .52622 L
.91316 .52622 L
.91316 .16187 L
s
.678 .847 .902 r
.91316 .16187 m
.91316 .52925 L
.91559 .52925 L
.91559 .16187 L
F
.2 .63 .79 r
.91316 .16187 m
.91316 .52925 L
.91559 .52925 L
.91559 .16187 L
s
.678 .847 .902 r
.91559 .16187 m
.91559 .53229 L
.91837 .53229 L
.91837 .16187 L
F
.2 .63 .79 r
.91559 .16187 m
.91559 .53229 L
.91837 .53229 L
.91837 .16187 L
s
.678 .847 .902 r
.91837 .16187 m
.91837 .53635 L
.92104 .53635 L
.92104 .16187 L
F
.2 .63 .79 r
.91837 .16187 m
.91837 .53635 L
.92104 .53635 L
.92104 .16187 L
s
.678 .847 .902 r
.92104 .16187 m
.92104 .53723 L
.92265 .53723 L
.92265 .16187 L
F
.2 .63 .79 r
.92104 .16187 m
.92104 .53723 L
.92265 .53723 L
.92265 .16187 L
s
.678 .847 .902 r
.92265 .16187 m
.92265 .54122 L
.92467 .54122 L
.92467 .16187 L
F
.2 .63 .79 r
.92265 .16187 m
.92265 .54122 L
.92467 .54122 L
.92467 .16187 L
s
.678 .847 .902 r
.92467 .16187 m
.92467 .54216 L
.92583 .54216 L
.92583 .16187 L
F
.2 .63 .79 r
.92467 .16187 m
.92467 .54216 L
.92583 .54216 L
.92583 .16187 L
s
.678 .847 .902 r
.92583 .16187 m
.92583 .54429 L
.9275 .54429 L
.9275 .16187 L
F
.2 .63 .79 r
.92583 .16187 m
.92583 .54429 L
.9275 .54429 L
.9275 .16187 L
s
.678 .847 .902 r
.9275 .16187 m
.9275 .54512 L
.92905 .54512 L
.92905 .16187 L
F
.2 .63 .79 r
.9275 .16187 m
.9275 .54512 L
.92905 .54512 L
.92905 .16187 L
s
.678 .847 .902 r
.92905 .16187 m
.92905 .54659 L
.93033 .54659 L
.93033 .16187 L
F
.2 .63 .79 r
.92905 .16187 m
.92905 .54659 L
.93033 .54659 L
.93033 .16187 L
s
.678 .847 .902 r
.93033 .16187 m
.93033 .54995 L
.93266 .54995 L
.93266 .16187 L
F
.2 .63 .79 r
.93033 .16187 m
.93033 .54995 L
.93266 .54995 L
.93266 .16187 L
s
.678 .847 .902 r
.93266 .16187 m
.93266 .55268 L
.93546 .55268 L
.93546 .16187 L
F
.2 .63 .79 r
.93266 .16187 m
.93266 .55268 L
.93546 .55268 L
.93546 .16187 L
s
.678 .847 .902 r
.93546 .16187 m
.93546 .55423 L
.9375 .55423 L
.9375 .16187 L
F
.2 .63 .79 r
.93546 .16187 m
.93546 .55423 L
.9375 .55423 L
.9375 .16187 L
s
.678 .847 .902 r
.9375 .16187 m
.9375 .55741 L
.9393 .55741 L
.9393 .16187 L
F
.2 .63 .79 r
.9375 .16187 m
.9375 .55741 L
.9393 .55741 L
.9393 .16187 L
s
.678 .847 .902 r
.9393 .16187 m
.9393 .55929 L
.94048 .55929 L
.94048 .16187 L
F
.2 .63 .79 r
.9393 .16187 m
.9393 .55929 L
.94048 .55929 L
.94048 .16187 L
s
.678 .847 .902 r
.94048 .16187 m
.94048 .56095 L
.94259 .56095 L
.94259 .16187 L
F
.2 .63 .79 r
.94048 .16187 m
.94048 .56095 L
.94259 .56095 L
.94259 .16187 L
s
.678 .847 .902 r
.94259 .16187 m
.94259 .56301 L
.94437 .56301 L
.94437 .16187 L
F
.2 .63 .79 r
.94259 .16187 m
.94259 .56301 L
.94437 .56301 L
.94437 .16187 L
s
.678 .847 .902 r
.94437 .16187 m
.94437 .56579 L
.94649 .56579 L
.94649 .16187 L
F
.2 .63 .79 r
.94437 .16187 m
.94437 .56579 L
.94649 .56579 L
.94649 .16187 L
s
.678 .847 .902 r
.94649 .16187 m
.94649 .56741 L
.94751 .56741 L
.94751 .16187 L
F
.2 .63 .79 r
.94649 .16187 m
.94649 .56741 L
.94751 .56741 L
.94751 .16187 L
s
.678 .847 .902 r
.94751 .16187 m
.94751 .56907 L
.94848 .56907 L
.94848 .16187 L
F
.2 .63 .79 r
.94751 .16187 m
.94751 .56907 L
.94848 .56907 L
.94848 .16187 L
s
.678 .847 .902 r
.94848 .16187 m
.94848 .57061 L
.94972 .57061 L
.94972 .16187 L
F
.2 .63 .79 r
.94848 .16187 m
.94848 .57061 L
.94972 .57061 L
.94972 .16187 L
s
.678 .847 .902 r
.94972 .16187 m
.94972 .57146 L
.95082 .57146 L
.95082 .16187 L
F
.2 .63 .79 r
.94972 .16187 m
.94972 .57146 L
.95082 .57146 L
.95082 .16187 L
s
.678 .847 .902 r
.95082 .16187 m
.95082 .57304 L
.95186 .57304 L
.95186 .16187 L
F
.2 .63 .79 r
.95082 .16187 m
.95082 .57304 L
.95186 .57304 L
.95186 .16187 L
s
.678 .847 .902 r
.95186 .16187 m
.95186 .57482 L
.95382 .57482 L
.95382 .16187 L
F
.2 .63 .79 r
.95186 .16187 m
.95186 .57482 L
.95382 .57482 L
.95382 .16187 L
s
.678 .847 .902 r
.95382 .16187 m
.95382 .57745 L
.95607 .57745 L
.95607 .16187 L
F
.2 .63 .79 r
.95382 .16187 m
.95382 .57745 L
.95607 .57745 L
.95607 .16187 L
s
.678 .847 .902 r
.95607 .16187 m
.95607 .5803 L
.95759 .5803 L
.95759 .16187 L
F
.2 .63 .79 r
.95607 .16187 m
.95607 .5803 L
.95759 .5803 L
.95759 .16187 L
s
.678 .847 .902 r
.95759 .16187 m
.95759 .58064 L
.95869 .58064 L
.95869 .16187 L
F
.2 .63 .79 r
.95759 .16187 m
.95759 .58064 L
.95869 .58064 L
.95869 .16187 L
s
.678 .847 .902 r
.95869 .16187 m
.95869 .58385 L
.96084 .58385 L
.96084 .16187 L
F
.2 .63 .79 r
.95869 .16187 m
.95869 .58385 L
.96084 .58385 L
.96084 .16187 L
s
.678 .847 .902 r
.96084 .16187 m
.96084 .58536 L
.96233 .58536 L
.96233 .16187 L
F
.2 .63 .79 r
.96084 .16187 m
.96084 .58536 L
.96233 .58536 L
.96233 .16187 L
s
.678 .847 .902 r
.96233 .16187 m
.96233 .58894 L
.96468 .58894 L
.96468 .16187 L
F
.2 .63 .79 r
.96233 .16187 m
.96233 .58894 L
.96468 .58894 L
.96468 .16187 L
s
.678 .847 .902 r
.96468 .16187 m
.96468 .5908 L
.96746 .5908 L
.96746 .16187 L
F
.2 .63 .79 r
.96468 .16187 m
.96468 .5908 L
.96746 .5908 L
.96746 .16187 L
s
.678 .847 .902 r
.96746 .16187 m
.96746 .59413 L
.96879 .59413 L
.96879 .16187 L
F
.2 .63 .79 r
.96746 .16187 m
.96746 .59413 L
.96879 .59413 L
.96879 .16187 L
s
.678 .847 .902 r
.96879 .16187 m
.96879 .59501 L
.97159 .59501 L
.97159 .16187 L
F
.2 .63 .79 r
.96879 .16187 m
.96879 .59501 L
.97159 .59501 L
.97159 .16187 L
s
.678 .847 .902 r
.97159 .16187 m
.97159 .59965 L
.9735 .59965 L
.9735 .16187 L
F
.2 .63 .79 r
.97159 .16187 m
.97159 .59965 L
.9735 .59965 L
.9735 .16187 L
s
.678 .847 .902 r
.9735 .16187 m
.9735 .60124 L
.97481 .60124 L
.97481 .16187 L
F
.2 .63 .79 r
.9735 .16187 m
.9735 .60124 L
.97481 .60124 L
.97481 .16187 L
s
.678 .847 .902 r
.97481 .16187 m
.97481 .60224 L
.97619 .60224 L
.97619 .16187 L
F
.2 .63 .79 r
.97481 .16187 m
.97481 .60224 L
.97619 .60224 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02431 .01472 Mdot
.02518 .01472 Mdot
.02627 .01472 Mdot
.029 .01473 Mdot
.0312 .01475 Mdot
.0324 .01476 Mdot
.03492 .0148 Mdot
.03616 .01481 Mdot
.03849 .01485 Mdot
.03978 .01488 Mdot
.04398 .01498 Mdot
.0443 .01499 Mdot
.04655 .01505 Mdot
.05006 .01516 Mdot
.05123 .0152 Mdot
.05209 .01523 Mdot
.05436 .01532 Mdot
.05536 .01536 Mdot
.0593 .01553 Mdot
.06004 .01557 Mdot
.0624 .01568 Mdot
.06343 .01573 Mdot
.06503 .01582 Mdot
.06783 .01597 Mdot
.06844 .01601 Mdot
.06953 .01607 Mdot
.0703 .01612 Mdot
.07117 .01617 Mdot
.07344 .01631 Mdot
.07466 .01639 Mdot
.07703 .01655 Mdot
.08001 .01676 Mdot
.08281 .01697 Mdot
.08497 .01714 Mdot
.08685 .01729 Mdot
.0887 .01745 Mdot
.08987 .01755 Mdot
.09138 .01768 Mdot
.09328 .01785 Mdot
.09433 .01794 Mdot
.09822 .01831 Mdot
.0997 .01845 Mdot
.10034 .01852 Mdot
.10271 .01876 Mdot
.10477 .01897 Mdot
.10598 .0191 Mdot
.10905 .01943 Mdot
.1113 .01968 Mdot
.1145 .02005 Mdot
.11546 .02017 Mdot
.11919 .02062 Mdot
.11938 .02064 Mdot
.12203 .02098 Mdot
.12378 .0212 Mdot
.12533 .0214 Mdot
.12664 .02158 Mdot
.12975 .022 Mdot
.13139 .02223 Mdot
.13413 .02261 Mdot
.13536 .02279 Mdot
.13577 .02285 Mdot
.13919 .02335 Mdot
.14239 .02384 Mdot
.14318 .02396 Mdot
.144 .02409 Mdot
.14623 .02444 Mdot
.14892 .02487 Mdot
.14995 .02504 Mdot
.15223 .02542 Mdot
.1537 .02566 Mdot
.15568 .026 Mdot
.15727 .02627 Mdot
.16175 .02706 Mdot
.16213 .02713 Mdot
.16435 .02753 Mdot
.16748 .02811 Mdot
.16873 .02834 Mdot
.17253 .02907 Mdot
.17276 .02911 Mdot
.17677 .0299 Mdot
.1799 .03053 Mdot
.18225 .03101 Mdot
.18381 .03133 Mdot
.18741 .03208 Mdot
.18982 .0326 Mdot
.19096 .03285 Mdot
.19231 .03314 Mdot
.1937 .03345 Mdot
.19626 .03401 Mdot
.19761 .03432 Mdot
.19856 .03453 Mdot
.20177 .03527 Mdot
.20349 .03567 Mdot
.2055 .03614 Mdot
.20715 .03653 Mdot
.20976 .03715 Mdot
.21227 .03776 Mdot
.21362 .03809 Mdot
.21476 .03838 Mdot
.21753 .03907 Mdot
.21886 .0394 Mdot
.22184 .04016 Mdot
.22305 .04048 Mdot
.22504 .04099 Mdot
.22695 .0415 Mdot
.22775 .04171 Mdot
.22915 .04208 Mdot
.23128 .04265 Mdot
.2323 .04292 Mdot
.2335 .04325 Mdot
.23728 .04429 Mdot
.23768 .0444 Mdot
.23941 .04488 Mdot
.24109 .04535 Mdot
.24294 .04588 Mdot
.24429 .04626 Mdot
.24713 .04708 Mdot
.24951 .04777 Mdot
.2514 .04833 Mdot
.25254 .04867 Mdot
.2545 .04925 Mdot
.25604 .04971 Mdot
.25707 .05002 Mdot
.25913 .05065 Mdot
.25996 .0509 Mdot
.26161 .05141 Mdot
.26394 .05213 Mdot
.2646 .05234 Mdot
.26696 .05308 Mdot
.26855 .05359 Mdot
.27097 .05436 Mdot
.27334 .05512 Mdot
.27594 .05597 Mdot
.27807 .05667 Mdot
.28058 .0575 Mdot
.28213 .05802 Mdot
.28386 .0586 Mdot
.28691 .05964 Mdot
.28815 .06006 Mdot
.28916 .06041 Mdot
.29024 .06078 Mdot
.29194 .06137 Mdot
.29408 .06212 Mdot
.29724 .06323 Mdot
.29941 .06401 Mdot
.30068 .06446 Mdot
.30265 .06517 Mdot
.30289 .06526 Mdot
.30516 .06609 Mdot
.30694 .06674 Mdot
.30742 .06691 Mdot
.30891 .06746 Mdot
.31148 .06842 Mdot
.31311 .06903 Mdot
.31592 .07009 Mdot
.31815 .07094 Mdot
.32037 .07179 Mdot
.322 .07242 Mdot
.32453 .0734 Mdot
.32496 .07357 Mdot
.32745 .07454 Mdot
.3309 .07591 Mdot
.33319 .07683 Mdot
.33353 .07697 Mdot
.336 .07796 Mdot
.33655 .07818 Mdot
.33864 .07904 Mdot
.34075 .0799 Mdot
.34246 .08061 Mdot
.34414 .0813 Mdot
.34573 .08196 Mdot
.34695 .08248 Mdot
.34833 .08306 Mdot
.3514 .08436 Mdot
.35316 .08511 Mdot
.35526 .08601 Mdot
.35633 .08647 Mdot
.35964 .08791 Mdot
.36032 .0882 Mdot
.36177 .08884 Mdot
.36463 .0901 Mdot
.36675 .09103 Mdot
.3672 .09123 Mdot
.37022 .09259 Mdot
.37237 .09356 Mdot
.37401 .0943 Mdot
.37456 .09455 Mdot
.37753 .09591 Mdot
.37944 .09679 Mdot
.38015 .09712 Mdot
.38147 .09773 Mdot
.38378 .0988 Mdot
.3853 .09951 Mdot
.38659 .10012 Mdot
.38917 .10134 Mdot
.39048 .10196 Mdot
.39219 .10278 Mdot
.39392 .10361 Mdot
.39728 .10523 Mdot
.39881 .10597 Mdot
.40039 .10674 Mdot
.40236 .10771 Mdot
.40422 .10862 Mdot
.40633 .10967 Mdot
.40696 .10998 Mdot
.40807 .11053 Mdot
.41117 .11209 Mdot
.41177 .11239 Mdot
.41401 .11352 Mdot
.41567 .11436 Mdot
.4181 .1156 Mdot
.41899 .11606 Mdot
.42014 .11665 Mdot
.42044 .1168 Mdot
.42339 .11833 Mdot
.42658 .11999 Mdot
.42929 .12141 Mdot
.43001 .12179 Mdot
.43119 .12241 Mdot
.432 .12284 Mdot
.43396 .12388 Mdot
.43466 .12425 Mdot
.43764 .12585 Mdot
.43849 .1263 Mdot
.44036 .12732 Mdot
.44093 .12762 Mdot
.4444 .12951 Mdot
.44581 .13028 Mdot
.44723 .13106 Mdot
.44951 .13231 Mdot
.45178 .13357 Mdot
.4524 .13392 Mdot
.45512 .13544 Mdot
.45662 .13628 Mdot
.4579 .13699 Mdot
.4604 .13841 Mdot
.46106 .13879 Mdot
.46311 .13995 Mdot
.46558 .14136 Mdot
.46619 .14171 Mdot
.46841 .14299 Mdot
.47022 .14404 Mdot
.47145 .14475 Mdot
.47318 .14575 Mdot
.47556 .14715 Mdot
.4782 .1487 Mdot
.48053 .15008 Mdot
.48261 .15131 Mdot
.48383 .15204 Mdot
.48784 .15445 Mdot
.48947 .15543 Mdot
.49024 .15589 Mdot
.49259 .15732 Mdot
.4946 .15855 Mdot
.49663 .15979 Mdot
.49924 .16139 Mdot
.50047 .16215 Mdot
.50133 .16269 Mdot
.50357 .16408 Mdot
.50636 .16582 Mdot
.50748 .16652 Mdot
.50974 .16795 Mdot
.51157 .1691 Mdot
.51334 .17023 Mdot
.51417 .17075 Mdot
.51695 .17253 Mdot
.51891 .17379 Mdot
.52181 .17565 Mdot
.52279 .17629 Mdot
.52529 .17791 Mdot
.52763 .17944 Mdot
.52885 .18023 Mdot
.5312 .18178 Mdot
.53251 .18265 Mdot
.53372 .18344 Mdot
.53661 .18536 Mdot
.53691 .18556 Mdot
.54001 .18763 Mdot
.54158 .18868 Mdot
.54341 .18992 Mdot
.54382 .1902 Mdot
.54536 .19124 Mdot
.54855 .1934 Mdot
.54886 .19361 Mdot
.55249 .1961 Mdot
.5545 .19747 Mdot
.55574 .19833 Mdot
.55723 .19936 Mdot
.55879 .20045 Mdot
.55962 .20102 Mdot
.56387 .20398 Mdot
.56541 .20506 Mdot
.56693 .20613 Mdot
.56952 .20797 Mdot
.57331 .21066 Mdot
.57459 .21158 Mdot
.57641 .21288 Mdot
.57736 .21356 Mdot
.57982 .21533 Mdot
.58147 .21652 Mdot
.58239 .21719 Mdot
.58387 .21826 Mdot
.58519 .21922 Mdot
.5859 .21975 Mdot
.58708 .22061 Mdot
.58791 .22121 Mdot
.58961 .22246 Mdot
.5904 .22304 Mdot
.59299 .22495 Mdot
.59466 .22618 Mdot
.596 .22718 Mdot
.5993 .22963 Mdot
.60014 .23027 Mdot
.60353 .23281 Mdot
.60502 .23393 Mdot
.60871 .23672 Mdot
.60957 .23737 Mdot
.60991 .23763 Mdot
.6132 .24014 Mdot
.61477 .24135 Mdot
.61636 .24257 Mdot
.61966 .24511 Mdot
.62058 .24582 Mdot
.62155 .24657 Mdot
.62296 .24767 Mdot
.6239 .2484 Mdot
.62465 .24899 Mdot
.62596 .25001 Mdot
.62731 .25107 Mdot
.63052 .25358 Mdot
.63429 .25657 Mdot
.63545 .25749 Mdot
.63848 .2599 Mdot
.64077 .26172 Mdot
.64262 .26321 Mdot
.64472 .2649 Mdot
.64578 .26576 Mdot
.6466 .26642 Mdot
.64881 .26821 Mdot
.65121 .27016 Mdot
.65381 .27228 Mdot
.65495 .27321 Mdot
.65937 .27684 Mdot
.66078 .27801 Mdot
.66374 .28047 Mdot
.66475 .2813 Mdot
.6664 .28268 Mdot
.66822 .2842 Mdot
.67037 .286 Mdot
.67287 .2881 Mdot
.67347 .28861 Mdot
.67484 .28976 Mdot
.6789 .2932 Mdot
.67935 .29359 Mdot
.68091 .29492 Mdot
.68419 .29771 Mdot
.68577 .29907 Mdot
.68877 .30166 Mdot
.69128 .30383 Mdot
.69217 .3046 Mdot
.69388 .30609 Mdot
.69666 .30851 Mdot
.69941 .31091 Mdot
.7011 .3124 Mdot
.70254 .31366 Mdot
.70478 .31564 Mdot
.70658 .31723 Mdot
.70729 .31786 Mdot
.709 .31938 Mdot
.70988 .32017 Mdot
.71195 .32201 Mdot
.71315 .32308 Mdot
.71596 .3256 Mdot
.71773 .32719 Mdot
.71848 .32787 Mdot
.7197 .32897 Mdot
.72383 .33271 Mdot
.72486 .33365 Mdot
.72774 .33628 Mdot
.72883 .33727 Mdot
.73092 .33918 Mdot
.73279 .34091 Mdot
.73315 .34123 Mdot
.73595 .34381 Mdot
.73621 .34406 Mdot
.73761 .34536 Mdot
.73873 .34639 Mdot
.73991 .34749 Mdot
.74215 .34958 Mdot
.74396 .35126 Mdot
.74497 .35221 Mdot
.74768 .35475 Mdot
.74974 .35669 Mdot
.7509 .35778 Mdot
.75477 .36145 Mdot
.75608 .36268 Mdot
.75783 .36435 Mdot
.75862 .36511 Mdot
.76031 .36672 Mdot
.76226 .36859 Mdot
.76508 .37129 Mdot
.766 .37218 Mdot
.76644 .37261 Mdot
.76863 .37472 Mdot
.76983 .37588 Mdot
.77059 .37661 Mdot
.77333 .37927 Mdot
.77608 .38196 Mdot
.77753 .38337 Mdot
.78092 .38669 Mdot
.78119 .38696 Mdot
.78509 .3908 Mdot
.78734 .39303 Mdot
.78796 .39365 Mdot
.79013 .3958 Mdot
.7916 .39726 Mdot
.792 .39767 Mdot
.79427 .39993 Mdot
.79775 .40341 Mdot
.79905 .40473 Mdot
.80082 .40651 Mdot
.8031 .40881 Mdot
.80501 .41074 Mdot
.80637 .41212 Mdot
.80783 .4136 Mdot
.81114 .41698 Mdot
.81262 .41849 Mdot
.81548 .42143 Mdot
.8175 .42351 Mdot
.81881 .42486 Mdot
.81942 .42549 Mdot
.82337 .42957 Mdot
.82424 .43048 Mdot
.82697 .43333 Mdot
.82869 .43511 Mdot
.82903 .43547 Mdot
.83123 .43778 Mdot
.83251 .43912 Mdot
.83411 .4408 Mdot
.8361 .44289 Mdot
.83803 .44493 Mdot
.83929 .44626 Mdot
.84024 .44727 Mdot
.84256 .44973 Mdot
.84348 .45071 Mdot
.84585 .45323 Mdot
.84703 .45449 Mdot
.84805 .45558 Mdot
.85128 .45905 Mdot
.85216 .46 Mdot
.85387 .46183 Mdot
.85698 .46519 Mdot
.85964 .46807 Mdot
.86076 .46928 Mdot
.86299 .47171 Mdot
.86602 .47501 Mdot
.86692 .476 Mdot
.86801 .47719 Mdot
.86913 .47843 Mdot
.87227 .48188 Mdot
.87314 .48284 Mdot
.87452 .48436 Mdot
.87603 .48602 Mdot
.87763 .4878 Mdot
.88042 .49089 Mdot
.88248 .49319 Mdot
.88333 .49413 Mdot
.88489 .49587 Mdot
.88656 .49774 Mdot
.88714 .4984 Mdot
.88889 .50035 Mdot
.8923 .50419 Mdot
.89362 .50568 Mdot
.8955 .50781 Mdot
.89767 .51026 Mdot
.90033 .51328 Mdot
.90067 .51367 Mdot
.90297 .51629 Mdot
.9041 .51758 Mdot
.90503 .51865 Mdot
.90849 .52261 Mdot
.9096 .52388 Mdot
.91163 .52622 Mdot
.91425 .52925 Mdot
.91688 .53229 Mdot
.92037 .53635 Mdot
.92113 .53723 Mdot
.92455 .54122 Mdot
.92535 .54216 Mdot
.92717 .54429 Mdot
.92788 .54512 Mdot
.92913 .54659 Mdot
.93199 .54995 Mdot
.9343 .55268 Mdot
.93561 .55423 Mdot
.9383 .55741 Mdot
.93987 .55929 Mdot
.94127 .56095 Mdot
.943 .56301 Mdot
.94533 .56579 Mdot
.94668 .56741 Mdot
.94807 .56907 Mdot
.94935 .57061 Mdot
.95006 .57146 Mdot
.95137 .57304 Mdot
.95285 .57482 Mdot
.95503 .57745 Mdot
.95738 .5803 Mdot
.95767 .58064 Mdot
.96031 .58385 Mdot
.96155 .58536 Mdot
.96449 .58894 Mdot
.96601 .5908 Mdot
.96873 .59413 Mdot
.96944 .59501 Mdot
.97322 .59965 Mdot
.9745 .60124 Mdot
.97532 .60224 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(518) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00596903) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666881) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<0
00000`3jl>H600000?l0n_3VV`3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00040?[`iP800000o`3jl>JM0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2
000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000040?[`iP800000o`3jl>JM0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JM0?[`iP40
oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4
000000<0n_3V100000030?[`iP@00000103jl>H3000000@0n_3V0`0000050?[`iP800000o`3jl>JM
0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H40000
00030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H20000
00D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`
iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000@0n_3V0P00003o0?[`iYd0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0
n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H400000?l0n_3VW@3jl>H10?ooo`007`3jl>H6000000@0n_3V
0P00000_0?[`iPD00000:03jl>H3000000`0n_3V0`0000040?[`iP<00000103jl>H3000000<0n_3V
0`0000040?[`iP<000001@3jl>H200000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0
n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00
000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H00000
0000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<0
0000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H10?ooo`00
8P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V
0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H20000
0080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP80
0000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000000000T0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
0000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP800000
1@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H000000000
00020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V
0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000
000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V
0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V1000
00030?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103j
l>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P00
00050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;
0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2
000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00003o
0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00000<0?[`
iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00003o0?[`
iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V0000
00000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`
iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0
000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H00000
01P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H30000
0080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V10000000
0`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H00000
0?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000@0n_3V0`0000040?[`iP<00000
0`3jl>H3000000D0n_3V0`0000030?[`iP<000001@3jl>H3000000@0n_3V0`00001[0?[`iP40oooo
000Q0?[`iP80000000<0n_3V0000000000001@000000103jl>H000000000000000020?[`iP800000
00<0n_3V0000000000002@3jl>H5000000T0n_3V0P00003O0?[`iP800000103jl>H200000080n_3V
0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP80
00000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00030?[`iP000000000000X0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
0080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H20000
00030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P0000040?[`iP8000000`3jl>H20000
00030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3jl>H00`00
0000n_3V0?[`iP02000006X0n_3V0@3oool00280n_3V0`00000Y0?[`iP800000gP3jl>H2000000@0
n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80
000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H20000
00030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H2000000D0n_3V0P0000020?[`
iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000050?[`
iP800000JP3jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP800000g@3jl>H4000000<0
n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H0
0000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000
003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H2000000<0n_3V100000020?[`
iP80000000<0n_3V0000000000000`3jl>H400000080n_3V0P0000000`3jl>H00000000000050?[`
iP800000JP3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002X0n_3V0P00003L0?[`iP80
000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00030?[`iP000000000000X0n_3V0`000000103jl>H000000000003jl>H200000080n_3V0P000002
0?[`iP<0000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02000001P0n_3V0P000000
0`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
00000080n_3V00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H4
000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000`3jl>H3
000006/0n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V
000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V
000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3j
l>H5000000/0n_3V0`0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000030?[`iP00
0000000000L000006@3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H4000000<0n_3V0P0000000`3jl>H000000000
00020?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00050?[`iP800000JP3jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`iP800000;P3jl>H2
000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000D0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0
n_3V00800000JP3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H20000
00@0n_3V0P0000060?[`iP8000006@3jl>H3000000030?[`iP000000000000800000;P3jl>H30000
00/0n_3V0`0000040?[`iP<000000`3jl>H5000000<0n_3V0`0000050?[`iP<000000`3jl>H30000
00@0n_3V0`0000040?[`iP<00000J`3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H020000000
0`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H01@000000n_3V0000003jl>H0
00000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3j
l>H10?ooo`00803jl>H3000000030?[`iP00000000000080000000@0n_3V0000003jl>H000000P3j
l>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000
103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@00000
0P3jl>H3000000030?[`iP000000000000H000006`3jl>H3000000<0n_3V1P0000020?[`iP<00000
^P3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000D0n_3V0000000000000000
0?[`iP04000000/0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V
0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP80
0000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000;0?[`iPD000002@3jl>H0
0`000000n_3V0?[`iP02000000@0n_3V0P0000030?[`iP80000000<0n_3V000000000000^@3jl>H1
0?ooo`008P3jl>H3000002P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H20000
0080n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000L0?[`
iP800000103jl>H2000000<0n_3V0P0000000`3jl>H000000000002i0?[`iP40oooo000R0?[`iP<0
00002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0
n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H40000
00d0n_3V1@00000<0?[`iP800000103jl>H2000000<0n_3V0P0000000`3jl>H000000000002i0?[`
iP40oooo000Q0?[`iP80000000<0n_3V0000000000009`3jl>H2000000030?[`iP00000000000=`0
n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000006@3jl>H00`000000n_3V0?[`iP02
000000@0n_3V0P0000040?[`iP<00000^P3jl>H10?ooo`00803jl>H3000000040?[`iP0000000000
000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H4
00000080n_3V0`000000103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3j
l>H4000000@0n_3V100000020?[`iPD000000`3jl>H5000001T0n_3V100000050?[`iP8000000`3j
l>H2000000030?[`iP00000000000;T0n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L
0?[`iP80000000<0n_3V000000000000403jl>H2000000`0n_3V0P00000h0?[`iP8000001@3jl>H4
000000<0n_3V0P0000000`3jl>H000000000002i0?[`iP40oooo001>0?[`iP<00000g03jl>H50000
0140n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000`0?[`iPD00000103jl>H20000
00@0n_3V0`00002j0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`007@3jl>HV0?ooh0800000K03oon02000000@0oooP0P0000040?ooh0800000J`3oon05
000006T0oooP1@0000020?ooh0800000103oon02000006/0oooP1000000S0?ooh1h0n_3V0@3oool0
01d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000P0oooP00@0
00000?ooh03oon000000K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00L0oooP
00@000000?ooh03oon000000JP3oon000`000000oooP0?ooh00T0?ooh1h0n_3V0@3oool001d0n_3V
9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000/0oooP00<000000?oo
h03oon00JP3oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00X0oooP00<000000?oo
h03oon00J@3oon000`000000oooP0?ooh00S0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000
oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0oooP0P00001]0?ooh0030000003oon00
oooP06/0oooP00<000000?ooh03oon00203oon02000006d0oooP00<000000?ooh03oon008P3oon0N
0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon0010000000oooP0?ooh000
00090?ooh0030000003oon00oooP06`0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?oo
h0080?ooh0030000003oon00oooP06X0oooP00@000000?ooh03oon0000008`3oon0N0?[`iP40oooo
000M0?[`iRH0oooP0P00001/0?ooh08000002P3oon03000006/0oooP0P00001/0?ooh08000002P3o
on03000006/0oooP0P00000T0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
o`00003Z000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<0
00000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?oo
h0030000003oon00oooP0740oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0D000001P3oon000`000000oooP0?oo
h0090?ooh1<00000o`3oon3:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB
0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00203oon0R00000?l0oooP_03oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?oo
h0@000001`3oon000`000000003o0000o`0H0000oa800000o`3oon2^0?ooh0@00000603oon0N0?[`
iP40oooo000M0?[`iPX0oooP100000040?ooh0030000003oon00oooP00H0oooP00<000000?ooh03o
on002@3oon0J000000P0003o4@00003o0?ooh:X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh0@0cHDo
00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`060<f5?a0000002P000?l>00000?l0oooP
X`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<0
00000?ooh03oon002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=
QCl00`3oi>40cHDo0<f5?`020<f5?``000002@000?l<00000?l0oooPW03oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo00d0cHDo2P000008
0000o`D0000000@0oooP0000000000000000o`3oon2G0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`02
0<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl:000000D0003o2P00003o
0?ooh940oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3o
i>40cHDo0<f5?`0E0<f5?`060?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo2@0000050000o`P00000o`3o
on2>0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ
0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00@0onCQ000000000000cHDo
100000050000o`T00000o`3oon280?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=
QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo
00<0onCQ0<f5?`3=QCl00`3=QCl7000000D0003o2000003o0?ooh8@0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon040<f5?`030?oTh@3=
QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`030?oTh@3=QCl0000000D00000
1@000?l800000?l0oooPO`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5
?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5?`030?oT
h@3=QCl0cHDo00L0cHDo00H0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl7000000@0003o2000003o0?oo
h7/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40
cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5
?`050?oTh@3=QCl0cHDo0<f5?`3oi>401P3=QCl6000000D0003o1P00003o0?ooh7P0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon040<f5
?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E0<f5
?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`050?oTh@3=QCl0
cHDo0<f5?`3oi>40203=QCl00`3oi>40cHDo00000006000000@0003o1P00003o0?ooh7@0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon04
0<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>40203=QCl01P3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`L0000010000?l60000
0?l0oooPL03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0
oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=
QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@00
0000000000D000000`000?l600000?l0oooPJ`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0
onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ0080cHDo1P0000040000o`D00000o`3oon1Z0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl0
5@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0
onCQ00D0cHDo00<0onCQ000000000000100000030000o`H00000o`3oon1V0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3o
i>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=
QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo
00<0onCQ0<f5?`3=QCl00P3=QCl5000000@0003o1@00003o0?ooh6<0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon040<f5?`030?oTh@3=
QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`050?oTh@3=QCl0cHDo0<f5?`3o
i>40203=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3o
i>40cHDo0<f5?`050<f5?`H000000`000?l400000?l0oooPH@3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl00`3oi>40cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=
QCl0cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@08
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=
QCl0cHDo00P0cHDo1P0000030000o`D00000o`3oon1M0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`02
0<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=
QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo
00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=
QCl0303=QCl500000080003o1P00003o0?ooh5X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo
00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3o
i>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40203=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0<f5?`0?
0<f5?`@000000`000?l500000?l0oooPF03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3o
i>40cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@07
0<f5?`030?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo0140cHDo
1@0000030000o`D00000o`3oon1E0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=
QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo
00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=
QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl05P3=QCl30000
0080003o1P00003o0?ooh580oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=
QCl03`3=QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3o
i>40cHDo0<f5?`070<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40203=QCl01@3oi>40cHDo0<f5?`3=
QCl0onCQ00@0cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0<f5?`0G0<f5?`@000000`00
0?l500000?l0oooPD03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0?
0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5?`030?oTh@3=
QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=QCl0cHDo0<f5?`3o
i>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo00@0onCQ00000000
000000000`000?l600000?l0oooPC03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40
cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5
?`030?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=QCl0
cHDo0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo00<0
onCQ0<f5?`3=QCl0100000030000o`D00000o`3oon1:0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`02
0<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=
QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo
00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=
QCl06P3=QCl00`3oi>40cHDo0<f5?`030<f5?`@000000P000?l500000?l0oooPB03oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP103=QCl00`3oi>40cHDo
0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ
0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`050<f5?`@000000`000?l500000?l0oooP@`3oon03
000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3o
i>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=
QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo
00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00<00000
0`000?l500000?l0oooP@P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5
?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5?`030?oT
h@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=QCl0cHDo0<f5
?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo00<0onCQ0<f5
?`3=QCl01P3=QCl00`3oi>40cHDo0<f5?`020<f5?`@000000P000?l500000?l0oooP@03oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0
cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5
?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oT
h@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo00<0onCQ0<f5?`3=QCl01P3=QCl00`3oi>40cHDo0<f5
?`050<f5?`<000000`000?l400000?l0oooP?P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0
0`3oi>40cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@070<f5?`030?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0
cHDo00<0onCQ0<f5?`3=QCl01P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0000000<0
00000`000?l400000?l0oooP>`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo
0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5?`03
0?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=QCl0cHDo
0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo00<0onCQ
0<f5?`3=QCl01P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo10000002
0000o`<00000o`3oon0j0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo
00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ
0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo
0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>400000
0000000300000080003o1000003o0?ooh3L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0
onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40
1`3=QCl00`3oi>40cHDo0<f5?`070<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40203=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0<f5?`0J0<f5
?`030?oTh@3=QCl0cHDo00H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5
?`030?oTh@3=QCl0cHDo0080cHDo0`0000020000o`D00000o`3oon0d0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40
cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0
onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0
onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0
onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`040?oTh@000000000000000080003o
1000003o0?ooh3<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=
QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo
0<f5?`070<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40203=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00@0cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0<f5?`0J0<f5?`030?oTh@3=QCl0cHDo
00H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo
00<0cHDo00<0onCQ0<f5?`3=QCl00`0000030000o`<00000o`3oon0a0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40
cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0
onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0
onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0
onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo1000
00020000o`@00000o`3oon0^0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0
onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40
cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40
cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl00`0000020000o`@0
0000o`3oon0/0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo
00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=
QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@04
0<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`06
0<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`03
0<f5?`030?oTh@3=QCl0cHDo0080cHDo00@0onCQ0<f5?`3=QCl0cHDo100000020000o`@00000o`3o
on0Z0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ
0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=
QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`03
0?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`03
0?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`03
0?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0103=QCl3000000<0003o1000003o0?ooh2L0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo
0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`05
0?oTh@3=QCl0cHDo0<f5?`3oi>40203=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00@0cHDo00<0onCQ
0<f5?`3oi>401@3=QCl00`3oi>40cHDo0<f5?`0J0<f5?`030?oTh@3=QCl0cHDo00H0cHDo00<0onCQ
0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`060<f5?`@000000P000?l300000?l0oooP9P3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP103=QCl00`3o
i>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=
QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo
00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo
00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo
00<0onCQ0<f5?`3=QCl0203=QCl400000080003o1000003o0?ooh240oooP0`00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl00`3oi>40cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@070<f5?`030?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`05
0?oTh@3=QCl0cHDo0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo
01X0cHDo00<0onCQ0<f5?`3=QCl01P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo
0080cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo
00X0cHDo100000020000o`@00000o`3oon0Q0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`03
0?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ
0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=
QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03@3=
QCl300000080003o0`00003o0?ooh200oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ
0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=
QCl00`3oi>40cHDo0<f5?`070<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40203=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0<f5?`0J0<f5?`03
0?oTh@3=QCl0cHDo00H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`03
0?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0>0<f5?`@0
00000P000?l300000?l0oooP7P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo
0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5?`03
0?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=QCl0cHDo
0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo00<0onCQ
0<f5?`3=QCl01P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ
0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo0140cHDo0`000002
0000o`@00000o`3oon0K0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo
00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ
0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo
0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo
0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl04P3=QCl400000080003o
0`00003o0?ooh1X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=
QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo
0<f5?`070<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40203=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00@0cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0<f5?`0J0<f5?`030?oTh@3=QCl0cHDo
00H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo
00<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0D0<f5?`@000000P000?l40000
0?l0oooP5`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0?0<f5?`03
0?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo
00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40103=
QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo00<0onCQ0<f5?`3=QCl01P3=
QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl00`3=
QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo01@0cHDo00<0onCQ0<f5?`0000000`00
00020000o`<00000o`3oon0F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0
onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40
cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40
cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0503=QCl0103oi>40
cHDo0<f5?`3oi>4400000080003o1000003o0?ooh1<0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon040<f5?`030?oTh@3=QCl0cHDo0080
cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5
?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40203=QCl0
1@3oi>40cHDo0<f5?`3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0<f5
?`0J0<f5?`030?oTh@3=QCl0cHDo00H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5
?`020<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5
?`0D0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo100000020000o`<00000o`3oon0B0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=
QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=
QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ
00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo
00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo
0080cHDo00<0onCQ0<f5?`3=QCl0503=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`<000000P000?l3
00000?l0oooP403oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0?0<f5
?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5?`030?oTh@3=QCl0
cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40
103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo00<0onCQ0<f5?`3=QCl0
1P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0
0`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo01@0cHDo00@0onCQ0<f5?`3=QCl0
onCQ1@3=QCl00`3oi>40000000000002000000030000o`000000000000800000o`3oon0>0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl0
5@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0
onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0
cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0
cHDo0080cHDo00<0onCQ0<f5?`3=QCl0503=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`040?oTh@3=
QCl0onCQ0<f5?`8000000P000?l400000?l0oooP303oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl00`3oi>40cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@070<f5?`030?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`05
0?oTh@3=QCl0cHDo0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo
01X0cHDo00<0onCQ0<f5?`3=QCl01P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo
0080cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo
01@0cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl00`3oi>40cHDo0?oTh@020<f5?`<000000P000?l3
00000?l0oooP2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon030000
00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5
?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl0
1@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oT
h@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oT
h@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oT
h@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0503=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`03
0?oTh@3=QCl0onCQ00@0cHDo0`0000000`000?l000000000000200000?l0oooP1`3oon03000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo
0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo
0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ
0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ
0<f5?`3=QCl0503=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`030?oTh@3=QCl0onCQ00H0cHDo0P00
00020000o`@00000o`3oon070?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0
onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0
cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40
cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40
cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0503=QCl0103oi>40
cHDo0<f5?`3oi>450<f5?`030?oTh@3=QCl0onCQ00P0cHDo0P0000020000o`<00000o`3oon060?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=
QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3o
i>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=
QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=
QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=
QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0503=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`030?oT
h@3=QCl0onCQ00T0cHDo0`0000020000o`<00000o`3oon040?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5
?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5
?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5
?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5
?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5
?`3=QCl0503=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`030?oTh@3=QCl0onCQ00/0cHDo0`000000
0`000?l000000000000200000?l0oooP0P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3o
i>40cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@07
0<f5?`030?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo
00<0onCQ0<f5?`3=QCl01P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo
00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo01@0cHDo
00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl00`3oi>40cHDo0?oTh@0<0<f5?`<000000P000?l300000?l0
oooP0@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0?0<f5?`030?oT
h@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo00L0
cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40103=QCl0
0`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0cHDo00<0onCQ0<f5?`3=QCl01P3=QCl0
0`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0
0`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo01@0cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=
QCl00`3oi>40cHDo0?oTh@0?0<f5?`8000000P000?l400000?d0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon040<f5?`030?oTh@3=QCl0
cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0
cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>40
203=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40
cHDo0<f5?`0J0<f5?`030?oTh@3=QCl0cHDo00H0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40
cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40
cHDo0<f5?`0D0<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo00<0onCQ0<f5?`3oi>40403=QCl30000
0080003o0`00003l0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0
cHDo00<0onCQ0<f5?`3=QCl05@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5
?`3=QCl01`3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@040<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5
?`060<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5
?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0503=QCl0103oi>40cHDo0<f5
?`3oi>450<f5?`030?oTh@3=QCl0onCQ0180cHDo0`00000010000?l0000000000000003k0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
103=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00l0cHDo00<0onCQ0<f5?`3=QCl0
5@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl01`3=QCl01@3oi>40
cHDo0<f5?`3=QCl0onCQ00P0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@040<f5?`030?oTh@3=QCl0
onCQ00D0cHDo00<0onCQ0<f5?`3=QCl06P3=QCl00`3oi>40cHDo0<f5?`060<f5?`030?oTh@3=QCl0
cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0
cHDo0080cHDo00<0onCQ0<f5?`3=QCl0503=QCl0103oi>40cHDo0<f5?`3oi>450<f5?`030?oTh@3=
QCl0onCQ01<0cHDo0`0000020000o`<00000n@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0@0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl0
0`3oi>40cHDo0<f5?`0?0<f5?`030?oTh@3=QCl0cHDo01D0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oT
h@070<f5?`030?oTh@3=QCl0cHDo00L0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@080<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>40103=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0cHDo01X0
cHDo00<0onCQ0<f5?`3=QCl01P3=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo0080
cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo01@0
cHDo00@0onCQ0<f5?`3=QCl0onCQ1@3=QCl00`3oi>40cHDo0?oTh@0F0<f5?`8000000P000?l30000
0?L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on002@3oon040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40
cHDo0<f5?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5
?`050?oTh@3=QCl0cHDo0<f5?`3oi>40203=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00@0cHDo00<0
onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0<f5?`0J0<f5?`030?oTh@3=QCl0cHDo00H0cHDo00<0
onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0
onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0D0<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo
00<0onCQ0<f5?`3oi>405`3=QCl3000000030000o`000000000000800000m@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3o
on040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5
?`0E0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>40203=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00@0cHDo00<0onCQ0<f5
?`3oi>401@3=QCl00`3oi>40cHDo0<f5?`0J0<f5?`030?oTh@3=QCl0cHDo00H0cHDo00<0onCQ0<f5
?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5
?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0D0<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo00<0onCQ
0<f5?`3oi>406@3=QCl200000080003o0`00003d0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon04
0<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl03`3=QCl00`3oi>40cHDo0<f5?`0E
0<f5?`050?oTh@3=QCl0cHDo0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`070<f5?`050?oTh@3=
QCl0cHDo0<f5?`3oi>40203=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ00@0cHDo00<0onCQ0<f5?`3o
i>401@3=QCl00`3oi>40cHDo0<f5?`0J0<f5?`030?oTh@3=QCl0cHDo00H0cHDo00<0onCQ0<f5?`3=
QCl01@3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl00`3oi>40cHDo0<f5?`0D0<f5?`040?oTh@3=QCl0cHDo0?oTh@D0cHDo00<0onCQ0<f5
?`3oi>406P3=QCl300000080003o0`00003b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP100000080?ooh>L000000P000?oX0000
00P0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?oo
h0030000003oon00oooP0>l0oooP0`00000010000?l0000000000000000B03>QbP030:gHiP0cXLX0
<j7:00T0<j7:00<0[MSV03>QbP2]f>H02@0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0
<j7:00P0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0
<j7:02<0<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0
<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3o
on000`000000oooP0?ooh03`0?ooh0<000000P000?l300000100<j7:00<0[MSV03>QbP0cXLX02@0c
XLX00`2]f>H0<j7:0:gHiP0903>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0200c
XLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX08`0c
XLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV
5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00lP3o
on03000000040000o`0000000000000000l0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:
0:gHiP0903>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:
03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:
03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0
<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03c0?ooh0<000000P000?l3000000d0<j7:
00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:0:gHiP0903>QbP030:gHiP0cXLX0<j7:00@0<j7:
00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:
00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:
00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03e0?ooh0<0000000@0003o0000000000000000300cXLX00`2]f>H0<j7:03>QbP0903>QbP03
0:gHiP0cXLX0[MSV00T0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0803>QbP03
0:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP03
0:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>Q
bP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?L0oooP0P0000020000o`80
00002`0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0[MSV00T0<j7:00<0[MSV03>QbP0c
XLX0100cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0c
XLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0c
XLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?T0oooP0P0000000`000?l0000000000002000000P0<j7:00<0[MSV03>QbP0c
XLX02@0cXLX00`2]f>H0<j7:0:gHiP0903>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0c
XLX0200cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0c
XLX08`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0c
XLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03j0?ooh080
000000<0003o0000000000000P00000703>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP2]
f>H02@0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0c
XLX02@0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0c
XLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>Q
bP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n`3oon0200000080003o1000000503>QbP03
0:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP2]f>H02@0cXLX00`2]f>H0<j7:03>QbP0403>QbP03
0:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0903>QbP03
0:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP04
0:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o@3oon02000000030000o`000000000000800000100cXLX00`2]f>H0<j7:03>QbP0903>QbP03
0:gHiP0cXLX0[MSV00T0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0803>QbP03
0:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP03
0:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>Q
bP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?h0oooP0P0000020000o`@0
00000P0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0[MSV00T0<j7:00<0[MSV03>QbP0c
XLX0100cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0c
XLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0c
XLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP0@3oon02000000030000o`000000000000<0000000<0[MSV03>QbP0c
XLX02@0cXLX00`2]f>H0<j7:0:gHiP0903>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0c
XLX0200cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0c
XLX08`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0c
XLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0<0
oooP00<000000000o`000?l01000000;03>QbP030:gHiP0cXLX0[MSV00T0<j7:00<0[MSV03>QbP0c
XLX0100cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0c
XLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0c
XLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP1@3oon000`000000003o00000003000000X0<j7:00<0[MSV03>QbP2]
f>H02@0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0c
XLX02@0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0c
XLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>Q
bP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh0H0oooP00<000000000o`000?l01000000803>QbP03
0:gHiP0cXLX0[MSV00T0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0803>QbP03
0:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP03
0:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>Q
bP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX90?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon070?ooh080000000<0003o00000000
00000P00000703>QbP030:gHiP0cXLX0[MSV00T0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0
<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0
<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0
<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP2@3oon000`000000003o0000o`03000000H0<j7:00<0[MSV03>QbP2]f>H02@0cXLX00`2]f>H0
<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0
<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0
<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0;0?ooh003000000000?l00000008000001@0cXLX00`2]f>H0
<j7:0:gHiP0903>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0
<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0
<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]
f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0`0oooP00<000000000o`00
0?l00`00000303>QbP030:gHiP0cXLX0[MSV00T0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0
<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0
<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0
<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP3@3oon02000000030000o`00000000000080000000@0<j7:0:gHiP0cXLX0[MSV2@0cXLX00`2]
f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]
f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]
f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0>0?ooh08000000P000?l3000000030:gHiP0cXLX0[MSV
00T0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:
00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:
01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0
<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP403oon02000000060000o`0000000000
0000000cXLX0[MSV2@0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0
[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0
[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:
00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0A0?ooh08000000P00
0?l3000000T0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0c
XLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0c
XLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gH
iP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP4`3oon02000000040000o`00
00000000000000P0<j7:00<0[MSV03>QbP0cXLX0100cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gH
iP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP030:gH
iP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP03
0:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP503oon0200000080003o
0`00000603>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:
03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:
03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0
<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1D0oooP0`00000010000?l00000
00000000000503>QbP030:gHiP0cXLX0<j7:00@0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0
<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0
<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]
f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1L0oooP0P0000020000o`<0
00000`0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0c
XLX02@0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0c
XLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>Q
bP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0H0?ooh0<0000000@0003o00000000
000000000P0cXLX00`2]f>H0<j7:03>QbP0403>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>Q
bP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>Q
bP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV
03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh1X0oooP0P0000020000o`80000000<0<j7:0:gH
iP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>Q
bP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>Q
bP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV
03>QbP2]f>H00`0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0K0?ooh0<0000000@0003o000000000000[MSV1P0cXLX00`2]f>H0<j7:03>QbP08
03>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S
03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]
f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP703oon03
000000030000o`000000000000H0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP09
03>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:03>QbP0M
03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>Q
bP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1d0oooP0`0000020000o`800000100cXLX0
0`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX0
0`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0
102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP7`3oon03000000040000o`000000000000000080<j7:00<0[MSV03>QbP0cXLX0200c
XLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX08`0c
XLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV
5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh200oooP0`00
00001P000?l00000000000000000<j7:0:gHiPX0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0
<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0
<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0R0?ooh08000000P000?l2000000030:gHiP0cXLX0<j7:00P0
<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0
<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gH
iQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0T0?ooh080
000000<0003o0000000000002P0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0
<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0
<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV
00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh2D0oooP0P00000010000?l0000000000000000803>QbP030:gHiP0cXLX0<j7:
00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:
01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0
<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP9P3oon0200000080003o0P00000703>Q
bP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP0S03>Q
bP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF
03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP9`3oon030000
00040000o`0000000000000000D0<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`2]f>H0<j7:03>QbP09
03>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?
03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0X0?ooh0<0000000@0003o0000000000000000100cXLX00`2]f>H0<j7:03>Q
bP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:03>Q
bP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:
03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2T0oooP0`0000020000o`8000000`0c
XLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX08`0c
XLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV
5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2/0oooP0`00
00000`000?l000000000000203>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX02@0c
XLX00`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0c
XLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3o
on0/0?ooh0<0000000D0003o00000000000000000:gHiP0;03>QbP030:gHiP0cXLX0<j7:00T0<j7:
00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:
00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0
<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
;@3oon0300000080003o0P00000;03>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX0
8`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0
[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2l0oooP
0`0000000`000?l000000000000:03>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX0
8`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0
[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh340oooP
0P0000000`000?l000000000000903>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0cXLX0
8`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0
[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP
0P00000010000?l0000000000000000703>QbP030:gHiP0cXLX0<j7:00T0<j7:00<0[MSV03>QbP0c
XLX08`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0c
XLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3<0
oooP0P0000020000o`8000001P0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0
<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gH
iQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0d0?ooh0<0
000000<0003o0000000000001@0cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0
<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gH
iQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0e0?ooh0<0
000000<0003o000000000000100cXLX00`2]f>H0<j7:03>QbP0903>QbP030:gHiP0cXLX0<j7:02<0
<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gH
iQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0g0?ooh080
00000P000?l01@000000<j7:03>QbP0cXLX0[MSV00/0<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]
f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX0
0`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3P0oooP0`0000001@00
0?l0000003>QbP0cXLX0[MSV00/0<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:03>QbP0M
03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>Q
bP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3T0oooP0`00000010000?l000000000002]
f>H;03>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>Q
bP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0j0?ooh0<0000000<0003o0000000000002`0cXLX00`2]f>H0<j7:03>Q
bP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>Q
bP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>`3o
on0300000080003o0P00000903>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0cXLX07@0c
XLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX0
5@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0l0?ooh0@0000000<0003o000000000000200c
XLX00`2]f>H0<j7:03>QbP0S03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0c
XLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP?P3oon03000000030000o`000000000000L0<j7:00<0[MSV03>QbP0cXLX08`0c
XLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV
5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP?`3oon03000000030000o`00
0000000000H0<j7:00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0c
XLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gH
iP0cXLX0[MSV00<0<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP@03oon03000000030000o`000000000000D0<j7:00<0[MSV03>QbP0cXLX08`0c
XLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV
5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh440oooP0`00
000010000?l0000000000000000303>QbP030:gHiP0cXLX0<j7:02<0<j7:00<0[MSV03>QbP0cXLX0
7@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0c
XLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon120?ooh0<000000P000?l200000080<j7:
00<0[MSV03>QbP0cXLX08`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:
00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh4@0oooP0`0000001@000?l000000000000cXLX0[MSV02D0<j7:00<0[MSV03>QbP0c
XLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>Q
bP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon150?ooh0<0000000@0003o00000000
0000[MSV9@0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>Q
bP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h4H0oooP0`0000000`000?l000000000000U03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>Q
bP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV
03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPB03oon02000000030000o`000000000002@0<j7:00<0[MSV03>Q
bP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV
03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon190?ooh080000000<0003o0000
000000008`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>Q
bP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h4X0oooP0P0000000`000?l000000000000R03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>Q
bP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV
03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPB`3oon02000000040000o`000000000000000200<j7:00<0[MSV
03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1<0?ooh080000000@0003o
00000000000000007`0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0
[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<0
00000?ooh03oon00o`3oon1=0?ooh08000000P000?l2000001h0<j7:00<0[MSV03>QbP0cXLX07@0c
XLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX0
5@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh4l0oooP0P00
000010000?l0000000000000000L03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX0
3`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]
f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000
003oon00oooP00H0oooP1000003o0?ooh4l0oooP0P00000010000?l0000000000000000K03>QbP03
0:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>Q
bP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX80?ooh0@00000603oon0N0?[`
iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh540
oooP0P0000000`000?l000000000000K03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0c
XLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh003
0000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1B0?ooh080000000<0003o00000000
00006P0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0c
XLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03o
on00o`3oon1C0?ooh080000000<0003o0000000000006@0cXLX00`2]f>H0<j7:03>QbP0M03>QbP03
0:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>Q
bP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh5@0oooP0P00000010000?l0000000000000000G03>Q
bP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF
03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPE@3oon020000
00040000o`0000000000000001H0<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?
03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1F0?ooh080000000@0003o00000000000000005@0cXLX00`2]f>H0<j7:03>Q
bP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:
03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5L0oooP0P0000020000o`800000500c
XLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV
5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5T0oooP0P00
00000`000?l000000000000C03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0c
XLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPFP3oon02000000030000o`00000000000180<j7:00<0[MSV03>QbP0cXLX07@0c
XLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX0
5@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1K0?ooh080000000<0003o0000000000004@0c
XLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0cXLX0[MSV
5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5`0oooP0P00
00000`000?l000000000000@03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV03>QbP0cXLX03`0c
XLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPG@3oon02000000040000o`0000000000000000h0<j7:00<0[MSV03>QbP0cXLX0
7@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0c
XLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1N0?ooh080000000@0003o000000000000
00003@0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV03>QbP0c
XLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPG`3oon0200000004
0000o`0000000000000000`0<j7:00<0[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>Q
bP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP03
03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h600oooP0P00000010000?l0000000000000000;03>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV
03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0
[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPHP3oon000`000000003o0000o`02000000X0<j7:00<0[MSV
03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1S0?ooh080000000<0003o
0000000000002@0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6<0oooP0`0000000`000?l000000000000803>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV
03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0
[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPI03oon03000000030000o`000000000000L0<j7:00<0[MSV
03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1V0?ooh080000000<0003o
0000000000001P0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6L0oooP0P0000000`000?l000000000000503>QbP030:gHiP0cXLX0<j7:01d0<j7:00<0[MSV
03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0
[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPJ03oon02000000040000o`0000000000000000<0<j7:00<0
[MSV03>QbP0cXLX07@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:
00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Y0?ooh080000000@0
003o00000000000000000P0cXLX00`2]f>H0<j7:03>QbP0M03>QbP030:gHiP0cXLX0<j7:00l0<j7:
00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh6X0oooP0P0000001P000?l00000000000000000<j7:0:gHiQl0<j7:00<0[MSV03>Q
bP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV
03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPJ`3oon02000000050000o`00000000000000002]f>H07`0cXLX0
0`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1]0?ooh003000000000?l00000008000007`0cXLX0
0`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1]0?ooh080000000<0003o0000000000007`0cXLX0
0`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1^0?ooh080000000<0003o0000000000007P0cXLX0
0`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh6l0oooP0P0000020000o`800000700cXLX00`2]f>H0<j7:03>QbP0?
03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gH
iP0303>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh700oooP0`0000000`000?l000000000000K03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh740oooP0`0000000`000?l000000000000J03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh780oooP0`0000000`000?l000000000000I03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7<0oooP0`0000000`000?l000000000000H03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7@0oooP0`0000000`000?l000000000000G03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7H0oooP0P0000000`000?l000000000000F03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7L0oooP0P0000000`000?l000000000000E03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7P0oooP0P0000000`000?l000000000000D03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7T0oooP0P0000000`000?l000000000000C03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7T0oooP0`0000000`000?l000000000000B03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7X0oooP0`0000000`000?l000000000000A03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7`0oooP0P0000000`000?l000000000000@03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7d0oooP0P0000000`000?l000000000000?03>QbP030:gHiP0cXLX0<j7:00l0<j7:00@0[MSV
03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPOP3oon02
000000030000o`000000000000h0<j7:00<0[MSV03>QbP0cXLX03`0cXLX0102]f>H0<j7:03>QbP2]
f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX90?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1n0?ooh0<0000000<0003o
0000000000003@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1o0?ooh0<0000000<0003o
000000000000300cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon210?ooh080000000<0003o
0000000000002`0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon210?ooh0<0000000<0003o
0000000000002P0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon220?ooh0<0000000<0003o
0000000000002@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon240?ooh080000000<0003o
000000000000200cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon250?ooh080000000<0003o
0000000000001`0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon260?ooh080000000<0003o
0000000000001P0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon270?ooh080000000<0003o
0000000000001@0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon280?ooh080000000<0003o
000000000000100cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon290?ooh080000000<0003o
0000000000000`0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2:0?ooh080000000<0003o
0000000000000P0cXLX00`2]f>H0<j7:03>QbP0?03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0
[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2;0?ooh080000000D0003o
000000000000<j7:0:gHiP0A03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX0
5@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh8`0oooP0P00000010000?l000000000002]f>HA03>QbP040:gH
iP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbPT0
oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8d0oooP
0P0000000`000?l000000000000A03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0c
XLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2>0?ooh080000000<0003o000000000000
400cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]
f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPSP3oon03000000030000o`000000000000l0<j7:00@0[MSV03>QbP0cXLX0
[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8l0oooP
0`0000000`000?l000000000000>03>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0c
XLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2A0?ooh003000000000?l0000000800000
3@0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]
f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPTP3oon0010000000003o00000000000=03>QbP040:gHiP0cXLX0<j7:0:gH
iQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2B0?ooh080
000000<0003o000000000000300cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0cXLX0<j7:
01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT`3oon02000000040000o`00000000000000
00X0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0
[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh9@0oooP0P00000010000?l0000000000000000903>QbP040:gHiP0cXLX0
<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2E
0?ooh080000000<0003o0000000000002@0cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0c
XLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPUP3oon02000000030000o`000000
000000P0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0c
XLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh9L0oooP0P0000000`000?l000000000000703>QbP040:gHiP0cXLX0
<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP100000070?ooh0030000003oon00
oooP0?l0oooPV03oon02000000030000o`000000000000H0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0c
XLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh0080?ooh0030000003oon00
oooP0?l0oooPV@3oon02000000030000o`000000000000D0<j7:00@0[MSV03>QbP0cXLX0[MSV5P0c
XLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon000`000000oooP0?ooh0070?ooh0@00000o`3oon2I
0?ooh003000000000?l0000000800000100cXLX0102]f>H0<j7:03>QbP2]f>HF03>QbP030:gHiP0c
XLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX80?ooh0@00000603oon0N0?[`iP40oooo000M
0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh9/0oooP00<00000
0000o`0000000P00000303>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh9`0oooP00<0
00000000o`0000000P00000203>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX0
5@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPW@3oon0010000000003o0000
0000000203>QbP040:gHiP0cXLX0<j7:0:gHiQH0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2N0?ooh003000000000?l000000080000000@0[MSV03>QbP0cXLX0
[MSV5P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9h0oooP
0P00000010000?l0000000000000000203>QbP030:gHiP0cXLX0<j7:01@0<j7:00<0[MSV03>QbP0c
XLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2O0?ooh080000000<0003o000000000000
0P0cXLX00`2]f>H0<j7:03>QbP0D03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPX03oon02000000050000o`00000000000000002]f>H05P0cXLX00`2]f>H0<j7:
03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:40oooP0P00000010000?l000000000
0000000F03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPXP3o
on02000000040000o`0000000000000001D0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2S0?ooh080000000<0003o0000000000005@0cXLX00`2]f>H0<j7:03>Q
bP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:@0oooP0P0000000`000?l000000000000D
03>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon020000
00030000o`000000000001<0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2V0?ooh080000000<0003o0000000000004P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP03
0:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon0300000?l0oooPY`3oon02000000030000o`00000000000140<j7:00<0[MSV03>QbP0cXLX0
5@0cXLX00`2]f>H0<j7:0:gHiP0303>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh:P0oooP0P0000000`000?l000000000000@03>QbP030:gHiP0c
XLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ03oon02000000040000o`000000
0000000000l0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Y
0?ooh080000000@0003o00000000000000003P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0c
XLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:/0oooP00<000000000o`0000000P00000=03>QbP030:gHiP0cXLX0
<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ`3oon02000000040000o`0000000000
000000`0<j7:00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2/0?oo
h080000000<0003o000000000000300cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV
00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh:d0oooP0P0000000`000?l000000000000;03>QbP030:gHiP0cXLX0<j7:01D0
<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[P3oon02000000030000o`000000000000X0<j7:
00<0[MSV03>QbP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2_0?ooh080000000<0
003o0000000000002@0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh;00oooP0P0000000`000?l000000000000803>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV
03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP/@3oon02000000030000o`000000<j7:00L0<j7:00<0[MSV03>Q
bP0cXLX05@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2b0?ooh080000000<0003o00000000
00001P0cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;80oooP
0`0000000`000?l000000000000503>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3o
on2c0?ooh0<0000000<0003o0000000cXLX0100cXLX00`2]f>H0<j7:03>QbP0E03>QbP030:gHiP0c
XLX0[MSV00<0<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP]03oon03000000030000o`000000<j7:00<0<j7:00<0[MSV03>QbP0cXLX05@0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2e0?ooh080000000<0003o0000000000000`0cXLX00`2]
f>H0<j7:03>QbP0E03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;H0oooP0P0000000`000?l0
00000000000203>QbP030:gHiP0cXLX0<j7:01D0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
]`3oon02000000050000o`000000000003>QbP2]f>H05`0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2g0?ooh0<0000000@0003o000000000000[MSV5`0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2h0?ooh0<0000000<0003o0000002]f>H05`0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2j0?ooh080000000<0003o0000000000005P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j
0?ooh080000000@0003o00000000000000005@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2k
0?ooh080000000<0003o0000000000005@0cXLX00`2]f>H0<j7:0:gHiP0303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2m0?oo
h004000000000?l00000000001@0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_@3oon020000
00030000o`000000000001<0<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_P3oon0200000003
0000o`00000000000180<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_`3oon02000000030000
o`00000000000140<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_`3oon02000000040000o`00
0000000000000100<j7:00<0[MSV03>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon300?ooh080000000@0003o0000000000000000
3`0cXLX00`2]f>H0<j7:0:gHiP0303>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<40oooP0P0000000`000?l000000000000?03>QbP030:gHiP0c
XLX0[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh<80oooP0P0000000`000?l000000000000>03>QbP030:gHiP0cXLX0
[MSV00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh<<0oooP0P0000000`000?l000000000000=03>QbP030:gHiP0cXLX0[MSV
00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh<@0oooP0P0000000`000?l000000000000<03>QbP030:gHiP0cXLX0[MSV00<0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<D0oooP00<000000000o`0000000P00000;03>QbP030:gHiP0cXLX0[MSV00<0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh<H0oooP00<000000000o`0000000P00000:03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<H0oooP0P0000000`000?l000000000000:03>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h<L0oooP0P0000000`000?l000000000000903>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<P0
oooP0P0000000`000?l000000000000803>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<T0oooP
0P0000000`000?l000000000000703>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<T0oooP0P00
000010000?l0000000000000000603>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<X0oooP0P00
000010000?l0000000000000000503>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh</0oooP0P00
00000`000?l000000000000503>QbP030:gHiP0cXLX0[MSV00<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPc03oon02000000030000o`000000
000000@0<j7:00<0[MSV03>QbP2]f>H00`0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon3=0?ooh080000000<0003o0000000000000`0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon3>0?ooh080000000<0003o0000000cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon3?0?ooh080000000L0003o000000000000<j7:0:gHiP0cXLX0[MSV
00<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh<l0oooP0P0000001`000?l00000000000000000[MSV03>QbP2]f>H00`0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPd03oon02000000060000o`00000000000:gHiP0cXLX0[MSV0`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd@3oon02
000000050000o`000000000003>QbP2]f>H00`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPdP3oon02000000040000o`000000
00000:gHiP<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh=<0oooP0P0000000`000?l000000000000303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3C0?oo
h0<0000000<0003o0000000000000P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe03oon03000000040000o`000000<j7:03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon3E0?ooh080000000@0003o000000000000<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon3F0?ooh080
000000<0003o0000000000002`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPe`3oon0200000003
0000o`000000000000X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP
00<000000?ooh03oon001P3oon0400000?l0oooPe`3oon02000000030000o`000000oooP00H0oooP
1000000H0?ooh1h0n_3V0@3oool001d0n_3V4`3oon000`000000oooP0?ooh0050?ooh0030000003o
on00oooP0?l0oooPf@3oon02000000/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00
oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740
oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
5@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
5@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
2@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H4
00000080n_3V200000020?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`00000
00<0n_3V00000000000010000000103jl>H000000000000000080?[`iPD00000103jl>H700000003
0?[`iP000000n_3V00<000002@3jl>H500000080n_3V100000020?[`iPD000004P3jl>H6000000H0
n_3V00<000000?[`iP3jl>H0103jl>H3000000040?[`iP000000000000000>@0n_3V0@3oool00=d0
n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000
003jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP000000000000T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0
n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP800000
0P3jl>H200000080n_3V0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP800000
00<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H2000000030?[`iP000000000000@0n_3V0P00
00030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P00
0000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V
0P0000020?[`iP8000000P3jl>H2000000`0n_3V1@0000050?[`iP8000001P3jl>H5000000H0n_3V
0`00003V0?[`iP40oooo003M0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000
003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V00000000
0000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP060?[`iP<00000iP3jl>H10?oo
o`00g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H0
00000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3j
l>H3000000030?[`iP000000n_3V0180n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P00
00000`3jl>H000000000003U0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000030?[`iP000000
000000800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@000002
0?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000000/0n_3V1@000002
0?[`iP@000000P3jl>H3000000030?[`iP000000000001<0n_3V0P00000?0?[`iP<0000000D0n_3V
00000000000000000?[`iP0400000=l0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000<`3jl>H2
000000<0n_3V00<000000?[`iP3jl>H0603jl>H200000240n_3V1000000H0?[`iP030000003jl>H0
n_3V0=l0n_3V0@3oool00=`0n_3V1P0000040?[`iP800000;`3jl>H5000001/0n_3V0`00000Q0?[`
iP8000006@3jl>H00`000000n_3V0?[`iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<000000?[`iP3j
l>H0g@3jl>H10?ooo`00o`3jl>Ie0?[`iP040000003jl>H0n_3V00000=l0n_3V0@3oool00?l0n_3V
MP3jl>H200000>00n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02471 .01472 L
.02471 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02471 .01472 L
.02471 .16187 L
s
1 .894 .882 r
.02471 .16187 m
.02471 .01472 L
.02598 .01472 L
.02598 .16187 L
F
.804 .522 .247 r
.02471 .16187 m
.02471 .01472 L
.02598 .01472 L
.02598 .16187 L
s
1 .894 .882 r
.02598 .16187 m
.02598 .01472 L
.02706 .01472 L
.02706 .16187 L
F
.804 .522 .247 r
.02598 .16187 m
.02598 .01472 L
.02706 .01472 L
.02706 .16187 L
s
1 .894 .882 r
.02706 .16187 m
.02706 .01473 L
.02922 .01473 L
.02922 .16187 L
F
.804 .522 .247 r
.02706 .16187 m
.02706 .01473 L
.02922 .01473 L
.02922 .16187 L
s
1 .894 .882 r
.02922 .16187 m
.02922 .01474 L
.03128 .01474 L
.03128 .16187 L
F
.804 .522 .247 r
.02922 .16187 m
.02922 .01474 L
.03128 .01474 L
.03128 .16187 L
s
1 .894 .882 r
.03128 .16187 m
.03128 .01476 L
.03339 .01476 L
.03339 .16187 L
F
.804 .522 .247 r
.03128 .16187 m
.03128 .01476 L
.03339 .01476 L
.03339 .16187 L
s
1 .894 .882 r
.03339 .16187 m
.03339 .01478 L
.03418 .01478 L
.03418 .16187 L
F
.804 .522 .247 r
.03339 .16187 m
.03339 .01478 L
.03418 .01478 L
.03418 .16187 L
s
1 .894 .882 r
.03418 .16187 m
.03418 .0148 L
.03546 .0148 L
.03546 .16187 L
F
.804 .522 .247 r
.03418 .16187 m
.03418 .0148 L
.03546 .0148 L
.03546 .16187 L
s
1 .894 .882 r
.03546 .16187 m
.03546 .01481 L
.03646 .01481 L
.03646 .16187 L
F
.804 .522 .247 r
.03546 .16187 m
.03546 .01481 L
.03646 .01481 L
.03646 .16187 L
s
1 .894 .882 r
.03646 .16187 m
.03646 .01483 L
.03809 .01483 L
.03809 .16187 L
F
.804 .522 .247 r
.03646 .16187 m
.03646 .01483 L
.03809 .01483 L
.03809 .16187 L
s
1 .894 .882 r
.03809 .16187 m
.03809 .01487 L
.03959 .01487 L
.03959 .16187 L
F
.804 .522 .247 r
.03809 .16187 m
.03809 .01487 L
.03959 .01487 L
.03959 .16187 L
s
1 .894 .882 r
.03959 .16187 m
.03959 .0149 L
.04163 .0149 L
.04163 .16187 L
F
.804 .522 .247 r
.03959 .16187 m
.03959 .0149 L
.04163 .0149 L
.04163 .16187 L
s
1 .894 .882 r
.04163 .16187 m
.04163 .01494 L
.04333 .01494 L
.04333 .16187 L
F
.804 .522 .247 r
.04163 .16187 m
.04163 .01494 L
.04333 .01494 L
.04333 .16187 L
s
1 .894 .882 r
.04333 .16187 m
.04333 .01497 L
.04517 .01497 L
.04517 .16187 L
F
.804 .522 .247 r
.04333 .16187 m
.04333 .01497 L
.04517 .01497 L
.04517 .16187 L
s
1 .894 .882 r
.04517 .16187 m
.04517 .01502 L
.04657 .01502 L
.04657 .16187 L
F
.804 .522 .247 r
.04517 .16187 m
.04517 .01502 L
.04657 .01502 L
.04657 .16187 L
s
1 .894 .882 r
.04657 .16187 m
.04657 .01508 L
.04746 .01508 L
.04746 .16187 L
F
.804 .522 .247 r
.04657 .16187 m
.04657 .01508 L
.04746 .01508 L
.04746 .16187 L
s
1 .894 .882 r
.04746 .16187 m
.04746 .0151 L
.04844 .0151 L
.04844 .16187 L
F
.804 .522 .247 r
.04746 .16187 m
.04746 .0151 L
.04844 .0151 L
.04844 .16187 L
s
1 .894 .882 r
.04844 .16187 m
.04844 .01517 L
.0504 .01517 L
.0504 .16187 L
F
.804 .522 .247 r
.04844 .16187 m
.04844 .01517 L
.0504 .01517 L
.0504 .16187 L
s
1 .894 .882 r
.0504 .16187 m
.0504 .01519 L
.05108 .01519 L
.05108 .16187 L
F
.804 .522 .247 r
.0504 .16187 m
.0504 .01519 L
.05108 .01519 L
.05108 .16187 L
s
1 .894 .882 r
.05108 .16187 m
.05108 .01521 L
.05204 .01521 L
.05204 .16187 L
F
.804 .522 .247 r
.05108 .16187 m
.05108 .01521 L
.05204 .01521 L
.05204 .16187 L
s
1 .894 .882 r
.05204 .16187 m
.05204 .01524 L
.05418 .01524 L
.05418 .16187 L
F
.804 .522 .247 r
.05204 .16187 m
.05204 .01524 L
.05418 .01524 L
.05418 .16187 L
s
1 .894 .882 r
.05418 .16187 m
.05418 .01532 L
.05485 .01532 L
.05485 .16187 L
F
.804 .522 .247 r
.05418 .16187 m
.05418 .01532 L
.05485 .01532 L
.05485 .16187 L
s
1 .894 .882 r
.05485 .16187 m
.05485 .01535 L
.05588 .01535 L
.05588 .16187 L
F
.804 .522 .247 r
.05485 .16187 m
.05485 .01535 L
.05588 .01535 L
.05588 .16187 L
s
1 .894 .882 r
.05588 .16187 m
.05588 .01542 L
.05781 .01542 L
.05781 .16187 L
F
.804 .522 .247 r
.05588 .16187 m
.05588 .01542 L
.05781 .01542 L
.05781 .16187 L
s
1 .894 .882 r
.05781 .16187 m
.05781 .01553 L
.05971 .01553 L
.05971 .16187 L
F
.804 .522 .247 r
.05781 .16187 m
.05781 .01553 L
.05971 .01553 L
.05971 .16187 L
s
1 .894 .882 r
.05971 .16187 m
.05971 .01561 L
.06127 .01561 L
.06127 .16187 L
F
.804 .522 .247 r
.05971 .16187 m
.05971 .01561 L
.06127 .01561 L
.06127 .16187 L
s
1 .894 .882 r
.06127 .16187 m
.06127 .01572 L
.0634 .01572 L
.0634 .16187 L
F
.804 .522 .247 r
.06127 .16187 m
.06127 .01572 L
.0634 .01572 L
.0634 .16187 L
s
1 .894 .882 r
.0634 .16187 m
.0634 .01575 L
.06534 .01575 L
.06534 .16187 L
F
.804 .522 .247 r
.0634 .16187 m
.0634 .01575 L
.06534 .01575 L
.06534 .16187 L
s
1 .894 .882 r
.06534 .16187 m
.06534 .01589 L
.06735 .01589 L
.06735 .16187 L
F
.804 .522 .247 r
.06534 .16187 m
.06534 .01589 L
.06735 .01589 L
.06735 .16187 L
s
1 .894 .882 r
.06735 .16187 m
.06735 .01599 L
.06898 .01599 L
.06898 .16187 L
F
.804 .522 .247 r
.06735 .16187 m
.06735 .01599 L
.06898 .01599 L
.06898 .16187 L
s
1 .894 .882 r
.06898 .16187 m
.06898 .01611 L
.07097 .01611 L
.07097 .16187 L
F
.804 .522 .247 r
.06898 .16187 m
.06898 .01611 L
.07097 .01611 L
.07097 .16187 L
s
1 .894 .882 r
.07097 .16187 m
.07097 .0162 L
.07228 .0162 L
.07228 .16187 L
F
.804 .522 .247 r
.07097 .16187 m
.07097 .0162 L
.07228 .0162 L
.07228 .16187 L
s
1 .894 .882 r
.07228 .16187 m
.07228 .01624 L
.07395 .01624 L
.07395 .16187 L
F
.804 .522 .247 r
.07228 .16187 m
.07228 .01624 L
.07395 .01624 L
.07395 .16187 L
s
1 .894 .882 r
.07395 .16187 m
.07395 .01635 L
.0746 .01635 L
.0746 .16187 L
F
.804 .522 .247 r
.07395 .16187 m
.07395 .01635 L
.0746 .01635 L
.0746 .16187 L
s
1 .894 .882 r
.0746 .16187 m
.0746 .01645 L
.07574 .01645 L
.07574 .16187 L
F
.804 .522 .247 r
.0746 .16187 m
.0746 .01645 L
.07574 .01645 L
.07574 .16187 L
s
1 .894 .882 r
.07574 .16187 m
.07574 .01647 L
.07719 .01647 L
.07719 .16187 L
F
.804 .522 .247 r
.07574 .16187 m
.07574 .01647 L
.07719 .01647 L
.07719 .16187 L
s
1 .894 .882 r
.07719 .16187 m
.07719 .01664 L
.07933 .01664 L
.07933 .16187 L
F
.804 .522 .247 r
.07719 .16187 m
.07719 .01664 L
.07933 .01664 L
.07933 .16187 L
s
1 .894 .882 r
.07933 .16187 m
.07933 .01672 L
.08031 .01672 L
.08031 .16187 L
F
.804 .522 .247 r
.07933 .16187 m
.07933 .01672 L
.08031 .01672 L
.08031 .16187 L
s
1 .894 .882 r
.08031 .16187 m
.08031 .01687 L
.08222 .01687 L
.08222 .16187 L
F
.804 .522 .247 r
.08031 .16187 m
.08031 .01687 L
.08222 .01687 L
.08222 .16187 L
s
1 .894 .882 r
.08222 .16187 m
.08222 .01694 L
.08343 .01694 L
.08343 .16187 L
F
.804 .522 .247 r
.08222 .16187 m
.08222 .01694 L
.08343 .01694 L
.08343 .16187 L
s
1 .894 .882 r
.08343 .16187 m
.08343 .01715 L
.08525 .01715 L
.08525 .16187 L
F
.804 .522 .247 r
.08343 .16187 m
.08343 .01715 L
.08525 .01715 L
.08525 .16187 L
s
1 .894 .882 r
.08525 .16187 m
.08525 .01717 L
.08644 .01717 L
.08644 .16187 L
F
.804 .522 .247 r
.08525 .16187 m
.08525 .01717 L
.08644 .01717 L
.08644 .16187 L
s
1 .894 .882 r
.08644 .16187 m
.08644 .01738 L
.08833 .01738 L
.08833 .16187 L
F
.804 .522 .247 r
.08644 .16187 m
.08644 .01738 L
.08833 .01738 L
.08833 .16187 L
s
1 .894 .882 r
.08833 .16187 m
.08833 .01747 L
.08922 .01747 L
.08922 .16187 L
F
.804 .522 .247 r
.08833 .16187 m
.08833 .01747 L
.08922 .01747 L
.08922 .16187 L
s
1 .894 .882 r
.08922 .16187 m
.08922 .01762 L
.09107 .01762 L
.09107 .16187 L
F
.804 .522 .247 r
.08922 .16187 m
.08922 .01762 L
.09107 .01762 L
.09107 .16187 L
s
1 .894 .882 r
.09107 .16187 m
.09107 .01772 L
.09225 .01772 L
.09225 .16187 L
F
.804 .522 .247 r
.09107 .16187 m
.09107 .01772 L
.09225 .01772 L
.09225 .16187 L
s
1 .894 .882 r
.09225 .16187 m
.09225 .01782 L
.09376 .01782 L
.09376 .16187 L
F
.804 .522 .247 r
.09225 .16187 m
.09225 .01782 L
.09376 .01782 L
.09376 .16187 L
s
1 .894 .882 r
.09376 .16187 m
.09376 .01792 L
.0949 .01792 L
.0949 .16187 L
F
.804 .522 .247 r
.09376 .16187 m
.09376 .01792 L
.0949 .01792 L
.0949 .16187 L
s
1 .894 .882 r
.0949 .16187 m
.0949 .01802 L
.09702 .01802 L
.09702 .16187 L
F
.804 .522 .247 r
.0949 .16187 m
.0949 .01802 L
.09702 .01802 L
.09702 .16187 L
s
1 .894 .882 r
.09702 .16187 m
.09702 .01834 L
.09881 .01834 L
.09881 .16187 L
F
.804 .522 .247 r
.09702 .16187 m
.09702 .01834 L
.09881 .01834 L
.09881 .16187 L
s
1 .894 .882 r
.09881 .16187 m
.09881 .01847 L
.10036 .01847 L
.10036 .16187 L
F
.804 .522 .247 r
.09881 .16187 m
.09881 .01847 L
.10036 .01847 L
.10036 .16187 L
s
1 .894 .882 r
.10036 .16187 m
.10036 .01854 L
.10173 .01854 L
.10173 .16187 L
F
.804 .522 .247 r
.10036 .16187 m
.10036 .01854 L
.10173 .01854 L
.10173 .16187 L
s
1 .894 .882 r
.10173 .16187 m
.10173 .0187 L
.10251 .0187 L
.10251 .16187 L
F
.804 .522 .247 r
.10173 .16187 m
.10173 .0187 L
.10251 .0187 L
.10251 .16187 L
s
1 .894 .882 r
.10251 .16187 m
.10251 .01876 L
.10331 .01876 L
.10331 .16187 L
F
.804 .522 .247 r
.10251 .16187 m
.10251 .01876 L
.10331 .01876 L
.10331 .16187 L
s
1 .894 .882 r
.10331 .16187 m
.10331 .01883 L
.10505 .01883 L
.10505 .16187 L
F
.804 .522 .247 r
.10331 .16187 m
.10331 .01883 L
.10505 .01883 L
.10505 .16187 L
s
1 .894 .882 r
.10505 .16187 m
.10505 .01904 L
.10576 .01904 L
.10576 .16187 L
F
.804 .522 .247 r
.10505 .16187 m
.10505 .01904 L
.10576 .01904 L
.10576 .16187 L
s
1 .894 .882 r
.10576 .16187 m
.10576 .01915 L
.10705 .01915 L
.10705 .16187 L
F
.804 .522 .247 r
.10576 .16187 m
.10576 .01915 L
.10705 .01915 L
.10705 .16187 L
s
1 .894 .882 r
.10705 .16187 m
.10705 .01923 L
.10784 .01923 L
.10784 .16187 L
F
.804 .522 .247 r
.10705 .16187 m
.10705 .01923 L
.10784 .01923 L
.10784 .16187 L
s
1 .894 .882 r
.10784 .16187 m
.10784 .01934 L
.1091 .01934 L
.1091 .16187 L
F
.804 .522 .247 r
.10784 .16187 m
.10784 .01934 L
.1091 .01934 L
.1091 .16187 L
s
1 .894 .882 r
.1091 .16187 m
.1091 .01952 L
.11053 .01952 L
.11053 .16187 L
F
.804 .522 .247 r
.1091 .16187 m
.1091 .01952 L
.11053 .01952 L
.11053 .16187 L
s
1 .894 .882 r
.11053 .16187 m
.11053 .01961 L
.11186 .01961 L
.11186 .16187 L
F
.804 .522 .247 r
.11053 .16187 m
.11053 .01961 L
.11186 .01961 L
.11186 .16187 L
s
1 .894 .882 r
.11186 .16187 m
.11186 .0198 L
.11384 .0198 L
.11384 .16187 L
F
.804 .522 .247 r
.11186 .16187 m
.11186 .0198 L
.11384 .0198 L
.11384 .16187 L
s
1 .894 .882 r
.11384 .16187 m
.11384 .0201 L
.11536 .0201 L
.11536 .16187 L
F
.804 .522 .247 r
.11384 .16187 m
.11384 .0201 L
.11536 .0201 L
.11536 .16187 L
s
1 .894 .882 r
.11536 .16187 m
.11536 .0202 L
.11624 .0202 L
.11624 .16187 L
F
.804 .522 .247 r
.11536 .16187 m
.11536 .0202 L
.11624 .0202 L
.11624 .16187 L
s
1 .894 .882 r
.11624 .16187 m
.11624 .0203 L
.11792 .0203 L
.11792 .16187 L
F
.804 .522 .247 r
.11624 .16187 m
.11624 .0203 L
.11792 .0203 L
.11792 .16187 L
s
1 .894 .882 r
.11792 .16187 m
.11792 .0205 L
.11936 .0205 L
.11936 .16187 L
F
.804 .522 .247 r
.11792 .16187 m
.11792 .0205 L
.11936 .0205 L
.11936 .16187 L
s
1 .894 .882 r
.11936 .16187 m
.11936 .02084 L
.12117 .02084 L
.12117 .16187 L
F
.804 .522 .247 r
.11936 .16187 m
.11936 .02084 L
.12117 .02084 L
.12117 .16187 L
s
1 .894 .882 r
.12117 .16187 m
.12117 .02107 L
.12333 .02107 L
.12333 .16187 L
F
.804 .522 .247 r
.12117 .16187 m
.12117 .02107 L
.12333 .02107 L
.12333 .16187 L
s
1 .894 .882 r
.12333 .16187 m
.12333 .02123 L
.12533 .02123 L
.12533 .16187 L
F
.804 .522 .247 r
.12333 .16187 m
.12333 .02123 L
.12533 .02123 L
.12533 .16187 L
s
1 .894 .882 r
.12533 .16187 m
.12533 .02147 L
.12625 .02147 L
.12625 .16187 L
F
.804 .522 .247 r
.12533 .16187 m
.12533 .02147 L
.12625 .02147 L
.12625 .16187 L
s
1 .894 .882 r
.12625 .16187 m
.12625 .02157 L
.1272 .02157 L
.1272 .16187 L
F
.804 .522 .247 r
.12625 .16187 m
.12625 .02157 L
.1272 .02157 L
.1272 .16187 L
s
1 .894 .882 r
.1272 .16187 m
.1272 .02176 L
.12886 .02176 L
.12886 .16187 L
F
.804 .522 .247 r
.1272 .16187 m
.1272 .02176 L
.12886 .02176 L
.12886 .16187 L
s
1 .894 .882 r
.12886 .16187 m
.12886 .02194 L
.13091 .02194 L
.13091 .16187 L
F
.804 .522 .247 r
.12886 .16187 m
.12886 .02194 L
.13091 .02194 L
.13091 .16187 L
s
1 .894 .882 r
.13091 .16187 m
.13091 .02228 L
.13222 .02228 L
.13222 .16187 L
F
.804 .522 .247 r
.13091 .16187 m
.13091 .02228 L
.13222 .02228 L
.13222 .16187 L
s
1 .894 .882 r
.13222 .16187 m
.13222 .0225 L
.13379 .0225 L
.13379 .16187 L
F
.804 .522 .247 r
.13222 .16187 m
.13222 .0225 L
.13379 .0225 L
.13379 .16187 L
s
1 .894 .882 r
.13379 .16187 m
.13379 .02261 L
.13474 .02261 L
.13474 .16187 L
F
.804 .522 .247 r
.13379 .16187 m
.13379 .02261 L
.13474 .02261 L
.13474 .16187 L
s
1 .894 .882 r
.13474 .16187 m
.13474 .02288 L
.13667 .02288 L
.13667 .16187 L
F
.804 .522 .247 r
.13474 .16187 m
.13474 .02288 L
.13667 .02288 L
.13667 .16187 L
s
1 .894 .882 r
.13667 .16187 m
.13667 .02303 L
.13783 .02303 L
.13783 .16187 L
F
.804 .522 .247 r
.13667 .16187 m
.13667 .02303 L
.13783 .02303 L
.13783 .16187 L
s
1 .894 .882 r
.13783 .16187 m
.13783 .02334 L
.13983 .02334 L
.13983 .16187 L
F
.804 .522 .247 r
.13783 .16187 m
.13783 .02334 L
.13983 .02334 L
.13983 .16187 L
s
1 .894 .882 r
.13983 .16187 m
.13983 .02356 L
.14072 .02356 L
.14072 .16187 L
F
.804 .522 .247 r
.13983 .16187 m
.13983 .02356 L
.14072 .02356 L
.14072 .16187 L
s
1 .894 .882 r
.14072 .16187 m
.14072 .0236 L
.14201 .0236 L
.14201 .16187 L
F
.804 .522 .247 r
.14072 .16187 m
.14072 .0236 L
.14201 .0236 L
.14201 .16187 L
s
1 .894 .882 r
.14201 .16187 m
.14201 .02379 L
.14303 .02379 L
.14303 .16187 L
F
.804 .522 .247 r
.14201 .16187 m
.14201 .02379 L
.14303 .02379 L
.14303 .16187 L
s
1 .894 .882 r
.14303 .16187 m
.14303 .02401 L
.14442 .02401 L
.14442 .16187 L
F
.804 .522 .247 r
.14303 .16187 m
.14303 .02401 L
.14442 .02401 L
.14442 .16187 L
s
1 .894 .882 r
.14442 .16187 m
.14442 .02422 L
.14606 .02422 L
.14606 .16187 L
F
.804 .522 .247 r
.14442 .16187 m
.14442 .02422 L
.14606 .02422 L
.14606 .16187 L
s
1 .894 .882 r
.14606 .16187 m
.14606 .02474 L
.1482 .02474 L
.1482 .16187 L
F
.804 .522 .247 r
.14606 .16187 m
.14606 .02474 L
.1482 .02474 L
.1482 .16187 L
s
1 .894 .882 r
.1482 .16187 m
.1482 .02491 L
.1494 .02491 L
.1494 .16187 L
F
.804 .522 .247 r
.1482 .16187 m
.1482 .02491 L
.1494 .02491 L
.1494 .16187 L
s
1 .894 .882 r
.1494 .16187 m
.1494 .02517 L
.15145 .02517 L
.15145 .16187 L
F
.804 .522 .247 r
.1494 .16187 m
.1494 .02517 L
.15145 .02517 L
.15145 .16187 L
s
1 .894 .882 r
.15145 .16187 m
.15145 .02547 L
.15286 .02547 L
.15286 .16187 L
F
.804 .522 .247 r
.15145 .16187 m
.15145 .02547 L
.15286 .02547 L
.15286 .16187 L
s
1 .894 .882 r
.15286 .16187 m
.15286 .02567 L
.15398 .02567 L
.15398 .16187 L
F
.804 .522 .247 r
.15286 .16187 m
.15286 .02567 L
.15398 .02567 L
.15398 .16187 L
s
1 .894 .882 r
.15398 .16187 m
.15398 .0259 L
.15591 .0259 L
.15591 .16187 L
F
.804 .522 .247 r
.15398 .16187 m
.15398 .0259 L
.15591 .0259 L
.15591 .16187 L
s
1 .894 .882 r
.15591 .16187 m
.15591 .02615 L
.15681 .02615 L
.15681 .16187 L
F
.804 .522 .247 r
.15591 .16187 m
.15591 .02615 L
.15681 .02615 L
.15681 .16187 L
s
1 .894 .882 r
.15681 .16187 m
.15681 .0262 L
.15823 .0262 L
.15823 .16187 L
F
.804 .522 .247 r
.15681 .16187 m
.15681 .0262 L
.15823 .0262 L
.15823 .16187 L
s
1 .894 .882 r
.15823 .16187 m
.15823 .02654 L
.15952 .02654 L
.15952 .16187 L
F
.804 .522 .247 r
.15823 .16187 m
.15823 .02654 L
.15952 .02654 L
.15952 .16187 L
s
1 .894 .882 r
.15952 .16187 m
.15952 .02668 L
.16118 .02668 L
.16118 .16187 L
F
.804 .522 .247 r
.15952 .16187 m
.15952 .02668 L
.16118 .02668 L
.16118 .16187 L
s
1 .894 .882 r
.16118 .16187 m
.16118 .02709 L
.1633 .02709 L
.1633 .16187 L
F
.804 .522 .247 r
.16118 .16187 m
.16118 .02709 L
.1633 .02709 L
.1633 .16187 L
s
1 .894 .882 r
.1633 .16187 m
.1633 .02752 L
.16523 .02752 L
.16523 .16187 L
F
.804 .522 .247 r
.1633 .16187 m
.1633 .02752 L
.16523 .02752 L
.16523 .16187 L
s
1 .894 .882 r
.16523 .16187 m
.16523 .02775 L
.16664 .02775 L
.16664 .16187 L
F
.804 .522 .247 r
.16523 .16187 m
.16523 .02775 L
.16664 .02775 L
.16664 .16187 L
s
1 .894 .882 r
.16664 .16187 m
.16664 .02802 L
.16765 .02802 L
.16765 .16187 L
F
.804 .522 .247 r
.16664 .16187 m
.16664 .02802 L
.16765 .02802 L
.16765 .16187 L
s
1 .894 .882 r
.16765 .16187 m
.16765 .02828 L
.16886 .02828 L
.16886 .16187 L
F
.804 .522 .247 r
.16765 .16187 m
.16765 .02828 L
.16886 .02828 L
.16886 .16187 L
s
1 .894 .882 r
.16886 .16187 m
.16886 .02842 L
.17048 .02842 L
.17048 .16187 L
F
.804 .522 .247 r
.16886 .16187 m
.16886 .02842 L
.17048 .02842 L
.17048 .16187 L
s
1 .894 .882 r
.17048 .16187 m
.17048 .02886 L
.17215 .02886 L
.17215 .16187 L
F
.804 .522 .247 r
.17048 .16187 m
.17048 .02886 L
.17215 .02886 L
.17215 .16187 L
s
1 .894 .882 r
.17215 .16187 m
.17215 .02901 L
.17417 .02901 L
.17417 .16187 L
F
.804 .522 .247 r
.17215 .16187 m
.17215 .02901 L
.17417 .02901 L
.17417 .16187 L
s
1 .894 .882 r
.17417 .16187 m
.17417 .02965 L
.17555 .02965 L
.17555 .16187 L
F
.804 .522 .247 r
.17417 .16187 m
.17417 .02965 L
.17555 .02965 L
.17555 .16187 L
s
1 .894 .882 r
.17555 .16187 m
.17555 .02976 L
.17693 .02976 L
.17693 .16187 L
F
.804 .522 .247 r
.17555 .16187 m
.17555 .02976 L
.17693 .02976 L
.17693 .16187 L
s
1 .894 .882 r
.17693 .16187 m
.17693 .03003 L
.17796 .03003 L
.17796 .16187 L
F
.804 .522 .247 r
.17693 .16187 m
.17693 .03003 L
.17796 .03003 L
.17796 .16187 L
s
1 .894 .882 r
.17796 .16187 m
.17796 .03047 L
.17962 .03047 L
.17962 .16187 L
F
.804 .522 .247 r
.17796 .16187 m
.17796 .03047 L
.17962 .03047 L
.17962 .16187 L
s
1 .894 .882 r
.17962 .16187 m
.17962 .03075 L
.18177 .03075 L
.18177 .16187 L
F
.804 .522 .247 r
.17962 .16187 m
.17962 .03075 L
.18177 .03075 L
.18177 .16187 L
s
1 .894 .882 r
.18177 .16187 m
.18177 .03096 L
.1837 .03096 L
.1837 .16187 L
F
.804 .522 .247 r
.18177 .16187 m
.18177 .03096 L
.1837 .03096 L
.1837 .16187 L
s
1 .894 .882 r
.1837 .16187 m
.1837 .03142 L
.18475 .03142 L
.18475 .16187 L
F
.804 .522 .247 r
.1837 .16187 m
.1837 .03142 L
.18475 .03142 L
.18475 .16187 L
s
1 .894 .882 r
.18475 .16187 m
.18475 .03157 L
.18586 .03157 L
.18586 .16187 L
F
.804 .522 .247 r
.18475 .16187 m
.18475 .03157 L
.18586 .03157 L
.18586 .16187 L
s
1 .894 .882 r
.18586 .16187 m
.18586 .03191 L
.18662 .03191 L
.18662 .16187 L
F
.804 .522 .247 r
.18586 .16187 m
.18586 .03191 L
.18662 .03191 L
.18662 .16187 L
s
1 .894 .882 r
.18662 .16187 m
.18662 .03201 L
.18779 .03201 L
.18779 .16187 L
F
.804 .522 .247 r
.18662 .16187 m
.18662 .03201 L
.18779 .03201 L
.18779 .16187 L
s
1 .894 .882 r
.18779 .16187 m
.18779 .03251 L
.1899 .03251 L
.1899 .16187 L
F
.804 .522 .247 r
.18779 .16187 m
.18779 .03251 L
.1899 .03251 L
.1899 .16187 L
s
1 .894 .882 r
.1899 .16187 m
.1899 .0328 L
.19125 .0328 L
.19125 .16187 L
F
.804 .522 .247 r
.1899 .16187 m
.1899 .0328 L
.19125 .0328 L
.19125 .16187 L
s
1 .894 .882 r
.19125 .16187 m
.19125 .03302 L
.19328 .03302 L
.19328 .16187 L
F
.804 .522 .247 r
.19125 .16187 m
.19125 .03302 L
.19328 .03302 L
.19328 .16187 L
s
1 .894 .882 r
.19328 .16187 m
.19328 .0335 L
.19521 .0335 L
.19521 .16187 L
F
.804 .522 .247 r
.19328 .16187 m
.19328 .0335 L
.19521 .0335 L
.19521 .16187 L
s
1 .894 .882 r
.19521 .16187 m
.19521 .03389 L
.19668 .03389 L
.19668 .16187 L
F
.804 .522 .247 r
.19521 .16187 m
.19521 .03389 L
.19668 .03389 L
.19668 .16187 L
s
1 .894 .882 r
.19668 .16187 m
.19668 .03435 L
.19854 .03435 L
.19854 .16187 L
F
.804 .522 .247 r
.19668 .16187 m
.19668 .03435 L
.19854 .03435 L
.19854 .16187 L
s
1 .894 .882 r
.19854 .16187 m
.19854 .03495 L
.20062 .03495 L
.20062 .16187 L
F
.804 .522 .247 r
.19854 .16187 m
.19854 .03495 L
.20062 .03495 L
.20062 .16187 L
s
1 .894 .882 r
.20062 .16187 m
.20062 .03513 L
.20128 .03513 L
.20128 .16187 L
F
.804 .522 .247 r
.20062 .16187 m
.20062 .03513 L
.20128 .03513 L
.20128 .16187 L
s
1 .894 .882 r
.20128 .16187 m
.20128 .03517 L
.20199 .03517 L
.20199 .16187 L
F
.804 .522 .247 r
.20128 .16187 m
.20128 .03517 L
.20199 .03517 L
.20199 .16187 L
s
1 .894 .882 r
.20199 .16187 m
.20199 .03539 L
.20349 .03539 L
.20349 .16187 L
F
.804 .522 .247 r
.20199 .16187 m
.20199 .03539 L
.20349 .03539 L
.20349 .16187 L
s
1 .894 .882 r
.20349 .16187 m
.20349 .03576 L
.20502 .03576 L
.20502 .16187 L
F
.804 .522 .247 r
.20349 .16187 m
.20349 .03576 L
.20502 .03576 L
.20502 .16187 L
s
1 .894 .882 r
.20502 .16187 m
.20502 .03621 L
.20622 .03621 L
.20622 .16187 L
F
.804 .522 .247 r
.20502 .16187 m
.20502 .03621 L
.20622 .03621 L
.20622 .16187 L
s
1 .894 .882 r
.20622 .16187 m
.20622 .03647 L
.20744 .03647 L
.20744 .16187 L
F
.804 .522 .247 r
.20622 .16187 m
.20622 .03647 L
.20744 .03647 L
.20744 .16187 L
s
1 .894 .882 r
.20744 .16187 m
.20744 .03666 L
.20909 .03666 L
.20909 .16187 L
F
.804 .522 .247 r
.20744 .16187 m
.20744 .03666 L
.20909 .03666 L
.20909 .16187 L
s
1 .894 .882 r
.20909 .16187 m
.20909 .03705 L
.20989 .03705 L
.20989 .16187 L
F
.804 .522 .247 r
.20909 .16187 m
.20909 .03705 L
.20989 .03705 L
.20989 .16187 L
s
1 .894 .882 r
.20989 .16187 m
.20989 .03733 L
.21189 .03733 L
.21189 .16187 L
F
.804 .522 .247 r
.20989 .16187 m
.20989 .03733 L
.21189 .03733 L
.21189 .16187 L
s
1 .894 .882 r
.21189 .16187 m
.21189 .03768 L
.21273 .03768 L
.21273 .16187 L
F
.804 .522 .247 r
.21189 .16187 m
.21189 .03768 L
.21273 .03768 L
.21273 .16187 L
s
1 .894 .882 r
.21273 .16187 m
.21273 .03796 L
.2149 .03796 L
.2149 .16187 L
F
.804 .522 .247 r
.21273 .16187 m
.21273 .03796 L
.2149 .03796 L
.2149 .16187 L
s
1 .894 .882 r
.2149 .16187 m
.2149 .03854 L
.21572 .03854 L
.21572 .16187 L
F
.804 .522 .247 r
.2149 .16187 m
.2149 .03854 L
.21572 .03854 L
.21572 .16187 L
s
1 .894 .882 r
.21572 .16187 m
.21572 .03864 L
.21644 .03864 L
.21644 .16187 L
F
.804 .522 .247 r
.21572 .16187 m
.21572 .03864 L
.21644 .03864 L
.21644 .16187 L
s
1 .894 .882 r
.21644 .16187 m
.21644 .03904 L
.2184 .03904 L
.2184 .16187 L
F
.804 .522 .247 r
.21644 .16187 m
.21644 .03904 L
.2184 .03904 L
.2184 .16187 L
s
1 .894 .882 r
.2184 .16187 m
.2184 .03971 L
.22011 .03971 L
.22011 .16187 L
F
.804 .522 .247 r
.2184 .16187 m
.2184 .03971 L
.22011 .03971 L
.22011 .16187 L
s
1 .894 .882 r
.22011 .16187 m
.22011 .03984 L
.22083 .03984 L
.22083 .16187 L
F
.804 .522 .247 r
.22011 .16187 m
.22011 .03984 L
.22083 .03984 L
.22083 .16187 L
s
1 .894 .882 r
.22083 .16187 m
.22083 .04026 L
.22255 .04026 L
.22255 .16187 L
F
.804 .522 .247 r
.22083 .16187 m
.22083 .04026 L
.22255 .04026 L
.22255 .16187 L
s
1 .894 .882 r
.22255 .16187 m
.22255 .04074 L
.22458 .04074 L
.22458 .16187 L
F
.804 .522 .247 r
.22255 .16187 m
.22255 .04074 L
.22458 .04074 L
.22458 .16187 L
s
1 .894 .882 r
.22458 .16187 m
.22458 .04097 L
.22559 .04097 L
.22559 .16187 L
F
.804 .522 .247 r
.22458 .16187 m
.22458 .04097 L
.22559 .04097 L
.22559 .16187 L
s
1 .894 .882 r
.22559 .16187 m
.22559 .04123 L
.22645 .04123 L
.22645 .16187 L
F
.804 .522 .247 r
.22559 .16187 m
.22559 .04123 L
.22645 .04123 L
.22645 .16187 L
s
1 .894 .882 r
.22645 .16187 m
.22645 .0416 L
.22841 .0416 L
.22841 .16187 L
F
.804 .522 .247 r
.22645 .16187 m
.22645 .0416 L
.22841 .0416 L
.22841 .16187 L
s
1 .894 .882 r
.22841 .16187 m
.22841 .04202 L
.22962 .04202 L
.22962 .16187 L
F
.804 .522 .247 r
.22841 .16187 m
.22841 .04202 L
.22962 .04202 L
.22962 .16187 L
s
1 .894 .882 r
.22962 .16187 m
.22962 .04248 L
.23094 .04248 L
.23094 .16187 L
F
.804 .522 .247 r
.22962 .16187 m
.22962 .04248 L
.23094 .04248 L
.23094 .16187 L
s
1 .894 .882 r
.23094 .16187 m
.23094 .04269 L
.2319 .04269 L
.2319 .16187 L
F
.804 .522 .247 r
.23094 .16187 m
.23094 .04269 L
.2319 .04269 L
.2319 .16187 L
s
1 .894 .882 r
.2319 .16187 m
.2319 .04315 L
.23386 .04315 L
.23386 .16187 L
F
.804 .522 .247 r
.2319 .16187 m
.2319 .04315 L
.23386 .04315 L
.23386 .16187 L
s
1 .894 .882 r
.23386 .16187 m
.23386 .04344 L
.23501 .04344 L
.23501 .16187 L
F
.804 .522 .247 r
.23386 .16187 m
.23386 .04344 L
.23501 .04344 L
.23501 .16187 L
s
1 .894 .882 r
.23501 .16187 m
.23501 .04398 L
.23701 .04398 L
.23701 .16187 L
F
.804 .522 .247 r
.23501 .16187 m
.23501 .04398 L
.23701 .04398 L
.23701 .16187 L
s
1 .894 .882 r
.23701 .16187 m
.23701 .04432 L
.23861 .04432 L
.23861 .16187 L
F
.804 .522 .247 r
.23701 .16187 m
.23701 .04432 L
.23861 .04432 L
.23861 .16187 L
s
1 .894 .882 r
.23861 .16187 m
.23861 .04503 L
.24002 .04503 L
.24002 .16187 L
F
.804 .522 .247 r
.23861 .16187 m
.23861 .04503 L
.24002 .04503 L
.24002 .16187 L
s
1 .894 .882 r
.24002 .16187 m
.24002 .04548 L
.24212 .04548 L
.24212 .16187 L
F
.804 .522 .247 r
.24002 .16187 m
.24002 .04548 L
.24212 .04548 L
.24212 .16187 L
s
1 .894 .882 r
.24212 .16187 m
.24212 .04576 L
.24312 .04576 L
.24312 .16187 L
F
.804 .522 .247 r
.24212 .16187 m
.24212 .04576 L
.24312 .04576 L
.24312 .16187 L
s
1 .894 .882 r
.24312 .16187 m
.24312 .04633 L
.24457 .04633 L
.24457 .16187 L
F
.804 .522 .247 r
.24312 .16187 m
.24312 .04633 L
.24457 .04633 L
.24457 .16187 L
s
1 .894 .882 r
.24457 .16187 m
.24457 .04664 L
.24616 .04664 L
.24616 .16187 L
F
.804 .522 .247 r
.24457 .16187 m
.24457 .04664 L
.24616 .04664 L
.24616 .16187 L
s
1 .894 .882 r
.24616 .16187 m
.24616 .04718 L
.24807 .04718 L
.24807 .16187 L
F
.804 .522 .247 r
.24616 .16187 m
.24616 .04718 L
.24807 .04718 L
.24807 .16187 L
s
1 .894 .882 r
.24807 .16187 m
.24807 .04743 L
.24907 .04743 L
.24907 .16187 L
F
.804 .522 .247 r
.24807 .16187 m
.24807 .04743 L
.24907 .04743 L
.24907 .16187 L
s
1 .894 .882 r
.24907 .16187 m
.24907 .04777 L
.25036 .04777 L
.25036 .16187 L
F
.804 .522 .247 r
.24907 .16187 m
.24907 .04777 L
.25036 .04777 L
.25036 .16187 L
s
1 .894 .882 r
.25036 .16187 m
.25036 .04824 L
.25188 .04824 L
.25188 .16187 L
F
.804 .522 .247 r
.25036 .16187 m
.25036 .04824 L
.25188 .04824 L
.25188 .16187 L
s
1 .894 .882 r
.25188 .16187 m
.25188 .04858 L
.254 .04858 L
.254 .16187 L
F
.804 .522 .247 r
.25188 .16187 m
.25188 .04858 L
.254 .04858 L
.254 .16187 L
s
1 .894 .882 r
.254 .16187 m
.254 .04923 L
.25547 .04923 L
.25547 .16187 L
F
.804 .522 .247 r
.254 .16187 m
.254 .04923 L
.25547 .04923 L
.25547 .16187 L
s
1 .894 .882 r
.25547 .16187 m
.25547 .04979 L
.25669 .04979 L
.25669 .16187 L
F
.804 .522 .247 r
.25547 .16187 m
.25547 .04979 L
.25669 .04979 L
.25669 .16187 L
s
1 .894 .882 r
.25669 .16187 m
.25669 .05032 L
.25867 .05032 L
.25867 .16187 L
F
.804 .522 .247 r
.25669 .16187 m
.25669 .05032 L
.25867 .05032 L
.25867 .16187 L
s
1 .894 .882 r
.25867 .16187 m
.25867 .05061 L
.25941 .05061 L
.25941 .16187 L
F
.804 .522 .247 r
.25867 .16187 m
.25867 .05061 L
.25941 .05061 L
.25941 .16187 L
s
1 .894 .882 r
.25941 .16187 m
.25941 .05105 L
.26052 .05105 L
.26052 .16187 L
F
.804 .522 .247 r
.25941 .16187 m
.25941 .05105 L
.26052 .05105 L
.26052 .16187 L
s
1 .894 .882 r
.26052 .16187 m
.26052 .05116 L
.26153 .05116 L
.26153 .16187 L
F
.804 .522 .247 r
.26052 .16187 m
.26052 .05116 L
.26153 .05116 L
.26153 .16187 L
s
1 .894 .882 r
.26153 .16187 m
.26153 .05143 L
.26219 .05143 L
.26219 .16187 L
F
.804 .522 .247 r
.26153 .16187 m
.26153 .05143 L
.26219 .05143 L
.26219 .16187 L
s
1 .894 .882 r
.26219 .16187 m
.26219 .0516 L
.2639 .0516 L
.2639 .16187 L
F
.804 .522 .247 r
.26219 .16187 m
.26219 .0516 L
.2639 .0516 L
.2639 .16187 L
s
1 .894 .882 r
.2639 .16187 m
.2639 .05221 L
.26586 .05221 L
.26586 .16187 L
F
.804 .522 .247 r
.2639 .16187 m
.2639 .05221 L
.26586 .05221 L
.26586 .16187 L
s
1 .894 .882 r
.26586 .16187 m
.26586 .0529 L
.26657 .0529 L
.26657 .16187 L
F
.804 .522 .247 r
.26586 .16187 m
.26586 .0529 L
.26657 .0529 L
.26657 .16187 L
s
1 .894 .882 r
.26657 .16187 m
.26657 .05312 L
.26745 .05312 L
.26745 .16187 L
F
.804 .522 .247 r
.26657 .16187 m
.26657 .05312 L
.26745 .05312 L
.26745 .16187 L
s
1 .894 .882 r
.26745 .16187 m
.26745 .05351 L
.26865 .05351 L
.26865 .16187 L
F
.804 .522 .247 r
.26745 .16187 m
.26745 .05351 L
.26865 .05351 L
.26865 .16187 L
s
1 .894 .882 r
.26865 .16187 m
.26865 .054 L
.27079 .054 L
.27079 .16187 L
F
.804 .522 .247 r
.26865 .16187 m
.26865 .054 L
.27079 .054 L
.27079 .16187 L
s
1 .894 .882 r
.27079 .16187 m
.27079 .0545 L
.27207 .0545 L
.27207 .16187 L
F
.804 .522 .247 r
.27079 .16187 m
.27079 .0545 L
.27207 .0545 L
.27207 .16187 L
s
1 .894 .882 r
.27207 .16187 m
.27207 .05506 L
.27372 .05506 L
.27372 .16187 L
F
.804 .522 .247 r
.27207 .16187 m
.27207 .05506 L
.27372 .05506 L
.27372 .16187 L
s
1 .894 .882 r
.27372 .16187 m
.27372 .05565 L
.27499 .05565 L
.27499 .16187 L
F
.804 .522 .247 r
.27372 .16187 m
.27372 .05565 L
.27499 .05565 L
.27499 .16187 L
s
1 .894 .882 r
.27499 .16187 m
.27499 .05574 L
.27679 .05574 L
.27679 .16187 L
F
.804 .522 .247 r
.27499 .16187 m
.27499 .05574 L
.27679 .05574 L
.27679 .16187 L
s
1 .894 .882 r
.27679 .16187 m
.27679 .05659 L
.27878 .05659 L
.27878 .16187 L
F
.804 .522 .247 r
.27679 .16187 m
.27679 .05659 L
.27878 .05659 L
.27878 .16187 L
s
1 .894 .882 r
.27878 .16187 m
.27878 .05714 L
.27949 .05714 L
.27949 .16187 L
F
.804 .522 .247 r
.27878 .16187 m
.27878 .05714 L
.27949 .05714 L
.27949 .16187 L
s
1 .894 .882 r
.27949 .16187 m
.27949 .05729 L
.28103 .05729 L
.28103 .16187 L
F
.804 .522 .247 r
.27949 .16187 m
.27949 .05729 L
.28103 .05729 L
.28103 .16187 L
s
1 .894 .882 r
.28103 .16187 m
.28103 .05808 L
.28248 .05808 L
.28248 .16187 L
F
.804 .522 .247 r
.28103 .16187 m
.28103 .05808 L
.28248 .05808 L
.28248 .16187 L
s
1 .894 .882 r
.28248 .16187 m
.28248 .05823 L
.28384 .05823 L
.28384 .16187 L
F
.804 .522 .247 r
.28248 .16187 m
.28248 .05823 L
.28384 .05823 L
.28384 .16187 L
s
1 .894 .882 r
.28384 .16187 m
.28384 .05883 L
.2852 .05883 L
.2852 .16187 L
F
.804 .522 .247 r
.28384 .16187 m
.28384 .05883 L
.2852 .05883 L
.2852 .16187 L
s
1 .894 .882 r
.2852 .16187 m
.2852 .05913 L
.28679 .05913 L
.28679 .16187 L
F
.804 .522 .247 r
.2852 .16187 m
.2852 .05913 L
.28679 .05913 L
.28679 .16187 L
s
1 .894 .882 r
.28679 .16187 m
.28679 .06003 L
.28895 .06003 L
.28895 .16187 L
F
.804 .522 .247 r
.28679 .16187 m
.28679 .06003 L
.28895 .06003 L
.28895 .16187 L
s
1 .894 .882 r
.28895 .16187 m
.28895 .06048 L
.28974 .06048 L
.28974 .16187 L
F
.804 .522 .247 r
.28895 .16187 m
.28895 .06048 L
.28974 .06048 L
.28974 .16187 L
s
1 .894 .882 r
.28974 .16187 m
.28974 .06105 L
.2913 .06105 L
.2913 .16187 L
F
.804 .522 .247 r
.28974 .16187 m
.28974 .06105 L
.2913 .06105 L
.2913 .16187 L
s
1 .894 .882 r
.2913 .16187 m
.2913 .06151 L
.29279 .06151 L
.29279 .16187 L
F
.804 .522 .247 r
.2913 .16187 m
.2913 .06151 L
.29279 .06151 L
.29279 .16187 L
s
1 .894 .882 r
.29279 .16187 m
.29279 .06206 L
.2945 .06206 L
.2945 .16187 L
F
.804 .522 .247 r
.29279 .16187 m
.29279 .06206 L
.2945 .06206 L
.2945 .16187 L
s
1 .894 .882 r
.2945 .16187 m
.2945 .06245 L
.29645 .06245 L
.29645 .16187 L
F
.804 .522 .247 r
.2945 .16187 m
.2945 .06245 L
.29645 .06245 L
.29645 .16187 L
s
1 .894 .882 r
.29645 .16187 m
.29645 .06328 L
.29799 .06328 L
.29799 .16187 L
F
.804 .522 .247 r
.29645 .16187 m
.29645 .06328 L
.29799 .06328 L
.29799 .16187 L
s
1 .894 .882 r
.29799 .16187 m
.29799 .06399 L
.29996 .06399 L
.29996 .16187 L
F
.804 .522 .247 r
.29799 .16187 m
.29799 .06399 L
.29996 .06399 L
.29996 .16187 L
s
1 .894 .882 r
.29996 .16187 m
.29996 .06455 L
.30188 .06455 L
.30188 .16187 L
F
.804 .522 .247 r
.29996 .16187 m
.29996 .06455 L
.30188 .06455 L
.30188 .16187 L
s
1 .894 .882 r
.30188 .16187 m
.30188 .06525 L
.30378 .06525 L
.30378 .16187 L
F
.804 .522 .247 r
.30188 .16187 m
.30188 .06525 L
.30378 .06525 L
.30378 .16187 L
s
1 .894 .882 r
.30378 .16187 m
.30378 .06558 L
.30509 .06558 L
.30509 .16187 L
F
.804 .522 .247 r
.30378 .16187 m
.30378 .06558 L
.30509 .06558 L
.30509 .16187 L
s
1 .894 .882 r
.30509 .16187 m
.30509 .06657 L
.30651 .06657 L
.30651 .16187 L
F
.804 .522 .247 r
.30509 .16187 m
.30509 .06657 L
.30651 .06657 L
.30651 .16187 L
s
1 .894 .882 r
.30651 .16187 m
.30651 .06725 L
.30845 .06725 L
.30845 .16187 L
F
.804 .522 .247 r
.30651 .16187 m
.30651 .06725 L
.30845 .06725 L
.30845 .16187 L
s
1 .894 .882 r
.30845 .16187 m
.30845 .0673 L
.30973 .0673 L
.30973 .16187 L
F
.804 .522 .247 r
.30845 .16187 m
.30845 .0673 L
.30973 .0673 L
.30973 .16187 L
s
1 .894 .882 r
.30973 .16187 m
.30973 .06801 L
.31156 .06801 L
.31156 .16187 L
F
.804 .522 .247 r
.30973 .16187 m
.30973 .06801 L
.31156 .06801 L
.31156 .16187 L
s
1 .894 .882 r
.31156 .16187 m
.31156 .06875 L
.31237 .06875 L
.31237 .16187 L
F
.804 .522 .247 r
.31156 .16187 m
.31156 .06875 L
.31237 .06875 L
.31237 .16187 L
s
1 .894 .882 r
.31237 .16187 m
.31237 .06899 L
.31316 .06899 L
.31316 .16187 L
F
.804 .522 .247 r
.31237 .16187 m
.31237 .06899 L
.31316 .06899 L
.31316 .16187 L
s
1 .894 .882 r
.31316 .16187 m
.31316 .06932 L
.31462 .06932 L
.31462 .16187 L
F
.804 .522 .247 r
.31316 .16187 m
.31316 .06932 L
.31462 .06932 L
.31462 .16187 L
s
1 .894 .882 r
.31462 .16187 m
.31462 .06984 L
.31639 .06984 L
.31639 .16187 L
F
.804 .522 .247 r
.31462 .16187 m
.31462 .06984 L
.31639 .06984 L
.31639 .16187 L
s
1 .894 .882 r
.31639 .16187 m
.31639 .07064 L
.31784 .07064 L
.31784 .16187 L
F
.804 .522 .247 r
.31639 .16187 m
.31639 .07064 L
.31784 .07064 L
.31784 .16187 L
s
1 .894 .882 r
.31784 .16187 m
.31784 .07135 L
.31935 .07135 L
.31935 .16187 L
F
.804 .522 .247 r
.31784 .16187 m
.31784 .07135 L
.31935 .07135 L
.31935 .16187 L
s
1 .894 .882 r
.31935 .16187 m
.31935 .07148 L
.3201 .07148 L
.3201 .16187 L
F
.804 .522 .247 r
.31935 .16187 m
.31935 .07148 L
.3201 .07148 L
.3201 .16187 L
s
1 .894 .882 r
.3201 .16187 m
.3201 .07203 L
.32117 .07203 L
.32117 .16187 L
F
.804 .522 .247 r
.3201 .16187 m
.3201 .07203 L
.32117 .07203 L
.32117 .16187 L
s
1 .894 .882 r
.32117 .16187 m
.32117 .07253 L
.3232 .07253 L
.3232 .16187 L
F
.804 .522 .247 r
.32117 .16187 m
.32117 .07253 L
.3232 .07253 L
.3232 .16187 L
s
1 .894 .882 r
.3232 .16187 m
.3232 .07308 L
.32472 .07308 L
.32472 .16187 L
F
.804 .522 .247 r
.3232 .16187 m
.3232 .07308 L
.32472 .07308 L
.32472 .16187 L
s
1 .894 .882 r
.32472 .16187 m
.32472 .07411 L
.32685 .07411 L
.32685 .16187 L
F
.804 .522 .247 r
.32472 .16187 m
.32472 .07411 L
.32685 .07411 L
.32685 .16187 L
s
1 .894 .882 r
.32685 .16187 m
.32685 .07432 L
.32854 .07432 L
.32854 .16187 L
F
.804 .522 .247 r
.32685 .16187 m
.32685 .07432 L
.32854 .07432 L
.32854 .16187 L
s
1 .894 .882 r
.32854 .16187 m
.32854 .07537 L
.32973 .07537 L
.32973 .16187 L
F
.804 .522 .247 r
.32854 .16187 m
.32854 .07537 L
.32973 .07537 L
.32973 .16187 L
s
1 .894 .882 r
.32973 .16187 m
.32973 .07598 L
.33172 .07598 L
.33172 .16187 L
F
.804 .522 .247 r
.32973 .16187 m
.32973 .07598 L
.33172 .07598 L
.33172 .16187 L
s
1 .894 .882 r
.33172 .16187 m
.33172 .0764 L
.33255 .0764 L
.33255 .16187 L
F
.804 .522 .247 r
.33172 .16187 m
.33172 .0764 L
.33255 .0764 L
.33255 .16187 L
s
1 .894 .882 r
.33255 .16187 m
.33255 .0767 L
.33335 .0767 L
.33335 .16187 L
F
.804 .522 .247 r
.33255 .16187 m
.33255 .0767 L
.33335 .0767 L
.33335 .16187 L
s
1 .894 .882 r
.33335 .16187 m
.33335 .07697 L
.33474 .07697 L
.33474 .16187 L
F
.804 .522 .247 r
.33335 .16187 m
.33335 .07697 L
.33474 .07697 L
.33474 .16187 L
s
1 .894 .882 r
.33474 .16187 m
.33474 .0775 L
.33547 .0775 L
.33547 .16187 L
F
.804 .522 .247 r
.33474 .16187 m
.33474 .0775 L
.33547 .0775 L
.33547 .16187 L
s
1 .894 .882 r
.33547 .16187 m
.33547 .07818 L
.33657 .07818 L
.33657 .16187 L
F
.804 .522 .247 r
.33547 .16187 m
.33547 .07818 L
.33657 .07818 L
.33657 .16187 L
s
1 .894 .882 r
.33657 .16187 m
.33657 .07847 L
.33823 .07847 L
.33823 .16187 L
F
.804 .522 .247 r
.33657 .16187 m
.33657 .07847 L
.33823 .07847 L
.33823 .16187 L
s
1 .894 .882 r
.33823 .16187 m
.33823 .07902 L
.34038 .07902 L
.34038 .16187 L
F
.804 .522 .247 r
.33823 .16187 m
.33823 .07902 L
.34038 .07902 L
.34038 .16187 L
s
1 .894 .882 r
.34038 .16187 m
.34038 .07984 L
.34134 .07984 L
.34134 .16187 L
F
.804 .522 .247 r
.34038 .16187 m
.34038 .07984 L
.34134 .07984 L
.34134 .16187 L
s
1 .894 .882 r
.34134 .16187 m
.34134 .08092 L
.34333 .08092 L
.34333 .16187 L
F
.804 .522 .247 r
.34134 .16187 m
.34134 .08092 L
.34333 .08092 L
.34333 .16187 L
s
1 .894 .882 r
.34333 .16187 m
.34333 .08101 L
.34534 .08101 L
.34534 .16187 L
F
.804 .522 .247 r
.34333 .16187 m
.34333 .08101 L
.34534 .08101 L
.34534 .16187 L
s
1 .894 .882 r
.34534 .16187 m
.34534 .08195 L
.34733 .08195 L
.34733 .16187 L
F
.804 .522 .247 r
.34534 .16187 m
.34534 .08195 L
.34733 .08195 L
.34733 .16187 L
s
1 .894 .882 r
.34733 .16187 m
.34733 .08278 L
.34815 .08278 L
.34815 .16187 L
F
.804 .522 .247 r
.34733 .16187 m
.34733 .08278 L
.34815 .08278 L
.34815 .16187 L
s
1 .894 .882 r
.34815 .16187 m
.34815 .0832 L
.34933 .0832 L
.34933 .16187 L
F
.804 .522 .247 r
.34815 .16187 m
.34815 .0832 L
.34933 .0832 L
.34933 .16187 L
s
1 .894 .882 r
.34933 .16187 m
.34933 .08374 L
.35022 .08374 L
.35022 .16187 L
F
.804 .522 .247 r
.34933 .16187 m
.34933 .08374 L
.35022 .08374 L
.35022 .16187 L
s
1 .894 .882 r
.35022 .16187 m
.35022 .0841 L
.35142 .0841 L
.35142 .16187 L
F
.804 .522 .247 r
.35022 .16187 m
.35022 .0841 L
.35142 .0841 L
.35142 .16187 L
s
1 .894 .882 r
.35142 .16187 m
.35142 .08469 L
.3529 .08469 L
.3529 .16187 L
F
.804 .522 .247 r
.35142 .16187 m
.35142 .08469 L
.3529 .08469 L
.3529 .16187 L
s
1 .894 .882 r
.3529 .16187 m
.3529 .08507 L
.35399 .08507 L
.35399 .16187 L
F
.804 .522 .247 r
.3529 .16187 m
.3529 .08507 L
.35399 .08507 L
.35399 .16187 L
s
1 .894 .882 r
.35399 .16187 m
.35399 .08618 L
.35598 .08618 L
.35598 .16187 L
F
.804 .522 .247 r
.35399 .16187 m
.35399 .08618 L
.35598 .08618 L
.35598 .16187 L
s
1 .894 .882 r
.35598 .16187 m
.35598 .08686 L
.35732 .08686 L
.35732 .16187 L
F
.804 .522 .247 r
.35598 .16187 m
.35598 .08686 L
.35732 .08686 L
.35732 .16187 L
s
1 .894 .882 r
.35732 .16187 m
.35732 .08706 L
.35945 .08706 L
.35945 .16187 L
F
.804 .522 .247 r
.35732 .16187 m
.35732 .08706 L
.35945 .08706 L
.35945 .16187 L
s
1 .894 .882 r
.35945 .16187 m
.35945 .08802 L
.36058 .08802 L
.36058 .16187 L
F
.804 .522 .247 r
.35945 .16187 m
.35945 .08802 L
.36058 .08802 L
.36058 .16187 L
s
1 .894 .882 r
.36058 .16187 m
.36058 .08866 L
.36154 .08866 L
.36154 .16187 L
F
.804 .522 .247 r
.36058 .16187 m
.36058 .08866 L
.36154 .08866 L
.36154 .16187 L
s
1 .894 .882 r
.36154 .16187 m
.36154 .08876 L
.36234 .08876 L
.36234 .16187 L
F
.804 .522 .247 r
.36154 .16187 m
.36154 .08876 L
.36234 .08876 L
.36234 .16187 L
s
1 .894 .882 r
.36234 .16187 m
.36234 .08926 L
.36313 .08926 L
.36313 .16187 L
F
.804 .522 .247 r
.36234 .16187 m
.36234 .08926 L
.36313 .08926 L
.36313 .16187 L
s
1 .894 .882 r
.36313 .16187 m
.36313 .08982 L
.36409 .08982 L
.36409 .16187 L
F
.804 .522 .247 r
.36313 .16187 m
.36313 .08982 L
.36409 .08982 L
.36409 .16187 L
s
1 .894 .882 r
.36409 .16187 m
.36409 .09 L
.36489 .09 L
.36489 .16187 L
F
.804 .522 .247 r
.36409 .16187 m
.36409 .09 L
.36489 .09 L
.36489 .16187 L
s
1 .894 .882 r
.36489 .16187 m
.36489 .09088 L
.36649 .09088 L
.36649 .16187 L
F
.804 .522 .247 r
.36489 .16187 m
.36489 .09088 L
.36649 .09088 L
.36649 .16187 L
s
1 .894 .882 r
.36649 .16187 m
.36649 .09102 L
.3672 .09102 L
.3672 .16187 L
F
.804 .522 .247 r
.36649 .16187 m
.36649 .09102 L
.3672 .09102 L
.3672 .16187 L
s
1 .894 .882 r
.3672 .16187 m
.3672 .09209 L
.36923 .09209 L
.36923 .16187 L
F
.804 .522 .247 r
.3672 .16187 m
.3672 .09209 L
.36923 .09209 L
.36923 .16187 L
s
1 .894 .882 r
.36923 .16187 m
.36923 .09215 L
.37054 .09215 L
.37054 .16187 L
F
.804 .522 .247 r
.36923 .16187 m
.36923 .09215 L
.37054 .09215 L
.37054 .16187 L
s
1 .894 .882 r
.37054 .16187 m
.37054 .0933 L
.37216 .0933 L
.37216 .16187 L
F
.804 .522 .247 r
.37054 .16187 m
.37054 .0933 L
.37216 .0933 L
.37216 .16187 L
s
1 .894 .882 r
.37216 .16187 m
.37216 .09356 L
.37409 .09356 L
.37409 .16187 L
F
.804 .522 .247 r
.37216 .16187 m
.37216 .09356 L
.37409 .09356 L
.37409 .16187 L
s
1 .894 .882 r
.37409 .16187 m
.37409 .09434 L
.37478 .09434 L
.37478 .16187 L
F
.804 .522 .247 r
.37409 .16187 m
.37409 .09434 L
.37478 .09434 L
.37478 .16187 L
s
1 .894 .882 r
.37478 .16187 m
.37478 .0953 L
.37626 .0953 L
.37626 .16187 L
F
.804 .522 .247 r
.37478 .16187 m
.37478 .0953 L
.37626 .0953 L
.37626 .16187 L
s
1 .894 .882 r
.37626 .16187 m
.37626 .09582 L
.37806 .09582 L
.37806 .16187 L
F
.804 .522 .247 r
.37626 .16187 m
.37626 .09582 L
.37806 .09582 L
.37806 .16187 L
s
1 .894 .882 r
.37806 .16187 m
.37806 .0967 L
.37982 .0967 L
.37982 .16187 L
F
.804 .522 .247 r
.37806 .16187 m
.37806 .0967 L
.37982 .0967 L
.37982 .16187 L
s
1 .894 .882 r
.37982 .16187 m
.37982 .0974 L
.3815 .0974 L
.3815 .16187 L
F
.804 .522 .247 r
.37982 .16187 m
.37982 .0974 L
.3815 .0974 L
.3815 .16187 L
s
1 .894 .882 r
.3815 .16187 m
.3815 .09789 L
.38274 .09789 L
.38274 .16187 L
F
.804 .522 .247 r
.3815 .16187 m
.3815 .09789 L
.38274 .09789 L
.38274 .16187 L
s
1 .894 .882 r
.38274 .16187 m
.38274 .09838 L
.384 .09838 L
.384 .16187 L
F
.804 .522 .247 r
.38274 .16187 m
.38274 .09838 L
.384 .09838 L
.384 .16187 L
s
1 .894 .882 r
.384 .16187 m
.384 .09898 L
.38493 .09898 L
.38493 .16187 L
F
.804 .522 .247 r
.384 .16187 m
.384 .09898 L
.38493 .09898 L
.38493 .16187 L
s
1 .894 .882 r
.38493 .16187 m
.38493 .09958 L
.38617 .09958 L
.38617 .16187 L
F
.804 .522 .247 r
.38493 .16187 m
.38493 .09958 L
.38617 .09958 L
.38617 .16187 L
s
1 .894 .882 r
.38617 .16187 m
.38617 .10021 L
.3876 .10021 L
.3876 .16187 L
F
.804 .522 .247 r
.38617 .16187 m
.38617 .10021 L
.3876 .10021 L
.3876 .16187 L
s
1 .894 .882 r
.3876 .16187 m
.3876 .10077 L
.38968 .10077 L
.38968 .16187 L
F
.804 .522 .247 r
.3876 .16187 m
.3876 .10077 L
.38968 .10077 L
.38968 .16187 L
s
1 .894 .882 r
.38968 .16187 m
.38968 .10204 L
.39066 .10204 L
.39066 .16187 L
F
.804 .522 .247 r
.38968 .16187 m
.38968 .10204 L
.39066 .10204 L
.39066 .16187 L
s
1 .894 .882 r
.39066 .16187 m
.39066 .10205 L
.39143 .10205 L
.39143 .16187 L
F
.804 .522 .247 r
.39066 .16187 m
.39066 .10205 L
.39143 .10205 L
.39143 .16187 L
s
1 .894 .882 r
.39143 .16187 m
.39143 .10273 L
.39255 .10273 L
.39255 .16187 L
F
.804 .522 .247 r
.39143 .16187 m
.39143 .10273 L
.39255 .10273 L
.39255 .16187 L
s
1 .894 .882 r
.39255 .16187 m
.39255 .10302 L
.39448 .10302 L
.39448 .16187 L
F
.804 .522 .247 r
.39255 .16187 m
.39255 .10302 L
.39448 .10302 L
.39448 .16187 L
s
1 .894 .882 r
.39448 .16187 m
.39448 .10407 L
.39532 .10407 L
.39532 .16187 L
F
.804 .522 .247 r
.39448 .16187 m
.39448 .10407 L
.39532 .10407 L
.39532 .16187 L
s
1 .894 .882 r
.39532 .16187 m
.39532 .10437 L
.3973 .10437 L
.3973 .16187 L
F
.804 .522 .247 r
.39532 .16187 m
.39532 .10437 L
.3973 .10437 L
.3973 .16187 L
s
1 .894 .882 r
.3973 .16187 m
.3973 .10532 L
.39827 .10532 L
.39827 .16187 L
F
.804 .522 .247 r
.3973 .16187 m
.3973 .10532 L
.39827 .10532 L
.39827 .16187 L
s
1 .894 .882 r
.39827 .16187 m
.39827 .10577 L
.39926 .10577 L
.39926 .16187 L
F
.804 .522 .247 r
.39827 .16187 m
.39827 .10577 L
.39926 .10577 L
.39926 .16187 L
s
1 .894 .882 r
.39926 .16187 m
.39926 .10625 L
.40004 .10625 L
.40004 .16187 L
F
.804 .522 .247 r
.39926 .16187 m
.39926 .10625 L
.40004 .10625 L
.40004 .16187 L
s
1 .894 .882 r
.40004 .16187 m
.40004 .10672 L
.40217 .10672 L
.40217 .16187 L
F
.804 .522 .247 r
.40004 .16187 m
.40004 .10672 L
.40217 .10672 L
.40217 .16187 L
s
1 .894 .882 r
.40217 .16187 m
.40217 .10776 L
.404 .10776 L
.404 .16187 L
F
.804 .522 .247 r
.40217 .16187 m
.40217 .10776 L
.404 .10776 L
.404 .16187 L
s
1 .894 .882 r
.404 .16187 m
.404 .10878 L
.40553 .10878 L
.40553 .16187 L
F
.804 .522 .247 r
.404 .16187 m
.404 .10878 L
.40553 .10878 L
.40553 .16187 L
s
1 .894 .882 r
.40553 .16187 m
.40553 .10929 L
.40657 .10929 L
.40657 .16187 L
F
.804 .522 .247 r
.40553 .16187 m
.40553 .10929 L
.40657 .10929 L
.40657 .16187 L
s
1 .894 .882 r
.40657 .16187 m
.40657 .10993 L
.40866 .10993 L
.40866 .16187 L
F
.804 .522 .247 r
.40657 .16187 m
.40657 .10993 L
.40866 .10993 L
.40866 .16187 L
s
1 .894 .882 r
.40866 .16187 m
.40866 .11093 L
.40966 .11093 L
.40966 .16187 L
F
.804 .522 .247 r
.40866 .16187 m
.40866 .11093 L
.40966 .11093 L
.40966 .16187 L
s
1 .894 .882 r
.40966 .16187 m
.40966 .11205 L
.41157 .11205 L
.41157 .16187 L
F
.804 .522 .247 r
.40966 .16187 m
.40966 .11205 L
.41157 .11205 L
.41157 .16187 L
s
1 .894 .882 r
.41157 .16187 m
.41157 .11255 L
.41301 .11255 L
.41301 .16187 L
F
.804 .522 .247 r
.41157 .16187 m
.41157 .11255 L
.41301 .11255 L
.41301 .16187 L
s
1 .894 .882 r
.41301 .16187 m
.41301 .11333 L
.41408 .11333 L
.41408 .16187 L
F
.804 .522 .247 r
.41301 .16187 m
.41301 .11333 L
.41408 .11333 L
.41408 .16187 L
s
1 .894 .882 r
.41408 .16187 m
.41408 .11448 L
.41601 .11448 L
.41601 .16187 L
F
.804 .522 .247 r
.41408 .16187 m
.41408 .11448 L
.41601 .11448 L
.41601 .16187 L
s
1 .894 .882 r
.41601 .16187 m
.41601 .11496 L
.41731 .11496 L
.41731 .16187 L
F
.804 .522 .247 r
.41601 .16187 m
.41601 .11496 L
.41731 .11496 L
.41731 .16187 L
s
1 .894 .882 r
.41731 .16187 m
.41731 .11532 L
.41848 .11532 L
.41848 .16187 L
F
.804 .522 .247 r
.41731 .16187 m
.41731 .11532 L
.41848 .11532 L
.41848 .16187 L
s
1 .894 .882 r
.41848 .16187 m
.41848 .11598 L
.42047 .11598 L
.42047 .16187 L
F
.804 .522 .247 r
.41848 .16187 m
.41848 .11598 L
.42047 .11598 L
.42047 .16187 L
s
1 .894 .882 r
.42047 .16187 m
.42047 .11713 L
.42163 .11713 L
.42163 .16187 L
F
.804 .522 .247 r
.42047 .16187 m
.42047 .11713 L
.42163 .11713 L
.42163 .16187 L
s
1 .894 .882 r
.42163 .16187 m
.42163 .11776 L
.42302 .11776 L
.42302 .16187 L
F
.804 .522 .247 r
.42163 .16187 m
.42163 .11776 L
.42302 .11776 L
.42302 .16187 L
s
1 .894 .882 r
.42302 .16187 m
.42302 .11823 L
.42387 .11823 L
.42387 .16187 L
F
.804 .522 .247 r
.42302 .16187 m
.42302 .11823 L
.42387 .11823 L
.42387 .16187 L
s
1 .894 .882 r
.42387 .16187 m
.42387 .11875 L
.42575 .11875 L
.42575 .16187 L
F
.804 .522 .247 r
.42387 .16187 m
.42387 .11875 L
.42575 .11875 L
.42575 .16187 L
s
1 .894 .882 r
.42575 .16187 m
.42575 .11988 L
.42643 .11988 L
.42643 .16187 L
F
.804 .522 .247 r
.42575 .16187 m
.42575 .11988 L
.42643 .11988 L
.42643 .16187 L
s
1 .894 .882 r
.42643 .16187 m
.42643 .12025 L
.42807 .12025 L
.42807 .16187 L
F
.804 .522 .247 r
.42643 .16187 m
.42643 .12025 L
.42807 .12025 L
.42807 .16187 L
s
1 .894 .882 r
.42807 .16187 m
.42807 .12102 L
.42873 .12102 L
.42873 .16187 L
F
.804 .522 .247 r
.42807 .16187 m
.42807 .12102 L
.42873 .12102 L
.42873 .16187 L
s
1 .894 .882 r
.42873 .16187 m
.42873 .1212 L
.43079 .1212 L
.43079 .16187 L
F
.804 .522 .247 r
.42873 .16187 m
.42873 .1212 L
.43079 .1212 L
.43079 .16187 L
s
1 .894 .882 r
.43079 .16187 m
.43079 .12295 L
.43269 .12295 L
.43269 .16187 L
F
.804 .522 .247 r
.43079 .16187 m
.43079 .12295 L
.43269 .12295 L
.43269 .16187 L
s
1 .894 .882 r
.43269 .16187 m
.43269 .12338 L
.43399 .12338 L
.43399 .16187 L
F
.804 .522 .247 r
.43269 .16187 m
.43269 .12338 L
.43399 .12338 L
.43399 .16187 L
s
1 .894 .882 r
.43399 .16187 m
.43399 .12454 L
.43604 .12454 L
.43604 .16187 L
F
.804 .522 .247 r
.43399 .16187 m
.43399 .12454 L
.43604 .12454 L
.43604 .16187 L
s
1 .894 .882 r
.43604 .16187 m
.43604 .12605 L
.43815 .12605 L
.43815 .16187 L
F
.804 .522 .247 r
.43604 .16187 m
.43604 .12605 L
.43815 .12605 L
.43815 .16187 L
s
1 .894 .882 r
.43815 .16187 m
.43815 .12635 L
.43887 .12635 L
.43887 .16187 L
F
.804 .522 .247 r
.43815 .16187 m
.43815 .12635 L
.43887 .12635 L
.43887 .16187 L
s
1 .894 .882 r
.43887 .16187 m
.43887 .12745 L
.4408 .12745 L
.4408 .16187 L
F
.804 .522 .247 r
.43887 .16187 m
.43887 .12745 L
.4408 .12745 L
.4408 .16187 L
s
1 .894 .882 r
.4408 .16187 m
.4408 .12805 L
.44247 .12805 L
.44247 .16187 L
F
.804 .522 .247 r
.4408 .16187 m
.4408 .12805 L
.44247 .12805 L
.44247 .16187 L
s
1 .894 .882 r
.44247 .16187 m
.44247 .12875 L
.44315 .12875 L
.44315 .16187 L
F
.804 .522 .247 r
.44247 .16187 m
.44247 .12875 L
.44315 .12875 L
.44315 .16187 L
s
1 .894 .882 r
.44315 .16187 m
.44315 .12921 L
.44504 .12921 L
.44504 .16187 L
F
.804 .522 .247 r
.44315 .16187 m
.44315 .12921 L
.44504 .12921 L
.44504 .16187 L
s
1 .894 .882 r
.44504 .16187 m
.44504 .12991 L
.44572 .12991 L
.44572 .16187 L
F
.804 .522 .247 r
.44504 .16187 m
.44504 .12991 L
.44572 .12991 L
.44572 .16187 L
s
1 .894 .882 r
.44572 .16187 m
.44572 .13032 L
.44659 .13032 L
.44659 .16187 L
F
.804 .522 .247 r
.44572 .16187 m
.44572 .13032 L
.44659 .13032 L
.44659 .16187 L
s
1 .894 .882 r
.44659 .16187 m
.44659 .13091 L
.44838 .13091 L
.44838 .16187 L
F
.804 .522 .247 r
.44659 .16187 m
.44659 .13091 L
.44838 .13091 L
.44838 .16187 L
s
1 .894 .882 r
.44838 .16187 m
.44838 .1322 L
.45051 .1322 L
.45051 .16187 L
F
.804 .522 .247 r
.44838 .16187 m
.44838 .1322 L
.45051 .1322 L
.45051 .16187 L
s
1 .894 .882 r
.45051 .16187 m
.45051 .13329 L
.45205 .13329 L
.45205 .16187 L
F
.804 .522 .247 r
.45051 .16187 m
.45051 .13329 L
.45205 .13329 L
.45205 .16187 L
s
1 .894 .882 r
.45205 .16187 m
.45205 .13475 L
.45393 .13475 L
.45393 .16187 L
F
.804 .522 .247 r
.45205 .16187 m
.45205 .13475 L
.45393 .13475 L
.45393 .16187 L
s
1 .894 .882 r
.45393 .16187 m
.45393 .13481 L
.4559 .13481 L
.4559 .16187 L
F
.804 .522 .247 r
.45393 .16187 m
.45393 .13481 L
.4559 .13481 L
.4559 .16187 L
s
1 .894 .882 r
.4559 .16187 m
.4559 .13671 L
.45753 .13671 L
.45753 .16187 L
F
.804 .522 .247 r
.4559 .16187 m
.4559 .13671 L
.45753 .13671 L
.45753 .16187 L
s
1 .894 .882 r
.45753 .16187 m
.45753 .1368 L
.45833 .1368 L
.45833 .16187 L
F
.804 .522 .247 r
.45753 .16187 m
.45753 .1368 L
.45833 .1368 L
.45833 .16187 L
s
1 .894 .882 r
.45833 .16187 m
.45833 .13797 L
.46002 .13797 L
.46002 .16187 L
F
.804 .522 .247 r
.45833 .16187 m
.45833 .13797 L
.46002 .13797 L
.46002 .16187 L
s
1 .894 .882 r
.46002 .16187 m
.46002 .13855 L
.46076 .13855 L
.46076 .16187 L
F
.804 .522 .247 r
.46002 .16187 m
.46002 .13855 L
.46076 .13855 L
.46076 .16187 L
s
1 .894 .882 r
.46076 .16187 m
.46076 .13951 L
.46236 .13951 L
.46236 .16187 L
F
.804 .522 .247 r
.46076 .16187 m
.46076 .13951 L
.46236 .13951 L
.46236 .16187 L
s
1 .894 .882 r
.46236 .16187 m
.46236 .14 L
.46369 .14 L
.46369 .16187 L
F
.804 .522 .247 r
.46236 .16187 m
.46236 .14 L
.46369 .14 L
.46369 .16187 L
s
1 .894 .882 r
.46369 .16187 m
.46369 .14032 L
.46538 .14032 L
.46538 .16187 L
F
.804 .522 .247 r
.46369 .16187 m
.46369 .14032 L
.46538 .14032 L
.46538 .16187 L
s
1 .894 .882 r
.46538 .16187 m
.46538 .14162 L
.46622 .14162 L
.46622 .16187 L
F
.804 .522 .247 r
.46538 .16187 m
.46538 .14162 L
.46622 .14162 L
.46622 .16187 L
s
1 .894 .882 r
.46622 .16187 m
.46622 .14199 L
.4681 .14199 L
.4681 .16187 L
F
.804 .522 .247 r
.46622 .16187 m
.46622 .14199 L
.4681 .14199 L
.4681 .16187 L
s
1 .894 .882 r
.4681 .16187 m
.4681 .14296 L
.46879 .14296 L
.46879 .16187 L
F
.804 .522 .247 r
.4681 .16187 m
.4681 .14296 L
.46879 .14296 L
.46879 .16187 L
s
1 .894 .882 r
.46879 .16187 m
.46879 .14368 L
.4706 .14368 L
.4706 .16187 L
F
.804 .522 .247 r
.46879 .16187 m
.46879 .14368 L
.4706 .14368 L
.4706 .16187 L
s
1 .894 .882 r
.4706 .16187 m
.4706 .1447 L
.47151 .1447 L
.47151 .16187 L
F
.804 .522 .247 r
.4706 .16187 m
.4706 .1447 L
.47151 .1447 L
.47151 .16187 L
s
1 .894 .882 r
.47151 .16187 m
.47151 .14547 L
.47332 .14547 L
.47332 .16187 L
F
.804 .522 .247 r
.47151 .16187 m
.47151 .14547 L
.47332 .14547 L
.47332 .16187 L
s
1 .894 .882 r
.47332 .16187 m
.47332 .1461 L
.47424 .1461 L
.47424 .16187 L
F
.804 .522 .247 r
.47332 .16187 m
.47332 .1461 L
.47424 .1461 L
.47424 .16187 L
s
1 .894 .882 r
.47424 .16187 m
.47424 .1468 L
.47504 .1468 L
.47504 .16187 L
F
.804 .522 .247 r
.47424 .16187 m
.47424 .1468 L
.47504 .1468 L
.47504 .16187 L
s
1 .894 .882 r
.47504 .16187 m
.47504 .14687 L
.47592 .14687 L
.47592 .16187 L
F
.804 .522 .247 r
.47504 .16187 m
.47504 .14687 L
.47592 .14687 L
.47592 .16187 L
s
1 .894 .882 r
.47592 .16187 m
.47592 .14771 L
.47801 .14771 L
.47801 .16187 L
F
.804 .522 .247 r
.47592 .16187 m
.47592 .14771 L
.47801 .14771 L
.47801 .16187 L
s
1 .894 .882 r
.47801 .16187 m
.47801 .14877 L
.47891 .14877 L
.47891 .16187 L
F
.804 .522 .247 r
.47801 .16187 m
.47801 .14877 L
.47891 .14877 L
.47891 .16187 L
s
1 .894 .882 r
.47891 .16187 m
.47891 .15002 L
.48101 .15002 L
.48101 .16187 L
F
.804 .522 .247 r
.47891 .16187 m
.47891 .15002 L
.48101 .15002 L
.48101 .16187 L
s
1 .894 .882 r
.48101 .16187 m
.48101 .15099 L
.48228 .15099 L
.48228 .16187 L
F
.804 .522 .247 r
.48101 .16187 m
.48101 .15099 L
.48228 .15099 L
.48228 .16187 L
s
1 .894 .882 r
.48228 .16187 m
.48228 .1522 L
.48441 .1522 L
.48441 .16187 L
F
.804 .522 .247 r
.48228 .16187 m
.48228 .1522 L
.48441 .1522 L
.48441 .16187 L
s
1 .894 .882 r
.48441 .16187 m
.48441 .15316 L
.48594 .15316 L
.48594 .16187 L
F
.804 .522 .247 r
.48441 .16187 m
.48441 .15316 L
.48594 .15316 L
.48594 .16187 L
s
1 .894 .882 r
.48594 .16187 m
.48594 .15369 L
.48681 .15369 L
.48681 .16187 L
F
.804 .522 .247 r
.48594 .16187 m
.48594 .15369 L
.48681 .15369 L
.48681 .16187 L
s
1 .894 .882 r
.48681 .16187 m
.48681 .15454 L
.48828 .15454 L
.48828 .16187 L
F
.804 .522 .247 r
.48681 .16187 m
.48681 .15454 L
.48828 .15454 L
.48828 .16187 L
s
1 .894 .882 r
.48828 .16187 m
.48828 .15537 L
.48944 .15537 L
.48944 .16187 L
F
.804 .522 .247 r
.48828 .16187 m
.48828 .15537 L
.48944 .15537 L
.48944 .16187 L
s
1 .894 .882 r
.48944 .16187 m
.48944 .15609 L
.49082 .15609 L
.49082 .16187 L
F
.804 .522 .247 r
.48944 .16187 m
.48944 .15609 L
.49082 .15609 L
.49082 .16187 L
s
1 .894 .882 r
.49082 .16187 m
.49082 .15705 L
.49217 .15705 L
.49217 .16187 L
F
.804 .522 .247 r
.49082 .16187 m
.49082 .15705 L
.49217 .15705 L
.49217 .16187 L
s
1 .894 .882 r
.49217 .16187 m
.49217 .15787 L
.49356 .15787 L
.49356 .16187 L
F
.804 .522 .247 r
.49217 .16187 m
.49217 .15787 L
.49356 .15787 L
.49356 .16187 L
s
1 .894 .882 r
.49356 .16187 m
.49356 .15892 L
.4953 .15892 L
.4953 .16187 L
F
.804 .522 .247 r
.49356 .16187 m
.49356 .15892 L
.4953 .15892 L
.4953 .16187 L
s
1 .894 .882 r
.4953 .16187 m
.4953 .15905 L
.49599 .15905 L
.49599 .16187 L
F
.804 .522 .247 r
.4953 .16187 m
.4953 .15905 L
.49599 .15905 L
.49599 .16187 L
s
1 .894 .882 r
.49599 .16187 m
.49599 .16046 L
.49783 .16046 L
.49783 .16187 L
F
.804 .522 .247 r
.49599 .16187 m
.49599 .16046 L
.49783 .16046 L
.49783 .16187 L
s
1 .894 .882 r
.49783 .16187 m
.49783 .16066 L
.49902 .16066 L
.49902 .16187 L
F
.804 .522 .247 r
.49783 .16187 m
.49783 .16066 L
.49902 .16066 L
.49902 .16187 L
s
.678 .847 .902 r
.49902 .16187 m
.49902 .16216 L
.50106 .16216 L
.50106 .16187 L
F
.2 .63 .79 r
.49902 .16187 m
.49902 .16216 L
.50106 .16216 L
.50106 .16187 L
s
.678 .847 .902 r
.50106 .16187 m
.50106 .16285 L
.50171 .16285 L
.50171 .16187 L
F
.2 .63 .79 r
.50106 .16187 m
.50106 .16285 L
.50171 .16285 L
.50171 .16187 L
s
.678 .847 .902 r
.50171 .16187 m
.50171 .16313 L
.50239 .16313 L
.50239 .16187 L
F
.2 .63 .79 r
.50171 .16187 m
.50171 .16313 L
.50239 .16313 L
.50239 .16187 L
s
.678 .847 .902 r
.50239 .16187 m
.50239 .16355 L
.50333 .16355 L
.50333 .16187 L
F
.2 .63 .79 r
.50239 .16187 m
.50239 .16355 L
.50333 .16355 L
.50333 .16187 L
s
.678 .847 .902 r
.50333 .16187 m
.50333 .16397 L
.50421 .16397 L
.50421 .16187 L
F
.2 .63 .79 r
.50333 .16187 m
.50333 .16397 L
.50421 .16397 L
.50421 .16187 L
s
.678 .847 .902 r
.50421 .16187 m
.50421 .16486 L
.50611 .16486 L
.50611 .16187 L
F
.2 .63 .79 r
.50421 .16187 m
.50421 .16486 L
.50611 .16486 L
.50611 .16187 L
s
.678 .847 .902 r
.50611 .16187 m
.50611 .16642 L
.50817 .16642 L
.50817 .16187 L
F
.2 .63 .79 r
.50611 .16187 m
.50611 .16642 L
.50817 .16642 L
.50817 .16187 L
s
.678 .847 .902 r
.50817 .16187 m
.50817 .16709 L
.50888 .16709 L
.50888 .16187 L
F
.2 .63 .79 r
.50817 .16187 m
.50817 .16709 L
.50888 .16709 L
.50888 .16187 L
s
.678 .847 .902 r
.50888 .16187 m
.50888 .16788 L
.50984 .16788 L
.50984 .16187 L
F
.2 .63 .79 r
.50888 .16187 m
.50888 .16788 L
.50984 .16788 L
.50984 .16187 L
s
.678 .847 .902 r
.50984 .16187 m
.50984 .16903 L
.51149 .16903 L
.51149 .16187 L
F
.2 .63 .79 r
.50984 .16187 m
.50984 .16903 L
.51149 .16903 L
.51149 .16187 L
s
.678 .847 .902 r
.51149 .16187 m
.51149 .17022 L
.51363 .17022 L
.51363 .16187 L
F
.2 .63 .79 r
.51149 .16187 m
.51149 .17022 L
.51363 .17022 L
.51363 .16187 L
s
.678 .847 .902 r
.51363 .16187 m
.51363 .17088 L
.51525 .17088 L
.51525 .16187 L
F
.2 .63 .79 r
.51363 .16187 m
.51363 .17088 L
.51525 .17088 L
.51525 .16187 L
s
.678 .847 .902 r
.51525 .16187 m
.51525 .17203 L
.51624 .17203 L
.51624 .16187 L
F
.2 .63 .79 r
.51525 .16187 m
.51525 .17203 L
.51624 .17203 L
.51624 .16187 L
s
.678 .847 .902 r
.51624 .16187 m
.51624 .17215 L
.51702 .17215 L
.51702 .16187 L
F
.2 .63 .79 r
.51624 .16187 m
.51624 .17215 L
.51702 .17215 L
.51702 .16187 L
s
.678 .847 .902 r
.51702 .16187 m
.51702 .17271 L
.51894 .17271 L
.51894 .16187 L
F
.2 .63 .79 r
.51702 .16187 m
.51702 .17271 L
.51894 .17271 L
.51894 .16187 L
s
.678 .847 .902 r
.51894 .16187 m
.51894 .17414 L
.51974 .17414 L
.51974 .16187 L
F
.2 .63 .79 r
.51894 .16187 m
.51894 .17414 L
.51974 .17414 L
.51974 .16187 L
s
.678 .847 .902 r
.51974 .16187 m
.51974 .17559 L
.52175 .17559 L
.52175 .16187 L
F
.2 .63 .79 r
.51974 .16187 m
.51974 .17559 L
.52175 .17559 L
.52175 .16187 L
s
.678 .847 .902 r
.52175 .16187 m
.52175 .17594 L
.52332 .17594 L
.52332 .16187 L
F
.2 .63 .79 r
.52175 .16187 m
.52175 .17594 L
.52332 .17594 L
.52332 .16187 L
s
.678 .847 .902 r
.52332 .16187 m
.52332 .17674 L
.52454 .17674 L
.52454 .16187 L
F
.2 .63 .79 r
.52332 .16187 m
.52332 .17674 L
.52454 .17674 L
.52454 .16187 L
s
.678 .847 .902 r
.52454 .16187 m
.52454 .17815 L
.52613 .17815 L
.52613 .16187 L
F
.2 .63 .79 r
.52454 .16187 m
.52454 .17815 L
.52613 .17815 L
.52613 .16187 L
s
.678 .847 .902 r
.52613 .16187 m
.52613 .17848 L
.52705 .17848 L
.52705 .16187 L
F
.2 .63 .79 r
.52613 .16187 m
.52613 .17848 L
.52705 .17848 L
.52705 .16187 L
s
.678 .847 .902 r
.52705 .16187 m
.52705 .1792 L
.52858 .1792 L
.52858 .16187 L
F
.2 .63 .79 r
.52705 .16187 m
.52705 .1792 L
.52858 .1792 L
.52858 .16187 L
s
.678 .847 .902 r
.52858 .16187 m
.52858 .18026 L
.53014 .18026 L
.53014 .16187 L
F
.2 .63 .79 r
.52858 .16187 m
.52858 .18026 L
.53014 .18026 L
.53014 .16187 L
s
.678 .847 .902 r
.53014 .16187 m
.53014 .18144 L
.53118 .18144 L
.53118 .16187 L
F
.2 .63 .79 r
.53014 .16187 m
.53014 .18144 L
.53118 .18144 L
.53118 .16187 L
s
.678 .847 .902 r
.53118 .16187 m
.53118 .18199 L
.53224 .18199 L
.53224 .16187 L
F
.2 .63 .79 r
.53118 .16187 m
.53118 .18199 L
.53224 .18199 L
.53224 .16187 L
s
.678 .847 .902 r
.53224 .16187 m
.53224 .18281 L
.53377 .18281 L
.53377 .16187 L
F
.2 .63 .79 r
.53224 .16187 m
.53224 .18281 L
.53377 .18281 L
.53377 .16187 L
s
.678 .847 .902 r
.53377 .16187 m
.53377 .1842 L
.5353 .1842 L
.5353 .16187 L
F
.2 .63 .79 r
.53377 .16187 m
.53377 .1842 L
.5353 .1842 L
.5353 .16187 L
s
.678 .847 .902 r
.5353 .16187 m
.5353 .18458 L
.53605 .18458 L
.53605 .16187 L
F
.2 .63 .79 r
.5353 .16187 m
.5353 .18458 L
.53605 .18458 L
.53605 .16187 L
s
.678 .847 .902 r
.53605 .16187 m
.53605 .18513 L
.53689 .18513 L
.53689 .16187 L
F
.2 .63 .79 r
.53605 .16187 m
.53605 .18513 L
.53689 .18513 L
.53689 .16187 L
s
.678 .847 .902 r
.53689 .16187 m
.53689 .18557 L
.53868 .18557 L
.53868 .16187 L
F
.2 .63 .79 r
.53689 .16187 m
.53689 .18557 L
.53868 .18557 L
.53868 .16187 L
s
.678 .847 .902 r
.53868 .16187 m
.53868 .18689 L
.54033 .18689 L
.54033 .16187 L
F
.2 .63 .79 r
.53868 .16187 m
.53868 .18689 L
.54033 .18689 L
.54033 .16187 L
s
.678 .847 .902 r
.54033 .16187 m
.54033 .18826 L
.54103 .18826 L
.54103 .16187 L
F
.2 .63 .79 r
.54033 .16187 m
.54033 .18826 L
.54103 .18826 L
.54103 .16187 L
s
.678 .847 .902 r
.54103 .16187 m
.54103 .18897 L
.54307 .18897 L
.54307 .16187 L
F
.2 .63 .79 r
.54103 .16187 m
.54103 .18897 L
.54307 .18897 L
.54307 .16187 L
s
.678 .847 .902 r
.54307 .16187 m
.54307 .18971 L
.54387 .18971 L
.54387 .16187 L
F
.2 .63 .79 r
.54307 .16187 m
.54307 .18971 L
.54387 .18971 L
.54387 .16187 L
s
.678 .847 .902 r
.54387 .16187 m
.54387 .19054 L
.54556 .19054 L
.54556 .16187 L
F
.2 .63 .79 r
.54387 .16187 m
.54387 .19054 L
.54556 .19054 L
.54556 .16187 L
s
.678 .847 .902 r
.54556 .16187 m
.54556 .19173 L
.54681 .19173 L
.54681 .16187 L
F
.2 .63 .79 r
.54556 .16187 m
.54556 .19173 L
.54681 .19173 L
.54681 .16187 L
s
.678 .847 .902 r
.54681 .16187 m
.54681 .19286 L
.54851 .19286 L
.54851 .16187 L
F
.2 .63 .79 r
.54681 .16187 m
.54681 .19286 L
.54851 .19286 L
.54851 .16187 L
s
.678 .847 .902 r
.54851 .16187 m
.54851 .19379 L
.54919 .19379 L
.54919 .16187 L
F
.2 .63 .79 r
.54851 .16187 m
.54851 .19379 L
.54919 .19379 L
.54919 .16187 L
s
.678 .847 .902 r
.54919 .16187 m
.54919 .19404 L
.55112 .19404 L
.55112 .16187 L
F
.2 .63 .79 r
.54919 .16187 m
.54919 .19404 L
.55112 .19404 L
.55112 .16187 L
s
.678 .847 .902 r
.55112 .16187 m
.55112 .19574 L
.55223 .19574 L
.55223 .16187 L
F
.2 .63 .79 r
.55112 .16187 m
.55112 .19574 L
.55223 .19574 L
.55223 .16187 L
s
.678 .847 .902 r
.55223 .16187 m
.55223 .19664 L
.5541 .19664 L
.5541 .16187 L
F
.2 .63 .79 r
.55223 .16187 m
.55223 .19664 L
.5541 .19664 L
.5541 .16187 L
s
.678 .847 .902 r
.5541 .16187 m
.5541 .19771 L
.55537 .19771 L
.55537 .16187 L
F
.2 .63 .79 r
.5541 .16187 m
.5541 .19771 L
.55537 .19771 L
.55537 .16187 L
s
.678 .847 .902 r
.55537 .16187 m
.55537 .1981 L
.55674 .1981 L
.55674 .16187 L
F
.2 .63 .79 r
.55537 .16187 m
.55537 .1981 L
.55674 .1981 L
.55674 .16187 L
s
.678 .847 .902 r
.55674 .16187 m
.55674 .1991 L
.55843 .1991 L
.55843 .16187 L
F
.2 .63 .79 r
.55674 .16187 m
.55674 .1991 L
.55843 .1991 L
.55843 .16187 L
s
.678 .847 .902 r
.55843 .16187 m
.55843 .20079 L
.56003 .20079 L
.56003 .16187 L
F
.2 .63 .79 r
.55843 .16187 m
.55843 .20079 L
.56003 .20079 L
.56003 .16187 L
s
.678 .847 .902 r
.56003 .16187 m
.56003 .20189 L
.56195 .20189 L
.56195 .16187 L
F
.2 .63 .79 r
.56003 .16187 m
.56003 .20189 L
.56195 .20189 L
.56195 .16187 L
s
.678 .847 .902 r
.56195 .16187 m
.56195 .20378 L
.56393 .20378 L
.56393 .16187 L
F
.2 .63 .79 r
.56195 .16187 m
.56195 .20378 L
.56393 .20378 L
.56393 .16187 L
s
.678 .847 .902 r
.56393 .16187 m
.56393 .20453 L
.56523 .20453 L
.56523 .16187 L
F
.2 .63 .79 r
.56393 .16187 m
.56393 .20453 L
.56523 .20453 L
.56523 .16187 L
s
.678 .847 .902 r
.56523 .16187 m
.56523 .20513 L
.56643 .20513 L
.56643 .16187 L
F
.2 .63 .79 r
.56523 .16187 m
.56523 .20513 L
.56643 .20513 L
.56643 .16187 L
s
.678 .847 .902 r
.56643 .16187 m
.56643 .20585 L
.56747 .20585 L
.56747 .16187 L
F
.2 .63 .79 r
.56643 .16187 m
.56643 .20585 L
.56747 .20585 L
.56747 .16187 L
s
.678 .847 .902 r
.56747 .16187 m
.56747 .2066 L
.56857 .2066 L
.56857 .16187 L
F
.2 .63 .79 r
.56747 .16187 m
.56747 .2066 L
.56857 .2066 L
.56857 .16187 L
s
.678 .847 .902 r
.56857 .16187 m
.56857 .2076 L
.56977 .2076 L
.56977 .16187 L
F
.2 .63 .79 r
.56857 .16187 m
.56857 .2076 L
.56977 .2076 L
.56977 .16187 L
s
.678 .847 .902 r
.56977 .16187 m
.56977 .20884 L
.57078 .20884 L
.57078 .16187 L
F
.2 .63 .79 r
.56977 .16187 m
.56977 .20884 L
.57078 .20884 L
.57078 .16187 L
s
.678 .847 .902 r
.57078 .16187 m
.57078 .20894 L
.57221 .20894 L
.57221 .16187 L
F
.2 .63 .79 r
.57078 .16187 m
.57078 .20894 L
.57221 .20894 L
.57221 .16187 L
s
.678 .847 .902 r
.57221 .16187 m
.57221 .211 L
.57383 .211 L
.57383 .16187 L
F
.2 .63 .79 r
.57221 .16187 m
.57221 .211 L
.57383 .211 L
.57383 .16187 L
s
.678 .847 .902 r
.57383 .16187 m
.57383 .21142 L
.57498 .21142 L
.57498 .16187 L
F
.2 .63 .79 r
.57383 .16187 m
.57383 .21142 L
.57498 .21142 L
.57498 .16187 L
s
.678 .847 .902 r
.57498 .16187 m
.57498 .21225 L
.57613 .21225 L
.57613 .16187 L
F
.2 .63 .79 r
.57498 .16187 m
.57498 .21225 L
.57613 .21225 L
.57613 .16187 L
s
.678 .847 .902 r
.57613 .16187 m
.57613 .2127 L
.5774 .2127 L
.5774 .16187 L
F
.2 .63 .79 r
.57613 .16187 m
.57613 .2127 L
.5774 .2127 L
.5774 .16187 L
s
.678 .847 .902 r
.5774 .16187 m
.5774 .21466 L
.57951 .21466 L
.57951 .16187 L
F
.2 .63 .79 r
.5774 .16187 m
.5774 .21466 L
.57951 .21466 L
.57951 .16187 L
s
.678 .847 .902 r
.57951 .16187 m
.57951 .21517 L
.58159 .21517 L
.58159 .16187 L
F
.2 .63 .79 r
.57951 .16187 m
.57951 .21517 L
.58159 .21517 L
.58159 .16187 L
s
.678 .847 .902 r
.58159 .16187 m
.58159 .2177 L
.5832 .2177 L
.5832 .16187 L
F
.2 .63 .79 r
.58159 .16187 m
.58159 .2177 L
.5832 .2177 L
.5832 .16187 L
s
.678 .847 .902 r
.5832 .16187 m
.5832 .2179 L
.58446 .2179 L
.58446 .16187 L
F
.2 .63 .79 r
.5832 .16187 m
.5832 .2179 L
.58446 .2179 L
.58446 .16187 L
s
.678 .847 .902 r
.58446 .16187 m
.58446 .21902 L
.58528 .21902 L
.58528 .16187 L
F
.2 .63 .79 r
.58446 .16187 m
.58446 .21902 L
.58528 .21902 L
.58528 .16187 L
s
.678 .847 .902 r
.58528 .16187 m
.58528 .21961 L
.58691 .21961 L
.58691 .16187 L
F
.2 .63 .79 r
.58528 .16187 m
.58528 .21961 L
.58691 .21961 L
.58691 .16187 L
s
.678 .847 .902 r
.58691 .16187 m
.58691 .22099 L
.58883 .22099 L
.58883 .16187 L
F
.2 .63 .79 r
.58691 .16187 m
.58691 .22099 L
.58883 .22099 L
.58883 .16187 L
s
.678 .847 .902 r
.58883 .16187 m
.58883 .22274 L
.59098 .22274 L
.59098 .16187 L
F
.2 .63 .79 r
.58883 .16187 m
.58883 .22274 L
.59098 .22274 L
.59098 .16187 L
s
.678 .847 .902 r
.59098 .16187 m
.59098 .2241 L
.59261 .2241 L
.59261 .16187 L
F
.2 .63 .79 r
.59098 .16187 m
.59098 .2241 L
.59261 .2241 L
.59261 .16187 L
s
.678 .847 .902 r
.59261 .16187 m
.59261 .22498 L
.59472 .22498 L
.59472 .16187 L
F
.2 .63 .79 r
.59261 .16187 m
.59261 .22498 L
.59472 .22498 L
.59472 .16187 L
s
.678 .847 .902 r
.59472 .16187 m
.59472 .22682 L
.59569 .22682 L
.59569 .16187 L
F
.2 .63 .79 r
.59472 .16187 m
.59472 .22682 L
.59569 .22682 L
.59569 .16187 L
s
.678 .847 .902 r
.59569 .16187 m
.59569 .22701 L
.59657 .22701 L
.59657 .16187 L
F
.2 .63 .79 r
.59569 .16187 m
.59569 .22701 L
.59657 .22701 L
.59657 .16187 L
s
.678 .847 .902 r
.59657 .16187 m
.59657 .22857 L
.5984 .22857 L
.5984 .16187 L
F
.2 .63 .79 r
.59657 .16187 m
.59657 .22857 L
.5984 .22857 L
.5984 .16187 L
s
.678 .847 .902 r
.5984 .16187 m
.5984 .22968 L
.59985 .22968 L
.59985 .16187 L
F
.2 .63 .79 r
.5984 .16187 m
.5984 .22968 L
.59985 .22968 L
.59985 .16187 L
s
.678 .847 .902 r
.59985 .16187 m
.59985 .23093 L
.6018 .23093 L
.6018 .16187 L
F
.2 .63 .79 r
.59985 .16187 m
.59985 .23093 L
.6018 .23093 L
.6018 .16187 L
s
.678 .847 .902 r
.6018 .16187 m
.6018 .23153 L
.60381 .23153 L
.60381 .16187 L
F
.2 .63 .79 r
.6018 .16187 m
.6018 .23153 L
.60381 .23153 L
.60381 .16187 L
s
.678 .847 .902 r
.60381 .16187 m
.60381 .23365 L
.60519 .23365 L
.60519 .16187 L
F
.2 .63 .79 r
.60381 .16187 m
.60381 .23365 L
.60519 .23365 L
.60519 .16187 L
s
.678 .847 .902 r
.60519 .16187 m
.60519 .23427 L
.60611 .23427 L
.60611 .16187 L
F
.2 .63 .79 r
.60519 .16187 m
.60519 .23427 L
.60611 .23427 L
.60611 .16187 L
s
.678 .847 .902 r
.60611 .16187 m
.60611 .23552 L
.60769 .23552 L
.60769 .16187 L
F
.2 .63 .79 r
.60611 .16187 m
.60611 .23552 L
.60769 .23552 L
.60769 .16187 L
s
.678 .847 .902 r
.60769 .16187 m
.60769 .23683 L
.60893 .23683 L
.60893 .16187 L
F
.2 .63 .79 r
.60769 .16187 m
.60769 .23683 L
.60893 .23683 L
.60893 .16187 L
s
.678 .847 .902 r
.60893 .16187 m
.60893 .23782 L
.61086 .23782 L
.61086 .16187 L
F
.2 .63 .79 r
.60893 .16187 m
.60893 .23782 L
.61086 .23782 L
.61086 .16187 L
s
.678 .847 .902 r
.61086 .16187 m
.61086 .23958 L
.61279 .23958 L
.61279 .16187 L
F
.2 .63 .79 r
.61086 .16187 m
.61086 .23958 L
.61279 .23958 L
.61279 .16187 L
s
.678 .847 .902 r
.61279 .16187 m
.61279 .23997 L
.61389 .23997 L
.61389 .16187 L
F
.2 .63 .79 r
.61279 .16187 m
.61279 .23997 L
.61389 .23997 L
.61389 .16187 L
s
.678 .847 .902 r
.61389 .16187 m
.61389 .24216 L
.61602 .24216 L
.61602 .16187 L
F
.2 .63 .79 r
.61389 .16187 m
.61389 .24216 L
.61602 .24216 L
.61602 .16187 L
s
.678 .847 .902 r
.61602 .16187 m
.61602 .24374 L
.61802 .24374 L
.61802 .16187 L
F
.2 .63 .79 r
.61602 .16187 m
.61602 .24374 L
.61802 .24374 L
.61802 .16187 L
s
.678 .847 .902 r
.61802 .16187 m
.61802 .24507 L
.62005 .24507 L
.62005 .16187 L
F
.2 .63 .79 r
.61802 .16187 m
.61802 .24507 L
.62005 .24507 L
.62005 .16187 L
s
.678 .847 .902 r
.62005 .16187 m
.62005 .2457 L
.6217 .2457 L
.6217 .16187 L
F
.2 .63 .79 r
.62005 .16187 m
.62005 .2457 L
.6217 .2457 L
.6217 .16187 L
s
.678 .847 .902 r
.6217 .16187 m
.6217 .24762 L
.62323 .24762 L
.62323 .16187 L
F
.2 .63 .79 r
.6217 .16187 m
.6217 .24762 L
.62323 .24762 L
.62323 .16187 L
s
.678 .847 .902 r
.62323 .16187 m
.62323 .24842 L
.62506 .24842 L
.62506 .16187 L
F
.2 .63 .79 r
.62323 .16187 m
.62323 .24842 L
.62506 .24842 L
.62506 .16187 L
s
.678 .847 .902 r
.62506 .16187 m
.62506 .24973 L
.62611 .24973 L
.62611 .16187 L
F
.2 .63 .79 r
.62506 .16187 m
.62506 .24973 L
.62611 .24973 L
.62611 .16187 L
s
.678 .847 .902 r
.62611 .16187 m
.62611 .25143 L
.62803 .25143 L
.62803 .16187 L
F
.2 .63 .79 r
.62611 .16187 m
.62611 .25143 L
.62803 .25143 L
.62803 .16187 L
s
.678 .847 .902 r
.62803 .16187 m
.62803 .25192 L
.62958 .25192 L
.62958 .16187 L
F
.2 .63 .79 r
.62803 .16187 m
.62803 .25192 L
.62958 .25192 L
.62958 .16187 L
s
.678 .847 .902 r
.62958 .16187 m
.62958 .25341 L
.63042 .25341 L
.63042 .16187 L
F
.2 .63 .79 r
.62958 .16187 m
.62958 .25341 L
.63042 .25341 L
.63042 .16187 L
s
.678 .847 .902 r
.63042 .16187 m
.63042 .25379 L
.63154 .25379 L
.63154 .16187 L
F
.2 .63 .79 r
.63042 .16187 m
.63042 .25379 L
.63154 .25379 L
.63154 .16187 L
s
.678 .847 .902 r
.63154 .16187 m
.63154 .25445 L
.63314 .25445 L
.63314 .16187 L
F
.2 .63 .79 r
.63154 .16187 m
.63154 .25445 L
.63314 .25445 L
.63314 .16187 L
s
.678 .847 .902 r
.63314 .16187 m
.63314 .25579 L
.63446 .25579 L
.63446 .16187 L
F
.2 .63 .79 r
.63314 .16187 m
.63314 .25579 L
.63446 .25579 L
.63446 .16187 L
s
.678 .847 .902 r
.63446 .16187 m
.63446 .25683 L
.63565 .25683 L
.63565 .16187 L
F
.2 .63 .79 r
.63446 .16187 m
.63446 .25683 L
.63565 .25683 L
.63565 .16187 L
s
.678 .847 .902 r
.63565 .16187 m
.63565 .2586 L
.63749 .2586 L
.63749 .16187 L
F
.2 .63 .79 r
.63565 .16187 m
.63565 .2586 L
.63749 .2586 L
.63749 .16187 L
s
.678 .847 .902 r
.63749 .16187 m
.63749 .25974 L
.63931 .25974 L
.63931 .16187 L
F
.2 .63 .79 r
.63749 .16187 m
.63749 .25974 L
.63931 .25974 L
.63931 .16187 L
s
.678 .847 .902 r
.63931 .16187 m
.63931 .2607 L
.6408 .2607 L
.6408 .16187 L
F
.2 .63 .79 r
.63931 .16187 m
.63931 .2607 L
.6408 .2607 L
.6408 .16187 L
s
.678 .847 .902 r
.6408 .16187 m
.6408 .26259 L
.64278 .26259 L
.64278 .16187 L
F
.2 .63 .79 r
.6408 .16187 m
.6408 .26259 L
.64278 .26259 L
.64278 .16187 L
s
.678 .847 .902 r
.64278 .16187 m
.64278 .26379 L
.64436 .26379 L
.64436 .16187 L
F
.2 .63 .79 r
.64278 .16187 m
.64278 .26379 L
.64436 .26379 L
.64436 .16187 L
s
.678 .847 .902 r
.64436 .16187 m
.64436 .26517 L
.64524 .26517 L
.64524 .16187 L
F
.2 .63 .79 r
.64436 .16187 m
.64436 .26517 L
.64524 .26517 L
.64524 .16187 L
s
.678 .847 .902 r
.64524 .16187 m
.64524 .26545 L
.64615 .26545 L
.64615 .16187 L
F
.2 .63 .79 r
.64524 .16187 m
.64524 .26545 L
.64615 .26545 L
.64615 .16187 L
s
.678 .847 .902 r
.64615 .16187 m
.64615 .26655 L
.64684 .26655 L
.64684 .16187 L
F
.2 .63 .79 r
.64615 .16187 m
.64615 .26655 L
.64684 .26655 L
.64684 .16187 L
s
.678 .847 .902 r
.64684 .16187 m
.64684 .2674 L
.64866 .2674 L
.64866 .16187 L
F
.2 .63 .79 r
.64684 .16187 m
.64684 .2674 L
.64866 .2674 L
.64866 .16187 L
s
.678 .847 .902 r
.64866 .16187 m
.64866 .2691 L
.65063 .2691 L
.65063 .16187 L
F
.2 .63 .79 r
.64866 .16187 m
.64866 .2691 L
.65063 .2691 L
.65063 .16187 L
s
.678 .847 .902 r
.65063 .16187 m
.65063 .2699 L
.65158 .2699 L
.65158 .16187 L
F
.2 .63 .79 r
.65063 .16187 m
.65063 .2699 L
.65158 .2699 L
.65158 .16187 L
s
.678 .847 .902 r
.65158 .16187 m
.65158 .27114 L
.65244 .27114 L
.65244 .16187 L
F
.2 .63 .79 r
.65158 .16187 m
.65158 .27114 L
.65244 .27114 L
.65244 .16187 L
s
.678 .847 .902 r
.65244 .16187 m
.65244 .27237 L
.65441 .27237 L
.65441 .16187 L
F
.2 .63 .79 r
.65244 .16187 m
.65244 .27237 L
.65441 .27237 L
.65441 .16187 L
s
.678 .847 .902 r
.65441 .16187 m
.65441 .27309 L
.65537 .27309 L
.65537 .16187 L
F
.2 .63 .79 r
.65441 .16187 m
.65441 .27309 L
.65537 .27309 L
.65537 .16187 L
s
.678 .847 .902 r
.65537 .16187 m
.65537 .2742 L
.65697 .2742 L
.65697 .16187 L
F
.2 .63 .79 r
.65537 .16187 m
.65537 .2742 L
.65697 .2742 L
.65697 .16187 L
s
.678 .847 .902 r
.65697 .16187 m
.65697 .27545 L
.65818 .27545 L
.65818 .16187 L
F
.2 .63 .79 r
.65697 .16187 m
.65697 .27545 L
.65818 .27545 L
.65818 .16187 L
s
.678 .847 .902 r
.65818 .16187 m
.65818 .27617 L
.65974 .27617 L
.65974 .16187 L
F
.2 .63 .79 r
.65818 .16187 m
.65818 .27617 L
.65974 .27617 L
.65974 .16187 L
s
.678 .847 .902 r
.65974 .16187 m
.65974 .2777 L
.66097 .2777 L
.66097 .16187 L
F
.2 .63 .79 r
.65974 .16187 m
.65974 .2777 L
.66097 .2777 L
.66097 .16187 L
s
.678 .847 .902 r
.66097 .16187 m
.66097 .27831 L
.66166 .27831 L
.66166 .16187 L
F
.2 .63 .79 r
.66097 .16187 m
.66097 .27831 L
.66166 .27831 L
.66166 .16187 L
s
.678 .847 .902 r
.66166 .16187 m
.66166 .27936 L
.66268 .27936 L
.66268 .16187 L
F
.2 .63 .79 r
.66166 .16187 m
.66166 .27936 L
.66268 .27936 L
.66268 .16187 L
s
.678 .847 .902 r
.66268 .16187 m
.66268 .28042 L
.66378 .28042 L
.66378 .16187 L
F
.2 .63 .79 r
.66268 .16187 m
.66268 .28042 L
.66378 .28042 L
.66378 .16187 L
s
.678 .847 .902 r
.66378 .16187 m
.66378 .28124 L
.66558 .28124 L
.66558 .16187 L
F
.2 .63 .79 r
.66378 .16187 m
.66378 .28124 L
.66558 .28124 L
.66558 .16187 L
s
.678 .847 .902 r
.66558 .16187 m
.66558 .28215 L
.66712 .28215 L
.66712 .16187 L
F
.2 .63 .79 r
.66558 .16187 m
.66558 .28215 L
.66712 .28215 L
.66712 .16187 L
s
.678 .847 .902 r
.66712 .16187 m
.66712 .28428 L
.66913 .28428 L
.66913 .16187 L
F
.2 .63 .79 r
.66712 .16187 m
.66712 .28428 L
.66913 .28428 L
.66913 .16187 L
s
.678 .847 .902 r
.66913 .16187 m
.66913 .28527 L
.67056 .28527 L
.67056 .16187 L
F
.2 .63 .79 r
.66913 .16187 m
.66913 .28527 L
.67056 .28527 L
.67056 .16187 L
s
.678 .847 .902 r
.67056 .16187 m
.67056 .28627 L
.67272 .28627 L
.67272 .16187 L
F
.2 .63 .79 r
.67056 .16187 m
.67056 .28627 L
.67272 .28627 L
.67272 .16187 L
s
.678 .847 .902 r
.67272 .16187 m
.67272 .28856 L
.67342 .28856 L
.67342 .16187 L
F
.2 .63 .79 r
.67272 .16187 m
.67272 .28856 L
.67342 .28856 L
.67342 .16187 L
s
.678 .847 .902 r
.67342 .16187 m
.67342 .2886 L
.6741 .2886 L
.6741 .16187 L
F
.2 .63 .79 r
.67342 .16187 m
.67342 .2886 L
.6741 .2886 L
.6741 .16187 L
s
.678 .847 .902 r
.6741 .16187 m
.6741 .29068 L
.67613 .29068 L
.67613 .16187 L
F
.2 .63 .79 r
.6741 .16187 m
.6741 .29068 L
.67613 .29068 L
.67613 .16187 L
s
.678 .847 .902 r
.67613 .16187 m
.67613 .29129 L
.67805 .29129 L
.67805 .16187 L
F
.2 .63 .79 r
.67613 .16187 m
.67613 .29129 L
.67805 .29129 L
.67805 .16187 L
s
.678 .847 .902 r
.67805 .16187 m
.67805 .29385 L
.68002 .29385 L
.68002 .16187 L
F
.2 .63 .79 r
.67805 .16187 m
.67805 .29385 L
.68002 .29385 L
.68002 .16187 L
s
.678 .847 .902 r
.68002 .16187 m
.68002 .29448 L
.68218 .29448 L
.68218 .16187 L
F
.2 .63 .79 r
.68002 .16187 m
.68002 .29448 L
.68218 .29448 L
.68218 .16187 L
s
.678 .847 .902 r
.68218 .16187 m
.68218 .29627 L
.68304 .29627 L
.68304 .16187 L
F
.2 .63 .79 r
.68218 .16187 m
.68218 .29627 L
.68304 .29627 L
.68304 .16187 L
s
.678 .847 .902 r
.68304 .16187 m
.68304 .29789 L
.68517 .29789 L
.68517 .16187 L
F
.2 .63 .79 r
.68304 .16187 m
.68304 .29789 L
.68517 .29789 L
.68517 .16187 L
s
.678 .847 .902 r
.68517 .16187 m
.68517 .29934 L
.68684 .29934 L
.68684 .16187 L
F
.2 .63 .79 r
.68517 .16187 m
.68517 .29934 L
.68684 .29934 L
.68684 .16187 L
s
.678 .847 .902 r
.68684 .16187 m
.68684 .30034 L
.6888 .30034 L
.6888 .16187 L
F
.2 .63 .79 r
.68684 .16187 m
.68684 .30034 L
.6888 .30034 L
.6888 .16187 L
s
.678 .847 .902 r
.6888 .16187 m
.6888 .30225 L
.68986 .30225 L
.68986 .16187 L
F
.2 .63 .79 r
.6888 .16187 m
.6888 .30225 L
.68986 .30225 L
.68986 .16187 L
s
.678 .847 .902 r
.68986 .16187 m
.68986 .30296 L
.69167 .30296 L
.69167 .16187 L
F
.2 .63 .79 r
.68986 .16187 m
.68986 .30296 L
.69167 .30296 L
.69167 .16187 L
s
.678 .847 .902 r
.69167 .16187 m
.69167 .3042 L
.6924 .3042 L
.6924 .16187 L
F
.2 .63 .79 r
.69167 .16187 m
.69167 .3042 L
.6924 .3042 L
.6924 .16187 L
s
.678 .847 .902 r
.6924 .16187 m
.6924 .30555 L
.6938 .30555 L
.6938 .16187 L
F
.2 .63 .79 r
.6924 .16187 m
.6924 .30555 L
.6938 .30555 L
.6938 .16187 L
s
.678 .847 .902 r
.6938 .16187 m
.6938 .30657 L
.69547 .30657 L
.69547 .16187 L
F
.2 .63 .79 r
.6938 .16187 m
.6938 .30657 L
.69547 .30657 L
.69547 .16187 L
s
.678 .847 .902 r
.69547 .16187 m
.69547 .30822 L
.69671 .30822 L
.69671 .16187 L
F
.2 .63 .79 r
.69547 .16187 m
.69547 .30822 L
.69671 .30822 L
.69671 .16187 L
s
.678 .847 .902 r
.69671 .16187 m
.69671 .30903 L
.6974 .30903 L
.6974 .16187 L
F
.2 .63 .79 r
.69671 .16187 m
.69671 .30903 L
.6974 .30903 L
.6974 .16187 L
s
.678 .847 .902 r
.6974 .16187 m
.6974 .30995 L
.69843 .30995 L
.69843 .16187 L
F
.2 .63 .79 r
.6974 .16187 m
.6974 .30995 L
.69843 .30995 L
.69843 .16187 L
s
.678 .847 .902 r
.69843 .16187 m
.69843 .31055 L
.69965 .31055 L
.69965 .16187 L
F
.2 .63 .79 r
.69843 .16187 m
.69843 .31055 L
.69965 .31055 L
.69965 .16187 L
s
.678 .847 .902 r
.69965 .16187 m
.69965 .3114 L
.70127 .3114 L
.70127 .16187 L
F
.2 .63 .79 r
.69965 .16187 m
.69965 .3114 L
.70127 .3114 L
.70127 .16187 L
s
.678 .847 .902 r
.70127 .16187 m
.70127 .31333 L
.70259 .31333 L
.70259 .16187 L
F
.2 .63 .79 r
.70127 .16187 m
.70127 .31333 L
.70259 .31333 L
.70259 .16187 L
s
.678 .847 .902 r
.70259 .16187 m
.70259 .31401 L
.70379 .31401 L
.70379 .16187 L
F
.2 .63 .79 r
.70259 .16187 m
.70259 .31401 L
.70379 .31401 L
.70379 .16187 L
s
.678 .847 .902 r
.70379 .16187 m
.70379 .31511 L
.70575 .31511 L
.70575 .16187 L
F
.2 .63 .79 r
.70379 .16187 m
.70379 .31511 L
.70575 .31511 L
.70575 .16187 L
s
.678 .847 .902 r
.70575 .16187 m
.70575 .31669 L
.70738 .31669 L
.70738 .16187 L
F
.2 .63 .79 r
.70575 .16187 m
.70575 .31669 L
.70738 .31669 L
.70738 .16187 L
s
.678 .847 .902 r
.70738 .16187 m
.70738 .31871 L
.70865 .31871 L
.70865 .16187 L
F
.2 .63 .79 r
.70738 .16187 m
.70738 .31871 L
.70865 .31871 L
.70865 .16187 L
s
.678 .847 .902 r
.70865 .16187 m
.70865 .3193 L
.70982 .3193 L
.70982 .16187 L
F
.2 .63 .79 r
.70865 .16187 m
.70865 .3193 L
.70982 .3193 L
.70982 .16187 L
s
.678 .847 .902 r
.70982 .16187 m
.70982 .32066 L
.71194 .32066 L
.71194 .16187 L
F
.2 .63 .79 r
.70982 .16187 m
.70982 .32066 L
.71194 .32066 L
.71194 .16187 L
s
.678 .847 .902 r
.71194 .16187 m
.71194 .32343 L
.71381 .32343 L
.71381 .16187 L
F
.2 .63 .79 r
.71194 .16187 m
.71194 .32343 L
.71381 .32343 L
.71381 .16187 L
s
.678 .847 .902 r
.71381 .16187 m
.71381 .32482 L
.71529 .32482 L
.71529 .16187 L
F
.2 .63 .79 r
.71381 .16187 m
.71381 .32482 L
.71529 .32482 L
.71529 .16187 L
s
.678 .847 .902 r
.71529 .16187 m
.71529 .32504 L
.71647 .32504 L
.71647 .16187 L
F
.2 .63 .79 r
.71529 .16187 m
.71529 .32504 L
.71647 .32504 L
.71647 .16187 L
s
.678 .847 .902 r
.71647 .16187 m
.71647 .32765 L
.71838 .32765 L
.71838 .16187 L
F
.2 .63 .79 r
.71647 .16187 m
.71647 .32765 L
.71838 .32765 L
.71838 .16187 L
s
.678 .847 .902 r
.71838 .16187 m
.71838 .32816 L
.72029 .32816 L
.72029 .16187 L
F
.2 .63 .79 r
.71838 .16187 m
.71838 .32816 L
.72029 .32816 L
.72029 .16187 L
s
.678 .847 .902 r
.72029 .16187 m
.72029 .33008 L
.72228 .33008 L
.72228 .16187 L
F
.2 .63 .79 r
.72029 .16187 m
.72029 .33008 L
.72228 .33008 L
.72228 .16187 L
s
.678 .847 .902 r
.72228 .16187 m
.72228 .33236 L
.72367 .33236 L
.72367 .16187 L
F
.2 .63 .79 r
.72228 .16187 m
.72228 .33236 L
.72367 .33236 L
.72367 .16187 L
s
.678 .847 .902 r
.72367 .16187 m
.72367 .33299 L
.72518 .33299 L
.72518 .16187 L
F
.2 .63 .79 r
.72367 .16187 m
.72367 .33299 L
.72518 .33299 L
.72518 .16187 L
s
.678 .847 .902 r
.72518 .16187 m
.72518 .33461 L
.72593 .33461 L
.72593 .16187 L
F
.2 .63 .79 r
.72518 .16187 m
.72518 .33461 L
.72593 .33461 L
.72593 .16187 L
s
.678 .847 .902 r
.72593 .16187 m
.72593 .33508 L
.72783 .33508 L
.72783 .16187 L
F
.2 .63 .79 r
.72593 .16187 m
.72593 .33508 L
.72783 .33508 L
.72783 .16187 L
s
.678 .847 .902 r
.72783 .16187 m
.72783 .33649 L
.72849 .33649 L
.72849 .16187 L
F
.2 .63 .79 r
.72783 .16187 m
.72783 .33649 L
.72849 .33649 L
.72849 .16187 L
s
.678 .847 .902 r
.72849 .16187 m
.72849 .33865 L
.7305 .33865 L
.7305 .16187 L
F
.2 .63 .79 r
.72849 .16187 m
.72849 .33865 L
.7305 .33865 L
.7305 .16187 L
s
.678 .847 .902 r
.7305 .16187 m
.7305 .33926 L
.73217 .33926 L
.73217 .16187 L
F
.2 .63 .79 r
.7305 .16187 m
.7305 .33926 L
.73217 .33926 L
.73217 .16187 L
s
.678 .847 .902 r
.73217 .16187 m
.73217 .34114 L
.73405 .34114 L
.73405 .16187 L
F
.2 .63 .79 r
.73217 .16187 m
.73217 .34114 L
.73405 .34114 L
.73405 .16187 L
s
.678 .847 .902 r
.73405 .16187 m
.73405 .34261 L
.73584 .34261 L
.73584 .16187 L
F
.2 .63 .79 r
.73405 .16187 m
.73405 .34261 L
.73584 .34261 L
.73584 .16187 L
s
.678 .847 .902 r
.73584 .16187 m
.73584 .34433 L
.73728 .34433 L
.73728 .16187 L
F
.2 .63 .79 r
.73584 .16187 m
.73584 .34433 L
.73728 .34433 L
.73728 .16187 L
s
.678 .847 .902 r
.73728 .16187 m
.73728 .34512 L
.738 .34512 L
.738 .16187 L
F
.2 .63 .79 r
.73728 .16187 m
.73728 .34512 L
.738 .34512 L
.738 .16187 L
s
.678 .847 .902 r
.738 .16187 m
.738 .34659 L
.7392 .34659 L
.7392 .16187 L
F
.2 .63 .79 r
.738 .16187 m
.738 .34659 L
.7392 .34659 L
.7392 .16187 L
s
.678 .847 .902 r
.7392 .16187 m
.7392 .34688 L
.74044 .34688 L
.74044 .16187 L
F
.2 .63 .79 r
.7392 .16187 m
.7392 .34688 L
.74044 .34688 L
.74044 .16187 L
s
.678 .847 .902 r
.74044 .16187 m
.74044 .34839 L
.74209 .34839 L
.74209 .16187 L
F
.2 .63 .79 r
.74044 .16187 m
.74044 .34839 L
.74209 .34839 L
.74209 .16187 L
s
.678 .847 .902 r
.74209 .16187 m
.74209 .35068 L
.74336 .35068 L
.74336 .16187 L
F
.2 .63 .79 r
.74209 .16187 m
.74209 .35068 L
.74336 .35068 L
.74336 .16187 L
s
.678 .847 .902 r
.74336 .16187 m
.74336 .3509 L
.74547 .3509 L
.74547 .16187 L
F
.2 .63 .79 r
.74336 .16187 m
.74336 .3509 L
.74547 .3509 L
.74547 .16187 L
s
.678 .847 .902 r
.74547 .16187 m
.74547 .35323 L
.74619 .35323 L
.74619 .16187 L
F
.2 .63 .79 r
.74547 .16187 m
.74547 .35323 L
.74619 .35323 L
.74619 .16187 L
s
.678 .847 .902 r
.74619 .16187 m
.74619 .3549 L
.7479 .3549 L
.7479 .16187 L
F
.2 .63 .79 r
.74619 .16187 m
.74619 .3549 L
.7479 .3549 L
.7479 .16187 L
s
.678 .847 .902 r
.7479 .16187 m
.7479 .35513 L
.74946 .35513 L
.74946 .16187 L
F
.2 .63 .79 r
.7479 .16187 m
.7479 .35513 L
.74946 .35513 L
.74946 .16187 L
s
.678 .847 .902 r
.74946 .16187 m
.74946 .35671 L
.75074 .35671 L
.75074 .16187 L
F
.2 .63 .79 r
.74946 .16187 m
.74946 .35671 L
.75074 .35671 L
.75074 .16187 L
s
.678 .847 .902 r
.75074 .16187 m
.75074 .3589 L
.75246 .3589 L
.75246 .16187 L
F
.2 .63 .79 r
.75074 .16187 m
.75074 .3589 L
.75246 .3589 L
.75246 .16187 L
s
.678 .847 .902 r
.75246 .16187 m
.75246 .35934 L
.75443 .35934 L
.75443 .16187 L
F
.2 .63 .79 r
.75246 .16187 m
.75246 .35934 L
.75443 .35934 L
.75443 .16187 L
s
.678 .847 .902 r
.75443 .16187 m
.75443 .36268 L
.75625 .36268 L
.75625 .16187 L
F
.2 .63 .79 r
.75443 .16187 m
.75443 .36268 L
.75625 .36268 L
.75625 .16187 L
s
.678 .847 .902 r
.75625 .16187 m
.75625 .36414 L
.75773 .36414 L
.75773 .16187 L
F
.2 .63 .79 r
.75625 .16187 m
.75625 .36414 L
.75773 .36414 L
.75773 .16187 L
s
.678 .847 .902 r
.75773 .16187 m
.75773 .36513 L
.7587 .36513 L
.7587 .16187 L
F
.2 .63 .79 r
.75773 .16187 m
.75773 .36513 L
.7587 .36513 L
.7587 .16187 L
s
.678 .847 .902 r
.7587 .16187 m
.7587 .36597 L
.75982 .36597 L
.75982 .16187 L
F
.2 .63 .79 r
.7587 .16187 m
.7587 .36597 L
.75982 .36597 L
.75982 .16187 L
s
.678 .847 .902 r
.75982 .16187 m
.75982 .36775 L
.76154 .36775 L
.76154 .16187 L
F
.2 .63 .79 r
.75982 .16187 m
.75982 .36775 L
.76154 .36775 L
.76154 .16187 L
s
.678 .847 .902 r
.76154 .16187 m
.76154 .36899 L
.76328 .36899 L
.76328 .16187 L
F
.2 .63 .79 r
.76154 .16187 m
.76154 .36899 L
.76328 .36899 L
.76328 .16187 L
s
.678 .847 .902 r
.76328 .16187 m
.76328 .37025 L
.76425 .37025 L
.76425 .16187 L
F
.2 .63 .79 r
.76328 .16187 m
.76328 .37025 L
.76425 .37025 L
.76425 .16187 L
s
.678 .847 .902 r
.76425 .16187 m
.76425 .37151 L
.76553 .37151 L
.76553 .16187 L
F
.2 .63 .79 r
.76425 .16187 m
.76425 .37151 L
.76553 .37151 L
.76553 .16187 L
s
.678 .847 .902 r
.76553 .16187 m
.76553 .37214 L
.76624 .37214 L
.76624 .16187 L
F
.2 .63 .79 r
.76553 .16187 m
.76553 .37214 L
.76624 .37214 L
.76624 .16187 L
s
.678 .847 .902 r
.76624 .16187 m
.76624 .37278 L
.76828 .37278 L
.76828 .16187 L
F
.2 .63 .79 r
.76624 .16187 m
.76624 .37278 L
.76828 .37278 L
.76828 .16187 L
s
.678 .847 .902 r
.76828 .16187 m
.76828 .3749 L
.76963 .3749 L
.76963 .16187 L
F
.2 .63 .79 r
.76828 .16187 m
.76828 .3749 L
.76963 .3749 L
.76963 .16187 L
s
.678 .847 .902 r
.76963 .16187 m
.76963 .37638 L
.77164 .37638 L
.77164 .16187 L
F
.2 .63 .79 r
.76963 .16187 m
.76963 .37638 L
.77164 .37638 L
.77164 .16187 L
s
.678 .847 .902 r
.77164 .16187 m
.77164 .37869 L
.7738 .37869 L
.7738 .16187 L
F
.2 .63 .79 r
.77164 .16187 m
.77164 .37869 L
.7738 .37869 L
.7738 .16187 L
s
.678 .847 .902 r
.7738 .16187 m
.7738 .38033 L
.77529 .38033 L
.77529 .16187 L
F
.2 .63 .79 r
.7738 .16187 m
.7738 .38033 L
.77529 .38033 L
.77529 .16187 L
s
.678 .847 .902 r
.77529 .16187 m
.77529 .38145 L
.77605 .38145 L
.77605 .16187 L
F
.2 .63 .79 r
.77529 .16187 m
.77529 .38145 L
.77605 .38145 L
.77605 .16187 L
s
.678 .847 .902 r
.77605 .16187 m
.77605 .38202 L
.77707 .38202 L
.77707 .16187 L
F
.2 .63 .79 r
.77605 .16187 m
.77605 .38202 L
.77707 .38202 L
.77707 .16187 L
s
.678 .847 .902 r
.77707 .16187 m
.77707 .38371 L
.77862 .38371 L
.77862 .16187 L
F
.2 .63 .79 r
.77707 .16187 m
.77707 .38371 L
.77862 .38371 L
.77862 .16187 L
s
.678 .847 .902 r
.77862 .16187 m
.77862 .3849 L
.78017 .3849 L
.78017 .16187 L
F
.2 .63 .79 r
.77862 .16187 m
.77862 .3849 L
.78017 .3849 L
.78017 .16187 L
s
.678 .847 .902 r
.78017 .16187 m
.78017 .38631 L
.78086 .38631 L
.78086 .16187 L
F
.2 .63 .79 r
.78017 .16187 m
.78017 .38631 L
.78086 .38631 L
.78086 .16187 L
s
.678 .847 .902 r
.78086 .16187 m
.78086 .38682 L
.78234 .38682 L
.78234 .16187 L
F
.2 .63 .79 r
.78086 .16187 m
.78086 .38682 L
.78234 .38682 L
.78234 .16187 L
s
.678 .847 .902 r
.78234 .16187 m
.78234 .38894 L
.7845 .38894 L
.7845 .16187 L
F
.2 .63 .79 r
.78234 .16187 m
.78234 .38894 L
.7845 .38894 L
.7845 .16187 L
s
.678 .847 .902 r
.7845 .16187 m
.7845 .39028 L
.78542 .39028 L
.78542 .16187 L
F
.2 .63 .79 r
.7845 .16187 m
.7845 .39028 L
.78542 .39028 L
.78542 .16187 L
s
.678 .847 .902 r
.78542 .16187 m
.78542 .39198 L
.78656 .39198 L
.78656 .16187 L
F
.2 .63 .79 r
.78542 .16187 m
.78542 .39198 L
.78656 .39198 L
.78656 .16187 L
s
.678 .847 .902 r
.78656 .16187 m
.78656 .3924 L
.78825 .3924 L
.78825 .16187 L
F
.2 .63 .79 r
.78656 .16187 m
.78656 .3924 L
.78825 .3924 L
.78825 .16187 L
s
.678 .847 .902 r
.78825 .16187 m
.78825 .39442 L
.78924 .39442 L
.78924 .16187 L
F
.2 .63 .79 r
.78825 .16187 m
.78825 .39442 L
.78924 .39442 L
.78924 .16187 L
s
.678 .847 .902 r
.78924 .16187 m
.78924 .39515 L
.79086 .39515 L
.79086 .16187 L
F
.2 .63 .79 r
.78924 .16187 m
.78924 .39515 L
.79086 .39515 L
.79086 .16187 L
s
.678 .847 .902 r
.79086 .16187 m
.79086 .39719 L
.79169 .39719 L
.79169 .16187 L
F
.2 .63 .79 r
.79086 .16187 m
.79086 .39719 L
.79169 .39719 L
.79169 .16187 L
s
.678 .847 .902 r
.79169 .16187 m
.79169 .39777 L
.7929 .39777 L
.7929 .16187 L
F
.2 .63 .79 r
.79169 .16187 m
.79169 .39777 L
.7929 .39777 L
.7929 .16187 L
s
.678 .847 .902 r
.7929 .16187 m
.7929 .39941 L
.79434 .39941 L
.79434 .16187 L
F
.2 .63 .79 r
.7929 .16187 m
.7929 .39941 L
.79434 .39941 L
.79434 .16187 L
s
.678 .847 .902 r
.79434 .16187 m
.79434 .40101 L
.79639 .40101 L
.79639 .16187 L
F
.2 .63 .79 r
.79434 .16187 m
.79434 .40101 L
.79639 .40101 L
.79639 .16187 L
s
.678 .847 .902 r
.79639 .16187 m
.79639 .4022 L
.79843 .4022 L
.79843 .16187 L
F
.2 .63 .79 r
.79639 .16187 m
.79639 .4022 L
.79843 .4022 L
.79843 .16187 L
s
.678 .847 .902 r
.79843 .16187 m
.79843 .4052 L
.80054 .4052 L
.80054 .16187 L
F
.2 .63 .79 r
.79843 .16187 m
.79843 .4052 L
.80054 .4052 L
.80054 .16187 L
s
.678 .847 .902 r
.80054 .16187 m
.80054 .40759 L
.80192 .40759 L
.80192 .16187 L
F
.2 .63 .79 r
.80054 .16187 m
.80054 .40759 L
.80192 .40759 L
.80192 .16187 L
s
.678 .847 .902 r
.80192 .16187 m
.80192 .40782 L
.80258 .40782 L
.80258 .16187 L
F
.2 .63 .79 r
.80192 .16187 m
.80192 .40782 L
.80258 .40782 L
.80258 .16187 L
s
.678 .847 .902 r
.80258 .16187 m
.80258 .4092 L
.80392 .4092 L
.80392 .16187 L
F
.2 .63 .79 r
.80258 .16187 m
.80258 .4092 L
.80392 .4092 L
.80392 .16187 L
s
.678 .847 .902 r
.80392 .16187 m
.80392 .40976 L
.80467 .40976 L
.80467 .16187 L
F
.2 .63 .79 r
.80392 .16187 m
.80392 .40976 L
.80467 .40976 L
.80467 .16187 L
s
.678 .847 .902 r
.80467 .16187 m
.80467 .41108 L
.80606 .41108 L
.80606 .16187 L
F
.2 .63 .79 r
.80467 .16187 m
.80467 .41108 L
.80606 .41108 L
.80606 .16187 L
s
.678 .847 .902 r
.80606 .16187 m
.80606 .41304 L
.80742 .41304 L
.80742 .16187 L
F
.2 .63 .79 r
.80606 .16187 m
.80606 .41304 L
.80742 .41304 L
.80742 .16187 L
s
.678 .847 .902 r
.80742 .16187 m
.80742 .41359 L
.80865 .41359 L
.80865 .16187 L
F
.2 .63 .79 r
.80742 .16187 m
.80742 .41359 L
.80865 .41359 L
.80865 .16187 L
s
.678 .847 .902 r
.80865 .16187 m
.80865 .41456 L
.81055 .41456 L
.81055 .16187 L
F
.2 .63 .79 r
.80865 .16187 m
.80865 .41456 L
.81055 .41456 L
.81055 .16187 L
s
.678 .847 .902 r
.81055 .16187 m
.81055 .41836 L
.81257 .41836 L
.81257 .16187 L
F
.2 .63 .79 r
.81055 .16187 m
.81055 .41836 L
.81257 .41836 L
.81257 .16187 L
s
.678 .847 .902 r
.81257 .16187 m
.81257 .41963 L
.81454 .41963 L
.81454 .16187 L
F
.2 .63 .79 r
.81257 .16187 m
.81257 .41963 L
.81454 .41963 L
.81454 .16187 L
s
.678 .847 .902 r
.81454 .16187 m
.81454 .42144 L
.81574 .42144 L
.81574 .16187 L
F
.2 .63 .79 r
.81454 .16187 m
.81454 .42144 L
.81574 .42144 L
.81574 .16187 L
s
.678 .847 .902 r
.81574 .16187 m
.81574 .42273 L
.81681 .42273 L
.81681 .16187 L
F
.2 .63 .79 r
.81574 .16187 m
.81574 .42273 L
.81681 .42273 L
.81681 .16187 L
s
.678 .847 .902 r
.81681 .16187 m
.81681 .42397 L
.81884 .42397 L
.81884 .16187 L
F
.2 .63 .79 r
.81681 .16187 m
.81681 .42397 L
.81884 .42397 L
.81884 .16187 L
s
.678 .847 .902 r
.81884 .16187 m
.81884 .42581 L
.82055 .42581 L
.82055 .16187 L
F
.2 .63 .79 r
.81884 .16187 m
.81884 .42581 L
.82055 .42581 L
.82055 .16187 L
s
.678 .847 .902 r
.82055 .16187 m
.82055 .42669 L
.82125 .42669 L
.82125 .16187 L
F
.2 .63 .79 r
.82055 .16187 m
.82055 .42669 L
.82125 .42669 L
.82125 .16187 L
s
.678 .847 .902 r
.82125 .16187 m
.82125 .42876 L
.82282 .42876 L
.82282 .16187 L
F
.2 .63 .79 r
.82125 .16187 m
.82125 .42876 L
.82282 .42876 L
.82282 .16187 L
s
.678 .847 .902 r
.82282 .16187 m
.82282 .4291 L
.82451 .4291 L
.82451 .16187 L
F
.2 .63 .79 r
.82282 .16187 m
.82282 .4291 L
.82451 .4291 L
.82451 .16187 L
s
.678 .847 .902 r
.82451 .16187 m
.82451 .43105 L
.82525 .43105 L
.82525 .16187 L
F
.2 .63 .79 r
.82451 .16187 m
.82451 .43105 L
.82525 .43105 L
.82525 .16187 L
s
.678 .847 .902 r
.82525 .16187 m
.82525 .43203 L
.82729 .43203 L
.82729 .16187 L
F
.2 .63 .79 r
.82525 .16187 m
.82525 .43203 L
.82729 .43203 L
.82729 .16187 L
s
.678 .847 .902 r
.82729 .16187 m
.82729 .43419 L
.82829 .43419 L
.82829 .16187 L
F
.2 .63 .79 r
.82729 .16187 m
.82729 .43419 L
.82829 .43419 L
.82829 .16187 L
s
.678 .847 .902 r
.82829 .16187 m
.82829 .43514 L
.8292 .43514 L
.8292 .16187 L
F
.2 .63 .79 r
.82829 .16187 m
.82829 .43514 L
.8292 .43514 L
.8292 .16187 L
s
.678 .847 .902 r
.8292 .16187 m
.8292 .43645 L
.83007 .43645 L
.83007 .16187 L
F
.2 .63 .79 r
.8292 .16187 m
.8292 .43645 L
.83007 .43645 L
.83007 .16187 L
s
.678 .847 .902 r
.83007 .16187 m
.83007 .43667 L
.83072 .43667 L
.83072 .16187 L
F
.2 .63 .79 r
.83007 .16187 m
.83007 .43667 L
.83072 .43667 L
.83072 .16187 L
s
.678 .847 .902 r
.83072 .16187 m
.83072 .43834 L
.83179 .43834 L
.83179 .16187 L
F
.2 .63 .79 r
.83072 .16187 m
.83072 .43834 L
.83179 .43834 L
.83179 .16187 L
s
.678 .847 .902 r
.83179 .16187 m
.83179 .43922 L
.83349 .43922 L
.83349 .16187 L
F
.2 .63 .79 r
.83179 .16187 m
.83179 .43922 L
.83349 .43922 L
.83349 .16187 L
s
.678 .847 .902 r
.83349 .16187 m
.83349 .44066 L
.83434 .44066 L
.83434 .16187 L
F
.2 .63 .79 r
.83349 .16187 m
.83349 .44066 L
.83434 .44066 L
.83434 .16187 L
s
.678 .847 .902 r
.83434 .16187 m
.83434 .4418 L
.83583 .4418 L
.83583 .16187 L
F
.2 .63 .79 r
.83434 .16187 m
.83434 .4418 L
.83583 .4418 L
.83583 .16187 L
s
.678 .847 .902 r
.83583 .16187 m
.83583 .44345 L
.8368 .44345 L
.8368 .16187 L
F
.2 .63 .79 r
.83583 .16187 m
.83583 .44345 L
.8368 .44345 L
.8368 .16187 L
s
.678 .847 .902 r
.8368 .16187 m
.8368 .44363 L
.83776 .44363 L
.83776 .16187 L
F
.2 .63 .79 r
.8368 .16187 m
.8368 .44363 L
.83776 .44363 L
.83776 .16187 L
s
.678 .847 .902 r
.83776 .16187 m
.83776 .44586 L
.83943 .44586 L
.83943 .16187 L
F
.2 .63 .79 r
.83776 .16187 m
.83776 .44586 L
.83943 .44586 L
.83943 .16187 L
s
.678 .847 .902 r
.83943 .16187 m
.83943 .44657 L
.84034 .44657 L
.84034 .16187 L
F
.2 .63 .79 r
.83943 .16187 m
.83943 .44657 L
.84034 .44657 L
.84034 .16187 L
s
.678 .847 .902 r
.84034 .16187 m
.84034 .44838 L
.84158 .44838 L
.84158 .16187 L
F
.2 .63 .79 r
.84034 .16187 m
.84034 .44838 L
.84158 .44838 L
.84158 .16187 L
s
.678 .847 .902 r
.84158 .16187 m
.84158 .44874 L
.8427 .44874 L
.8427 .16187 L
F
.2 .63 .79 r
.84158 .16187 m
.84158 .44874 L
.8427 .44874 L
.8427 .16187 L
s
.678 .847 .902 r
.8427 .16187 m
.8427 .45008 L
.84457 .45008 L
.84457 .16187 L
F
.2 .63 .79 r
.8427 .16187 m
.8427 .45008 L
.84457 .45008 L
.84457 .16187 L
s
.678 .847 .902 r
.84457 .16187 m
.84457 .45263 L
.84646 .45263 L
.84646 .16187 L
F
.2 .63 .79 r
.84457 .16187 m
.84457 .45263 L
.84646 .45263 L
.84646 .16187 L
s
.678 .847 .902 r
.84646 .16187 m
.84646 .45461 L
.84728 .45461 L
.84728 .16187 L
F
.2 .63 .79 r
.84646 .16187 m
.84646 .45461 L
.84728 .45461 L
.84728 .16187 L
s
.678 .847 .902 r
.84728 .16187 m
.84728 .4554 L
.84853 .4554 L
.84853 .16187 L
F
.2 .63 .79 r
.84728 .16187 m
.84728 .4554 L
.84853 .4554 L
.84853 .16187 L
s
.678 .847 .902 r
.84853 .16187 m
.84853 .45661 L
.84935 .45661 L
.84935 .16187 L
F
.2 .63 .79 r
.84853 .16187 m
.84853 .45661 L
.84935 .45661 L
.84935 .16187 L
s
.678 .847 .902 r
.84935 .16187 m
.84935 .45765 L
.85119 .45765 L
.85119 .16187 L
F
.2 .63 .79 r
.84935 .16187 m
.84935 .45765 L
.85119 .45765 L
.85119 .16187 L
s
.678 .847 .902 r
.85119 .16187 m
.85119 .46045 L
.85262 .46045 L
.85262 .16187 L
F
.2 .63 .79 r
.85119 .16187 m
.85119 .46045 L
.85262 .46045 L
.85262 .16187 L
s
.678 .847 .902 r
.85262 .16187 m
.85262 .46128 L
.85435 .46128 L
.85435 .16187 L
F
.2 .63 .79 r
.85262 .16187 m
.85262 .46128 L
.85435 .46128 L
.85435 .16187 L
s
.678 .847 .902 r
.85435 .16187 m
.85435 .46252 L
.85508 .46252 L
.85508 .16187 L
F
.2 .63 .79 r
.85435 .16187 m
.85435 .46252 L
.85508 .46252 L
.85508 .16187 L
s
.678 .847 .902 r
.85508 .16187 m
.85508 .46336 L
.85706 .46336 L
.85706 .16187 L
F
.2 .63 .79 r
.85508 .16187 m
.85508 .46336 L
.85706 .46336 L
.85706 .16187 L
s
.678 .847 .902 r
.85706 .16187 m
.85706 .46582 L
.85814 .46582 L
.85814 .16187 L
F
.2 .63 .79 r
.85706 .16187 m
.85706 .46582 L
.85814 .46582 L
.85814 .16187 L
s
.678 .847 .902 r
.85814 .16187 m
.85814 .46798 L
.85961 .46798 L
.85961 .16187 L
F
.2 .63 .79 r
.85814 .16187 m
.85814 .46798 L
.85961 .46798 L
.85961 .16187 L
s
.678 .847 .902 r
.85961 .16187 m
.85961 .46878 L
.86165 .46878 L
.86165 .16187 L
F
.2 .63 .79 r
.85961 .16187 m
.85961 .46878 L
.86165 .46878 L
.86165 .16187 L
s
.678 .847 .902 r
.86165 .16187 m
.86165 .47228 L
.86363 .47228 L
.86363 .16187 L
F
.2 .63 .79 r
.86165 .16187 m
.86165 .47228 L
.86363 .47228 L
.86363 .16187 L
s
.678 .847 .902 r
.86363 .16187 m
.86363 .47275 L
.86429 .47275 L
.86429 .16187 L
F
.2 .63 .79 r
.86363 .16187 m
.86363 .47275 L
.86429 .47275 L
.86429 .16187 L
s
.678 .847 .902 r
.86429 .16187 m
.86429 .47415 L
.86624 .47415 L
.86624 .16187 L
F
.2 .63 .79 r
.86429 .16187 m
.86429 .47415 L
.86624 .47415 L
.86624 .16187 L
s
.678 .847 .902 r
.86624 .16187 m
.86624 .47677 L
.86807 .47677 L
.86807 .16187 L
F
.2 .63 .79 r
.86624 .16187 m
.86624 .47677 L
.86807 .47677 L
.86807 .16187 L
s
.678 .847 .902 r
.86807 .16187 m
.86807 .47784 L
.86921 .47784 L
.86921 .16187 L
F
.2 .63 .79 r
.86807 .16187 m
.86807 .47784 L
.86921 .47784 L
.86921 .16187 L
s
.678 .847 .902 r
.86921 .16187 m
.86921 .47985 L
.87108 .47985 L
.87108 .16187 L
F
.2 .63 .79 r
.86921 .16187 m
.86921 .47985 L
.87108 .47985 L
.87108 .16187 L
s
.678 .847 .902 r
.87108 .16187 m
.87108 .48143 L
.87272 .48143 L
.87272 .16187 L
F
.2 .63 .79 r
.87108 .16187 m
.87108 .48143 L
.87272 .48143 L
.87272 .16187 L
s
.678 .847 .902 r
.87272 .16187 m
.87272 .48243 L
.87354 .48243 L
.87354 .16187 L
F
.2 .63 .79 r
.87272 .16187 m
.87272 .48243 L
.87354 .48243 L
.87354 .16187 L
s
.678 .847 .902 r
.87354 .16187 m
.87354 .48355 L
.87442 .48355 L
.87442 .16187 L
F
.2 .63 .79 r
.87354 .16187 m
.87354 .48355 L
.87442 .48355 L
.87442 .16187 L
s
.678 .847 .902 r
.87442 .16187 m
.87442 .4855 L
.8757 .4855 L
.8757 .16187 L
F
.2 .63 .79 r
.87442 .16187 m
.87442 .4855 L
.8757 .4855 L
.8757 .16187 L
s
.678 .847 .902 r
.8757 .16187 m
.8757 .48623 L
.87688 .48623 L
.87688 .16187 L
F
.2 .63 .79 r
.8757 .16187 m
.8757 .48623 L
.87688 .48623 L
.87688 .16187 L
s
.678 .847 .902 r
.87688 .16187 m
.87688 .48816 L
.87799 .48816 L
.87799 .16187 L
F
.2 .63 .79 r
.87688 .16187 m
.87688 .48816 L
.87799 .48816 L
.87799 .16187 L
s
.678 .847 .902 r
.87799 .16187 m
.87799 .48937 L
.87916 .48937 L
.87916 .16187 L
F
.2 .63 .79 r
.87799 .16187 m
.87799 .48937 L
.87916 .48937 L
.87916 .16187 L
s
.678 .847 .902 r
.87916 .16187 m
.87916 .48956 L
.88027 .48956 L
.88027 .16187 L
F
.2 .63 .79 r
.87916 .16187 m
.87916 .48956 L
.88027 .48956 L
.88027 .16187 L
s
.678 .847 .902 r
.88027 .16187 m
.88027 .49296 L
.88237 .49296 L
.88237 .16187 L
F
.2 .63 .79 r
.88027 .16187 m
.88027 .49296 L
.88237 .49296 L
.88237 .16187 L
s
.678 .847 .902 r
.88237 .16187 m
.88237 .49347 L
.88332 .49347 L
.88332 .16187 L
F
.2 .63 .79 r
.88237 .16187 m
.88237 .49347 L
.88332 .49347 L
.88332 .16187 L
s
.678 .847 .902 r
.88332 .16187 m
.88332 .49507 L
.88481 .49507 L
.88481 .16187 L
F
.2 .63 .79 r
.88332 .16187 m
.88332 .49507 L
.88481 .49507 L
.88481 .16187 L
s
.678 .847 .902 r
.88481 .16187 m
.88481 .49596 L
.88668 .49596 L
.88668 .16187 L
F
.2 .63 .79 r
.88481 .16187 m
.88481 .49596 L
.88668 .49596 L
.88668 .16187 L
s
.678 .847 .902 r
.88668 .16187 m
.88668 .49848 L
.88769 .49848 L
.88769 .16187 L
F
.2 .63 .79 r
.88668 .16187 m
.88668 .49848 L
.88769 .49848 L
.88769 .16187 L
s
.678 .847 .902 r
.88769 .16187 m
.88769 .49918 L
.88857 .49918 L
.88857 .16187 L
F
.2 .63 .79 r
.88769 .16187 m
.88769 .49918 L
.88857 .49918 L
.88857 .16187 L
s
.678 .847 .902 r
.88857 .16187 m
.88857 .50088 L
.89025 .50088 L
.89025 .16187 L
F
.2 .63 .79 r
.88857 .16187 m
.88857 .50088 L
.89025 .50088 L
.89025 .16187 L
s
.678 .847 .902 r
.89025 .16187 m
.89025 .50288 L
.89169 .50288 L
.89169 .16187 L
F
.2 .63 .79 r
.89025 .16187 m
.89025 .50288 L
.89169 .50288 L
.89169 .16187 L
s
.678 .847 .902 r
.89169 .16187 m
.89169 .50461 L
.89341 .50461 L
.89341 .16187 L
F
.2 .63 .79 r
.89169 .16187 m
.89169 .50461 L
.89341 .50461 L
.89341 .16187 L
s
.678 .847 .902 r
.89341 .16187 m
.89341 .5064 L
.89442 .5064 L
.89442 .16187 L
F
.2 .63 .79 r
.89341 .16187 m
.89341 .5064 L
.89442 .5064 L
.89442 .16187 L
s
.678 .847 .902 r
.89442 .16187 m
.89442 .50769 L
.8963 .50769 L
.8963 .16187 L
F
.2 .63 .79 r
.89442 .16187 m
.89442 .50769 L
.8963 .50769 L
.8963 .16187 L
s
.678 .847 .902 r
.8963 .16187 m
.8963 .50893 L
.89773 .50893 L
.89773 .16187 L
F
.2 .63 .79 r
.8963 .16187 m
.8963 .50893 L
.89773 .50893 L
.89773 .16187 L
s
.678 .847 .902 r
.89773 .16187 m
.89773 .51052 L
.89967 .51052 L
.89967 .16187 L
F
.2 .63 .79 r
.89773 .16187 m
.89773 .51052 L
.89967 .51052 L
.89967 .16187 L
s
.678 .847 .902 r
.89967 .16187 m
.89967 .51266 L
.90102 .51266 L
.90102 .16187 L
F
.2 .63 .79 r
.89967 .16187 m
.89967 .51266 L
.90102 .51266 L
.90102 .16187 L
s
.678 .847 .902 r
.90102 .16187 m
.90102 .51417 L
.90241 .51417 L
.90241 .16187 L
F
.2 .63 .79 r
.90102 .16187 m
.90102 .51417 L
.90241 .51417 L
.90241 .16187 L
s
.678 .847 .902 r
.90241 .16187 m
.90241 .51662 L
.90415 .51662 L
.90415 .16187 L
F
.2 .63 .79 r
.90241 .16187 m
.90241 .51662 L
.90415 .51662 L
.90415 .16187 L
s
.678 .847 .902 r
.90415 .16187 m
.90415 .5183 L
.9051 .5183 L
.9051 .16187 L
F
.2 .63 .79 r
.90415 .16187 m
.90415 .5183 L
.9051 .5183 L
.9051 .16187 L
s
.678 .847 .902 r
.9051 .16187 m
.9051 .51874 L
.90629 .51874 L
.90629 .16187 L
F
.2 .63 .79 r
.9051 .16187 m
.9051 .51874 L
.90629 .51874 L
.90629 .16187 L
s
.678 .847 .902 r
.90629 .16187 m
.90629 .52111 L
.90745 .52111 L
.90745 .16187 L
F
.2 .63 .79 r
.90629 .16187 m
.90629 .52111 L
.90745 .52111 L
.90745 .16187 L
s
.678 .847 .902 r
.90745 .16187 m
.90745 .52218 L
.90856 .52218 L
.90856 .16187 L
F
.2 .63 .79 r
.90745 .16187 m
.90745 .52218 L
.90856 .52218 L
.90856 .16187 L
s
.678 .847 .902 r
.90856 .16187 m
.90856 .52306 L
.9105 .52306 L
.9105 .16187 L
F
.2 .63 .79 r
.90856 .16187 m
.90856 .52306 L
.9105 .52306 L
.9105 .16187 L
s
.678 .847 .902 r
.9105 .16187 m
.9105 .52496 L
.91123 .52496 L
.91123 .16187 L
F
.2 .63 .79 r
.9105 .16187 m
.9105 .52496 L
.91123 .52496 L
.91123 .16187 L
s
.678 .847 .902 r
.91123 .16187 m
.91123 .52791 L
.9134 .52791 L
.9134 .16187 L
F
.2 .63 .79 r
.91123 .16187 m
.91123 .52791 L
.9134 .52791 L
.9134 .16187 L
s
.678 .847 .902 r
.9134 .16187 m
.9134 .52961 L
.91556 .52961 L
.91556 .16187 L
F
.2 .63 .79 r
.9134 .16187 m
.9134 .52961 L
.91556 .52961 L
.91556 .16187 L
s
.678 .847 .902 r
.91556 .16187 m
.91556 .53126 L
.91759 .53126 L
.91759 .16187 L
F
.2 .63 .79 r
.91556 .16187 m
.91556 .53126 L
.91759 .53126 L
.91759 .16187 L
s
.678 .847 .902 r
.91759 .16187 m
.91759 .5346 L
.91953 .5346 L
.91953 .16187 L
F
.2 .63 .79 r
.91759 .16187 m
.91759 .5346 L
.91953 .5346 L
.91953 .16187 L
s
.678 .847 .902 r
.91953 .16187 m
.91953 .53582 L
.92086 .53582 L
.92086 .16187 L
F
.2 .63 .79 r
.91953 .16187 m
.91953 .53582 L
.92086 .53582 L
.92086 .16187 L
s
.678 .847 .902 r
.92086 .16187 m
.92086 .53743 L
.92182 .53743 L
.92182 .16187 L
F
.2 .63 .79 r
.92086 .16187 m
.92086 .53743 L
.92182 .53743 L
.92182 .16187 L
s
.678 .847 .902 r
.92182 .16187 m
.92182 .53934 L
.92347 .53934 L
.92347 .16187 L
F
.2 .63 .79 r
.92182 .16187 m
.92182 .53934 L
.92347 .53934 L
.92347 .16187 L
s
.678 .847 .902 r
.92347 .16187 m
.92347 .54095 L
.9252 .54095 L
.9252 .16187 L
F
.2 .63 .79 r
.92347 .16187 m
.92347 .54095 L
.9252 .54095 L
.9252 .16187 L
s
.678 .847 .902 r
.9252 .16187 m
.9252 .54374 L
.92702 .54374 L
.92702 .16187 L
F
.2 .63 .79 r
.9252 .16187 m
.9252 .54374 L
.92702 .54374 L
.92702 .16187 L
s
.678 .847 .902 r
.92702 .16187 m
.92702 .54578 L
.9287 .54578 L
.9287 .16187 L
F
.2 .63 .79 r
.92702 .16187 m
.92702 .54578 L
.9287 .54578 L
.9287 .16187 L
s
.678 .847 .902 r
.9287 .16187 m
.9287 .54637 L
.93082 .54637 L
.93082 .16187 L
F
.2 .63 .79 r
.9287 .16187 m
.9287 .54637 L
.93082 .54637 L
.93082 .16187 L
s
.678 .847 .902 r
.93082 .16187 m
.93082 .54963 L
.93218 .54963 L
.93218 .16187 L
F
.2 .63 .79 r
.93082 .16187 m
.93082 .54963 L
.93218 .54963 L
.93218 .16187 L
s
.678 .847 .902 r
.93218 .16187 m
.93218 .55094 L
.9343 .55094 L
.9343 .16187 L
F
.2 .63 .79 r
.93218 .16187 m
.93218 .55094 L
.9343 .55094 L
.9343 .16187 L
s
.678 .847 .902 r
.9343 .16187 m
.9343 .55344 L
.93521 .55344 L
.93521 .16187 L
F
.2 .63 .79 r
.9343 .16187 m
.9343 .55344 L
.93521 .55344 L
.93521 .16187 L
s
.678 .847 .902 r
.93521 .16187 m
.93521 .55378 L
.93604 .55378 L
.93604 .16187 L
F
.2 .63 .79 r
.93521 .16187 m
.93521 .55378 L
.93604 .55378 L
.93604 .16187 L
s
.678 .847 .902 r
.93604 .16187 m
.93604 .55518 L
.9367 .55518 L
.9367 .16187 L
F
.2 .63 .79 r
.93604 .16187 m
.93604 .55518 L
.9367 .55518 L
.9367 .16187 L
s
.678 .847 .902 r
.9367 .16187 m
.9367 .55591 L
.93808 .55591 L
.93808 .16187 L
F
.2 .63 .79 r
.9367 .16187 m
.9367 .55591 L
.93808 .55591 L
.93808 .16187 L
s
.678 .847 .902 r
.93808 .16187 m
.93808 .55751 L
.93942 .55751 L
.93942 .16187 L
F
.2 .63 .79 r
.93808 .16187 m
.93808 .55751 L
.93942 .55751 L
.93942 .16187 L
s
.678 .847 .902 r
.93942 .16187 m
.93942 .55978 L
.94147 .55978 L
.94147 .16187 L
F
.2 .63 .79 r
.93942 .16187 m
.93942 .55978 L
.94147 .55978 L
.94147 .16187 L
s
.678 .847 .902 r
.94147 .16187 m
.94147 .5623 L
.94312 .5623 L
.94312 .16187 L
F
.2 .63 .79 r
.94147 .16187 m
.94147 .5623 L
.94312 .5623 L
.94312 .16187 L
s
.678 .847 .902 r
.94312 .16187 m
.94312 .56364 L
.94399 .56364 L
.94399 .16187 L
F
.2 .63 .79 r
.94312 .16187 m
.94312 .56364 L
.94399 .56364 L
.94399 .16187 L
s
.678 .847 .902 r
.94399 .16187 m
.94399 .56486 L
.94488 .56486 L
.94488 .16187 L
F
.2 .63 .79 r
.94399 .16187 m
.94399 .56486 L
.94488 .56486 L
.94488 .16187 L
s
.678 .847 .902 r
.94488 .16187 m
.94488 .56549 L
.94564 .56549 L
.94564 .16187 L
F
.2 .63 .79 r
.94488 .16187 m
.94488 .56549 L
.94564 .56549 L
.94564 .16187 L
s
.678 .847 .902 r
.94564 .16187 m
.94564 .56715 L
.94721 .56715 L
.94721 .16187 L
F
.2 .63 .79 r
.94564 .16187 m
.94564 .56715 L
.94721 .56715 L
.94721 .16187 L
s
.678 .847 .902 r
.94721 .16187 m
.94721 .56868 L
.94809 .56868 L
.94809 .16187 L
F
.2 .63 .79 r
.94721 .16187 m
.94721 .56868 L
.94809 .56868 L
.94809 .16187 L
s
.678 .847 .902 r
.94809 .16187 m
.94809 .56919 L
.94898 .56919 L
.94898 .16187 L
F
.2 .63 .79 r
.94809 .16187 m
.94809 .56919 L
.94898 .56919 L
.94898 .16187 L
s
.678 .847 .902 r
.94898 .16187 m
.94898 .57022 L
.94989 .57022 L
.94989 .16187 L
F
.2 .63 .79 r
.94898 .16187 m
.94898 .57022 L
.94989 .57022 L
.94989 .16187 L
s
.678 .847 .902 r
.94989 .16187 m
.94989 .57313 L
.95169 .57313 L
.95169 .16187 L
F
.2 .63 .79 r
.94989 .16187 m
.94989 .57313 L
.95169 .57313 L
.95169 .16187 L
s
.678 .847 .902 r
.95169 .16187 m
.95169 .57408 L
.95342 .57408 L
.95342 .16187 L
F
.2 .63 .79 r
.95169 .16187 m
.95169 .57408 L
.95342 .57408 L
.95342 .16187 L
s
.678 .847 .902 r
.95342 .16187 m
.95342 .57711 L
.95553 .57711 L
.95553 .16187 L
F
.2 .63 .79 r
.95342 .16187 m
.95342 .57711 L
.95553 .57711 L
.95553 .16187 L
s
.678 .847 .902 r
.95553 .16187 m
.95553 .57869 L
.95695 .57869 L
.95695 .16187 L
F
.2 .63 .79 r
.95553 .16187 m
.95553 .57869 L
.95695 .57869 L
.95695 .16187 L
s
.678 .847 .902 r
.95695 .16187 m
.95695 .58011 L
.95767 .58011 L
.95767 .16187 L
F
.2 .63 .79 r
.95695 .16187 m
.95695 .58011 L
.95767 .58011 L
.95767 .16187 L
s
.678 .847 .902 r
.95767 .16187 m
.95767 .58189 L
.95976 .58189 L
.95976 .16187 L
F
.2 .63 .79 r
.95767 .16187 m
.95767 .58189 L
.95976 .58189 L
.95976 .16187 L
s
.678 .847 .902 r
.95976 .16187 m
.95976 .58421 L
.96084 .58421 L
.96084 .16187 L
F
.2 .63 .79 r
.95976 .16187 m
.95976 .58421 L
.96084 .58421 L
.96084 .16187 L
s
.678 .847 .902 r
.96084 .16187 m
.96084 .58495 L
.96232 .58495 L
.96232 .16187 L
F
.2 .63 .79 r
.96084 .16187 m
.96084 .58495 L
.96232 .58495 L
.96232 .16187 L
s
.678 .847 .902 r
.96232 .16187 m
.96232 .58764 L
.96385 .58764 L
.96385 .16187 L
F
.2 .63 .79 r
.96232 .16187 m
.96232 .58764 L
.96385 .58764 L
.96385 .16187 L
s
.678 .847 .902 r
.96385 .16187 m
.96385 .58865 L
.96599 .58865 L
.96599 .16187 L
F
.2 .63 .79 r
.96385 .16187 m
.96385 .58865 L
.96599 .58865 L
.96599 .16187 L
s
.678 .847 .902 r
.96599 .16187 m
.96599 .59086 L
.96682 .59086 L
.96682 .16187 L
F
.2 .63 .79 r
.96599 .16187 m
.96599 .59086 L
.96682 .59086 L
.96682 .16187 L
s
.678 .847 .902 r
.96682 .16187 m
.96682 .59214 L
.96812 .59214 L
.96812 .16187 L
F
.2 .63 .79 r
.96682 .16187 m
.96682 .59214 L
.96812 .59214 L
.96812 .16187 L
s
.678 .847 .902 r
.96812 .16187 m
.96812 .59365 L
.96964 .59365 L
.96964 .16187 L
F
.2 .63 .79 r
.96812 .16187 m
.96812 .59365 L
.96964 .59365 L
.96964 .16187 L
s
.678 .847 .902 r
.96964 .16187 m
.96964 .59689 L
.97106 .59689 L
.97106 .16187 L
F
.2 .63 .79 r
.96964 .16187 m
.96964 .59689 L
.97106 .59689 L
.97106 .16187 L
s
.678 .847 .902 r
.97106 .16187 m
.97106 .59871 L
.97271 .59871 L
.97271 .16187 L
F
.2 .63 .79 r
.97106 .16187 m
.97106 .59871 L
.97271 .59871 L
.97271 .16187 L
s
.678 .847 .902 r
.97271 .16187 m
.97271 .60043 L
.97413 .60043 L
.97413 .16187 L
F
.2 .63 .79 r
.97271 .16187 m
.97271 .60043 L
.97413 .60043 L
.97413 .16187 L
s
.678 .847 .902 r
.97413 .16187 m
.97413 .60224 L
.97619 .60224 L
.97619 .16187 L
F
.2 .63 .79 r
.97413 .16187 m
.97413 .60224 L
.97619 .60224 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02412 .01472 Mdot
.02534 .01472 Mdot
.02646 .01472 Mdot
.02775 .01473 Mdot
.02963 .01474 Mdot
.032 .01476 Mdot
.0336 .01478 Mdot
.03491 .0148 Mdot
.03595 .01481 Mdot
.03708 .01483 Mdot
.03924 .01487 Mdot
.04066 .0149 Mdot
.04256 .01494 Mdot
.04351 .01497 Mdot
.04548 .01502 Mdot
.04742 .01508 Mdot
.04802 .0151 Mdot
.05038 .01517 Mdot
.05094 .01519 Mdot
.05144 .01521 Mdot
.05219 .01524 Mdot
.0544 .01532 Mdot
.05514 .01535 Mdot
.05675 .01542 Mdot
.05917 .01553 Mdot
.06101 .01561 Mdot
.06307 .01572 Mdot
.06365 .01575 Mdot
.06638 .01589 Mdot
.06815 .01599 Mdot
.07012 .01611 Mdot
.0717 .0162 Mdot
.07233 .01624 Mdot
.07402 .01635 Mdot
.07552 .01645 Mdot
.07578 .01647 Mdot
.07821 .01664 Mdot
.07934 .01672 Mdot
.08143 .01687 Mdot
.08232 .01694 Mdot
.08508 .01715 Mdot
.08527 .01717 Mdot
.08794 .01738 Mdot
.08896 .01747 Mdot
.09077 .01762 Mdot
.09188 .01772 Mdot
.09302 .01782 Mdot
.09406 .01792 Mdot
.09515 .01802 Mdot
.09856 .01834 Mdot
.09984 .01847 Mdot
.10055 .01854 Mdot
.1022 .0187 Mdot
.1028 .01876 Mdot
.10347 .01883 Mdot
.10546 .01904 Mdot
.1065 .01915 Mdot
.10725 .01923 Mdot
.1082 .01934 Mdot
.10989 .01952 Mdot
.11066 .01961 Mdot
.11235 .0198 Mdot
.1149 .0201 Mdot
.11577 .0202 Mdot
.11655 .0203 Mdot
.11825 .0205 Mdot
.121 .02084 Mdot
.1228 .02107 Mdot
.12402 .02123 Mdot
.12582 .02147 Mdot
.12662 .02157 Mdot
.12802 .02176 Mdot
.12934 .02194 Mdot
.1318 .02228 Mdot
.13336 .0225 Mdot
.13413 .02261 Mdot
.13596 .02288 Mdot
.13703 .02303 Mdot
.1391 .02334 Mdot
.14053 .02356 Mdot
.1408 .0236 Mdot
.14207 .02379 Mdot
.14351 .02401 Mdot
.14481 .02422 Mdot
.14813 .02474 Mdot
.14917 .02491 Mdot
.15074 .02517 Mdot
.15254 .02547 Mdot
.15373 .02567 Mdot
.15509 .0259 Mdot
.15658 .02615 Mdot
.15683 .0262 Mdot
.15878 .02654 Mdot
.15959 .02668 Mdot
.16193 .02709 Mdot
.1643 .02752 Mdot
.16551 .02775 Mdot
.16701 .02802 Mdot
.1684 .02828 Mdot
.16911 .02842 Mdot
.17143 .02886 Mdot
.17225 .02901 Mdot
.17553 .02965 Mdot
.17606 .02976 Mdot
.17746 .03003 Mdot
.17961 .03047 Mdot
.181 .03075 Mdot
.18203 .03096 Mdot
.18427 .03142 Mdot
.18497 .03157 Mdot
.18661 .03191 Mdot
.18704 .03201 Mdot
.1894 .03251 Mdot
.19073 .0328 Mdot
.19175 .03302 Mdot
.19395 .0335 Mdot
.1957 .03389 Mdot
.19774 .03435 Mdot
.2004 .03495 Mdot
.20117 .03513 Mdot
.20137 .03517 Mdot
.2023 .03539 Mdot
.2039 .03576 Mdot
.20583 .03621 Mdot
.2069 .03647 Mdot
.2077 .03666 Mdot
.20932 .03705 Mdot
.21049 .03733 Mdot
.21193 .03768 Mdot
.21308 .03796 Mdot
.21543 .03854 Mdot
.21584 .03864 Mdot
.21744 .03904 Mdot
.22006 .03971 Mdot
.22058 .03984 Mdot
.22221 .04026 Mdot
.22406 .04074 Mdot
.22494 .04097 Mdot
.22594 .04123 Mdot
.22734 .0416 Mdot
.22892 .04202 Mdot
.23066 .04248 Mdot
.23144 .04269 Mdot
.23313 .04315 Mdot
.23419 .04344 Mdot
.23617 .04398 Mdot
.2374 .04432 Mdot
.23995 .04503 Mdot
.24156 .04548 Mdot
.24254 .04576 Mdot
.24452 .04633 Mdot
.24561 .04664 Mdot
.24746 .04718 Mdot
.24833 .04743 Mdot
.24949 .04777 Mdot
.2511 .04824 Mdot
.25225 .04858 Mdot
.25443 .04923 Mdot
.25629 .04979 Mdot
.25803 .05032 Mdot
.25898 .05061 Mdot
.26044 .05105 Mdot
.26078 .05116 Mdot
.26168 .05143 Mdot
.26221 .0516 Mdot
.26418 .05221 Mdot
.26639 .0529 Mdot
.2671 .05312 Mdot
.26831 .05351 Mdot
.26986 .054 Mdot
.27143 .0545 Mdot
.27314 .05506 Mdot
.27497 .05565 Mdot
.27524 .05574 Mdot
.27785 .05659 Mdot
.27949 .05714 Mdot
.27996 .05729 Mdot
.28231 .05808 Mdot
.28276 .05823 Mdot
.28454 .05883 Mdot
.28541 .05913 Mdot
.28806 .06003 Mdot
.28937 .06048 Mdot
.29103 .06105 Mdot
.29236 .06151 Mdot
.29391 .06206 Mdot
.29502 .06245 Mdot
.29738 .06328 Mdot
.29937 .06399 Mdot
.30093 .06455 Mdot
.30287 .06525 Mdot
.30378 .06558 Mdot
.30648 .06657 Mdot
.30834 .06725 Mdot
.30848 .0673 Mdot
.31038 .06801 Mdot
.31236 .06875 Mdot
.313 .06899 Mdot
.31388 .06932 Mdot
.31526 .06984 Mdot
.31738 .07064 Mdot
.31923 .07135 Mdot
.31957 .07148 Mdot
.321 .07203 Mdot
.32229 .07253 Mdot
.3237 .07308 Mdot
.32634 .07411 Mdot
.32688 .07432 Mdot
.32954 .07537 Mdot
.33108 .07598 Mdot
.33212 .0764 Mdot
.33288 .0767 Mdot
.33355 .07697 Mdot
.33486 .0775 Mdot
.33653 .07818 Mdot
.33725 .07847 Mdot
.33859 .07902 Mdot
.3406 .07984 Mdot
.34321 .08092 Mdot
.34343 .08101 Mdot
.34569 .08195 Mdot
.34768 .08278 Mdot
.34868 .0832 Mdot
.34995 .08374 Mdot
.35081 .0841 Mdot
.35218 .08469 Mdot
.35307 .08507 Mdot
.35567 .08618 Mdot
.35724 .08686 Mdot
.3577 .08706 Mdot
.3599 .08802 Mdot
.36137 .08866 Mdot
.36161 .08876 Mdot
.36274 .08926 Mdot
.364 .08982 Mdot
.36442 .09 Mdot
.3664 .09088 Mdot
.36673 .09102 Mdot
.36912 .09209 Mdot
.36924 .09215 Mdot
.3718 .0933 Mdot
.37237 .09356 Mdot
.37409 .09434 Mdot
.3762 .0953 Mdot
.37734 .09582 Mdot
.37925 .0967 Mdot
.38076 .0974 Mdot
.38183 .09789 Mdot
.38288 .09838 Mdot
.38415 .09898 Mdot
.38543 .09958 Mdot
.38677 .10021 Mdot
.38796 .10077 Mdot
.39065 .10204 Mdot
.39066 .10205 Mdot
.39209 .10273 Mdot
.3927 .10302 Mdot
.39488 .10407 Mdot
.3955 .10437 Mdot
.39747 .10532 Mdot
.3984 .10577 Mdot
.39937 .10625 Mdot
.40035 .10672 Mdot
.40247 .10776 Mdot
.40455 .10878 Mdot
.40558 .10929 Mdot
.40686 .10993 Mdot
.40886 .11093 Mdot
.4111 .11205 Mdot
.41209 .11255 Mdot
.41363 .11333 Mdot
.41589 .11448 Mdot
.41685 .11496 Mdot
.41755 .11532 Mdot
.41884 .11598 Mdot
.42107 .11713 Mdot
.42229 .11776 Mdot
.4232 .11823 Mdot
.4242 .11875 Mdot
.42638 .11988 Mdot
.42707 .12025 Mdot
.42855 .12102 Mdot
.4289 .1212 Mdot
.43221 .12295 Mdot
.43302 .12338 Mdot
.43519 .12454 Mdot
.43801 .12605 Mdot
.43857 .12635 Mdot
.44061 .12745 Mdot
.44171 .12805 Mdot
.44301 .12875 Mdot
.44385 .12921 Mdot
.44513 .12991 Mdot
.44587 .13032 Mdot
.44696 .13091 Mdot
.4493 .1322 Mdot
.45128 .13329 Mdot
.4539 .13475 Mdot
.45399 .13481 Mdot
.45739 .13671 Mdot
.45755 .1368 Mdot
.45963 .13797 Mdot
.46065 .13855 Mdot
.46233 .13951 Mdot
.46321 .14 Mdot
.46376 .14032 Mdot
.46603 .14162 Mdot
.46667 .14199 Mdot
.46836 .14296 Mdot
.46961 .14368 Mdot
.47136 .1447 Mdot
.47269 .14547 Mdot
.47376 .1461 Mdot
.47496 .1468 Mdot
.47508 .14687 Mdot
.47651 .14771 Mdot
.47832 .14877 Mdot
.48043 .15002 Mdot
.48207 .15099 Mdot
.4841 .1522 Mdot
.4857 .15316 Mdot
.48659 .15369 Mdot
.48799 .15454 Mdot
.48937 .15537 Mdot
.49057 .15609 Mdot
.49214 .15705 Mdot
.49349 .15787 Mdot
.49521 .15892 Mdot
.49542 .15905 Mdot
.49771 .16046 Mdot
.49804 .16066 Mdot
.50048 .16216 Mdot
.50158 .16285 Mdot
.50204 .16313 Mdot
.50271 .16355 Mdot
.50338 .16397 Mdot
.50482 .16486 Mdot
.50731 .16642 Mdot
.50838 .16709 Mdot
.50963 .16788 Mdot
.51146 .16903 Mdot
.51333 .17022 Mdot
.51438 .17088 Mdot
.51617 .17203 Mdot
.51635 .17215 Mdot
.51724 .17271 Mdot
.51946 .17414 Mdot
.52172 .17559 Mdot
.52225 .17594 Mdot
.52349 .17674 Mdot
.52566 .17815 Mdot
.52616 .17848 Mdot
.52727 .1792 Mdot
.52889 .18026 Mdot
.53069 .18144 Mdot
.53152 .18199 Mdot
.53276 .18281 Mdot
.53486 .1842 Mdot
.53544 .18458 Mdot
.53627 .18513 Mdot
.53693 .18557 Mdot
.5389 .18689 Mdot
.54095 .18826 Mdot
.54201 .18897 Mdot
.54311 .18971 Mdot
.54433 .19054 Mdot
.54609 .19173 Mdot
.54775 .19286 Mdot
.54912 .19379 Mdot
.54949 .19404 Mdot
.55198 .19574 Mdot
.55329 .19664 Mdot
.55484 .19771 Mdot
.5554 .1981 Mdot
.55686 .1991 Mdot
.55929 .20079 Mdot
.56087 .20189 Mdot
.56357 .20378 Mdot
.56464 .20453 Mdot
.56549 .20513 Mdot
.56653 .20585 Mdot
.56759 .2066 Mdot
.569 .2076 Mdot
.57075 .20884 Mdot
.57089 .20894 Mdot
.57379 .211 Mdot
.57437 .21142 Mdot
.57554 .21225 Mdot
.57616 .2127 Mdot
.57889 .21466 Mdot
.5796 .21517 Mdot
.58309 .2177 Mdot
.58336 .2179 Mdot
.58491 .21902 Mdot
.58572 .21961 Mdot
.5876 .22099 Mdot
.59 .22274 Mdot
.59184 .2241 Mdot
.59303 .22498 Mdot
.59552 .22682 Mdot
.59578 .22701 Mdot
.59787 .22857 Mdot
.59935 .22968 Mdot
.60103 .23093 Mdot
.60182 .23153 Mdot
.60465 .23365 Mdot
.60547 .23427 Mdot
.60712 .23552 Mdot
.60885 .23683 Mdot
.61015 .23782 Mdot
.61246 .23958 Mdot
.61297 .23997 Mdot
.61583 .24216 Mdot
.61788 .24374 Mdot
.61961 .24507 Mdot
.62043 .2457 Mdot
.6229 .24762 Mdot
.62393 .24842 Mdot
.6256 .24973 Mdot
.62777 .25143 Mdot
.6284 .25192 Mdot
.6303 .25341 Mdot
.63077 .25379 Mdot
.63161 .25445 Mdot
.63331 .25579 Mdot
.63463 .25683 Mdot
.63686 .2586 Mdot
.63828 .25974 Mdot
.63949 .2607 Mdot
.64184 .26259 Mdot
.64334 .26379 Mdot
.64506 .26517 Mdot
.64541 .26545 Mdot
.64677 .26655 Mdot
.64781 .2674 Mdot
.64991 .2691 Mdot
.65089 .2699 Mdot
.65241 .27114 Mdot
.65392 .27237 Mdot
.6548 .27309 Mdot
.65616 .2742 Mdot
.65768 .27545 Mdot
.65855 .27617 Mdot
.66041 .2777 Mdot
.66115 .27831 Mdot
.66241 .27936 Mdot
.66369 .28042 Mdot
.66468 .28124 Mdot
.66577 .28215 Mdot
.66832 .28428 Mdot
.66951 .28527 Mdot
.6707 .28627 Mdot
.67342 .28856 Mdot
.67347 .2886 Mdot
.67593 .29068 Mdot
.67665 .29129 Mdot
.67966 .29385 Mdot
.6804 .29448 Mdot
.6825 .29627 Mdot
.6844 .29789 Mdot
.68608 .29934 Mdot
.68724 .30034 Mdot
.68945 .30225 Mdot
.69027 .30296 Mdot
.69171 .3042 Mdot
.69327 .30555 Mdot
.69444 .30657 Mdot
.69633 .30822 Mdot
.69726 .30903 Mdot
.69831 .30995 Mdot
.699 .31055 Mdot
.69996 .3114 Mdot
.70216 .31333 Mdot
.70293 .31401 Mdot
.70418 .31511 Mdot
.70596 .31669 Mdot
.70824 .31871 Mdot
.7089 .3193 Mdot
.71044 .32066 Mdot
.71354 .32343 Mdot
.71508 .32482 Mdot
.71534 .32504 Mdot
.71823 .32765 Mdot
.7188 .32816 Mdot
.72093 .33008 Mdot
.72345 .33236 Mdot
.72413 .33299 Mdot
.72592 .33461 Mdot
.72643 .33508 Mdot
.72797 .33649 Mdot
.73034 .33865 Mdot
.731 .33926 Mdot
.73304 .34114 Mdot
.73464 .34261 Mdot
.7365 .34433 Mdot
.73736 .34512 Mdot
.73894 .34659 Mdot
.73926 .34688 Mdot
.74088 .34839 Mdot
.74333 .35068 Mdot
.74357 .3509 Mdot
.74606 .35323 Mdot
.74784 .3549 Mdot
.74809 .35513 Mdot
.74977 .35671 Mdot
.75209 .3589 Mdot
.75255 .35934 Mdot
.75607 .36268 Mdot
.75761 .36414 Mdot
.75864 .36513 Mdot
.75953 .36597 Mdot
.76139 .36775 Mdot
.76268 .36899 Mdot
.76399 .37025 Mdot
.7653 .37151 Mdot
.76596 .37214 Mdot
.76663 .37278 Mdot
.76882 .3749 Mdot
.77035 .37638 Mdot
.77273 .37869 Mdot
.77441 .38033 Mdot
.77556 .38145 Mdot
.77615 .38202 Mdot
.77788 .38371 Mdot
.77909 .3849 Mdot
.78053 .38631 Mdot
.78105 .38682 Mdot
.7832 .38894 Mdot
.78456 .39028 Mdot
.78628 .39198 Mdot
.7867 .3924 Mdot
.78874 .39442 Mdot
.78948 .39515 Mdot
.79152 .39719 Mdot
.7921 .39777 Mdot
.79375 .39941 Mdot
.79535 .40101 Mdot
.79654 .4022 Mdot
.79953 .4052 Mdot
.8019 .40759 Mdot
.80212 .40782 Mdot
.80349 .4092 Mdot
.80404 .40976 Mdot
.80534 .41108 Mdot
.80727 .41304 Mdot
.80781 .41359 Mdot
.80877 .41456 Mdot
.81249 .41836 Mdot
.81373 .41963 Mdot
.81548 .42144 Mdot
.81674 .42273 Mdot
.81795 .42397 Mdot
.81973 .42581 Mdot
.82058 .42669 Mdot
.82258 .42876 Mdot
.82291 .4291 Mdot
.82478 .43105 Mdot
.82573 .43203 Mdot
.8278 .43419 Mdot
.82871 .43514 Mdot
.82996 .43645 Mdot
.83017 .43667 Mdot
.83177 .43834 Mdot
.83261 .43922 Mdot
.83398 .44066 Mdot
.83506 .4418 Mdot
.83663 .44345 Mdot
.8368 .44363 Mdot
.83891 .44586 Mdot
.83958 .44657 Mdot
.84129 .44838 Mdot
.84163 .44874 Mdot
.84289 .45008 Mdot
.84529 .45263 Mdot
.84714 .45461 Mdot
.84788 .4554 Mdot
.84901 .45661 Mdot
.84998 .45765 Mdot
.85259 .46045 Mdot
.85336 .46128 Mdot
.85451 .46252 Mdot
.85529 .46336 Mdot
.85756 .46582 Mdot
.85956 .46798 Mdot
.86029 .46878 Mdot
.86352 .47228 Mdot
.86394 .47275 Mdot
.86523 .47415 Mdot
.86763 .47677 Mdot
.8686 .47784 Mdot
.87043 .47985 Mdot
.87187 .48143 Mdot
.87278 .48243 Mdot
.87379 .48355 Mdot
.87555 .4855 Mdot
.87622 .48623 Mdot
.87796 .48816 Mdot
.87905 .48937 Mdot
.87922 .48956 Mdot
.88228 .49296 Mdot
.88274 .49347 Mdot
.88417 .49507 Mdot
.88496 .49596 Mdot
.88722 .49848 Mdot
.88784 .49918 Mdot
.88935 .50088 Mdot
.89114 .50288 Mdot
.89267 .50461 Mdot
.89426 .5064 Mdot
.8954 .50769 Mdot
.89649 .50893 Mdot
.8979 .51052 Mdot
.89978 .51266 Mdot
.90111 .51417 Mdot
.90325 .51662 Mdot
.90473 .5183 Mdot
.90511 .51874 Mdot
.90718 .52111 Mdot
.90811 .52218 Mdot
.90888 .52306 Mdot
.91053 .52496 Mdot
.9131 .52791 Mdot
.91457 .52961 Mdot
.91599 .53126 Mdot
.91887 .5346 Mdot
.91992 .53582 Mdot
.9213 .53743 Mdot
.92295 .53934 Mdot
.92432 .54095 Mdot
.9267 .54374 Mdot
.92844 .54578 Mdot
.92895 .54637 Mdot
.93171 .54963 Mdot
.93283 .55094 Mdot
.93494 .55344 Mdot
.93523 .55378 Mdot
.93642 .55518 Mdot
.93703 .55591 Mdot
.93838 .55751 Mdot
.94029 .55978 Mdot
.94241 .5623 Mdot
.94353 .56364 Mdot
.94455 .56486 Mdot
.94508 .56549 Mdot
.94646 .56715 Mdot
.94774 .56868 Mdot
.94817 .56919 Mdot
.94903 .57022 Mdot
.95145 .57313 Mdot
.95223 .57408 Mdot
.95474 .57711 Mdot
.95605 .57869 Mdot
.95722 .58011 Mdot
.95869 .58189 Mdot
.9606 .58421 Mdot
.96121 .58495 Mdot
.96342 .58764 Mdot
.96425 .58865 Mdot
.96605 .59086 Mdot
.96711 .59214 Mdot
.96834 .59365 Mdot
.97098 .59689 Mdot
.97246 .59871 Mdot
.97385 .60043 Mdot
.97532 .60224 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(665) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00455121) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666493) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V100000020?[`iP<0
00001@3jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V000000000000103jl>H2000000D0n_3V0P0000030?[`iP030000003jl>H0n_3V00800000o`3j
l>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000@0
n_3V000000000000n_3V1P0000050?[`iP8000001@3jl>H200000?l0n_3VW03jl>H10?ooo`00803j
l>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H200000003
0?[`iP000000000000<000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
00000000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000
003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000050?[`iP0000000000
0?[`iP0000000P3jl>H2000000@0n_3V100000050?[`iP800000o`3jl>JL0?[`iP40oooo000P0?[`
iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP0000000000
0?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP800000
00<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V
100000030?[`iP@000000`3jl>H010000000n_3V0000000000030?[`iP80000000<0n_3V00000000
00000`3jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3jl>H00000
00000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`iPD00000
0P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`iP800000
00<0n_3V0000000000002@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H010000000n_3V
0000000000030?[`iP80000000<0n_3V0000000000001@3jl>H200000?l0n_3VW03jl>H10?ooo`00
803jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0U0?[`iP800000
00<0n_3V0000000000002P3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H3000000<0n_3V
0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V00800000o`3jl>JL0?[`iP40oooo
000O0?[`iPH00000103jl>H2000002l0n_3V1@00000X0?[`iP<00000303jl>H3000000@0n_3V0`00
00040?[`iP<00000103jl>H2000000@0n_3V0`0000040?[`iP<00000o`3jl>JM0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool003d0n_3V
1000003o0?[`i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3Vo`3jl>HG0?[`iP40oooo000P
0?[`iPH0000000D0n_3V00000000000000000?[`iP0300000080n_3V0`0000030?[`iP@000000`3j
l>H2000000040?[`iP00000000000?[`iPD000000`3jl>H<000002l0n_3V0`0000040?[`iP800000
1@3jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP800000
o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P00
00020?[`iP040000003jl>H00000000000<0n_3V00D000000?[`iP00000000000?[`iP0300000080
n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`iPD000002@3jl>H200000003
0?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000050?[`iP800000
0P3jl>H200000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000`0?[`iP800000
00<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000040?[`iPH0000000<0n_3V0000000000000P3j
l>H200000080n_3V0P0000050?[`iPD000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2
000000030?[`iP00000000000080n_3V0P0000040?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP<000000P3jl>H3000000030?[`iP000000n_3V00@0n_3V0P0000030?[`iP800000<03j
l>H2000000030?[`iP000000000000T0n_3V100000030?[`iP@000000`3jl>H4000000<0n_3V1000
00030?[`iP@000001P3jl>H200000?l0n_3VW@3jl>H10?ooo`008P3jl>H2000000<0n_3V1@000002
0?[`iPD000000`3jl>H4000000<0n_3V0P0000000`3jl>H0000000000004000000030?[`iP000000
00000080n_3V100000040?[`iP800000<03jl>H2000000030?[`iP000000000000T0n_3V0P000005
0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000203jl>H200000?l0n_3VW@3jl>H1
0?ooo`008P3jl>H2000000/0n_3V0P00000R0?[`iP800000<03jl>H2000000030?[`iP0000000000
00X0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000103jl>H00`00
0000n_3V0?[`iP0200000?l0n_3VW@3jl>H10?ooo`00803jl>H6000000T0n_3V0P00000P0?[`iP@0
0000<@3jl>H3000000`0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<0
00000P3jl>H500000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003j
l>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H010000000n_3V
0000003jl>H200000080n_3V00<000000?[`iP3jl>H00`00003o0?[`i_l0n_3V903jl>H10?ooo`00
803jl>H3000000030?[`iP00000000000080000000D0n_3V0000003jl>H000000?[`iP0300000080
n_3V00<000000?[`iP000000603jl>H500000=/0n_3V100000040?[`iP/00000103jl>H300000080
n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000@0n_3V00000000
00000000203jl>H4000000030?[`iP00000000000080n_3V100000020?[`iPD0000000L0n_3V0000
0000000000000?[`iP000000n_3V00<00000603jl>H3000000@0n_3V0P0000050?[`iP<00000103j
l>H3000000@0n_3V100000030?[`iP<00000103jl>H3000000<0n_3V1P0000000`3jl>H000000000
000300000080n_3V1P00001Y0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@000000
103jl>H000000000000000020?[`iP80000000<0n_3V0000000000002@3jl>H5000000T0n_3V0P00
003O0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@0
00000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003j
l>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP03
0000003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`iP02000000@0n_3V0P0000030?[`iP80
00001`3jl>H2000006/0n_3V0@3oool00280n_3V0`00000Y0?[`iP800000gP3jl>H2000000@0n_3V
0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V
0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP800000
00D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H200000003
0?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000@0n_3V000000000000n_3V1P0000050?[`iP8000001@3jl>H20000
00@0n_3V0P0000040?[`iP8000001P3jl>H2000006/0n_3V0@3oool00280n_3V0`00000J0?[`iPD0
00002`3jl>H200000=d0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H0
00000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3j
l>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000050?[`iP0000000000
0?[`iP0000000P3jl>H2000000H0n_3V0P0000050?[`iP800000103jl>H2000000D0n_3V0P000005
0?[`iP800000J`3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002X0n_3V0P00003L0?[`
iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2
000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2
000000030?[`iP000000000000X0n_3V0`000000103jl>H000000000003jl>H200000080n_3V0P00
00020?[`iP<0000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02000001P0n_3V0P00
00000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V00@000000?[`iP00000000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V
00<000000?[`iP3jl>H00P0000040?[`iP8000001P3jl>H2000000@0n_3V0P00001[0?[`iP40oooo
000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`iP00000000000=`0n_3V
0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD0
00000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0
000000<0n_3V0000000000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0
n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V00@000000?[`iP00000000000`3jl>H4000000<0n_3V100000050?[`
iP8000000`3jl>H2000000030?[`iP000000000000@0n_3V0P00001[0?[`iP40oooo001=0?[`iP80
000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP80
00008P3jl>H200000080n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000030?[`iP<000000`3jl>H2000000D0
n_3V0P0000050?[`iP@000000`3jl>H2000000030?[`iP00000000000080n_3V1000001[0?[`iP40
oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V
0P00000I0?[`iP<0000000<0n_3V0000000000000P00000^0?[`iP<000002`3jl>H3000000@0n_3V
0`0000050?[`iP8000000`3jl>H500000080n_3V1@0000040?[`iP800000103jl>H3000000D0n_3V
0P00001[0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0
n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`iP0000000P3jl>H010000000
n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0
000000<0n_3V0000000000000P000000103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V
00000080n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H3
00000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V
0000000000001P00000K0?[`iP<00000103jl>H3000000@0n_3V0`00002j0?[`iP40oooo000Q0?[`
iP80000000<0n_3V0000000000001@0000001@3jl>H00000000000000000n_3V00@000002`3jl>H5
000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P000002
0?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3j
l>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`
iP00000000000?[`iP8000000P3jl>H2000000/0n_3V1@0000090?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P00002i0?[`iP40
oooo000R0?[`iP<00000:03jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP800000
0P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000
0`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H4000001T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H200000;T0n_3V
0@3oool00280n_3V0`0000090?[`iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0
n_3V000000000000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P00
00040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00
000000000?[`iP@000003@3jl>H5000000T0n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V0000000000001@3jl>H200000;T0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000
000W0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP000000000000D0n_3V0P00
00020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V
0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080
n_3V0P00000I0?[`iP@000000`3jl>H4000000<0n_3V00<000000?[`iP3jl>H00P00002i0?[`iP40
oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`iP00000000000=`0
n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`
iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@0000030?[`
iPD000006@3jl>H2000000D0n_3V0P0000050?[`iP@00000^P3jl>H10?ooo`00C@3jl>H200000003
0?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2000003T0
n_3V0P0000050?[`iP800000103jl>H200000;`0n_3V0@3oool004h0n_3V0`00003L0?[`iPD00000
4@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H200000380n_3V0`0000040?[`iP<00000
0P3jl>H500000;T0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo000M0?[`iRH0oooP0P00001/0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D0
0000J@3oon0500000080oooP0P0000040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`00
7@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000203oon001000
0000oooP0?ooh000001/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon001`3oon00
10000000oooP0?ooh000001Z0?ooh0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU
0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002`3oon000`000000oooP
0?ooh01Z0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon002P3oon000`000000oooP
0?ooh01Y0?ooh0030000003oon00oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003o
on00oooP000006X0oooP00@000000?ooh03oon0000002@3oon02000006d0oooP00<000000?ooh03o
on00J`3oon000`000000oooP0?ooh0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0
n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP0000
00T0oooP00<000000?ooh03oon00K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP
00P0oooP00<000000?ooh03oon00JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool0
01d0n_3V9P3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?oo
h0<00000J`3oon02000002@0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o
00000>X00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP
00<000000?ooh03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP
00P0oooP5000003o0?ooh<X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80
oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0070?ooh2@00000o`3oon2k0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP
100000060?ooh08000006P000?lB00000?l0oooP[P3oon04000001P0oooP7P3jl>H10?ooo`007@3j
l>H:0?ooh0@00000103oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP00P0oooP6`00
00080000oa400000o`3oon2Z0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB
0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon0A0<f5?a4000002P000?l?
00000?l0oooPXP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon020000
00P0oooP00<000000?ooh03oon002@3oon0P0<f5?``000002@000?l<00000?l0oooPW03oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh2X0
cHDo2`0000080000o`T00000o`3oon2G0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP<P3=QCl;000000D0003o2@00003o0?ooh980oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on0j0<f5?`P000001@000?l:00000?l0oooPS03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh3l0cHDo200000050000o`T00000o`3oon28
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooPA@3=QCl7000000D0003o2000003o0?ooh8@0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1:0<f5?`L000001@000?l800000?l0
oooPO`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh4l0cHDo1`0000040000o`L00000o`3oon1l0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPE03=QCl6000000D0003o1P00
003o0?ooh7P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon1H0<f5?`L0000010000?l600000?l0oooPM03oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh5d0cHDo1P0000040000
o`H00000o`3oon1`0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
00002@3oon1P0<f5?`L000000`000?l600000?l0oooPJ`3oon03000001P0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPI03=QCl6000000@0003o1@00003o0?ooh6X0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on1W0<f5?`L000000`000?l500000?l0oooPI`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh6/0cHDo1P0000040000o`D00000o`3oon1S
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooPK`3=QCl6000000<0003o1@00003o0?ooh600oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1b0<f5?`H000000`000?l400000?l0
oooPGP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh7H0cHDo1@0000020000o`H00000o`3oon1J0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPN@3=QCl4000000<0003o1@00
003o0?ooh5P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon1l0<f5?`@000000`000?l500000?l0oooPE@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh7h0cHDo1@0000020000
o`H00000o`3oon1B0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooPPP3=QCl3000000<0003o1P00003o0?ooh4l0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon250<f5?`<00000
0`000?l500000?l0oooPC@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh8L0cHDo100000030000o`D00000o`3oon1:0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPRP3=QCl4
00000080003o1@00003o0?ooh4P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`0000090?ooh8`0cHDo100000030000o`D00000o`3oon130?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2?0<f5?`@000000`000?l500000?l0
oooP@P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh940cHDo1@0000020000o`D00000o`3oon100?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPU03=QCl4000000<0003o1@00
003o0?ooh3d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon2G0<f5?`@000000`000?l400000?l0oooP>`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh9X0cHDo100000020000
o`@00000o`3oon0i0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooPW03=QCl400000080003o1000003o0?ooh3L0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2N0<f5?`@00000
0P000?l400000?l0oooP=@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh:40cHDo0`0000020000o`D00000o`3oon0b0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPX`3=QCl3
000000<0003o1000003o0?ooh300oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon2U0<f5?`@000000P000?l400000?l0oooP;P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh:P0
cHDo0`0000020000o`D00000o`3oon0[0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPZ@3=QCl400000080003o1000003o0?ooh2X0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on2/0<f5?`<000000`000?l300000?l0oooP:03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh:h0cHDo100000020000o`@00000o`3oon0U
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon2`0<f5
?`@000000P000?l400000?l0oooP8@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP/P3=QCl400000080003o1000003o0?ooh240oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2d0<f5?`@00000
0P000?l300000?l0oooP803oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh;H0cHDo100000020000o`<00000o`3oon0N0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP^@3=QCl3
00000080003o1000003o0?ooh1/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon2k0<f5?`<000000P000?l300000?l0oooP6P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh;`0
cHDo100000020000o`<00000o`3oon0H0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP_P3=QCl400000080003o0`00003o0?ooh1H0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on310<f5?`<000000P000?l300000?l0oooP503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh<80cHDo100000020000o`<00000o`3oon0B
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooPa03=QCl400000080003o0`00003o0?ooh100oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon360<f5?`@0000000<0003o00000000
00000P00003o0?ooh0h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon380<f5?`<000000P000?l400000?l0oooP303oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh<X0cHDo0`00
00020000o`<00000o`3oon0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<000002@3oon3<0<f5?`<0000000@0003o0000000000000000o`3oon080?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon3>0<f5?`8000000P000?l4
00000?l0oooP1`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh=00cHDo0P0000020000o`@00000o`3oon050?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPd@3=QCl300000080
003o0`00003o0?ooh0@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon3C0<f5?`<0000000<0003o0000000000000P00003o0?ooh080oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on3E0<f5?`8000000P000?l400000?l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon3G0<f5?`8000000P000?l400000?d0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon3H0<f5
?`<000000P000?l400000?/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon3J0<f5?`<0000000<0003o0000000000000P00003j0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP
g03=QCl200000080003o1000003h0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooPgP3=QCl200000080003o1000003f0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPg`3=QCl3
000000030000o`000000000000800000m@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3oon3P0<f5?`<000000P000?l30000
0?@0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03o
on0000001`3oon000`000000oooP0?ooh0090?ooh>80cHDo0`0000020000o`<00000lP3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?oo
h0@00000203oon3W00000080003oj00000080?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ00
oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03_0?ooh0<0000000H0003o0000
00000000000003>QbP2]f>J303>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00
oooP000000L0oooP00<000000?ooh03oon00l@3oon0200000080003o0`00002303>QbP030:gHiP0c
XLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03b0?ooh0<0000000@0003o
0000000000000000PP0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03d
0?ooh08000000P000?l300000800<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00m@3oon03000000030000o`000000000000800000OP0cXLX00`2]f>H0<j7:03>QbP1603>Q
bP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03g0?ooh08000000P000?l3000007d0<j7:00<0[MSV03>QbP0c
XLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n03oon03000000030000o`000000000000800000
N`0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03j0?ooh080000000<0
003o0000000000000P00001j03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?/0oooP0P0000020000o`<00000N@0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0
<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03m0?ooh080000000<0003o0000000000000P00001g03>QbP030:gHiP0cXLX0<j7:
04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?h0oooP0P0000020000o`<00000MP0cXLX00`2]f>H0
<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh040oooP0P0000000`000?l00000
00000002000007@0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on020?ooh08000000P000?l400000780<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>Q
bP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon040?ooh080000000<0003o0000000000000P00001a03>QbP030:gHiP0cXLX0
<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon050?ooh08000000P000?l4000006l0<j7:00<0[MSV03>Q
bP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh0L0oooP0P0000000`000?l0000000000002000006h0
<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon090?ooh0030000
00000?l0003o00<00000K@0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh0X0oooP0P0000000`000?l0000000000002000006/0<j7:00<0[MSV03>QbP0cXLX0AP0c
XLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0;0?ooh08000000P000?l3000006X0<j7:00<0[MSV
03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0=0?ooh080000000<0003o0000
000000000P00001X03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP3P3oon0200000080003o0`00001W03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0c
XLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP403oon02000000040000o`0000000000000006H0<j7:00<0[MSV03>QbP0c
XLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0A0?ooh08000000P000?l3000006@0<j7:
00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0B0?ooh0<0000000@0
003o0000000000000000H`0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh1@0oooP0P0000020000o`800000HP0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0c
XLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh1D0oooP0`00000010000?l0000000000000001P03>QbP030:gHiP0c
XLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP5P3oon0300000080003o0P00001O
03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP603oon030000
00040000o`0000000000000005d0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?oo
h1X0oooP0P0000020000o`800000G00cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:
01<0<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP6`3oon03000000040000o`0000000000000005X0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]
f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0L0?ooh0<0000000@0003o0000000000000000F@0cXLX00`2]
f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1h0oooP0P0000020000o`<0
0000E`0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1l0oooP
0`00000010000?l0000000000000001F03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0c
XLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP803oon03000000040000o`0000000000000005D0<j7:00<0[MSV03>QbP0c
XLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0R0?ooh08000000P000?l2000005@0<j7:
00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0S0?ooh0<0000000<0
003o000000000000D`0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh2@0oooP0`0000000`000?l000000000001B03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV
03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP9P3oon0200000080003o0P00001@03>QbP030:gHiP0cXLX0<j7:
04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP9`3oon03000000040000o`00000000000000
04h0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0X0?ooh0<0
000000@0003o0000000000000000C@0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:
01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh2X0oooP0P0000020000o`800000C00cXLX00`2]f>H0<j7:03>QbP1603>QbP03
0:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh2/0oooP0`00000010000?l0000000000000001:03>QbP03
0:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0/0?ooh0<0000000@0003o000000000000
0000B@0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2@3oon03000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;@3oon0300000080003o
0P00001803>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;`3o
on03000000030000o`000000000004L0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>Q
bP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0`0?ooh0<0000000@0003o0000000000000000A@0cXLX00`2]f>H0<j7:03>Q
bP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh340oooP0`00000010000?l0000000000000
001403>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<P3oon03
00000080003o0P00001303>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP=03oon03000000030000o`00000000000480<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]
f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0e0?ooh0<0000000<0003o000000000000@@0cXLX00`2]f>H0
<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3H0oooP0`0000020000o`800000
?`0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3P0oooP0`00
00000`000?l000000000000n03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP>@3oon03000000030000o`000000000003d0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX0
0`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0j0?ooh0<0000000<0003o000000000000?00cXLX00`2]
f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3/0oooP0`0000020000o`80
0000>P0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3`0oooP
100000000`000?l000000000000i03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX0
4`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP?@3oon04000000030000o`000000000003P0<j7:00<0[MSV03>QbP0cXLX0AP0c
XLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh3l0oooP0`0000000`000?l000000000000g03>QbP030:gHiP0cXLX0
<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon100?ooh0<0000000@0003o0000000000000000=@0cXLX0
0`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh440oooP0`0000001000
0?l0000000000000000d03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP@`3oon0200000080003o00<0000003>QbP0cXLX0<P0cXLX00`2]f>H0<j7:03>QbP1603>Q
bP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh4@0oooP0`0000000`000?l0000003>QbP0b03>QbP03
0:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPA@3oon03000000030000
o`00000000000340<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on160?ooh0<0000000<0003o000000000000<00cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0c
XLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh4L0oooP0`0000000`000?l000000000000_03>QbP030:gHiP0cXLX0
<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB@3oon02000000040000o`0000000000
000002d0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1:0?oo
h080000000@0003o0000000000000000;00cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0
<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh4/0oooP0P00000010000?l0000000000000000[03>QbP030:gHiP0cXLX0
<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPC03oon02000000040000o`0000000000
000002X0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP
0?l0oooPC@3oon0200000080003o0P00000Y03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>Q
bP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh003
0000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1>0?ooh0<0000000<0003o00000000
0000:00cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000
o`3oon1?0?ooh080000000<0003o0000000000009`0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gH
iP0cXLX0<j7:01<0<j7:203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003o
on00oooP00H0oooP00<000000?ooh03oon00o`3oon1A0?ooh080000000@0003o0000000000000000
9@0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003o
on00oooP0?l0oooPDP3oon02000000040000o`0000000000000002@0<j7:00<0[MSV03>QbP0cXLX0
AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPD`3oon02000000040000o`00
00000000000002<0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1D0?ooh080000000@0003o00000000000000008P0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gH
iP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh5H0oooP00<000000000o`0000000P00000Q03>QbP030:gHiP0c
XLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPEP3oon02000000040000o`000000
000000000200<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1G
0?ooh08000000P000?l2000001l0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon1H0?ooh0<0000000<0003o0000000000007P0cXLX00`2]f>H0<j7:03>QbP1603>Q
bP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh5T0oooP0`0000000`000?l000000000000M03>QbP03
0:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF`3oon02000000040000
o`0000000000000001/0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1L0?ooh080000000@0003o00000000000000006P0cXLX00`2]f>H0<j7:03>QbP1603>QbP03
0:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh5d0oooP0P00000010000?l0000000000000000I03>QbP03
0:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPGP3oon02000000040000
o`0000000000000001P0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh5l0oooP
0P00000010000?l0000000000000000G03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0c
XLX04`0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1P0?ooh080000000@0003o00000000000000005P0cXLX00`2]f>H0<j7:03>QbP1603>QbP03
0:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh680oooP00<000000000o`000?l00P00000E03>QbP030:gH
iP0cXLX0<j7:04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH`3oon02000000030000o`00
0000000001@0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1T
0?ooh080000000<0003o0000000000004`0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0
<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh6D0oooP0P0000000`000?l000000000000B03>QbP030:gHiP0cXLX0<j7:
04H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPIP3oon02000000030000o`00000000000140
<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W0?ooh0800000
00<0003o000000000000400cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh6P0oooP0P0000000`000?l000000000000?03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0
[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPJ@3oon02000000030000o`000000000000h0<j7:00<0[MSV
03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Z0?ooh080000000<0003o0000
000000003@0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6/0
oooP0P00000010000?l0000000000000000;03>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>Q
bP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPK03oon02000000040000o`0000000000000000X0<j7:00<0[MSV03>Q
bP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1]0?ooh080000000@0003o00000000
000000002@0cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6h0
oooP0P00000010000?l0000000000000000803>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>Q
bP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon1_0?ooh08000000P000?l2000000L0<j7:00<0[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0
<j7:03>QbP0C03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh700oooP0`0000000`000?l000000000000603>QbP030:gHiP0cXLX0<j7:04H0<j7:
00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPL@3oon03000000030000o`000000000000D0<j7:00<0
[MSV03>QbP0cXLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1b0?ooh0<0000000<0003o
000000000000100cXLX00`2]f>H0<j7:03>QbP1603>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h7<0oooP0`0000000`000?l000000000000303>QbP030:gHiP0cXLX0<j7:04H0<j7:00<0[MSV03>Q
bP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPM03oon03000000030000o`00000000000080<j7:00<0[MSV03>QbP0c
XLX0AP0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1f0?ooh080000000D0003o000000000000
<j7:0:gHiP1803>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7L0oooP0P00000010000?l00000
0000002]f>I803>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7P0oooP0P0000000`000?l00000
0000001803>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7T0oooP0P0000000`000?l000000000
001703>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7X0oooP0P0000000`000?l0000000000016
03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7/0oooP0P0000000`000?l000000000001503>Q
bP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP0P0000000`000?l000000000001403>QbP03
0:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh7d0oooP0P0000000`000?l000000000001303>QbP030:gH
iP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on0300000?l0oooPOP3oon02000000030000o`00000000000480<j7:00<0[MSV03>QbP0cXLX04`0c
XLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1o
0?ooh080000000<0003o000000000000@@0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon200?oo
h080000000<0003o000000000000@00cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon210?ooh080
000000<0003o000000000000?`0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon220?ooh0800000
00<0003o000000000000?P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon230?ooh080000000<0
003o000000000000?@0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon240?ooh080000000<0003o
000000000000?00cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon250?ooh080000000<0003o0000
00000000>`0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon260?ooh080000000<0003o00000000
0000>P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon270?ooh080000000<0003o000000000000
>@0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon280?ooh080000000<0003o000000000000>00c
XLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon290?ooh080000000<0003o000000000000=`0cXLX0
0`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2:0?ooh080000000<0003o000000000000=P0cXLX00`2]
f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2;0?ooh080000000<0003o000000000000=@0cXLX00`2]f>H0
<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`00003o0?ooh8/0oooP0`0000000`000?l000000000000d03>QbP030:gHiP0cXLX0<j7:01<0<j7:
2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPS03o
on03000000030000o`000000000003<0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPSP3oon02
000000030000o`00000000000380<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPS`3oon020000
00030000o`00000000000340<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT03oon0200000003
0000o`00000000000300<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT03oon02000000030000
o`00000000000300<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT@3oon02000000040000o`00
00000000000002h0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPTP3oon02000000040000o`00
00000000000002d0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPT`3oon02000000040000o`00
00000000000002`0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU03oon02000000040000o`00
00000000000002/0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU@3oon02000000040000o`00
00000000000002X0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPUP3oon02000000030000o`00
0000000002X0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPU`3oon02000000040000o`000000
0000000002P0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>H@0?ooh0@000001`3oon000`000000oooP0?ooh03o0?ooh9P0oooP0P000000
10000?l0000000000000000W03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh0080?ooh0030000003oon00
oooP0?l0oooPV@3oon02000000030000o`000000000002L0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0030000003oon00oooP
00L0oooP1000003o0?ooh9T0oooP00<000000000o`0000000P00000V03>QbP030:gHiP0cXLX0<j7:
01<0<j7:203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0
oooP00<000000?ooh03oon00o`3oon2K0?ooh003000000000?l00000008000009@0cXLX00`2]f>H0
<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP
00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh9`0oooP00<000000000o`00
00000P00000T03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon2M0?ooh0030000
00000?l00000008000008`0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2N0?ooh00300000000
0?l00000008000008P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2O0?ooh003000000000?l0
0000008000008@0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2P0?ooh003000000000?l00000
00800000800cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Q0?ooh003000000000?l000000080
00007`0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2R0?ooh003000000000?l0000000800000
7P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2R0?ooh080000000@0003o0000000000000000
7@0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2S0?ooh080000000<0003o0000000000007@0c
XLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2T0?ooh080000000<0003o000000000000700cXLX0
0`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2U0?ooh080000000<0003o0000000000006`0cXLX00`2]
f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2V0?ooh080000000<0003o0000000000006P0cXLX00`2]f>H0
<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`00003o0?ooh:L0oooP0P0000000`000?l000000000000I03>QbP030:gHiP0cXLX0<j7:01<0<j7:
2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY`3o
on03000000030000o`000000000001P0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ03oon02
000000040000o`0000000000000001L0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ@3oon02
000000040000o`0000000000000001H0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZP3oon02
000000040000o`0000000000000001D0<j7:00<0[MSV03>QbP0cXLX04`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[03oon00
10000000003o00000000000E03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:`0oooP0P000000
0`000?l000000000000D03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP0P0000000`00
0?l000000000000C03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:h0oooP0P0000000`000?l0
00000000000B03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:l0oooP0P0000000`000?l00000
0000000A03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;00oooP0P0000000`000?l000000000
000@03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;40oooP0P0000000`000?l000000000000?
03>QbP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;80oooP0P0000000`000?l0000003>QbP0>03>Q
bP030:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh;80oooP0`0000000`000?l0000003>QbP0=03>QbP03
0:gHiP0cXLX0<j7:01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon0300000?l0oooP/`3oon03000000030000o`000000<j7:00`0<j7:00<0[MSV03>QbP0cXLX0
4`0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2d0?ooh0<0000000<0003o0000000cXLX02`0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2e
0?ooh080000000<0003o0000000000002`0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2f0?oo
h080000000<0003o0000000000002P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh080
000000<0003o0000000000002@0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2h0?ooh0800000
00<0003o000000000000200cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2h0?ooh0<0000000<0
003o0000000000001`0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2i0?ooh0<0000000<0003o
0000000cXLX01P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh080000000@0003o0000
0000000000001@0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2k0?ooh080000000@0003o0000
000000000000100cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2l0?ooh080000000<0003o0000
00000000100cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2m0?ooh080000000<0003o00000000
00000`0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n0?ooh080000000<0003o0000000cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2n0?ooh0<0000000D0003o0000000cXLX0<j7:
0:gHiP0E03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2o0?ooh080000000D0003o000000000000<j7:0:gHiP0E03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh<00oooP0P00
000010000?l000000000002]f>HE03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<40oooP0P0000000`000?l000000000000E03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon32
0?ooh080000000<0003o000000000000500cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP``3oon02000000030000o`0000000000
01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh<@0oooP0P0000000`000?l000000000000B03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon340?ooh0800000
00<0003o0000000000004P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPa@3oon02000000030000o`00000000000140<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<H0oooP0P0000000`000?l000000000000@03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon370?ooh080000000<0003o0000
000000003`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPb03oon02000000030000o`000000000000h0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<T0oooP
0P0000000`000?l000000000000=03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?ooh080000000@0003o0000000000000000
300cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPbP3oon02000000030000o`000000000000`0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh</0oooP0P000000
0`000?l000000000000;03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP0`00003o0?ooh<`0oooP0P0000000`000?l000000000000:03>QbPT0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<d0oooP0P0000000`000?l0
00000000000903>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon3>0?ooh080000000<0003o000000000000200cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPc`3o
on02000000030000o`000000<j7:00L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<l0oooP0P0000000`000?l0000000000007
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon3@0?ooh080000000<0003o0000000000001P0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd@3oon0200000003
0000o`000000000000D0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh=80oooP0P0000000`000?l000000000000403>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on3C0?ooh080000000<0003o0000000000000`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe03oon02000000030000o`000000
00000080<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh=@0oooP0`00000010000?l0000003>QbP0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe@3oon020000
00040000o`000000000003>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPeP3oon02000000030000o`0000000000
00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03o
on0000001`3oon000`000000oooP0?ooh03o0?ooh=L0oooP0P0000000`000?l000000000000:0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0
oooP1000003o0?ooh=H0oooP0`0000000`000?l000000?ooh0060?ooh0@00000603oon0N0?[`iP40
oooo000M0?[`iQ<0oooP00<000000?ooh03oon001@3oon000`000000oooP0?ooh03o0?ooh=P0oooP
0`00000;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003o
on00oooP000000L0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh>H0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP
0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03o
on00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP
0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=`0n_3V100000020?[`iPP000000P3j
l>H4000000070?[`iP00000000000000003jl>H000000?[`iP0<000000030?[`iP000000000000@0
000000@0n_3V0000000000000000203jl>H5000000@0n_3V1`0000000`3jl>H000000?[`iP030000
00T0n_3V1@0000020?[`iP@000000P3jl>H500000180n_3V1P0000060?[`iP030000003jl>H0n_3V
00@0n_3V0`000000103jl>H0000000000000003T0?[`iP40oooo003M0?[`iP8000000P3jl>H20000
00<0n_3V0P0000030?[`iP8000000`3jl>H01`000000n_3V000000000000n_3V0000003jl>H01000
00020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00090?[`iP040000003jl>H0n_3V0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80
000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80
00005P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000>D0
n_3V0@3oool00=d0n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000D0n_3V
0P0000000`3jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000d0n_3V0P0000020?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P00000<0?[`iPD000001@3jl>H2000000H0n_3V1@0000060?[`iP<00000iP3jl>H10?ooo`00
g@3jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H20000
00030?[`iP000000000000<000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H2
000000P0n_3V00<000000?[`iP3jl>H01P3jl>H300000>H0n_3V0@3oool00=d0n_3V0P0000020?[`
iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003j
l>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H00000
0?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H00000
0?[`iP0B0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000
i@3jl>H10?ooo`00g@3jl>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V1000
00000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P00
00050?[`iP<0000000<0n_3V0000000000001`00000;0?[`iPD000000P3jl>H400000080n_3V0`00
00000`3jl>H000000000000C0?[`iP8000003`3jl>H3000000050?[`iP00000000000000003jl>H0
1000003O0?[`iP40oooo003M0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003j
l>H0n_3V01P0n_3V0P00000Q0?[`iP@00000603jl>H00`000000n_3V0?[`iP3O0?[`iP40oooo003L
0?[`iPH00000103jl>H2000002l0n_3V1@00000K0?[`iP<000008@3jl>H2000001T0n_3V00<00000
0?[`iP3jl>H0gP3jl>H10?ooo`00o`3jl>Ih0?[`iP030000003jl>H0n_3V0=d0n_3V0@3oool00?l0
n_3VM@3jl>H010000000n_3V0?[`iP00003O0?[`iP40oooo003o0?[`iWH0n_3V0P00003P0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02489 .01472 L
.02489 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02489 .01472 L
.02489 .16187 L
s
1 .894 .882 r
.02489 .16187 m
.02489 .01472 L
.02567 .01472 L
.02567 .16187 L
F
.804 .522 .247 r
.02489 .16187 m
.02489 .01472 L
.02567 .01472 L
.02567 .16187 L
s
1 .894 .882 r
.02567 .16187 m
.02567 .01472 L
.02683 .01472 L
.02683 .16187 L
F
.804 .522 .247 r
.02567 .16187 m
.02567 .01472 L
.02683 .01472 L
.02683 .16187 L
s
1 .894 .882 r
.02683 .16187 m
.02683 .01472 L
.02741 .01472 L
.02741 .16187 L
F
.804 .522 .247 r
.02683 .16187 m
.02683 .01472 L
.02741 .01472 L
.02741 .16187 L
s
1 .894 .882 r
.02741 .16187 m
.02741 .01472 L
.02896 .01472 L
.02896 .16187 L
F
.804 .522 .247 r
.02741 .16187 m
.02741 .01472 L
.02896 .01472 L
.02896 .16187 L
s
1 .894 .882 r
.02896 .16187 m
.02896 .01473 L
.02963 .01473 L
.02963 .16187 L
F
.804 .522 .247 r
.02896 .16187 m
.02896 .01473 L
.02963 .01473 L
.02963 .16187 L
s
1 .894 .882 r
.02963 .16187 m
.02963 .01474 L
.03074 .01474 L
.03074 .16187 L
F
.804 .522 .247 r
.02963 .16187 m
.02963 .01474 L
.03074 .01474 L
.03074 .16187 L
s
1 .894 .882 r
.03074 .16187 m
.03074 .01475 L
.03147 .01475 L
.03147 .16187 L
F
.804 .522 .247 r
.03074 .16187 m
.03074 .01475 L
.03147 .01475 L
.03147 .16187 L
s
1 .894 .882 r
.03147 .16187 m
.03147 .01476 L
.03265 .01476 L
.03265 .16187 L
F
.804 .522 .247 r
.03147 .16187 m
.03147 .01476 L
.03265 .01476 L
.03265 .16187 L
s
1 .894 .882 r
.03265 .16187 m
.03265 .01477 L
.03376 .01477 L
.03376 .16187 L
F
.804 .522 .247 r
.03265 .16187 m
.03265 .01477 L
.03376 .01477 L
.03376 .16187 L
s
1 .894 .882 r
.03376 .16187 m
.03376 .01478 L
.03444 .01478 L
.03444 .16187 L
F
.804 .522 .247 r
.03376 .16187 m
.03376 .01478 L
.03444 .01478 L
.03444 .16187 L
s
1 .894 .882 r
.03444 .16187 m
.03444 .01481 L
.03592 .01481 L
.03592 .16187 L
F
.804 .522 .247 r
.03444 .16187 m
.03444 .01481 L
.03592 .01481 L
.03592 .16187 L
s
1 .894 .882 r
.03592 .16187 m
.03592 .01482 L
.0365 .01482 L
.0365 .16187 L
F
.804 .522 .247 r
.03592 .16187 m
.03592 .01482 L
.0365 .01482 L
.0365 .16187 L
s
1 .894 .882 r
.0365 .16187 m
.0365 .01483 L
.03788 .01483 L
.03788 .16187 L
F
.804 .522 .247 r
.0365 .16187 m
.0365 .01483 L
.03788 .01483 L
.03788 .16187 L
s
1 .894 .882 r
.03788 .16187 m
.03788 .01486 L
.03945 .01486 L
.03945 .16187 L
F
.804 .522 .247 r
.03788 .16187 m
.03788 .01486 L
.03945 .01486 L
.03945 .16187 L
s
1 .894 .882 r
.03945 .16187 m
.03945 .01487 L
.04007 .01487 L
.04007 .16187 L
F
.804 .522 .247 r
.03945 .16187 m
.03945 .01487 L
.04007 .01487 L
.04007 .16187 L
s
1 .894 .882 r
.04007 .16187 m
.04007 .01492 L
.04163 .01492 L
.04163 .16187 L
F
.804 .522 .247 r
.04007 .16187 m
.04007 .01492 L
.04163 .01492 L
.04163 .16187 L
s
1 .894 .882 r
.04163 .16187 m
.04163 .01494 L
.04292 .01494 L
.04292 .16187 L
F
.804 .522 .247 r
.04163 .16187 m
.04163 .01494 L
.04292 .01494 L
.04292 .16187 L
s
1 .894 .882 r
.04292 .16187 m
.04292 .01496 L
.04423 .01496 L
.04423 .16187 L
F
.804 .522 .247 r
.04292 .16187 m
.04292 .01496 L
.04423 .01496 L
.04423 .16187 L
s
1 .894 .882 r
.04423 .16187 m
.04423 .015 L
.04587 .015 L
.04587 .16187 L
F
.804 .522 .247 r
.04423 .16187 m
.04423 .015 L
.04587 .015 L
.04587 .16187 L
s
1 .894 .882 r
.04587 .16187 m
.04587 .01508 L
.0475 .01508 L
.0475 .16187 L
F
.804 .522 .247 r
.04587 .16187 m
.04587 .01508 L
.0475 .01508 L
.0475 .16187 L
s
1 .894 .882 r
.0475 .16187 m
.0475 .0151 L
.04897 .0151 L
.04897 .16187 L
F
.804 .522 .247 r
.0475 .16187 m
.0475 .0151 L
.04897 .0151 L
.04897 .16187 L
s
1 .894 .882 r
.04897 .16187 m
.04897 .01515 L
.05052 .01515 L
.05052 .16187 L
F
.804 .522 .247 r
.04897 .16187 m
.04897 .01515 L
.05052 .01515 L
.05052 .16187 L
s
1 .894 .882 r
.05052 .16187 m
.05052 .01519 L
.05147 .01519 L
.05147 .16187 L
F
.804 .522 .247 r
.05052 .16187 m
.05052 .01519 L
.05147 .01519 L
.05147 .16187 L
s
1 .894 .882 r
.05147 .16187 m
.05147 .01522 L
.05254 .01522 L
.05254 .16187 L
F
.804 .522 .247 r
.05147 .16187 m
.05147 .01522 L
.05254 .01522 L
.05254 .16187 L
s
1 .894 .882 r
.05254 .16187 m
.05254 .01526 L
.05375 .01526 L
.05375 .16187 L
F
.804 .522 .247 r
.05254 .16187 m
.05254 .01526 L
.05375 .01526 L
.05375 .16187 L
s
1 .894 .882 r
.05375 .16187 m
.05375 .01532 L
.05464 .01532 L
.05464 .16187 L
F
.804 .522 .247 r
.05375 .16187 m
.05375 .01532 L
.05464 .01532 L
.05464 .16187 L
s
1 .894 .882 r
.05464 .16187 m
.05464 .01534 L
.05553 .01534 L
.05553 .16187 L
F
.804 .522 .247 r
.05464 .16187 m
.05464 .01534 L
.05553 .01534 L
.05553 .16187 L
s
1 .894 .882 r
.05553 .16187 m
.05553 .01538 L
.05676 .01538 L
.05676 .16187 L
F
.804 .522 .247 r
.05553 .16187 m
.05553 .01538 L
.05676 .01538 L
.05676 .16187 L
s
1 .894 .882 r
.05676 .16187 m
.05676 .01542 L
.05781 .01542 L
.05781 .16187 L
F
.804 .522 .247 r
.05676 .16187 m
.05676 .01542 L
.05781 .01542 L
.05781 .16187 L
s
1 .894 .882 r
.05781 .16187 m
.05781 .01549 L
.0593 .01549 L
.0593 .16187 L
F
.804 .522 .247 r
.05781 .16187 m
.05781 .01549 L
.0593 .01549 L
.0593 .16187 L
s
1 .894 .882 r
.0593 .16187 m
.0593 .01556 L
.05997 .01556 L
.05997 .16187 L
F
.804 .522 .247 r
.0593 .16187 m
.0593 .01556 L
.05997 .01556 L
.05997 .16187 L
s
1 .894 .882 r
.05997 .16187 m
.05997 .01559 L
.06054 .01559 L
.06054 .16187 L
F
.804 .522 .247 r
.05997 .16187 m
.05997 .01559 L
.06054 .01559 L
.06054 .16187 L
s
1 .894 .882 r
.06054 .16187 m
.06054 .01559 L
.06218 .01559 L
.06218 .16187 L
F
.804 .522 .247 r
.06054 .16187 m
.06054 .01559 L
.06218 .01559 L
.06218 .16187 L
s
1 .894 .882 r
.06218 .16187 m
.06218 .01568 L
.06352 .01568 L
.06352 .16187 L
F
.804 .522 .247 r
.06218 .16187 m
.06218 .01568 L
.06352 .01568 L
.06352 .16187 L
s
1 .894 .882 r
.06352 .16187 m
.06352 .01578 L
.06442 .01578 L
.06442 .16187 L
F
.804 .522 .247 r
.06352 .16187 m
.06352 .01578 L
.06442 .01578 L
.06442 .16187 L
s
1 .894 .882 r
.06442 .16187 m
.06442 .0158 L
.06611 .0158 L
.06611 .16187 L
F
.804 .522 .247 r
.06442 .16187 m
.06442 .0158 L
.06611 .0158 L
.06611 .16187 L
s
1 .894 .882 r
.06611 .16187 m
.06611 .0159 L
.0669 .0159 L
.0669 .16187 L
F
.804 .522 .247 r
.06611 .16187 m
.06611 .0159 L
.0669 .0159 L
.0669 .16187 L
s
1 .894 .882 r
.0669 .16187 m
.0669 .01597 L
.06837 .01597 L
.06837 .16187 L
F
.804 .522 .247 r
.0669 .16187 m
.0669 .01597 L
.06837 .01597 L
.06837 .16187 L
s
1 .894 .882 r
.06837 .16187 m
.06837 .01605 L
.06917 .01605 L
.06917 .16187 L
F
.804 .522 .247 r
.06837 .16187 m
.06837 .01605 L
.06917 .01605 L
.06917 .16187 L
s
1 .894 .882 r
.06917 .16187 m
.06917 .01606 L
.06981 .01606 L
.06981 .16187 L
F
.804 .522 .247 r
.06917 .16187 m
.06917 .01606 L
.06981 .01606 L
.06981 .16187 L
s
1 .894 .882 r
.06981 .16187 m
.06981 .0161 L
.07102 .0161 L
.07102 .16187 L
F
.804 .522 .247 r
.06981 .16187 m
.06981 .0161 L
.07102 .0161 L
.07102 .16187 L
s
1 .894 .882 r
.07102 .16187 m
.07102 .01618 L
.07169 .01618 L
.07169 .16187 L
F
.804 .522 .247 r
.07102 .16187 m
.07102 .01618 L
.07169 .01618 L
.07169 .16187 L
s
1 .894 .882 r
.07169 .16187 m
.07169 .01624 L
.07256 .01624 L
.07256 .16187 L
F
.804 .522 .247 r
.07169 .16187 m
.07169 .01624 L
.07256 .01624 L
.07256 .16187 L
s
1 .894 .882 r
.07256 .16187 m
.07256 .01627 L
.07329 .01627 L
.07329 .16187 L
F
.804 .522 .247 r
.07256 .16187 m
.07256 .01627 L
.07329 .01627 L
.07329 .16187 L
s
1 .894 .882 r
.07329 .16187 m
.07329 .01637 L
.07473 .01637 L
.07473 .16187 L
F
.804 .522 .247 r
.07329 .16187 m
.07329 .01637 L
.07473 .01637 L
.07473 .16187 L
s
1 .894 .882 r
.07473 .16187 m
.07473 .0164 L
.07558 .0164 L
.07558 .16187 L
F
.804 .522 .247 r
.07473 .16187 m
.07473 .0164 L
.07558 .0164 L
.07558 .16187 L
s
1 .894 .882 r
.07558 .16187 m
.07558 .01649 L
.07721 .01649 L
.07721 .16187 L
F
.804 .522 .247 r
.07558 .16187 m
.07558 .01649 L
.07721 .01649 L
.07721 .16187 L
s
1 .894 .882 r
.07721 .16187 m
.07721 .01666 L
.07858 .01666 L
.07858 .16187 L
F
.804 .522 .247 r
.07721 .16187 m
.07721 .01666 L
.07858 .01666 L
.07858 .16187 L
s
1 .894 .882 r
.07858 .16187 m
.07858 .01668 L
.07933 .01668 L
.07933 .16187 L
F
.804 .522 .247 r
.07858 .16187 m
.07858 .01668 L
.07933 .01668 L
.07933 .16187 L
s
1 .894 .882 r
.07933 .16187 m
.07933 .01677 L
.08099 .01677 L
.08099 .16187 L
F
.804 .522 .247 r
.07933 .16187 m
.07933 .01677 L
.08099 .01677 L
.08099 .16187 L
s
1 .894 .882 r
.08099 .16187 m
.08099 .01685 L
.08225 .01685 L
.08225 .16187 L
F
.804 .522 .247 r
.08099 .16187 m
.08099 .01685 L
.08225 .01685 L
.08225 .16187 L
s
1 .894 .882 r
.08225 .16187 m
.08225 .01697 L
.08291 .01697 L
.08291 .16187 L
F
.804 .522 .247 r
.08225 .16187 m
.08225 .01697 L
.08291 .01697 L
.08291 .16187 L
s
1 .894 .882 r
.08291 .16187 m
.08291 .01702 L
.08431 .01702 L
.08431 .16187 L
F
.804 .522 .247 r
.08291 .16187 m
.08291 .01702 L
.08431 .01702 L
.08431 .16187 L
s
1 .894 .882 r
.08431 .16187 m
.08431 .0171 L
.085 .0171 L
.085 .16187 L
F
.804 .522 .247 r
.08431 .16187 m
.08431 .0171 L
.085 .0171 L
.085 .16187 L
s
1 .894 .882 r
.085 .16187 m
.085 .01716 L
.0861 .01716 L
.0861 .16187 L
F
.804 .522 .247 r
.085 .16187 m
.085 .01716 L
.0861 .01716 L
.0861 .16187 L
s
1 .894 .882 r
.0861 .16187 m
.0861 .01728 L
.0867 .01728 L
.0867 .16187 L
F
.804 .522 .247 r
.0861 .16187 m
.0861 .01728 L
.0867 .01728 L
.0867 .16187 L
s
1 .894 .882 r
.0867 .16187 m
.0867 .01732 L
.08817 .01732 L
.08817 .16187 L
F
.804 .522 .247 r
.0867 .16187 m
.0867 .01732 L
.08817 .01732 L
.08817 .16187 L
s
1 .894 .882 r
.08817 .16187 m
.08817 .01741 L
.08924 .01741 L
.08924 .16187 L
F
.804 .522 .247 r
.08817 .16187 m
.08817 .01741 L
.08924 .01741 L
.08924 .16187 L
s
1 .894 .882 r
.08924 .16187 m
.08924 .01751 L
.08995 .01751 L
.08995 .16187 L
F
.804 .522 .247 r
.08924 .16187 m
.08924 .01751 L
.08995 .01751 L
.08995 .16187 L
s
1 .894 .882 r
.08995 .16187 m
.08995 .01759 L
.09057 .01759 L
.09057 .16187 L
F
.804 .522 .247 r
.08995 .16187 m
.08995 .01759 L
.09057 .01759 L
.09057 .16187 L
s
1 .894 .882 r
.09057 .16187 m
.09057 .01768 L
.09177 .01768 L
.09177 .16187 L
F
.804 .522 .247 r
.09057 .16187 m
.09057 .01768 L
.09177 .01768 L
.09177 .16187 L
s
1 .894 .882 r
.09177 .16187 m
.09177 .01776 L
.09308 .01776 L
.09308 .16187 L
F
.804 .522 .247 r
.09177 .16187 m
.09177 .01776 L
.09308 .01776 L
.09308 .16187 L
s
1 .894 .882 r
.09308 .16187 m
.09308 .01786 L
.0947 .01786 L
.0947 .16187 L
F
.804 .522 .247 r
.09308 .16187 m
.09308 .01786 L
.0947 .01786 L
.0947 .16187 L
s
1 .894 .882 r
.0947 .16187 m
.0947 .01806 L
.09638 .01806 L
.09638 .16187 L
F
.804 .522 .247 r
.0947 .16187 m
.0947 .01806 L
.09638 .01806 L
.09638 .16187 L
s
1 .894 .882 r
.09638 .16187 m
.09638 .01816 L
.0969 .01816 L
.0969 .16187 L
F
.804 .522 .247 r
.09638 .16187 m
.09638 .01816 L
.0969 .01816 L
.0969 .16187 L
s
1 .894 .882 r
.0969 .16187 m
.0969 .01829 L
.09804 .01829 L
.09804 .16187 L
F
.804 .522 .247 r
.0969 .16187 m
.0969 .01829 L
.09804 .01829 L
.09804 .16187 L
s
1 .894 .882 r
.09804 .16187 m
.09804 .01837 L
.09931 .01837 L
.09931 .16187 L
F
.804 .522 .247 r
.09804 .16187 m
.09804 .01837 L
.09931 .01837 L
.09931 .16187 L
s
1 .894 .882 r
.09931 .16187 m
.09931 .01845 L
.10078 .01845 L
.10078 .16187 L
F
.804 .522 .247 r
.09931 .16187 m
.09931 .01845 L
.10078 .01845 L
.10078 .16187 L
s
1 .894 .882 r
.10078 .16187 m
.10078 .01863 L
.10156 .01863 L
.10156 .16187 L
F
.804 .522 .247 r
.10078 .16187 m
.10078 .01863 L
.10156 .01863 L
.10156 .16187 L
s
1 .894 .882 r
.10156 .16187 m
.10156 .01872 L
.10238 .01872 L
.10238 .16187 L
F
.804 .522 .247 r
.10156 .16187 m
.10156 .01872 L
.10238 .01872 L
.10238 .16187 L
s
1 .894 .882 r
.10238 .16187 m
.10238 .01877 L
.10372 .01877 L
.10372 .16187 L
F
.804 .522 .247 r
.10238 .16187 m
.10238 .01877 L
.10372 .01877 L
.10372 .16187 L
s
1 .894 .882 r
.10372 .16187 m
.10372 .01888 L
.10433 .01888 L
.10433 .16187 L
F
.804 .522 .247 r
.10372 .16187 m
.10372 .01888 L
.10433 .01888 L
.10433 .16187 L
s
1 .894 .882 r
.10433 .16187 m
.10433 .01895 L
.10488 .01895 L
.10488 .16187 L
F
.804 .522 .247 r
.10433 .16187 m
.10433 .01895 L
.10488 .01895 L
.10488 .16187 L
s
1 .894 .882 r
.10488 .16187 m
.10488 .01902 L
.10574 .01902 L
.10574 .16187 L
F
.804 .522 .247 r
.10488 .16187 m
.10488 .01902 L
.10574 .01902 L
.10574 .16187 L
s
1 .894 .882 r
.10574 .16187 m
.10574 .01909 L
.10635 .01909 L
.10635 .16187 L
F
.804 .522 .247 r
.10574 .16187 m
.10574 .01909 L
.10635 .01909 L
.10635 .16187 L
s
1 .894 .882 r
.10635 .16187 m
.10635 .01922 L
.10801 .01922 L
.10801 .16187 L
F
.804 .522 .247 r
.10635 .16187 m
.10635 .01922 L
.10801 .01922 L
.10801 .16187 L
s
1 .894 .882 r
.10801 .16187 m
.10801 .01933 L
.10887 .01933 L
.10887 .16187 L
F
.804 .522 .247 r
.10801 .16187 m
.10801 .01933 L
.10887 .01933 L
.10887 .16187 L
s
1 .894 .882 r
.10887 .16187 m
.10887 .01944 L
.10956 .01944 L
.10956 .16187 L
F
.804 .522 .247 r
.10887 .16187 m
.10887 .01944 L
.10956 .01944 L
.10956 .16187 L
s
1 .894 .882 r
.10956 .16187 m
.10956 .0195 L
.11078 .0195 L
.11078 .16187 L
F
.804 .522 .247 r
.10956 .16187 m
.10956 .0195 L
.11078 .0195 L
.11078 .16187 L
s
1 .894 .882 r
.11078 .16187 m
.11078 .01972 L
.11235 .01972 L
.11235 .16187 L
F
.804 .522 .247 r
.11078 .16187 m
.11078 .01972 L
.11235 .01972 L
.11235 .16187 L
s
1 .894 .882 r
.11235 .16187 m
.11235 .0199 L
.11344 .0199 L
.11344 .16187 L
F
.804 .522 .247 r
.11235 .16187 m
.11235 .0199 L
.11344 .0199 L
.11344 .16187 L
s
1 .894 .882 r
.11344 .16187 m
.11344 .01998 L
.11478 .01998 L
.11478 .16187 L
F
.804 .522 .247 r
.11344 .16187 m
.11344 .01998 L
.11478 .01998 L
.11478 .16187 L
s
1 .894 .882 r
.11478 .16187 m
.11478 .02019 L
.1158 .02019 L
.1158 .16187 L
F
.804 .522 .247 r
.11478 .16187 m
.11478 .02019 L
.1158 .02019 L
.1158 .16187 L
s
1 .894 .882 r
.1158 .16187 m
.1158 .02034 L
.11727 .02034 L
.11727 .16187 L
F
.804 .522 .247 r
.1158 .16187 m
.1158 .02034 L
.11727 .02034 L
.11727 .16187 L
s
1 .894 .882 r
.11727 .16187 m
.11727 .0204 L
.11887 .0204 L
.11887 .16187 L
F
.804 .522 .247 r
.11727 .16187 m
.11727 .0204 L
.11887 .0204 L
.11887 .16187 L
s
1 .894 .882 r
.11887 .16187 m
.11887 .02064 L
.11942 .02064 L
.11942 .16187 L
F
.804 .522 .247 r
.11887 .16187 m
.11887 .02064 L
.11942 .02064 L
.11942 .16187 L
s
1 .894 .882 r
.11942 .16187 m
.11942 .02073 L
.12053 .02073 L
.12053 .16187 L
F
.804 .522 .247 r
.11942 .16187 m
.11942 .02073 L
.12053 .02073 L
.12053 .16187 L
s
1 .894 .882 r
.12053 .16187 m
.12053 .02083 L
.12202 .02083 L
.12202 .16187 L
F
.804 .522 .247 r
.12053 .16187 m
.12053 .02083 L
.12202 .02083 L
.12202 .16187 L
s
1 .894 .882 r
.12202 .16187 m
.12202 .02109 L
.12362 .02109 L
.12362 .16187 L
F
.804 .522 .247 r
.12202 .16187 m
.12202 .02109 L
.12362 .02109 L
.12362 .16187 L
s
1 .894 .882 r
.12362 .16187 m
.12362 .02131 L
.12474 .02131 L
.12474 .16187 L
F
.804 .522 .247 r
.12362 .16187 m
.12362 .02131 L
.12474 .02131 L
.12474 .16187 L
s
1 .894 .882 r
.12474 .16187 m
.12474 .02153 L
.12629 .02153 L
.12629 .16187 L
F
.804 .522 .247 r
.12474 .16187 m
.12474 .02153 L
.12629 .02153 L
.12629 .16187 L
s
1 .894 .882 r
.12629 .16187 m
.12629 .02153 L
.12683 .02153 L
.12683 .16187 L
F
.804 .522 .247 r
.12629 .16187 m
.12629 .02153 L
.12683 .02153 L
.12683 .16187 L
s
1 .894 .882 r
.12683 .16187 m
.12683 .02172 L
.12816 .02172 L
.12816 .16187 L
F
.804 .522 .247 r
.12683 .16187 m
.12683 .02172 L
.12816 .02172 L
.12816 .16187 L
s
1 .894 .882 r
.12816 .16187 m
.12816 .02189 L
.12898 .02189 L
.12898 .16187 L
F
.804 .522 .247 r
.12816 .16187 m
.12816 .02189 L
.12898 .02189 L
.12898 .16187 L
s
1 .894 .882 r
.12898 .16187 m
.12898 .02196 L
.1297 .02196 L
.1297 .16187 L
F
.804 .522 .247 r
.12898 .16187 m
.12898 .02196 L
.1297 .02196 L
.1297 .16187 L
s
1 .894 .882 r
.1297 .16187 m
.1297 .02216 L
.13134 .02216 L
.13134 .16187 L
F
.804 .522 .247 r
.1297 .16187 m
.1297 .02216 L
.13134 .02216 L
.13134 .16187 L
s
1 .894 .882 r
.13134 .16187 m
.13134 .02226 L
.13263 .02226 L
.13263 .16187 L
F
.804 .522 .247 r
.13134 .16187 m
.13134 .02226 L
.13263 .02226 L
.13263 .16187 L
s
1 .894 .882 r
.13263 .16187 m
.13263 .02252 L
.1343 .02252 L
.1343 .16187 L
F
.804 .522 .247 r
.13263 .16187 m
.13263 .02252 L
.1343 .02252 L
.1343 .16187 L
s
1 .894 .882 r
.1343 .16187 m
.1343 .02267 L
.13493 .02267 L
.13493 .16187 L
F
.804 .522 .247 r
.1343 .16187 m
.1343 .02267 L
.13493 .02267 L
.13493 .16187 L
s
1 .894 .882 r
.13493 .16187 m
.13493 .0228 L
.13662 .0228 L
.13662 .16187 L
F
.804 .522 .247 r
.13493 .16187 m
.13493 .0228 L
.13662 .0228 L
.13662 .16187 L
s
1 .894 .882 r
.13662 .16187 m
.13662 .02299 L
.13757 .02299 L
.13757 .16187 L
F
.804 .522 .247 r
.13662 .16187 m
.13662 .02299 L
.13757 .02299 L
.13757 .16187 L
s
1 .894 .882 r
.13757 .16187 m
.13757 .02315 L
.13906 .02315 L
.13906 .16187 L
F
.804 .522 .247 r
.13757 .16187 m
.13757 .02315 L
.13906 .02315 L
.13906 .16187 L
s
1 .894 .882 r
.13906 .16187 m
.13906 .02339 L
.14019 .02339 L
.14019 .16187 L
F
.804 .522 .247 r
.13906 .16187 m
.13906 .02339 L
.14019 .02339 L
.14019 .16187 L
s
1 .894 .882 r
.14019 .16187 m
.14019 .02358 L
.14081 .02358 L
.14081 .16187 L
F
.804 .522 .247 r
.14019 .16187 m
.14019 .02358 L
.14081 .02358 L
.14081 .16187 L
s
1 .894 .882 r
.14081 .16187 m
.14081 .02367 L
.14238 .02367 L
.14238 .16187 L
F
.804 .522 .247 r
.14081 .16187 m
.14081 .02367 L
.14238 .02367 L
.14238 .16187 L
s
1 .894 .882 r
.14238 .16187 m
.14238 .02393 L
.14304 .02393 L
.14304 .16187 L
F
.804 .522 .247 r
.14238 .16187 m
.14238 .02393 L
.14304 .02393 L
.14304 .16187 L
s
1 .894 .882 r
.14304 .16187 m
.14304 .02399 L
.14367 .02399 L
.14367 .16187 L
F
.804 .522 .247 r
.14304 .16187 m
.14304 .02399 L
.14367 .02399 L
.14367 .16187 L
s
1 .894 .882 r
.14367 .16187 m
.14367 .02417 L
.14454 .02417 L
.14454 .16187 L
F
.804 .522 .247 r
.14367 .16187 m
.14367 .02417 L
.14454 .02417 L
.14454 .16187 L
s
1 .894 .882 r
.14454 .16187 m
.14454 .02422 L
.14621 .02422 L
.14621 .16187 L
F
.804 .522 .247 r
.14454 .16187 m
.14454 .02422 L
.14621 .02422 L
.14621 .16187 L
s
1 .894 .882 r
.14621 .16187 m
.14621 .02454 L
.14685 .02454 L
.14685 .16187 L
F
.804 .522 .247 r
.14621 .16187 m
.14621 .02454 L
.14685 .02454 L
.14685 .16187 L
s
1 .894 .882 r
.14685 .16187 m
.14685 .0247 L
.14807 .0247 L
.14807 .16187 L
F
.804 .522 .247 r
.14685 .16187 m
.14685 .0247 L
.14807 .0247 L
.14807 .16187 L
s
1 .894 .882 r
.14807 .16187 m
.14807 .02487 L
.14916 .02487 L
.14916 .16187 L
F
.804 .522 .247 r
.14807 .16187 m
.14807 .02487 L
.14916 .02487 L
.14916 .16187 L
s
1 .894 .882 r
.14916 .16187 m
.14916 .02497 L
.14975 .02497 L
.14975 .16187 L
F
.804 .522 .247 r
.14916 .16187 m
.14916 .02497 L
.14975 .02497 L
.14975 .16187 L
s
1 .894 .882 r
.14975 .16187 m
.14975 .02502 L
.15098 .02502 L
.15098 .16187 L
F
.804 .522 .247 r
.14975 .16187 m
.14975 .02502 L
.15098 .02502 L
.15098 .16187 L
s
1 .894 .882 r
.15098 .16187 m
.15098 .0254 L
.15236 .0254 L
.15236 .16187 L
F
.804 .522 .247 r
.15098 .16187 m
.15098 .0254 L
.15236 .0254 L
.15236 .16187 L
s
1 .894 .882 r
.15236 .16187 m
.15236 .02557 L
.15342 .02557 L
.15342 .16187 L
F
.804 .522 .247 r
.15236 .16187 m
.15236 .02557 L
.15342 .02557 L
.15342 .16187 L
s
1 .894 .882 r
.15342 .16187 m
.15342 .02577 L
.15439 .02577 L
.15439 .16187 L
F
.804 .522 .247 r
.15342 .16187 m
.15342 .02577 L
.15439 .02577 L
.15439 .16187 L
s
1 .894 .882 r
.15439 .16187 m
.15439 .0258 L
.15532 .0258 L
.15532 .16187 L
F
.804 .522 .247 r
.15439 .16187 m
.15439 .0258 L
.15532 .0258 L
.15532 .16187 L
s
1 .894 .882 r
.15532 .16187 m
.15532 .02598 L
.15649 .02598 L
.15649 .16187 L
F
.804 .522 .247 r
.15532 .16187 m
.15532 .02598 L
.15649 .02598 L
.15649 .16187 L
s
1 .894 .882 r
.15649 .16187 m
.15649 .02633 L
.15762 .02633 L
.15762 .16187 L
F
.804 .522 .247 r
.15649 .16187 m
.15649 .02633 L
.15762 .02633 L
.15762 .16187 L
s
1 .894 .882 r
.15762 .16187 m
.15762 .02652 L
.15902 .02652 L
.15902 .16187 L
F
.804 .522 .247 r
.15762 .16187 m
.15762 .02652 L
.15902 .02652 L
.15902 .16187 L
s
1 .894 .882 r
.15902 .16187 m
.15902 .02668 L
.15999 .02668 L
.15999 .16187 L
F
.804 .522 .247 r
.15902 .16187 m
.15902 .02668 L
.15999 .02668 L
.15999 .16187 L
s
1 .894 .882 r
.15999 .16187 m
.15999 .0269 L
.16104 .0269 L
.16104 .16187 L
F
.804 .522 .247 r
.15999 .16187 m
.15999 .0269 L
.16104 .0269 L
.16104 .16187 L
s
1 .894 .882 r
.16104 .16187 m
.16104 .02708 L
.1622 .02708 L
.1622 .16187 L
F
.804 .522 .247 r
.16104 .16187 m
.16104 .02708 L
.1622 .02708 L
.1622 .16187 L
s
1 .894 .882 r
.1622 .16187 m
.1622 .02726 L
.16316 .02726 L
.16316 .16187 L
F
.804 .522 .247 r
.1622 .16187 m
.1622 .02726 L
.16316 .02726 L
.16316 .16187 L
s
1 .894 .882 r
.16316 .16187 m
.16316 .02741 L
.16435 .02741 L
.16435 .16187 L
F
.804 .522 .247 r
.16316 .16187 m
.16316 .02741 L
.16435 .02741 L
.16435 .16187 L
s
1 .894 .882 r
.16435 .16187 m
.16435 .02767 L
.16598 .02767 L
.16598 .16187 L
F
.804 .522 .247 r
.16435 .16187 m
.16435 .02767 L
.16598 .02767 L
.16598 .16187 L
s
1 .894 .882 r
.16598 .16187 m
.16598 .02801 L
.16703 .02801 L
.16703 .16187 L
F
.804 .522 .247 r
.16598 .16187 m
.16598 .02801 L
.16703 .02801 L
.16703 .16187 L
s
1 .894 .882 r
.16703 .16187 m
.16703 .0281 L
.16814 .0281 L
.16814 .16187 L
F
.804 .522 .247 r
.16703 .16187 m
.16703 .0281 L
.16814 .0281 L
.16814 .16187 L
s
1 .894 .882 r
.16814 .16187 m
.16814 .02835 L
.16918 .02835 L
.16918 .16187 L
F
.804 .522 .247 r
.16814 .16187 m
.16814 .02835 L
.16918 .02835 L
.16918 .16187 L
s
1 .894 .882 r
.16918 .16187 m
.16918 .02843 L
.1707 .02843 L
.1707 .16187 L
F
.804 .522 .247 r
.16918 .16187 m
.16918 .02843 L
.1707 .02843 L
.1707 .16187 L
s
1 .894 .882 r
.1707 .16187 m
.1707 .02884 L
.17139 .02884 L
.17139 .16187 L
F
.804 .522 .247 r
.1707 .16187 m
.1707 .02884 L
.17139 .02884 L
.17139 .16187 L
s
1 .894 .882 r
.17139 .16187 m
.17139 .02889 L
.17254 .02889 L
.17254 .16187 L
F
.804 .522 .247 r
.17139 .16187 m
.17139 .02889 L
.17254 .02889 L
.17254 .16187 L
s
1 .894 .882 r
.17254 .16187 m
.17254 .02918 L
.17346 .02918 L
.17346 .16187 L
F
.804 .522 .247 r
.17254 .16187 m
.17254 .02918 L
.17346 .02918 L
.17346 .16187 L
s
1 .894 .882 r
.17346 .16187 m
.17346 .02927 L
.17426 .02927 L
.17426 .16187 L
F
.804 .522 .247 r
.17346 .16187 m
.17346 .02927 L
.17426 .02927 L
.17426 .16187 L
s
1 .894 .882 r
.17426 .16187 m
.17426 .02945 L
.17559 .02945 L
.17559 .16187 L
F
.804 .522 .247 r
.17426 .16187 m
.17426 .02945 L
.17559 .02945 L
.17559 .16187 L
s
1 .894 .882 r
.17559 .16187 m
.17559 .02978 L
.17665 .02978 L
.17665 .16187 L
F
.804 .522 .247 r
.17559 .16187 m
.17559 .02978 L
.17665 .02978 L
.17665 .16187 L
s
1 .894 .882 r
.17665 .16187 m
.17665 .03002 L
.17805 .03002 L
.17805 .16187 L
F
.804 .522 .247 r
.17665 .16187 m
.17665 .03002 L
.17805 .03002 L
.17805 .16187 L
s
1 .894 .882 r
.17805 .16187 m
.17805 .03023 L
.17919 .03023 L
.17919 .16187 L
F
.804 .522 .247 r
.17805 .16187 m
.17805 .03023 L
.17919 .03023 L
.17919 .16187 L
s
1 .894 .882 r
.17919 .16187 m
.17919 .03045 L
.17997 .03045 L
.17997 .16187 L
F
.804 .522 .247 r
.17919 .16187 m
.17919 .03045 L
.17997 .03045 L
.17997 .16187 L
s
1 .894 .882 r
.17997 .16187 m
.17997 .03061 L
.18057 .03061 L
.18057 .16187 L
F
.804 .522 .247 r
.17997 .16187 m
.17997 .03061 L
.18057 .03061 L
.18057 .16187 L
s
1 .894 .882 r
.18057 .16187 m
.18057 .03075 L
.18156 .03075 L
.18156 .16187 L
F
.804 .522 .247 r
.18057 .16187 m
.18057 .03075 L
.18156 .03075 L
.18156 .16187 L
s
1 .894 .882 r
.18156 .16187 m
.18156 .03092 L
.18323 .03092 L
.18323 .16187 L
F
.804 .522 .247 r
.18156 .16187 m
.18156 .03092 L
.18323 .03092 L
.18323 .16187 L
s
1 .894 .882 r
.18323 .16187 m
.18323 .03134 L
.18459 .03134 L
.18459 .16187 L
F
.804 .522 .247 r
.18323 .16187 m
.18323 .03134 L
.18459 .03134 L
.18459 .16187 L
s
1 .894 .882 r
.18459 .16187 m
.18459 .03166 L
.18552 .03166 L
.18552 .16187 L
F
.804 .522 .247 r
.18459 .16187 m
.18459 .03166 L
.18552 .03166 L
.18552 .16187 L
s
1 .894 .882 r
.18552 .16187 m
.18552 .03177 L
.18604 .03177 L
.18604 .16187 L
F
.804 .522 .247 r
.18552 .16187 m
.18552 .03177 L
.18604 .03177 L
.18604 .16187 L
s
1 .894 .882 r
.18604 .16187 m
.18604 .03188 L
.18719 .03188 L
.18719 .16187 L
F
.804 .522 .247 r
.18604 .16187 m
.18604 .03188 L
.18719 .03188 L
.18719 .16187 L
s
1 .894 .882 r
.18719 .16187 m
.18719 .03215 L
.1879 .03215 L
.1879 .16187 L
F
.804 .522 .247 r
.18719 .16187 m
.18719 .03215 L
.1879 .03215 L
.1879 .16187 L
s
1 .894 .882 r
.1879 .16187 m
.1879 .03225 L
.18957 .03225 L
.18957 .16187 L
F
.804 .522 .247 r
.1879 .16187 m
.1879 .03225 L
.18957 .03225 L
.18957 .16187 L
s
1 .894 .882 r
.18957 .16187 m
.18957 .03263 L
.19062 .03263 L
.19062 .16187 L
F
.804 .522 .247 r
.18957 .16187 m
.18957 .03263 L
.19062 .03263 L
.19062 .16187 L
s
1 .894 .882 r
.19062 .16187 m
.19062 .03301 L
.19184 .03301 L
.19184 .16187 L
F
.804 .522 .247 r
.19062 .16187 m
.19062 .03301 L
.19184 .03301 L
.19184 .16187 L
s
1 .894 .882 r
.19184 .16187 m
.19184 .03329 L
.19321 .03329 L
.19321 .16187 L
F
.804 .522 .247 r
.19184 .16187 m
.19184 .03329 L
.19321 .03329 L
.19321 .16187 L
s
1 .894 .882 r
.19321 .16187 m
.19321 .03353 L
.19429 .03353 L
.19429 .16187 L
F
.804 .522 .247 r
.19321 .16187 m
.19321 .03353 L
.19429 .03353 L
.19429 .16187 L
s
1 .894 .882 r
.19429 .16187 m
.19429 .03367 L
.19481 .03367 L
.19481 .16187 L
F
.804 .522 .247 r
.19429 .16187 m
.19429 .03367 L
.19481 .03367 L
.19481 .16187 L
s
1 .894 .882 r
.19481 .16187 m
.19481 .03397 L
.19623 .03397 L
.19623 .16187 L
F
.804 .522 .247 r
.19481 .16187 m
.19481 .03397 L
.19623 .03397 L
.19623 .16187 L
s
1 .894 .882 r
.19623 .16187 m
.19623 .03425 L
.19742 .03425 L
.19742 .16187 L
F
.804 .522 .247 r
.19623 .16187 m
.19623 .03425 L
.19742 .03425 L
.19742 .16187 L
s
1 .894 .882 r
.19742 .16187 m
.19742 .03451 L
.19907 .03451 L
.19907 .16187 L
F
.804 .522 .247 r
.19742 .16187 m
.19742 .03451 L
.19907 .03451 L
.19907 .16187 L
s
1 .894 .882 r
.19907 .16187 m
.19907 .0347 L
.20038 .0347 L
.20038 .16187 L
F
.804 .522 .247 r
.19907 .16187 m
.19907 .0347 L
.20038 .0347 L
.20038 .16187 L
s
1 .894 .882 r
.20038 .16187 m
.20038 .03513 L
.20151 .03513 L
.20151 .16187 L
F
.804 .522 .247 r
.20038 .16187 m
.20038 .03513 L
.20151 .03513 L
.20151 .16187 L
s
1 .894 .882 r
.20151 .16187 m
.20151 .03547 L
.20308 .03547 L
.20308 .16187 L
F
.804 .522 .247 r
.20151 .16187 m
.20151 .03547 L
.20308 .03547 L
.20308 .16187 L
s
1 .894 .882 r
.20308 .16187 m
.20308 .03559 L
.20418 .03559 L
.20418 .16187 L
F
.804 .522 .247 r
.20308 .16187 m
.20308 .03559 L
.20418 .03559 L
.20418 .16187 L
s
1 .894 .882 r
.20418 .16187 m
.20418 .03608 L
.2058 .03608 L
.2058 .16187 L
F
.804 .522 .247 r
.20418 .16187 m
.20418 .03608 L
.2058 .03608 L
.2058 .16187 L
s
1 .894 .882 r
.2058 .16187 m
.2058 .03626 L
.20632 .03626 L
.20632 .16187 L
F
.804 .522 .247 r
.2058 .16187 m
.2058 .03626 L
.20632 .03626 L
.20632 .16187 L
s
1 .894 .882 r
.20632 .16187 m
.20632 .03642 L
.20762 .03642 L
.20762 .16187 L
F
.804 .522 .247 r
.20632 .16187 m
.20632 .03642 L
.20762 .03642 L
.20762 .16187 L
s
1 .894 .882 r
.20762 .16187 m
.20762 .03675 L
.20862 .03675 L
.20862 .16187 L
F
.804 .522 .247 r
.20762 .16187 m
.20762 .03675 L
.20862 .03675 L
.20862 .16187 L
s
1 .894 .882 r
.20862 .16187 m
.20862 .03695 L
.20978 .03695 L
.20978 .16187 L
F
.804 .522 .247 r
.20862 .16187 m
.20862 .03695 L
.20978 .03695 L
.20978 .16187 L
s
1 .894 .882 r
.20978 .16187 m
.20978 .03719 L
.21033 .03719 L
.21033 .16187 L
F
.804 .522 .247 r
.20978 .16187 m
.20978 .03719 L
.21033 .03719 L
.21033 .16187 L
s
1 .894 .882 r
.21033 .16187 m
.21033 .03762 L
.21198 .03762 L
.21198 .16187 L
F
.804 .522 .247 r
.21033 .16187 m
.21033 .03762 L
.21198 .03762 L
.21198 .16187 L
s
1 .894 .882 r
.21198 .16187 m
.21198 .03778 L
.21257 .03778 L
.21257 .16187 L
F
.804 .522 .247 r
.21198 .16187 m
.21198 .03778 L
.21257 .03778 L
.21257 .16187 L
s
1 .894 .882 r
.21257 .16187 m
.21257 .03795 L
.21371 .03795 L
.21371 .16187 L
F
.804 .522 .247 r
.21257 .16187 m
.21257 .03795 L
.21371 .03795 L
.21371 .16187 L
s
1 .894 .882 r
.21371 .16187 m
.21371 .03836 L
.21484 .03836 L
.21484 .16187 L
F
.804 .522 .247 r
.21371 .16187 m
.21371 .03836 L
.21484 .03836 L
.21484 .16187 L
s
1 .894 .882 r
.21484 .16187 m
.21484 .03841 L
.21629 .03841 L
.21629 .16187 L
F
.804 .522 .247 r
.21484 .16187 m
.21484 .03841 L
.21629 .03841 L
.21629 .16187 L
s
1 .894 .882 r
.21629 .16187 m
.21629 .03883 L
.21692 .03883 L
.21692 .16187 L
F
.804 .522 .247 r
.21629 .16187 m
.21629 .03883 L
.21692 .03883 L
.21692 .16187 L
s
1 .894 .882 r
.21692 .16187 m
.21692 .03892 L
.21753 .03892 L
.21753 .16187 L
F
.804 .522 .247 r
.21692 .16187 m
.21692 .03892 L
.21753 .03892 L
.21753 .16187 L
s
1 .894 .882 r
.21753 .16187 m
.21753 .03947 L
.21914 .03947 L
.21914 .16187 L
F
.804 .522 .247 r
.21753 .16187 m
.21753 .03947 L
.21914 .03947 L
.21914 .16187 L
s
1 .894 .882 r
.21914 .16187 m
.21914 .03951 L
.21974 .03951 L
.21974 .16187 L
F
.804 .522 .247 r
.21914 .16187 m
.21914 .03951 L
.21974 .03951 L
.21974 .16187 L
s
1 .894 .882 r
.21974 .16187 m
.21974 .03982 L
.221 .03982 L
.221 .16187 L
F
.804 .522 .247 r
.21974 .16187 m
.21974 .03982 L
.221 .03982 L
.221 .16187 L
s
1 .894 .882 r
.221 .16187 m
.221 .03999 L
.2216 .03999 L
.2216 .16187 L
F
.804 .522 .247 r
.221 .16187 m
.221 .03999 L
.2216 .03999 L
.2216 .16187 L
s
1 .894 .882 r
.2216 .16187 m
.2216 .04012 L
.2223 .04012 L
.2223 .16187 L
F
.804 .522 .247 r
.2216 .16187 m
.2216 .04012 L
.2223 .04012 L
.2223 .16187 L
s
1 .894 .882 r
.2223 .16187 m
.2223 .04037 L
.22343 .04037 L
.22343 .16187 L
F
.804 .522 .247 r
.2223 .16187 m
.2223 .04037 L
.22343 .04037 L
.22343 .16187 L
s
1 .894 .882 r
.22343 .16187 m
.22343 .04091 L
.22475 .04091 L
.22475 .16187 L
F
.804 .522 .247 r
.22343 .16187 m
.22343 .04091 L
.22475 .04091 L
.22475 .16187 L
s
1 .894 .882 r
.22475 .16187 m
.22475 .04094 L
.22575 .04094 L
.22575 .16187 L
F
.804 .522 .247 r
.22475 .16187 m
.22475 .04094 L
.22575 .04094 L
.22575 .16187 L
s
1 .894 .882 r
.22575 .16187 m
.22575 .04131 L
.22703 .04131 L
.22703 .16187 L
F
.804 .522 .247 r
.22575 .16187 m
.22575 .04131 L
.22703 .04131 L
.22703 .16187 L
s
1 .894 .882 r
.22703 .16187 m
.22703 .04171 L
.2283 .04171 L
.2283 .16187 L
F
.804 .522 .247 r
.22703 .16187 m
.22703 .04171 L
.2283 .04171 L
.2283 .16187 L
s
1 .894 .882 r
.2283 .16187 m
.2283 .04203 L
.22904 .04203 L
.22904 .16187 L
F
.804 .522 .247 r
.2283 .16187 m
.2283 .04203 L
.22904 .04203 L
.22904 .16187 L
s
1 .894 .882 r
.22904 .16187 m
.22904 .04217 L
.23013 .04217 L
.23013 .16187 L
F
.804 .522 .247 r
.22904 .16187 m
.22904 .04217 L
.23013 .04217 L
.23013 .16187 L
s
1 .894 .882 r
.23013 .16187 m
.23013 .04234 L
.2314 .04234 L
.2314 .16187 L
F
.804 .522 .247 r
.23013 .16187 m
.23013 .04234 L
.2314 .04234 L
.2314 .16187 L
s
1 .894 .882 r
.2314 .16187 m
.2314 .04282 L
.23309 .04282 L
.23309 .16187 L
F
.804 .522 .247 r
.2314 .16187 m
.2314 .04282 L
.23309 .04282 L
.23309 .16187 L
s
1 .894 .882 r
.23309 .16187 m
.23309 .04331 L
.23454 .04331 L
.23454 .16187 L
F
.804 .522 .247 r
.23309 .16187 m
.23309 .04331 L
.23454 .04331 L
.23454 .16187 L
s
1 .894 .882 r
.23454 .16187 m
.23454 .04361 L
.23619 .04361 L
.23619 .16187 L
F
.804 .522 .247 r
.23454 .16187 m
.23454 .04361 L
.23619 .04361 L
.23619 .16187 L
s
1 .894 .882 r
.23619 .16187 m
.23619 .04425 L
.23742 .04425 L
.23742 .16187 L
F
.804 .522 .247 r
.23619 .16187 m
.23619 .04425 L
.23742 .04425 L
.23742 .16187 L
s
1 .894 .882 r
.23742 .16187 m
.23742 .0444 L
.23796 .0444 L
.23796 .16187 L
F
.804 .522 .247 r
.23742 .16187 m
.23742 .0444 L
.23796 .0444 L
.23796 .16187 L
s
1 .894 .882 r
.23796 .16187 m
.23796 .04479 L
.23934 .04479 L
.23934 .16187 L
F
.804 .522 .247 r
.23796 .16187 m
.23796 .04479 L
.23934 .04479 L
.23934 .16187 L
s
1 .894 .882 r
.23934 .16187 m
.23934 .04507 L
.24036 .04507 L
.24036 .16187 L
F
.804 .522 .247 r
.23934 .16187 m
.23934 .04507 L
.24036 .04507 L
.24036 .16187 L
s
1 .894 .882 r
.24036 .16187 m
.24036 .04531 L
.24098 .04531 L
.24098 .16187 L
F
.804 .522 .247 r
.24036 .16187 m
.24036 .04531 L
.24098 .04531 L
.24098 .16187 L
s
1 .894 .882 r
.24098 .16187 m
.24098 .04542 L
.24178 .04542 L
.24178 .16187 L
F
.804 .522 .247 r
.24098 .16187 m
.24098 .04542 L
.24178 .04542 L
.24178 .16187 L
s
1 .894 .882 r
.24178 .16187 m
.24178 .04569 L
.24304 .04569 L
.24304 .16187 L
F
.804 .522 .247 r
.24178 .16187 m
.24178 .04569 L
.24304 .04569 L
.24304 .16187 L
s
1 .894 .882 r
.24304 .16187 m
.24304 .04609 L
.24396 .04609 L
.24396 .16187 L
F
.804 .522 .247 r
.24304 .16187 m
.24304 .04609 L
.24396 .04609 L
.24396 .16187 L
s
1 .894 .882 r
.24396 .16187 m
.24396 .04636 L
.2447 .04636 L
.2447 .16187 L
F
.804 .522 .247 r
.24396 .16187 m
.24396 .04636 L
.2447 .04636 L
.2447 .16187 L
s
1 .894 .882 r
.2447 .16187 m
.2447 .04642 L
.2454 .04642 L
.2454 .16187 L
F
.804 .522 .247 r
.2447 .16187 m
.2447 .04642 L
.2454 .04642 L
.2454 .16187 L
s
1 .894 .882 r
.2454 .16187 m
.2454 .0467 L
.24592 .0467 L
.24592 .16187 L
F
.804 .522 .247 r
.2454 .16187 m
.2454 .0467 L
.24592 .0467 L
.24592 .16187 L
s
1 .894 .882 r
.24592 .16187 m
.24592 .04684 L
.24675 .04684 L
.24675 .16187 L
F
.804 .522 .247 r
.24592 .16187 m
.24592 .04684 L
.24675 .04684 L
.24675 .16187 L
s
1 .894 .882 r
.24675 .16187 m
.24675 .0471 L
.2473 .0471 L
.2473 .16187 L
F
.804 .522 .247 r
.24675 .16187 m
.24675 .0471 L
.2473 .0471 L
.2473 .16187 L
s
1 .894 .882 r
.2473 .16187 m
.2473 .04747 L
.24859 .04747 L
.24859 .16187 L
F
.804 .522 .247 r
.2473 .16187 m
.2473 .04747 L
.24859 .04747 L
.24859 .16187 L
s
1 .894 .882 r
.24859 .16187 m
.24859 .04771 L
.2495 .04771 L
.2495 .16187 L
F
.804 .522 .247 r
.24859 .16187 m
.24859 .04771 L
.2495 .04771 L
.2495 .16187 L
s
1 .894 .882 r
.2495 .16187 m
.2495 .04794 L
.25104 .04794 L
.25104 .16187 L
F
.804 .522 .247 r
.2495 .16187 m
.2495 .04794 L
.25104 .04794 L
.25104 .16187 L
s
1 .894 .882 r
.25104 .16187 m
.25104 .04835 L
.25202 .04835 L
.25202 .16187 L
F
.804 .522 .247 r
.25104 .16187 m
.25104 .04835 L
.25202 .04835 L
.25202 .16187 L
s
1 .894 .882 r
.25202 .16187 m
.25202 .04856 L
.25255 .04856 L
.25255 .16187 L
F
.804 .522 .247 r
.25202 .16187 m
.25202 .04856 L
.25255 .04856 L
.25255 .16187 L
s
1 .894 .882 r
.25255 .16187 m
.25255 .04885 L
.25324 .04885 L
.25324 .16187 L
F
.804 .522 .247 r
.25255 .16187 m
.25255 .04885 L
.25324 .04885 L
.25324 .16187 L
s
1 .894 .882 r
.25324 .16187 m
.25324 .04915 L
.2542 .04915 L
.2542 .16187 L
F
.804 .522 .247 r
.25324 .16187 m
.25324 .04915 L
.2542 .04915 L
.2542 .16187 L
s
1 .894 .882 r
.2542 .16187 m
.2542 .04934 L
.25562 .04934 L
.25562 .16187 L
F
.804 .522 .247 r
.2542 .16187 m
.2542 .04934 L
.25562 .04934 L
.25562 .16187 L
s
1 .894 .882 r
.25562 .16187 m
.25562 .04959 L
.25618 .04959 L
.25618 .16187 L
F
.804 .522 .247 r
.25562 .16187 m
.25562 .04959 L
.25618 .04959 L
.25618 .16187 L
s
1 .894 .882 r
.25618 .16187 m
.25618 .04988 L
.25713 .04988 L
.25713 .16187 L
F
.804 .522 .247 r
.25618 .16187 m
.25618 .04988 L
.25713 .04988 L
.25713 .16187 L
s
1 .894 .882 r
.25713 .16187 m
.25713 .05029 L
.25815 .05029 L
.25815 .16187 L
F
.804 .522 .247 r
.25713 .16187 m
.25713 .05029 L
.25815 .05029 L
.25815 .16187 L
s
1 .894 .882 r
.25815 .16187 m
.25815 .05049 L
.25885 .05049 L
.25885 .16187 L
F
.804 .522 .247 r
.25815 .16187 m
.25815 .05049 L
.25885 .05049 L
.25885 .16187 L
s
1 .894 .882 r
.25885 .16187 m
.25885 .05065 L
.25938 .05065 L
.25938 .16187 L
F
.804 .522 .247 r
.25885 .16187 m
.25885 .05065 L
.25938 .05065 L
.25938 .16187 L
s
1 .894 .882 r
.25938 .16187 m
.25938 .05096 L
.26067 .05096 L
.26067 .16187 L
F
.804 .522 .247 r
.25938 .16187 m
.25938 .05096 L
.26067 .05096 L
.26067 .16187 L
s
1 .894 .882 r
.26067 .16187 m
.26067 .05113 L
.26118 .05113 L
.26118 .16187 L
F
.804 .522 .247 r
.26067 .16187 m
.26067 .05113 L
.26118 .05113 L
.26118 .16187 L
s
1 .894 .882 r
.26118 .16187 m
.26118 .05141 L
.26177 .05141 L
.26177 .16187 L
F
.804 .522 .247 r
.26118 .16187 m
.26118 .05141 L
.26177 .05141 L
.26177 .16187 L
s
1 .894 .882 r
.26177 .16187 m
.26177 .0515 L
.26322 .0515 L
.26322 .16187 L
F
.804 .522 .247 r
.26177 .16187 m
.26177 .0515 L
.26322 .0515 L
.26322 .16187 L
s
1 .894 .882 r
.26322 .16187 m
.26322 .05194 L
.26376 .05194 L
.26376 .16187 L
F
.804 .522 .247 r
.26322 .16187 m
.26322 .05194 L
.26376 .05194 L
.26376 .16187 L
s
1 .894 .882 r
.26376 .16187 m
.26376 .05222 L
.26506 .05222 L
.26506 .16187 L
F
.804 .522 .247 r
.26376 .16187 m
.26376 .05222 L
.26506 .05222 L
.26506 .16187 L
s
1 .894 .882 r
.26506 .16187 m
.26506 .05289 L
.26663 .05289 L
.26663 .16187 L
F
.804 .522 .247 r
.26506 .16187 m
.26506 .05289 L
.26663 .05289 L
.26663 .16187 L
s
1 .894 .882 r
.26663 .16187 m
.26663 .05332 L
.26789 .05332 L
.26789 .16187 L
F
.804 .522 .247 r
.26663 .16187 m
.26663 .05332 L
.26789 .05332 L
.26789 .16187 L
s
1 .894 .882 r
.26789 .16187 m
.26789 .05345 L
.26842 .05345 L
.26842 .16187 L
F
.804 .522 .247 r
.26789 .16187 m
.26789 .05345 L
.26842 .05345 L
.26842 .16187 L
s
1 .894 .882 r
.26842 .16187 m
.26842 .05382 L
.2694 .05382 L
.2694 .16187 L
F
.804 .522 .247 r
.26842 .16187 m
.26842 .05382 L
.2694 .05382 L
.2694 .16187 L
s
1 .894 .882 r
.2694 .16187 m
.2694 .05386 L
.27094 .05386 L
.27094 .16187 L
F
.804 .522 .247 r
.2694 .16187 m
.2694 .05386 L
.27094 .05386 L
.27094 .16187 L
s
1 .894 .882 r
.27094 .16187 m
.27094 .05486 L
.27262 .05486 L
.27262 .16187 L
F
.804 .522 .247 r
.27094 .16187 m
.27094 .05486 L
.27262 .05486 L
.27262 .16187 L
s
1 .894 .882 r
.27262 .16187 m
.27262 .05516 L
.27395 .05516 L
.27395 .16187 L
F
.804 .522 .247 r
.27262 .16187 m
.27262 .05516 L
.27395 .05516 L
.27395 .16187 L
s
1 .894 .882 r
.27395 .16187 m
.27395 .05551 L
.27511 .05551 L
.27511 .16187 L
F
.804 .522 .247 r
.27395 .16187 m
.27395 .05551 L
.27511 .05551 L
.27511 .16187 L
s
1 .894 .882 r
.27511 .16187 m
.27511 .0559 L
.27617 .0559 L
.27617 .16187 L
F
.804 .522 .247 r
.27511 .16187 m
.27511 .0559 L
.27617 .0559 L
.27617 .16187 L
s
1 .894 .882 r
.27617 .16187 m
.27617 .05639 L
.27785 .05639 L
.27785 .16187 L
F
.804 .522 .247 r
.27617 .16187 m
.27617 .05639 L
.27785 .05639 L
.27785 .16187 L
s
1 .894 .882 r
.27785 .16187 m
.27785 .05689 L
.279 .05689 L
.279 .16187 L
F
.804 .522 .247 r
.27785 .16187 m
.27785 .05689 L
.279 .05689 L
.279 .16187 L
s
1 .894 .882 r
.279 .16187 m
.279 .0571 L
.27971 .0571 L
.27971 .16187 L
F
.804 .522 .247 r
.279 .16187 m
.279 .0571 L
.27971 .0571 L
.27971 .16187 L
s
1 .894 .882 r
.27971 .16187 m
.27971 .05728 L
.28106 .05728 L
.28106 .16187 L
F
.804 .522 .247 r
.27971 .16187 m
.27971 .05728 L
.28106 .05728 L
.28106 .16187 L
s
1 .894 .882 r
.28106 .16187 m
.28106 .058 L
.28269 .058 L
.28269 .16187 L
F
.804 .522 .247 r
.28106 .16187 m
.28106 .058 L
.28269 .058 L
.28269 .16187 L
s
1 .894 .882 r
.28269 .16187 m
.28269 .05829 L
.28341 .05829 L
.28341 .16187 L
F
.804 .522 .247 r
.28269 .16187 m
.28269 .05829 L
.28341 .05829 L
.28341 .16187 L
s
1 .894 .882 r
.28341 .16187 m
.28341 .0588 L
.28481 .0588 L
.28481 .16187 L
F
.804 .522 .247 r
.28341 .16187 m
.28341 .0588 L
.28481 .0588 L
.28481 .16187 L
s
1 .894 .882 r
.28481 .16187 m
.28481 .05912 L
.28597 .05912 L
.28597 .16187 L
F
.804 .522 .247 r
.28481 .16187 m
.28481 .05912 L
.28597 .05912 L
.28597 .16187 L
s
1 .894 .882 r
.28597 .16187 m
.28597 .05937 L
.28759 .05937 L
.28759 .16187 L
F
.804 .522 .247 r
.28597 .16187 m
.28597 .05937 L
.28759 .05937 L
.28759 .16187 L
s
1 .894 .882 r
.28759 .16187 m
.28759 .06016 L
.28873 .06016 L
.28873 .16187 L
F
.804 .522 .247 r
.28759 .16187 m
.28759 .06016 L
.28873 .06016 L
.28873 .16187 L
s
1 .894 .882 r
.28873 .16187 m
.28873 .0606 L
.29012 .0606 L
.29012 .16187 L
F
.804 .522 .247 r
.28873 .16187 m
.28873 .0606 L
.29012 .0606 L
.29012 .16187 L
s
1 .894 .882 r
.29012 .16187 m
.29012 .06103 L
.29121 .06103 L
.29121 .16187 L
F
.804 .522 .247 r
.29012 .16187 m
.29012 .06103 L
.29121 .06103 L
.29121 .16187 L
s
1 .894 .882 r
.29121 .16187 m
.29121 .06112 L
.29189 .06112 L
.29189 .16187 L
F
.804 .522 .247 r
.29121 .16187 m
.29121 .06112 L
.29189 .06112 L
.29189 .16187 L
s
1 .894 .882 r
.29189 .16187 m
.29189 .06157 L
.29302 .06157 L
.29302 .16187 L
F
.804 .522 .247 r
.29189 .16187 m
.29189 .06157 L
.29302 .06157 L
.29302 .16187 L
s
1 .894 .882 r
.29302 .16187 m
.29302 .06182 L
.29362 .06182 L
.29362 .16187 L
F
.804 .522 .247 r
.29302 .16187 m
.29302 .06182 L
.29362 .06182 L
.29362 .16187 L
s
1 .894 .882 r
.29362 .16187 m
.29362 .06236 L
.29484 .06236 L
.29484 .16187 L
F
.804 .522 .247 r
.29362 .16187 m
.29362 .06236 L
.29484 .06236 L
.29484 .16187 L
s
1 .894 .882 r
.29484 .16187 m
.29484 .06245 L
.29598 .06245 L
.29598 .16187 L
F
.804 .522 .247 r
.29484 .16187 m
.29484 .06245 L
.29598 .06245 L
.29598 .16187 L
s
1 .894 .882 r
.29598 .16187 m
.29598 .06284 L
.29709 .06284 L
.29709 .16187 L
F
.804 .522 .247 r
.29598 .16187 m
.29598 .06284 L
.29709 .06284 L
.29709 .16187 L
s
1 .894 .882 r
.29709 .16187 m
.29709 .0634 L
.29842 .0634 L
.29842 .16187 L
F
.804 .522 .247 r
.29709 .16187 m
.29709 .0634 L
.29842 .0634 L
.29842 .16187 L
s
1 .894 .882 r
.29842 .16187 m
.29842 .06412 L
.29982 .06412 L
.29982 .16187 L
F
.804 .522 .247 r
.29842 .16187 m
.29842 .06412 L
.29982 .06412 L
.29982 .16187 L
s
1 .894 .882 r
.29982 .16187 m
.29982 .06425 L
.30099 .06425 L
.30099 .16187 L
F
.804 .522 .247 r
.29982 .16187 m
.29982 .06425 L
.30099 .06425 L
.30099 .16187 L
s
1 .894 .882 r
.30099 .16187 m
.30099 .06483 L
.30248 .06483 L
.30248 .16187 L
F
.804 .522 .247 r
.30099 .16187 m
.30099 .06483 L
.30248 .06483 L
.30248 .16187 L
s
1 .894 .882 r
.30248 .16187 m
.30248 .06535 L
.30317 .06535 L
.30317 .16187 L
F
.804 .522 .247 r
.30248 .16187 m
.30248 .06535 L
.30317 .06535 L
.30317 .16187 L
s
1 .894 .882 r
.30317 .16187 m
.30317 .06547 L
.30402 .06547 L
.30402 .16187 L
F
.804 .522 .247 r
.30317 .16187 m
.30317 .06547 L
.30402 .06547 L
.30402 .16187 L
s
1 .894 .882 r
.30402 .16187 m
.30402 .06593 L
.30522 .06593 L
.30522 .16187 L
F
.804 .522 .247 r
.30402 .16187 m
.30402 .06593 L
.30522 .06593 L
.30522 .16187 L
s
1 .894 .882 r
.30522 .16187 m
.30522 .06633 L
.30607 .06633 L
.30607 .16187 L
F
.804 .522 .247 r
.30522 .16187 m
.30522 .06633 L
.30607 .06633 L
.30607 .16187 L
s
1 .894 .882 r
.30607 .16187 m
.30607 .06667 L
.30777 .06667 L
.30777 .16187 L
F
.804 .522 .247 r
.30607 .16187 m
.30607 .06667 L
.30777 .06667 L
.30777 .16187 L
s
1 .894 .882 r
.30777 .16187 m
.30777 .06713 L
.30898 .06713 L
.30898 .16187 L
F
.804 .522 .247 r
.30777 .16187 m
.30777 .06713 L
.30898 .06713 L
.30898 .16187 L
s
1 .894 .882 r
.30898 .16187 m
.30898 .06795 L
.31026 .06795 L
.31026 .16187 L
F
.804 .522 .247 r
.30898 .16187 m
.30898 .06795 L
.31026 .06795 L
.31026 .16187 L
s
1 .894 .882 r
.31026 .16187 m
.31026 .06805 L
.3109 .06805 L
.3109 .16187 L
F
.804 .522 .247 r
.31026 .16187 m
.31026 .06805 L
.3109 .06805 L
.3109 .16187 L
s
1 .894 .882 r
.3109 .16187 m
.3109 .0684 L
.31172 .0684 L
.31172 .16187 L
F
.804 .522 .247 r
.3109 .16187 m
.3109 .0684 L
.31172 .0684 L
.31172 .16187 L
s
1 .894 .882 r
.31172 .16187 m
.31172 .06865 L
.31228 .06865 L
.31228 .16187 L
F
.804 .522 .247 r
.31172 .16187 m
.31172 .06865 L
.31228 .06865 L
.31228 .16187 L
s
1 .894 .882 r
.31228 .16187 m
.31228 .06917 L
.31365 .06917 L
.31365 .16187 L
F
.804 .522 .247 r
.31228 .16187 m
.31228 .06917 L
.31365 .06917 L
.31365 .16187 L
s
1 .894 .882 r
.31365 .16187 m
.31365 .06952 L
.31486 .06952 L
.31486 .16187 L
F
.804 .522 .247 r
.31365 .16187 m
.31365 .06952 L
.31486 .06952 L
.31486 .16187 L
s
1 .894 .882 r
.31486 .16187 m
.31486 .0701 L
.316 .0701 L
.316 .16187 L
F
.804 .522 .247 r
.31486 .16187 m
.31486 .0701 L
.316 .0701 L
.316 .16187 L
s
1 .894 .882 r
.316 .16187 m
.316 .07054 L
.31719 .07054 L
.31719 .16187 L
F
.804 .522 .247 r
.316 .16187 m
.316 .07054 L
.31719 .07054 L
.31719 .16187 L
s
1 .894 .882 r
.31719 .16187 m
.31719 .07096 L
.31839 .07096 L
.31839 .16187 L
F
.804 .522 .247 r
.31719 .16187 m
.31719 .07096 L
.31839 .07096 L
.31839 .16187 L
s
1 .894 .882 r
.31839 .16187 m
.31839 .07105 L
.31898 .07105 L
.31898 .16187 L
F
.804 .522 .247 r
.31839 .16187 m
.31839 .07105 L
.31898 .07105 L
.31898 .16187 L
s
1 .894 .882 r
.31898 .16187 m
.31898 .07149 L
.32003 .07149 L
.32003 .16187 L
F
.804 .522 .247 r
.31898 .16187 m
.31898 .07149 L
.32003 .07149 L
.32003 .16187 L
s
1 .894 .882 r
.32003 .16187 m
.32003 .0723 L
.32171 .0723 L
.32171 .16187 L
F
.804 .522 .247 r
.32003 .16187 m
.32003 .0723 L
.32171 .0723 L
.32171 .16187 L
s
1 .894 .882 r
.32171 .16187 m
.32171 .07246 L
.32229 .07246 L
.32229 .16187 L
F
.804 .522 .247 r
.32171 .16187 m
.32171 .07246 L
.32229 .07246 L
.32229 .16187 L
s
1 .894 .882 r
.32229 .16187 m
.32229 .07298 L
.32349 .07298 L
.32349 .16187 L
F
.804 .522 .247 r
.32229 .16187 m
.32229 .07298 L
.32349 .07298 L
.32349 .16187 L
s
1 .894 .882 r
.32349 .16187 m
.32349 .07306 L
.32492 .07306 L
.32492 .16187 L
F
.804 .522 .247 r
.32349 .16187 m
.32349 .07306 L
.32492 .07306 L
.32492 .16187 L
s
1 .894 .882 r
.32492 .16187 m
.32492 .07356 L
.32571 .07356 L
.32571 .16187 L
F
.804 .522 .247 r
.32492 .16187 m
.32492 .07356 L
.32571 .07356 L
.32571 .16187 L
s
1 .894 .882 r
.32571 .16187 m
.32571 .07406 L
.32683 .07406 L
.32683 .16187 L
F
.804 .522 .247 r
.32571 .16187 m
.32571 .07406 L
.32683 .07406 L
.32683 .16187 L
s
1 .894 .882 r
.32683 .16187 m
.32683 .07457 L
.32825 .07457 L
.32825 .16187 L
F
.804 .522 .247 r
.32683 .16187 m
.32683 .07457 L
.32825 .07457 L
.32825 .16187 L
s
1 .894 .882 r
.32825 .16187 m
.32825 .07494 L
.3295 .07494 L
.3295 .16187 L
F
.804 .522 .247 r
.32825 .16187 m
.32825 .07494 L
.3295 .07494 L
.3295 .16187 L
s
1 .894 .882 r
.3295 .16187 m
.3295 .0758 L
.33116 .0758 L
.33116 .16187 L
F
.804 .522 .247 r
.3295 .16187 m
.3295 .0758 L
.33116 .0758 L
.33116 .16187 L
s
1 .894 .882 r
.33116 .16187 m
.33116 .07658 L
.33279 .07658 L
.33279 .16187 L
F
.804 .522 .247 r
.33116 .16187 m
.33116 .07658 L
.33279 .07658 L
.33279 .16187 L
s
1 .894 .882 r
.33279 .16187 m
.33279 .077 L
.33387 .077 L
.33387 .16187 L
F
.804 .522 .247 r
.33279 .16187 m
.33279 .077 L
.33387 .077 L
.33387 .16187 L
s
1 .894 .882 r
.33387 .16187 m
.33387 .07749 L
.33514 .07749 L
.33514 .16187 L
F
.804 .522 .247 r
.33387 .16187 m
.33387 .07749 L
.33514 .07749 L
.33514 .16187 L
s
1 .894 .882 r
.33514 .16187 m
.33514 .07779 L
.3361 .07779 L
.3361 .16187 L
F
.804 .522 .247 r
.33514 .16187 m
.33514 .07779 L
.3361 .07779 L
.3361 .16187 L
s
1 .894 .882 r
.3361 .16187 m
.3361 .07831 L
.33696 .07831 L
.33696 .16187 L
F
.804 .522 .247 r
.3361 .16187 m
.3361 .07831 L
.33696 .07831 L
.33696 .16187 L
s
1 .894 .882 r
.33696 .16187 m
.33696 .0785 L
.33792 .0785 L
.33792 .16187 L
F
.804 .522 .247 r
.33696 .16187 m
.33696 .0785 L
.33792 .0785 L
.33792 .16187 L
s
1 .894 .882 r
.33792 .16187 m
.33792 .07878 L
.33889 .07878 L
.33889 .16187 L
F
.804 .522 .247 r
.33792 .16187 m
.33792 .07878 L
.33889 .07878 L
.33889 .16187 L
s
1 .894 .882 r
.33889 .16187 m
.33889 .07942 L
.3398 .07942 L
.3398 .16187 L
F
.804 .522 .247 r
.33889 .16187 m
.33889 .07942 L
.3398 .07942 L
.3398 .16187 L
s
1 .894 .882 r
.3398 .16187 m
.3398 .07951 L
.34099 .07951 L
.34099 .16187 L
F
.804 .522 .247 r
.3398 .16187 m
.3398 .07951 L
.34099 .07951 L
.34099 .16187 L
s
1 .894 .882 r
.34099 .16187 m
.34099 .08045 L
.34246 .08045 L
.34246 .16187 L
F
.804 .522 .247 r
.34099 .16187 m
.34099 .08045 L
.34246 .08045 L
.34246 .16187 L
s
1 .894 .882 r
.34246 .16187 m
.34246 .08069 L
.344 .08069 L
.344 .16187 L
F
.804 .522 .247 r
.34246 .16187 m
.34246 .08069 L
.344 .08069 L
.344 .16187 L
s
1 .894 .882 r
.344 .16187 m
.344 .08174 L
.34543 .08174 L
.34543 .16187 L
F
.804 .522 .247 r
.344 .16187 m
.344 .08174 L
.34543 .08174 L
.34543 .16187 L
s
1 .894 .882 r
.34543 .16187 m
.34543 .08195 L
.34714 .08195 L
.34714 .16187 L
F
.804 .522 .247 r
.34543 .16187 m
.34543 .08195 L
.34714 .08195 L
.34714 .16187 L
s
1 .894 .882 r
.34714 .16187 m
.34714 .08293 L
.34852 .08293 L
.34852 .16187 L
F
.804 .522 .247 r
.34714 .16187 m
.34714 .08293 L
.34852 .08293 L
.34852 .16187 L
s
1 .894 .882 r
.34852 .16187 m
.34852 .08337 L
.34952 .08337 L
.34952 .16187 L
F
.804 .522 .247 r
.34852 .16187 m
.34852 .08337 L
.34952 .08337 L
.34952 .16187 L
s
1 .894 .882 r
.34952 .16187 m
.34952 .08408 L
.35099 .08408 L
.35099 .16187 L
F
.804 .522 .247 r
.34952 .16187 m
.34952 .08408 L
.35099 .08408 L
.35099 .16187 L
s
1 .894 .882 r
.35099 .16187 m
.35099 .08451 L
.35263 .08451 L
.35263 .16187 L
F
.804 .522 .247 r
.35099 .16187 m
.35099 .08451 L
.35263 .08451 L
.35263 .16187 L
s
1 .894 .882 r
.35263 .16187 m
.35263 .08508 L
.35333 .08508 L
.35333 .16187 L
F
.804 .522 .247 r
.35263 .16187 m
.35263 .08508 L
.35333 .08508 L
.35333 .16187 L
s
1 .894 .882 r
.35333 .16187 m
.35333 .08542 L
.35462 .08542 L
.35462 .16187 L
F
.804 .522 .247 r
.35333 .16187 m
.35333 .08542 L
.35462 .08542 L
.35462 .16187 L
s
1 .894 .882 r
.35462 .16187 m
.35462 .08614 L
.3558 .08614 L
.3558 .16187 L
F
.804 .522 .247 r
.35462 .16187 m
.35462 .08614 L
.3558 .08614 L
.3558 .16187 L
s
1 .894 .882 r
.3558 .16187 m
.3558 .08624 L
.35684 .08624 L
.35684 .16187 L
F
.804 .522 .247 r
.3558 .16187 m
.3558 .08624 L
.35684 .08624 L
.35684 .16187 L
s
1 .894 .882 r
.35684 .16187 m
.35684 .08678 L
.35783 .08678 L
.35783 .16187 L
F
.804 .522 .247 r
.35684 .16187 m
.35684 .08678 L
.35783 .08678 L
.35783 .16187 L
s
1 .894 .882 r
.35783 .16187 m
.35783 .08718 L
.35838 .08718 L
.35838 .16187 L
F
.804 .522 .247 r
.35783 .16187 m
.35783 .08718 L
.35838 .08718 L
.35838 .16187 L
s
1 .894 .882 r
.35838 .16187 m
.35838 .08742 L
.35962 .08742 L
.35962 .16187 L
F
.804 .522 .247 r
.35838 .16187 m
.35838 .08742 L
.35962 .08742 L
.35962 .16187 L
s
1 .894 .882 r
.35962 .16187 m
.35962 .08796 L
.36074 .08796 L
.36074 .16187 L
F
.804 .522 .247 r
.35962 .16187 m
.35962 .08796 L
.36074 .08796 L
.36074 .16187 L
s
1 .894 .882 r
.36074 .16187 m
.36074 .0887 L
.36236 .0887 L
.36236 .16187 L
F
.804 .522 .247 r
.36074 .16187 m
.36074 .0887 L
.36236 .0887 L
.36236 .16187 L
s
1 .894 .882 r
.36236 .16187 m
.36236 .08932 L
.36334 .08932 L
.36334 .16187 L
F
.804 .522 .247 r
.36236 .16187 m
.36236 .08932 L
.36334 .08932 L
.36334 .16187 L
s
1 .894 .882 r
.36334 .16187 m
.36334 .08976 L
.36414 .08976 L
.36414 .16187 L
F
.804 .522 .247 r
.36334 .16187 m
.36334 .08976 L
.36414 .08976 L
.36414 .16187 L
s
1 .894 .882 r
.36414 .16187 m
.36414 .08997 L
.36492 .08997 L
.36492 .16187 L
F
.804 .522 .247 r
.36414 .16187 m
.36414 .08997 L
.36492 .08997 L
.36492 .16187 L
s
1 .894 .882 r
.36492 .16187 m
.36492 .09026 L
.36609 .09026 L
.36609 .16187 L
F
.804 .522 .247 r
.36492 .16187 m
.36492 .09026 L
.36609 .09026 L
.36609 .16187 L
s
1 .894 .882 r
.36609 .16187 m
.36609 .09085 L
.36662 .09085 L
.36662 .16187 L
F
.804 .522 .247 r
.36609 .16187 m
.36609 .09085 L
.36662 .09085 L
.36662 .16187 L
s
1 .894 .882 r
.36662 .16187 m
.36662 .09162 L
.36822 .09162 L
.36822 .16187 L
F
.804 .522 .247 r
.36662 .16187 m
.36662 .09162 L
.36822 .09162 L
.36822 .16187 L
s
1 .894 .882 r
.36822 .16187 m
.36822 .09184 L
.36952 .09184 L
.36952 .16187 L
F
.804 .522 .247 r
.36822 .16187 m
.36822 .09184 L
.36952 .09184 L
.36952 .16187 L
s
1 .894 .882 r
.36952 .16187 m
.36952 .09248 L
.37093 .09248 L
.37093 .16187 L
F
.804 .522 .247 r
.36952 .16187 m
.36952 .09248 L
.37093 .09248 L
.37093 .16187 L
s
1 .894 .882 r
.37093 .16187 m
.37093 .09301 L
.37163 .09301 L
.37163 .16187 L
F
.804 .522 .247 r
.37093 .16187 m
.37093 .09301 L
.37163 .09301 L
.37163 .16187 L
s
1 .894 .882 r
.37163 .16187 m
.37163 .09325 L
.37232 .09325 L
.37232 .16187 L
F
.804 .522 .247 r
.37163 .16187 m
.37163 .09325 L
.37232 .09325 L
.37232 .16187 L
s
1 .894 .882 r
.37232 .16187 m
.37232 .0936 L
.37362 .0936 L
.37362 .16187 L
F
.804 .522 .247 r
.37232 .16187 m
.37232 .0936 L
.37362 .0936 L
.37362 .16187 L
s
1 .894 .882 r
.37362 .16187 m
.37362 .09429 L
.37417 .09429 L
.37417 .16187 L
F
.804 .522 .247 r
.37362 .16187 m
.37362 .09429 L
.37417 .09429 L
.37417 .16187 L
s
1 .894 .882 r
.37417 .16187 m
.37417 .09486 L
.37557 .09486 L
.37557 .16187 L
F
.804 .522 .247 r
.37417 .16187 m
.37417 .09486 L
.37557 .09486 L
.37557 .16187 L
s
1 .894 .882 r
.37557 .16187 m
.37557 .09511 L
.37651 .09511 L
.37651 .16187 L
F
.804 .522 .247 r
.37557 .16187 m
.37557 .09511 L
.37651 .09511 L
.37651 .16187 L
s
1 .894 .882 r
.37651 .16187 m
.37651 .09584 L
.37787 .09584 L
.37787 .16187 L
F
.804 .522 .247 r
.37651 .16187 m
.37651 .09584 L
.37787 .09584 L
.37787 .16187 L
s
1 .894 .882 r
.37787 .16187 m
.37787 .09678 L
.37944 .09678 L
.37944 .16187 L
F
.804 .522 .247 r
.37787 .16187 m
.37787 .09678 L
.37944 .09678 L
.37944 .16187 L
s
1 .894 .882 r
.37944 .16187 m
.37944 .09688 L
.38007 .09688 L
.38007 .16187 L
F
.804 .522 .247 r
.37944 .16187 m
.37944 .09688 L
.38007 .09688 L
.38007 .16187 L
s
1 .894 .882 r
.38007 .16187 m
.38007 .09737 L
.38153 .09737 L
.38153 .16187 L
F
.804 .522 .247 r
.38007 .16187 m
.38007 .09737 L
.38153 .09737 L
.38153 .16187 L
s
1 .894 .882 r
.38153 .16187 m
.38153 .098 L
.38237 .098 L
.38237 .16187 L
F
.804 .522 .247 r
.38153 .16187 m
.38153 .098 L
.38237 .098 L
.38237 .16187 L
s
1 .894 .882 r
.38237 .16187 m
.38237 .09855 L
.38346 .09855 L
.38346 .16187 L
F
.804 .522 .247 r
.38237 .16187 m
.38237 .09855 L
.38346 .09855 L
.38346 .16187 L
s
1 .894 .882 r
.38346 .16187 m
.38346 .09867 L
.38405 .09867 L
.38405 .16187 L
F
.804 .522 .247 r
.38346 .16187 m
.38346 .09867 L
.38405 .09867 L
.38405 .16187 L
s
1 .894 .882 r
.38405 .16187 m
.38405 .09904 L
.38479 .09904 L
.38479 .16187 L
F
.804 .522 .247 r
.38405 .16187 m
.38405 .09904 L
.38479 .09904 L
.38479 .16187 L
s
1 .894 .882 r
.38479 .16187 m
.38479 .0996 L
.38621 .0996 L
.38621 .16187 L
F
.804 .522 .247 r
.38479 .16187 m
.38479 .0996 L
.38621 .0996 L
.38621 .16187 L
s
1 .894 .882 r
.38621 .16187 m
.38621 .10014 L
.3874 .10014 L
.3874 .16187 L
F
.804 .522 .247 r
.38621 .16187 m
.38621 .10014 L
.3874 .10014 L
.3874 .16187 L
s
1 .894 .882 r
.3874 .16187 m
.3874 .10084 L
.38872 .10084 L
.38872 .16187 L
F
.804 .522 .247 r
.3874 .16187 m
.3874 .10084 L
.38872 .10084 L
.38872 .16187 L
s
1 .894 .882 r
.38872 .16187 m
.38872 .10163 L
.39037 .10163 L
.39037 .16187 L
F
.804 .522 .247 r
.38872 .16187 m
.38872 .10163 L
.39037 .10163 L
.39037 .16187 L
s
1 .894 .882 r
.39037 .16187 m
.39037 .10204 L
.39153 .10204 L
.39153 .16187 L
F
.804 .522 .247 r
.39037 .16187 m
.39037 .10204 L
.39153 .10204 L
.39153 .16187 L
s
1 .894 .882 r
.39153 .16187 m
.39153 .10254 L
.39207 .10254 L
.39207 .16187 L
F
.804 .522 .247 r
.39153 .16187 m
.39153 .10254 L
.39207 .10254 L
.39207 .16187 L
s
1 .894 .882 r
.39207 .16187 m
.39207 .10278 L
.39337 .10278 L
.39337 .16187 L
F
.804 .522 .247 r
.39207 .16187 m
.39207 .10278 L
.39337 .10278 L
.39337 .16187 L
s
1 .894 .882 r
.39337 .16187 m
.39337 .10354 L
.39393 .10354 L
.39393 .16187 L
F
.804 .522 .247 r
.39337 .16187 m
.39337 .10354 L
.39393 .10354 L
.39393 .16187 L
s
1 .894 .882 r
.39393 .16187 m
.39393 .10435 L
.3955 .10435 L
.3955 .16187 L
F
.804 .522 .247 r
.39393 .16187 m
.39393 .10435 L
.3955 .10435 L
.3955 .16187 L
s
1 .894 .882 r
.3955 .16187 m
.3955 .10476 L
.39634 .10476 L
.39634 .16187 L
F
.804 .522 .247 r
.3955 .16187 m
.3955 .10476 L
.39634 .10476 L
.39634 .16187 L
s
1 .894 .882 r
.39634 .16187 m
.39634 .10519 L
.39745 .10519 L
.39745 .16187 L
F
.804 .522 .247 r
.39634 .16187 m
.39634 .10519 L
.39745 .10519 L
.39745 .16187 L
s
1 .894 .882 r
.39745 .16187 m
.39745 .10583 L
.39904 .10583 L
.39904 .16187 L
F
.804 .522 .247 r
.39745 .16187 m
.39745 .10583 L
.39904 .10583 L
.39904 .16187 L
s
1 .894 .882 r
.39904 .16187 m
.39904 .10642 L
.39983 .10642 L
.39983 .16187 L
F
.804 .522 .247 r
.39904 .16187 m
.39904 .10642 L
.39983 .10642 L
.39983 .16187 L
s
1 .894 .882 r
.39983 .16187 m
.39983 .10658 L
.40063 .10658 L
.40063 .16187 L
F
.804 .522 .247 r
.39983 .16187 m
.39983 .10658 L
.40063 .10658 L
.40063 .16187 L
s
1 .894 .882 r
.40063 .16187 m
.40063 .10687 L
.40205 .10687 L
.40205 .16187 L
F
.804 .522 .247 r
.40063 .16187 m
.40063 .10687 L
.40205 .10687 L
.40205 .16187 L
s
1 .894 .882 r
.40205 .16187 m
.40205 .1078 L
.40322 .1078 L
.40322 .16187 L
F
.804 .522 .247 r
.40205 .16187 m
.40205 .1078 L
.40322 .1078 L
.40322 .16187 L
s
1 .894 .882 r
.40322 .16187 m
.40322 .10826 L
.40435 .10826 L
.40435 .16187 L
F
.804 .522 .247 r
.40322 .16187 m
.40322 .10826 L
.40435 .10826 L
.40435 .16187 L
s
1 .894 .882 r
.40435 .16187 m
.40435 .10882 L
.4053 .10882 L
.4053 .16187 L
F
.804 .522 .247 r
.40435 .16187 m
.40435 .10882 L
.4053 .10882 L
.4053 .16187 L
s
1 .894 .882 r
.4053 .16187 m
.4053 .10959 L
.4066 .10959 L
.4066 .16187 L
F
.804 .522 .247 r
.4053 .16187 m
.4053 .10959 L
.4066 .10959 L
.4066 .16187 L
s
1 .894 .882 r
.4066 .16187 m
.4066 .11051 L
.40802 .11051 L
.40802 .16187 L
F
.804 .522 .247 r
.4066 .16187 m
.4066 .11051 L
.40802 .11051 L
.40802 .16187 L
s
1 .894 .882 r
.40802 .16187 m
.40802 .11075 L
.40882 .11075 L
.40882 .16187 L
F
.804 .522 .247 r
.40802 .16187 m
.40802 .11075 L
.40882 .11075 L
.40882 .16187 L
s
1 .894 .882 r
.40882 .16187 m
.40882 .1113 L
.41039 .1113 L
.41039 .16187 L
F
.804 .522 .247 r
.40882 .16187 m
.40882 .1113 L
.41039 .1113 L
.41039 .16187 L
s
1 .894 .882 r
.41039 .16187 m
.41039 .11208 L
.41161 .11208 L
.41161 .16187 L
F
.804 .522 .247 r
.41039 .16187 m
.41039 .11208 L
.41161 .11208 L
.41161 .16187 L
s
1 .894 .882 r
.41161 .16187 m
.41161 .11273 L
.41282 .11273 L
.41282 .16187 L
F
.804 .522 .247 r
.41161 .16187 m
.41161 .11273 L
.41282 .11273 L
.41282 .16187 L
s
1 .894 .882 r
.41282 .16187 m
.41282 .11297 L
.41391 .11297 L
.41391 .16187 L
F
.804 .522 .247 r
.41282 .16187 m
.41282 .11297 L
.41391 .11297 L
.41391 .16187 L
s
1 .894 .882 r
.41391 .16187 m
.41391 .11353 L
.4148 .11353 L
.4148 .16187 L
F
.804 .522 .247 r
.41391 .16187 m
.41391 .11353 L
.4148 .11353 L
.4148 .16187 L
s
1 .894 .882 r
.4148 .16187 m
.4148 .11399 L
.41641 .11399 L
.41641 .16187 L
F
.804 .522 .247 r
.4148 .16187 m
.4148 .11399 L
.41641 .11399 L
.41641 .16187 L
s
1 .894 .882 r
.41641 .16187 m
.41641 .11477 L
.41767 .11477 L
.41767 .16187 L
F
.804 .522 .247 r
.41641 .16187 m
.41641 .11477 L
.41767 .11477 L
.41767 .16187 L
s
1 .894 .882 r
.41767 .16187 m
.41767 .11612 L
.41932 .11612 L
.41932 .16187 L
F
.804 .522 .247 r
.41767 .16187 m
.41767 .11612 L
.41932 .11612 L
.41932 .16187 L
s
1 .894 .882 r
.41932 .16187 m
.41932 .11661 L
.42019 .11661 L
.42019 .16187 L
F
.804 .522 .247 r
.41932 .16187 m
.41932 .11661 L
.42019 .11661 L
.42019 .16187 L
s
1 .894 .882 r
.42019 .16187 m
.42019 .1171 L
.42101 .1171 L
.42101 .16187 L
F
.804 .522 .247 r
.42019 .16187 m
.42019 .1171 L
.42101 .1171 L
.42101 .16187 L
s
1 .894 .882 r
.42101 .16187 m
.42101 .11729 L
.42223 .11729 L
.42223 .16187 L
F
.804 .522 .247 r
.42101 .16187 m
.42101 .11729 L
.42223 .11729 L
.42223 .16187 L
s
1 .894 .882 r
.42223 .16187 m
.42223 .118 L
.42282 .118 L
.42282 .16187 L
F
.804 .522 .247 r
.42223 .16187 m
.42223 .118 L
.42282 .118 L
.42282 .16187 L
s
1 .894 .882 r
.42282 .16187 m
.42282 .11828 L
.42336 .11828 L
.42336 .16187 L
F
.804 .522 .247 r
.42282 .16187 m
.42282 .11828 L
.42336 .11828 L
.42336 .16187 L
s
1 .894 .882 r
.42336 .16187 m
.42336 .11847 L
.42478 .11847 L
.42478 .16187 L
F
.804 .522 .247 r
.42336 .16187 m
.42336 .11847 L
.42478 .11847 L
.42478 .16187 L
s
1 .894 .882 r
.42478 .16187 m
.42478 .11949 L
.42612 .11949 L
.42612 .16187 L
F
.804 .522 .247 r
.42478 .16187 m
.42478 .11949 L
.42612 .11949 L
.42612 .16187 L
s
1 .894 .882 r
.42612 .16187 m
.42612 .11978 L
.42764 .11978 L
.42764 .16187 L
F
.804 .522 .247 r
.42612 .16187 m
.42612 .11978 L
.42764 .11978 L
.42764 .16187 L
s
1 .894 .882 r
.42764 .16187 m
.42764 .12101 L
.42909 .12101 L
.42909 .16187 L
F
.804 .522 .247 r
.42764 .16187 m
.42764 .12101 L
.42909 .12101 L
.42909 .16187 L
s
1 .894 .882 r
.42909 .16187 m
.42909 .12136 L
.42961 .12136 L
.42961 .16187 L
F
.804 .522 .247 r
.42909 .16187 m
.42909 .12136 L
.42961 .12136 L
.42961 .16187 L
s
1 .894 .882 r
.42961 .16187 m
.42961 .12165 L
.43028 .12165 L
.43028 .16187 L
F
.804 .522 .247 r
.42961 .16187 m
.42961 .12165 L
.43028 .12165 L
.43028 .16187 L
s
1 .894 .882 r
.43028 .16187 m
.43028 .12232 L
.43119 .12232 L
.43119 .16187 L
F
.804 .522 .247 r
.43028 .16187 m
.43028 .12232 L
.43119 .12232 L
.43119 .16187 L
s
1 .894 .882 r
.43119 .16187 m
.43119 .12259 L
.43221 .12259 L
.43221 .16187 L
F
.804 .522 .247 r
.43119 .16187 m
.43119 .12259 L
.43221 .12259 L
.43221 .16187 L
s
1 .894 .882 r
.43221 .16187 m
.43221 .12321 L
.43314 .12321 L
.43314 .16187 L
F
.804 .522 .247 r
.43221 .16187 m
.43221 .12321 L
.43314 .12321 L
.43314 .16187 L
s
1 .894 .882 r
.43314 .16187 m
.43314 .12355 L
.4341 .12355 L
.4341 .16187 L
F
.804 .522 .247 r
.43314 .16187 m
.43314 .12355 L
.4341 .12355 L
.4341 .16187 L
s
1 .894 .882 r
.4341 .16187 m
.4341 .12403 L
.43472 .12403 L
.43472 .16187 L
F
.804 .522 .247 r
.4341 .16187 m
.4341 .12403 L
.43472 .12403 L
.43472 .16187 L
s
1 .894 .882 r
.43472 .16187 m
.43472 .12481 L
.43588 .12481 L
.43588 .16187 L
F
.804 .522 .247 r
.43472 .16187 m
.43472 .12481 L
.43588 .12481 L
.43588 .16187 L
s
1 .894 .882 r
.43588 .16187 m
.43588 .12559 L
.4373 .12559 L
.4373 .16187 L
F
.804 .522 .247 r
.43588 .16187 m
.43588 .12559 L
.4373 .12559 L
.4373 .16187 L
s
1 .894 .882 r
.4373 .16187 m
.4373 .12607 L
.43877 .12607 L
.43877 .16187 L
F
.804 .522 .247 r
.4373 .16187 m
.4373 .12607 L
.43877 .12607 L
.43877 .16187 L
s
1 .894 .882 r
.43877 .16187 m
.43877 .12654 L
.44001 .12654 L
.44001 .16187 L
F
.804 .522 .247 r
.43877 .16187 m
.43877 .12654 L
.44001 .12654 L
.44001 .16187 L
s
1 .894 .882 r
.44001 .16187 m
.44001 .12742 L
.44079 .12742 L
.44079 .16187 L
F
.804 .522 .247 r
.44001 .16187 m
.44001 .12742 L
.44079 .12742 L
.44079 .16187 L
s
1 .894 .882 r
.44079 .16187 m
.44079 .12822 L
.44232 .12822 L
.44232 .16187 L
F
.804 .522 .247 r
.44079 .16187 m
.44079 .12822 L
.44232 .12822 L
.44232 .16187 L
s
1 .894 .882 r
.44232 .16187 m
.44232 .12856 L
.44303 .12856 L
.44303 .16187 L
F
.804 .522 .247 r
.44232 .16187 m
.44232 .12856 L
.44303 .12856 L
.44303 .16187 L
s
1 .894 .882 r
.44303 .16187 m
.44303 .12894 L
.44433 .12894 L
.44433 .16187 L
F
.804 .522 .247 r
.44303 .16187 m
.44303 .12894 L
.44433 .12894 L
.44433 .16187 L
s
1 .894 .882 r
.44433 .16187 m
.44433 .13023 L
.44597 .13023 L
.44597 .16187 L
F
.804 .522 .247 r
.44433 .16187 m
.44433 .13023 L
.44597 .13023 L
.44597 .16187 L
s
1 .894 .882 r
.44597 .16187 m
.44597 .13091 L
.44718 .13091 L
.44718 .16187 L
F
.804 .522 .247 r
.44597 .16187 m
.44597 .13091 L
.44718 .13091 L
.44718 .16187 L
s
1 .894 .882 r
.44718 .16187 m
.44718 .13115 L
.44839 .13115 L
.44839 .16187 L
F
.804 .522 .247 r
.44718 .16187 m
.44718 .13115 L
.44839 .13115 L
.44839 .16187 L
s
1 .894 .882 r
.44839 .16187 m
.44839 .13193 L
.44962 .13193 L
.44962 .16187 L
F
.804 .522 .247 r
.44839 .16187 m
.44839 .13193 L
.44962 .13193 L
.44962 .16187 L
s
1 .894 .882 r
.44962 .16187 m
.44962 .13322 L
.45122 .13322 L
.45122 .16187 L
F
.804 .522 .247 r
.44962 .16187 m
.44962 .13322 L
.45122 .13322 L
.45122 .16187 L
s
1 .894 .882 r
.45122 .16187 m
.45122 .13377 L
.45272 .13377 L
.45272 .16187 L
F
.804 .522 .247 r
.45122 .16187 m
.45122 .13377 L
.45272 .13377 L
.45272 .16187 L
s
1 .894 .882 r
.45272 .16187 m
.45272 .13457 L
.45431 .13457 L
.45431 .16187 L
F
.804 .522 .247 r
.45272 .16187 m
.45272 .13457 L
.45431 .13457 L
.45431 .16187 L
s
1 .894 .882 r
.45431 .16187 m
.45431 .13522 L
.45573 .13522 L
.45573 .16187 L
F
.804 .522 .247 r
.45431 .16187 m
.45431 .13522 L
.45573 .13522 L
.45573 .16187 L
s
1 .894 .882 r
.45573 .16187 m
.45573 .1359 L
.45639 .1359 L
.45639 .16187 L
F
.804 .522 .247 r
.45573 .16187 m
.45573 .1359 L
.45639 .1359 L
.45639 .16187 L
s
1 .894 .882 r
.45639 .16187 m
.45639 .13649 L
.45788 .13649 L
.45788 .16187 L
F
.804 .522 .247 r
.45639 .16187 m
.45639 .13649 L
.45788 .13649 L
.45788 .16187 L
s
1 .894 .882 r
.45788 .16187 m
.45788 .13726 L
.45931 .13726 L
.45931 .16187 L
F
.804 .522 .247 r
.45788 .16187 m
.45788 .13726 L
.45931 .13726 L
.45931 .16187 L
s
1 .894 .882 r
.45931 .16187 m
.45931 .13808 L
.46034 .13808 L
.46034 .16187 L
F
.804 .522 .247 r
.45931 .16187 m
.45931 .13808 L
.46034 .13808 L
.46034 .16187 L
s
1 .894 .882 r
.46034 .16187 m
.46034 .13838 L
.4617 .13838 L
.4617 .16187 L
F
.804 .522 .247 r
.46034 .16187 m
.46034 .13838 L
.4617 .13838 L
.4617 .16187 L
s
1 .894 .882 r
.4617 .16187 m
.4617 .13968 L
.46277 .13968 L
.46277 .16187 L
F
.804 .522 .247 r
.4617 .16187 m
.4617 .13968 L
.46277 .13968 L
.46277 .16187 L
s
1 .894 .882 r
.46277 .16187 m
.46277 .13983 L
.46376 .13983 L
.46376 .16187 L
F
.804 .522 .247 r
.46277 .16187 m
.46277 .13983 L
.46376 .13983 L
.46376 .16187 L
s
1 .894 .882 r
.46376 .16187 m
.46376 .14046 L
.46468 .14046 L
.46468 .16187 L
F
.804 .522 .247 r
.46376 .16187 m
.46376 .14046 L
.46468 .14046 L
.46468 .16187 L
s
1 .894 .882 r
.46468 .16187 m
.46468 .14091 L
.46539 .14091 L
.46539 .16187 L
F
.804 .522 .247 r
.46468 .16187 m
.46468 .14091 L
.46539 .14091 L
.46539 .16187 L
s
1 .894 .882 r
.46539 .16187 m
.46539 .14202 L
.46675 .14202 L
.46675 .16187 L
F
.804 .522 .247 r
.46539 .16187 m
.46539 .14202 L
.46675 .14202 L
.46675 .16187 L
s
1 .894 .882 r
.46675 .16187 m
.46675 .14247 L
.46798 .14247 L
.46798 .16187 L
F
.804 .522 .247 r
.46675 .16187 m
.46675 .14247 L
.46798 .14247 L
.46798 .16187 L
s
1 .894 .882 r
.46798 .16187 m
.46798 .14286 L
.46938 .14286 L
.46938 .16187 L
F
.804 .522 .247 r
.46798 .16187 m
.46798 .14286 L
.46938 .14286 L
.46938 .16187 L
s
1 .894 .882 r
.46938 .16187 m
.46938 .14398 L
.47101 .14398 L
.47101 .16187 L
F
.804 .522 .247 r
.46938 .16187 m
.46938 .14398 L
.47101 .14398 L
.47101 .16187 L
s
1 .894 .882 r
.47101 .16187 m
.47101 .14464 L
.47257 .14464 L
.47257 .16187 L
F
.804 .522 .247 r
.47101 .16187 m
.47101 .14464 L
.47257 .14464 L
.47257 .16187 L
s
1 .894 .882 r
.47257 .16187 m
.47257 .14549 L
.47359 .14549 L
.47359 .16187 L
F
.804 .522 .247 r
.47257 .16187 m
.47257 .14549 L
.47359 .14549 L
.47359 .16187 L
s
1 .894 .882 r
.47359 .16187 m
.47359 .14632 L
.4742 .14632 L
.4742 .16187 L
F
.804 .522 .247 r
.47359 .16187 m
.47359 .14632 L
.4742 .14632 L
.4742 .16187 L
s
1 .894 .882 r
.4742 .16187 m
.4742 .14696 L
.47591 .14696 L
.47591 .16187 L
F
.804 .522 .247 r
.4742 .16187 m
.4742 .14696 L
.47591 .14696 L
.47591 .16187 L
s
1 .894 .882 r
.47591 .16187 m
.47591 .14752 L
.47677 .14752 L
.47677 .16187 L
F
.804 .522 .247 r
.47591 .16187 m
.47591 .14752 L
.47677 .14752 L
.47677 .16187 L
s
1 .894 .882 r
.47677 .16187 m
.47677 .14873 L
.47829 .14873 L
.47829 .16187 L
F
.804 .522 .247 r
.47677 .16187 m
.47677 .14873 L
.47829 .14873 L
.47829 .16187 L
s
1 .894 .882 r
.47829 .16187 m
.47829 .14911 L
.47939 .14911 L
.47939 .16187 L
F
.804 .522 .247 r
.47829 .16187 m
.47829 .14911 L
.47939 .14911 L
.47939 .16187 L
s
1 .894 .882 r
.47939 .16187 m
.47939 .14964 L
.48001 .14964 L
.48001 .16187 L
F
.804 .522 .247 r
.47939 .16187 m
.47939 .14964 L
.48001 .14964 L
.48001 .16187 L
s
1 .894 .882 r
.48001 .16187 m
.48001 .15023 L
.48108 .15023 L
.48108 .16187 L
F
.804 .522 .247 r
.48001 .16187 m
.48001 .15023 L
.48108 .15023 L
.48108 .16187 L
s
1 .894 .882 r
.48108 .16187 m
.48108 .15083 L
.48272 .15083 L
.48272 .16187 L
F
.804 .522 .247 r
.48108 .16187 m
.48108 .15083 L
.48272 .15083 L
.48272 .16187 L
s
1 .894 .882 r
.48272 .16187 m
.48272 .15159 L
.48411 .15159 L
.48411 .16187 L
F
.804 .522 .247 r
.48272 .16187 m
.48272 .15159 L
.48411 .15159 L
.48411 .16187 L
s
1 .894 .882 r
.48411 .16187 m
.48411 .15253 L
.48578 .15253 L
.48578 .16187 L
F
.804 .522 .247 r
.48411 .16187 m
.48411 .15253 L
.48578 .15253 L
.48578 .16187 L
s
1 .894 .882 r
.48578 .16187 m
.48578 .15346 L
.48707 .15346 L
.48707 .16187 L
F
.804 .522 .247 r
.48578 .16187 m
.48578 .15346 L
.48707 .15346 L
.48707 .16187 L
s
1 .894 .882 r
.48707 .16187 m
.48707 .15403 L
.4878 .15403 L
.4878 .16187 L
F
.804 .522 .247 r
.48707 .16187 m
.48707 .15403 L
.4878 .15403 L
.4878 .16187 L
s
1 .894 .882 r
.4878 .16187 m
.4878 .15483 L
.48868 .15483 L
.48868 .16187 L
F
.804 .522 .247 r
.4878 .16187 m
.4878 .15483 L
.48868 .15483 L
.48868 .16187 L
s
1 .894 .882 r
.48868 .16187 m
.48868 .15511 L
.48949 .15511 L
.48949 .16187 L
F
.804 .522 .247 r
.48868 .16187 m
.48868 .15511 L
.48949 .15511 L
.48949 .16187 L
s
1 .894 .882 r
.48949 .16187 m
.48949 .15564 L
.49023 .15564 L
.49023 .16187 L
F
.804 .522 .247 r
.48949 .16187 m
.48949 .15564 L
.49023 .15564 L
.49023 .16187 L
s
1 .894 .882 r
.49023 .16187 m
.49023 .15674 L
.49168 .15674 L
.49168 .16187 L
F
.804 .522 .247 r
.49023 .16187 m
.49023 .15674 L
.49168 .15674 L
.49168 .16187 L
s
1 .894 .882 r
.49168 .16187 m
.49168 .15727 L
.49335 .15727 L
.49335 .16187 L
F
.804 .522 .247 r
.49168 .16187 m
.49168 .15727 L
.49335 .15727 L
.49335 .16187 L
s
1 .894 .882 r
.49335 .16187 m
.49335 .15785 L
.49397 .15785 L
.49397 .16187 L
F
.804 .522 .247 r
.49335 .16187 m
.49335 .15785 L
.49397 .15785 L
.49397 .16187 L
s
1 .894 .882 r
.49397 .16187 m
.49397 .15848 L
.49506 .15848 L
.49506 .16187 L
F
.804 .522 .247 r
.49397 .16187 m
.49397 .15848 L
.49506 .15848 L
.49506 .16187 L
s
1 .894 .882 r
.49506 .16187 m
.49506 .15898 L
.4958 .15898 L
.4958 .16187 L
F
.804 .522 .247 r
.49506 .16187 m
.49506 .15898 L
.4958 .15898 L
.4958 .16187 L
s
1 .894 .882 r
.4958 .16187 m
.4958 .15945 L
.49658 .15945 L
.49658 .16187 L
F
.804 .522 .247 r
.4958 .16187 m
.4958 .15945 L
.49658 .15945 L
.49658 .16187 L
s
1 .894 .882 r
.49658 .16187 m
.49658 .16006 L
.49728 .16006 L
.49728 .16187 L
F
.804 .522 .247 r
.49658 .16187 m
.49658 .16006 L
.49728 .16006 L
.49728 .16187 L
s
1 .894 .882 r
.49728 .16187 m
.49728 .16043 L
.49852 .16043 L
.49852 .16187 L
F
.804 .522 .247 r
.49728 .16187 m
.49728 .16043 L
.49852 .16043 L
.49852 .16187 L
s
1 .894 .882 r
.49852 .16187 m
.49852 .16113 L
.49995 .16113 L
.49995 .16187 L
F
.804 .522 .247 r
.49852 .16187 m
.49852 .16113 L
.49995 .16113 L
.49995 .16187 L
s
.678 .847 .902 r
.49995 .16187 m
.49995 .16203 L
.50064 .16203 L
.50064 .16187 L
F
.2 .63 .79 r
.49995 .16187 m
.49995 .16203 L
.50064 .16203 L
.50064 .16187 L
s
.678 .847 .902 r
.50064 .16187 m
.50064 .1623 L
.50134 .1623 L
.50134 .16187 L
F
.2 .63 .79 r
.50064 .16187 m
.50064 .1623 L
.50134 .1623 L
.50134 .16187 L
s
.678 .847 .902 r
.50134 .16187 m
.50134 .16324 L
.50224 .16324 L
.50224 .16187 L
F
.2 .63 .79 r
.50134 .16187 m
.50134 .16324 L
.50224 .16324 L
.50224 .16187 L
s
.678 .847 .902 r
.50224 .16187 m
.50224 .16348 L
.50386 .16348 L
.50386 .16187 L
F
.2 .63 .79 r
.50224 .16187 m
.50224 .16348 L
.50386 .16348 L
.50386 .16187 L
s
.678 .847 .902 r
.50386 .16187 m
.50386 .16498 L
.50515 .16498 L
.50515 .16187 L
F
.2 .63 .79 r
.50386 .16187 m
.50386 .16498 L
.50515 .16498 L
.50515 .16187 L
s
.678 .847 .902 r
.50515 .16187 m
.50515 .16523 L
.50575 .16523 L
.50575 .16187 L
F
.2 .63 .79 r
.50515 .16187 m
.50515 .16523 L
.50575 .16523 L
.50575 .16187 L
s
.678 .847 .902 r
.50575 .16187 m
.50575 .16568 L
.50729 .16568 L
.50729 .16187 L
F
.2 .63 .79 r
.50575 .16187 m
.50575 .16568 L
.50729 .16568 L
.50729 .16187 L
s
.678 .847 .902 r
.50729 .16187 m
.50729 .16725 L
.50898 .16725 L
.50898 .16187 L
F
.2 .63 .79 r
.50729 .16187 m
.50729 .16725 L
.50898 .16725 L
.50898 .16187 L
s
.678 .847 .902 r
.50898 .16187 m
.50898 .16812 L
.5106 .16812 L
.5106 .16187 L
F
.2 .63 .79 r
.50898 .16187 m
.50898 .16812 L
.5106 .16812 L
.5106 .16187 L
s
.678 .847 .902 r
.5106 .16187 m
.5106 .16854 L
.51124 .16854 L
.51124 .16187 L
F
.2 .63 .79 r
.5106 .16187 m
.5106 .16854 L
.51124 .16854 L
.51124 .16187 L
s
.678 .847 .902 r
.51124 .16187 m
.51124 .16934 L
.512 .16934 L
.512 .16187 L
F
.2 .63 .79 r
.51124 .16187 m
.51124 .16934 L
.512 .16934 L
.512 .16187 L
s
.678 .847 .902 r
.512 .16187 m
.512 .17003 L
.51348 .17003 L
.51348 .16187 L
F
.2 .63 .79 r
.512 .16187 m
.512 .17003 L
.51348 .17003 L
.51348 .16187 L
s
.678 .847 .902 r
.51348 .16187 m
.51348 .17101 L
.51473 .17101 L
.51473 .16187 L
F
.2 .63 .79 r
.51348 .16187 m
.51348 .17101 L
.51473 .17101 L
.51473 .16187 L
s
.678 .847 .902 r
.51473 .16187 m
.51473 .17189 L
.51626 .17189 L
.51626 .16187 L
F
.2 .63 .79 r
.51473 .16187 m
.51473 .17189 L
.51626 .17189 L
.51626 .16187 L
s
.678 .847 .902 r
.51626 .16187 m
.51626 .17225 L
.5168 .17225 L
.5168 .16187 L
F
.2 .63 .79 r
.51626 .16187 m
.51626 .17225 L
.5168 .17225 L
.5168 .16187 L
s
.678 .847 .902 r
.5168 .16187 m
.5168 .17269 L
.51734 .17269 L
.51734 .16187 L
F
.2 .63 .79 r
.5168 .16187 m
.5168 .17269 L
.51734 .17269 L
.51734 .16187 L
s
.678 .847 .902 r
.51734 .16187 m
.51734 .17309 L
.51863 .17309 L
.51863 .16187 L
F
.2 .63 .79 r
.51734 .16187 m
.51734 .17309 L
.51863 .17309 L
.51863 .16187 L
s
.678 .847 .902 r
.51863 .16187 m
.51863 .17418 L
.52006 .17418 L
.52006 .16187 L
F
.2 .63 .79 r
.51863 .16187 m
.51863 .17418 L
.52006 .17418 L
.52006 .16187 L
s
.678 .847 .902 r
.52006 .16187 m
.52006 .17528 L
.52123 .17528 L
.52123 .16187 L
F
.2 .63 .79 r
.52006 .16187 m
.52006 .17528 L
.52123 .17528 L
.52123 .16187 L
s
.678 .847 .902 r
.52123 .16187 m
.52123 .17566 L
.52273 .17566 L
.52273 .16187 L
F
.2 .63 .79 r
.52123 .16187 m
.52123 .17566 L
.52273 .17566 L
.52273 .16187 L
s
.678 .847 .902 r
.52273 .16187 m
.52273 .17627 L
.52376 .17627 L
.52376 .16187 L
F
.2 .63 .79 r
.52273 .16187 m
.52273 .17627 L
.52376 .17627 L
.52376 .16187 L
s
.678 .847 .902 r
.52376 .16187 m
.52376 .17766 L
.52501 .17766 L
.52501 .16187 L
F
.2 .63 .79 r
.52376 .16187 m
.52376 .17766 L
.52501 .17766 L
.52501 .16187 L
s
.678 .847 .902 r
.52501 .16187 m
.52501 .17845 L
.52664 .17845 L
.52664 .16187 L
F
.2 .63 .79 r
.52501 .16187 m
.52501 .17845 L
.52664 .17845 L
.52664 .16187 L
s
.678 .847 .902 r
.52664 .16187 m
.52664 .17886 L
.52723 .17886 L
.52723 .16187 L
F
.2 .63 .79 r
.52664 .16187 m
.52664 .17886 L
.52723 .17886 L
.52723 .16187 L
s
.678 .847 .902 r
.52723 .16187 m
.52723 .1795 L
.52809 .1795 L
.52809 .16187 L
F
.2 .63 .79 r
.52723 .16187 m
.52723 .1795 L
.52809 .1795 L
.52809 .16187 L
s
.678 .847 .902 r
.52809 .16187 m
.52809 .1803 L
.52915 .1803 L
.52915 .16187 L
F
.2 .63 .79 r
.52809 .16187 m
.52809 .1803 L
.52915 .1803 L
.52915 .16187 L
s
.678 .847 .902 r
.52915 .16187 m
.52915 .181 L
.53039 .181 L
.53039 .16187 L
F
.2 .63 .79 r
.52915 .16187 m
.52915 .181 L
.53039 .181 L
.53039 .16187 L
s
.678 .847 .902 r
.53039 .16187 m
.53039 .18168 L
.53107 .18168 L
.53107 .16187 L
F
.2 .63 .79 r
.53039 .16187 m
.53039 .18168 L
.53107 .18168 L
.53107 .16187 L
s
.678 .847 .902 r
.53107 .16187 m
.53107 .18227 L
.53234 .18227 L
.53234 .16187 L
F
.2 .63 .79 r
.53107 .16187 m
.53107 .18227 L
.53234 .18227 L
.53234 .16187 L
s
.678 .847 .902 r
.53234 .16187 m
.53234 .18278 L
.53332 .18278 L
.53332 .16187 L
F
.2 .63 .79 r
.53234 .16187 m
.53234 .18278 L
.53332 .18278 L
.53332 .16187 L
s
.678 .847 .902 r
.53332 .16187 m
.53332 .1836 L
.53473 .1836 L
.53473 .16187 L
F
.2 .63 .79 r
.53332 .16187 m
.53332 .1836 L
.53473 .1836 L
.53473 .16187 L
s
.678 .847 .902 r
.53473 .16187 m
.53473 .1842 L
.53545 .1842 L
.53545 .16187 L
F
.2 .63 .79 r
.53473 .16187 m
.53473 .1842 L
.53545 .1842 L
.53545 .16187 L
s
.678 .847 .902 r
.53545 .16187 m
.53545 .18463 L
.53681 .18463 L
.53681 .16187 L
F
.2 .63 .79 r
.53545 .16187 m
.53545 .18463 L
.53681 .18463 L
.53681 .16187 L
s
.678 .847 .902 r
.53681 .16187 m
.53681 .18564 L
.53766 .18564 L
.53766 .16187 L
F
.2 .63 .79 r
.53681 .16187 m
.53681 .18564 L
.53766 .18564 L
.53766 .16187 L
s
.678 .847 .902 r
.53766 .16187 m
.53766 .18647 L
.53882 .18647 L
.53882 .16187 L
F
.2 .63 .79 r
.53766 .16187 m
.53766 .18647 L
.53882 .18647 L
.53882 .16187 L
s
.678 .847 .902 r
.53882 .16187 m
.53882 .18713 L
.53977 .18713 L
.53977 .16187 L
F
.2 .63 .79 r
.53882 .16187 m
.53882 .18713 L
.53977 .18713 L
.53977 .16187 L
s
.678 .847 .902 r
.53977 .16187 m
.53977 .18754 L
.5404 .18754 L
.5404 .16187 L
F
.2 .63 .79 r
.53977 .16187 m
.53977 .18754 L
.5404 .18754 L
.5404 .16187 L
s
.678 .847 .902 r
.5404 .16187 m
.5404 .18821 L
.54142 .18821 L
.54142 .16187 L
F
.2 .63 .79 r
.5404 .16187 m
.5404 .18821 L
.54142 .18821 L
.54142 .16187 L
s
.678 .847 .902 r
.54142 .16187 m
.54142 .18862 L
.54256 .18862 L
.54256 .16187 L
F
.2 .63 .79 r
.54142 .16187 m
.54142 .18862 L
.54256 .18862 L
.54256 .16187 L
s
.678 .847 .902 r
.54256 .16187 m
.54256 .1898 L
.54349 .1898 L
.54349 .16187 L
F
.2 .63 .79 r
.54256 .16187 m
.54256 .1898 L
.54349 .1898 L
.54349 .16187 L
s
.678 .847 .902 r
.54349 .16187 m
.54349 .19052 L
.54453 .19052 L
.54453 .16187 L
F
.2 .63 .79 r
.54349 .16187 m
.54349 .19052 L
.54453 .19052 L
.54453 .16187 L
s
.678 .847 .902 r
.54453 .16187 m
.54453 .19141 L
.54583 .19141 L
.54583 .16187 L
F
.2 .63 .79 r
.54453 .16187 m
.54453 .19141 L
.54583 .19141 L
.54583 .16187 L
s
.678 .847 .902 r
.54583 .16187 m
.54583 .19163 L
.54752 .19163 L
.54752 .16187 L
F
.2 .63 .79 r
.54583 .16187 m
.54583 .19163 L
.54752 .19163 L
.54752 .16187 L
s
.678 .847 .902 r
.54752 .16187 m
.54752 .19296 L
.54865 .19296 L
.54865 .16187 L
F
.2 .63 .79 r
.54752 .16187 m
.54752 .19296 L
.54865 .19296 L
.54865 .16187 L
s
.678 .847 .902 r
.54865 .16187 m
.54865 .19374 L
.54918 .19374 L
.54918 .16187 L
F
.2 .63 .79 r
.54865 .16187 m
.54865 .19374 L
.54918 .19374 L
.54918 .16187 L
s
.678 .847 .902 r
.54918 .16187 m
.54918 .19419 L
.54975 .19419 L
.54975 .16187 L
F
.2 .63 .79 r
.54918 .16187 m
.54918 .19419 L
.54975 .19419 L
.54975 .16187 L
s
.678 .847 .902 r
.54975 .16187 m
.54975 .19437 L
.55032 .19437 L
.55032 .16187 L
F
.2 .63 .79 r
.54975 .16187 m
.54975 .19437 L
.55032 .19437 L
.55032 .16187 L
s
.678 .847 .902 r
.55032 .16187 m
.55032 .19471 L
.55137 .19471 L
.55137 .16187 L
F
.2 .63 .79 r
.55032 .16187 m
.55032 .19471 L
.55137 .19471 L
.55137 .16187 L
s
.678 .847 .902 r
.55137 .16187 m
.55137 .19549 L
.55276 .19549 L
.55276 .16187 L
F
.2 .63 .79 r
.55137 .16187 m
.55137 .19549 L
.55276 .19549 L
.55276 .16187 L
s
.678 .847 .902 r
.55276 .16187 m
.55276 .19637 L
.55399 .19637 L
.55399 .16187 L
F
.2 .63 .79 r
.55276 .16187 m
.55276 .19637 L
.55399 .19637 L
.55399 .16187 L
s
.678 .847 .902 r
.55399 .16187 m
.55399 .19761 L
.55503 .19761 L
.55503 .16187 L
F
.2 .63 .79 r
.55399 .16187 m
.55399 .19761 L
.55503 .19761 L
.55503 .16187 L
s
.678 .847 .902 r
.55503 .16187 m
.55503 .19795 L
.5559 .19795 L
.5559 .16187 L
F
.2 .63 .79 r
.55503 .16187 m
.55503 .19795 L
.5559 .19795 L
.5559 .16187 L
s
.678 .847 .902 r
.5559 .16187 m
.5559 .19865 L
.55653 .19865 L
.55653 .16187 L
F
.2 .63 .79 r
.5559 .16187 m
.5559 .19865 L
.55653 .19865 L
.55653 .16187 L
s
.678 .847 .902 r
.55653 .16187 m
.55653 .19926 L
.55729 .19926 L
.55729 .16187 L
F
.2 .63 .79 r
.55653 .16187 m
.55653 .19926 L
.55729 .19926 L
.55729 .16187 L
s
.678 .847 .902 r
.55729 .16187 m
.55729 .19962 L
.55863 .19962 L
.55863 .16187 L
F
.2 .63 .79 r
.55729 .16187 m
.55729 .19962 L
.55863 .19962 L
.55863 .16187 L
s
.678 .847 .902 r
.55863 .16187 m
.55863 .20034 L
.55931 .20034 L
.55931 .16187 L
F
.2 .63 .79 r
.55863 .16187 m
.55863 .20034 L
.55931 .20034 L
.55931 .16187 L
s
.678 .847 .902 r
.55931 .16187 m
.55931 .2011 L
.56029 .2011 L
.56029 .16187 L
F
.2 .63 .79 r
.55931 .16187 m
.55931 .2011 L
.56029 .2011 L
.56029 .16187 L
s
.678 .847 .902 r
.56029 .16187 m
.56029 .20202 L
.56192 .20202 L
.56192 .16187 L
F
.2 .63 .79 r
.56029 .16187 m
.56029 .20202 L
.56192 .20202 L
.56192 .16187 L
s
.678 .847 .902 r
.56192 .16187 m
.56192 .20296 L
.56261 .20296 L
.56261 .16187 L
F
.2 .63 .79 r
.56192 .16187 m
.56192 .20296 L
.56261 .20296 L
.56261 .16187 L
s
.678 .847 .902 r
.56261 .16187 m
.56261 .20365 L
.56405 .20365 L
.56405 .16187 L
F
.2 .63 .79 r
.56261 .16187 m
.56261 .20365 L
.56405 .20365 L
.56405 .16187 L
s
.678 .847 .902 r
.56405 .16187 m
.56405 .20427 L
.56491 .20427 L
.56491 .16187 L
F
.2 .63 .79 r
.56405 .16187 m
.56405 .20427 L
.56491 .20427 L
.56491 .16187 L
s
.678 .847 .902 r
.56491 .16187 m
.56491 .20472 L
.56603 .20472 L
.56603 .16187 L
F
.2 .63 .79 r
.56491 .16187 m
.56491 .20472 L
.56603 .20472 L
.56603 .16187 L
s
.678 .847 .902 r
.56603 .16187 m
.56603 .20607 L
.56729 .20607 L
.56729 .16187 L
F
.2 .63 .79 r
.56603 .16187 m
.56603 .20607 L
.56729 .20607 L
.56729 .16187 L
s
.678 .847 .902 r
.56729 .16187 m
.56729 .20698 L
.56832 .20698 L
.56832 .16187 L
F
.2 .63 .79 r
.56729 .16187 m
.56729 .20698 L
.56832 .20698 L
.56832 .16187 L
s
.678 .847 .902 r
.56832 .16187 m
.56832 .20764 L
.56986 .20764 L
.56986 .16187 L
F
.2 .63 .79 r
.56832 .16187 m
.56832 .20764 L
.56986 .20764 L
.56986 .16187 L
s
.678 .847 .902 r
.56986 .16187 m
.56986 .20839 L
.57138 .20839 L
.57138 .16187 L
F
.2 .63 .79 r
.56986 .16187 m
.56986 .20839 L
.57138 .20839 L
.57138 .16187 L
s
.678 .847 .902 r
.57138 .16187 m
.57138 .20982 L
.57266 .20982 L
.57266 .16187 L
F
.2 .63 .79 r
.57138 .16187 m
.57138 .20982 L
.57266 .20982 L
.57266 .16187 L
s
.678 .847 .902 r
.57266 .16187 m
.57266 .21075 L
.57427 .21075 L
.57427 .16187 L
F
.2 .63 .79 r
.57266 .16187 m
.57266 .21075 L
.57427 .21075 L
.57427 .16187 L
s
.678 .847 .902 r
.57427 .16187 m
.57427 .21214 L
.5758 .21214 L
.5758 .16187 L
F
.2 .63 .79 r
.57427 .16187 m
.57427 .21214 L
.5758 .21214 L
.5758 .16187 L
s
.678 .847 .902 r
.5758 .16187 m
.5758 .2127 L
.57726 .2127 L
.57726 .16187 L
F
.2 .63 .79 r
.5758 .16187 m
.5758 .2127 L
.57726 .2127 L
.57726 .16187 L
s
.678 .847 .902 r
.57726 .16187 m
.57726 .21366 L
.57849 .21366 L
.57849 .16187 L
F
.2 .63 .79 r
.57726 .16187 m
.57726 .21366 L
.57849 .21366 L
.57849 .16187 L
s
.678 .847 .902 r
.57849 .16187 m
.57849 .21463 L
.57956 .21463 L
.57956 .16187 L
F
.2 .63 .79 r
.57849 .16187 m
.57849 .21463 L
.57956 .21463 L
.57956 .16187 L
s
.678 .847 .902 r
.57956 .16187 m
.57956 .21541 L
.58021 .21541 L
.58021 .16187 L
F
.2 .63 .79 r
.57956 .16187 m
.57956 .21541 L
.58021 .21541 L
.58021 .16187 L
s
.678 .847 .902 r
.58021 .16187 m
.58021 .21569 L
.58096 .21569 L
.58096 .16187 L
F
.2 .63 .79 r
.58021 .16187 m
.58021 .21569 L
.58096 .21569 L
.58096 .16187 L
s
.678 .847 .902 r
.58096 .16187 m
.58096 .21642 L
.58166 .21642 L
.58166 .16187 L
F
.2 .63 .79 r
.58096 .16187 m
.58096 .21642 L
.58166 .21642 L
.58166 .16187 L
s
.678 .847 .902 r
.58166 .16187 m
.58166 .21674 L
.58237 .21674 L
.58237 .16187 L
F
.2 .63 .79 r
.58166 .16187 m
.58166 .21674 L
.58237 .21674 L
.58237 .16187 L
s
.678 .847 .902 r
.58237 .16187 m
.58237 .21721 L
.58291 .21721 L
.58291 .16187 L
F
.2 .63 .79 r
.58237 .16187 m
.58237 .21721 L
.58291 .21721 L
.58291 .16187 L
s
.678 .847 .902 r
.58291 .16187 m
.58291 .21807 L
.5846 .21807 L
.5846 .16187 L
F
.2 .63 .79 r
.58291 .16187 m
.58291 .21807 L
.5846 .21807 L
.5846 .16187 L
s
.678 .847 .902 r
.5846 .16187 m
.5846 .21902 L
.58568 .21902 L
.58568 .16187 L
F
.2 .63 .79 r
.5846 .16187 m
.5846 .21902 L
.58568 .21902 L
.58568 .16187 L
s
.678 .847 .902 r
.58568 .16187 m
.58568 .21964 L
.58622 .21964 L
.58622 .16187 L
F
.2 .63 .79 r
.58568 .16187 m
.58568 .21964 L
.58622 .21964 L
.58622 .16187 L
s
.678 .847 .902 r
.58622 .16187 m
.58622 .22058 L
.58749 .22058 L
.58749 .16187 L
F
.2 .63 .79 r
.58622 .16187 m
.58622 .22058 L
.58749 .22058 L
.58749 .16187 L
s
.678 .847 .902 r
.58749 .16187 m
.58749 .22131 L
.58808 .22131 L
.58808 .16187 L
F
.2 .63 .79 r
.58749 .16187 m
.58749 .22131 L
.58808 .22131 L
.58808 .16187 L
s
.678 .847 .902 r
.58808 .16187 m
.58808 .22172 L
.58898 .22172 L
.58898 .16187 L
F
.2 .63 .79 r
.58808 .16187 m
.58808 .22172 L
.58898 .22172 L
.58898 .16187 L
s
.678 .847 .902 r
.58898 .16187 m
.58898 .22235 L
.58979 .22235 L
.58979 .16187 L
F
.2 .63 .79 r
.58898 .16187 m
.58898 .22235 L
.58979 .22235 L
.58979 .16187 L
s
.678 .847 .902 r
.58979 .16187 m
.58979 .22285 L
.59071 .22285 L
.59071 .16187 L
F
.2 .63 .79 r
.58979 .16187 m
.58979 .22285 L
.59071 .22285 L
.59071 .16187 L
s
.678 .847 .902 r
.59071 .16187 m
.59071 .22407 L
.59189 .22407 L
.59189 .16187 L
F
.2 .63 .79 r
.59071 .16187 m
.59071 .22407 L
.59189 .22407 L
.59189 .16187 L
s
.678 .847 .902 r
.59189 .16187 m
.59189 .22507 L
.59324 .22507 L
.59324 .16187 L
F
.2 .63 .79 r
.59189 .16187 m
.59189 .22507 L
.59324 .22507 L
.59324 .16187 L
s
.678 .847 .902 r
.59324 .16187 m
.59324 .226 L
.59473 .226 L
.59473 .16187 L
F
.2 .63 .79 r
.59324 .16187 m
.59324 .226 L
.59473 .226 L
.59473 .16187 L
s
.678 .847 .902 r
.59473 .16187 m
.59473 .22697 L
.59582 .22697 L
.59582 .16187 L
F
.2 .63 .79 r
.59473 .16187 m
.59473 .22697 L
.59582 .22697 L
.59582 .16187 L
s
.678 .847 .902 r
.59582 .16187 m
.59582 .22783 L
.5972 .22783 L
.5972 .16187 L
F
.2 .63 .79 r
.59582 .16187 m
.59582 .22783 L
.5972 .22783 L
.5972 .16187 L
s
.678 .847 .902 r
.5972 .16187 m
.5972 .22822 L
.59778 .22822 L
.59778 .16187 L
F
.2 .63 .79 r
.5972 .16187 m
.5972 .22822 L
.59778 .22822 L
.59778 .16187 L
s
.678 .847 .902 r
.59778 .16187 m
.59778 .22887 L
.59937 .22887 L
.59937 .16187 L
F
.2 .63 .79 r
.59778 .16187 m
.59778 .22887 L
.59937 .22887 L
.59937 .16187 L
s
.678 .847 .902 r
.59937 .16187 m
.59937 .22986 L
.60065 .22986 L
.60065 .16187 L
F
.2 .63 .79 r
.59937 .16187 m
.59937 .22986 L
.60065 .22986 L
.60065 .16187 L
s
.678 .847 .902 r
.60065 .16187 m
.60065 .23128 L
.60228 .23128 L
.60228 .16187 L
F
.2 .63 .79 r
.60065 .16187 m
.60065 .23128 L
.60228 .23128 L
.60228 .16187 L
s
.678 .847 .902 r
.60228 .16187 m
.60228 .23199 L
.60334 .23199 L
.60334 .16187 L
F
.2 .63 .79 r
.60228 .16187 m
.60228 .23199 L
.60334 .23199 L
.60334 .16187 L
s
.678 .847 .902 r
.60334 .16187 m
.60334 .23343 L
.60437 .23343 L
.60437 .16187 L
F
.2 .63 .79 r
.60334 .16187 m
.60334 .23343 L
.60437 .23343 L
.60437 .16187 L
s
.678 .847 .902 r
.60437 .16187 m
.60437 .23398 L
.60552 .23398 L
.60552 .16187 L
F
.2 .63 .79 r
.60437 .16187 m
.60437 .23398 L
.60552 .23398 L
.60552 .16187 L
s
.678 .847 .902 r
.60552 .16187 m
.60552 .2347 L
.60691 .2347 L
.60691 .16187 L
F
.2 .63 .79 r
.60552 .16187 m
.60552 .2347 L
.60691 .2347 L
.60691 .16187 L
s
.678 .847 .902 r
.60691 .16187 m
.60691 .23578 L
.60778 .23578 L
.60778 .16187 L
F
.2 .63 .79 r
.60691 .16187 m
.60691 .23578 L
.60778 .23578 L
.60778 .16187 L
s
.678 .847 .902 r
.60778 .16187 m
.60778 .23655 L
.60862 .23655 L
.60862 .16187 L
F
.2 .63 .79 r
.60778 .16187 m
.60778 .23655 L
.60862 .23655 L
.60862 .16187 L
s
.678 .847 .902 r
.60862 .16187 m
.60862 .23712 L
.60974 .23712 L
.60974 .16187 L
F
.2 .63 .79 r
.60862 .16187 m
.60862 .23712 L
.60974 .23712 L
.60974 .16187 L
s
.678 .847 .902 r
.60974 .16187 m
.60974 .23855 L
.61115 .23855 L
.61115 .16187 L
F
.2 .63 .79 r
.60974 .16187 m
.60974 .23855 L
.61115 .23855 L
.61115 .16187 L
s
.678 .847 .902 r
.61115 .16187 m
.61115 .23899 L
.61265 .23899 L
.61265 .16187 L
F
.2 .63 .79 r
.61115 .16187 m
.61115 .23899 L
.61265 .23899 L
.61265 .16187 L
s
.678 .847 .902 r
.61265 .16187 m
.61265 .24015 L
.61347 .24015 L
.61347 .16187 L
F
.2 .63 .79 r
.61265 .16187 m
.61265 .24015 L
.61347 .24015 L
.61347 .16187 L
s
.678 .847 .902 r
.61347 .16187 m
.61347 .24143 L
.61503 .24143 L
.61503 .16187 L
F
.2 .63 .79 r
.61347 .16187 m
.61347 .24143 L
.61503 .24143 L
.61503 .16187 L
s
.678 .847 .902 r
.61503 .16187 m
.61503 .24158 L
.61637 .24158 L
.61637 .16187 L
F
.2 .63 .79 r
.61503 .16187 m
.61503 .24158 L
.61637 .24158 L
.61637 .16187 L
s
.678 .847 .902 r
.61637 .16187 m
.61637 .24325 L
.61748 .24325 L
.61748 .16187 L
F
.2 .63 .79 r
.61637 .16187 m
.61637 .24325 L
.61748 .24325 L
.61748 .16187 L
s
.678 .847 .902 r
.61748 .16187 m
.61748 .24347 L
.618 .24347 L
.618 .16187 L
F
.2 .63 .79 r
.61748 .16187 m
.61748 .24347 L
.618 .24347 L
.618 .16187 L
s
.678 .847 .902 r
.618 .16187 m
.618 .24429 L
.61915 .24429 L
.61915 .16187 L
F
.2 .63 .79 r
.618 .16187 m
.618 .24429 L
.61915 .24429 L
.61915 .16187 L
s
.678 .847 .902 r
.61915 .16187 m
.61915 .24477 L
.61983 .24477 L
.61983 .16187 L
F
.2 .63 .79 r
.61915 .16187 m
.61915 .24477 L
.61983 .24477 L
.61983 .16187 L
s
.678 .847 .902 r
.61983 .16187 m
.61983 .24621 L
.6213 .24621 L
.6213 .16187 L
F
.2 .63 .79 r
.61983 .16187 m
.61983 .24621 L
.6213 .24621 L
.6213 .16187 L
s
.678 .847 .902 r
.6213 .16187 m
.6213 .24656 L
.62204 .24656 L
.62204 .16187 L
F
.2 .63 .79 r
.6213 .16187 m
.6213 .24656 L
.62204 .24656 L
.62204 .16187 L
s
.678 .847 .902 r
.62204 .16187 m
.62204 .24723 L
.62261 .24723 L
.62261 .16187 L
F
.2 .63 .79 r
.62204 .16187 m
.62204 .24723 L
.62261 .24723 L
.62261 .16187 L
s
.678 .847 .902 r
.62261 .16187 m
.62261 .24767 L
.62363 .24767 L
.62363 .16187 L
F
.2 .63 .79 r
.62261 .16187 m
.62261 .24767 L
.62363 .24767 L
.62363 .16187 L
s
.678 .847 .902 r
.62363 .16187 m
.62363 .24873 L
.62504 .24873 L
.62504 .16187 L
F
.2 .63 .79 r
.62363 .16187 m
.62363 .24873 L
.62504 .24873 L
.62504 .16187 L
s
.678 .847 .902 r
.62504 .16187 m
.62504 .24995 L
.62589 .24995 L
.62589 .16187 L
F
.2 .63 .79 r
.62504 .16187 m
.62504 .24995 L
.62589 .24995 L
.62589 .16187 L
s
.678 .847 .902 r
.62589 .16187 m
.62589 .2503 L
.62689 .2503 L
.62689 .16187 L
F
.2 .63 .79 r
.62589 .16187 m
.62589 .2503 L
.62689 .2503 L
.62689 .16187 L
s
.678 .847 .902 r
.62689 .16187 m
.62689 .25145 L
.62799 .25145 L
.62799 .16187 L
F
.2 .63 .79 r
.62689 .16187 m
.62689 .25145 L
.62799 .25145 L
.62799 .16187 L
s
.678 .847 .902 r
.62799 .16187 m
.62799 .25183 L
.62886 .25183 L
.62886 .16187 L
F
.2 .63 .79 r
.62799 .16187 m
.62799 .25183 L
.62886 .25183 L
.62886 .16187 L
s
.678 .847 .902 r
.62886 .16187 m
.62886 .25349 L
.63039 .25349 L
.63039 .16187 L
F
.2 .63 .79 r
.62886 .16187 m
.62886 .25349 L
.63039 .25349 L
.63039 .16187 L
s
.678 .847 .902 r
.63039 .16187 m
.63039 .25449 L
.63196 .25449 L
.63196 .16187 L
F
.2 .63 .79 r
.63039 .16187 m
.63039 .25449 L
.63196 .25449 L
.63196 .16187 L
s
.678 .847 .902 r
.63196 .16187 m
.63196 .25521 L
.63338 .25521 L
.63338 .16187 L
F
.2 .63 .79 r
.63196 .16187 m
.63196 .25521 L
.63338 .25521 L
.63338 .16187 L
s
.678 .847 .902 r
.63338 .16187 m
.63338 .25678 L
.63509 .25678 L
.63509 .16187 L
F
.2 .63 .79 r
.63338 .16187 m
.63338 .25678 L
.63509 .25678 L
.63509 .16187 L
s
.678 .847 .902 r
.63509 .16187 m
.63509 .25736 L
.63629 .25736 L
.63629 .16187 L
F
.2 .63 .79 r
.63509 .16187 m
.63509 .25736 L
.63629 .25736 L
.63629 .16187 L
s
.678 .847 .902 r
.63629 .16187 m
.63629 .25835 L
.63726 .25835 L
.63726 .16187 L
F
.2 .63 .79 r
.63629 .16187 m
.63629 .25835 L
.63726 .25835 L
.63726 .16187 L
s
.678 .847 .902 r
.63726 .16187 m
.63726 .25911 L
.63777 .25911 L
.63777 .16187 L
F
.2 .63 .79 r
.63726 .16187 m
.63726 .25911 L
.63777 .25911 L
.63777 .16187 L
s
.678 .847 .902 r
.63777 .16187 m
.63777 .25952 L
.6385 .25952 L
.6385 .16187 L
F
.2 .63 .79 r
.63777 .16187 m
.63777 .25952 L
.6385 .25952 L
.6385 .16187 L
s
.678 .847 .902 r
.6385 .16187 m
.6385 .26025 L
.6394 .26025 L
.6394 .16187 L
F
.2 .63 .79 r
.6385 .16187 m
.6385 .26025 L
.6394 .26025 L
.6394 .16187 L
s
.678 .847 .902 r
.6394 .16187 m
.6394 .26095 L
.64052 .26095 L
.64052 .16187 L
F
.2 .63 .79 r
.6394 .16187 m
.6394 .26095 L
.64052 .26095 L
.64052 .16187 L
s
.678 .847 .902 r
.64052 .16187 m
.64052 .26183 L
.6414 .26183 L
.6414 .16187 L
F
.2 .63 .79 r
.64052 .16187 m
.64052 .26183 L
.6414 .26183 L
.6414 .16187 L
s
.678 .847 .902 r
.6414 .16187 m
.6414 .26281 L
.64272 .26281 L
.64272 .16187 L
F
.2 .63 .79 r
.6414 .16187 m
.6414 .26281 L
.64272 .26281 L
.64272 .16187 L
s
.678 .847 .902 r
.64272 .16187 m
.64272 .26357 L
.64363 .26357 L
.64363 .16187 L
F
.2 .63 .79 r
.64272 .16187 m
.64272 .26357 L
.64363 .26357 L
.64363 .16187 L
s
.678 .847 .902 r
.64363 .16187 m
.64363 .26514 L
.6453 .26514 L
.6453 .16187 L
F
.2 .63 .79 r
.64363 .16187 m
.64363 .26514 L
.6453 .26514 L
.6453 .16187 L
s
.678 .847 .902 r
.6453 .16187 m
.6453 .26556 L
.64603 .26556 L
.64603 .16187 L
F
.2 .63 .79 r
.6453 .16187 m
.6453 .26556 L
.64603 .26556 L
.64603 .16187 L
s
.678 .847 .902 r
.64603 .16187 m
.64603 .26682 L
.64758 .26682 L
.64758 .16187 L
F
.2 .63 .79 r
.64603 .16187 m
.64603 .26682 L
.64758 .26682 L
.64758 .16187 L
s
.678 .847 .902 r
.64758 .16187 m
.64758 .26726 L
.64826 .26726 L
.64826 .16187 L
F
.2 .63 .79 r
.64758 .16187 m
.64758 .26726 L
.64826 .26726 L
.64826 .16187 L
s
.678 .847 .902 r
.64826 .16187 m
.64826 .26804 L
.64987 .26804 L
.64987 .16187 L
F
.2 .63 .79 r
.64826 .16187 m
.64826 .26804 L
.64987 .26804 L
.64987 .16187 L
s
.678 .847 .902 r
.64987 .16187 m
.64987 .27022 L
.6513 .27022 L
.6513 .16187 L
F
.2 .63 .79 r
.64987 .16187 m
.64987 .27022 L
.6513 .27022 L
.6513 .16187 L
s
.678 .847 .902 r
.6513 .16187 m
.6513 .27033 L
.65195 .27033 L
.65195 .16187 L
F
.2 .63 .79 r
.6513 .16187 m
.6513 .27033 L
.65195 .27033 L
.65195 .16187 L
s
.678 .847 .902 r
.65195 .16187 m
.65195 .2709 L
.65349 .2709 L
.65349 .16187 L
F
.2 .63 .79 r
.65195 .16187 m
.65195 .2709 L
.65349 .2709 L
.65349 .16187 L
s
.678 .847 .902 r
.65349 .16187 m
.65349 .27274 L
.65462 .27274 L
.65462 .16187 L
F
.2 .63 .79 r
.65349 .16187 m
.65349 .27274 L
.65462 .27274 L
.65462 .16187 L
s
.678 .847 .902 r
.65462 .16187 m
.65462 .27306 L
.65546 .27306 L
.65546 .16187 L
F
.2 .63 .79 r
.65462 .16187 m
.65462 .27306 L
.65546 .27306 L
.65546 .16187 L
s
.678 .847 .902 r
.65546 .16187 m
.65546 .27469 L
.65696 .27469 L
.65696 .16187 L
F
.2 .63 .79 r
.65546 .16187 m
.65546 .27469 L
.65696 .27469 L
.65696 .16187 L
s
.678 .847 .902 r
.65696 .16187 m
.65696 .27501 L
.65867 .27501 L
.65867 .16187 L
F
.2 .63 .79 r
.65696 .16187 m
.65696 .27501 L
.65867 .27501 L
.65867 .16187 L
s
.678 .847 .902 r
.65867 .16187 m
.65867 .27729 L
.65994 .27729 L
.65994 .16187 L
F
.2 .63 .79 r
.65867 .16187 m
.65867 .27729 L
.65994 .27729 L
.65994 .16187 L
s
.678 .847 .902 r
.65994 .16187 m
.65994 .27801 L
.66108 .27801 L
.66108 .16187 L
F
.2 .63 .79 r
.65994 .16187 m
.65994 .27801 L
.66108 .27801 L
.66108 .16187 L
s
.678 .847 .902 r
.66108 .16187 m
.66108 .27847 L
.66258 .27847 L
.66258 .16187 L
F
.2 .63 .79 r
.66108 .16187 m
.66108 .27847 L
.66258 .27847 L
.66258 .16187 L
s
.678 .847 .902 r
.66258 .16187 m
.66258 .28029 L
.6636 .28029 L
.6636 .16187 L
F
.2 .63 .79 r
.66258 .16187 m
.66258 .28029 L
.6636 .28029 L
.6636 .16187 L
s
.678 .847 .902 r
.6636 .16187 m
.6636 .28083 L
.66442 .28083 L
.66442 .16187 L
F
.2 .63 .79 r
.6636 .16187 m
.6636 .28083 L
.66442 .28083 L
.66442 .16187 L
s
.678 .847 .902 r
.66442 .16187 m
.66442 .28128 L
.66556 .28128 L
.66556 .16187 L
F
.2 .63 .79 r
.66442 .16187 m
.66442 .28128 L
.66556 .28128 L
.66556 .16187 L
s
.678 .847 .902 r
.66556 .16187 m
.66556 .28288 L
.66685 .28288 L
.66685 .16187 L
F
.2 .63 .79 r
.66556 .16187 m
.66556 .28288 L
.66685 .28288 L
.66685 .16187 L
s
.678 .847 .902 r
.66685 .16187 m
.66685 .28329 L
.66748 .28329 L
.66748 .16187 L
F
.2 .63 .79 r
.66685 .16187 m
.66685 .28329 L
.66748 .28329 L
.66748 .16187 L
s
.678 .847 .902 r
.66748 .16187 m
.66748 .284 L
.6689 .284 L
.6689 .16187 L
F
.2 .63 .79 r
.66748 .16187 m
.66748 .284 L
.6689 .284 L
.6689 .16187 L
s
.678 .847 .902 r
.6689 .16187 m
.6689 .28529 L
.66966 .28529 L
.66966 .16187 L
F
.2 .63 .79 r
.6689 .16187 m
.6689 .28529 L
.66966 .28529 L
.66966 .16187 L
s
.678 .847 .902 r
.66966 .16187 m
.66966 .28582 L
.67134 .28582 L
.67134 .16187 L
F
.2 .63 .79 r
.66966 .16187 m
.66966 .28582 L
.67134 .28582 L
.67134 .16187 L
s
.678 .847 .902 r
.67134 .16187 m
.67134 .28691 L
.67278 .28691 L
.67278 .16187 L
F
.2 .63 .79 r
.67134 .16187 m
.67134 .28691 L
.67278 .28691 L
.67278 .16187 L
s
.678 .847 .902 r
.67278 .16187 m
.67278 .28867 L
.67424 .28867 L
.67424 .16187 L
F
.2 .63 .79 r
.67278 .16187 m
.67278 .28867 L
.67424 .28867 L
.67424 .16187 L
s
.678 .847 .902 r
.67424 .16187 m
.67424 .28948 L
.67478 .28948 L
.67478 .16187 L
F
.2 .63 .79 r
.67424 .16187 m
.67424 .28948 L
.67478 .28948 L
.67478 .16187 L
s
.678 .847 .902 r
.67478 .16187 m
.67478 .29004 L
.67543 .29004 L
.67543 .16187 L
F
.2 .63 .79 r
.67478 .16187 m
.67478 .29004 L
.67543 .29004 L
.67543 .16187 L
s
.678 .847 .902 r
.67543 .16187 m
.67543 .29132 L
.6767 .29132 L
.6767 .16187 L
F
.2 .63 .79 r
.67543 .16187 m
.67543 .29132 L
.6767 .29132 L
.6767 .16187 L
s
.678 .847 .902 r
.6767 .16187 m
.6767 .29175 L
.67826 .29175 L
.67826 .16187 L
F
.2 .63 .79 r
.6767 .16187 m
.6767 .29175 L
.67826 .29175 L
.67826 .16187 L
s
.678 .847 .902 r
.67826 .16187 m
.67826 .29301 L
.67909 .29301 L
.67909 .16187 L
F
.2 .63 .79 r
.67826 .16187 m
.67826 .29301 L
.67909 .29301 L
.67909 .16187 L
s
.678 .847 .902 r
.67909 .16187 m
.67909 .29395 L
.68079 .29395 L
.68079 .16187 L
F
.2 .63 .79 r
.67909 .16187 m
.67909 .29395 L
.68079 .29395 L
.68079 .16187 L
s
.678 .847 .902 r
.68079 .16187 m
.68079 .2959 L
.68224 .2959 L
.68224 .16187 L
F
.2 .63 .79 r
.68079 .16187 m
.68079 .2959 L
.68224 .2959 L
.68224 .16187 L
s
.678 .847 .902 r
.68224 .16187 m
.68224 .29648 L
.68318 .29648 L
.68318 .16187 L
F
.2 .63 .79 r
.68224 .16187 m
.68224 .29648 L
.68318 .29648 L
.68318 .16187 L
s
.678 .847 .902 r
.68318 .16187 m
.68318 .29734 L
.68488 .29734 L
.68488 .16187 L
F
.2 .63 .79 r
.68318 .16187 m
.68318 .29734 L
.68488 .29734 L
.68488 .16187 L
s
.678 .847 .902 r
.68488 .16187 m
.68488 .29865 L
.6856 .29865 L
.6856 .16187 L
F
.2 .63 .79 r
.68488 .16187 m
.68488 .29865 L
.6856 .29865 L
.6856 .16187 L
s
.678 .847 .902 r
.6856 .16187 m
.6856 .29989 L
.68705 .29989 L
.68705 .16187 L
F
.2 .63 .79 r
.6856 .16187 m
.6856 .29989 L
.68705 .29989 L
.68705 .16187 L
s
.678 .847 .902 r
.68705 .16187 m
.68705 .30084 L
.68843 .30084 L
.68843 .16187 L
F
.2 .63 .79 r
.68705 .16187 m
.68705 .30084 L
.68843 .30084 L
.68843 .16187 L
s
.678 .847 .902 r
.68843 .16187 m
.68843 .30192 L
.68951 .30192 L
.68951 .16187 L
F
.2 .63 .79 r
.68843 .16187 m
.68843 .30192 L
.68951 .30192 L
.68951 .16187 L
s
.678 .847 .902 r
.68951 .16187 m
.68951 .30259 L
.69043 .30259 L
.69043 .16187 L
F
.2 .63 .79 r
.68951 .16187 m
.68951 .30259 L
.69043 .30259 L
.69043 .16187 L
s
.678 .847 .902 r
.69043 .16187 m
.69043 .30378 L
.69138 .30378 L
.69138 .16187 L
F
.2 .63 .79 r
.69043 .16187 m
.69043 .30378 L
.69138 .30378 L
.69138 .16187 L
s
.678 .847 .902 r
.69138 .16187 m
.69138 .3047 L
.69245 .3047 L
.69245 .16187 L
F
.2 .63 .79 r
.69138 .16187 m
.69138 .3047 L
.69245 .3047 L
.69245 .16187 L
s
.678 .847 .902 r
.69245 .16187 m
.69245 .30531 L
.69411 .30531 L
.69411 .16187 L
F
.2 .63 .79 r
.69245 .16187 m
.69245 .30531 L
.69411 .30531 L
.69411 .16187 L
s
.678 .847 .902 r
.69411 .16187 m
.69411 .3069 L
.69545 .3069 L
.69545 .16187 L
F
.2 .63 .79 r
.69411 .16187 m
.69411 .3069 L
.69545 .3069 L
.69545 .16187 L
s
.678 .847 .902 r
.69545 .16187 m
.69545 .30772 L
.69628 .30772 L
.69628 .16187 L
F
.2 .63 .79 r
.69545 .16187 m
.69545 .30772 L
.69628 .30772 L
.69628 .16187 L
s
.678 .847 .902 r
.69628 .16187 m
.69628 .30876 L
.69764 .30876 L
.69764 .16187 L
F
.2 .63 .79 r
.69628 .16187 m
.69628 .30876 L
.69764 .30876 L
.69764 .16187 L
s
.678 .847 .902 r
.69764 .16187 m
.69764 .30998 L
.69906 .30998 L
.69906 .16187 L
F
.2 .63 .79 r
.69764 .16187 m
.69764 .30998 L
.69906 .30998 L
.69906 .16187 L
s
.678 .847 .902 r
.69906 .16187 m
.69906 .31089 L
.70042 .31089 L
.70042 .16187 L
F
.2 .63 .79 r
.69906 .16187 m
.69906 .31089 L
.70042 .31089 L
.70042 .16187 L
s
.678 .847 .902 r
.70042 .16187 m
.70042 .31209 L
.70153 .31209 L
.70153 .16187 L
F
.2 .63 .79 r
.70042 .16187 m
.70042 .31209 L
.70153 .31209 L
.70153 .16187 L
s
.678 .847 .902 r
.70153 .16187 m
.70153 .31414 L
.70314 .31414 L
.70314 .16187 L
F
.2 .63 .79 r
.70153 .16187 m
.70153 .31414 L
.70314 .31414 L
.70314 .16187 L
s
.678 .847 .902 r
.70314 .16187 m
.70314 .31541 L
.70453 .31541 L
.70453 .16187 L
F
.2 .63 .79 r
.70314 .16187 m
.70314 .31541 L
.70453 .31541 L
.70453 .16187 L
s
.678 .847 .902 r
.70453 .16187 m
.70453 .3161 L
.70576 .3161 L
.70576 .16187 L
F
.2 .63 .79 r
.70453 .16187 m
.70453 .3161 L
.70576 .3161 L
.70576 .16187 L
s
.678 .847 .902 r
.70576 .16187 m
.70576 .31693 L
.70731 .31693 L
.70731 .16187 L
F
.2 .63 .79 r
.70576 .16187 m
.70576 .31693 L
.70731 .31693 L
.70731 .16187 L
s
.678 .847 .902 r
.70731 .16187 m
.70731 .31821 L
.70788 .31821 L
.70788 .16187 L
F
.2 .63 .79 r
.70731 .16187 m
.70731 .31821 L
.70788 .31821 L
.70788 .16187 L
s
.678 .847 .902 r
.70788 .16187 m
.70788 .31885 L
.70895 .31885 L
.70895 .16187 L
F
.2 .63 .79 r
.70788 .16187 m
.70788 .31885 L
.70895 .31885 L
.70895 .16187 L
s
.678 .847 .902 r
.70895 .16187 m
.70895 .31958 L
.71019 .31958 L
.71019 .16187 L
F
.2 .63 .79 r
.70895 .16187 m
.70895 .31958 L
.71019 .31958 L
.71019 .16187 L
s
.678 .847 .902 r
.71019 .16187 m
.71019 .32067 L
.7108 .32067 L
.7108 .16187 L
F
.2 .63 .79 r
.71019 .16187 m
.71019 .32067 L
.7108 .32067 L
.7108 .16187 L
s
.678 .847 .902 r
.7108 .16187 m
.7108 .32113 L
.71214 .32113 L
.71214 .16187 L
F
.2 .63 .79 r
.7108 .16187 m
.7108 .32113 L
.71214 .32113 L
.71214 .16187 L
s
.678 .847 .902 r
.71214 .16187 m
.71214 .32233 L
.71322 .32233 L
.71322 .16187 L
F
.2 .63 .79 r
.71214 .16187 m
.71214 .32233 L
.71322 .32233 L
.71322 .16187 L
s
.678 .847 .902 r
.71322 .16187 m
.71322 .32378 L
.71425 .32378 L
.71425 .16187 L
F
.2 .63 .79 r
.71322 .16187 m
.71322 .32378 L
.71425 .32378 L
.71425 .16187 L
s
.678 .847 .902 r
.71425 .16187 m
.71425 .32459 L
.71514 .32459 L
.71514 .16187 L
F
.2 .63 .79 r
.71425 .16187 m
.71425 .32459 L
.71514 .32459 L
.71514 .16187 L
s
.678 .847 .902 r
.71514 .16187 m
.71514 .3257 L
.7168 .3257 L
.7168 .16187 L
F
.2 .63 .79 r
.71514 .16187 m
.71514 .3257 L
.7168 .3257 L
.7168 .16187 L
s
.678 .847 .902 r
.7168 .16187 m
.7168 .32662 L
.71732 .32662 L
.71732 .16187 L
F
.2 .63 .79 r
.7168 .16187 m
.7168 .32662 L
.71732 .32662 L
.71732 .16187 L
s
.678 .847 .902 r
.71732 .16187 m
.71732 .32699 L
.71794 .32699 L
.71794 .16187 L
F
.2 .63 .79 r
.71732 .16187 m
.71732 .32699 L
.71794 .32699 L
.71794 .16187 L
s
.678 .847 .902 r
.71794 .16187 m
.71794 .32861 L
.71959 .32861 L
.71959 .16187 L
F
.2 .63 .79 r
.71794 .16187 m
.71794 .32861 L
.71959 .32861 L
.71959 .16187 L
s
.678 .847 .902 r
.71959 .16187 m
.71959 .32959 L
.7207 .32959 L
.7207 .16187 L
F
.2 .63 .79 r
.71959 .16187 m
.71959 .32959 L
.7207 .32959 L
.7207 .16187 L
s
.678 .847 .902 r
.7207 .16187 m
.7207 .32999 L
.72127 .32999 L
.72127 .16187 L
F
.2 .63 .79 r
.7207 .16187 m
.7207 .32999 L
.72127 .32999 L
.72127 .16187 L
s
.678 .847 .902 r
.72127 .16187 m
.72127 .33108 L
.72226 .33108 L
.72226 .16187 L
F
.2 .63 .79 r
.72127 .16187 m
.72127 .33108 L
.72226 .33108 L
.72226 .16187 L
s
.678 .847 .902 r
.72226 .16187 m
.72226 .33183 L
.7236 .33183 L
.7236 .16187 L
F
.2 .63 .79 r
.72226 .16187 m
.72226 .33183 L
.7236 .33183 L
.7236 .16187 L
s
.678 .847 .902 r
.7236 .16187 m
.7236 .3328 L
.72505 .3328 L
.72505 .16187 L
F
.2 .63 .79 r
.7236 .16187 m
.7236 .3328 L
.72505 .3328 L
.72505 .16187 L
s
.678 .847 .902 r
.72505 .16187 m
.72505 .3344 L
.72592 .3344 L
.72592 .16187 L
F
.2 .63 .79 r
.72505 .16187 m
.72505 .3344 L
.72592 .3344 L
.72592 .16187 L
s
.678 .847 .902 r
.72592 .16187 m
.72592 .33527 L
.72726 .33527 L
.72726 .16187 L
F
.2 .63 .79 r
.72592 .16187 m
.72592 .33527 L
.72726 .33527 L
.72726 .16187 L
s
.678 .847 .902 r
.72726 .16187 m
.72726 .33594 L
.728 .33594 L
.728 .16187 L
F
.2 .63 .79 r
.72726 .16187 m
.72726 .33594 L
.728 .33594 L
.728 .16187 L
s
.678 .847 .902 r
.728 .16187 m
.728 .33688 L
.72955 .33688 L
.72955 .16187 L
F
.2 .63 .79 r
.728 .16187 m
.728 .33688 L
.72955 .33688 L
.72955 .16187 L
s
.678 .847 .902 r
.72955 .16187 m
.72955 .33874 L
.73075 .33874 L
.73075 .16187 L
F
.2 .63 .79 r
.72955 .16187 m
.72955 .33874 L
.73075 .33874 L
.73075 .16187 L
s
.678 .847 .902 r
.73075 .16187 m
.73075 .33954 L
.73137 .33954 L
.73137 .16187 L
F
.2 .63 .79 r
.73075 .16187 m
.73075 .33954 L
.73137 .33954 L
.73137 .16187 L
s
.678 .847 .902 r
.73137 .16187 m
.73137 .34029 L
.73227 .34029 L
.73227 .16187 L
F
.2 .63 .79 r
.73137 .16187 m
.73137 .34029 L
.73227 .34029 L
.73227 .16187 L
s
.678 .847 .902 r
.73227 .16187 m
.73227 .34126 L
.73377 .34126 L
.73377 .16187 L
F
.2 .63 .79 r
.73227 .16187 m
.73227 .34126 L
.73377 .34126 L
.73377 .16187 L
s
.678 .847 .902 r
.73377 .16187 m
.73377 .34195 L
.73441 .34195 L
.73441 .16187 L
F
.2 .63 .79 r
.73377 .16187 m
.73377 .34195 L
.73441 .34195 L
.73441 .16187 L
s
.678 .847 .902 r
.73441 .16187 m
.73441 .34308 L
.7355 .34308 L
.7355 .16187 L
F
.2 .63 .79 r
.73441 .16187 m
.73441 .34308 L
.7355 .34308 L
.7355 .16187 L
s
.678 .847 .902 r
.7355 .16187 m
.7355 .34371 L
.7363 .34371 L
.7363 .16187 L
F
.2 .63 .79 r
.7355 .16187 m
.7355 .34371 L
.7363 .34371 L
.7363 .16187 L
s
.678 .847 .902 r
.7363 .16187 m
.7363 .34444 L
.73698 .34444 L
.73698 .16187 L
F
.2 .63 .79 r
.7363 .16187 m
.7363 .34444 L
.73698 .34444 L
.73698 .16187 L
s
.678 .847 .902 r
.73698 .16187 m
.73698 .34488 L
.73825 .34488 L
.73825 .16187 L
F
.2 .63 .79 r
.73698 .16187 m
.73698 .34488 L
.73825 .34488 L
.73825 .16187 L
s
.678 .847 .902 r
.73825 .16187 m
.73825 .34648 L
.73882 .34648 L
.73882 .16187 L
F
.2 .63 .79 r
.73825 .16187 m
.73825 .34648 L
.73882 .34648 L
.73882 .16187 L
s
.678 .847 .902 r
.73882 .16187 m
.73882 .34762 L
.74045 .34762 L
.74045 .16187 L
F
.2 .63 .79 r
.73882 .16187 m
.73882 .34762 L
.74045 .34762 L
.74045 .16187 L
s
.678 .847 .902 r
.74045 .16187 m
.74045 .34861 L
.74117 .34861 L
.74117 .16187 L
F
.2 .63 .79 r
.74045 .16187 m
.74045 .34861 L
.74117 .34861 L
.74117 .16187 L
s
.678 .847 .902 r
.74117 .16187 m
.74117 .34929 L
.74244 .34929 L
.74244 .16187 L
F
.2 .63 .79 r
.74117 .16187 m
.74117 .34929 L
.74244 .34929 L
.74244 .16187 L
s
.678 .847 .902 r
.74244 .16187 m
.74244 .35092 L
.7441 .35092 L
.7441 .16187 L
F
.2 .63 .79 r
.74244 .16187 m
.74244 .35092 L
.7441 .35092 L
.7441 .16187 L
s
.678 .847 .902 r
.7441 .16187 m
.7441 .35287 L
.74579 .35287 L
.74579 .16187 L
F
.2 .63 .79 r
.7441 .16187 m
.7441 .35287 L
.74579 .35287 L
.74579 .16187 L
s
.678 .847 .902 r
.74579 .16187 m
.74579 .35323 L
.74712 .35323 L
.74712 .16187 L
F
.2 .63 .79 r
.74579 .16187 m
.74579 .35323 L
.74712 .35323 L
.74712 .16187 L
s
.678 .847 .902 r
.74712 .16187 m
.74712 .35456 L
.74833 .35456 L
.74833 .16187 L
F
.2 .63 .79 r
.74712 .16187 m
.74712 .35456 L
.74833 .35456 L
.74833 .16187 L
s
.678 .847 .902 r
.74833 .16187 m
.74833 .35639 L
.74951 .35639 L
.74951 .16187 L
F
.2 .63 .79 r
.74833 .16187 m
.74833 .35639 L
.74951 .35639 L
.74951 .16187 L
s
.678 .847 .902 r
.74951 .16187 m
.74951 .35687 L
.75038 .35687 L
.75038 .16187 L
F
.2 .63 .79 r
.74951 .16187 m
.74951 .35687 L
.75038 .35687 L
.75038 .16187 L
s
.678 .847 .902 r
.75038 .16187 m
.75038 .35876 L
.75197 .35876 L
.75197 .16187 L
F
.2 .63 .79 r
.75038 .16187 m
.75038 .35876 L
.75197 .35876 L
.75197 .16187 L
s
.678 .847 .902 r
.75197 .16187 m
.75197 .35924 L
.75282 .35924 L
.75282 .16187 L
F
.2 .63 .79 r
.75197 .16187 m
.75197 .35924 L
.75282 .35924 L
.75282 .16187 L
s
.678 .847 .902 r
.75282 .16187 m
.75282 .36017 L
.75438 .36017 L
.75438 .16187 L
F
.2 .63 .79 r
.75282 .16187 m
.75282 .36017 L
.75438 .36017 L
.75438 .16187 L
s
.678 .847 .902 r
.75438 .16187 m
.75438 .36127 L
.75502 .36127 L
.75502 .16187 L
F
.2 .63 .79 r
.75438 .16187 m
.75438 .36127 L
.75502 .36127 L
.75502 .16187 L
s
.678 .847 .902 r
.75502 .16187 m
.75502 .36206 L
.75557 .36206 L
.75557 .16187 L
F
.2 .63 .79 r
.75502 .16187 m
.75502 .36206 L
.75557 .36206 L
.75557 .16187 L
s
.678 .847 .902 r
.75557 .16187 m
.75557 .36327 L
.75694 .36327 L
.75694 .16187 L
F
.2 .63 .79 r
.75557 .16187 m
.75557 .36327 L
.75694 .36327 L
.75694 .16187 L
s
.678 .847 .902 r
.75694 .16187 m
.75694 .36417 L
.75839 .36417 L
.75839 .16187 L
F
.2 .63 .79 r
.75694 .16187 m
.75694 .36417 L
.75839 .36417 L
.75839 .16187 L
s
.678 .847 .902 r
.75839 .16187 m
.75839 .36556 L
.75984 .36556 L
.75984 .16187 L
F
.2 .63 .79 r
.75839 .16187 m
.75839 .36556 L
.75984 .36556 L
.75984 .16187 L
s
.678 .847 .902 r
.75984 .16187 m
.75984 .36635 L
.7606 .36635 L
.7606 .16187 L
F
.2 .63 .79 r
.75984 .16187 m
.75984 .36635 L
.7606 .36635 L
.7606 .16187 L
s
.678 .847 .902 r
.7606 .16187 m
.7606 .36767 L
.76184 .36767 L
.76184 .16187 L
F
.2 .63 .79 r
.7606 .16187 m
.7606 .36767 L
.76184 .36767 L
.76184 .16187 L
s
.678 .847 .902 r
.76184 .16187 m
.76184 .36886 L
.76271 .36886 L
.76271 .16187 L
F
.2 .63 .79 r
.76184 .16187 m
.76184 .36886 L
.76271 .36886 L
.76271 .16187 L
s
.678 .847 .902 r
.76271 .16187 m
.76271 .3691 L
.76388 .3691 L
.76388 .16187 L
F
.2 .63 .79 r
.76271 .16187 m
.76271 .3691 L
.76388 .3691 L
.76388 .16187 L
s
.678 .847 .902 r
.76388 .16187 m
.76388 .3705 L
.76448 .3705 L
.76448 .16187 L
F
.2 .63 .79 r
.76388 .16187 m
.76388 .3705 L
.76448 .3705 L
.76448 .16187 L
s
.678 .847 .902 r
.76448 .16187 m
.76448 .37149 L
.76616 .37149 L
.76616 .16187 L
F
.2 .63 .79 r
.76448 .16187 m
.76448 .37149 L
.76616 .37149 L
.76616 .16187 L
s
.678 .847 .902 r
.76616 .16187 m
.76616 .37296 L
.76696 .37296 L
.76696 .16187 L
F
.2 .63 .79 r
.76616 .16187 m
.76616 .37296 L
.76696 .37296 L
.76696 .16187 L
s
.678 .847 .902 r
.76696 .16187 m
.76696 .3735 L
.76823 .3735 L
.76823 .16187 L
F
.2 .63 .79 r
.76696 .16187 m
.76696 .3735 L
.76823 .3735 L
.76823 .16187 L
s
.678 .847 .902 r
.76823 .16187 m
.76823 .37541 L
.76981 .37541 L
.76981 .16187 L
F
.2 .63 .79 r
.76823 .16187 m
.76823 .37541 L
.76981 .37541 L
.76981 .16187 L
s
.678 .847 .902 r
.76981 .16187 m
.76981 .37671 L
.77074 .37671 L
.77074 .16187 L
F
.2 .63 .79 r
.76981 .16187 m
.76981 .37671 L
.77074 .37671 L
.77074 .16187 L
s
.678 .847 .902 r
.77074 .16187 m
.77074 .37685 L
.77159 .37685 L
.77159 .16187 L
F
.2 .63 .79 r
.77074 .16187 m
.77074 .37685 L
.77159 .37685 L
.77159 .16187 L
s
.678 .847 .902 r
.77159 .16187 m
.77159 .37807 L
.77288 .37807 L
.77288 .16187 L
F
.2 .63 .79 r
.77159 .16187 m
.77159 .37807 L
.77288 .37807 L
.77288 .16187 L
s
.678 .847 .902 r
.77288 .16187 m
.77288 .37921 L
.77364 .37921 L
.77364 .16187 L
F
.2 .63 .79 r
.77288 .16187 m
.77288 .37921 L
.77364 .37921 L
.77364 .16187 L
s
.678 .847 .902 r
.77364 .16187 m
.77364 .38049 L
.77508 .38049 L
.77508 .16187 L
F
.2 .63 .79 r
.77364 .16187 m
.77364 .38049 L
.77508 .38049 L
.77508 .16187 L
s
.678 .847 .902 r
.77508 .16187 m
.77508 .38123 L
.77645 .38123 L
.77645 .16187 L
F
.2 .63 .79 r
.77508 .16187 m
.77508 .38123 L
.77645 .38123 L
.77645 .16187 L
s
.678 .847 .902 r
.77645 .16187 m
.77645 .38315 L
.77739 .38315 L
.77739 .16187 L
F
.2 .63 .79 r
.77645 .16187 m
.77645 .38315 L
.77739 .38315 L
.77739 .16187 L
s
.678 .847 .902 r
.77739 .16187 m
.77739 .38369 L
.77827 .38369 L
.77827 .16187 L
F
.2 .63 .79 r
.77739 .16187 m
.77739 .38369 L
.77827 .38369 L
.77827 .16187 L
s
.678 .847 .902 r
.77827 .16187 m
.77827 .3842 L
.77937 .3842 L
.77937 .16187 L
F
.2 .63 .79 r
.77827 .16187 m
.77827 .3842 L
.77937 .3842 L
.77937 .16187 L
s
.678 .847 .902 r
.77937 .16187 m
.77937 .38637 L
.7809 .38637 L
.7809 .16187 L
F
.2 .63 .79 r
.77937 .16187 m
.77937 .38637 L
.7809 .38637 L
.7809 .16187 L
s
.678 .847 .902 r
.7809 .16187 m
.7809 .38714 L
.78172 .38714 L
.78172 .16187 L
F
.2 .63 .79 r
.7809 .16187 m
.7809 .38714 L
.78172 .38714 L
.78172 .16187 L
s
.678 .847 .902 r
.78172 .16187 m
.78172 .38814 L
.78255 .38814 L
.78255 .16187 L
F
.2 .63 .79 r
.78172 .16187 m
.78172 .38814 L
.78255 .38814 L
.78255 .16187 L
s
.678 .847 .902 r
.78255 .16187 m
.78255 .38869 L
.784 .38869 L
.784 .16187 L
F
.2 .63 .79 r
.78255 .16187 m
.78255 .38869 L
.784 .38869 L
.784 .16187 L
s
.678 .847 .902 r
.784 .16187 m
.784 .38991 L
.7846 .38991 L
.7846 .16187 L
F
.2 .63 .79 r
.784 .16187 m
.784 .38991 L
.7846 .38991 L
.7846 .16187 L
s
.678 .847 .902 r
.7846 .16187 m
.7846 .39041 L
.78567 .39041 L
.78567 .16187 L
F
.2 .63 .79 r
.7846 .16187 m
.7846 .39041 L
.78567 .39041 L
.78567 .16187 L
s
.678 .847 .902 r
.78567 .16187 m
.78567 .39178 L
.78626 .39178 L
.78626 .16187 L
F
.2 .63 .79 r
.78567 .16187 m
.78567 .39178 L
.78626 .39178 L
.78626 .16187 L
s
.678 .847 .902 r
.78626 .16187 m
.78626 .39246 L
.78698 .39246 L
.78698 .16187 L
F
.2 .63 .79 r
.78626 .16187 m
.78626 .39246 L
.78698 .39246 L
.78698 .16187 L
s
.678 .847 .902 r
.78698 .16187 m
.78698 .39339 L
.78842 .39339 L
.78842 .16187 L
F
.2 .63 .79 r
.78698 .16187 m
.78698 .39339 L
.78842 .39339 L
.78842 .16187 L
s
.678 .847 .902 r
.78842 .16187 m
.78842 .39412 L
.79003 .39412 L
.79003 .16187 L
F
.2 .63 .79 r
.78842 .16187 m
.78842 .39412 L
.79003 .39412 L
.79003 .16187 L
s
.678 .847 .902 r
.79003 .16187 m
.79003 .39581 L
.79174 .39581 L
.79174 .16187 L
F
.2 .63 .79 r
.79003 .16187 m
.79003 .39581 L
.79174 .39581 L
.79174 .16187 L
s
.678 .847 .902 r
.79174 .16187 m
.79174 .39757 L
.79248 .39757 L
.79248 .16187 L
F
.2 .63 .79 r
.79174 .16187 m
.79174 .39757 L
.79248 .39757 L
.79248 .16187 L
s
.678 .847 .902 r
.79248 .16187 m
.79248 .39894 L
.79364 .39894 L
.79364 .16187 L
F
.2 .63 .79 r
.79248 .16187 m
.79248 .39894 L
.79364 .39894 L
.79364 .16187 L
s
.678 .847 .902 r
.79364 .16187 m
.79364 .39989 L
.7945 .39989 L
.7945 .16187 L
F
.2 .63 .79 r
.79364 .16187 m
.79364 .39989 L
.7945 .39989 L
.7945 .16187 L
s
.678 .847 .902 r
.7945 .16187 m
.7945 .40038 L
.79514 .40038 L
.79514 .16187 L
F
.2 .63 .79 r
.7945 .16187 m
.7945 .40038 L
.79514 .40038 L
.79514 .16187 L
s
.678 .847 .902 r
.79514 .16187 m
.79514 .40122 L
.79666 .40122 L
.79666 .16187 L
F
.2 .63 .79 r
.79514 .16187 m
.79514 .40122 L
.79666 .40122 L
.79666 .16187 L
s
.678 .847 .902 r
.79666 .16187 m
.79666 .4028 L
.79748 .4028 L
.79748 .16187 L
F
.2 .63 .79 r
.79666 .16187 m
.79666 .4028 L
.79748 .4028 L
.79748 .16187 L
s
.678 .847 .902 r
.79748 .16187 m
.79748 .40354 L
.79876 .40354 L
.79876 .16187 L
F
.2 .63 .79 r
.79748 .16187 m
.79748 .40354 L
.79876 .40354 L
.79876 .16187 L
s
.678 .847 .902 r
.79876 .16187 m
.79876 .4058 L
.80036 .4058 L
.80036 .16187 L
F
.2 .63 .79 r
.79876 .16187 m
.79876 .4058 L
.80036 .4058 L
.80036 .16187 L
s
.678 .847 .902 r
.80036 .16187 m
.80036 .40642 L
.80095 .40642 L
.80095 .16187 L
F
.2 .63 .79 r
.80036 .16187 m
.80036 .40642 L
.80095 .40642 L
.80095 .16187 L
s
.678 .847 .902 r
.80095 .16187 m
.80095 .4071 L
.80211 .4071 L
.80211 .16187 L
F
.2 .63 .79 r
.80095 .16187 m
.80095 .4071 L
.80211 .4071 L
.80211 .16187 L
s
.678 .847 .902 r
.80211 .16187 m
.80211 .40816 L
.80297 .40816 L
.80297 .16187 L
F
.2 .63 .79 r
.80211 .16187 m
.80211 .40816 L
.80297 .40816 L
.80297 .16187 L
s
.678 .847 .902 r
.80297 .16187 m
.80297 .40907 L
.8042 .40907 L
.8042 .16187 L
F
.2 .63 .79 r
.80297 .16187 m
.80297 .40907 L
.8042 .40907 L
.8042 .16187 L
s
.678 .847 .902 r
.8042 .16187 m
.8042 .41057 L
.8054 .41057 L
.8054 .16187 L
F
.2 .63 .79 r
.8042 .16187 m
.8042 .41057 L
.8054 .41057 L
.8054 .16187 L
s
.678 .847 .902 r
.8054 .16187 m
.8054 .41195 L
.80674 .41195 L
.80674 .16187 L
F
.2 .63 .79 r
.8054 .16187 m
.8054 .41195 L
.80674 .41195 L
.80674 .16187 L
s
.678 .847 .902 r
.80674 .16187 m
.80674 .41297 L
.8073 .41297 L
.8073 .16187 L
F
.2 .63 .79 r
.80674 .16187 m
.80674 .41297 L
.8073 .41297 L
.8073 .16187 L
s
.678 .847 .902 r
.8073 .16187 m
.8073 .41354 L
.80821 .41354 L
.80821 .16187 L
F
.2 .63 .79 r
.8073 .16187 m
.8073 .41354 L
.80821 .41354 L
.80821 .16187 L
s
.678 .847 .902 r
.80821 .16187 m
.80821 .41438 L
.80967 .41438 L
.80967 .16187 L
F
.2 .63 .79 r
.80821 .16187 m
.80821 .41438 L
.80967 .41438 L
.80967 .16187 L
s
.678 .847 .902 r
.80967 .16187 m
.80967 .41585 L
.81093 .41585 L
.81093 .16187 L
F
.2 .63 .79 r
.80967 .16187 m
.80967 .41585 L
.81093 .41585 L
.81093 .16187 L
s
.678 .847 .902 r
.81093 .16187 m
.81093 .41768 L
.81212 .41768 L
.81212 .16187 L
F
.2 .63 .79 r
.81093 .16187 m
.81093 .41768 L
.81212 .41768 L
.81212 .16187 L
s
.678 .847 .902 r
.81212 .16187 m
.81212 .4187 L
.81296 .4187 L
.81296 .16187 L
F
.2 .63 .79 r
.81212 .16187 m
.81212 .4187 L
.81296 .4187 L
.81296 .16187 L
s
.678 .847 .902 r
.81296 .16187 m
.81296 .41956 L
.81422 .41956 L
.81422 .16187 L
F
.2 .63 .79 r
.81296 .16187 m
.81296 .41956 L
.81422 .41956 L
.81422 .16187 L
s
.678 .847 .902 r
.81422 .16187 m
.81422 .42136 L
.81574 .42136 L
.81574 .16187 L
F
.2 .63 .79 r
.81422 .16187 m
.81422 .42136 L
.81574 .42136 L
.81574 .16187 L
s
.678 .847 .902 r
.81574 .16187 m
.81574 .42268 L
.81704 .42268 L
.81704 .16187 L
F
.2 .63 .79 r
.81574 .16187 m
.81574 .42268 L
.81704 .42268 L
.81704 .16187 L
s
.678 .847 .902 r
.81704 .16187 m
.81704 .4237 L
.81788 .4237 L
.81788 .16187 L
F
.2 .63 .79 r
.81704 .16187 m
.81704 .4237 L
.81788 .4237 L
.81788 .16187 L
s
.678 .847 .902 r
.81788 .16187 m
.81788 .42425 L
.81891 .42425 L
.81891 .16187 L
F
.2 .63 .79 r
.81788 .16187 m
.81788 .42425 L
.81891 .42425 L
.81891 .16187 L
s
.678 .847 .902 r
.81891 .16187 m
.81891 .42505 L
.81979 .42505 L
.81979 .16187 L
F
.2 .63 .79 r
.81891 .16187 m
.81891 .42505 L
.81979 .42505 L
.81979 .16187 L
s
.678 .847 .902 r
.81979 .16187 m
.81979 .42592 L
.82074 .42592 L
.82074 .16187 L
F
.2 .63 .79 r
.81979 .16187 m
.81979 .42592 L
.82074 .42592 L
.82074 .16187 L
s
.678 .847 .902 r
.82074 .16187 m
.82074 .42716 L
.82146 .42716 L
.82146 .16187 L
F
.2 .63 .79 r
.82074 .16187 m
.82074 .42716 L
.82146 .42716 L
.82146 .16187 L
s
.678 .847 .902 r
.82146 .16187 m
.82146 .42766 L
.82268 .42766 L
.82268 .16187 L
F
.2 .63 .79 r
.82146 .16187 m
.82146 .42766 L
.82268 .42766 L
.82268 .16187 L
s
.678 .847 .902 r
.82268 .16187 m
.82268 .42916 L
.82325 .42916 L
.82325 .16187 L
F
.2 .63 .79 r
.82268 .16187 m
.82268 .42916 L
.82325 .42916 L
.82325 .16187 L
s
.678 .847 .902 r
.82325 .16187 m
.82325 .43051 L
.82463 .43051 L
.82463 .16187 L
F
.2 .63 .79 r
.82325 .16187 m
.82325 .43051 L
.82463 .43051 L
.82463 .16187 L
s
.678 .847 .902 r
.82463 .16187 m
.82463 .43137 L
.82546 .43137 L
.82546 .16187 L
F
.2 .63 .79 r
.82463 .16187 m
.82463 .43137 L
.82546 .43137 L
.82546 .16187 L
s
.678 .847 .902 r
.82546 .16187 m
.82546 .43225 L
.8266 .43225 L
.8266 .16187 L
F
.2 .63 .79 r
.82546 .16187 m
.82546 .43225 L
.8266 .43225 L
.8266 .16187 L
s
.678 .847 .902 r
.8266 .16187 m
.8266 .43308 L
.82773 .43308 L
.82773 .16187 L
F
.2 .63 .79 r
.8266 .16187 m
.8266 .43308 L
.82773 .43308 L
.82773 .16187 L
s
.678 .847 .902 r
.82773 .16187 m
.82773 .43448 L
.82876 .43448 L
.82876 .16187 L
F
.2 .63 .79 r
.82773 .16187 m
.82773 .43448 L
.82876 .43448 L
.82876 .16187 L
s
.678 .847 .902 r
.82876 .16187 m
.82876 .43553 L
.83008 .43553 L
.83008 .16187 L
F
.2 .63 .79 r
.82876 .16187 m
.82876 .43553 L
.83008 .43553 L
.83008 .16187 L
s
.678 .847 .902 r
.83008 .16187 m
.83008 .43811 L
.83172 .43811 L
.83172 .16187 L
F
.2 .63 .79 r
.83008 .16187 m
.83008 .43811 L
.83172 .43811 L
.83172 .16187 L
s
.678 .847 .902 r
.83172 .16187 m
.83172 .43912 L
.83323 .43912 L
.83323 .16187 L
F
.2 .63 .79 r
.83172 .16187 m
.83172 .43912 L
.83323 .43912 L
.83323 .16187 L
s
.678 .847 .902 r
.83323 .16187 m
.83323 .4404 L
.83422 .4404 L
.83422 .16187 L
F
.2 .63 .79 r
.83323 .16187 m
.83323 .4404 L
.83422 .4404 L
.83422 .16187 L
s
.678 .847 .902 r
.83422 .16187 m
.83422 .44161 L
.83513 .44161 L
.83513 .16187 L
F
.2 .63 .79 r
.83422 .16187 m
.83422 .44161 L
.83513 .44161 L
.83513 .16187 L
s
.678 .847 .902 r
.83513 .16187 m
.83513 .44234 L
.83583 .44234 L
.83583 .16187 L
F
.2 .63 .79 r
.83513 .16187 m
.83513 .44234 L
.83583 .44234 L
.83583 .16187 L
s
.678 .847 .902 r
.83583 .16187 m
.83583 .4428 L
.83659 .4428 L
.83659 .16187 L
F
.2 .63 .79 r
.83583 .16187 m
.83583 .4428 L
.83659 .4428 L
.83659 .16187 L
s
.678 .847 .902 r
.83659 .16187 m
.83659 .44462 L
.8381 .44462 L
.8381 .16187 L
F
.2 .63 .79 r
.83659 .16187 m
.83659 .44462 L
.8381 .44462 L
.8381 .16187 L
s
.678 .847 .902 r
.8381 .16187 m
.8381 .44557 L
.83869 .44557 L
.83869 .16187 L
F
.2 .63 .79 r
.8381 .16187 m
.8381 .44557 L
.83869 .44557 L
.83869 .16187 L
s
.678 .847 .902 r
.83869 .16187 m
.83869 .44573 L
.83984 .44573 L
.83984 .16187 L
F
.2 .63 .79 r
.83869 .16187 m
.83869 .44573 L
.83984 .44573 L
.83984 .16187 L
s
.678 .847 .902 r
.83984 .16187 m
.83984 .4473 L
.84079 .4473 L
.84079 .16187 L
F
.2 .63 .79 r
.83984 .16187 m
.83984 .4473 L
.84079 .4473 L
.84079 .16187 L
s
.678 .847 .902 r
.84079 .16187 m
.84079 .44787 L
.84152 .44787 L
.84152 .16187 L
F
.2 .63 .79 r
.84079 .16187 m
.84079 .44787 L
.84152 .44787 L
.84152 .16187 L
s
.678 .847 .902 r
.84152 .16187 m
.84152 .44885 L
.84297 .44885 L
.84297 .16187 L
F
.2 .63 .79 r
.84152 .16187 m
.84152 .44885 L
.84297 .44885 L
.84297 .16187 L
s
.678 .847 .902 r
.84297 .16187 m
.84297 .45068 L
.84361 .45068 L
.84361 .16187 L
F
.2 .63 .79 r
.84297 .16187 m
.84297 .45068 L
.84361 .45068 L
.84361 .16187 L
s
.678 .847 .902 r
.84361 .16187 m
.84361 .45107 L
.8442 .45107 L
.8442 .16187 L
F
.2 .63 .79 r
.84361 .16187 m
.84361 .45107 L
.8442 .45107 L
.8442 .16187 L
s
.678 .847 .902 r
.8442 .16187 m
.8442 .45301 L
.84569 .45301 L
.84569 .16187 L
F
.2 .63 .79 r
.8442 .16187 m
.8442 .45301 L
.84569 .45301 L
.84569 .16187 L
s
.678 .847 .902 r
.84569 .16187 m
.84569 .45403 L
.84693 .45403 L
.84693 .16187 L
F
.2 .63 .79 r
.84569 .16187 m
.84569 .45403 L
.84693 .45403 L
.84693 .16187 L
s
.678 .847 .902 r
.84693 .16187 m
.84693 .45524 L
.84806 .45524 L
.84806 .16187 L
F
.2 .63 .79 r
.84693 .16187 m
.84693 .45524 L
.84806 .45524 L
.84806 .16187 L
s
.678 .847 .902 r
.84806 .16187 m
.84806 .45608 L
.84859 .45608 L
.84859 .16187 L
F
.2 .63 .79 r
.84806 .16187 m
.84806 .45608 L
.84859 .45608 L
.84859 .16187 L
s
.678 .847 .902 r
.84859 .16187 m
.84859 .45632 L
.84922 .45632 L
.84922 .16187 L
F
.2 .63 .79 r
.84859 .16187 m
.84859 .45632 L
.84922 .45632 L
.84922 .16187 L
s
.678 .847 .902 r
.84922 .16187 m
.84922 .457 L
.85014 .457 L
.85014 .16187 L
F
.2 .63 .79 r
.84922 .16187 m
.84922 .457 L
.85014 .457 L
.85014 .16187 L
s
.678 .847 .902 r
.85014 .16187 m
.85014 .45834 L
.85185 .45834 L
.85185 .16187 L
F
.2 .63 .79 r
.85014 .16187 m
.85014 .45834 L
.85185 .45834 L
.85185 .16187 L
s
.678 .847 .902 r
.85185 .16187 m
.85185 .46052 L
.85296 .46052 L
.85296 .16187 L
F
.2 .63 .79 r
.85185 .16187 m
.85185 .46052 L
.85296 .46052 L
.85296 .16187 L
s
.678 .847 .902 r
.85296 .16187 m
.85296 .4621 L
.85426 .4621 L
.85426 .16187 L
F
.2 .63 .79 r
.85296 .16187 m
.85296 .4621 L
.85426 .4621 L
.85426 .16187 L
s
.678 .847 .902 r
.85426 .16187 m
.85426 .46357 L
.85558 .46357 L
.85558 .16187 L
F
.2 .63 .79 r
.85426 .16187 m
.85426 .46357 L
.85558 .46357 L
.85558 .16187 L
s
.678 .847 .902 r
.85558 .16187 m
.85558 .46392 L
.85616 .46392 L
.85616 .16187 L
F
.2 .63 .79 r
.85558 .16187 m
.85558 .46392 L
.85616 .46392 L
.85616 .16187 L
s
.678 .847 .902 r
.85616 .16187 m
.85616 .46459 L
.85748 .46459 L
.85748 .16187 L
F
.2 .63 .79 r
.85616 .16187 m
.85616 .46459 L
.85748 .46459 L
.85748 .16187 L
s
.678 .847 .902 r
.85748 .16187 m
.85748 .46607 L
.8583 .46607 L
.8583 .16187 L
F
.2 .63 .79 r
.85748 .16187 m
.85748 .46607 L
.8583 .46607 L
.8583 .16187 L
s
.678 .847 .902 r
.8583 .16187 m
.8583 .46681 L
.85922 .46681 L
.85922 .16187 L
F
.2 .63 .79 r
.8583 .16187 m
.8583 .46681 L
.85922 .46681 L
.85922 .16187 L
s
.678 .847 .902 r
.85922 .16187 m
.85922 .46892 L
.86081 .46892 L
.86081 .16187 L
F
.2 .63 .79 r
.85922 .16187 m
.85922 .46892 L
.86081 .46892 L
.86081 .16187 L
s
.678 .847 .902 r
.86081 .16187 m
.86081 .47046 L
.86188 .47046 L
.86188 .16187 L
F
.2 .63 .79 r
.86081 .16187 m
.86081 .47046 L
.86188 .47046 L
.86188 .16187 L
s
.678 .847 .902 r
.86188 .16187 m
.86188 .47121 L
.86291 .47121 L
.86291 .16187 L
F
.2 .63 .79 r
.86188 .16187 m
.86188 .47121 L
.86291 .47121 L
.86291 .16187 L
s
.678 .847 .902 r
.86291 .16187 m
.86291 .47189 L
.86376 .47189 L
.86376 .16187 L
F
.2 .63 .79 r
.86291 .16187 m
.86291 .47189 L
.86376 .47189 L
.86376 .16187 L
s
.678 .847 .902 r
.86376 .16187 m
.86376 .47324 L
.86471 .47324 L
.86471 .16187 L
F
.2 .63 .79 r
.86376 .16187 m
.86376 .47324 L
.86471 .47324 L
.86471 .16187 L
s
.678 .847 .902 r
.86471 .16187 m
.86471 .47393 L
.86533 .47393 L
.86533 .16187 L
F
.2 .63 .79 r
.86471 .16187 m
.86471 .47393 L
.86533 .47393 L
.86533 .16187 L
s
.678 .847 .902 r
.86533 .16187 m
.86533 .47482 L
.86615 .47482 L
.86615 .16187 L
F
.2 .63 .79 r
.86533 .16187 m
.86533 .47482 L
.86615 .47482 L
.86615 .16187 L
s
.678 .847 .902 r
.86615 .16187 m
.86615 .47533 L
.86726 .47533 L
.86726 .16187 L
F
.2 .63 .79 r
.86615 .16187 m
.86615 .47533 L
.86726 .47533 L
.86726 .16187 L
s
.678 .847 .902 r
.86726 .16187 m
.86726 .4772 L
.86809 .4772 L
.86809 .16187 L
F
.2 .63 .79 r
.86726 .16187 m
.86726 .4772 L
.86809 .4772 L
.86809 .16187 L
s
.678 .847 .902 r
.86809 .16187 m
.86809 .47737 L
.86864 .47737 L
.86864 .16187 L
F
.2 .63 .79 r
.86809 .16187 m
.86809 .47737 L
.86864 .47737 L
.86864 .16187 L
s
.678 .847 .902 r
.86864 .16187 m
.86864 .47862 L
.86968 .47862 L
.86968 .16187 L
F
.2 .63 .79 r
.86864 .16187 m
.86864 .47862 L
.86968 .47862 L
.86968 .16187 L
s
.678 .847 .902 r
.86968 .16187 m
.86968 .47974 L
.87126 .47974 L
.87126 .16187 L
F
.2 .63 .79 r
.86968 .16187 m
.86968 .47974 L
.87126 .47974 L
.87126 .16187 L
s
.678 .847 .902 r
.87126 .16187 m
.87126 .48108 L
.87266 .48108 L
.87266 .16187 L
F
.2 .63 .79 r
.87126 .16187 m
.87126 .48108 L
.87266 .48108 L
.87266 .16187 L
s
.678 .847 .902 r
.87266 .16187 m
.87266 .48249 L
.8732 .48249 L
.8732 .16187 L
F
.2 .63 .79 r
.87266 .16187 m
.87266 .48249 L
.8732 .48249 L
.8732 .16187 L
s
.678 .847 .902 r
.8732 .16187 m
.8732 .48332 L
.87413 .48332 L
.87413 .16187 L
F
.2 .63 .79 r
.8732 .16187 m
.8732 .48332 L
.87413 .48332 L
.87413 .16187 L
s
.678 .847 .902 r
.87413 .16187 m
.87413 .48424 L
.87529 .48424 L
.87529 .16187 L
F
.2 .63 .79 r
.87413 .16187 m
.87413 .48424 L
.87529 .48424 L
.87529 .16187 L
s
.678 .847 .902 r
.87529 .16187 m
.87529 .48666 L
.8767 .48666 L
.8767 .16187 L
F
.2 .63 .79 r
.87529 .16187 m
.87529 .48666 L
.8767 .48666 L
.8767 .16187 L
s
.678 .847 .902 r
.8767 .16187 m
.8767 .48751 L
.87784 .48751 L
.87784 .16187 L
F
.2 .63 .79 r
.8767 .16187 m
.8767 .48751 L
.87784 .48751 L
.87784 .16187 L
s
.678 .847 .902 r
.87784 .16187 m
.87784 .4888 L
.87918 .4888 L
.87918 .16187 L
F
.2 .63 .79 r
.87784 .16187 m
.87784 .4888 L
.87918 .4888 L
.87918 .16187 L
s
.678 .847 .902 r
.87918 .16187 m
.87918 .49007 L
.88073 .49007 L
.88073 .16187 L
F
.2 .63 .79 r
.87918 .16187 m
.87918 .49007 L
.88073 .49007 L
.88073 .16187 L
s
.678 .847 .902 r
.88073 .16187 m
.88073 .49205 L
.88209 .49205 L
.88209 .16187 L
F
.2 .63 .79 r
.88073 .16187 m
.88073 .49205 L
.88209 .49205 L
.88209 .16187 L
s
.678 .847 .902 r
.88209 .16187 m
.88209 .4934 L
.88361 .4934 L
.88361 .16187 L
F
.2 .63 .79 r
.88209 .16187 m
.88209 .4934 L
.88361 .4934 L
.88361 .16187 L
s
.678 .847 .902 r
.88361 .16187 m
.88361 .4946 L
.88464 .4946 L
.88464 .16187 L
F
.2 .63 .79 r
.88361 .16187 m
.88361 .4946 L
.88464 .4946 L
.88464 .16187 L
s
.678 .847 .902 r
.88464 .16187 m
.88464 .49577 L
.88579 .49577 L
.88579 .16187 L
F
.2 .63 .79 r
.88464 .16187 m
.88464 .49577 L
.88579 .49577 L
.88579 .16187 L
s
.678 .847 .902 r
.88579 .16187 m
.88579 .49818 L
.88726 .49818 L
.88726 .16187 L
F
.2 .63 .79 r
.88579 .16187 m
.88579 .49818 L
.88726 .49818 L
.88726 .16187 L
s
.678 .847 .902 r
.88726 .16187 m
.88726 .49899 L
.88824 .49899 L
.88824 .16187 L
F
.2 .63 .79 r
.88726 .16187 m
.88726 .49899 L
.88824 .49899 L
.88824 .16187 L
s
.678 .847 .902 r
.88824 .16187 m
.88824 .49991 L
.88875 .49991 L
.88875 .16187 L
F
.2 .63 .79 r
.88824 .16187 m
.88824 .49991 L
.88875 .49991 L
.88875 .16187 L
s
.678 .847 .902 r
.88875 .16187 m
.88875 .50097 L
.88956 .50097 L
.88956 .16187 L
F
.2 .63 .79 r
.88875 .16187 m
.88875 .50097 L
.88956 .50097 L
.88956 .16187 L
s
.678 .847 .902 r
.88956 .16187 m
.88956 .50125 L
.8906 .50125 L
.8906 .16187 L
F
.2 .63 .79 r
.88956 .16187 m
.88956 .50125 L
.8906 .50125 L
.8906 .16187 L
s
.678 .847 .902 r
.8906 .16187 m
.8906 .50316 L
.89146 .50316 L
.89146 .16187 L
F
.2 .63 .79 r
.8906 .16187 m
.8906 .50316 L
.89146 .50316 L
.89146 .16187 L
s
.678 .847 .902 r
.89146 .16187 m
.89146 .50465 L
.89287 .50465 L
.89287 .16187 L
F
.2 .63 .79 r
.89146 .16187 m
.89146 .50465 L
.89287 .50465 L
.89287 .16187 L
s
.678 .847 .902 r
.89287 .16187 m
.89287 .50596 L
.89428 .50596 L
.89428 .16187 L
F
.2 .63 .79 r
.89287 .16187 m
.89287 .50596 L
.89428 .50596 L
.89428 .16187 L
s
.678 .847 .902 r
.89428 .16187 m
.89428 .50659 L
.89501 .50659 L
.89501 .16187 L
F
.2 .63 .79 r
.89428 .16187 m
.89428 .50659 L
.89501 .50659 L
.89501 .16187 L
s
.678 .847 .902 r
.89501 .16187 m
.89501 .50795 L
.89583 .50795 L
.89583 .16187 L
F
.2 .63 .79 r
.89501 .16187 m
.89501 .50795 L
.89583 .50795 L
.89583 .16187 L
s
.678 .847 .902 r
.89583 .16187 m
.89583 .50842 L
.89671 .50842 L
.89671 .16187 L
F
.2 .63 .79 r
.89583 .16187 m
.89583 .50842 L
.89671 .50842 L
.89671 .16187 L
s
.678 .847 .902 r
.89671 .16187 m
.89671 .5097 L
.89826 .5097 L
.89826 .16187 L
F
.2 .63 .79 r
.89671 .16187 m
.89671 .5097 L
.89826 .5097 L
.89826 .16187 L
s
.678 .847 .902 r
.89826 .16187 m
.89826 .51209 L
.89929 .51209 L
.89929 .16187 L
F
.2 .63 .79 r
.89826 .16187 m
.89826 .51209 L
.89929 .51209 L
.89929 .16187 L
s
.678 .847 .902 r
.89929 .16187 m
.89929 .51251 L
.90009 .51251 L
.90009 .16187 L
F
.2 .63 .79 r
.89929 .16187 m
.89929 .51251 L
.90009 .51251 L
.90009 .16187 L
s
.678 .847 .902 r
.90009 .16187 m
.90009 .51457 L
.90175 .51457 L
.90175 .16187 L
F
.2 .63 .79 r
.90009 .16187 m
.90009 .51457 L
.90175 .51457 L
.90175 .16187 L
s
.678 .847 .902 r
.90175 .16187 m
.90175 .51496 L
.90265 .51496 L
.90265 .16187 L
F
.2 .63 .79 r
.90175 .16187 m
.90175 .51496 L
.90265 .51496 L
.90265 .16187 L
s
.678 .847 .902 r
.90265 .16187 m
.90265 .51602 L
.90399 .51602 L
.90399 .16187 L
F
.2 .63 .79 r
.90265 .16187 m
.90265 .51602 L
.90399 .51602 L
.90399 .16187 L
s
.678 .847 .902 r
.90399 .16187 m
.90399 .5188 L
.90536 .5188 L
.90536 .16187 L
F
.2 .63 .79 r
.90399 .16187 m
.90399 .5188 L
.90536 .5188 L
.90536 .16187 L
s
.678 .847 .902 r
.90536 .16187 m
.90536 .51931 L
.9062 .51931 L
.9062 .16187 L
F
.2 .63 .79 r
.90536 .16187 m
.90536 .51931 L
.9062 .51931 L
.9062 .16187 L
s
.678 .847 .902 r
.9062 .16187 m
.9062 .52086 L
.90725 .52086 L
.90725 .16187 L
F
.2 .63 .79 r
.9062 .16187 m
.9062 .52086 L
.90725 .52086 L
.90725 .16187 L
s
.678 .847 .902 r
.90725 .16187 m
.90725 .5222 L
.90895 .5222 L
.90895 .16187 L
F
.2 .63 .79 r
.90725 .16187 m
.90725 .5222 L
.90895 .5222 L
.90895 .16187 L
s
.678 .847 .902 r
.90895 .16187 m
.90895 .52398 L
.91051 .52398 L
.91051 .16187 L
F
.2 .63 .79 r
.90895 .16187 m
.90895 .52398 L
.91051 .52398 L
.91051 .16187 L
s
.678 .847 .902 r
.91051 .16187 m
.91051 .52522 L
.91203 .52522 L
.91203 .16187 L
F
.2 .63 .79 r
.91051 .16187 m
.91051 .52522 L
.91203 .52522 L
.91203 .16187 L
s
.678 .847 .902 r
.91203 .16187 m
.91203 .52779 L
.91364 .52779 L
.91364 .16187 L
F
.2 .63 .79 r
.91203 .16187 m
.91203 .52779 L
.91364 .52779 L
.91364 .16187 L
s
.678 .847 .902 r
.91364 .16187 m
.91364 .52917 L
.91438 .52917 L
.91438 .16187 L
F
.2 .63 .79 r
.91364 .16187 m
.91364 .52917 L
.91438 .52917 L
.91438 .16187 L
s
.678 .847 .902 r
.91438 .16187 m
.91438 .52946 L
.91548 .52946 L
.91548 .16187 L
F
.2 .63 .79 r
.91438 .16187 m
.91438 .52946 L
.91548 .52946 L
.91548 .16187 L
s
.678 .847 .902 r
.91548 .16187 m
.91548 .53183 L
.917 .53183 L
.917 .16187 L
F
.2 .63 .79 r
.91548 .16187 m
.91548 .53183 L
.917 .53183 L
.917 .16187 L
s
.678 .847 .902 r
.917 .16187 m
.917 .53356 L
.91832 .53356 L
.91832 .16187 L
F
.2 .63 .79 r
.917 .16187 m
.917 .53356 L
.91832 .53356 L
.91832 .16187 L
s
.678 .847 .902 r
.91832 .16187 m
.91832 .53497 L
.91973 .53497 L
.91973 .16187 L
F
.2 .63 .79 r
.91832 .16187 m
.91832 .53497 L
.91973 .53497 L
.91973 .16187 L
s
.678 .847 .902 r
.91973 .16187 m
.91973 .53572 L
.92048 .53572 L
.92048 .16187 L
F
.2 .63 .79 r
.91973 .16187 m
.91973 .53572 L
.92048 .53572 L
.92048 .16187 L
s
.678 .847 .902 r
.92048 .16187 m
.92048 .53704 L
.92111 .53704 L
.92111 .16187 L
F
.2 .63 .79 r
.92048 .16187 m
.92048 .53704 L
.92111 .53704 L
.92111 .16187 L
s
.678 .847 .902 r
.92111 .16187 m
.92111 .53727 L
.92272 .53727 L
.92272 .16187 L
F
.2 .63 .79 r
.92111 .16187 m
.92111 .53727 L
.92272 .53727 L
.92272 .16187 L
s
.678 .847 .902 r
.92272 .16187 m
.92272 .53966 L
.92392 .53966 L
.92392 .16187 L
F
.2 .63 .79 r
.92272 .16187 m
.92272 .53966 L
.92392 .53966 L
.92392 .16187 L
s
.678 .847 .902 r
.92392 .16187 m
.92392 .54122 L
.92557 .54122 L
.92557 .16187 L
F
.2 .63 .79 r
.92392 .16187 m
.92392 .54122 L
.92557 .54122 L
.92557 .16187 L
s
.678 .847 .902 r
.92557 .16187 m
.92557 .54333 L
.92702 .54333 L
.92702 .16187 L
F
.2 .63 .79 r
.92557 .16187 m
.92557 .54333 L
.92702 .54333 L
.92702 .16187 L
s
.678 .847 .902 r
.92702 .16187 m
.92702 .54461 L
.92759 .54461 L
.92759 .16187 L
F
.2 .63 .79 r
.92702 .16187 m
.92702 .54461 L
.92759 .54461 L
.92759 .16187 L
s
.678 .847 .902 r
.92759 .16187 m
.92759 .54512 L
.92827 .54512 L
.92827 .16187 L
F
.2 .63 .79 r
.92759 .16187 m
.92759 .54512 L
.92827 .54512 L
.92827 .16187 L
s
.678 .847 .902 r
.92827 .16187 m
.92827 .54709 L
.92964 .54709 L
.92964 .16187 L
F
.2 .63 .79 r
.92827 .16187 m
.92827 .54709 L
.92964 .54709 L
.92964 .16187 L
s
.678 .847 .902 r
.92964 .16187 m
.92964 .54845 L
.93114 .54845 L
.93114 .16187 L
F
.2 .63 .79 r
.92964 .16187 m
.92964 .54845 L
.93114 .54845 L
.93114 .16187 L
s
.678 .847 .902 r
.93114 .16187 m
.93114 .55007 L
.93253 .55007 L
.93253 .16187 L
F
.2 .63 .79 r
.93114 .16187 m
.93114 .55007 L
.93253 .55007 L
.93253 .16187 L
s
.678 .847 .902 r
.93253 .16187 m
.93253 .55104 L
.93358 .55104 L
.93358 .16187 L
F
.2 .63 .79 r
.93253 .16187 m
.93253 .55104 L
.93358 .55104 L
.93358 .16187 L
s
.678 .847 .902 r
.93358 .16187 m
.93358 .55201 L
.93529 .55201 L
.93529 .16187 L
F
.2 .63 .79 r
.93358 .16187 m
.93358 .55201 L
.93529 .55201 L
.93529 .16187 L
s
.678 .847 .902 r
.93529 .16187 m
.93529 .55443 L
.93647 .55443 L
.93647 .16187 L
F
.2 .63 .79 r
.93529 .16187 m
.93529 .55443 L
.93647 .55443 L
.93647 .16187 L
s
.678 .847 .902 r
.93647 .16187 m
.93647 .5562 L
.93731 .5562 L
.93731 .16187 L
F
.2 .63 .79 r
.93647 .16187 m
.93647 .5562 L
.93731 .5562 L
.93731 .16187 L
s
.678 .847 .902 r
.93731 .16187 m
.93731 .55732 L
.93839 .55732 L
.93839 .16187 L
F
.2 .63 .79 r
.93731 .16187 m
.93731 .55732 L
.93839 .55732 L
.93839 .16187 L
s
.678 .847 .902 r
.93839 .16187 m
.93839 .558 L
.93904 .558 L
.93904 .16187 L
F
.2 .63 .79 r
.93839 .16187 m
.93839 .558 L
.93904 .558 L
.93904 .16187 L
s
.678 .847 .902 r
.93904 .16187 m
.93904 .55871 L
.94042 .55871 L
.94042 .16187 L
F
.2 .63 .79 r
.93904 .16187 m
.93904 .55871 L
.94042 .55871 L
.94042 .16187 L
s
.678 .847 .902 r
.94042 .16187 m
.94042 .56034 L
.94136 .56034 L
.94136 .16187 L
F
.2 .63 .79 r
.94042 .16187 m
.94042 .56034 L
.94136 .56034 L
.94136 .16187 L
s
.678 .847 .902 r
.94136 .16187 m
.94136 .56116 L
.94221 .56116 L
.94221 .16187 L
F
.2 .63 .79 r
.94136 .16187 m
.94136 .56116 L
.94221 .56116 L
.94221 .16187 L
s
.678 .847 .902 r
.94221 .16187 m
.94221 .56292 L
.94347 .56292 L
.94347 .16187 L
F
.2 .63 .79 r
.94221 .16187 m
.94221 .56292 L
.94347 .56292 L
.94347 .16187 L
s
.678 .847 .902 r
.94347 .16187 m
.94347 .56469 L
.94505 .56469 L
.94505 .16187 L
F
.2 .63 .79 r
.94347 .16187 m
.94347 .56469 L
.94505 .56469 L
.94505 .16187 L
s
.678 .847 .902 r
.94505 .16187 m
.94505 .56644 L
.94638 .56644 L
.94638 .16187 L
F
.2 .63 .79 r
.94505 .16187 m
.94505 .56644 L
.94638 .56644 L
.94638 .16187 L
s
.678 .847 .902 r
.94638 .16187 m
.94638 .56773 L
.94753 .56773 L
.94753 .16187 L
F
.2 .63 .79 r
.94638 .16187 m
.94638 .56773 L
.94753 .56773 L
.94753 .16187 L
s
.678 .847 .902 r
.94753 .16187 m
.94753 .56895 L
.94855 .56895 L
.94855 .16187 L
F
.2 .63 .79 r
.94753 .16187 m
.94753 .56895 L
.94855 .56895 L
.94855 .16187 L
s
.678 .847 .902 r
.94855 .16187 m
.94855 .57109 L
.95002 .57109 L
.95002 .16187 L
F
.2 .63 .79 r
.94855 .16187 m
.94855 .57109 L
.95002 .57109 L
.95002 .16187 L
s
.678 .847 .902 r
.95002 .16187 m
.95002 .57242 L
.95144 .57242 L
.95144 .16187 L
F
.2 .63 .79 r
.95002 .16187 m
.95002 .57242 L
.95144 .57242 L
.95144 .16187 L
s
.678 .847 .902 r
.95144 .16187 m
.95144 .57329 L
.95312 .57329 L
.95312 .16187 L
F
.2 .63 .79 r
.95144 .16187 m
.95144 .57329 L
.95312 .57329 L
.95312 .16187 L
s
.678 .847 .902 r
.95312 .16187 m
.95312 .5752 L
.95419 .5752 L
.95419 .16187 L
F
.2 .63 .79 r
.95312 .16187 m
.95312 .5752 L
.95419 .5752 L
.95419 .16187 L
s
.678 .847 .902 r
.95419 .16187 m
.95419 .57662 L
.95472 .57662 L
.95472 .16187 L
F
.2 .63 .79 r
.95419 .16187 m
.95419 .57662 L
.95472 .57662 L
.95472 .16187 L
s
.678 .847 .902 r
.95472 .16187 m
.95472 .57848 L
.95609 .57848 L
.95609 .16187 L
F
.2 .63 .79 r
.95472 .16187 m
.95472 .57848 L
.95609 .57848 L
.95609 .16187 L
s
.678 .847 .902 r
.95609 .16187 m
.95609 .57992 L
.9576 .57992 L
.9576 .16187 L
F
.2 .63 .79 r
.95609 .16187 m
.95609 .57992 L
.9576 .57992 L
.9576 .16187 L
s
.678 .847 .902 r
.9576 .16187 m
.9576 .58074 L
.95902 .58074 L
.95902 .16187 L
F
.2 .63 .79 r
.9576 .16187 m
.9576 .58074 L
.95902 .58074 L
.95902 .16187 L
s
.678 .847 .902 r
.95902 .16187 m
.95902 .58278 L
.95975 .58278 L
.95975 .16187 L
F
.2 .63 .79 r
.95902 .16187 m
.95902 .58278 L
.95975 .58278 L
.95975 .16187 L
s
.678 .847 .902 r
.95975 .16187 m
.95975 .58351 L
.96145 .58351 L
.96145 .16187 L
F
.2 .63 .79 r
.95975 .16187 m
.95975 .58351 L
.96145 .58351 L
.96145 .16187 L
s
.678 .847 .902 r
.96145 .16187 m
.96145 .58557 L
.96241 .58557 L
.96241 .16187 L
F
.2 .63 .79 r
.96145 .16187 m
.96145 .58557 L
.96241 .58557 L
.96241 .16187 L
s
.678 .847 .902 r
.96241 .16187 m
.96241 .58644 L
.96384 .58644 L
.96384 .16187 L
F
.2 .63 .79 r
.96241 .16187 m
.96241 .58644 L
.96384 .58644 L
.96384 .16187 L
s
.678 .847 .902 r
.96384 .16187 m
.96384 .58837 L
.96511 .58837 L
.96511 .16187 L
F
.2 .63 .79 r
.96384 .16187 m
.96384 .58837 L
.96511 .58837 L
.96511 .16187 L
s
.678 .847 .902 r
.96511 .16187 m
.96511 .59004 L
.96648 .59004 L
.96648 .16187 L
F
.2 .63 .79 r
.96511 .16187 m
.96511 .59004 L
.96648 .59004 L
.96648 .16187 L
s
.678 .847 .902 r
.96648 .16187 m
.96648 .59223 L
.96808 .59223 L
.96808 .16187 L
F
.2 .63 .79 r
.96648 .16187 m
.96648 .59223 L
.96808 .59223 L
.96808 .16187 L
s
.678 .847 .902 r
.96808 .16187 m
.96808 .59396 L
.96937 .59396 L
.96937 .16187 L
F
.2 .63 .79 r
.96808 .16187 m
.96808 .59396 L
.96937 .59396 L
.96937 .16187 L
s
.678 .847 .902 r
.96937 .16187 m
.96937 .59665 L
.97096 .59665 L
.97096 .16187 L
F
.2 .63 .79 r
.96937 .16187 m
.96937 .59665 L
.97096 .59665 L
.97096 .16187 L
s
.678 .847 .902 r
.97096 .16187 m
.97096 .59785 L
.97191 .59785 L
.97191 .16187 L
F
.2 .63 .79 r
.97096 .16187 m
.97096 .59785 L
.97191 .59785 L
.97191 .16187 L
s
.678 .847 .902 r
.97191 .16187 m
.97191 .59854 L
.97317 .59854 L
.97317 .16187 L
F
.2 .63 .79 r
.97191 .16187 m
.97191 .59854 L
.97317 .59854 L
.97317 .16187 L
s
.678 .847 .902 r
.97317 .16187 m
.97317 .60015 L
.97371 .60015 L
.97371 .16187 L
F
.2 .63 .79 r
.97317 .16187 m
.97317 .60015 L
.97371 .60015 L
.97371 .16187 L
s
.678 .847 .902 r
.97371 .16187 m
.97371 .60045 L
.97425 .60045 L
.97425 .16187 L
F
.2 .63 .79 r
.97371 .16187 m
.97371 .60045 L
.97425 .60045 L
.97425 .16187 L
s
.678 .847 .902 r
.97425 .16187 m
.97425 .60127 L
.97558 .60127 L
.97558 .16187 L
F
.2 .63 .79 r
.97425 .16187 m
.97425 .60127 L
.97558 .60127 L
.97558 .16187 L
s
.678 .847 .902 r
.97558 .16187 m
.97558 .60319 L
.97619 .60319 L
.97619 .16187 L
F
.2 .63 .79 r
.97558 .16187 m
.97558 .60319 L
.97619 .60319 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02446 .01472 Mdot
.02506 .01472 Mdot
.02674 .01472 Mdot
.0269 .01472 Mdot
.02762 .01472 Mdot
.0291 .01473 Mdot
.02986 .01474 Mdot
.03095 .01475 Mdot
.03192 .01476 Mdot
.03267 .01477 Mdot
.03391 .01478 Mdot
.03579 .01481 Mdot
.03628 .01482 Mdot
.03705 .01483 Mdot
.03867 .01486 Mdot
.03946 .01487 Mdot
.04158 .01492 Mdot
.04227 .01494 Mdot
.04311 .01496 Mdot
.04487 .015 Mdot
.0474 .01508 Mdot
.0482 .0151 Mdot
.04968 .01515 Mdot
.05081 .01519 Mdot
.05182 .01522 Mdot
.05285 .01526 Mdot
.05422 .01532 Mdot
.05481 .01534 Mdot
.05577 .01538 Mdot
.05681 .01542 Mdot
.0583 .01549 Mdot
.0599 .01556 Mdot
.06043 .01559 Mdot
.06059 .01559 Mdot
.06233 .01568 Mdot
.06441 .01578 Mdot
.06476 .0158 Mdot
.06661 .0159 Mdot
.06779 .01597 Mdot
.06915 .01605 Mdot
.06932 .01606 Mdot
.06998 .0161 Mdot
.07133 .01618 Mdot
.07221 .01624 Mdot
.07278 .01627 Mdot
.07425 .01637 Mdot
.07474 .0164 Mdot
.07604 .01649 Mdot
.07854 .01666 Mdot
.07889 .01668 Mdot
.08012 .01677 Mdot
.08111 .01685 Mdot
.08276 .01697 Mdot
.08341 .01702 Mdot
.08441 .0171 Mdot
.08521 .01716 Mdot
.08667 .01728 Mdot
.08718 .01732 Mdot
.08821 .01741 Mdot
.08938 .01751 Mdot
.09042 .01759 Mdot
.0914 .01768 Mdot
.09233 .01776 Mdot
.09344 .01786 Mdot
.09558 .01806 Mdot
.09667 .01816 Mdot
.09799 .01829 Mdot
.09885 .01837 Mdot
.09963 .01845 Mdot
.10147 .01863 Mdot
.10233 .01872 Mdot
.10285 .01877 Mdot
.10388 .01888 Mdot
.10459 .01895 Mdot
.10529 .01902 Mdot
.1059 .01909 Mdot
.10715 .01922 Mdot
.10811 .01933 Mdot
.1091 .01944 Mdot
.10964 .0195 Mdot
.1116 .01972 Mdot
.11322 .0199 Mdot
.11385 .01998 Mdot
.11566 .02019 Mdot
.11692 .02034 Mdot
.11744 .0204 Mdot
.11935 .02064 Mdot
.12012 .02073 Mdot
.12089 .02083 Mdot
.12291 .02109 Mdot
.12464 .02131 Mdot
.12629 .02153 Mdot
.1263 .02153 Mdot
.12773 .02172 Mdot
.12895 .02189 Mdot
.12945 .02196 Mdot
.13095 .02216 Mdot
.1316 .02226 Mdot
.13345 .02252 Mdot
.13455 .02267 Mdot
.13541 .0228 Mdot
.1367 .02299 Mdot
.13781 .02315 Mdot
.13943 .02339 Mdot
.14066 .02358 Mdot
.14127 .02367 Mdot
.14295 .02393 Mdot
.14333 .02399 Mdot
.14453 .02417 Mdot
.14485 .02422 Mdot
.14684 .02454 Mdot
.14787 .0247 Mdot
.14889 .02487 Mdot
.14953 .02497 Mdot
.14983 .02502 Mdot
.15213 .0254 Mdot
.15314 .02557 Mdot
.15435 .02577 Mdot
.15449 .0258 Mdot
.15554 .02598 Mdot
.1576 .02633 Mdot
.15867 .02652 Mdot
.15961 .02668 Mdot
.16082 .0269 Mdot
.16184 .02708 Mdot
.16284 .02726 Mdot
.16369 .02741 Mdot
.16512 .02767 Mdot
.16696 .02801 Mdot
.16745 .0281 Mdot
.16875 .02835 Mdot
.16918 .02843 Mdot
.17135 .02884 Mdot
.17161 .02889 Mdot
.17309 .02918 Mdot
.17359 .02927 Mdot
.1745 .02945 Mdot
.17618 .02978 Mdot
.17739 .03002 Mdot
.17843 .03023 Mdot
.17953 .03045 Mdot
.18033 .03061 Mdot
.18099 .03075 Mdot
.18181 .03092 Mdot
.18386 .03134 Mdot
.18538 .03166 Mdot
.18595 .03177 Mdot
.18645 .03188 Mdot
.18773 .03215 Mdot
.18821 .03225 Mdot
.18996 .03263 Mdot
.1917 .03301 Mdot
.19299 .03329 Mdot
.19409 .03353 Mdot
.1947 .03367 Mdot
.19607 .03397 Mdot
.1973 .03425 Mdot
.19846 .03451 Mdot
.19932 .0347 Mdot
.20119 .03513 Mdot
.20265 .03547 Mdot
.20316 .03559 Mdot
.20525 .03608 Mdot
.206 .03626 Mdot
.20669 .03642 Mdot
.20809 .03675 Mdot
.20889 .03695 Mdot
.2099 .03719 Mdot
.21168 .03762 Mdot
.21235 .03778 Mdot
.21305 .03795 Mdot
.21469 .03836 Mdot
.21491 .03841 Mdot
.21656 .03883 Mdot
.21695 .03892 Mdot
.21912 .03947 Mdot
.21927 .03951 Mdot
.22052 .03982 Mdot
.22115 .03999 Mdot
.22167 .04012 Mdot
.22265 .04037 Mdot
.22474 .04091 Mdot
.22482 .04094 Mdot
.22625 .04131 Mdot
.22778 .04171 Mdot
.22898 .04203 Mdot
.22948 .04217 Mdot
.23014 .04234 Mdot
.23193 .04282 Mdot
.23373 .04331 Mdot
.23482 .04361 Mdot
.23715 .04425 Mdot
.23769 .0444 Mdot
.2391 .04479 Mdot
.24011 .04507 Mdot
.24092 .04531 Mdot
.24133 .04542 Mdot
.24228 .04569 Mdot
.24369 .04609 Mdot
.24464 .04636 Mdot
.24485 .04642 Mdot
.2458 .0467 Mdot
.24629 .04684 Mdot
.2472 .0471 Mdot
.24847 .04747 Mdot
.2493 .04771 Mdot
.25008 .04794 Mdot
.25146 .04835 Mdot
.25219 .04856 Mdot
.25315 .04885 Mdot
.25417 .04915 Mdot
.2548 .04934 Mdot
.25563 .04959 Mdot
.25658 .04988 Mdot
.25794 .05029 Mdot
.2586 .05049 Mdot
.25913 .05065 Mdot
.26015 .05096 Mdot
.26069 .05113 Mdot
.26162 .05141 Mdot
.26189 .0515 Mdot
.26333 .05194 Mdot
.2642 .05222 Mdot
.26635 .05289 Mdot
.2677 .05332 Mdot
.26811 .05345 Mdot
.2693 .05382 Mdot
.26941 .05386 Mdot
.27253 .05486 Mdot
.27347 .05516 Mdot
.27455 .05551 Mdot
.27572 .0559 Mdot
.27722 .05639 Mdot
.27873 .05689 Mdot
.27939 .0571 Mdot
.27991 .05728 Mdot
.28207 .058 Mdot
.28294 .05829 Mdot
.28446 .0588 Mdot
.2854 .05912 Mdot
.28613 .05937 Mdot
.28844 .06016 Mdot
.28971 .0606 Mdot
.29096 .06103 Mdot
.29122 .06112 Mdot
.29251 .06157 Mdot
.29324 .06182 Mdot
.29478 .06236 Mdot
.29504 .06245 Mdot
.29612 .06284 Mdot
.29772 .0634 Mdot
.29974 .06412 Mdot
.30009 .06425 Mdot
.30172 .06483 Mdot
.30314 .06535 Mdot
.30348 .06547 Mdot
.30474 .06593 Mdot
.30584 .06633 Mdot
.30677 .06667 Mdot
.30802 .06713 Mdot
.31023 .06795 Mdot
.3105 .06805 Mdot
.31144 .0684 Mdot
.31211 .06865 Mdot
.31348 .06917 Mdot
.31442 .06952 Mdot
.31594 .0701 Mdot
.31711 .07054 Mdot
.31821 .07096 Mdot
.31844 .07105 Mdot
.3196 .07149 Mdot
.32169 .0723 Mdot
.32211 .07246 Mdot
.32345 .07298 Mdot
.32365 .07306 Mdot
.32495 .07356 Mdot
.32622 .07406 Mdot
.32751 .07457 Mdot
.32845 .07494 Mdot
.33062 .0758 Mdot
.33256 .07658 Mdot
.33361 .077 Mdot
.33482 .07749 Mdot
.33559 .07779 Mdot
.33686 .07831 Mdot
.33732 .0785 Mdot
.338 .07878 Mdot
.33958 .07942 Mdot
.3398 .07951 Mdot
.34208 .08045 Mdot
.34266 .08069 Mdot
.34518 .08174 Mdot
.34569 .08195 Mdot
.34803 .08293 Mdot
.34907 .08337 Mdot
.35076 .08408 Mdot
.35175 .08451 Mdot
.35311 .08508 Mdot
.35388 .08542 Mdot
.35557 .08614 Mdot
.35581 .08624 Mdot
.35704 .08678 Mdot
.35798 .08718 Mdot
.35853 .08742 Mdot
.35978 .08796 Mdot
.36146 .0887 Mdot
.36288 .08932 Mdot
.36387 .08976 Mdot
.36434 .08997 Mdot
.365 .09026 Mdot
.36632 .09085 Mdot
.36807 .09162 Mdot
.36855 .09184 Mdot
.36998 .09248 Mdot
.37115 .09301 Mdot
.37169 .09325 Mdot
.37246 .0936 Mdot
.37399 .09429 Mdot
.37524 .09486 Mdot
.37579 .09511 Mdot
.37738 .09584 Mdot
.37943 .09678 Mdot
.37965 .09688 Mdot
.3807 .09737 Mdot
.38206 .098 Mdot
.38323 .09855 Mdot
.38349 .09867 Mdot
.38428 .09904 Mdot
.38549 .0996 Mdot
.38663 .10014 Mdot
.38811 .10084 Mdot
.38979 .10163 Mdot
.39064 .10204 Mdot
.39168 .10254 Mdot
.39219 .10278 Mdot
.39379 .10354 Mdot
.39546 .10435 Mdot
.3963 .10476 Mdot
.39721 .10519 Mdot
.39851 .10583 Mdot
.39972 .10642 Mdot
.40005 .10658 Mdot
.40065 .10687 Mdot
.40255 .1078 Mdot
.40347 .10826 Mdot
.40462 .10882 Mdot
.40618 .10959 Mdot
.40802 .11051 Mdot
.4085 .11075 Mdot
.40959 .1113 Mdot
.41115 .11208 Mdot
.41244 .11273 Mdot
.41293 .11297 Mdot
.41403 .11353 Mdot
.41494 .11399 Mdot
.41646 .11477 Mdot
.41911 .11612 Mdot
.42006 .11661 Mdot
.42101 .1171 Mdot
.42138 .11729 Mdot
.42276 .118 Mdot
.4233 .11828 Mdot
.42367 .11847 Mdot
.42563 .11949 Mdot
.42618 .11978 Mdot
.42853 .12101 Mdot
.4292 .12136 Mdot
.42975 .12165 Mdot
.43102 .12232 Mdot
.43153 .12259 Mdot
.4327 .12321 Mdot
.43334 .12355 Mdot
.43424 .12403 Mdot
.43569 .12481 Mdot
.43716 .12559 Mdot
.43806 .12607 Mdot
.43892 .12654 Mdot
.44056 .12742 Mdot
.44204 .12822 Mdot
.44265 .12856 Mdot
.44335 .12894 Mdot
.44572 .13023 Mdot
.44696 .13091 Mdot
.44739 .13115 Mdot
.44881 .13193 Mdot
.45114 .13322 Mdot
.45213 .13377 Mdot
.45358 .13457 Mdot
.45474 .13522 Mdot
.45595 .1359 Mdot
.45699 .13649 Mdot
.45837 .13726 Mdot
.45982 .13808 Mdot
.46034 .13838 Mdot
.46264 .13968 Mdot
.4629 .13983 Mdot
.464 .14046 Mdot
.46479 .14091 Mdot
.46672 .14202 Mdot
.46751 .14247 Mdot
.46818 .14286 Mdot
.47012 .14398 Mdot
.47126 .14464 Mdot
.47271 .14549 Mdot
.47414 .14632 Mdot
.47524 .14696 Mdot
.4762 .14752 Mdot
.47825 .14873 Mdot
.4789 .14911 Mdot
.47979 .14964 Mdot
.48079 .15023 Mdot
.48179 .15083 Mdot
.48307 .15159 Mdot
.48465 .15253 Mdot
.4862 .15346 Mdot
.48714 .15403 Mdot
.48847 .15483 Mdot
.48894 .15511 Mdot
.48983 .15564 Mdot
.49163 .15674 Mdot
.49251 .15727 Mdot
.49345 .15785 Mdot
.49449 .15848 Mdot
.49531 .15898 Mdot
.49607 .15945 Mdot
.49708 .16006 Mdot
.49767 .16043 Mdot
.49881 .16113 Mdot
.50026 .16203 Mdot
.50071 .1623 Mdot
.50222 .16324 Mdot
.50261 .16348 Mdot
.50502 .16498 Mdot
.50542 .16523 Mdot
.50613 .16568 Mdot
.50863 .16725 Mdot
.51002 .16812 Mdot
.51067 .16854 Mdot
.51194 .16934 Mdot
.51303 .17003 Mdot
.51458 .17101 Mdot
.51594 .17189 Mdot
.51652 .17225 Mdot
.5172 .17269 Mdot
.51783 .17309 Mdot
.51953 .17418 Mdot
.52122 .17528 Mdot
.52182 .17566 Mdot
.52277 .17627 Mdot
.5249 .17766 Mdot
.52612 .17845 Mdot
.52675 .17886 Mdot
.52773 .1795 Mdot
.52895 .1803 Mdot
.53001 .181 Mdot
.53105 .18168 Mdot
.53195 .18227 Mdot
.53271 .18278 Mdot
.53396 .1836 Mdot
.53485 .1842 Mdot
.53551 .18463 Mdot
.53703 .18564 Mdot
.53828 .18647 Mdot
.53927 .18713 Mdot
.53988 .18754 Mdot
.54087 .18821 Mdot
.54149 .18862 Mdot
.54324 .1898 Mdot
.5443 .19052 Mdot
.54562 .19141 Mdot
.54594 .19163 Mdot
.5479 .19296 Mdot
.54905 .19374 Mdot
.54971 .19419 Mdot
.54997 .19437 Mdot
.55047 .19471 Mdot
.55161 .19549 Mdot
.55289 .19637 Mdot
.5547 .19761 Mdot
.55518 .19795 Mdot
.5562 .19865 Mdot
.55709 .19926 Mdot
.55761 .19962 Mdot
.55864 .20034 Mdot
.55974 .2011 Mdot
.56106 .20202 Mdot
.5624 .20296 Mdot
.56339 .20365 Mdot
.56428 .20427 Mdot
.56492 .20472 Mdot
.56684 .20607 Mdot
.56813 .20698 Mdot
.56905 .20764 Mdot
.57011 .20839 Mdot
.57212 .20982 Mdot
.57343 .21075 Mdot
.57538 .21214 Mdot
.57615 .2127 Mdot
.5775 .21366 Mdot
.57884 .21463 Mdot
.57992 .21541 Mdot
.58032 .21569 Mdot
.58132 .21642 Mdot
.58177 .21674 Mdot
.58241 .21721 Mdot
.5836 .21807 Mdot
.5849 .21902 Mdot
.58576 .21964 Mdot
.58704 .22058 Mdot
.58804 .22131 Mdot
.5886 .22172 Mdot
.58946 .22235 Mdot
.59014 .22285 Mdot
.59181 .22407 Mdot
.59315 .22507 Mdot
.59442 .226 Mdot
.59572 .22697 Mdot
.59687 .22783 Mdot
.5974 .22822 Mdot
.59828 .22887 Mdot
.5996 .22986 Mdot
.6015 .23128 Mdot
.60245 .23199 Mdot
.60436 .23343 Mdot
.60509 .23398 Mdot
.60605 .2347 Mdot
.60747 .23578 Mdot
.60848 .23655 Mdot
.60923 .23712 Mdot
.61111 .23855 Mdot
.6117 .23899 Mdot
.61321 .24015 Mdot
.61488 .24143 Mdot
.61507 .24158 Mdot
.61724 .24325 Mdot
.61753 .24347 Mdot
.6186 .24429 Mdot
.61922 .24477 Mdot
.62108 .24621 Mdot
.62152 .24656 Mdot
.62239 .24723 Mdot
.62296 .24767 Mdot
.62432 .24873 Mdot
.62588 .24995 Mdot
.62633 .2503 Mdot
.62779 .25145 Mdot
.62828 .25183 Mdot
.63039 .25349 Mdot
.63166 .25449 Mdot
.63258 .25521 Mdot
.63456 .25678 Mdot
.63529 .25736 Mdot
.63654 .25835 Mdot
.6375 .25911 Mdot
.63801 .25952 Mdot
.63893 .26025 Mdot
.6398 .26095 Mdot
.6409 .26183 Mdot
.64212 .26281 Mdot
.64307 .26357 Mdot
.64502 .26514 Mdot
.64554 .26556 Mdot
.6471 .26682 Mdot
.64764 .26726 Mdot
.64861 .26804 Mdot
.65129 .27022 Mdot
.65143 .27033 Mdot
.65212 .2709 Mdot
.65437 .27274 Mdot
.65476 .27306 Mdot
.65675 .27469 Mdot
.65714 .27501 Mdot
.65991 .27729 Mdot
.66078 .27801 Mdot
.66133 .27847 Mdot
.66354 .28029 Mdot
.66419 .28083 Mdot
.66473 .28128 Mdot
.66665 .28288 Mdot
.66714 .28329 Mdot
.66798 .284 Mdot
.66953 .28529 Mdot
.67016 .28582 Mdot
.67145 .28691 Mdot
.67355 .28867 Mdot
.67451 .28948 Mdot
.67518 .29004 Mdot
.67668 .29132 Mdot
.67719 .29175 Mdot
.67868 .29301 Mdot
.67978 .29395 Mdot
.68207 .2959 Mdot
.68274 .29648 Mdot
.68375 .29734 Mdot
.68527 .29865 Mdot
.68672 .29989 Mdot
.68782 .30084 Mdot
.68907 .30192 Mdot
.68986 .30259 Mdot
.69122 .30378 Mdot
.69229 .3047 Mdot
.69299 .30531 Mdot
.69482 .3069 Mdot
.69576 .30772 Mdot
.69695 .30876 Mdot
.69834 .30998 Mdot
.69938 .31089 Mdot
.70075 .31209 Mdot
.70309 .31414 Mdot
.70452 .31541 Mdot
.7053 .3161 Mdot
.70624 .31693 Mdot
.70768 .31821 Mdot
.7084 .31885 Mdot
.70922 .31958 Mdot
.71045 .32067 Mdot
.71097 .32113 Mdot
.71231 .32233 Mdot
.71392 .32378 Mdot
.71483 .32459 Mdot
.71607 .3257 Mdot
.71709 .32662 Mdot
.71751 .32699 Mdot
.7193 .32861 Mdot
.72038 .32959 Mdot
.72083 .32999 Mdot
.72203 .33108 Mdot
.72286 .33183 Mdot
.72392 .3328 Mdot
.72569 .3344 Mdot
.72663 .33527 Mdot
.72737 .33594 Mdot
.7284 .33688 Mdot
.73044 .33874 Mdot
.73131 .33954 Mdot
.73213 .34029 Mdot
.73318 .34126 Mdot
.73393 .34195 Mdot
.73515 .34308 Mdot
.73583 .34371 Mdot
.73663 .34444 Mdot
.73709 .34488 Mdot
.73882 .34648 Mdot
.74005 .34762 Mdot
.74112 .34861 Mdot
.74184 .34929 Mdot
.7436 .35092 Mdot
.74568 .35287 Mdot
.74606 .35323 Mdot
.74748 .35456 Mdot
.74943 .35639 Mdot
.74993 .35687 Mdot
.75194 .35876 Mdot
.75245 .35924 Mdot
.75343 .36017 Mdot
.75459 .36127 Mdot
.75542 .36206 Mdot
.75669 .36327 Mdot
.75764 .36417 Mdot
.75909 .36556 Mdot
.75993 .36635 Mdot
.76131 .36767 Mdot
.76254 .36886 Mdot
.7628 .3691 Mdot
.76426 .3705 Mdot
.76528 .37149 Mdot
.76681 .37296 Mdot
.76737 .3735 Mdot
.76935 .37541 Mdot
.77069 .37671 Mdot
.77084 .37685 Mdot
.77209 .37807 Mdot
.77326 .37921 Mdot
.77458 .38049 Mdot
.77534 .38123 Mdot
.7773 .38315 Mdot
.77785 .38369 Mdot
.77837 .3842 Mdot
.78059 .38637 Mdot
.78137 .38714 Mdot
.78239 .38814 Mdot
.78295 .38869 Mdot
.78419 .38991 Mdot
.78469 .39041 Mdot
.78608 .39178 Mdot
.78677 .39246 Mdot
.7877 .39339 Mdot
.78844 .39412 Mdot
.79014 .39581 Mdot
.79191 .39757 Mdot
.79328 .39894 Mdot
.79423 .39989 Mdot
.79472 .40038 Mdot
.79556 .40122 Mdot
.79714 .4028 Mdot
.79787 .40354 Mdot
.80011 .4058 Mdot
.80073 .40642 Mdot
.80141 .4071 Mdot
.80246 .40816 Mdot
.80336 .40907 Mdot
.80484 .41057 Mdot
.8062 .41195 Mdot
.8072 .41297 Mdot
.80777 .41354 Mdot
.80859 .41438 Mdot
.81003 .41585 Mdot
.81182 .41768 Mdot
.81281 .4187 Mdot
.81366 .41956 Mdot
.81542 .42136 Mdot
.8167 .42268 Mdot
.81768 .4237 Mdot
.81822 .42425 Mdot
.81899 .42505 Mdot
.81983 .42592 Mdot
.82104 .42716 Mdot
.82152 .42766 Mdot
.82297 .42916 Mdot
.82427 .43051 Mdot
.8251 .43137 Mdot
.82595 .43225 Mdot
.82674 .43308 Mdot
.82808 .43448 Mdot
.82908 .43553 Mdot
.83155 .43811 Mdot
.83251 .43912 Mdot
.83373 .4404 Mdot
.83489 .44161 Mdot
.83558 .44234 Mdot
.83601 .4428 Mdot
.83773 .44462 Mdot
.83863 .44557 Mdot
.83878 .44573 Mdot
.84027 .4473 Mdot
.84081 .44787 Mdot
.84173 .44885 Mdot
.84345 .45068 Mdot
.84382 .45107 Mdot
.84564 .45301 Mdot
.8466 .45403 Mdot
.84773 .45524 Mdot
.84851 .45608 Mdot
.84874 .45632 Mdot
.84937 .457 Mdot
.85062 .45834 Mdot
.85265 .46052 Mdot
.85412 .4621 Mdot
.85548 .46357 Mdot
.85581 .46392 Mdot
.85642 .46459 Mdot
.8578 .46607 Mdot
.85848 .46681 Mdot
.86042 .46892 Mdot
.86184 .47046 Mdot
.86253 .47121 Mdot
.86315 .47189 Mdot
.86439 .47324 Mdot
.86503 .47393 Mdot
.86584 .47482 Mdot
.86631 .47533 Mdot
.86802 .4772 Mdot
.86817 .47737 Mdot
.86931 .47862 Mdot
.87033 .47974 Mdot
.87155 .48108 Mdot
.87283 .48249 Mdot
.87358 .48332 Mdot
.87441 .48424 Mdot
.8766 .48666 Mdot
.87737 .48751 Mdot
.87854 .4888 Mdot
.87968 .49007 Mdot
.88146 .49205 Mdot
.88267 .4934 Mdot
.88375 .4946 Mdot
.8848 .49577 Mdot
.88695 .49818 Mdot
.88767 .49899 Mdot
.88849 .49991 Mdot
.88944 .50097 Mdot
.88968 .50125 Mdot
.89138 .50316 Mdot
.8927 .50465 Mdot
.89387 .50596 Mdot
.89443 .50659 Mdot
.89563 .50795 Mdot
.89604 .50842 Mdot
.89717 .5097 Mdot
.89928 .51209 Mdot
.89965 .51251 Mdot
.90146 .51457 Mdot
.9018 .51496 Mdot
.90274 .51602 Mdot
.90517 .5188 Mdot
.90561 .51931 Mdot
.90697 .52086 Mdot
.90814 .5222 Mdot
.90968 .52398 Mdot
.91076 .52522 Mdot
.91299 .52779 Mdot
.91418 .52917 Mdot
.91443 .52946 Mdot
.91649 .53183 Mdot
.91798 .53356 Mdot
.91919 .53497 Mdot
.91983 .53572 Mdot
.92097 .53704 Mdot
.92116 .53727 Mdot
.92322 .53966 Mdot
.92455 .54122 Mdot
.92635 .54333 Mdot
.92744 .54461 Mdot
.92788 .54512 Mdot
.92956 .54709 Mdot
.93072 .54845 Mdot
.93209 .55007 Mdot
.93291 .55104 Mdot
.93373 .55201 Mdot
.93578 .55443 Mdot
.93728 .5562 Mdot
.93822 .55732 Mdot
.93879 .558 Mdot
.93939 .55871 Mdot
.94076 .56034 Mdot
.94145 .56116 Mdot
.94293 .56292 Mdot
.94441 .56469 Mdot
.94587 .56644 Mdot
.94695 .56773 Mdot
.94797 .56895 Mdot
.94975 .57109 Mdot
.95085 .57242 Mdot
.95158 .57329 Mdot
.95317 .5752 Mdot
.95434 .57662 Mdot
.95588 .57848 Mdot
.95707 .57992 Mdot
.95774 .58074 Mdot
.95943 .58278 Mdot
.96003 .58351 Mdot
.96172 .58557 Mdot
.96244 .58644 Mdot
.96402 .58837 Mdot
.96538 .59004 Mdot
.96718 .59223 Mdot
.96859 .59396 Mdot
.97078 .59665 Mdot
.97176 .59785 Mdot
.97232 .59854 Mdot
.97362 .60015 Mdot
.97387 .60045 Mdot
.97453 .60127 Mdot
.97609 .60319 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(854) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00359418) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66673) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P0000040?[`iP<0
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00040?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000?l0n_3VX`3jl>H10?ooo`00803jl>H2
000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000
n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00
00060?[`iP800000o`3jl>JS0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P000000
1P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP800000
00@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80
000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000103jl>H2000000H0n_3V0P00003o0?[`iZ<0
n_3V0@3oool00200n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP800000
00H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V0000
00000000n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H0000000000009
0?[`iP@000000`3jl>H4000000<0n_3V100000060?[`iP8000000`3jl>H300000?l0n_3VY03jl>H1
0?ooo`00803jl>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3j
l>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`
iP<0000000<0n_3V0000000000001`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H20000
00D0n_3V0P0000050?[`iP800000203jl>H2000000D0n_3V0P00003o0?[`iZ<0n_3V0@3oool00200
n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H200000003
0?[`iP000000000000X0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3j
l>H00P0000020?[`iP030000003jl>H0n_3V00800000o`3jl>JS0?[`iP40oooo000O0?[`iPH00000
103jl>H2000002l0n_3V1@00000X0?[`iP<00000303jl>H3000000@0n_3V0`0000040?[`iP<00000
0P3jl>H5000000<0n_3V0`00003o0?[`iZ@0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40
oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200n_3V1P0000001@3jl>H000000000
00000000n_3V00<000000P3jl>H3000000<0n_3V100000030?[`iP80000000@0n_3V000000000000
n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P0000050?[`iP<00000103jl>H3000000@0
n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V00@000000?[`iP000000
00000`3jl>H01@000000n_3V000000000000n_3V00<000000P3jl>H2000000@0n_3V0P0000020?[`
iP8000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000000000000`3jl>H20000
00@0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
00000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H0
0000000000020?[`iP800000103jl>H2000000D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0
n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0
n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V000000000000
0P3jl>H2000000@0n_3V1P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000D0n_3V
1@0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000090?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V
0P00003o0?[`iYh0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3j
l>H2000000@0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0`0000020?[`iP<00000
00<0n_3V0000003jl>H0103jl>H2000000<0n_3V0P00000`0?[`iP80000000<0n_3V000000000000
2@3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000<0n_3V100000060?[`iP800000
o`3jl>JM0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080n_3V1@0000030?[`iP@000000`3j
l>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H4000000@0n_3V0P00
000`0?[`iP80000000<0n_3V0000000000002@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3j
l>H2000000D0n_3V0P0000080?[`iP800000o`3jl>JM0?[`iP40oooo000R0?[`iP8000002`3jl>H2
00000280n_3V0P00000`0?[`iP80000000<0n_3V0000000000002P3jl>H2000000D0n_3V0P000005
0?[`iP8000001@3jl>H2000000D0n_3V0P0000040?[`iP030000003jl>H0n_3V00800000o`3jl>JM
0?[`iP40oooo000P0?[`iPH000002@3jl>H200000200n_3V1000000a0?[`iP<00000303jl>H30000
00@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000020?[`iPD00000o`3jl>JM0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP0000000000
0?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP040000003jl>H000000?[`iP8000000P3jl>H00`00
0000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0000000<0n_3V00000000
00000P0000001@3jl>H000000?[`iP000000n_3V00<000000P3jl>H00`000000n_3V0000000H0?[`
iPD00000f`3jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`
iPH000000P3jl>H400000080n_3V0`000000103jl>H000000000000000080?[`iP@0000000<0n_3V
0000000000000P3jl>H400000080n_3V1@0000001`3jl>H00000000000000000n_3V0000003jl>H0
0`00000H0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V
0`0000030?[`iP<000001@3jl>H400000080n_3V1P0000020?[`iP<00000J`3jl>H10?ooo`008@3j
l>H2000000030?[`iP000000000000D0000000@0n_3V00000000000000000P3jl>H2000000030?[`
iP000000000000T0n_3V1@0000090?[`iP800000g`3jl>H2000000@0n_3V0P0000020?[`iP800000
0P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080
n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3j
l>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3j
l>H00000000000030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP030000003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`iP020000
00@0n_3V0P0000050?[`iP8000001@3jl>H2000000<0n_3V0P0000000`3jl>H000000000001Z0?[`
iP40oooo000R0?[`iP<00000:@3jl>H200000=h0n_3V0P0000040?[`iP8000000P3jl>H200000080
n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000
003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP020000
01P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000030?[`iP0000000000
00@00000103jl>H2000000<0n_3V0P0000000`3jl>H000000000001Z0?[`iP40oooo000R0?[`iP<0
00006P3jl>H5000000/0n_3V0P00003M0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP80
00001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80
000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`
iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`
iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000050?[`iP8000001@3jl>H2000000<0n_3V10000000103jl>H000000?[`iP3jl>H2
000000D0n_3V0P0000030?[`iP80000000<0n_3V000000000000JP3jl>H10?ooo`008@3jl>H20000
00030?[`iP000000000002X0n_3V0P00003L0?[`iP80000000<0n_3V0000000000001@3jl>H20000
0080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2
000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0`000000
103jl>H000000000003jl>H200000080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H00P00
00000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0`0000030?[`iP030000003j
l>H0n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V00@000000?[`iP0000000000
1@3jl>H2000000@0n_3V0`00001[0?[`iP40oooo000P0?[`iP<0000000@0n_3V0000000000000000
9P3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@00000
0P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@0
0000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0n_3V0000000000000P3jl>H400000080
n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP@0
00000`3jl>H2000000030?[`iP00000000000080n_3V00@000000?[`iP00000000001@3jl>H20000
00<0n_3V0P0000000`3jl>H000000000001Z0?[`iP40oooo001=0?[`iP80000000<0n_3V00000000
0000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP8000008P3jl>H200000080
n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V008000000P3jl>H2000000D0
n_3V0P0000000`3jl>H00000000000030?[`iP<000000`3jl>H4000000<0n_3V0P0000000`3jl>H0
00000000001Z0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000
103jl>H2000000H0n_3V0P00000I0?[`iP<0000000<0n_3V0000000000000P00000^0?[`iP<00000
2`3jl>H3000000@0n_3V0`0000040?[`iP<000000`3jl>H5000000<0n_3V0`0000050?[`iP800000
1@3jl>H2000000@0n_3V0`00001[0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP0800000003
0?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`iP00
00000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`
iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P000000103jl>H000000?[`iP0000020?[`
iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V10000004
0?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V10000002
0?[`iP<0000000<0n_3V0000000000001P00000K0?[`iP<00000103jl>H3000000@0n_3V1000002i
0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@0000001@3jl>H00000000000000000
n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H2
00000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P00
00040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000/0n_3V1@0000090?[`iP80
000000<0n_3V0000000000000P3jl>H00`000000n_3V0?[`iP02000000@0n_3V0P00002j0?[`iP40
oooo000R0?[`iP<00000:03jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP800000
0P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000
0`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H4000001T0n_3V
0P0000000`3jl>H00000000000050?[`iP80000000<0n_3V0000000000001000002i0?[`iP40oooo
000R0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`iP00
000000000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103j
l>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000
003jl>H4000000d0n_3V1@0000090?[`iP80000000<0n_3V0000000000001@3jl>H2000000040?[`
iP000000n_3V0?[`iP800000^P3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002L0n_3V
0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V
0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H20000
01X0n_3V0`0000030?[`iP030000003jl>H0n_3V008000000P3jl>H010000000n_3V00000000002j
0?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`iP000000
00000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP000000
00000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00
00030?[`iPD000006@3jl>H2000000030?[`iP00000000000080n_3V100000030?[`iP040000003j
l>H0000000000;X0n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0
n_3V000000000000403jl>H2000000`0n_3V0P00000h0?[`iP80000000<0n_3V0000000000000P3j
l>H2000000H0n_3V0`00002j0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P000006
0?[`iP800000103jl>H2000000H0n_3V0P00000a0?[`iP<000000`3jl>H5000000@0n_3V0P00002j
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`007@3j
l>HV0?ooh0800000K03oon02000000@0oooP0P0000040?ooh0800000J`3oon05000006T0oooP1@00
00020?ooh0800000103oon02000006/0oooP1000000S0?ooh1h0n_3V0@3oool001d0n_3V9@3oon00
10000000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000P0oooP00@000000?ooh03oon00
0000K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00L0oooP00@000000?ooh03o
on000000JP3oon000`000000oooP0?ooh00T0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000
oooP0?ooh000001Z0?ooh0040000003oon00oooP000000/0oooP00<000000?ooh03oon00JP3oon00
0`000000oooP0?ooh01[0?ooh0030000003oon00oooP00X0oooP00<000000?ooh03oon00J@3oon00
0`000000oooP0?ooh00S0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z
0?ooh0040000003oon00oooP000000T0oooP0P00001]0?ooh0030000003oon00oooP06/0oooP00<0
00000?ooh03oon00203oon02000006d0oooP00<000000?ooh03oon008P3oon0N0?[`iP40oooo000M
0?[`iRD0oooP00@000000?ooh03oon000000JP3oon0010000000oooP0?ooh00000090?ooh0030000
003oon00oooP06`0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0080?ooh0030000
003oon00oooP06X0oooP00@000000?ooh03oon0000008`3oon0N0?[`iP40oooo000M0?[`iRH0oooP
0P00001/0?ooh08000002P3oon03000006/0oooP0P00001/0?ooh08000002P3oon03000006/0oooP
0P00000T0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`iQ/0oooPo`00003Z000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
5@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?oo
h00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00
oooP0740oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0D000001P3oon000`000000oooP0?ooh0090?ooh1<00000
o`3oon3:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003o
on00oooP00H0oooP00<000000?ooh03oon00203oon0S00000?l0oooP^`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@000001`3oon00
0`000000003o0000o`0H0000oa400000o`3oon2_0?ooh0@00000603oon0N0?[`iP40oooo000M0?[`
iPX0oooP100000040?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon0J0000
00P0003o4P00003o0?ooh:T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80
oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh140cHDo4@00000:0000o`l0
0000o`3oon2R0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000
203oon000`000000oooP0?ooh0090?ooh200cHDo300000090000o``00000o`3oon2L0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP:P3=
QCl;000000P0003o2@00003o0?ooh9L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon0c0<f5?`X000001@000?l:00000?l0oooPT@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h3T0cHDo2@0000050000o`X00000o`3oon2<0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP?`3=QCl8000000D0003o2@00003o0?ooh8P0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon150<f5?`L000001@000?l900000?l0oooPP`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh4X0cHDo1`0000050000o`P00000o`3o
on1o0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPC`3=QCl7000000@0003o2000003o0?ooh7/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1D0<f5?`H000001@000?l70000
0?l0oooPM`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh5P0cHDo1`0000040000o`H00000o`3oon1d0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPG03=QCl7000000@0003o
1P00003o0?ooh700oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
00090?ooh600cHDo1`0000030000o`H00000o`3oon1[0?ooh0<00000603oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon1T0<f5?`H0000010000?l500000?l0oooPJP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h6P0cHDo1P0000030000o`D00000o`3oon1W0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPJ`3=QCl6000000@0003o1000003o0?ooh6@0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon1_0<f5?`H000000`000?l500000?l0oooPH03oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh780cHDo1P0000030000o`D00000o`3o
on1M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPM@3=QCl600000080003o1P00003o0?ooh5X0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1h0<f5?`D000000`000?l50000
0?l0oooPF03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh7`0cHDo100000030000o`D00000o`3oon1E0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPOP3=QCl500000080003o
1P00003o0?ooh580oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon210<f5?`@000000`000?l600000?l0oooPC`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh8@0cHDo10000003
0000o`H00000o`3oon1<0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooPQ`3=QCl4000000<0003o1@00003o0?ooh4X0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2:0<f5?`@0
00000P000?l600000?l0oooPA`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon03000000T0oooPS03=QCl4000000<0003o1@00003o0?ooh4<0oooP0`00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh8l0cHDo100000030000o`@00000o`3o
on130?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPT@3=QCl500000080003o1@00003o0?ooh400oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2E0<f5?`<000000`000?l40000
0?l0oooP?P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh9L0cHDo100000030000o`@00000o`3oon0k0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPV@3=QCl500000080003o
1000003o0?ooh3T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon2L0<f5?`@000000P000?l500000?l0oooP=P3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh9h0cHDo10000002
0000o`@00000o`3oon0e0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooPX03=QCl400000080003o1@00003o0?ooh380oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2R0<f5?`@0
00000`000?l400000?l0oooP<03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh:D0cHDo100000020000o`@00000o`3oon0^0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPY`3=
QCl400000080003o1@00003o0?ooh2/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon2Y0<f5?`@000000P000?l500000?l0oooP:@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h:`0cHDo0`0000030000o`@00000o`3oon0W0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP[P3=QCl400000080003o1000003o0?ooh2D0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh;00cHDo
100000020000o`@00000o`3oon0Q0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon2b0<f5?`@000000P000?l400000?l0oooP8@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh;@0cHDo10000002
0000o`<00000o`3oon0P0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP]P3=QCl400000080003o1000003o0?ooh1d0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2h0<f5?`@0
00000P000?l400000?l0oooP6`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh;/0cHDo0`0000020000o`@00000o`3oon0I0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP_03=
QCl400000080003o0`00003o0?ooh1P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon2o0<f5?`<000000P000?l300000?l0oooP5P3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h<00cHDo100000020000o`<00000o`3oon0D0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP`P3=QCl400000080003o0`00003o0?ooh180
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon350<f5?`<000000P000?l300000?l0oooP403oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh<H0cHDo100000000`000?l000000000
000200000?l0oooP3P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh<P0cHDo0`0000020000o`<00000o`3oon0=0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPbP3=QCl30000
0080003o1000003o0?ooh0X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP0`0000090?ooh</0cHDo100000000`000?l000000000000200000?l0oooP1`3oon03000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPcP3=QCl200000080003o
1000003o0?ooh0L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon3@0<f5?`8000000P000?l400000?l0oooP1@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=40cHDo0`000002
0000o`@00000o`3oon030?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooPd`3=QCl3000000030000o`000000000000800000o`3oon020?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooPe@3=QCl200000080003o1000003o0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPeP3=QCl300000080003o1000003m0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPf03=
QCl300000080003o0`00003l0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP00T0oooPfP3=QCl3000000030000o`000000000000800000nP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h=/0cHDo0`0000020000o`@00000n03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh=d0cHDo0`0000020000o`<00000m`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=l0cHDo
0`0000000`000?l000000000000200000?D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP00T0oooPh@3=QCl200000080003o1000
003c0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00
oooP000000L0oooP00<000000?ooh03oon002@3oon3R0<f5?`<000000P000?l300000?80oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3o
on04000000P0oooPi`0000020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H@
0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00kP3oon04000000030000o`00
0000000000800000h`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@
0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00l03oon0300000080003o0`00
003R03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P000008
0?ooh0030000003oon00oooP0?80oooP0`00000010000?l0000000000000003Q03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00l`3oon03
00000080003o0`00003O03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00m@3oon03000000030000o`000000000000800000g@0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?L0
oooP0P0000020000o`<00000g00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?P0oooP0`0000000`000?l000000000000200000=X0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03j0?ooh080000000<0003o0000000000000P00003I03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n`3oon0200000080003o1000003G
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o@3oon02000000030000o`000000000000800000eP0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?h0oooP0P0000020000o`@0
0000e00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP0@3oon02000000030000o`000000000000800000d`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP0P3o
on0200000080003o1000003A03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon040?ooh080000000<0003o0000000000000P00003@
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?oo
h0D0oooP0P0000020000o`@00000cP0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon070?ooh080000000<0003o0000000000000P00003=03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon090?ooh003000000000?l0003o00<00000c00cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2P3oon02000000030000o`00
0000000000800000bP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP2`3oon0200000080003o1000003803>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0=0?oo
h080000000<0003o0000000000000P00003703>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0>0?ooh08000000P000?l400000<D0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh100oooP0P0000000`000?l000000000000200000<@0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh140oooP0P00
00020000o`<00000``0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP4`3oon02000000040000o`000000000000000<80<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh1@0oooP0P0000020000o`<00000`00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP5@3oon03000000040000o`0000000000
00000;l0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh1H0oooP0`0000020000o`<00000_@0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP603oon0300000004
0000o`000000000000000;`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon0300000?l0oooP6@3oon0300000080003o0P00002k03>QbPT0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1/0oooP0`0000000`000?l00000
0000002j03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0L0?ooh0<0000000@0003o0000000000000000^00cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7@3o
on0300000080003o0P00002g03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0O0?ooh0<0000000<0003o000000000000]P0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP803oon03000000040000o`000000000000000;@0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh280oooP0P0000020000
o`<00000/P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP8`3oon03000000040000o`000000000000000;40<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2@0
oooP0`00000010000?l0000000000000002`03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0V0?ooh08000000P000?l300000:h0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh2P0oooP0P00000010000?l0000000000000002]03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0X0?ooh0<00000
00@0003o0000000000000000[00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:@3oon0300000080003o0P00002[03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0[0?ooh0<0000000@0003o0000000000000000Z@0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0/0?ooh0<0000000@0003o0000000000000000
Z00cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0]0?ooh0<000000P000?l200000:L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2l0oooP0`0000000`000?l000000000002V
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0`0?ooh0<0000000@0003o0000000000000000Y00cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<P3oon020000
00040000o`000000000000000:<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3<0oooP0P0000020000o`800000XP0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP=03oon03000000030000o`00000000000:40<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3D0oooP0`0000000`000?l00000
0000002P03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0f0?ooh0<000000P000?l00`000000<j7:03>QbP2M03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0h
0?ooh0<0000000<0003o000000000000W@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>@3oon03000000030000o`0000000000
09`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh3X0oooP0`0000000`000?l000000000002K03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0k0?ooh0<00000
0P000?l2000009T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh3d0oooP0`0000000`000?l000000000002H03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0n
0?ooh0<0000000<0003o000000000000U`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon0o0?ooh0<0000000<0003o000000000000UP0cXLX90?oo
h0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon100?ooh0<0
000000<0003o000000000000U@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@@3oon03000000030000o`000000000009@0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh4<0oooP0P0000020000o`800000TP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPA03oon03000000030000o`000000
00000940<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh4D0oooP0`0000000`000?l000000000002@03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon160?ooh0<0
000000<0003o000000000000S`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPA`3oon03000000040000o`0000000000000008d0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh4P0oooP0`00000010000?l0000000000000002<03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1:0?ooh0800000
00@0003o0000000000000000R`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB`3oon02000000040000o`0000000000000008X0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh4`0oooP0P00000010000?l0000000000000002903>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP0?l0oooP
C@3oon0200000080003o0P00002803>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh4h0oooP0`00
000010000?l0000000000000002603>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ80oooP00<000000?ooh03oon001P3oon0400000?l0oooPCP3oon03000000040000o`00
00000000000008D0<j7:203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003o
on00oooP00H0oooP00<000000?ooh03oon00o`3oon1A0?ooh080000000<0003o000000000000Q@0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00
oooP00H0oooP00<000000?ooh03oon00o`3oon1B0?ooh080000000@0003o0000000000000000P`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon00
0`000000oooP0?ooh03o0?ooh5<0oooP0P00000010000?l0000000000000002203>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1D
0?ooh080000000@0003o0000000000000000P@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPE@3oon02000000040000o`000000
000000000800<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh5H0oooP0P00000010000?l0000000000000001o03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1G
0?ooh08000000P000?l2000007h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5T0oooP0P0000000`000?l000000000001m03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1J0?ooh080000000@0003o0000000000000000N`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF`3oon0200000004
0000o`0000000000000007X0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh5`0oooP0P00000010000?l0000000000000001i03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1M0?ooh080000000@0003o0000000000000000N00cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPGP3oon0200000004
0000o`0000000000000007L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon0300000?l0oooPG`3oon02000000040000o`0000000000000007H0<j7:2@3oon030000
01P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH03oon0200000004
0000o`0000000000000007D0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh640oooP0P0000020000o`800000M00cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
HP3oon03000000030000o`000000000007<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh6<0oooP0`0000000`000?l000000000
001b03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1U0?ooh080000000<0003o000000000000L@0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPIP3oon020000
00030000o`00000000000700<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh6L0oooP0P0000000`000?l000000000001_03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1X0?ooh080000000<0003o000000000000KP0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ@3oon02000000040000o`00
00000000000006`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh6X0oooP0P00000010000?l0000000000000001[03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1[0?ooh080000000@0003o0000000000000000JP0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK03oon02000000040000o`00
00000000000006T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh6d0oooP0P00000010000?l0000000000000001X03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1^0?ooh080000000@0003o0000000000000000I`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon1`0?ooh003000000000?l0003o00800000IP0c
XLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1`
0?ooh0<0000000<0003o000000000000I@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL@3oon03000000030000o`0000000000
06@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh780oooP0`0000000`000?l000000000001S03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1c0?ooh0<00000
00<0003o000000000000HP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPM03oon03000000030000o`00000000000640<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7D0oooP0`0000000`000?l000000000001P03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1g0?ooh080000000<0003o0000
00000000G`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPN03oon02000000030000o`000000000005h0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7T0oooP
0P0000000`000?l000000000001M03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1i0?ooh0<0000000<0003o000000000000G00c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPNP3oon03000000030000o`000000000005/0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP0P0000000`00
0?l000000000001J03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1m0?ooh080000000<0003o000000000000F@0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon1n0?ooh0800000
00<0003o000000000000F00cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1o0?ooh080000000<0003o000000000000E`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP03oon02
000000030000o`000000000005H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh840oooP0P0000000`000?l000000000001E03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon220?ooh080000000<0003o000000000000E00cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP`3oon02000000030000
o`000000000005<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8@0oooP0P0000000`000?l000000000001B03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon25
0?ooh080000000<0003o000000000000D@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQP3oon02000000030000o`0000000000
0500<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh8L0oooP0P0000000`000?l000000000001?03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon270?ooh0<00000
00<0003o000000000000CP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPR03oon03000000030000o`000000000004d0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh8X0oooP0P0000000`000?l000000000001<03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2;0?ooh080000000<0003o0000
00000000B`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon2;0?ooh0<0000000<0003o000000000000BP0cXLX90?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2<0?ooh0<0000000<0003o000000000000
B@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPSP3oon02000000030000o`000000000004P0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8h0oooP0`000000
0`000?l000000000001703>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2?0?ooh0<0000000<0003o000000000000AP0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPT03oon02000000040000o`0000000000000004D0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh940oooP0P00000010000?l0
000000000000001403>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2B0?ooh080000000@0003o0000000000000000@`0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPT`3oon02000000030000o`000000000004<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9@0oooP0P0000000`000?l00000
0000001203>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2E0?ooh080000000<0003o000000000000@@0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPUP3oon02
000000030000o`00000000000400<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9L0oooP0P0000000`000?l000000000000o03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP100000070?ooh003
0000003oon00oooP0?l0oooPV03oon02000000030000o`000000000003h0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh0080?ooh0030000
003oon00oooP0?l0oooPV@3oon02000000030000o`000000000003d0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon000`000000oooP0?ooh0070?ooh0@00000o`3o
on2I0?ooh003000000000?l0000000800000?00cXLX80?ooh0@00000603oon0N0?[`iP40oooo000M
0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh9/0oooP00<00000
0000o`0000000P00000k03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh9`0oooP00<00000
0000o`0000000P00000j03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPW@3oon000`000000003o000000020000
03T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh9h0oooP00<000000000o`0000000P00000h03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2O0?ooh0030000
00000?l0000000800000=`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPX03oon000`000000003o00000002000003H0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh:40oooP00<000000000o`0000000P00000e03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Q0?ooh080000000@0003o0000
000000000000=00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPXP3oon02000000040000o`0000000000000003<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:<0oooP0P0000000`000?l000000000000c03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2T0?ooh080000000<0003o00000000
0000<P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPY@3oon02000000030000o`00000000000340<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:H0oooP0P00
00000`000?l000000000000`03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`00003o0?ooh:L0oooP0P0000000`000?l000000000000_03>QbPT0oooP0`00000H
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:P0oooP0P0000000`00
0?l000000000000^03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2X0?ooh080000000@0003o0000000000000000;@0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPZ@3oon02000000040000o`0000000000000002`0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP0P0000000`000?l0
00000000000/03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2[0?ooh080000000<0003o000000000000:`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[03o
on02000000030000o`000000000002X0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP0P0000000`000?l000000000000Y
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2^0?ooh080000000<0003o000000000000:00cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[`3oon0200000003
0000o`000000000002L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh;00oooP0P0000000`000?l000000000000V03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2`0?ooh0<0000000<0003o0000000000009@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon03000000030000o`000000
000002@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh;80oooP0`0000000`000?l000000000000S03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh;<0oooP0`0000000`000?l0
00000000000R03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh;@0oooP0`0000000`000?l0000003>QbP0Q03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2e0?ooh080000000<0
003o0000000000008@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP]P3oon02000000030000o`00000000000200<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;L0oooP0P0000000`000?l000000000000O03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2h0?ooh080000000<0003o00000000
00007P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP^@3oon02000000030000o`000000000001d0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP0P00
00000`000?l0000003>QbP0L03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh080000000<0003o000000000000700cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP^`3oon02000000030000o`000000000001/0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;`0oooP0P0000000`000?l0
00000000000J03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2m0?ooh080000000<0003o0000000000006@0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_P3o
on02000000030000o`000000000001P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;l0oooP0P0000000`000?l000000000000G
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2o0?ooh080000000@0003o00000000000000005P0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon300?ooh080000000<0003o0000
000000005P0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon310?ooh080000000<0003o0000000000005@0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`P3oon02000000030000
o`000000000001@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<<0oooP0P0000000`000?l000000000000C03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon34
0?ooh080000000<0003o0000000000004P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa@3oon000`000000003o000000020000
0140<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh<D0oooP0P00000010000?l0000000000000000@03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon360?ooh080
000000@0003o00000000000000003`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa`3oon02000000030000o`000000000000l0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<P0oooP0P0000000`000?l000000000000>03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?ooh080000000<0
003o0000000000003@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPbP3oon000`000000003o00000002000000`0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h<X0oooP0P00000010000?l0000000000000000;03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3;0?ooh080000000<0003o0000
000000002`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon3<0?ooh080000000<0003o0000000000002P0cXLX90?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3=0?ooh080000000<0003o000000000000
2@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPcP3oon02000000030000o`000000000000P0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<l0oooP0P000000
0`000?l000000000000703>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon3?0?ooh080000000@0003o00000000000000001P0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPd03oon02000000030000o`000000000000H0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=40oooP0P0000000`000?l0
00000000000503>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon3B0?ooh080000000<0003o000000000000100cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd`3o
on02000000030000o`000000000000<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=@0oooP0P0000000`000?l0000000000002
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon3D0?ooh0<0000000@0003o0000000cXLX0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=D0oooP0P0000001000
0?l000000000000cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?oo
h0800000203oon000`000000oooP0?ooh03o0?ooh=H0oooP0P0000000`000?l000000000000;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP0000
00L0oooP00<000000?ooh03oon00o`3oon3G0?ooh080000000<0003o0000000000002P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@0
0000o`3oon3F0?ooh0<0000000<0003o0000003oon001P3oon04000001P0oooP7P3jl>H10?ooo`00
7@3jl>HC0?ooh0030000003oon00oooP00D0oooP00<000000?ooh03oon00o`3oon3H0?ooh0@00000
2P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?oo
h00000070?ooh0030000003oon00oooP0?l0oooPf@3oon02000000/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H400000080n_3V2000
00020?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V00000000
000010000000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V
00<000002@3jl>H500000080n_3V100000020?[`iPD000004P3jl>H6000000H0n_3V00<000000?[`
iP3jl>H0103jl>H3000000040?[`iP000000000000000>@0n_3V0@3oool00=d0n_3V0P0000020?[`
iP8000000`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`
iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V00000000
0000i@3jl>H10?ooo`00g@3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP800000
1@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H00000
0000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000`0n_3V1@0000050?[`iP8000001P3jl>H5000000H0n_3V0`00003V0?[`iP40
oooo003M0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`
iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P000000
0`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F
0?[`iP800000203jl>H00`000000n_3V0?[`iP060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H20000
0080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H0
00000?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`
iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`
iP000000n_3V0180n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H00000
0000003U0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103j
l>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3j
l>H2000000D0n_3V0`0000000`3jl>H0000000000007000000/0n_3V1@0000020?[`iP@000000P3j
l>H3000000030?[`iP000000000001<0n_3V0P00000?0?[`iP<0000000D0n_3V0000000000000000
0?[`iP0400000=l0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<0
00000?[`iP3jl>H0603jl>H200000240n_3V1000000H0?[`iP030000003jl>H0n_3V0=l0n_3V0@3o
ool00=`0n_3V1P0000040?[`iP800000;`3jl>H5000001/0n_3V0`00000Q0?[`iP8000006@3jl>H0
0`000000n_3V0?[`iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<000000?[`iP3jl>H0g@3jl>H10?oo
o`00o`3jl>Ie0?[`iP040000003jl>H0n_3V00000=l0n_3V0@3oool00?l0n_3VMP3jl>H200000>00
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.0246 .01472 L
.0246 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.0246 .01472 L
.0246 .16187 L
s
1 .894 .882 r
.0246 .16187 m
.0246 .01472 L
.02545 .01472 L
.02545 .16187 L
F
.804 .522 .247 r
.0246 .16187 m
.0246 .01472 L
.02545 .01472 L
.02545 .16187 L
s
1 .894 .882 r
.02545 .16187 m
.02545 .01472 L
.02646 .01472 L
.02646 .16187 L
F
.804 .522 .247 r
.02545 .16187 m
.02545 .01472 L
.02646 .01472 L
.02646 .16187 L
s
1 .894 .882 r
.02646 .16187 m
.02646 .01472 L
.02757 .01472 L
.02757 .16187 L
F
.804 .522 .247 r
.02646 .16187 m
.02646 .01472 L
.02757 .01472 L
.02757 .16187 L
s
1 .894 .882 r
.02757 .16187 m
.02757 .01473 L
.02832 .01473 L
.02832 .16187 L
F
.804 .522 .247 r
.02757 .16187 m
.02757 .01473 L
.02832 .01473 L
.02832 .16187 L
s
1 .894 .882 r
.02832 .16187 m
.02832 .01473 L
.02891 .01473 L
.02891 .16187 L
F
.804 .522 .247 r
.02832 .16187 m
.02832 .01473 L
.02891 .01473 L
.02891 .16187 L
s
1 .894 .882 r
.02891 .16187 m
.02891 .01474 L
.03006 .01474 L
.03006 .16187 L
F
.804 .522 .247 r
.02891 .16187 m
.02891 .01474 L
.03006 .01474 L
.03006 .16187 L
s
1 .894 .882 r
.03006 .16187 m
.03006 .01474 L
.03056 .01474 L
.03056 .16187 L
F
.804 .522 .247 r
.03006 .16187 m
.03006 .01474 L
.03056 .01474 L
.03056 .16187 L
s
1 .894 .882 r
.03056 .16187 m
.03056 .01475 L
.0312 .01475 L
.0312 .16187 L
F
.804 .522 .247 r
.03056 .16187 m
.03056 .01475 L
.0312 .01475 L
.0312 .16187 L
s
1 .894 .882 r
.0312 .16187 m
.0312 .01476 L
.03221 .01476 L
.03221 .16187 L
F
.804 .522 .247 r
.0312 .16187 m
.0312 .01476 L
.03221 .01476 L
.03221 .16187 L
s
1 .894 .882 r
.03221 .16187 m
.03221 .01476 L
.03321 .01476 L
.03321 .16187 L
F
.804 .522 .247 r
.03221 .16187 m
.03221 .01476 L
.03321 .01476 L
.03321 .16187 L
s
1 .894 .882 r
.03321 .16187 m
.03321 .01478 L
.03439 .01478 L
.03439 .16187 L
F
.804 .522 .247 r
.03321 .16187 m
.03321 .01478 L
.03439 .01478 L
.03439 .16187 L
s
1 .894 .882 r
.03439 .16187 m
.03439 .01479 L
.03502 .01479 L
.03502 .16187 L
F
.804 .522 .247 r
.03439 .16187 m
.03439 .01479 L
.03502 .01479 L
.03502 .16187 L
s
1 .894 .882 r
.03502 .16187 m
.03502 .01481 L
.0359 .01481 L
.0359 .16187 L
F
.804 .522 .247 r
.03502 .16187 m
.03502 .01481 L
.0359 .01481 L
.0359 .16187 L
s
1 .894 .882 r
.0359 .16187 m
.0359 .01481 L
.0367 .01481 L
.0367 .16187 L
F
.804 .522 .247 r
.0359 .16187 m
.0359 .01481 L
.0367 .01481 L
.0367 .16187 L
s
1 .894 .882 r
.0367 .16187 m
.0367 .01483 L
.03747 .01483 L
.03747 .16187 L
F
.804 .522 .247 r
.0367 .16187 m
.0367 .01483 L
.03747 .01483 L
.03747 .16187 L
s
1 .894 .882 r
.03747 .16187 m
.03747 .01484 L
.03867 .01484 L
.03867 .16187 L
F
.804 .522 .247 r
.03747 .16187 m
.03747 .01484 L
.03867 .01484 L
.03867 .16187 L
s
1 .894 .882 r
.03867 .16187 m
.03867 .01487 L
.03965 .01487 L
.03965 .16187 L
F
.804 .522 .247 r
.03867 .16187 m
.03867 .01487 L
.03965 .01487 L
.03965 .16187 L
s
1 .894 .882 r
.03965 .16187 m
.03965 .01489 L
.04061 .01489 L
.04061 .16187 L
F
.804 .522 .247 r
.03965 .16187 m
.03965 .01489 L
.04061 .01489 L
.04061 .16187 L
s
1 .894 .882 r
.04061 .16187 m
.04061 .0149 L
.04107 .0149 L
.04107 .16187 L
F
.804 .522 .247 r
.04061 .16187 m
.04061 .0149 L
.04107 .0149 L
.04107 .16187 L
s
1 .894 .882 r
.04107 .16187 m
.04107 .01491 L
.04148 .01491 L
.04148 .16187 L
F
.804 .522 .247 r
.04107 .16187 m
.04107 .01491 L
.04148 .01491 L
.04148 .16187 L
s
1 .894 .882 r
.04148 .16187 m
.04148 .01493 L
.04219 .01493 L
.04219 .16187 L
F
.804 .522 .247 r
.04148 .16187 m
.04148 .01493 L
.04219 .01493 L
.04219 .16187 L
s
1 .894 .882 r
.04219 .16187 m
.04219 .01494 L
.04295 .01494 L
.04295 .16187 L
F
.804 .522 .247 r
.04219 .16187 m
.04219 .01494 L
.04295 .01494 L
.04295 .16187 L
s
1 .894 .882 r
.04295 .16187 m
.04295 .01495 L
.04357 .01495 L
.04357 .16187 L
F
.804 .522 .247 r
.04295 .16187 m
.04295 .01495 L
.04357 .01495 L
.04357 .16187 L
s
1 .894 .882 r
.04357 .16187 m
.04357 .01497 L
.04455 .01497 L
.04455 .16187 L
F
.804 .522 .247 r
.04357 .16187 m
.04357 .01497 L
.04455 .01497 L
.04455 .16187 L
s
1 .894 .882 r
.04455 .16187 m
.04455 .01503 L
.04575 .01503 L
.04575 .16187 L
F
.804 .522 .247 r
.04455 .16187 m
.04455 .01503 L
.04575 .01503 L
.04575 .16187 L
s
1 .894 .882 r
.04575 .16187 m
.04575 .01505 L
.04686 .01505 L
.04686 .16187 L
F
.804 .522 .247 r
.04575 .16187 m
.04575 .01505 L
.04686 .01505 L
.04686 .16187 L
s
1 .894 .882 r
.04686 .16187 m
.04686 .01507 L
.04772 .01507 L
.04772 .16187 L
F
.804 .522 .247 r
.04686 .16187 m
.04686 .01507 L
.04772 .01507 L
.04772 .16187 L
s
1 .894 .882 r
.04772 .16187 m
.04772 .0151 L
.04836 .0151 L
.04836 .16187 L
F
.804 .522 .247 r
.04772 .16187 m
.04772 .0151 L
.04836 .0151 L
.04836 .16187 L
s
1 .894 .882 r
.04836 .16187 m
.04836 .01513 L
.04938 .01513 L
.04938 .16187 L
F
.804 .522 .247 r
.04836 .16187 m
.04836 .01513 L
.04938 .01513 L
.04938 .16187 L
s
1 .894 .882 r
.04938 .16187 m
.04938 .01514 L
.0507 .01514 L
.0507 .16187 L
F
.804 .522 .247 r
.04938 .16187 m
.04938 .01514 L
.0507 .01514 L
.0507 .16187 L
s
1 .894 .882 r
.0507 .16187 m
.0507 .01521 L
.05146 .01521 L
.05146 .16187 L
F
.804 .522 .247 r
.0507 .16187 m
.0507 .01521 L
.05146 .01521 L
.05146 .16187 L
s
1 .894 .882 r
.05146 .16187 m
.05146 .01523 L
.05187 .01523 L
.05187 .16187 L
F
.804 .522 .247 r
.05146 .16187 m
.05146 .01523 L
.05187 .01523 L
.05187 .16187 L
s
1 .894 .882 r
.05187 .16187 m
.05187 .01524 L
.05228 .01524 L
.05228 .16187 L
F
.804 .522 .247 r
.05187 .16187 m
.05187 .01524 L
.05228 .01524 L
.05228 .16187 L
s
1 .894 .882 r
.05228 .16187 m
.05228 .01527 L
.05301 .01527 L
.05301 .16187 L
F
.804 .522 .247 r
.05228 .16187 m
.05228 .01527 L
.05301 .01527 L
.05301 .16187 L
s
1 .894 .882 r
.05301 .16187 m
.05301 .01529 L
.05394 .01529 L
.05394 .16187 L
F
.804 .522 .247 r
.05301 .16187 m
.05301 .01529 L
.05394 .01529 L
.05394 .16187 L
s
1 .894 .882 r
.05394 .16187 m
.05394 .01533 L
.05507 .01533 L
.05507 .16187 L
F
.804 .522 .247 r
.05394 .16187 m
.05394 .01533 L
.05507 .01533 L
.05507 .16187 L
s
1 .894 .882 r
.05507 .16187 m
.05507 .01536 L
.05597 .01536 L
.05597 .16187 L
F
.804 .522 .247 r
.05507 .16187 m
.05507 .01536 L
.05597 .01536 L
.05597 .16187 L
s
1 .894 .882 r
.05597 .16187 m
.05597 .01542 L
.05724 .01542 L
.05724 .16187 L
F
.804 .522 .247 r
.05597 .16187 m
.05597 .01542 L
.05724 .01542 L
.05724 .16187 L
s
1 .894 .882 r
.05724 .16187 m
.05724 .01544 L
.05782 .01544 L
.05782 .16187 L
F
.804 .522 .247 r
.05724 .16187 m
.05724 .01544 L
.05782 .01544 L
.05782 .16187 L
s
1 .894 .882 r
.05782 .16187 m
.05782 .01548 L
.05911 .01548 L
.05911 .16187 L
F
.804 .522 .247 r
.05782 .16187 m
.05782 .01548 L
.05911 .01548 L
.05911 .16187 L
s
1 .894 .882 r
.05911 .16187 m
.05911 .01555 L
.06038 .01555 L
.06038 .16187 L
F
.804 .522 .247 r
.05911 .16187 m
.05911 .01555 L
.06038 .01555 L
.06038 .16187 L
s
1 .894 .882 r
.06038 .16187 m
.06038 .01559 L
.06109 .01559 L
.06109 .16187 L
F
.804 .522 .247 r
.06038 .16187 m
.06038 .01559 L
.06109 .01559 L
.06109 .16187 L
s
1 .894 .882 r
.06109 .16187 m
.06109 .01564 L
.06162 .01564 L
.06162 .16187 L
F
.804 .522 .247 r
.06109 .16187 m
.06109 .01564 L
.06162 .01564 L
.06162 .16187 L
s
1 .894 .882 r
.06162 .16187 m
.06162 .01571 L
.06291 .01571 L
.06291 .16187 L
F
.804 .522 .247 r
.06162 .16187 m
.06162 .01571 L
.06291 .01571 L
.06291 .16187 L
s
1 .894 .882 r
.06291 .16187 m
.06291 .01574 L
.06387 .01574 L
.06387 .16187 L
F
.804 .522 .247 r
.06291 .16187 m
.06291 .01574 L
.06387 .01574 L
.06387 .16187 L
s
1 .894 .882 r
.06387 .16187 m
.06387 .01581 L
.06519 .01581 L
.06519 .16187 L
F
.804 .522 .247 r
.06387 .16187 m
.06387 .01581 L
.06519 .01581 L
.06519 .16187 L
s
1 .894 .882 r
.06519 .16187 m
.06519 .01588 L
.06645 .01588 L
.06645 .16187 L
F
.804 .522 .247 r
.06519 .16187 m
.06519 .01588 L
.06645 .01588 L
.06645 .16187 L
s
1 .894 .882 r
.06645 .16187 m
.06645 .01593 L
.06716 .01593 L
.06716 .16187 L
F
.804 .522 .247 r
.06645 .16187 m
.06645 .01593 L
.06716 .01593 L
.06716 .16187 L
s
1 .894 .882 r
.06716 .16187 m
.06716 .01598 L
.06827 .01598 L
.06827 .16187 L
F
.804 .522 .247 r
.06716 .16187 m
.06716 .01598 L
.06827 .01598 L
.06827 .16187 L
s
1 .894 .882 r
.06827 .16187 m
.06827 .01601 L
.06888 .01601 L
.06888 .16187 L
F
.804 .522 .247 r
.06827 .16187 m
.06827 .01601 L
.06888 .01601 L
.06888 .16187 L
s
1 .894 .882 r
.06888 .16187 m
.06888 .01606 L
.0697 .01606 L
.0697 .16187 L
F
.804 .522 .247 r
.06888 .16187 m
.06888 .01606 L
.0697 .01606 L
.0697 .16187 L
s
1 .894 .882 r
.0697 .16187 m
.0697 .01609 L
.07017 .01609 L
.07017 .16187 L
F
.804 .522 .247 r
.0697 .16187 m
.0697 .01609 L
.07017 .01609 L
.07017 .16187 L
s
1 .894 .882 r
.07017 .16187 m
.07017 .01613 L
.07067 .01613 L
.07067 .16187 L
F
.804 .522 .247 r
.07017 .16187 m
.07017 .01613 L
.07067 .01613 L
.07067 .16187 L
s
1 .894 .882 r
.07067 .16187 m
.07067 .01615 L
.07132 .01615 L
.07132 .16187 L
F
.804 .522 .247 r
.07067 .16187 m
.07067 .01615 L
.07132 .01615 L
.07132 .16187 L
s
1 .894 .882 r
.07132 .16187 m
.07132 .01619 L
.07178 .01619 L
.07178 .16187 L
F
.804 .522 .247 r
.07132 .16187 m
.07132 .01619 L
.07178 .01619 L
.07178 .16187 L
s
1 .894 .882 r
.07178 .16187 m
.07178 .01622 L
.07226 .01622 L
.07226 .16187 L
F
.804 .522 .247 r
.07178 .16187 m
.07178 .01622 L
.07226 .01622 L
.07226 .16187 L
s
1 .894 .882 r
.07226 .16187 m
.07226 .01627 L
.07274 .01627 L
.07274 .16187 L
F
.804 .522 .247 r
.07226 .16187 m
.07226 .01627 L
.07274 .01627 L
.07274 .16187 L
s
1 .894 .882 r
.07274 .16187 m
.07274 .01629 L
.07403 .01629 L
.07403 .16187 L
F
.804 .522 .247 r
.07274 .16187 m
.07274 .01629 L
.07403 .01629 L
.07403 .16187 L
s
1 .894 .882 r
.07403 .16187 m
.07403 .0164 L
.07491 .0164 L
.07491 .16187 L
F
.804 .522 .247 r
.07403 .16187 m
.07403 .0164 L
.07491 .0164 L
.07491 .16187 L
s
1 .894 .882 r
.07491 .16187 m
.07491 .01644 L
.0756 .01644 L
.0756 .16187 L
F
.804 .522 .247 r
.07491 .16187 m
.07491 .01644 L
.0756 .01644 L
.0756 .16187 L
s
1 .894 .882 r
.0756 .16187 m
.0756 .0165 L
.07654 .0165 L
.07654 .16187 L
F
.804 .522 .247 r
.0756 .16187 m
.0756 .0165 L
.07654 .0165 L
.07654 .16187 L
s
1 .894 .882 r
.07654 .16187 m
.07654 .01654 L
.07696 .01654 L
.07696 .16187 L
F
.804 .522 .247 r
.07654 .16187 m
.07654 .01654 L
.07696 .01654 L
.07696 .16187 L
s
1 .894 .882 r
.07696 .16187 m
.07696 .01659 L
.07768 .01659 L
.07768 .16187 L
F
.804 .522 .247 r
.07696 .16187 m
.07696 .01659 L
.07768 .01659 L
.07768 .16187 L
s
1 .894 .882 r
.07768 .16187 m
.07768 .01662 L
.07844 .01662 L
.07844 .16187 L
F
.804 .522 .247 r
.07768 .16187 m
.07768 .01662 L
.07844 .01662 L
.07844 .16187 L
s
1 .894 .882 r
.07844 .16187 m
.07844 .01667 L
.07947 .01667 L
.07947 .16187 L
F
.804 .522 .247 r
.07844 .16187 m
.07844 .01667 L
.07947 .01667 L
.07947 .16187 L
s
1 .894 .882 r
.07947 .16187 m
.07947 .01677 L
.08052 .01677 L
.08052 .16187 L
F
.804 .522 .247 r
.07947 .16187 m
.07947 .01677 L
.08052 .01677 L
.08052 .16187 L
s
1 .894 .882 r
.08052 .16187 m
.08052 .01684 L
.08112 .01684 L
.08112 .16187 L
F
.804 .522 .247 r
.08052 .16187 m
.08052 .01684 L
.08112 .01684 L
.08112 .16187 L
s
1 .894 .882 r
.08112 .16187 m
.08112 .01687 L
.08195 .01687 L
.08195 .16187 L
F
.804 .522 .247 r
.08112 .16187 m
.08112 .01687 L
.08195 .01687 L
.08195 .16187 L
s
1 .894 .882 r
.08195 .16187 m
.08195 .01693 L
.08242 .01693 L
.08242 .16187 L
F
.804 .522 .247 r
.08195 .16187 m
.08195 .01693 L
.08242 .01693 L
.08242 .16187 L
s
1 .894 .882 r
.08242 .16187 m
.08242 .01701 L
.08351 .01701 L
.08351 .16187 L
F
.804 .522 .247 r
.08242 .16187 m
.08242 .01701 L
.08351 .01701 L
.08351 .16187 L
s
1 .894 .882 r
.08351 .16187 m
.08351 .01708 L
.0842 .01708 L
.0842 .16187 L
F
.804 .522 .247 r
.08351 .16187 m
.08351 .01708 L
.0842 .01708 L
.0842 .16187 L
s
1 .894 .882 r
.0842 .16187 m
.0842 .01711 L
.08473 .01711 L
.08473 .16187 L
F
.804 .522 .247 r
.0842 .16187 m
.0842 .01711 L
.08473 .01711 L
.08473 .16187 L
s
1 .894 .882 r
.08473 .16187 m
.08473 .01718 L
.08545 .01718 L
.08545 .16187 L
F
.804 .522 .247 r
.08473 .16187 m
.08473 .01718 L
.08545 .01718 L
.08545 .16187 L
s
1 .894 .882 r
.08545 .16187 m
.08545 .01722 L
.08633 .01722 L
.08633 .16187 L
F
.804 .522 .247 r
.08545 .16187 m
.08545 .01722 L
.08633 .01722 L
.08633 .16187 L
s
1 .894 .882 r
.08633 .16187 m
.08633 .0173 L
.08756 .0173 L
.08756 .16187 L
F
.804 .522 .247 r
.08633 .16187 m
.08633 .0173 L
.08756 .0173 L
.08756 .16187 L
s
1 .894 .882 r
.08756 .16187 m
.08756 .01737 L
.08802 .01737 L
.08802 .16187 L
F
.804 .522 .247 r
.08756 .16187 m
.08756 .01737 L
.08802 .01737 L
.08802 .16187 L
s
1 .894 .882 r
.08802 .16187 m
.08802 .0174 L
.08865 .0174 L
.08865 .16187 L
F
.804 .522 .247 r
.08802 .16187 m
.08802 .0174 L
.08865 .0174 L
.08865 .16187 L
s
1 .894 .882 r
.08865 .16187 m
.08865 .01746 L
.08928 .01746 L
.08928 .16187 L
F
.804 .522 .247 r
.08865 .16187 m
.08865 .01746 L
.08928 .01746 L
.08928 .16187 L
s
1 .894 .882 r
.08928 .16187 m
.08928 .0175 L
.09046 .0175 L
.09046 .16187 L
F
.804 .522 .247 r
.08928 .16187 m
.08928 .0175 L
.09046 .0175 L
.09046 .16187 L
s
1 .894 .882 r
.09046 .16187 m
.09046 .01761 L
.0918 .01761 L
.0918 .16187 L
F
.804 .522 .247 r
.09046 .16187 m
.09046 .01761 L
.0918 .01761 L
.0918 .16187 L
s
1 .894 .882 r
.0918 .16187 m
.0918 .01773 L
.09236 .01773 L
.09236 .16187 L
F
.804 .522 .247 r
.0918 .16187 m
.0918 .01773 L
.09236 .01773 L
.09236 .16187 L
s
1 .894 .882 r
.09236 .16187 m
.09236 .01777 L
.09306 .01777 L
.09306 .16187 L
F
.804 .522 .247 r
.09236 .16187 m
.09236 .01777 L
.09306 .01777 L
.09306 .16187 L
s
1 .894 .882 r
.09306 .16187 m
.09306 .01784 L
.09376 .01784 L
.09376 .16187 L
F
.804 .522 .247 r
.09306 .16187 m
.09306 .01784 L
.09376 .01784 L
.09376 .16187 L
s
1 .894 .882 r
.09376 .16187 m
.09376 .01793 L
.09481 .01793 L
.09481 .16187 L
F
.804 .522 .247 r
.09376 .16187 m
.09376 .01793 L
.09481 .01793 L
.09481 .16187 L
s
1 .894 .882 r
.09481 .16187 m
.09481 .01803 L
.09578 .01803 L
.09578 .16187 L
F
.804 .522 .247 r
.09481 .16187 m
.09481 .01803 L
.09578 .01803 L
.09578 .16187 L
s
1 .894 .882 r
.09578 .16187 m
.09578 .0181 L
.09647 .0181 L
.09647 .16187 L
F
.804 .522 .247 r
.09578 .16187 m
.09578 .0181 L
.09647 .0181 L
.09647 .16187 L
s
1 .894 .882 r
.09647 .16187 m
.09647 .01819 L
.09781 .01819 L
.09781 .16187 L
F
.804 .522 .247 r
.09647 .16187 m
.09647 .01819 L
.09781 .01819 L
.09781 .16187 L
s
1 .894 .882 r
.09781 .16187 m
.09781 .01833 L
.0985 .01833 L
.0985 .16187 L
F
.804 .522 .247 r
.09781 .16187 m
.09781 .01833 L
.0985 .01833 L
.0985 .16187 L
s
1 .894 .882 r
.0985 .16187 m
.0985 .01837 L
.0998 .01837 L
.0998 .16187 L
F
.804 .522 .247 r
.0985 .16187 m
.0985 .01837 L
.0998 .01837 L
.0998 .16187 L
s
1 .894 .882 r
.0998 .16187 m
.0998 .01853 L
.10079 .01853 L
.10079 .16187 L
F
.804 .522 .247 r
.0998 .16187 m
.0998 .01853 L
.10079 .01853 L
.10079 .16187 L
s
1 .894 .882 r
.10079 .16187 m
.10079 .01862 L
.10194 .01862 L
.10194 .16187 L
F
.804 .522 .247 r
.10079 .16187 m
.10079 .01862 L
.10194 .01862 L
.10194 .16187 L
s
1 .894 .882 r
.10194 .16187 m
.10194 .01875 L
.10316 .01875 L
.10316 .16187 L
F
.804 .522 .247 r
.10194 .16187 m
.10194 .01875 L
.10316 .01875 L
.10316 .16187 L
s
1 .894 .882 r
.10316 .16187 m
.10316 .01889 L
.10439 .01889 L
.10439 .16187 L
F
.804 .522 .247 r
.10316 .16187 m
.10316 .01889 L
.10439 .01889 L
.10439 .16187 L
s
1 .894 .882 r
.10439 .16187 m
.10439 .01906 L
.10564 .01906 L
.10564 .16187 L
F
.804 .522 .247 r
.10439 .16187 m
.10439 .01906 L
.10564 .01906 L
.10564 .16187 L
s
1 .894 .882 r
.10564 .16187 m
.10564 .01911 L
.10652 .01911 L
.10652 .16187 L
F
.804 .522 .247 r
.10564 .16187 m
.10564 .01911 L
.10652 .01911 L
.10652 .16187 L
s
1 .894 .882 r
.10652 .16187 m
.10652 .01927 L
.10762 .01927 L
.10762 .16187 L
F
.804 .522 .247 r
.10652 .16187 m
.10652 .01927 L
.10762 .01927 L
.10762 .16187 L
s
1 .894 .882 r
.10762 .16187 m
.10762 .01935 L
.10853 .01935 L
.10853 .16187 L
F
.804 .522 .247 r
.10762 .16187 m
.10762 .01935 L
.10853 .01935 L
.10853 .16187 L
s
1 .894 .882 r
.10853 .16187 m
.10853 .01941 L
.10931 .01941 L
.10931 .16187 L
F
.804 .522 .247 r
.10853 .16187 m
.10853 .01941 L
.10931 .01941 L
.10931 .16187 L
s
1 .894 .882 r
.10931 .16187 m
.10931 .01946 L
.11031 .01946 L
.11031 .16187 L
F
.804 .522 .247 r
.10931 .16187 m
.10931 .01946 L
.11031 .01946 L
.11031 .16187 L
s
1 .894 .882 r
.11031 .16187 m
.11031 .01964 L
.11136 .01964 L
.11136 .16187 L
F
.804 .522 .247 r
.11031 .16187 m
.11031 .01964 L
.11136 .01964 L
.11136 .16187 L
s
1 .894 .882 r
.11136 .16187 m
.11136 .01974 L
.11204 .01974 L
.11204 .16187 L
F
.804 .522 .247 r
.11136 .16187 m
.11136 .01974 L
.11204 .01974 L
.11204 .16187 L
s
1 .894 .882 r
.11204 .16187 m
.11204 .01977 L
.11259 .01977 L
.11259 .16187 L
F
.804 .522 .247 r
.11204 .16187 m
.11204 .01977 L
.11259 .01977 L
.11259 .16187 L
s
1 .894 .882 r
.11259 .16187 m
.11259 .01996 L
.11377 .01996 L
.11377 .16187 L
F
.804 .522 .247 r
.11259 .16187 m
.11259 .01996 L
.11377 .01996 L
.11377 .16187 L
s
1 .894 .882 r
.11377 .16187 m
.11377 .02003 L
.11484 .02003 L
.11484 .16187 L
F
.804 .522 .247 r
.11377 .16187 m
.11377 .02003 L
.11484 .02003 L
.11484 .16187 L
s
1 .894 .882 r
.11484 .16187 m
.11484 .02012 L
.11537 .02012 L
.11537 .16187 L
F
.804 .522 .247 r
.11484 .16187 m
.11484 .02012 L
.11537 .02012 L
.11537 .16187 L
s
1 .894 .882 r
.11537 .16187 m
.11537 .02016 L
.11657 .02016 L
.11657 .16187 L
F
.804 .522 .247 r
.11537 .16187 m
.11537 .02016 L
.11657 .02016 L
.11657 .16187 L
s
1 .894 .882 r
.11657 .16187 m
.11657 .02038 L
.11746 .02038 L
.11746 .16187 L
F
.804 .522 .247 r
.11657 .16187 m
.11657 .02038 L
.11746 .02038 L
.11746 .16187 L
s
1 .894 .882 r
.11746 .16187 m
.11746 .02041 L
.11789 .02041 L
.11789 .16187 L
F
.804 .522 .247 r
.11746 .16187 m
.11746 .02041 L
.11789 .02041 L
.11789 .16187 L
s
1 .894 .882 r
.11789 .16187 m
.11789 .02056 L
.1188 .02056 L
.1188 .16187 L
F
.804 .522 .247 r
.11789 .16187 m
.11789 .02056 L
.1188 .02056 L
.1188 .16187 L
s
1 .894 .882 r
.1188 .16187 m
.1188 .02065 L
.11972 .02065 L
.11972 .16187 L
F
.804 .522 .247 r
.1188 .16187 m
.1188 .02065 L
.11972 .02065 L
.11972 .16187 L
s
1 .894 .882 r
.11972 .16187 m
.11972 .02073 L
.12063 .02073 L
.12063 .16187 L
F
.804 .522 .247 r
.11972 .16187 m
.11972 .02073 L
.12063 .02073 L
.12063 .16187 L
s
1 .894 .882 r
.12063 .16187 m
.12063 .02082 L
.12171 .02082 L
.12171 .16187 L
F
.804 .522 .247 r
.12063 .16187 m
.12063 .02082 L
.12171 .02082 L
.12171 .16187 L
s
1 .894 .882 r
.12171 .16187 m
.12171 .02101 L
.12268 .02101 L
.12268 .16187 L
F
.804 .522 .247 r
.12171 .16187 m
.12171 .02101 L
.12268 .02101 L
.12268 .16187 L
s
1 .894 .882 r
.12268 .16187 m
.12268 .02121 L
.12397 .02121 L
.12397 .16187 L
F
.804 .522 .247 r
.12268 .16187 m
.12268 .02121 L
.12397 .02121 L
.12397 .16187 L
s
1 .894 .882 r
.12397 .16187 m
.12397 .02135 L
.12507 .02135 L
.12507 .16187 L
F
.804 .522 .247 r
.12397 .16187 m
.12397 .02135 L
.12507 .02135 L
.12507 .16187 L
s
1 .894 .882 r
.12507 .16187 m
.12507 .02147 L
.12629 .02147 L
.12629 .16187 L
F
.804 .522 .247 r
.12507 .16187 m
.12507 .02147 L
.12629 .02147 L
.12629 .16187 L
s
1 .894 .882 r
.12629 .16187 m
.12629 .02166 L
.12739 .02166 L
.12739 .16187 L
F
.804 .522 .247 r
.12629 .16187 m
.12629 .02166 L
.12739 .02166 L
.12739 .16187 L
s
1 .894 .882 r
.12739 .16187 m
.12739 .02173 L
.12783 .02173 L
.12783 .16187 L
F
.804 .522 .247 r
.12739 .16187 m
.12739 .02173 L
.12783 .02173 L
.12783 .16187 L
s
1 .894 .882 r
.12783 .16187 m
.12783 .02177 L
.12847 .02177 L
.12847 .16187 L
F
.804 .522 .247 r
.12783 .16187 m
.12783 .02177 L
.12847 .02177 L
.12847 .16187 L
s
1 .894 .882 r
.12847 .16187 m
.12847 .02187 L
.12899 .02187 L
.12899 .16187 L
F
.804 .522 .247 r
.12847 .16187 m
.12847 .02187 L
.12899 .02187 L
.12899 .16187 L
s
1 .894 .882 r
.12899 .16187 m
.12899 .02191 L
.12958 .02191 L
.12958 .16187 L
F
.804 .522 .247 r
.12899 .16187 m
.12899 .02191 L
.12958 .02191 L
.12958 .16187 L
s
1 .894 .882 r
.12958 .16187 m
.12958 .02205 L
.1306 .02205 L
.1306 .16187 L
F
.804 .522 .247 r
.12958 .16187 m
.12958 .02205 L
.1306 .02205 L
.1306 .16187 L
s
1 .894 .882 r
.1306 .16187 m
.1306 .02216 L
.13159 .02216 L
.13159 .16187 L
F
.804 .522 .247 r
.1306 .16187 m
.1306 .02216 L
.13159 .02216 L
.13159 .16187 L
s
1 .894 .882 r
.13159 .16187 m
.13159 .02226 L
.13242 .02226 L
.13242 .16187 L
F
.804 .522 .247 r
.13159 .16187 m
.13159 .02226 L
.13242 .02226 L
.13242 .16187 L
s
1 .894 .882 r
.13242 .16187 m
.13242 .02246 L
.13369 .02246 L
.13369 .16187 L
F
.804 .522 .247 r
.13242 .16187 m
.13242 .02246 L
.13369 .02246 L
.13369 .16187 L
s
1 .894 .882 r
.13369 .16187 m
.13369 .02261 L
.13457 .02261 L
.13457 .16187 L
F
.804 .522 .247 r
.13369 .16187 m
.13369 .02261 L
.13457 .02261 L
.13457 .16187 L
s
1 .894 .882 r
.13457 .16187 m
.13457 .02274 L
.13573 .02274 L
.13573 .16187 L
F
.804 .522 .247 r
.13457 .16187 m
.13457 .02274 L
.13573 .02274 L
.13573 .16187 L
s
1 .894 .882 r
.13573 .16187 m
.13573 .02293 L
.13685 .02293 L
.13685 .16187 L
F
.804 .522 .247 r
.13573 .16187 m
.13573 .02293 L
.13685 .02293 L
.13685 .16187 L
s
1 .894 .882 r
.13685 .16187 m
.13685 .02302 L
.13799 .02302 L
.13799 .16187 L
F
.804 .522 .247 r
.13685 .16187 m
.13685 .02302 L
.13799 .02302 L
.13799 .16187 L
s
1 .894 .882 r
.13799 .16187 m
.13799 .02324 L
.13902 .02324 L
.13902 .16187 L
F
.804 .522 .247 r
.13799 .16187 m
.13799 .02324 L
.13902 .02324 L
.13902 .16187 L
s
1 .894 .882 r
.13902 .16187 m
.13902 .02339 L
.13969 .02339 L
.13969 .16187 L
F
.804 .522 .247 r
.13902 .16187 m
.13902 .02339 L
.13969 .02339 L
.13969 .16187 L
s
1 .894 .882 r
.13969 .16187 m
.13969 .0235 L
.1408 .0235 L
.1408 .16187 L
F
.804 .522 .247 r
.13969 .16187 m
.13969 .0235 L
.1408 .0235 L
.1408 .16187 L
s
1 .894 .882 r
.1408 .16187 m
.1408 .02362 L
.14143 .02362 L
.14143 .16187 L
F
.804 .522 .247 r
.1408 .16187 m
.1408 .02362 L
.14143 .02362 L
.14143 .16187 L
s
1 .894 .882 r
.14143 .16187 m
.14143 .02376 L
.14195 .02376 L
.14195 .16187 L
F
.804 .522 .247 r
.14143 .16187 m
.14143 .02376 L
.14195 .02376 L
.14195 .16187 L
s
1 .894 .882 r
.14195 .16187 m
.14195 .0238 L
.14308 .0238 L
.14308 .16187 L
F
.804 .522 .247 r
.14195 .16187 m
.14195 .0238 L
.14308 .0238 L
.14308 .16187 L
s
1 .894 .882 r
.14308 .16187 m
.14308 .02396 L
.1435 .02396 L
.1435 .16187 L
F
.804 .522 .247 r
.14308 .16187 m
.14308 .02396 L
.1435 .02396 L
.1435 .16187 L
s
1 .894 .882 r
.1435 .16187 m
.1435 .02411 L
.14452 .02411 L
.14452 .16187 L
F
.804 .522 .247 r
.1435 .16187 m
.1435 .02411 L
.14452 .02411 L
.14452 .16187 L
s
1 .894 .882 r
.14452 .16187 m
.14452 .02425 L
.14511 .02425 L
.14511 .16187 L
F
.804 .522 .247 r
.14452 .16187 m
.14452 .02425 L
.14511 .02425 L
.14511 .16187 L
s
1 .894 .882 r
.14511 .16187 m
.14511 .02428 L
.14553 .02428 L
.14553 .16187 L
F
.804 .522 .247 r
.14511 .16187 m
.14511 .02428 L
.14553 .02428 L
.14553 .16187 L
s
1 .894 .882 r
.14553 .16187 m
.14553 .02438 L
.14609 .02438 L
.14609 .16187 L
F
.804 .522 .247 r
.14553 .16187 m
.14553 .02438 L
.14609 .02438 L
.14609 .16187 L
s
1 .894 .882 r
.14609 .16187 m
.14609 .02457 L
.14738 .02457 L
.14738 .16187 L
F
.804 .522 .247 r
.14609 .16187 m
.14609 .02457 L
.14738 .02457 L
.14738 .16187 L
s
1 .894 .882 r
.14738 .16187 m
.14738 .0247 L
.14792 .0247 L
.14792 .16187 L
F
.804 .522 .247 r
.14738 .16187 m
.14738 .0247 L
.14792 .0247 L
.14792 .16187 L
s
1 .894 .882 r
.14792 .16187 m
.14792 .02488 L
.14907 .02488 L
.14907 .16187 L
F
.804 .522 .247 r
.14792 .16187 m
.14792 .02488 L
.14907 .02488 L
.14907 .16187 L
s
1 .894 .882 r
.14907 .16187 m
.14907 .02496 L
.14951 .02496 L
.14951 .16187 L
F
.804 .522 .247 r
.14907 .16187 m
.14907 .02496 L
.14951 .02496 L
.14951 .16187 L
s
1 .894 .882 r
.14951 .16187 m
.14951 .02508 L
.15061 .02508 L
.15061 .16187 L
F
.804 .522 .247 r
.14951 .16187 m
.14951 .02508 L
.15061 .02508 L
.15061 .16187 L
s
1 .894 .882 r
.15061 .16187 m
.15061 .0252 L
.15149 .0252 L
.15149 .16187 L
F
.804 .522 .247 r
.15061 .16187 m
.15061 .0252 L
.15149 .0252 L
.15149 .16187 L
s
1 .894 .882 r
.15149 .16187 m
.15149 .02535 L
.15205 .02535 L
.15205 .16187 L
F
.804 .522 .247 r
.15149 .16187 m
.15149 .02535 L
.15205 .02535 L
.15205 .16187 L
s
1 .894 .882 r
.15205 .16187 m
.15205 .02553 L
.15302 .02553 L
.15302 .16187 L
F
.804 .522 .247 r
.15205 .16187 m
.15205 .02553 L
.15302 .02553 L
.15302 .16187 L
s
1 .894 .882 r
.15302 .16187 m
.15302 .02557 L
.15421 .02557 L
.15421 .16187 L
F
.804 .522 .247 r
.15302 .16187 m
.15302 .02557 L
.15421 .02557 L
.15421 .16187 L
s
1 .894 .882 r
.15421 .16187 m
.15421 .02597 L
.15556 .02597 L
.15556 .16187 L
F
.804 .522 .247 r
.15421 .16187 m
.15421 .02597 L
.15556 .02597 L
.15556 .16187 L
s
1 .894 .882 r
.15556 .16187 m
.15556 .02601 L
.15632 .02601 L
.15632 .16187 L
F
.804 .522 .247 r
.15556 .16187 m
.15556 .02601 L
.15632 .02601 L
.15632 .16187 L
s
1 .894 .882 r
.15632 .16187 m
.15632 .02617 L
.15752 .02617 L
.15752 .16187 L
F
.804 .522 .247 r
.15632 .16187 m
.15632 .02617 L
.15752 .02617 L
.15752 .16187 L
s
1 .894 .882 r
.15752 .16187 m
.15752 .02632 L
.15798 .02632 L
.15798 .16187 L
F
.804 .522 .247 r
.15752 .16187 m
.15752 .02632 L
.15798 .02632 L
.15798 .16187 L
s
1 .894 .882 r
.15798 .16187 m
.15798 .02646 L
.15871 .02646 L
.15871 .16187 L
F
.804 .522 .247 r
.15798 .16187 m
.15798 .02646 L
.15871 .02646 L
.15871 .16187 L
s
1 .894 .882 r
.15871 .16187 m
.15871 .02658 L
.1592 .02658 L
.1592 .16187 L
F
.804 .522 .247 r
.15871 .16187 m
.15871 .02658 L
.1592 .02658 L
.1592 .16187 L
s
1 .894 .882 r
.1592 .16187 m
.1592 .02669 L
.1597 .02669 L
.1597 .16187 L
F
.804 .522 .247 r
.1592 .16187 m
.1592 .02669 L
.1597 .02669 L
.1597 .16187 L
s
1 .894 .882 r
.1597 .16187 m
.1597 .02687 L
.16088 .02687 L
.16088 .16187 L
F
.804 .522 .247 r
.1597 .16187 m
.1597 .02687 L
.16088 .02687 L
.16088 .16187 L
s
1 .894 .882 r
.16088 .16187 m
.16088 .02699 L
.1615 .02699 L
.1615 .16187 L
F
.804 .522 .247 r
.16088 .16187 m
.16088 .02699 L
.1615 .02699 L
.1615 .16187 L
s
1 .894 .882 r
.1615 .16187 m
.1615 .02708 L
.16222 .02708 L
.16222 .16187 L
F
.804 .522 .247 r
.1615 .16187 m
.1615 .02708 L
.16222 .02708 L
.16222 .16187 L
s
1 .894 .882 r
.16222 .16187 m
.16222 .02721 L
.16271 .02721 L
.16271 .16187 L
F
.804 .522 .247 r
.16222 .16187 m
.16222 .02721 L
.16271 .02721 L
.16271 .16187 L
s
1 .894 .882 r
.16271 .16187 m
.16271 .02725 L
.16327 .02725 L
.16327 .16187 L
F
.804 .522 .247 r
.16271 .16187 m
.16271 .02725 L
.16327 .02725 L
.16327 .16187 L
s
1 .894 .882 r
.16327 .16187 m
.16327 .0274 L
.16371 .0274 L
.16371 .16187 L
F
.804 .522 .247 r
.16327 .16187 m
.16327 .0274 L
.16371 .0274 L
.16371 .16187 L
s
1 .894 .882 r
.16371 .16187 m
.16371 .02744 L
.1644 .02744 L
.1644 .16187 L
F
.804 .522 .247 r
.16371 .16187 m
.16371 .02744 L
.1644 .02744 L
.1644 .16187 L
s
1 .894 .882 r
.1644 .16187 m
.1644 .02756 L
.16569 .02756 L
.16569 .16187 L
F
.804 .522 .247 r
.1644 .16187 m
.1644 .02756 L
.16569 .02756 L
.16569 .16187 L
s
1 .894 .882 r
.16569 .16187 m
.16569 .02783 L
.16632 .02783 L
.16632 .16187 L
F
.804 .522 .247 r
.16569 .16187 m
.16569 .02783 L
.16632 .02783 L
.16632 .16187 L
s
1 .894 .882 r
.16632 .16187 m
.16632 .02811 L
.16757 .02811 L
.16757 .16187 L
F
.804 .522 .247 r
.16632 .16187 m
.16632 .02811 L
.16757 .02811 L
.16757 .16187 L
s
1 .894 .882 r
.16757 .16187 m
.16757 .02818 L
.16847 .02818 L
.16847 .16187 L
F
.804 .522 .247 r
.16757 .16187 m
.16757 .02818 L
.16847 .02818 L
.16847 .16187 L
s
1 .894 .882 r
.16847 .16187 m
.16847 .02832 L
.16973 .02832 L
.16973 .16187 L
F
.804 .522 .247 r
.16847 .16187 m
.16847 .02832 L
.16973 .02832 L
.16973 .16187 L
s
1 .894 .882 r
.16973 .16187 m
.16973 .02868 L
.17061 .02868 L
.17061 .16187 L
F
.804 .522 .247 r
.16973 .16187 m
.16973 .02868 L
.17061 .02868 L
.17061 .16187 L
s
1 .894 .882 r
.17061 .16187 m
.17061 .02878 L
.17139 .02878 L
.17139 .16187 L
F
.804 .522 .247 r
.17061 .16187 m
.17061 .02878 L
.17139 .02878 L
.17139 .16187 L
s
1 .894 .882 r
.17139 .16187 m
.17139 .02895 L
.17214 .02895 L
.17214 .16187 L
F
.804 .522 .247 r
.17139 .16187 m
.17139 .02895 L
.17214 .02895 L
.17214 .16187 L
s
1 .894 .882 r
.17214 .16187 m
.17214 .02903 L
.17283 .02903 L
.17283 .16187 L
F
.804 .522 .247 r
.17214 .16187 m
.17214 .02903 L
.17283 .02903 L
.17283 .16187 L
s
1 .894 .882 r
.17283 .16187 m
.17283 .02928 L
.17387 .02928 L
.17387 .16187 L
F
.804 .522 .247 r
.17283 .16187 m
.17283 .02928 L
.17387 .02928 L
.17387 .16187 L
s
1 .894 .882 r
.17387 .16187 m
.17387 .02942 L
.17466 .02942 L
.17466 .16187 L
F
.804 .522 .247 r
.17387 .16187 m
.17387 .02942 L
.17466 .02942 L
.17466 .16187 L
s
1 .894 .882 r
.17466 .16187 m
.17466 .0296 L
.176 .0296 L
.176 .16187 L
F
.804 .522 .247 r
.17466 .16187 m
.17466 .0296 L
.176 .0296 L
.176 .16187 L
s
1 .894 .882 r
.176 .16187 m
.176 .0299 L
.17685 .0299 L
.17685 .16187 L
F
.804 .522 .247 r
.176 .16187 m
.176 .0299 L
.17685 .0299 L
.17685 .16187 L
s
1 .894 .882 r
.17685 .16187 m
.17685 .03006 L
.17783 .03006 L
.17783 .16187 L
F
.804 .522 .247 r
.17685 .16187 m
.17685 .03006 L
.17783 .03006 L
.17783 .16187 L
s
1 .894 .882 r
.17783 .16187 m
.17783 .03012 L
.1783 .03012 L
.1783 .16187 L
F
.804 .522 .247 r
.17783 .16187 m
.17783 .03012 L
.1783 .03012 L
.1783 .16187 L
s
1 .894 .882 r
.1783 .16187 m
.1783 .0304 L
.17957 .0304 L
.17957 .16187 L
F
.804 .522 .247 r
.1783 .16187 m
.1783 .0304 L
.17957 .0304 L
.17957 .16187 L
s
1 .894 .882 r
.17957 .16187 m
.17957 .03046 L
.18032 .03046 L
.18032 .16187 L
F
.804 .522 .247 r
.17957 .16187 m
.17957 .03046 L
.18032 .03046 L
.18032 .16187 L
s
1 .894 .882 r
.18032 .16187 m
.18032 .03083 L
.18147 .03083 L
.18147 .16187 L
F
.804 .522 .247 r
.18032 .16187 m
.18032 .03083 L
.18147 .03083 L
.18147 .16187 L
s
1 .894 .882 r
.18147 .16187 m
.18147 .03095 L
.18268 .03095 L
.18268 .16187 L
F
.804 .522 .247 r
.18147 .16187 m
.18147 .03095 L
.18268 .03095 L
.18268 .16187 L
s
1 .894 .882 r
.18268 .16187 m
.18268 .03115 L
.18364 .03115 L
.18364 .16187 L
F
.804 .522 .247 r
.18268 .16187 m
.18268 .03115 L
.18364 .03115 L
.18364 .16187 L
s
1 .894 .882 r
.18364 .16187 m
.18364 .03134 L
.1843 .03134 L
.1843 .16187 L
F
.804 .522 .247 r
.18364 .16187 m
.18364 .03134 L
.1843 .03134 L
.1843 .16187 L
s
1 .894 .882 r
.1843 .16187 m
.1843 .03159 L
.1853 .03159 L
.1853 .16187 L
F
.804 .522 .247 r
.1843 .16187 m
.1843 .03159 L
.1853 .03159 L
.1853 .16187 L
s
1 .894 .882 r
.1853 .16187 m
.1853 .03178 L
.18647 .03178 L
.18647 .16187 L
F
.804 .522 .247 r
.1853 .16187 m
.1853 .03178 L
.18647 .03178 L
.18647 .16187 L
s
1 .894 .882 r
.18647 .16187 m
.18647 .03189 L
.18715 .03189 L
.18715 .16187 L
F
.804 .522 .247 r
.18647 .16187 m
.18647 .03189 L
.18715 .03189 L
.18715 .16187 L
s
1 .894 .882 r
.18715 .16187 m
.18715 .03208 L
.18788 .03208 L
.18788 .16187 L
F
.804 .522 .247 r
.18715 .16187 m
.18715 .03208 L
.18788 .03208 L
.18788 .16187 L
s
1 .894 .882 r
.18788 .16187 m
.18788 .03223 L
.18866 .03223 L
.18866 .16187 L
F
.804 .522 .247 r
.18788 .16187 m
.18788 .03223 L
.18866 .03223 L
.18866 .16187 L
s
1 .894 .882 r
.18866 .16187 m
.18866 .03252 L
.18993 .03252 L
.18993 .16187 L
F
.804 .522 .247 r
.18866 .16187 m
.18866 .03252 L
.18993 .03252 L
.18993 .16187 L
s
1 .894 .882 r
.18993 .16187 m
.18993 .03281 L
.19105 .03281 L
.19105 .16187 L
F
.804 .522 .247 r
.18993 .16187 m
.18993 .03281 L
.19105 .03281 L
.19105 .16187 L
s
1 .894 .882 r
.19105 .16187 m
.19105 .0329 L
.19189 .0329 L
.19189 .16187 L
F
.804 .522 .247 r
.19105 .16187 m
.19105 .0329 L
.19189 .0329 L
.19189 .16187 L
s
1 .894 .882 r
.19189 .16187 m
.19189 .03316 L
.19315 .03316 L
.19315 .16187 L
F
.804 .522 .247 r
.19189 .16187 m
.19189 .03316 L
.19315 .03316 L
.19315 .16187 L
s
1 .894 .882 r
.19315 .16187 m
.19315 .03334 L
.19403 .03334 L
.19403 .16187 L
F
.804 .522 .247 r
.19315 .16187 m
.19315 .03334 L
.19403 .03334 L
.19403 .16187 L
s
1 .894 .882 r
.19403 .16187 m
.19403 .03353 L
.19482 .03353 L
.19482 .16187 L
F
.804 .522 .247 r
.19403 .16187 m
.19403 .03353 L
.19482 .03353 L
.19482 .16187 L
s
1 .894 .882 r
.19482 .16187 m
.19482 .03381 L
.19537 .03381 L
.19537 .16187 L
F
.804 .522 .247 r
.19482 .16187 m
.19482 .03381 L
.19537 .03381 L
.19537 .16187 L
s
1 .894 .882 r
.19537 .16187 m
.19537 .03391 L
.19599 .03391 L
.19599 .16187 L
F
.804 .522 .247 r
.19537 .16187 m
.19537 .03391 L
.19599 .03391 L
.19599 .16187 L
s
1 .894 .882 r
.19599 .16187 m
.19599 .03401 L
.1965 .03401 L
.1965 .16187 L
F
.804 .522 .247 r
.19599 .16187 m
.19599 .03401 L
.1965 .03401 L
.1965 .16187 L
s
1 .894 .882 r
.1965 .16187 m
.1965 .03418 L
.1973 .03418 L
.1973 .16187 L
F
.804 .522 .247 r
.1965 .16187 m
.1965 .03418 L
.1973 .03418 L
.1973 .16187 L
s
1 .894 .882 r
.1973 .16187 m
.1973 .03448 L
.19835 .03448 L
.19835 .16187 L
F
.804 .522 .247 r
.1973 .16187 m
.1973 .03448 L
.19835 .03448 L
.19835 .16187 L
s
1 .894 .882 r
.19835 .16187 m
.19835 .03469 L
.19935 .03469 L
.19935 .16187 L
F
.804 .522 .247 r
.19835 .16187 m
.19835 .03469 L
.19935 .03469 L
.19935 .16187 L
s
1 .894 .882 r
.19935 .16187 m
.19935 .03474 L
.19979 .03474 L
.19979 .16187 L
F
.804 .522 .247 r
.19935 .16187 m
.19935 .03474 L
.19979 .03474 L
.19979 .16187 L
s
1 .894 .882 r
.19979 .16187 m
.19979 .03498 L
.20068 .03498 L
.20068 .16187 L
F
.804 .522 .247 r
.19979 .16187 m
.19979 .03498 L
.20068 .03498 L
.20068 .16187 L
s
1 .894 .882 r
.20068 .16187 m
.20068 .03517 L
.20139 .03517 L
.20139 .16187 L
F
.804 .522 .247 r
.20068 .16187 m
.20068 .03517 L
.20139 .03517 L
.20139 .16187 L
s
1 .894 .882 r
.20139 .16187 m
.20139 .03544 L
.20259 .03544 L
.20259 .16187 L
F
.804 .522 .247 r
.20139 .16187 m
.20139 .03544 L
.20259 .03544 L
.20259 .16187 L
s
1 .894 .882 r
.20259 .16187 m
.20259 .03558 L
.20318 .03558 L
.20318 .16187 L
F
.804 .522 .247 r
.20259 .16187 m
.20259 .03558 L
.20318 .03558 L
.20318 .16187 L
s
1 .894 .882 r
.20318 .16187 m
.20318 .03576 L
.20447 .03576 L
.20447 .16187 L
F
.804 .522 .247 r
.20318 .16187 m
.20318 .03576 L
.20447 .03576 L
.20447 .16187 L
s
1 .894 .882 r
.20447 .16187 m
.20447 .03596 L
.20491 .03596 L
.20491 .16187 L
F
.804 .522 .247 r
.20447 .16187 m
.20447 .03596 L
.20491 .03596 L
.20491 .16187 L
s
1 .894 .882 r
.20491 .16187 m
.20491 .03603 L
.20552 .03603 L
.20552 .16187 L
F
.804 .522 .247 r
.20491 .16187 m
.20491 .03603 L
.20552 .03603 L
.20552 .16187 L
s
1 .894 .882 r
.20552 .16187 m
.20552 .0362 L
.2063 .0362 L
.2063 .16187 L
F
.804 .522 .247 r
.20552 .16187 m
.20552 .0362 L
.2063 .0362 L
.2063 .16187 L
s
1 .894 .882 r
.2063 .16187 m
.2063 .03645 L
.20732 .03645 L
.20732 .16187 L
F
.804 .522 .247 r
.2063 .16187 m
.2063 .03645 L
.20732 .03645 L
.20732 .16187 L
s
1 .894 .882 r
.20732 .16187 m
.20732 .03664 L
.20839 .03664 L
.20839 .16187 L
F
.804 .522 .247 r
.20732 .16187 m
.20732 .03664 L
.20839 .03664 L
.20839 .16187 L
s
1 .894 .882 r
.20839 .16187 m
.20839 .03708 L
.20957 .03708 L
.20957 .16187 L
F
.804 .522 .247 r
.20839 .16187 m
.20839 .03708 L
.20957 .03708 L
.20957 .16187 L
s
1 .894 .882 r
.20957 .16187 m
.20957 .03725 L
.21043 .03725 L
.21043 .16187 L
F
.804 .522 .247 r
.20957 .16187 m
.20957 .03725 L
.21043 .03725 L
.21043 .16187 L
s
1 .894 .882 r
.21043 .16187 m
.21043 .03755 L
.21169 .03755 L
.21169 .16187 L
F
.804 .522 .247 r
.21043 .16187 m
.21043 .03755 L
.21169 .03755 L
.21169 .16187 L
s
1 .894 .882 r
.21169 .16187 m
.21169 .03764 L
.21233 .03764 L
.21233 .16187 L
F
.804 .522 .247 r
.21169 .16187 m
.21169 .03764 L
.21233 .03764 L
.21233 .16187 L
s
1 .894 .882 r
.21233 .16187 m
.21233 .03793 L
.21361 .03793 L
.21361 .16187 L
F
.804 .522 .247 r
.21233 .16187 m
.21233 .03793 L
.21361 .03793 L
.21361 .16187 L
s
1 .894 .882 r
.21361 .16187 m
.21361 .03829 L
.21494 .03829 L
.21494 .16187 L
F
.804 .522 .247 r
.21361 .16187 m
.21361 .03829 L
.21494 .03829 L
.21494 .16187 L
s
1 .894 .882 r
.21494 .16187 m
.21494 .03857 L
.21581 .03857 L
.21581 .16187 L
F
.804 .522 .247 r
.21494 .16187 m
.21494 .03857 L
.21581 .03857 L
.21581 .16187 L
s
1 .894 .882 r
.21581 .16187 m
.21581 .03866 L
.21631 .03866 L
.21631 .16187 L
F
.804 .522 .247 r
.21581 .16187 m
.21581 .03866 L
.21631 .03866 L
.21631 .16187 L
s
1 .894 .882 r
.21631 .16187 m
.21631 .03898 L
.21737 .03898 L
.21737 .16187 L
F
.804 .522 .247 r
.21631 .16187 m
.21631 .03898 L
.21737 .03898 L
.21737 .16187 L
s
1 .894 .882 r
.21737 .16187 m
.21737 .03907 L
.2186 .03907 L
.2186 .16187 L
F
.804 .522 .247 r
.21737 .16187 m
.21737 .03907 L
.2186 .03907 L
.2186 .16187 L
s
1 .894 .882 r
.2186 .16187 m
.2186 .03935 L
.21908 .03935 L
.21908 .16187 L
F
.804 .522 .247 r
.2186 .16187 m
.2186 .03935 L
.21908 .03935 L
.21908 .16187 L
s
1 .894 .882 r
.21908 .16187 m
.21908 .03949 L
.21989 .03949 L
.21989 .16187 L
F
.804 .522 .247 r
.21908 .16187 m
.21908 .03949 L
.21989 .03949 L
.21989 .16187 L
s
1 .894 .882 r
.21989 .16187 m
.21989 .03977 L
.22035 .03977 L
.22035 .16187 L
F
.804 .522 .247 r
.21989 .16187 m
.21989 .03977 L
.22035 .03977 L
.22035 .16187 L
s
1 .894 .882 r
.22035 .16187 m
.22035 .04004 L
.22155 .04004 L
.22155 .16187 L
F
.804 .522 .247 r
.22035 .16187 m
.22035 .04004 L
.22155 .04004 L
.22155 .16187 L
s
1 .894 .882 r
.22155 .16187 m
.22155 .04014 L
.22248 .04014 L
.22248 .16187 L
F
.804 .522 .247 r
.22155 .16187 m
.22155 .04014 L
.22248 .04014 L
.22248 .16187 L
s
1 .894 .882 r
.22248 .16187 m
.22248 .04036 L
.223 .04036 L
.223 .16187 L
F
.804 .522 .247 r
.22248 .16187 m
.22248 .04036 L
.223 .04036 L
.223 .16187 L
s
1 .894 .882 r
.223 .16187 m
.223 .04062 L
.22361 .04062 L
.22361 .16187 L
F
.804 .522 .247 r
.223 .16187 m
.223 .04062 L
.22361 .04062 L
.22361 .16187 L
s
1 .894 .882 r
.22361 .16187 m
.22361 .04087 L
.22463 .04087 L
.22463 .16187 L
F
.804 .522 .247 r
.22361 .16187 m
.22361 .04087 L
.22463 .04087 L
.22463 .16187 L
s
1 .894 .882 r
.22463 .16187 m
.22463 .04106 L
.22563 .04106 L
.22563 .16187 L
F
.804 .522 .247 r
.22463 .16187 m
.22463 .04106 L
.22563 .04106 L
.22563 .16187 L
s
1 .894 .882 r
.22563 .16187 m
.22563 .04122 L
.2261 .04122 L
.2261 .16187 L
F
.804 .522 .247 r
.22563 .16187 m
.22563 .04122 L
.2261 .04122 L
.2261 .16187 L
s
1 .894 .882 r
.2261 .16187 m
.2261 .04136 L
.22651 .04136 L
.22651 .16187 L
F
.804 .522 .247 r
.2261 .16187 m
.2261 .04136 L
.22651 .04136 L
.22651 .16187 L
s
1 .894 .882 r
.22651 .16187 m
.22651 .04149 L
.22717 .04149 L
.22717 .16187 L
F
.804 .522 .247 r
.22651 .16187 m
.22651 .04149 L
.22717 .04149 L
.22717 .16187 L
s
1 .894 .882 r
.22717 .16187 m
.22717 .04161 L
.2285 .04161 L
.2285 .16187 L
F
.804 .522 .247 r
.22717 .16187 m
.22717 .04161 L
.2285 .04161 L
.2285 .16187 L
s
1 .894 .882 r
.2285 .16187 m
.2285 .04197 L
.22926 .04197 L
.22926 .16187 L
F
.804 .522 .247 r
.2285 .16187 m
.2285 .04197 L
.22926 .04197 L
.22926 .16187 L
s
1 .894 .882 r
.22926 .16187 m
.22926 .04224 L
.22984 .04224 L
.22984 .16187 L
F
.804 .522 .247 r
.22926 .16187 m
.22926 .04224 L
.22984 .04224 L
.22984 .16187 L
s
1 .894 .882 r
.22984 .16187 m
.22984 .04255 L
.23099 .04255 L
.23099 .16187 L
F
.804 .522 .247 r
.22984 .16187 m
.22984 .04255 L
.23099 .04255 L
.23099 .16187 L
s
1 .894 .882 r
.23099 .16187 m
.23099 .04262 L
.23147 .04262 L
.23147 .16187 L
F
.804 .522 .247 r
.23099 .16187 m
.23099 .04262 L
.23147 .04262 L
.23147 .16187 L
s
1 .894 .882 r
.23147 .16187 m
.23147 .04273 L
.232 .04273 L
.232 .16187 L
F
.804 .522 .247 r
.23147 .16187 m
.23147 .04273 L
.232 .04273 L
.232 .16187 L
s
1 .894 .882 r
.232 .16187 m
.232 .04291 L
.23266 .04291 L
.23266 .16187 L
F
.804 .522 .247 r
.232 .16187 m
.232 .04291 L
.23266 .04291 L
.23266 .16187 L
s
1 .894 .882 r
.23266 .16187 m
.23266 .04313 L
.23384 .04313 L
.23384 .16187 L
F
.804 .522 .247 r
.23266 .16187 m
.23266 .04313 L
.23384 .04313 L
.23384 .16187 L
s
1 .894 .882 r
.23384 .16187 m
.23384 .04353 L
.2348 .04353 L
.2348 .16187 L
F
.804 .522 .247 r
.23384 .16187 m
.23384 .04353 L
.2348 .04353 L
.2348 .16187 L
s
1 .894 .882 r
.2348 .16187 m
.2348 .04361 L
.23523 .04361 L
.23523 .16187 L
F
.804 .522 .247 r
.2348 .16187 m
.2348 .04361 L
.23523 .04361 L
.23523 .16187 L
s
1 .894 .882 r
.23523 .16187 m
.23523 .04386 L
.23618 .04386 L
.23618 .16187 L
F
.804 .522 .247 r
.23523 .16187 m
.23523 .04386 L
.23618 .04386 L
.23618 .16187 L
s
1 .894 .882 r
.23618 .16187 m
.23618 .04405 L
.23748 .04405 L
.23748 .16187 L
F
.804 .522 .247 r
.23618 .16187 m
.23618 .04405 L
.23748 .04405 L
.23748 .16187 L
s
1 .894 .882 r
.23748 .16187 m
.23748 .04451 L
.23838 .04451 L
.23838 .16187 L
F
.804 .522 .247 r
.23748 .16187 m
.23748 .04451 L
.23838 .04451 L
.23838 .16187 L
s
1 .894 .882 r
.23838 .16187 m
.23838 .04482 L
.23935 .04482 L
.23935 .16187 L
F
.804 .522 .247 r
.23838 .16187 m
.23838 .04482 L
.23935 .04482 L
.23935 .16187 L
s
1 .894 .882 r
.23935 .16187 m
.23935 .04501 L
.24025 .04501 L
.24025 .16187 L
F
.804 .522 .247 r
.23935 .16187 m
.23935 .04501 L
.24025 .04501 L
.24025 .16187 L
s
1 .894 .882 r
.24025 .16187 m
.24025 .04517 L
.24076 .04517 L
.24076 .16187 L
F
.804 .522 .247 r
.24025 .16187 m
.24025 .04517 L
.24076 .04517 L
.24076 .16187 L
s
1 .894 .882 r
.24076 .16187 m
.24076 .04542 L
.24207 .04542 L
.24207 .16187 L
F
.804 .522 .247 r
.24076 .16187 m
.24076 .04542 L
.24207 .04542 L
.24207 .16187 L
s
1 .894 .882 r
.24207 .16187 m
.24207 .04579 L
.24294 .04579 L
.24294 .16187 L
F
.804 .522 .247 r
.24207 .16187 m
.24207 .04579 L
.24294 .04579 L
.24294 .16187 L
s
1 .894 .882 r
.24294 .16187 m
.24294 .046 L
.24363 .046 L
.24363 .16187 L
F
.804 .522 .247 r
.24294 .16187 m
.24294 .046 L
.24363 .046 L
.24363 .16187 L
s
1 .894 .882 r
.24363 .16187 m
.24363 .04618 L
.24447 .04618 L
.24447 .16187 L
F
.804 .522 .247 r
.24363 .16187 m
.24363 .04618 L
.24447 .04618 L
.24447 .16187 L
s
1 .894 .882 r
.24447 .16187 m
.24447 .04647 L
.2452 .04647 L
.2452 .16187 L
F
.804 .522 .247 r
.24447 .16187 m
.24447 .04647 L
.2452 .04647 L
.2452 .16187 L
s
1 .894 .882 r
.2452 .16187 m
.2452 .04653 L
.246 .04653 L
.246 .16187 L
F
.804 .522 .247 r
.2452 .16187 m
.2452 .04653 L
.246 .04653 L
.246 .16187 L
s
1 .894 .882 r
.246 .16187 m
.246 .04692 L
.24669 .04692 L
.24669 .16187 L
F
.804 .522 .247 r
.246 .16187 m
.246 .04692 L
.24669 .04692 L
.24669 .16187 L
s
1 .894 .882 r
.24669 .16187 m
.24669 .04709 L
.24727 .04709 L
.24727 .16187 L
F
.804 .522 .247 r
.24669 .16187 m
.24669 .04709 L
.24727 .04709 L
.24727 .16187 L
s
1 .894 .882 r
.24727 .16187 m
.24727 .04726 L
.24803 .04726 L
.24803 .16187 L
F
.804 .522 .247 r
.24727 .16187 m
.24727 .04726 L
.24803 .04726 L
.24803 .16187 L
s
1 .894 .882 r
.24803 .16187 m
.24803 .04743 L
.24847 .04743 L
.24847 .16187 L
F
.804 .522 .247 r
.24803 .16187 m
.24803 .04743 L
.24847 .04743 L
.24847 .16187 L
s
1 .894 .882 r
.24847 .16187 m
.24847 .04761 L
.24899 .04761 L
.24899 .16187 L
F
.804 .522 .247 r
.24847 .16187 m
.24847 .04761 L
.24899 .04761 L
.24899 .16187 L
s
1 .894 .882 r
.24899 .16187 m
.24899 .04782 L
.24978 .04782 L
.24978 .16187 L
F
.804 .522 .247 r
.24899 .16187 m
.24899 .04782 L
.24978 .04782 L
.24978 .16187 L
s
1 .894 .882 r
.24978 .16187 m
.24978 .0479 L
.25046 .0479 L
.25046 .16187 L
F
.804 .522 .247 r
.24978 .16187 m
.24978 .0479 L
.25046 .0479 L
.25046 .16187 L
s
1 .894 .882 r
.25046 .16187 m
.25046 .04825 L
.25173 .04825 L
.25173 .16187 L
F
.804 .522 .247 r
.25046 .16187 m
.25046 .04825 L
.25173 .04825 L
.25173 .16187 L
s
1 .894 .882 r
.25173 .16187 m
.25173 .04864 L
.25295 .04864 L
.25295 .16187 L
F
.804 .522 .247 r
.25173 .16187 m
.25173 .04864 L
.25295 .04864 L
.25295 .16187 L
s
1 .894 .882 r
.25295 .16187 m
.25295 .04894 L
.25391 .04894 L
.25391 .16187 L
F
.804 .522 .247 r
.25295 .16187 m
.25295 .04894 L
.25391 .04894 L
.25391 .16187 L
s
1 .894 .882 r
.25391 .16187 m
.25391 .04924 L
.25499 .04924 L
.25499 .16187 L
F
.804 .522 .247 r
.25391 .16187 m
.25391 .04924 L
.25499 .04924 L
.25499 .16187 L
s
1 .894 .882 r
.25499 .16187 m
.25499 .04958 L
.25623 .04958 L
.25623 .16187 L
F
.804 .522 .247 r
.25499 .16187 m
.25499 .04958 L
.25623 .04958 L
.25623 .16187 L
s
1 .894 .882 r
.25623 .16187 m
.25623 .04978 L
.2569 .04978 L
.2569 .16187 L
F
.804 .522 .247 r
.25623 .16187 m
.25623 .04978 L
.2569 .04978 L
.2569 .16187 L
s
1 .894 .882 r
.2569 .16187 m
.2569 .05007 L
.25792 .05007 L
.25792 .16187 L
F
.804 .522 .247 r
.2569 .16187 m
.2569 .05007 L
.25792 .05007 L
.25792 .16187 L
s
1 .894 .882 r
.25792 .16187 m
.25792 .05044 L
.25851 .05044 L
.25851 .16187 L
F
.804 .522 .247 r
.25792 .16187 m
.25792 .05044 L
.25851 .05044 L
.25851 .16187 L
s
1 .894 .882 r
.25851 .16187 m
.25851 .0506 L
.25918 .0506 L
.25918 .16187 L
F
.804 .522 .247 r
.25851 .16187 m
.25851 .0506 L
.25918 .0506 L
.25918 .16187 L
s
1 .894 .882 r
.25918 .16187 m
.25918 .05083 L
.26031 .05083 L
.26031 .16187 L
F
.804 .522 .247 r
.25918 .16187 m
.25918 .05083 L
.26031 .05083 L
.26031 .16187 L
s
1 .894 .882 r
.26031 .16187 m
.26031 .05128 L
.26123 .05128 L
.26123 .16187 L
F
.804 .522 .247 r
.26031 .16187 m
.26031 .05128 L
.26123 .05128 L
.26123 .16187 L
s
1 .894 .882 r
.26123 .16187 m
.26123 .05137 L
.26186 .05137 L
.26186 .16187 L
F
.804 .522 .247 r
.26123 .16187 m
.26123 .05137 L
.26186 .05137 L
.26186 .16187 L
s
1 .894 .882 r
.26186 .16187 m
.26186 .05149 L
.26302 .05149 L
.26302 .16187 L
F
.804 .522 .247 r
.26186 .16187 m
.26186 .05149 L
.26302 .05149 L
.26302 .16187 L
s
1 .894 .882 r
.26302 .16187 m
.26302 .05207 L
.26386 .05207 L
.26386 .16187 L
F
.804 .522 .247 r
.26302 .16187 m
.26302 .05207 L
.26386 .05207 L
.26386 .16187 L
s
1 .894 .882 r
.26386 .16187 m
.26386 .05219 L
.26434 .05219 L
.26434 .16187 L
F
.804 .522 .247 r
.26386 .16187 m
.26386 .05219 L
.26434 .05219 L
.26434 .16187 L
s
1 .894 .882 r
.26434 .16187 m
.26434 .05251 L
.26561 .05251 L
.26561 .16187 L
F
.804 .522 .247 r
.26434 .16187 m
.26434 .05251 L
.26561 .05251 L
.26561 .16187 L
s
1 .894 .882 r
.26561 .16187 m
.26561 .05289 L
.26637 .05289 L
.26637 .16187 L
F
.804 .522 .247 r
.26561 .16187 m
.26561 .05289 L
.26637 .05289 L
.26637 .16187 L
s
1 .894 .882 r
.26637 .16187 m
.26637 .0529 L
.26693 .0529 L
.26693 .16187 L
F
.804 .522 .247 r
.26637 .16187 m
.26637 .0529 L
.26693 .0529 L
.26693 .16187 L
s
1 .894 .882 r
.26693 .16187 m
.26693 .05335 L
.26818 .05335 L
.26818 .16187 L
F
.804 .522 .247 r
.26693 .16187 m
.26693 .05335 L
.26818 .05335 L
.26818 .16187 L
s
1 .894 .882 r
.26818 .16187 m
.26818 .05347 L
.2691 .05347 L
.2691 .16187 L
F
.804 .522 .247 r
.26818 .16187 m
.26818 .05347 L
.2691 .05347 L
.2691 .16187 L
s
1 .894 .882 r
.2691 .16187 m
.2691 .05382 L
.26982 .05382 L
.26982 .16187 L
F
.804 .522 .247 r
.2691 .16187 m
.2691 .05382 L
.26982 .05382 L
.26982 .16187 L
s
1 .894 .882 r
.26982 .16187 m
.26982 .054 L
.27027 .054 L
.27027 .16187 L
F
.804 .522 .247 r
.26982 .16187 m
.26982 .054 L
.27027 .054 L
.27027 .16187 L
s
1 .894 .882 r
.27027 .16187 m
.27027 .05437 L
.27114 .05437 L
.27114 .16187 L
F
.804 .522 .247 r
.27027 .16187 m
.27027 .05437 L
.27114 .05437 L
.27114 .16187 L
s
1 .894 .882 r
.27114 .16187 m
.27114 .05457 L
.27178 .05457 L
.27178 .16187 L
F
.804 .522 .247 r
.27114 .16187 m
.27114 .05457 L
.27178 .05457 L
.27178 .16187 L
s
1 .894 .882 r
.27178 .16187 m
.27178 .05481 L
.27259 .05481 L
.27259 .16187 L
F
.804 .522 .247 r
.27178 .16187 m
.27178 .05481 L
.27259 .05481 L
.27259 .16187 L
s
1 .894 .882 r
.27259 .16187 m
.27259 .05497 L
.27318 .05497 L
.27318 .16187 L
F
.804 .522 .247 r
.27259 .16187 m
.27259 .05497 L
.27318 .05497 L
.27318 .16187 L
s
1 .894 .882 r
.27318 .16187 m
.27318 .0552 L
.27444 .0552 L
.27444 .16187 L
F
.804 .522 .247 r
.27318 .16187 m
.27318 .0552 L
.27444 .0552 L
.27444 .16187 L
s
1 .894 .882 r
.27444 .16187 m
.27444 .05556 L
.27536 .05556 L
.27536 .16187 L
F
.804 .522 .247 r
.27444 .16187 m
.27444 .05556 L
.27536 .05556 L
.27536 .16187 L
s
1 .894 .882 r
.27536 .16187 m
.27536 .05585 L
.27627 .05585 L
.27627 .16187 L
F
.804 .522 .247 r
.27536 .16187 m
.27536 .05585 L
.27627 .05585 L
.27627 .16187 L
s
1 .894 .882 r
.27627 .16187 m
.27627 .05626 L
.27755 .05626 L
.27755 .16187 L
F
.804 .522 .247 r
.27627 .16187 m
.27627 .05626 L
.27755 .05626 L
.27755 .16187 L
s
1 .894 .882 r
.27755 .16187 m
.27755 .05671 L
.2782 .05671 L
.2782 .16187 L
F
.804 .522 .247 r
.27755 .16187 m
.27755 .05671 L
.2782 .05671 L
.2782 .16187 L
s
1 .894 .882 r
.2782 .16187 m
.2782 .05681 L
.27894 .05681 L
.27894 .16187 L
F
.804 .522 .247 r
.2782 .16187 m
.2782 .05681 L
.27894 .05681 L
.27894 .16187 L
s
1 .894 .882 r
.27894 .16187 m
.27894 .05708 L
.27958 .05708 L
.27958 .16187 L
F
.804 .522 .247 r
.27894 .16187 m
.27894 .05708 L
.27958 .05708 L
.27958 .16187 L
s
1 .894 .882 r
.27958 .16187 m
.27958 .05735 L
.28015 .05735 L
.28015 .16187 L
F
.804 .522 .247 r
.27958 .16187 m
.27958 .05735 L
.28015 .05735 L
.28015 .16187 L
s
1 .894 .882 r
.28015 .16187 m
.28015 .05737 L
.28123 .05737 L
.28123 .16187 L
F
.804 .522 .247 r
.28015 .16187 m
.28015 .05737 L
.28123 .05737 L
.28123 .16187 L
s
1 .894 .882 r
.28123 .16187 m
.28123 .05772 L
.28174 .05772 L
.28174 .16187 L
F
.804 .522 .247 r
.28123 .16187 m
.28123 .05772 L
.28174 .05772 L
.28174 .16187 L
s
1 .894 .882 r
.28174 .16187 m
.28174 .05805 L
.28258 .05805 L
.28258 .16187 L
F
.804 .522 .247 r
.28174 .16187 m
.28174 .05805 L
.28258 .05805 L
.28258 .16187 L
s
1 .894 .882 r
.28258 .16187 m
.28258 .0582 L
.28366 .0582 L
.28366 .16187 L
F
.804 .522 .247 r
.28258 .16187 m
.28258 .0582 L
.28366 .0582 L
.28366 .16187 L
s
1 .894 .882 r
.28366 .16187 m
.28366 .0587 L
.28467 .0587 L
.28467 .16187 L
F
.804 .522 .247 r
.28366 .16187 m
.28366 .0587 L
.28467 .0587 L
.28467 .16187 L
s
1 .894 .882 r
.28467 .16187 m
.28467 .05895 L
.28526 .05895 L
.28526 .16187 L
F
.804 .522 .247 r
.28467 .16187 m
.28467 .05895 L
.28526 .05895 L
.28526 .16187 L
s
1 .894 .882 r
.28526 .16187 m
.28526 .05917 L
.28575 .05917 L
.28575 .16187 L
F
.804 .522 .247 r
.28526 .16187 m
.28526 .05917 L
.28575 .05917 L
.28575 .16187 L
s
1 .894 .882 r
.28575 .16187 m
.28575 .05926 L
.28669 .05926 L
.28669 .16187 L
F
.804 .522 .247 r
.28575 .16187 m
.28575 .05926 L
.28669 .05926 L
.28669 .16187 L
s
1 .894 .882 r
.28669 .16187 m
.28669 .05986 L
.28779 .05986 L
.28779 .16187 L
F
.804 .522 .247 r
.28669 .16187 m
.28669 .05986 L
.28779 .05986 L
.28779 .16187 L
s
1 .894 .882 r
.28779 .16187 m
.28779 .06006 L
.28882 .06006 L
.28882 .16187 L
F
.804 .522 .247 r
.28779 .16187 m
.28779 .06006 L
.28882 .06006 L
.28882 .16187 L
s
1 .894 .882 r
.28882 .16187 m
.28882 .06042 L
.28994 .06042 L
.28994 .16187 L
F
.804 .522 .247 r
.28882 .16187 m
.28882 .06042 L
.28994 .06042 L
.28994 .16187 L
s
1 .894 .882 r
.28994 .16187 m
.28994 .06097 L
.29084 .06097 L
.29084 .16187 L
F
.804 .522 .247 r
.28994 .16187 m
.28994 .06097 L
.29084 .06097 L
.29084 .16187 L
s
1 .894 .882 r
.29084 .16187 m
.29084 .0612 L
.29148 .0612 L
.29148 .16187 L
F
.804 .522 .247 r
.29084 .16187 m
.29084 .0612 L
.29148 .0612 L
.29148 .16187 L
s
1 .894 .882 r
.29148 .16187 m
.29148 .06137 L
.29227 .06137 L
.29227 .16187 L
F
.804 .522 .247 r
.29148 .16187 m
.29148 .06137 L
.29227 .06137 L
.29227 .16187 L
s
1 .894 .882 r
.29227 .16187 m
.29227 .06164 L
.29299 .06164 L
.29299 .16187 L
F
.804 .522 .247 r
.29227 .16187 m
.29227 .06164 L
.29299 .06164 L
.29299 .16187 L
s
1 .894 .882 r
.29299 .16187 m
.29299 .06185 L
.2937 .06185 L
.2937 .16187 L
F
.804 .522 .247 r
.29299 .16187 m
.29299 .06185 L
.2937 .06185 L
.2937 .16187 L
s
1 .894 .882 r
.2937 .16187 m
.2937 .06214 L
.29444 .06214 L
.29444 .16187 L
F
.804 .522 .247 r
.2937 .16187 m
.2937 .06214 L
.29444 .06214 L
.29444 .16187 L
s
1 .894 .882 r
.29444 .16187 m
.29444 .06237 L
.29566 .06237 L
.29566 .16187 L
F
.804 .522 .247 r
.29444 .16187 m
.29444 .06237 L
.29566 .06237 L
.29566 .16187 L
s
1 .894 .882 r
.29566 .16187 m
.29566 .06282 L
.29683 .06282 L
.29683 .16187 L
F
.804 .522 .247 r
.29566 .16187 m
.29566 .06282 L
.29683 .06282 L
.29683 .16187 L
s
1 .894 .882 r
.29683 .16187 m
.29683 .0631 L
.29762 .0631 L
.29762 .16187 L
F
.804 .522 .247 r
.29683 .16187 m
.29683 .0631 L
.29762 .0631 L
.29762 .16187 L
s
1 .894 .882 r
.29762 .16187 m
.29762 .06347 L
.29811 .06347 L
.29811 .16187 L
F
.804 .522 .247 r
.29762 .16187 m
.29762 .06347 L
.29811 .06347 L
.29811 .16187 L
s
1 .894 .882 r
.29811 .16187 m
.29811 .06382 L
.29901 .06382 L
.29901 .16187 L
F
.804 .522 .247 r
.29811 .16187 m
.29811 .06382 L
.29901 .06382 L
.29901 .16187 L
s
1 .894 .882 r
.29901 .16187 m
.29901 .06412 L
.29993 .06412 L
.29993 .16187 L
F
.804 .522 .247 r
.29901 .16187 m
.29901 .06412 L
.29993 .06412 L
.29993 .16187 L
s
1 .894 .882 r
.29993 .16187 m
.29993 .06421 L
.30056 .06421 L
.30056 .16187 L
F
.804 .522 .247 r
.29993 .16187 m
.29993 .06421 L
.30056 .06421 L
.30056 .16187 L
s
1 .894 .882 r
.30056 .16187 m
.30056 .06458 L
.30132 .06458 L
.30132 .16187 L
F
.804 .522 .247 r
.30056 .16187 m
.30056 .06458 L
.30132 .06458 L
.30132 .16187 L
s
1 .894 .882 r
.30132 .16187 m
.30132 .06494 L
.30212 .06494 L
.30212 .16187 L
F
.804 .522 .247 r
.30132 .16187 m
.30132 .06494 L
.30212 .06494 L
.30212 .16187 L
s
1 .894 .882 r
.30212 .16187 m
.30212 .06501 L
.30261 .06501 L
.30261 .16187 L
F
.804 .522 .247 r
.30212 .16187 m
.30212 .06501 L
.30261 .06501 L
.30261 .16187 L
s
1 .894 .882 r
.30261 .16187 m
.30261 .06548 L
.30351 .06548 L
.30351 .16187 L
F
.804 .522 .247 r
.30261 .16187 m
.30261 .06548 L
.30351 .06548 L
.30351 .16187 L
s
1 .894 .882 r
.30351 .16187 m
.30351 .06552 L
.30462 .06552 L
.30462 .16187 L
F
.804 .522 .247 r
.30351 .16187 m
.30351 .06552 L
.30462 .06552 L
.30462 .16187 L
s
1 .894 .882 r
.30462 .16187 m
.30462 .066 L
.30524 .066 L
.30524 .16187 L
F
.804 .522 .247 r
.30462 .16187 m
.30462 .066 L
.30524 .066 L
.30524 .16187 L
s
1 .894 .882 r
.30524 .16187 m
.30524 .06641 L
.30659 .06641 L
.30659 .16187 L
F
.804 .522 .247 r
.30524 .16187 m
.30524 .06641 L
.30659 .06641 L
.30659 .16187 L
s
1 .894 .882 r
.30659 .16187 m
.30659 .06707 L
.30791 .06707 L
.30791 .16187 L
F
.804 .522 .247 r
.30659 .16187 m
.30659 .06707 L
.30791 .06707 L
.30791 .16187 L
s
1 .894 .882 r
.30791 .16187 m
.30791 .06714 L
.30832 .06714 L
.30832 .16187 L
F
.804 .522 .247 r
.30791 .16187 m
.30791 .06714 L
.30832 .06714 L
.30832 .16187 L
s
1 .894 .882 r
.30832 .16187 m
.30832 .0673 L
.30927 .0673 L
.30927 .16187 L
F
.804 .522 .247 r
.30832 .16187 m
.30832 .0673 L
.30927 .0673 L
.30927 .16187 L
s
1 .894 .882 r
.30927 .16187 m
.30927 .06766 L
.3099 .06766 L
.3099 .16187 L
F
.804 .522 .247 r
.30927 .16187 m
.30927 .06766 L
.3099 .06766 L
.3099 .16187 L
s
1 .894 .882 r
.3099 .16187 m
.3099 .06813 L
.31074 .06813 L
.31074 .16187 L
F
.804 .522 .247 r
.3099 .16187 m
.3099 .06813 L
.31074 .06813 L
.31074 .16187 L
s
1 .894 .882 r
.31074 .16187 m
.31074 .0683 L
.31186 .0683 L
.31186 .16187 L
F
.804 .522 .247 r
.31074 .16187 m
.31074 .0683 L
.31186 .0683 L
.31186 .16187 L
s
1 .894 .882 r
.31186 .16187 m
.31186 .06868 L
.31243 .06868 L
.31243 .16187 L
F
.804 .522 .247 r
.31186 .16187 m
.31186 .06868 L
.31243 .06868 L
.31243 .16187 L
s
1 .894 .882 r
.31243 .16187 m
.31243 .06908 L
.31368 .06908 L
.31368 .16187 L
F
.804 .522 .247 r
.31243 .16187 m
.31243 .06908 L
.31368 .06908 L
.31368 .16187 L
s
1 .894 .882 r
.31368 .16187 m
.31368 .06935 L
.31422 .06935 L
.31422 .16187 L
F
.804 .522 .247 r
.31368 .16187 m
.31368 .06935 L
.31422 .06935 L
.31422 .16187 L
s
1 .894 .882 r
.31422 .16187 m
.31422 .06967 L
.31501 .06967 L
.31501 .16187 L
F
.804 .522 .247 r
.31422 .16187 m
.31422 .06967 L
.31501 .06967 L
.31501 .16187 L
s
1 .894 .882 r
.31501 .16187 m
.31501 .06982 L
.31571 .06982 L
.31571 .16187 L
F
.804 .522 .247 r
.31501 .16187 m
.31501 .06982 L
.31571 .06982 L
.31571 .16187 L
s
1 .894 .882 r
.31571 .16187 m
.31571 .07006 L
.3162 .07006 L
.3162 .16187 L
F
.804 .522 .247 r
.31571 .16187 m
.31571 .07006 L
.3162 .07006 L
.3162 .16187 L
s
1 .894 .882 r
.3162 .16187 m
.3162 .0704 L
.31731 .0704 L
.31731 .16187 L
F
.804 .522 .247 r
.3162 .16187 m
.3162 .0704 L
.31731 .0704 L
.31731 .16187 L
s
1 .894 .882 r
.31731 .16187 m
.31731 .07065 L
.31801 .07065 L
.31801 .16187 L
F
.804 .522 .247 r
.31731 .16187 m
.31731 .07065 L
.31801 .07065 L
.31801 .16187 L
s
1 .894 .882 r
.31801 .16187 m
.31801 .07106 L
.31917 .07106 L
.31917 .16187 L
F
.804 .522 .247 r
.31801 .16187 m
.31801 .07106 L
.31917 .07106 L
.31917 .16187 L
s
1 .894 .882 r
.31917 .16187 m
.31917 .07151 L
.32009 .07151 L
.32009 .16187 L
F
.804 .522 .247 r
.31917 .16187 m
.31917 .07151 L
.32009 .07151 L
.32009 .16187 L
s
1 .894 .882 r
.32009 .16187 m
.32009 .07182 L
.32098 .07182 L
.32098 .16187 L
F
.804 .522 .247 r
.32009 .16187 m
.32009 .07182 L
.32098 .07182 L
.32098 .16187 L
s
1 .894 .882 r
.32098 .16187 m
.32098 .0723 L
.32228 .0723 L
.32228 .16187 L
F
.804 .522 .247 r
.32098 .16187 m
.32098 .0723 L
.32228 .0723 L
.32228 .16187 L
s
1 .894 .882 r
.32228 .16187 m
.32228 .07268 L
.32304 .07268 L
.32304 .16187 L
F
.804 .522 .247 r
.32228 .16187 m
.32228 .07268 L
.32304 .07268 L
.32304 .16187 L
s
1 .894 .882 r
.32304 .16187 m
.32304 .07293 L
.32389 .07293 L
.32389 .16187 L
F
.804 .522 .247 r
.32304 .16187 m
.32304 .07293 L
.32389 .07293 L
.32389 .16187 L
s
1 .894 .882 r
.32389 .16187 m
.32389 .07336 L
.32522 .07336 L
.32522 .16187 L
F
.804 .522 .247 r
.32389 .16187 m
.32389 .07336 L
.32522 .07336 L
.32522 .16187 L
s
1 .894 .882 r
.32522 .16187 m
.32522 .07378 L
.32582 .07378 L
.32582 .16187 L
F
.804 .522 .247 r
.32522 .16187 m
.32522 .07378 L
.32582 .07378 L
.32582 .16187 L
s
1 .894 .882 r
.32582 .16187 m
.32582 .07391 L
.32637 .07391 L
.32637 .16187 L
F
.804 .522 .247 r
.32582 .16187 m
.32582 .07391 L
.32637 .07391 L
.32637 .16187 L
s
1 .894 .882 r
.32637 .16187 m
.32637 .07437 L
.32722 .07437 L
.32722 .16187 L
F
.804 .522 .247 r
.32637 .16187 m
.32637 .07437 L
.32722 .07437 L
.32722 .16187 L
s
1 .894 .882 r
.32722 .16187 m
.32722 .07453 L
.32763 .07453 L
.32763 .16187 L
F
.804 .522 .247 r
.32722 .16187 m
.32722 .07453 L
.32763 .07453 L
.32763 .16187 L
s
1 .894 .882 r
.32763 .16187 m
.32763 .07465 L
.32823 .07465 L
.32823 .16187 L
F
.804 .522 .247 r
.32763 .16187 m
.32763 .07465 L
.32823 .07465 L
.32823 .16187 L
s
1 .894 .882 r
.32823 .16187 m
.32823 .07519 L
.32919 .07519 L
.32919 .16187 L
F
.804 .522 .247 r
.32823 .16187 m
.32823 .07519 L
.32919 .07519 L
.32919 .16187 L
s
1 .894 .882 r
.32919 .16187 m
.32919 .07535 L
.32982 .07535 L
.32982 .16187 L
F
.804 .522 .247 r
.32919 .16187 m
.32919 .07535 L
.32982 .07535 L
.32982 .16187 L
s
1 .894 .882 r
.32982 .16187 m
.32982 .07566 L
.33075 .07566 L
.33075 .16187 L
F
.804 .522 .247 r
.32982 .16187 m
.32982 .07566 L
.33075 .07566 L
.33075 .16187 L
s
1 .894 .882 r
.33075 .16187 m
.33075 .07611 L
.33158 .07611 L
.33158 .16187 L
F
.804 .522 .247 r
.33075 .16187 m
.33075 .07611 L
.33158 .07611 L
.33158 .16187 L
s
1 .894 .882 r
.33158 .16187 m
.33158 .07628 L
.33238 .07628 L
.33238 .16187 L
F
.804 .522 .247 r
.33158 .16187 m
.33158 .07628 L
.33238 .07628 L
.33238 .16187 L
s
1 .894 .882 r
.33238 .16187 m
.33238 .07674 L
.33311 .07674 L
.33311 .16187 L
F
.804 .522 .247 r
.33238 .16187 m
.33238 .07674 L
.33311 .07674 L
.33311 .16187 L
s
1 .894 .882 r
.33311 .16187 m
.33311 .07711 L
.3339 .07711 L
.3339 .16187 L
F
.804 .522 .247 r
.33311 .16187 m
.33311 .07711 L
.3339 .07711 L
.3339 .16187 L
s
1 .894 .882 r
.3339 .16187 m
.3339 .07712 L
.33435 .07712 L
.33435 .16187 L
F
.804 .522 .247 r
.3339 .16187 m
.3339 .07712 L
.33435 .07712 L
.33435 .16187 L
s
1 .894 .882 r
.33435 .16187 m
.33435 .0773 L
.33486 .0773 L
.33486 .16187 L
F
.804 .522 .247 r
.33435 .16187 m
.33435 .0773 L
.33486 .0773 L
.33486 .16187 L
s
1 .894 .882 r
.33486 .16187 m
.33486 .07764 L
.33551 .07764 L
.33551 .16187 L
F
.804 .522 .247 r
.33486 .16187 m
.33486 .07764 L
.33551 .07764 L
.33551 .16187 L
s
1 .894 .882 r
.33551 .16187 m
.33551 .07797 L
.33655 .07797 L
.33655 .16187 L
F
.804 .522 .247 r
.33551 .16187 m
.33551 .07797 L
.33655 .07797 L
.33655 .16187 L
s
1 .894 .882 r
.33655 .16187 m
.33655 .07857 L
.33764 .07857 L
.33764 .16187 L
F
.804 .522 .247 r
.33655 .16187 m
.33655 .07857 L
.33764 .07857 L
.33764 .16187 L
s
1 .894 .882 r
.33764 .16187 m
.33764 .07881 L
.33835 .07881 L
.33835 .16187 L
F
.804 .522 .247 r
.33764 .16187 m
.33764 .07881 L
.33835 .07881 L
.33835 .16187 L
s
1 .894 .882 r
.33835 .16187 m
.33835 .07936 L
.33943 .07936 L
.33943 .16187 L
F
.804 .522 .247 r
.33835 .16187 m
.33835 .07936 L
.33943 .07936 L
.33943 .16187 L
s
1 .894 .882 r
.33943 .16187 m
.33943 .07938 L
.33999 .07938 L
.33999 .16187 L
F
.804 .522 .247 r
.33943 .16187 m
.33943 .07938 L
.33999 .07938 L
.33999 .16187 L
s
1 .894 .882 r
.33999 .16187 m
.33999 .07974 L
.34114 .07974 L
.34114 .16187 L
F
.804 .522 .247 r
.33999 .16187 m
.33999 .07974 L
.34114 .07974 L
.34114 .16187 L
s
1 .894 .882 r
.34114 .16187 m
.34114 .08011 L
.34244 .08011 L
.34244 .16187 L
F
.804 .522 .247 r
.34114 .16187 m
.34114 .08011 L
.34244 .08011 L
.34244 .16187 L
s
1 .894 .882 r
.34244 .16187 m
.34244 .08077 L
.34308 .08077 L
.34308 .16187 L
F
.804 .522 .247 r
.34244 .16187 m
.34244 .08077 L
.34308 .08077 L
.34308 .16187 L
s
1 .894 .882 r
.34308 .16187 m
.34308 .08103 L
.34366 .08103 L
.34366 .16187 L
F
.804 .522 .247 r
.34308 .16187 m
.34308 .08103 L
.34366 .08103 L
.34366 .16187 L
s
1 .894 .882 r
.34366 .16187 m
.34366 .08145 L
.34463 .08145 L
.34463 .16187 L
F
.804 .522 .247 r
.34366 .16187 m
.34366 .08145 L
.34463 .08145 L
.34463 .16187 L
s
1 .894 .882 r
.34463 .16187 m
.34463 .08154 L
.34578 .08154 L
.34578 .16187 L
F
.804 .522 .247 r
.34463 .16187 m
.34463 .08154 L
.34578 .08154 L
.34578 .16187 L
s
1 .894 .882 r
.34578 .16187 m
.34578 .08243 L
.34692 .08243 L
.34692 .16187 L
F
.804 .522 .247 r
.34578 .16187 m
.34578 .08243 L
.34692 .08243 L
.34692 .16187 L
s
1 .894 .882 r
.34692 .16187 m
.34692 .08252 L
.3475 .08252 L
.3475 .16187 L
F
.804 .522 .247 r
.34692 .16187 m
.34692 .08252 L
.3475 .08252 L
.3475 .16187 L
s
1 .894 .882 r
.3475 .16187 m
.3475 .08294 L
.34827 .08294 L
.34827 .16187 L
F
.804 .522 .247 r
.3475 .16187 m
.3475 .08294 L
.34827 .08294 L
.34827 .16187 L
s
1 .894 .882 r
.34827 .16187 m
.34827 .08308 L
.34887 .08308 L
.34887 .16187 L
F
.804 .522 .247 r
.34827 .16187 m
.34827 .08308 L
.34887 .08308 L
.34887 .16187 L
s
1 .894 .882 r
.34887 .16187 m
.34887 .08346 L
.34978 .08346 L
.34978 .16187 L
F
.804 .522 .247 r
.34887 .16187 m
.34887 .08346 L
.34978 .08346 L
.34978 .16187 L
s
1 .894 .882 r
.34978 .16187 m
.34978 .08398 L
.35079 .08398 L
.35079 .16187 L
F
.804 .522 .247 r
.34978 .16187 m
.34978 .08398 L
.35079 .08398 L
.35079 .16187 L
s
1 .894 .882 r
.35079 .16187 m
.35079 .08462 L
.35209 .08462 L
.35209 .16187 L
F
.804 .522 .247 r
.35079 .16187 m
.35079 .08462 L
.35209 .08462 L
.35209 .16187 L
s
1 .894 .882 r
.35209 .16187 m
.35209 .08507 L
.35324 .08507 L
.35324 .16187 L
F
.804 .522 .247 r
.35209 .16187 m
.35209 .08507 L
.35324 .08507 L
.35324 .16187 L
s
1 .894 .882 r
.35324 .16187 m
.35324 .0853 L
.35383 .0853 L
.35383 .16187 L
F
.804 .522 .247 r
.35324 .16187 m
.35324 .0853 L
.35383 .0853 L
.35383 .16187 L
s
1 .894 .882 r
.35383 .16187 m
.35383 .08559 L
.35445 .08559 L
.35445 .16187 L
F
.804 .522 .247 r
.35383 .16187 m
.35383 .08559 L
.35445 .08559 L
.35445 .16187 L
s
1 .894 .882 r
.35445 .16187 m
.35445 .08617 L
.35571 .08617 L
.35571 .16187 L
F
.804 .522 .247 r
.35445 .16187 m
.35445 .08617 L
.35571 .08617 L
.35571 .16187 L
s
1 .894 .882 r
.35571 .16187 m
.35571 .08658 L
.35676 .08658 L
.35676 .16187 L
F
.804 .522 .247 r
.35571 .16187 m
.35571 .08658 L
.35676 .08658 L
.35676 .16187 L
s
1 .894 .882 r
.35676 .16187 m
.35676 .08672 L
.35806 .08672 L
.35806 .16187 L
F
.804 .522 .247 r
.35676 .16187 m
.35676 .08672 L
.35806 .08672 L
.35806 .16187 L
s
1 .894 .882 r
.35806 .16187 m
.35806 .08732 L
.359 .08732 L
.359 .16187 L
F
.804 .522 .247 r
.35806 .16187 m
.35806 .08732 L
.359 .08732 L
.359 .16187 L
s
1 .894 .882 r
.359 .16187 m
.359 .08764 L
.35956 .08764 L
.35956 .16187 L
F
.804 .522 .247 r
.359 .16187 m
.359 .08764 L
.35956 .08764 L
.35956 .16187 L
s
1 .894 .882 r
.35956 .16187 m
.35956 .08793 L
.36032 .08793 L
.36032 .16187 L
F
.804 .522 .247 r
.35956 .16187 m
.35956 .08793 L
.36032 .08793 L
.36032 .16187 L
s
1 .894 .882 r
.36032 .16187 m
.36032 .08823 L
.36094 .08823 L
.36094 .16187 L
F
.804 .522 .247 r
.36032 .16187 m
.36032 .08823 L
.36094 .08823 L
.36094 .16187 L
s
1 .894 .882 r
.36094 .16187 m
.36094 .08852 L
.36172 .08852 L
.36172 .16187 L
F
.804 .522 .247 r
.36094 .16187 m
.36094 .08852 L
.36172 .08852 L
.36172 .16187 L
s
1 .894 .882 r
.36172 .16187 m
.36172 .08907 L
.36248 .08907 L
.36248 .16187 L
F
.804 .522 .247 r
.36172 .16187 m
.36172 .08907 L
.36248 .08907 L
.36248 .16187 L
s
1 .894 .882 r
.36248 .16187 m
.36248 .08919 L
.3633 .08919 L
.3633 .16187 L
F
.804 .522 .247 r
.36248 .16187 m
.36248 .08919 L
.3633 .08919 L
.3633 .16187 L
s
1 .894 .882 r
.3633 .16187 m
.3633 .08978 L
.36464 .08978 L
.36464 .16187 L
F
.804 .522 .247 r
.3633 .16187 m
.3633 .08978 L
.36464 .08978 L
.36464 .16187 L
s
1 .894 .882 r
.36464 .16187 m
.36464 .09022 L
.36525 .09022 L
.36525 .16187 L
F
.804 .522 .247 r
.36464 .16187 m
.36464 .09022 L
.36525 .09022 L
.36525 .16187 L
s
1 .894 .882 r
.36525 .16187 m
.36525 .09082 L
.3664 .09082 L
.3664 .16187 L
F
.804 .522 .247 r
.36525 .16187 m
.36525 .09082 L
.3664 .09082 L
.3664 .16187 L
s
1 .894 .882 r
.3664 .16187 m
.3664 .0909 L
.36742 .0909 L
.36742 .16187 L
F
.804 .522 .247 r
.3664 .16187 m
.3664 .0909 L
.36742 .0909 L
.36742 .16187 L
s
1 .894 .882 r
.36742 .16187 m
.36742 .09148 L
.36803 .09148 L
.36803 .16187 L
F
.804 .522 .247 r
.36742 .16187 m
.36742 .09148 L
.36803 .09148 L
.36803 .16187 L
s
1 .894 .882 r
.36803 .16187 m
.36803 .09165 L
.36846 .09165 L
.36846 .16187 L
F
.804 .522 .247 r
.36803 .16187 m
.36803 .09165 L
.36846 .09165 L
.36846 .16187 L
s
1 .894 .882 r
.36846 .16187 m
.36846 .09186 L
.36925 .09186 L
.36925 .16187 L
F
.804 .522 .247 r
.36846 .16187 m
.36846 .09186 L
.36925 .09186 L
.36925 .16187 L
s
1 .894 .882 r
.36925 .16187 m
.36925 .09248 L
.37008 .09248 L
.37008 .16187 L
F
.804 .522 .247 r
.36925 .16187 m
.36925 .09248 L
.37008 .09248 L
.37008 .16187 L
s
1 .894 .882 r
.37008 .16187 m
.37008 .09256 L
.37113 .09256 L
.37113 .16187 L
F
.804 .522 .247 r
.37008 .16187 m
.37008 .09256 L
.37113 .09256 L
.37113 .16187 L
s
1 .894 .882 r
.37113 .16187 m
.37113 .09318 L
.3719 .09318 L
.3719 .16187 L
F
.804 .522 .247 r
.37113 .16187 m
.37113 .09318 L
.3719 .09318 L
.3719 .16187 L
s
1 .894 .882 r
.3719 .16187 m
.3719 .09343 L
.37275 .09343 L
.37275 .16187 L
F
.804 .522 .247 r
.3719 .16187 m
.3719 .09343 L
.37275 .09343 L
.37275 .16187 L
s
1 .894 .882 r
.37275 .16187 m
.37275 .09373 L
.37378 .09373 L
.37378 .16187 L
F
.804 .522 .247 r
.37275 .16187 m
.37275 .09373 L
.37378 .09373 L
.37378 .16187 L
s
1 .894 .882 r
.37378 .16187 m
.37378 .09437 L
.37465 .09437 L
.37465 .16187 L
F
.804 .522 .247 r
.37378 .16187 m
.37378 .09437 L
.37465 .09437 L
.37465 .16187 L
s
1 .894 .882 r
.37465 .16187 m
.37465 .09479 L
.3752 .09479 L
.3752 .16187 L
F
.804 .522 .247 r
.37465 .16187 m
.37465 .09479 L
.3752 .09479 L
.3752 .16187 L
s
1 .894 .882 r
.3752 .16187 m
.3752 .09496 L
.37616 .09496 L
.37616 .16187 L
F
.804 .522 .247 r
.3752 .16187 m
.3752 .09496 L
.37616 .09496 L
.37616 .16187 L
s
1 .894 .882 r
.37616 .16187 m
.37616 .09539 L
.37748 .09539 L
.37748 .16187 L
F
.804 .522 .247 r
.37616 .16187 m
.37616 .09539 L
.37748 .09539 L
.37748 .16187 L
s
1 .894 .882 r
.37748 .16187 m
.37748 .09603 L
.37841 .09603 L
.37841 .16187 L
F
.804 .522 .247 r
.37748 .16187 m
.37748 .09603 L
.37841 .09603 L
.37841 .16187 L
s
1 .894 .882 r
.37841 .16187 m
.37841 .09654 L
.37938 .09654 L
.37938 .16187 L
F
.804 .522 .247 r
.37841 .16187 m
.37841 .09654 L
.37938 .09654 L
.37938 .16187 L
s
1 .894 .882 r
.37938 .16187 m
.37938 .09683 L
.38018 .09683 L
.38018 .16187 L
F
.804 .522 .247 r
.37938 .16187 m
.37938 .09683 L
.38018 .09683 L
.38018 .16187 L
s
1 .894 .882 r
.38018 .16187 m
.38018 .09757 L
.38115 .09757 L
.38115 .16187 L
F
.804 .522 .247 r
.38018 .16187 m
.38018 .09757 L
.38115 .09757 L
.38115 .16187 L
s
1 .894 .882 r
.38115 .16187 m
.38115 .09766 L
.38187 .09766 L
.38187 .16187 L
F
.804 .522 .247 r
.38115 .16187 m
.38115 .09766 L
.38187 .09766 L
.38187 .16187 L
s
1 .894 .882 r
.38187 .16187 m
.38187 .09801 L
.38246 .09801 L
.38246 .16187 L
F
.804 .522 .247 r
.38187 .16187 m
.38187 .09801 L
.38246 .09801 L
.38246 .16187 L
s
1 .894 .882 r
.38246 .16187 m
.38246 .09828 L
.38291 .09828 L
.38291 .16187 L
F
.804 .522 .247 r
.38246 .16187 m
.38246 .09828 L
.38291 .09828 L
.38291 .16187 L
s
1 .894 .882 r
.38291 .16187 m
.38291 .09862 L
.38347 .09862 L
.38347 .16187 L
F
.804 .522 .247 r
.38291 .16187 m
.38291 .09862 L
.38347 .09862 L
.38347 .16187 L
s
1 .894 .882 r
.38347 .16187 m
.38347 .09892 L
.3842 .09892 L
.3842 .16187 L
F
.804 .522 .247 r
.38347 .16187 m
.38347 .09892 L
.3842 .09892 L
.3842 .16187 L
s
1 .894 .882 r
.3842 .16187 m
.3842 .09957 L
.38554 .09957 L
.38554 .16187 L
F
.804 .522 .247 r
.3842 .16187 m
.3842 .09957 L
.38554 .09957 L
.38554 .16187 L
s
1 .894 .882 r
.38554 .16187 m
.38554 .0998 L
.38619 .0998 L
.38619 .16187 L
F
.804 .522 .247 r
.38554 .16187 m
.38554 .0998 L
.38619 .0998 L
.38619 .16187 L
s
1 .894 .882 r
.38619 .16187 m
.38619 .10028 L
.38708 .10028 L
.38708 .16187 L
F
.804 .522 .247 r
.38619 .16187 m
.38619 .10028 L
.38708 .10028 L
.38708 .16187 L
s
1 .894 .882 r
.38708 .16187 m
.38708 .10041 L
.38762 .10041 L
.38762 .16187 L
F
.804 .522 .247 r
.38708 .16187 m
.38708 .10041 L
.38762 .10041 L
.38762 .16187 L
s
1 .894 .882 r
.38762 .16187 m
.38762 .10101 L
.38893 .10101 L
.38893 .16187 L
F
.804 .522 .247 r
.38762 .16187 m
.38762 .10101 L
.38893 .10101 L
.38893 .16187 L
s
1 .894 .882 r
.38893 .16187 m
.38893 .10146 L
.39015 .10146 L
.39015 .16187 L
F
.804 .522 .247 r
.38893 .16187 m
.38893 .10146 L
.39015 .10146 L
.39015 .16187 L
s
1 .894 .882 r
.39015 .16187 m
.39015 .10202 L
.39061 .10202 L
.39061 .16187 L
F
.804 .522 .247 r
.39015 .16187 m
.39015 .10202 L
.39061 .10202 L
.39061 .16187 L
s
1 .894 .882 r
.39061 .16187 m
.39061 .10209 L
.39146 .10209 L
.39146 .16187 L
F
.804 .522 .247 r
.39061 .16187 m
.39061 .10209 L
.39146 .10209 L
.39146 .16187 L
s
1 .894 .882 r
.39146 .16187 m
.39146 .10249 L
.3924 .10249 L
.3924 .16187 L
F
.804 .522 .247 r
.39146 .16187 m
.39146 .10249 L
.3924 .10249 L
.3924 .16187 L
s
1 .894 .882 r
.3924 .16187 m
.3924 .10295 L
.39318 .10295 L
.39318 .16187 L
F
.804 .522 .247 r
.3924 .16187 m
.3924 .10295 L
.39318 .10295 L
.39318 .16187 L
s
1 .894 .882 r
.39318 .16187 m
.39318 .10361 L
.39397 .10361 L
.39397 .16187 L
F
.804 .522 .247 r
.39318 .16187 m
.39318 .10361 L
.39397 .10361 L
.39397 .16187 L
s
1 .894 .882 r
.39397 .16187 m
.39397 .10409 L
.3953 .10409 L
.3953 .16187 L
F
.804 .522 .247 r
.39397 .16187 m
.39397 .10409 L
.3953 .10409 L
.3953 .16187 L
s
1 .894 .882 r
.3953 .16187 m
.3953 .10441 L
.39609 .10441 L
.39609 .16187 L
F
.804 .522 .247 r
.3953 .16187 m
.3953 .10441 L
.39609 .10441 L
.39609 .16187 L
s
1 .894 .882 r
.39609 .16187 m
.39609 .10518 L
.39727 .10518 L
.39727 .16187 L
F
.804 .522 .247 r
.39609 .16187 m
.39609 .10518 L
.39727 .10518 L
.39727 .16187 L
s
1 .894 .882 r
.39727 .16187 m
.39727 .10553 L
.39809 .10553 L
.39809 .16187 L
F
.804 .522 .247 r
.39727 .16187 m
.39727 .10553 L
.39809 .10553 L
.39809 .16187 L
s
1 .894 .882 r
.39809 .16187 m
.39809 .10577 L
.39889 .10577 L
.39889 .16187 L
F
.804 .522 .247 r
.39809 .16187 m
.39809 .10577 L
.39889 .10577 L
.39889 .16187 L
s
1 .894 .882 r
.39889 .16187 m
.39889 .10651 L
.40008 .10651 L
.40008 .16187 L
F
.804 .522 .247 r
.39889 .16187 m
.39889 .10651 L
.40008 .10651 L
.40008 .16187 L
s
1 .894 .882 r
.40008 .16187 m
.40008 .10687 L
.40086 .10687 L
.40086 .16187 L
F
.804 .522 .247 r
.40008 .16187 m
.40008 .10687 L
.40086 .10687 L
.40086 .16187 L
s
1 .894 .882 r
.40086 .16187 m
.40086 .10744 L
.40206 .10744 L
.40206 .16187 L
F
.804 .522 .247 r
.40086 .16187 m
.40086 .10744 L
.40206 .10744 L
.40206 .16187 L
s
1 .894 .882 r
.40206 .16187 m
.40206 .1076 L
.40256 .1076 L
.40256 .16187 L
F
.804 .522 .247 r
.40206 .16187 m
.40206 .1076 L
.40256 .1076 L
.40256 .16187 L
s
1 .894 .882 r
.40256 .16187 m
.40256 .10805 L
.40356 .10805 L
.40356 .16187 L
F
.804 .522 .247 r
.40256 .16187 m
.40256 .10805 L
.40356 .10805 L
.40356 .16187 L
s
1 .894 .882 r
.40356 .16187 m
.40356 .1084 L
.4043 .1084 L
.4043 .16187 L
F
.804 .522 .247 r
.40356 .16187 m
.40356 .1084 L
.4043 .1084 L
.4043 .16187 L
s
1 .894 .882 r
.4043 .16187 m
.4043 .10915 L
.40535 .10915 L
.40535 .16187 L
F
.804 .522 .247 r
.4043 .16187 m
.4043 .10915 L
.40535 .10915 L
.40535 .16187 L
s
1 .894 .882 r
.40535 .16187 m
.40535 .10939 L
.40647 .10939 L
.40647 .16187 L
F
.804 .522 .247 r
.40535 .16187 m
.40535 .10939 L
.40647 .10939 L
.40647 .16187 L
s
1 .894 .882 r
.40647 .16187 m
.40647 .11003 L
.40748 .11003 L
.40748 .16187 L
F
.804 .522 .247 r
.40647 .16187 m
.40647 .11003 L
.40748 .11003 L
.40748 .16187 L
s
1 .894 .882 r
.40748 .16187 m
.40748 .11042 L
.40799 .11042 L
.40799 .16187 L
F
.804 .522 .247 r
.40748 .16187 m
.40748 .11042 L
.40799 .11042 L
.40799 .16187 L
s
1 .894 .882 r
.40799 .16187 m
.40799 .11052 L
.40855 .11052 L
.40855 .16187 L
F
.804 .522 .247 r
.40799 .16187 m
.40799 .11052 L
.40855 .11052 L
.40855 .16187 L
s
1 .894 .882 r
.40855 .16187 m
.40855 .11084 L
.40954 .11084 L
.40954 .16187 L
F
.804 .522 .247 r
.40855 .16187 m
.40855 .11084 L
.40954 .11084 L
.40954 .16187 L
s
1 .894 .882 r
.40954 .16187 m
.40954 .11176 L
.41059 .11176 L
.41059 .16187 L
F
.804 .522 .247 r
.40954 .16187 m
.40954 .11176 L
.41059 .11176 L
.41059 .16187 L
s
1 .894 .882 r
.41059 .16187 m
.41059 .1119 L
.41124 .1119 L
.41124 .16187 L
F
.804 .522 .247 r
.41059 .16187 m
.41059 .1119 L
.41124 .1119 L
.41124 .16187 L
s
1 .894 .882 r
.41124 .16187 m
.41124 .11215 L
.41174 .11215 L
.41174 .16187 L
F
.804 .522 .247 r
.41124 .16187 m
.41124 .11215 L
.41174 .11215 L
.41174 .16187 L
s
1 .894 .882 r
.41174 .16187 m
.41174 .11264 L
.41229 .11264 L
.41229 .16187 L
F
.804 .522 .247 r
.41174 .16187 m
.41174 .11264 L
.41229 .11264 L
.41229 .16187 L
s
1 .894 .882 r
.41229 .16187 m
.41229 .11286 L
.4128 .11286 L
.4128 .16187 L
F
.804 .522 .247 r
.41229 .16187 m
.41229 .11286 L
.4128 .11286 L
.4128 .16187 L
s
1 .894 .882 r
.4128 .16187 m
.4128 .11299 L
.41403 .11299 L
.41403 .16187 L
F
.804 .522 .247 r
.4128 .16187 m
.4128 .11299 L
.41403 .11299 L
.41403 .16187 L
s
1 .894 .882 r
.41403 .16187 m
.41403 .11363 L
.4151 .11363 L
.4151 .16187 L
F
.804 .522 .247 r
.41403 .16187 m
.41403 .11363 L
.4151 .11363 L
.4151 .16187 L
s
1 .894 .882 r
.4151 .16187 m
.4151 .11414 L
.41567 .11414 L
.41567 .16187 L
F
.804 .522 .247 r
.4151 .16187 m
.4151 .11414 L
.41567 .11414 L
.41567 .16187 L
s
1 .894 .882 r
.41567 .16187 m
.41567 .1146 L
.41674 .1146 L
.41674 .16187 L
F
.804 .522 .247 r
.41567 .16187 m
.41567 .1146 L
.41674 .1146 L
.41674 .16187 L
s
1 .894 .882 r
.41674 .16187 m
.41674 .11496 L
.4172 .11496 L
.4172 .16187 L
F
.804 .522 .247 r
.41674 .16187 m
.41674 .11496 L
.4172 .11496 L
.4172 .16187 L
s
1 .894 .882 r
.4172 .16187 m
.4172 .11528 L
.41786 .11528 L
.41786 .16187 L
F
.804 .522 .247 r
.4172 .16187 m
.4172 .11528 L
.41786 .11528 L
.41786 .16187 L
s
1 .894 .882 r
.41786 .16187 m
.41786 .11597 L
.41898 .11597 L
.41898 .16187 L
F
.804 .522 .247 r
.41786 .16187 m
.41786 .11597 L
.41898 .11597 L
.41898 .16187 L
s
1 .894 .882 r
.41898 .16187 m
.41898 .11642 L
.42022 .11642 L
.42022 .16187 L
F
.804 .522 .247 r
.41898 .16187 m
.41898 .11642 L
.42022 .11642 L
.42022 .16187 L
s
1 .894 .882 r
.42022 .16187 m
.42022 .11695 L
.42125 .11695 L
.42125 .16187 L
F
.804 .522 .247 r
.42022 .16187 m
.42022 .11695 L
.42125 .11695 L
.42125 .16187 L
s
1 .894 .882 r
.42125 .16187 m
.42125 .11747 L
.42207 .11747 L
.42207 .16187 L
F
.804 .522 .247 r
.42125 .16187 m
.42125 .11747 L
.42207 .11747 L
.42207 .16187 L
s
1 .894 .882 r
.42207 .16187 m
.42207 .11802 L
.4231 .11802 L
.4231 .16187 L
F
.804 .522 .247 r
.42207 .16187 m
.42207 .11802 L
.4231 .11802 L
.4231 .16187 L
s
1 .894 .882 r
.4231 .16187 m
.4231 .1182 L
.42374 .1182 L
.42374 .16187 L
F
.804 .522 .247 r
.4231 .16187 m
.4231 .1182 L
.42374 .1182 L
.42374 .16187 L
s
1 .894 .882 r
.42374 .16187 m
.42374 .11859 L
.42443 .11859 L
.42443 .16187 L
F
.804 .522 .247 r
.42374 .16187 m
.42374 .11859 L
.42443 .11859 L
.42443 .16187 L
s
1 .894 .882 r
.42443 .16187 m
.42443 .11927 L
.42556 .11927 L
.42556 .16187 L
F
.804 .522 .247 r
.42443 .16187 m
.42443 .11927 L
.42556 .11927 L
.42556 .16187 L
s
1 .894 .882 r
.42556 .16187 m
.42556 .11967 L
.42683 .11967 L
.42683 .16187 L
F
.804 .522 .247 r
.42556 .16187 m
.42556 .11967 L
.42683 .11967 L
.42683 .16187 L
s
1 .894 .882 r
.42683 .16187 m
.42683 .12037 L
.42782 .12037 L
.42782 .16187 L
F
.804 .522 .247 r
.42683 .16187 m
.42683 .12037 L
.42782 .12037 L
.42782 .16187 L
s
1 .894 .882 r
.42782 .16187 m
.42782 .12079 L
.42841 .12079 L
.42841 .16187 L
F
.804 .522 .247 r
.42782 .16187 m
.42782 .12079 L
.42841 .12079 L
.42841 .16187 L
s
1 .894 .882 r
.42841 .16187 m
.42841 .12124 L
.42937 .12124 L
.42937 .16187 L
F
.804 .522 .247 r
.42841 .16187 m
.42841 .12124 L
.42937 .12124 L
.42937 .16187 L
s
1 .894 .882 r
.42937 .16187 m
.42937 .12153 L
.43006 .12153 L
.43006 .16187 L
F
.804 .522 .247 r
.42937 .16187 m
.42937 .12153 L
.43006 .12153 L
.43006 .16187 L
s
1 .894 .882 r
.43006 .16187 m
.43006 .12219 L
.43136 .12219 L
.43136 .16187 L
F
.804 .522 .247 r
.43006 .16187 m
.43006 .12219 L
.43136 .12219 L
.43136 .16187 L
s
1 .894 .882 r
.43136 .16187 m
.43136 .12263 L
.43265 .12263 L
.43265 .16187 L
F
.804 .522 .247 r
.43136 .16187 m
.43136 .12263 L
.43265 .12263 L
.43265 .16187 L
s
1 .894 .882 r
.43265 .16187 m
.43265 .12339 L
.43352 .12339 L
.43352 .16187 L
F
.804 .522 .247 r
.43265 .16187 m
.43265 .12339 L
.43352 .12339 L
.43352 .16187 L
s
1 .894 .882 r
.43352 .16187 m
.43352 .12372 L
.43407 .12372 L
.43407 .16187 L
F
.804 .522 .247 r
.43352 .16187 m
.43352 .12372 L
.43407 .12372 L
.43407 .16187 L
s
1 .894 .882 r
.43407 .16187 m
.43407 .12442 L
.43527 .12442 L
.43527 .16187 L
F
.804 .522 .247 r
.43407 .16187 m
.43407 .12442 L
.43527 .12442 L
.43527 .16187 L
s
1 .894 .882 r
.43527 .16187 m
.43527 .12459 L
.43573 .12459 L
.43573 .16187 L
F
.804 .522 .247 r
.43527 .16187 m
.43527 .12459 L
.43573 .12459 L
.43573 .16187 L
s
1 .894 .882 r
.43573 .16187 m
.43573 .12499 L
.43688 .12499 L
.43688 .16187 L
F
.804 .522 .247 r
.43573 .16187 m
.43573 .12499 L
.43688 .12499 L
.43688 .16187 L
s
1 .894 .882 r
.43688 .16187 m
.43688 .12546 L
.43822 .12546 L
.43822 .16187 L
F
.804 .522 .247 r
.43688 .16187 m
.43688 .12546 L
.43822 .12546 L
.43822 .16187 L
s
1 .894 .882 r
.43822 .16187 m
.43822 .12625 L
.43875 .12625 L
.43875 .16187 L
F
.804 .522 .247 r
.43822 .16187 m
.43822 .12625 L
.43875 .12625 L
.43875 .16187 L
s
1 .894 .882 r
.43875 .16187 m
.43875 .12663 L
.43916 .12663 L
.43916 .16187 L
F
.804 .522 .247 r
.43875 .16187 m
.43875 .12663 L
.43916 .12663 L
.43916 .16187 L
s
1 .894 .882 r
.43916 .16187 m
.43916 .12709 L
.44006 .12709 L
.44006 .16187 L
F
.804 .522 .247 r
.43916 .16187 m
.43916 .12709 L
.44006 .12709 L
.44006 .16187 L
s
1 .894 .882 r
.44006 .16187 m
.44006 .12721 L
.44068 .12721 L
.44068 .16187 L
F
.804 .522 .247 r
.44006 .16187 m
.44006 .12721 L
.44068 .12721 L
.44068 .16187 L
s
1 .894 .882 r
.44068 .16187 m
.44068 .12775 L
.44134 .12775 L
.44134 .16187 L
F
.804 .522 .247 r
.44068 .16187 m
.44068 .12775 L
.44134 .12775 L
.44134 .16187 L
s
1 .894 .882 r
.44134 .16187 m
.44134 .12798 L
.44207 .12798 L
.44207 .16187 L
F
.804 .522 .247 r
.44134 .16187 m
.44134 .12798 L
.44207 .12798 L
.44207 .16187 L
s
1 .894 .882 r
.44207 .16187 m
.44207 .12831 L
.44255 .12831 L
.44255 .16187 L
F
.804 .522 .247 r
.44207 .16187 m
.44207 .12831 L
.44255 .12831 L
.44255 .16187 L
s
1 .894 .882 r
.44255 .16187 m
.44255 .12874 L
.4435 .12874 L
.4435 .16187 L
F
.804 .522 .247 r
.44255 .16187 m
.44255 .12874 L
.4435 .12874 L
.4435 .16187 L
s
1 .894 .882 r
.4435 .16187 m
.4435 .12917 L
.44392 .12917 L
.44392 .16187 L
F
.804 .522 .247 r
.4435 .16187 m
.4435 .12917 L
.44392 .12917 L
.44392 .16187 L
s
1 .894 .882 r
.44392 .16187 m
.44392 .12928 L
.44437 .12928 L
.44437 .16187 L
F
.804 .522 .247 r
.44392 .16187 m
.44392 .12928 L
.44437 .12928 L
.44437 .16187 L
s
1 .894 .882 r
.44437 .16187 m
.44437 .12972 L
.44508 .12972 L
.44508 .16187 L
F
.804 .522 .247 r
.44437 .16187 m
.44437 .12972 L
.44508 .12972 L
.44508 .16187 L
s
1 .894 .882 r
.44508 .16187 m
.44508 .12996 L
.44612 .12996 L
.44612 .16187 L
F
.804 .522 .247 r
.44508 .16187 m
.44508 .12996 L
.44612 .12996 L
.44612 .16187 L
s
1 .894 .882 r
.44612 .16187 m
.44612 .13052 L
.44689 .13052 L
.44689 .16187 L
F
.804 .522 .247 r
.44612 .16187 m
.44612 .13052 L
.44689 .13052 L
.44689 .16187 L
s
1 .894 .882 r
.44689 .16187 m
.44689 .13129 L
.44811 .13129 L
.44811 .16187 L
F
.804 .522 .247 r
.44689 .16187 m
.44689 .13129 L
.44811 .13129 L
.44811 .16187 L
s
1 .894 .882 r
.44811 .16187 m
.44811 .13155 L
.44921 .13155 L
.44921 .16187 L
F
.804 .522 .247 r
.44811 .16187 m
.44811 .13155 L
.44921 .13155 L
.44921 .16187 L
s
1 .894 .882 r
.44921 .16187 m
.44921 .13254 L
.44996 .13254 L
.44996 .16187 L
F
.804 .522 .247 r
.44921 .16187 m
.44921 .13254 L
.44996 .13254 L
.44996 .16187 L
s
1 .894 .882 r
.44996 .16187 m
.44996 .13285 L
.4508 .13285 L
.4508 .16187 L
F
.804 .522 .247 r
.44996 .16187 m
.44996 .13285 L
.4508 .13285 L
.4508 .16187 L
s
1 .894 .882 r
.4508 .16187 m
.4508 .13333 L
.45208 .13333 L
.45208 .16187 L
F
.804 .522 .247 r
.4508 .16187 m
.4508 .13333 L
.45208 .13333 L
.45208 .16187 L
s
1 .894 .882 r
.45208 .16187 m
.45208 .13394 L
.45272 .13394 L
.45272 .16187 L
F
.804 .522 .247 r
.45208 .16187 m
.45208 .13394 L
.45272 .13394 L
.45272 .16187 L
s
1 .894 .882 r
.45272 .16187 m
.45272 .13432 L
.45333 .13432 L
.45333 .16187 L
F
.804 .522 .247 r
.45272 .16187 m
.45272 .13432 L
.45333 .13432 L
.45333 .16187 L
s
1 .894 .882 r
.45333 .16187 m
.45333 .13492 L
.45432 .13492 L
.45432 .16187 L
F
.804 .522 .247 r
.45333 .16187 m
.45333 .13492 L
.45432 .13492 L
.45432 .16187 L
s
1 .894 .882 r
.45432 .16187 m
.45432 .13524 L
.45554 .13524 L
.45554 .16187 L
F
.804 .522 .247 r
.45432 .16187 m
.45432 .13524 L
.45554 .13524 L
.45554 .16187 L
s
1 .894 .882 r
.45554 .16187 m
.45554 .13581 L
.45639 .13581 L
.45639 .16187 L
F
.804 .522 .247 r
.45554 .16187 m
.45554 .13581 L
.45639 .13581 L
.45639 .16187 L
s
1 .894 .882 r
.45639 .16187 m
.45639 .13638 L
.45702 .13638 L
.45702 .16187 L
F
.804 .522 .247 r
.45639 .16187 m
.45639 .13638 L
.45702 .13638 L
.45702 .16187 L
s
1 .894 .882 r
.45702 .16187 m
.45702 .13677 L
.45788 .13677 L
.45788 .16187 L
F
.804 .522 .247 r
.45702 .16187 m
.45702 .13677 L
.45788 .13677 L
.45788 .16187 L
s
1 .894 .882 r
.45788 .16187 m
.45788 .13735 L
.4591 .13735 L
.4591 .16187 L
F
.804 .522 .247 r
.45788 .16187 m
.45788 .13735 L
.4591 .13735 L
.4591 .16187 L
s
1 .894 .882 r
.4591 .16187 m
.4591 .13799 L
.46041 .13799 L
.46041 .16187 L
F
.804 .522 .247 r
.4591 .16187 m
.4591 .13799 L
.46041 .13799 L
.46041 .16187 L
s
1 .894 .882 r
.46041 .16187 m
.46041 .13878 L
.46176 .13878 L
.46176 .16187 L
F
.804 .522 .247 r
.46041 .16187 m
.46041 .13878 L
.46176 .13878 L
.46176 .16187 L
s
1 .894 .882 r
.46176 .16187 m
.46176 .13947 L
.46238 .13947 L
.46238 .16187 L
F
.804 .522 .247 r
.46176 .16187 m
.46176 .13947 L
.46238 .13947 L
.46238 .16187 L
s
1 .894 .882 r
.46238 .16187 m
.46238 .13963 L
.46327 .13963 L
.46327 .16187 L
F
.804 .522 .247 r
.46238 .16187 m
.46238 .13963 L
.46327 .13963 L
.46327 .16187 L
s
1 .894 .882 r
.46327 .16187 m
.46327 .14016 L
.46451 .14016 L
.46451 .16187 L
F
.804 .522 .247 r
.46327 .16187 m
.46327 .14016 L
.46451 .14016 L
.46451 .16187 L
s
1 .894 .882 r
.46451 .16187 m
.46451 .14075 L
.46532 .14075 L
.46532 .16187 L
F
.804 .522 .247 r
.46451 .16187 m
.46451 .14075 L
.46532 .14075 L
.46532 .16187 L
s
1 .894 .882 r
.46532 .16187 m
.46532 .14127 L
.46593 .14127 L
.46593 .16187 L
F
.804 .522 .247 r
.46532 .16187 m
.46532 .14127 L
.46593 .14127 L
.46593 .16187 L
s
1 .894 .882 r
.46593 .16187 m
.46593 .14159 L
.46677 .14159 L
.46677 .16187 L
F
.804 .522 .247 r
.46593 .16187 m
.46593 .14159 L
.46677 .14159 L
.46677 .16187 L
s
1 .894 .882 r
.46677 .16187 m
.46677 .14236 L
.4677 .14236 L
.4677 .16187 L
F
.804 .522 .247 r
.46677 .16187 m
.46677 .14236 L
.4677 .14236 L
.4677 .16187 L
s
1 .894 .882 r
.4677 .16187 m
.4677 .14315 L
.46883 .14315 L
.46883 .16187 L
F
.804 .522 .247 r
.4677 .16187 m
.4677 .14315 L
.46883 .14315 L
.46883 .16187 L
s
1 .894 .882 r
.46883 .16187 m
.46883 .14392 L
.47002 .14392 L
.47002 .16187 L
F
.804 .522 .247 r
.46883 .16187 m
.46883 .14392 L
.47002 .14392 L
.47002 .16187 L
s
1 .894 .882 r
.47002 .16187 m
.47002 .14418 L
.471 .14418 L
.471 .16187 L
F
.804 .522 .247 r
.47002 .16187 m
.47002 .14418 L
.471 .14418 L
.471 .16187 L
s
1 .894 .882 r
.471 .16187 m
.471 .14489 L
.47218 .14489 L
.47218 .16187 L
F
.804 .522 .247 r
.471 .16187 m
.471 .14489 L
.47218 .14489 L
.47218 .16187 L
s
1 .894 .882 r
.47218 .16187 m
.47218 .14561 L
.47297 .14561 L
.47297 .16187 L
F
.804 .522 .247 r
.47218 .16187 m
.47218 .14561 L
.47297 .14561 L
.47297 .16187 L
s
1 .894 .882 r
.47297 .16187 m
.47297 .1458 L
.47373 .1458 L
.47373 .16187 L
F
.804 .522 .247 r
.47297 .16187 m
.47297 .1458 L
.47373 .1458 L
.47373 .16187 L
s
1 .894 .882 r
.47373 .16187 m
.47373 .14609 L
.47479 .14609 L
.47479 .16187 L
F
.804 .522 .247 r
.47373 .16187 m
.47373 .14609 L
.47479 .14609 L
.47479 .16187 L
s
1 .894 .882 r
.47479 .16187 m
.47479 .14671 L
.47573 .14671 L
.47573 .16187 L
F
.804 .522 .247 r
.47479 .16187 m
.47479 .14671 L
.47573 .14671 L
.47573 .16187 L
s
1 .894 .882 r
.47573 .16187 m
.47573 .14734 L
.47632 .14734 L
.47632 .16187 L
F
.804 .522 .247 r
.47573 .16187 m
.47573 .14734 L
.47632 .14734 L
.47632 .16187 L
s
1 .894 .882 r
.47632 .16187 m
.47632 .14792 L
.47744 .14792 L
.47744 .16187 L
F
.804 .522 .247 r
.47632 .16187 m
.47632 .14792 L
.47744 .14792 L
.47744 .16187 L
s
1 .894 .882 r
.47744 .16187 m
.47744 .14871 L
.47863 .14871 L
.47863 .16187 L
F
.804 .522 .247 r
.47744 .16187 m
.47744 .14871 L
.47863 .14871 L
.47863 .16187 L
s
1 .894 .882 r
.47863 .16187 m
.47863 .14917 L
.47913 .14917 L
.47913 .16187 L
F
.804 .522 .247 r
.47863 .16187 m
.47863 .14917 L
.47913 .14917 L
.47913 .16187 L
s
1 .894 .882 r
.47913 .16187 m
.47913 .14975 L
.48045 .14975 L
.48045 .16187 L
F
.804 .522 .247 r
.47913 .16187 m
.47913 .14975 L
.48045 .14975 L
.48045 .16187 L
s
1 .894 .882 r
.48045 .16187 m
.48045 .1504 L
.48111 .1504 L
.48111 .16187 L
F
.804 .522 .247 r
.48045 .16187 m
.48045 .1504 L
.48111 .1504 L
.48111 .16187 L
s
1 .894 .882 r
.48111 .16187 m
.48111 .15052 L
.48244 .15052 L
.48244 .16187 L
F
.804 .522 .247 r
.48111 .16187 m
.48111 .15052 L
.48244 .15052 L
.48244 .16187 L
s
1 .894 .882 r
.48244 .16187 m
.48244 .15131 L
.48298 .15131 L
.48298 .16187 L
F
.804 .522 .247 r
.48244 .16187 m
.48244 .15131 L
.48298 .15131 L
.48298 .16187 L
s
1 .894 .882 r
.48298 .16187 m
.48298 .15166 L
.48431 .15166 L
.48431 .16187 L
F
.804 .522 .247 r
.48298 .16187 m
.48298 .15166 L
.48431 .15166 L
.48431 .16187 L
s
1 .894 .882 r
.48431 .16187 m
.48431 .15236 L
.48475 .15236 L
.48475 .16187 L
F
.804 .522 .247 r
.48431 .16187 m
.48431 .15236 L
.48475 .15236 L
.48475 .16187 L
s
1 .894 .882 r
.48475 .16187 m
.48475 .15307 L
.48561 .15307 L
.48561 .16187 L
F
.804 .522 .247 r
.48475 .16187 m
.48475 .15307 L
.48561 .15307 L
.48561 .16187 L
s
1 .894 .882 r
.48561 .16187 m
.48561 .15316 L
.48626 .15316 L
.48626 .16187 L
F
.804 .522 .247 r
.48561 .16187 m
.48561 .15316 L
.48626 .15316 L
.48626 .16187 L
s
1 .894 .882 r
.48626 .16187 m
.48626 .15359 L
.48718 .15359 L
.48718 .16187 L
F
.804 .522 .247 r
.48626 .16187 m
.48626 .15359 L
.48718 .15359 L
.48718 .16187 L
s
1 .894 .882 r
.48718 .16187 m
.48718 .15473 L
.48838 .15473 L
.48838 .16187 L
F
.804 .522 .247 r
.48718 .16187 m
.48718 .15473 L
.48838 .15473 L
.48838 .16187 L
s
1 .894 .882 r
.48838 .16187 m
.48838 .15499 L
.48879 .15499 L
.48879 .16187 L
F
.804 .522 .247 r
.48838 .16187 m
.48838 .15499 L
.48879 .15499 L
.48879 .16187 L
s
1 .894 .882 r
.48879 .16187 m
.48879 .15539 L
.48988 .15539 L
.48988 .16187 L
F
.804 .522 .247 r
.48879 .16187 m
.48879 .15539 L
.48988 .15539 L
.48988 .16187 L
s
1 .894 .882 r
.48988 .16187 m
.48988 .15587 L
.49102 .15587 L
.49102 .16187 L
F
.804 .522 .247 r
.48988 .16187 m
.48988 .15587 L
.49102 .15587 L
.49102 .16187 L
s
1 .894 .882 r
.49102 .16187 m
.49102 .15661 L
.49143 .15661 L
.49143 .16187 L
F
.804 .522 .247 r
.49102 .16187 m
.49102 .15661 L
.49143 .15661 L
.49143 .16187 L
s
1 .894 .882 r
.49143 .16187 m
.49143 .15681 L
.49222 .15681 L
.49222 .16187 L
F
.804 .522 .247 r
.49143 .16187 m
.49143 .15681 L
.49222 .15681 L
.49222 .16187 L
s
1 .894 .882 r
.49222 .16187 m
.49222 .15785 L
.49348 .15785 L
.49348 .16187 L
F
.804 .522 .247 r
.49222 .16187 m
.49222 .15785 L
.49348 .15785 L
.49348 .16187 L
s
1 .894 .882 r
.49348 .16187 m
.49348 .15802 L
.49424 .15802 L
.49424 .16187 L
F
.804 .522 .247 r
.49348 .16187 m
.49348 .15802 L
.49424 .15802 L
.49424 .16187 L
s
1 .894 .882 r
.49424 .16187 m
.49424 .15869 L
.49524 .15869 L
.49524 .16187 L
F
.804 .522 .247 r
.49424 .16187 m
.49424 .15869 L
.49524 .15869 L
.49524 .16187 L
s
1 .894 .882 r
.49524 .16187 m
.49524 .1592 L
.49633 .1592 L
.49633 .16187 L
F
.804 .522 .247 r
.49524 .16187 m
.49524 .1592 L
.49633 .1592 L
.49633 .16187 L
s
1 .894 .882 r
.49633 .16187 m
.49633 .16004 L
.49706 .16004 L
.49706 .16187 L
F
.804 .522 .247 r
.49633 .16187 m
.49633 .16004 L
.49706 .16004 L
.49706 .16187 L
s
1 .894 .882 r
.49706 .16187 m
.49706 .16007 L
.49763 .16007 L
.49763 .16187 L
F
.804 .522 .247 r
.49706 .16187 m
.49706 .16007 L
.49763 .16007 L
.49763 .16187 L
s
1 .894 .882 r
.49763 .16187 m
.49763 .16048 L
.49888 .16048 L
.49888 .16187 L
F
.804 .522 .247 r
.49763 .16187 m
.49763 .16048 L
.49888 .16048 L
.49888 .16187 L
s
1 .894 .882 r
.49888 .16187 m
.49888 .16174 L
.50012 .16174 L
.50012 .16187 L
F
.804 .522 .247 r
.49888 .16187 m
.49888 .16174 L
.50012 .16174 L
.50012 .16187 L
s
.678 .847 .902 r
.50012 .16187 m
.50012 .16203 L
.50076 .16203 L
.50076 .16187 L
F
.2 .63 .79 r
.50012 .16187 m
.50012 .16203 L
.50076 .16203 L
.50076 .16187 L
s
.678 .847 .902 r
.50076 .16187 m
.50076 .1625 L
.50136 .1625 L
.50136 .16187 L
F
.2 .63 .79 r
.50076 .16187 m
.50076 .1625 L
.50136 .1625 L
.50136 .16187 L
s
.678 .847 .902 r
.50136 .16187 m
.50136 .16281 L
.50236 .16281 L
.50236 .16187 L
F
.2 .63 .79 r
.50136 .16187 m
.50136 .16281 L
.50236 .16281 L
.50236 .16187 L
s
.678 .847 .902 r
.50236 .16187 m
.50236 .16381 L
.50363 .16381 L
.50363 .16187 L
F
.2 .63 .79 r
.50236 .16187 m
.50236 .16381 L
.50363 .16381 L
.50363 .16187 L
s
.678 .847 .902 r
.50363 .16187 m
.50363 .16441 L
.50413 .16441 L
.50413 .16187 L
F
.2 .63 .79 r
.50363 .16187 m
.50363 .16441 L
.50413 .16441 L
.50413 .16187 L
s
.678 .847 .902 r
.50413 .16187 m
.50413 .16453 L
.50477 .16453 L
.50477 .16187 L
F
.2 .63 .79 r
.50413 .16187 m
.50413 .16453 L
.50477 .16453 L
.50477 .16187 L
s
.678 .847 .902 r
.50477 .16187 m
.50477 .16486 L
.50572 .16486 L
.50572 .16187 L
F
.2 .63 .79 r
.50477 .16187 m
.50477 .16486 L
.50572 .16486 L
.50572 .16187 L
s
.678 .847 .902 r
.50572 .16187 m
.50572 .16577 L
.50654 .16577 L
.50654 .16187 L
F
.2 .63 .79 r
.50572 .16187 m
.50572 .16577 L
.50654 .16577 L
.50654 .16187 L
s
.678 .847 .902 r
.50654 .16187 m
.50654 .16652 L
.50774 .16652 L
.50774 .16187 L
F
.2 .63 .79 r
.50654 .16187 m
.50654 .16652 L
.50774 .16652 L
.50774 .16187 L
s
.678 .847 .902 r
.50774 .16187 m
.50774 .16676 L
.50882 .16676 L
.50882 .16187 L
F
.2 .63 .79 r
.50774 .16187 m
.50774 .16676 L
.50882 .16676 L
.50882 .16187 L
s
.678 .847 .902 r
.50882 .16187 m
.50882 .16744 L
.50993 .16744 L
.50993 .16187 L
F
.2 .63 .79 r
.50882 .16187 m
.50882 .16744 L
.50993 .16744 L
.50993 .16187 L
s
.678 .847 .902 r
.50993 .16187 m
.50993 .16849 L
.51075 .16849 L
.51075 .16187 L
F
.2 .63 .79 r
.50993 .16187 m
.50993 .16849 L
.51075 .16849 L
.51075 .16187 L
s
.678 .847 .902 r
.51075 .16187 m
.51075 .16865 L
.51127 .16865 L
.51127 .16187 L
F
.2 .63 .79 r
.51075 .16187 m
.51075 .16865 L
.51127 .16865 L
.51127 .16187 L
s
.678 .847 .902 r
.51127 .16187 m
.51127 .16958 L
.51255 .16958 L
.51255 .16187 L
F
.2 .63 .79 r
.51127 .16187 m
.51127 .16958 L
.51255 .16958 L
.51255 .16187 L
s
.678 .847 .902 r
.51255 .16187 m
.51255 .16983 L
.51366 .16983 L
.51366 .16187 L
F
.2 .63 .79 r
.51255 .16187 m
.51255 .16983 L
.51366 .16983 L
.51366 .16187 L
s
.678 .847 .902 r
.51366 .16187 m
.51366 .17054 L
.5141 .17054 L
.5141 .16187 L
F
.2 .63 .79 r
.51366 .16187 m
.51366 .17054 L
.5141 .17054 L
.5141 .16187 L
s
.678 .847 .902 r
.5141 .16187 m
.5141 .17079 L
.51471 .17079 L
.51471 .16187 L
F
.2 .63 .79 r
.5141 .16187 m
.5141 .17079 L
.51471 .17079 L
.51471 .16187 L
s
.678 .847 .902 r
.51471 .16187 m
.51471 .17138 L
.51565 .17138 L
.51565 .16187 L
F
.2 .63 .79 r
.51471 .16187 m
.51471 .17138 L
.51565 .17138 L
.51565 .16187 L
s
.678 .847 .902 r
.51565 .16187 m
.51565 .17188 L
.51615 .17188 L
.51615 .16187 L
F
.2 .63 .79 r
.51565 .16187 m
.51565 .17188 L
.51615 .17188 L
.51615 .16187 L
s
.678 .847 .902 r
.51615 .16187 m
.51615 .17203 L
.51686 .17203 L
.51686 .16187 L
F
.2 .63 .79 r
.51615 .16187 m
.51615 .17203 L
.51686 .17203 L
.51686 .16187 L
s
.678 .847 .902 r
.51686 .16187 m
.51686 .17268 L
.5181 .17268 L
.5181 .16187 L
F
.2 .63 .79 r
.51686 .16187 m
.51686 .17268 L
.5181 .17268 L
.5181 .16187 L
s
.678 .847 .902 r
.5181 .16187 m
.5181 .17347 L
.51887 .17347 L
.51887 .16187 L
F
.2 .63 .79 r
.5181 .16187 m
.5181 .17347 L
.51887 .17347 L
.51887 .16187 L
s
.678 .847 .902 r
.51887 .16187 m
.51887 .17395 L
.51948 .17395 L
.51948 .16187 L
F
.2 .63 .79 r
.51887 .16187 m
.51887 .17395 L
.51948 .17395 L
.51948 .16187 L
s
.678 .847 .902 r
.51948 .16187 m
.51948 .1743 L
.52029 .1743 L
.52029 .16187 L
F
.2 .63 .79 r
.51948 .16187 m
.51948 .1743 L
.52029 .1743 L
.52029 .16187 L
s
.678 .847 .902 r
.52029 .16187 m
.52029 .1747 L
.5213 .1747 L
.5213 .16187 L
F
.2 .63 .79 r
.52029 .16187 m
.52029 .1747 L
.5213 .1747 L
.5213 .16187 L
s
.678 .847 .902 r
.5213 .16187 m
.5213 .1757 L
.52188 .1757 L
.52188 .16187 L
F
.2 .63 .79 r
.5213 .16187 m
.5213 .1757 L
.52188 .1757 L
.52188 .16187 L
s
.678 .847 .902 r
.52188 .16187 m
.52188 .17589 L
.52286 .17589 L
.52286 .16187 L
F
.2 .63 .79 r
.52188 .16187 m
.52188 .17589 L
.52286 .17589 L
.52286 .16187 L
s
.678 .847 .902 r
.52286 .16187 m
.52286 .17672 L
.52375 .17672 L
.52375 .16187 L
F
.2 .63 .79 r
.52286 .16187 m
.52286 .17672 L
.52375 .17672 L
.52375 .16187 L
s
.678 .847 .902 r
.52375 .16187 m
.52375 .17698 L
.52466 .17698 L
.52466 .16187 L
F
.2 .63 .79 r
.52375 .16187 m
.52375 .17698 L
.52466 .17698 L
.52466 .16187 L
s
.678 .847 .902 r
.52466 .16187 m
.52466 .17813 L
.52596 .17813 L
.52596 .16187 L
F
.2 .63 .79 r
.52466 .16187 m
.52466 .17813 L
.52596 .17813 L
.52596 .16187 L
s
.678 .847 .902 r
.52596 .16187 m
.52596 .17842 L
.52639 .17842 L
.52639 .16187 L
F
.2 .63 .79 r
.52596 .16187 m
.52596 .17842 L
.52639 .17842 L
.52639 .16187 L
s
.678 .847 .902 r
.52639 .16187 m
.52639 .17893 L
.52687 .17893 L
.52687 .16187 L
F
.2 .63 .79 r
.52639 .16187 m
.52639 .17893 L
.52687 .17893 L
.52687 .16187 L
s
.678 .847 .902 r
.52687 .16187 m
.52687 .17918 L
.52793 .17918 L
.52793 .16187 L
F
.2 .63 .79 r
.52687 .16187 m
.52687 .17918 L
.52793 .17918 L
.52793 .16187 L
s
.678 .847 .902 r
.52793 .16187 m
.52793 .1799 L
.52857 .1799 L
.52857 .16187 L
F
.2 .63 .79 r
.52793 .16187 m
.52793 .1799 L
.52857 .1799 L
.52857 .16187 L
s
.678 .847 .902 r
.52857 .16187 m
.52857 .18012 L
.52924 .18012 L
.52924 .16187 L
F
.2 .63 .79 r
.52857 .16187 m
.52857 .18012 L
.52924 .18012 L
.52924 .16187 L
s
.678 .847 .902 r
.52924 .16187 m
.52924 .1806 L
.53025 .1806 L
.53025 .16187 L
F
.2 .63 .79 r
.52924 .16187 m
.52924 .1806 L
.53025 .1806 L
.53025 .16187 L
s
.678 .847 .902 r
.53025 .16187 m
.53025 .18124 L
.5312 .18124 L
.5312 .16187 L
F
.2 .63 .79 r
.53025 .16187 m
.53025 .18124 L
.5312 .18124 L
.5312 .16187 L
s
.678 .847 .902 r
.5312 .16187 m
.5312 .18216 L
.53191 .18216 L
.53191 .16187 L
F
.2 .63 .79 r
.5312 .16187 m
.5312 .18216 L
.53191 .18216 L
.53191 .16187 L
s
.678 .847 .902 r
.53191 .16187 m
.53191 .18225 L
.53282 .18225 L
.53282 .16187 L
F
.2 .63 .79 r
.53191 .16187 m
.53191 .18225 L
.53282 .18225 L
.53282 .16187 L
s
.678 .847 .902 r
.53282 .16187 m
.53282 .18334 L
.53381 .18334 L
.53381 .16187 L
F
.2 .63 .79 r
.53282 .16187 m
.53282 .18334 L
.53381 .18334 L
.53381 .16187 L
s
.678 .847 .902 r
.53381 .16187 m
.53381 .18395 L
.53456 .18395 L
.53456 .16187 L
F
.2 .63 .79 r
.53381 .16187 m
.53381 .18395 L
.53456 .18395 L
.53456 .16187 L
s
.678 .847 .902 r
.53456 .16187 m
.53456 .18425 L
.53568 .18425 L
.53568 .16187 L
F
.2 .63 .79 r
.53456 .16187 m
.53456 .18425 L
.53568 .18425 L
.53568 .16187 L
s
.678 .847 .902 r
.53568 .16187 m
.53568 .18498 L
.5365 .18498 L
.5365 .16187 L
F
.2 .63 .79 r
.53568 .16187 m
.53568 .18498 L
.5365 .18498 L
.5365 .16187 L
s
.678 .847 .902 r
.5365 .16187 m
.5365 .18563 L
.53719 .18563 L
.53719 .16187 L
F
.2 .63 .79 r
.5365 .16187 m
.5365 .18563 L
.53719 .18563 L
.53719 .16187 L
s
.678 .847 .902 r
.53719 .16187 m
.53719 .18612 L
.53804 .18612 L
.53804 .16187 L
F
.2 .63 .79 r
.53719 .16187 m
.53719 .18612 L
.53804 .18612 L
.53804 .16187 L
s
.678 .847 .902 r
.53804 .16187 m
.53804 .18678 L
.5388 .18678 L
.5388 .16187 L
F
.2 .63 .79 r
.53804 .16187 m
.53804 .18678 L
.5388 .18678 L
.5388 .16187 L
s
.678 .847 .902 r
.5388 .16187 m
.5388 .18722 L
.53941 .18722 L
.53941 .16187 L
F
.2 .63 .79 r
.5388 .16187 m
.5388 .18722 L
.53941 .18722 L
.53941 .16187 L
s
.678 .847 .902 r
.53941 .16187 m
.53941 .18761 L
.54065 .18761 L
.54065 .16187 L
F
.2 .63 .79 r
.53941 .16187 m
.53941 .18761 L
.54065 .18761 L
.54065 .16187 L
s
.678 .847 .902 r
.54065 .16187 m
.54065 .18855 L
.54185 .18855 L
.54185 .16187 L
F
.2 .63 .79 r
.54065 .16187 m
.54065 .18855 L
.54185 .18855 L
.54185 .16187 L
s
.678 .847 .902 r
.54185 .16187 m
.54185 .18923 L
.54243 .18923 L
.54243 .16187 L
F
.2 .63 .79 r
.54185 .16187 m
.54185 .18923 L
.54243 .18923 L
.54243 .16187 L
s
.678 .847 .902 r
.54243 .16187 m
.54243 .1897 L
.54342 .1897 L
.54342 .16187 L
F
.2 .63 .79 r
.54243 .16187 m
.54243 .1897 L
.54342 .1897 L
.54342 .16187 L
s
.678 .847 .902 r
.54342 .16187 m
.54342 .19033 L
.54417 .19033 L
.54417 .16187 L
F
.2 .63 .79 r
.54342 .16187 m
.54342 .19033 L
.54417 .19033 L
.54417 .16187 L
s
.678 .847 .902 r
.54417 .16187 m
.54417 .19066 L
.54487 .19066 L
.54487 .16187 L
F
.2 .63 .79 r
.54417 .16187 m
.54417 .19066 L
.54487 .19066 L
.54487 .16187 L
s
.678 .847 .902 r
.54487 .16187 m
.54487 .19098 L
.54551 .19098 L
.54551 .16187 L
F
.2 .63 .79 r
.54487 .16187 m
.54487 .19098 L
.54551 .19098 L
.54551 .16187 L
s
.678 .847 .902 r
.54551 .16187 m
.54551 .1916 L
.54648 .1916 L
.54648 .16187 L
F
.2 .63 .79 r
.54551 .16187 m
.54551 .1916 L
.54648 .1916 L
.54648 .16187 L
s
.678 .847 .902 r
.54648 .16187 m
.54648 .19237 L
.54715 .19237 L
.54715 .16187 L
F
.2 .63 .79 r
.54648 .16187 m
.54648 .19237 L
.54715 .19237 L
.54715 .16187 L
s
.678 .847 .902 r
.54715 .16187 m
.54715 .19255 L
.54814 .19255 L
.54814 .16187 L
F
.2 .63 .79 r
.54715 .16187 m
.54715 .19255 L
.54814 .19255 L
.54814 .16187 L
s
.678 .847 .902 r
.54814 .16187 m
.54814 .19328 L
.54856 .19328 L
.54856 .16187 L
F
.2 .63 .79 r
.54814 .16187 m
.54814 .19328 L
.54856 .19328 L
.54856 .16187 L
s
.678 .847 .902 r
.54856 .16187 m
.54856 .19352 L
.54926 .19352 L
.54926 .16187 L
F
.2 .63 .79 r
.54856 .16187 m
.54856 .19352 L
.54926 .19352 L
.54926 .16187 L
s
.678 .847 .902 r
.54926 .16187 m
.54926 .19434 L
.55027 .19434 L
.55027 .16187 L
F
.2 .63 .79 r
.54926 .16187 m
.54926 .19434 L
.55027 .19434 L
.55027 .16187 L
s
.678 .847 .902 r
.55027 .16187 m
.55027 .19458 L
.55071 .19458 L
.55071 .16187 L
F
.2 .63 .79 r
.55027 .16187 m
.55027 .19458 L
.55071 .19458 L
.55071 .16187 L
s
.678 .847 .902 r
.55071 .16187 m
.55071 .19541 L
.55179 .19541 L
.55179 .16187 L
F
.2 .63 .79 r
.55071 .16187 m
.55071 .19541 L
.55179 .19541 L
.55179 .16187 L
s
.678 .847 .902 r
.55179 .16187 m
.55179 .1958 L
.55292 .1958 L
.55292 .16187 L
F
.2 .63 .79 r
.55179 .16187 m
.55179 .1958 L
.55292 .1958 L
.55292 .16187 L
s
.678 .847 .902 r
.55292 .16187 m
.55292 .19666 L
.55336 .19666 L
.55336 .16187 L
F
.2 .63 .79 r
.55292 .16187 m
.55292 .19666 L
.55336 .19666 L
.55336 .16187 L
s
.678 .847 .902 r
.55336 .16187 m
.55336 .19676 L
.55441 .19676 L
.55441 .16187 L
F
.2 .63 .79 r
.55336 .16187 m
.55336 .19676 L
.55441 .19676 L
.55441 .16187 L
s
.678 .847 .902 r
.55441 .16187 m
.55441 .19776 L
.55572 .19776 L
.55572 .16187 L
F
.2 .63 .79 r
.55441 .16187 m
.55441 .19776 L
.55572 .19776 L
.55572 .16187 L
s
.678 .847 .902 r
.55572 .16187 m
.55572 .19872 L
.55644 .19872 L
.55644 .16187 L
F
.2 .63 .79 r
.55572 .16187 m
.55572 .19872 L
.55644 .19872 L
.55644 .16187 L
s
.678 .847 .902 r
.55644 .16187 m
.55644 .19894 L
.55754 .19894 L
.55754 .16187 L
F
.2 .63 .79 r
.55644 .16187 m
.55644 .19894 L
.55754 .19894 L
.55754 .16187 L
s
.678 .847 .902 r
.55754 .16187 m
.55754 .19976 L
.55814 .19976 L
.55814 .16187 L
F
.2 .63 .79 r
.55754 .16187 m
.55754 .19976 L
.55814 .19976 L
.55814 .16187 L
s
.678 .847 .902 r
.55814 .16187 m
.55814 .20031 L
.5591 .20031 L
.5591 .16187 L
F
.2 .63 .79 r
.55814 .16187 m
.55814 .20031 L
.5591 .20031 L
.5591 .16187 L
s
.678 .847 .902 r
.5591 .16187 m
.5591 .20096 L
.55962 .20096 L
.55962 .16187 L
F
.2 .63 .79 r
.5591 .16187 m
.5591 .20096 L
.55962 .20096 L
.55962 .16187 L
s
.678 .847 .902 r
.55962 .16187 m
.55962 .20162 L
.56084 .20162 L
.56084 .16187 L
F
.2 .63 .79 r
.55962 .16187 m
.55962 .20162 L
.56084 .20162 L
.56084 .16187 L
s
.678 .847 .902 r
.56084 .16187 m
.56084 .20231 L
.56159 .20231 L
.56159 .16187 L
F
.2 .63 .79 r
.56084 .16187 m
.56084 .20231 L
.56159 .20231 L
.56159 .16187 L
s
.678 .847 .902 r
.56159 .16187 m
.56159 .2027 L
.56238 .2027 L
.56238 .16187 L
F
.2 .63 .79 r
.56159 .16187 m
.56159 .2027 L
.56238 .2027 L
.56238 .16187 L
s
.678 .847 .902 r
.56238 .16187 m
.56238 .20306 L
.56326 .20306 L
.56326 .16187 L
F
.2 .63 .79 r
.56238 .16187 m
.56238 .20306 L
.56326 .20306 L
.56326 .16187 L
s
.678 .847 .902 r
.56326 .16187 m
.56326 .20412 L
.56413 .20412 L
.56413 .16187 L
F
.2 .63 .79 r
.56326 .16187 m
.56326 .20412 L
.56413 .20412 L
.56413 .16187 L
s
.678 .847 .902 r
.56413 .16187 m
.56413 .20428 L
.5646 .20428 L
.5646 .16187 L
F
.2 .63 .79 r
.56413 .16187 m
.56413 .20428 L
.5646 .20428 L
.5646 .16187 L
s
.678 .847 .902 r
.5646 .16187 m
.5646 .20464 L
.56515 .20464 L
.56515 .16187 L
F
.2 .63 .79 r
.5646 .16187 m
.5646 .20464 L
.56515 .20464 L
.56515 .16187 L
s
.678 .847 .902 r
.56515 .16187 m
.56515 .20559 L
.56642 .20559 L
.56642 .16187 L
F
.2 .63 .79 r
.56515 .16187 m
.56515 .20559 L
.56642 .20559 L
.56642 .16187 L
s
.678 .847 .902 r
.56642 .16187 m
.56642 .20582 L
.56702 .20582 L
.56702 .16187 L
F
.2 .63 .79 r
.56642 .16187 m
.56642 .20582 L
.56702 .20582 L
.56702 .16187 L
s
.678 .847 .902 r
.56702 .16187 m
.56702 .20632 L
.56786 .20632 L
.56786 .16187 L
F
.2 .63 .79 r
.56702 .16187 m
.56702 .20632 L
.56786 .20632 L
.56786 .16187 L
s
.678 .847 .902 r
.56786 .16187 m
.56786 .20711 L
.56839 .20711 L
.56839 .16187 L
F
.2 .63 .79 r
.56786 .16187 m
.56786 .20711 L
.56839 .20711 L
.56839 .16187 L
s
.678 .847 .902 r
.56839 .16187 m
.56839 .20755 L
.56937 .20755 L
.56937 .16187 L
F
.2 .63 .79 r
.56839 .16187 m
.56839 .20755 L
.56937 .20755 L
.56937 .16187 L
s
.678 .847 .902 r
.56937 .16187 m
.56937 .20815 L
.57031 .20815 L
.57031 .16187 L
F
.2 .63 .79 r
.56937 .16187 m
.56937 .20815 L
.57031 .20815 L
.57031 .16187 L
s
.678 .847 .902 r
.57031 .16187 m
.57031 .20863 L
.57111 .20863 L
.57111 .16187 L
F
.2 .63 .79 r
.57031 .16187 m
.57031 .20863 L
.57111 .20863 L
.57111 .16187 L
s
.678 .847 .902 r
.57111 .16187 m
.57111 .20916 L
.57193 .20916 L
.57193 .16187 L
F
.2 .63 .79 r
.57111 .16187 m
.57111 .20916 L
.57193 .20916 L
.57193 .16187 L
s
.678 .847 .902 r
.57193 .16187 m
.57193 .20993 L
.57313 .20993 L
.57313 .16187 L
F
.2 .63 .79 r
.57193 .16187 m
.57193 .20993 L
.57313 .20993 L
.57313 .16187 L
s
.678 .847 .902 r
.57313 .16187 m
.57313 .21088 L
.57404 .21088 L
.57404 .16187 L
F
.2 .63 .79 r
.57313 .16187 m
.57313 .21088 L
.57404 .21088 L
.57404 .16187 L
s
.678 .847 .902 r
.57404 .16187 m
.57404 .21125 L
.57515 .21125 L
.57515 .16187 L
F
.2 .63 .79 r
.57404 .16187 m
.57404 .21125 L
.57515 .21125 L
.57515 .16187 L
s
.678 .847 .902 r
.57515 .16187 m
.57515 .21242 L
.57601 .21242 L
.57601 .16187 L
F
.2 .63 .79 r
.57515 .16187 m
.57515 .21242 L
.57601 .21242 L
.57601 .16187 L
s
.678 .847 .902 r
.57601 .16187 m
.57601 .2129 L
.57689 .2129 L
.57689 .16187 L
F
.2 .63 .79 r
.57601 .16187 m
.57601 .2129 L
.57689 .2129 L
.57689 .16187 L
s
.678 .847 .902 r
.57689 .16187 m
.57689 .21353 L
.57806 .21353 L
.57806 .16187 L
F
.2 .63 .79 r
.57689 .16187 m
.57689 .21353 L
.57806 .21353 L
.57806 .16187 L
s
.678 .847 .902 r
.57806 .16187 m
.57806 .21448 L
.57897 .21448 L
.57897 .16187 L
F
.2 .63 .79 r
.57806 .16187 m
.57806 .21448 L
.57897 .21448 L
.57897 .16187 L
s
.678 .847 .902 r
.57897 .16187 m
.57897 .21495 L
.58023 .21495 L
.58023 .16187 L
F
.2 .63 .79 r
.57897 .16187 m
.57897 .21495 L
.58023 .21495 L
.58023 .16187 L
s
.678 .847 .902 r
.58023 .16187 m
.58023 .21598 L
.581 .21598 L
.581 .16187 L
F
.2 .63 .79 r
.58023 .16187 m
.58023 .21598 L
.581 .21598 L
.581 .16187 L
s
.678 .847 .902 r
.581 .16187 m
.581 .21681 L
.58231 .21681 L
.58231 .16187 L
F
.2 .63 .79 r
.581 .16187 m
.581 .21681 L
.58231 .21681 L
.58231 .16187 L
s
.678 .847 .902 r
.58231 .16187 m
.58231 .21746 L
.58287 .21746 L
.58287 .16187 L
F
.2 .63 .79 r
.58231 .16187 m
.58231 .21746 L
.58287 .21746 L
.58287 .16187 L
s
.678 .847 .902 r
.58287 .16187 m
.58287 .21799 L
.58375 .21799 L
.58375 .16187 L
F
.2 .63 .79 r
.58287 .16187 m
.58287 .21799 L
.58375 .21799 L
.58375 .16187 L
s
.678 .847 .902 r
.58375 .16187 m
.58375 .21859 L
.58499 .21859 L
.58499 .16187 L
F
.2 .63 .79 r
.58375 .16187 m
.58375 .21859 L
.58499 .21859 L
.58499 .16187 L
s
.678 .847 .902 r
.58499 .16187 m
.58499 .21954 L
.58583 .21954 L
.58583 .16187 L
F
.2 .63 .79 r
.58499 .16187 m
.58499 .21954 L
.58583 .21954 L
.58583 .16187 L
s
.678 .847 .902 r
.58583 .16187 m
.58583 .21986 L
.58633 .21986 L
.58633 .16187 L
F
.2 .63 .79 r
.58583 .16187 m
.58583 .21986 L
.58633 .21986 L
.58633 .16187 L
s
.678 .847 .902 r
.58633 .16187 m
.58633 .22024 L
.58707 .22024 L
.58707 .16187 L
F
.2 .63 .79 r
.58633 .16187 m
.58633 .22024 L
.58707 .22024 L
.58707 .16187 L
s
.678 .847 .902 r
.58707 .16187 m
.58707 .22124 L
.5884 .22124 L
.5884 .16187 L
F
.2 .63 .79 r
.58707 .16187 m
.58707 .22124 L
.5884 .22124 L
.5884 .16187 L
s
.678 .847 .902 r
.5884 .16187 m
.5884 .22188 L
.58904 .22188 L
.58904 .16187 L
F
.2 .63 .79 r
.5884 .16187 m
.5884 .22188 L
.58904 .22188 L
.58904 .16187 L
s
.678 .847 .902 r
.58904 .16187 m
.58904 .22224 L
.59006 .22224 L
.59006 .16187 L
F
.2 .63 .79 r
.58904 .16187 m
.58904 .22224 L
.59006 .22224 L
.59006 .16187 L
s
.678 .847 .902 r
.59006 .16187 m
.59006 .22302 L
.59067 .22302 L
.59067 .16187 L
F
.2 .63 .79 r
.59006 .16187 m
.59006 .22302 L
.59067 .22302 L
.59067 .16187 L
s
.678 .847 .902 r
.59067 .16187 m
.59067 .22331 L
.59143 .22331 L
.59143 .16187 L
F
.2 .63 .79 r
.59067 .16187 m
.59067 .22331 L
.59143 .22331 L
.59143 .16187 L
s
.678 .847 .902 r
.59143 .16187 m
.59143 .22397 L
.59249 .22397 L
.59249 .16187 L
F
.2 .63 .79 r
.59143 .16187 m
.59143 .22397 L
.59249 .22397 L
.59249 .16187 L
s
.678 .847 .902 r
.59249 .16187 m
.59249 .22462 L
.59311 .22462 L
.59311 .16187 L
F
.2 .63 .79 r
.59249 .16187 m
.59249 .22462 L
.59311 .22462 L
.59311 .16187 L
s
.678 .847 .902 r
.59311 .16187 m
.59311 .22537 L
.59426 .22537 L
.59426 .16187 L
F
.2 .63 .79 r
.59311 .16187 m
.59311 .22537 L
.59426 .22537 L
.59426 .16187 L
s
.678 .847 .902 r
.59426 .16187 m
.59426 .22644 L
.59517 .22644 L
.59517 .16187 L
F
.2 .63 .79 r
.59426 .16187 m
.59426 .22644 L
.59517 .22644 L
.59517 .16187 L
s
.678 .847 .902 r
.59517 .16187 m
.59517 .22684 L
.59573 .22684 L
.59573 .16187 L
F
.2 .63 .79 r
.59517 .16187 m
.59517 .22684 L
.59573 .22684 L
.59573 .16187 L
s
.678 .847 .902 r
.59573 .16187 m
.59573 .22762 L
.59659 .22762 L
.59659 .16187 L
F
.2 .63 .79 r
.59573 .16187 m
.59573 .22762 L
.59659 .22762 L
.59659 .16187 L
s
.678 .847 .902 r
.59659 .16187 m
.59659 .22796 L
.59729 .22796 L
.59729 .16187 L
F
.2 .63 .79 r
.59659 .16187 m
.59659 .22796 L
.59729 .22796 L
.59729 .16187 L
s
.678 .847 .902 r
.59729 .16187 m
.59729 .22825 L
.59773 .22825 L
.59773 .16187 L
F
.2 .63 .79 r
.59729 .16187 m
.59729 .22825 L
.59773 .22825 L
.59773 .16187 L
s
.678 .847 .902 r
.59773 .16187 m
.59773 .22864 L
.59847 .22864 L
.59847 .16187 L
F
.2 .63 .79 r
.59773 .16187 m
.59773 .22864 L
.59847 .22864 L
.59847 .16187 L
s
.678 .847 .902 r
.59847 .16187 m
.59847 .22936 L
.59978 .22936 L
.59978 .16187 L
F
.2 .63 .79 r
.59847 .16187 m
.59847 .22936 L
.59978 .22936 L
.59978 .16187 L
s
.678 .847 .902 r
.59978 .16187 m
.59978 .23024 L
.60057 .23024 L
.60057 .16187 L
F
.2 .63 .79 r
.59978 .16187 m
.59978 .23024 L
.60057 .23024 L
.60057 .16187 L
s
.678 .847 .902 r
.60057 .16187 m
.60057 .23112 L
.6016 .23112 L
.6016 .16187 L
F
.2 .63 .79 r
.60057 .16187 m
.60057 .23112 L
.6016 .23112 L
.6016 .16187 L
s
.678 .847 .902 r
.6016 .16187 m
.6016 .23174 L
.60238 .23174 L
.60238 .16187 L
F
.2 .63 .79 r
.6016 .16187 m
.6016 .23174 L
.60238 .23174 L
.60238 .16187 L
s
.678 .847 .902 r
.60238 .16187 m
.60238 .23242 L
.60355 .23242 L
.60355 .16187 L
F
.2 .63 .79 r
.60238 .16187 m
.60238 .23242 L
.60355 .23242 L
.60355 .16187 L
s
.678 .847 .902 r
.60355 .16187 m
.60355 .23348 L
.60481 .23348 L
.60481 .16187 L
F
.2 .63 .79 r
.60355 .16187 m
.60355 .23348 L
.60481 .23348 L
.60481 .16187 L
s
.678 .847 .902 r
.60481 .16187 m
.60481 .23398 L
.60595 .23398 L
.60595 .16187 L
F
.2 .63 .79 r
.60481 .16187 m
.60481 .23398 L
.60595 .23398 L
.60595 .16187 L
s
.678 .847 .902 r
.60595 .16187 m
.60595 .23551 L
.60724 .23551 L
.60724 .16187 L
F
.2 .63 .79 r
.60595 .16187 m
.60595 .23551 L
.60724 .23551 L
.60724 .16187 L
s
.678 .847 .902 r
.60724 .16187 m
.60724 .23568 L
.60832 .23568 L
.60832 .16187 L
F
.2 .63 .79 r
.60724 .16187 m
.60724 .23568 L
.60832 .23568 L
.60832 .16187 L
s
.678 .847 .902 r
.60832 .16187 m
.60832 .23668 L
.60925 .23668 L
.60925 .16187 L
F
.2 .63 .79 r
.60832 .16187 m
.60832 .23668 L
.60925 .23668 L
.60925 .16187 L
s
.678 .847 .902 r
.60925 .16187 m
.60925 .23764 L
.61042 .23764 L
.61042 .16187 L
F
.2 .63 .79 r
.60925 .16187 m
.60925 .23764 L
.61042 .23764 L
.61042 .16187 L
s
.678 .847 .902 r
.61042 .16187 m
.61042 .23821 L
.61147 .23821 L
.61147 .16187 L
F
.2 .63 .79 r
.61042 .16187 m
.61042 .23821 L
.61147 .23821 L
.61147 .16187 L
s
.678 .847 .902 r
.61147 .16187 m
.61147 .23911 L
.61193 .23911 L
.61193 .16187 L
F
.2 .63 .79 r
.61147 .16187 m
.61147 .23911 L
.61193 .23911 L
.61193 .16187 L
s
.678 .847 .902 r
.61193 .16187 m
.61193 .23965 L
.61266 .23965 L
.61266 .16187 L
F
.2 .63 .79 r
.61193 .16187 m
.61193 .23965 L
.61266 .23965 L
.61266 .16187 L
s
.678 .847 .902 r
.61266 .16187 m
.61266 .24001 L
.61348 .24001 L
.61348 .16187 L
F
.2 .63 .79 r
.61266 .16187 m
.61266 .24001 L
.61348 .24001 L
.61348 .16187 L
s
.678 .847 .902 r
.61348 .16187 m
.61348 .24037 L
.61482 .24037 L
.61482 .16187 L
F
.2 .63 .79 r
.61348 .16187 m
.61348 .24037 L
.61482 .24037 L
.61482 .16187 L
s
.678 .847 .902 r
.61482 .16187 m
.61482 .24206 L
.61602 .24206 L
.61602 .16187 L
F
.2 .63 .79 r
.61482 .16187 m
.61482 .24206 L
.61602 .24206 L
.61602 .16187 L
s
.678 .847 .902 r
.61602 .16187 m
.61602 .24264 L
.61695 .24264 L
.61695 .16187 L
F
.2 .63 .79 r
.61602 .16187 m
.61602 .24264 L
.61695 .24264 L
.61695 .16187 L
s
.678 .847 .902 r
.61695 .16187 m
.61695 .24364 L
.61822 .24364 L
.61822 .16187 L
F
.2 .63 .79 r
.61695 .16187 m
.61695 .24364 L
.61822 .24364 L
.61822 .16187 L
s
.678 .847 .902 r
.61822 .16187 m
.61822 .24431 L
.61941 .24431 L
.61941 .16187 L
F
.2 .63 .79 r
.61822 .16187 m
.61822 .24431 L
.61941 .24431 L
.61941 .16187 L
s
.678 .847 .902 r
.61941 .16187 m
.61941 .24534 L
.62015 .24534 L
.62015 .16187 L
F
.2 .63 .79 r
.61941 .16187 m
.61941 .24534 L
.62015 .24534 L
.62015 .16187 L
s
.678 .847 .902 r
.62015 .16187 m
.62015 .24589 L
.62079 .24589 L
.62079 .16187 L
F
.2 .63 .79 r
.62015 .16187 m
.62015 .24589 L
.62079 .24589 L
.62079 .16187 L
s
.678 .847 .902 r
.62079 .16187 m
.62079 .24627 L
.62202 .24627 L
.62202 .16187 L
F
.2 .63 .79 r
.62079 .16187 m
.62079 .24627 L
.62202 .24627 L
.62202 .16187 L
s
.678 .847 .902 r
.62202 .16187 m
.62202 .24696 L
.62289 .24696 L
.62289 .16187 L
F
.2 .63 .79 r
.62202 .16187 m
.62202 .24696 L
.62289 .24696 L
.62289 .16187 L
s
.678 .847 .902 r
.62289 .16187 m
.62289 .24785 L
.62366 .24785 L
.62366 .16187 L
F
.2 .63 .79 r
.62289 .16187 m
.62289 .24785 L
.62366 .24785 L
.62366 .16187 L
s
.678 .847 .902 r
.62366 .16187 m
.62366 .24859 L
.62487 .24859 L
.62487 .16187 L
F
.2 .63 .79 r
.62366 .16187 m
.62366 .24859 L
.62487 .24859 L
.62487 .16187 L
s
.678 .847 .902 r
.62487 .16187 m
.62487 .24944 L
.62548 .24944 L
.62548 .16187 L
F
.2 .63 .79 r
.62487 .16187 m
.62487 .24944 L
.62548 .24944 L
.62548 .16187 L
s
.678 .847 .902 r
.62548 .16187 m
.62548 .24978 L
.62597 .24978 L
.62597 .16187 L
F
.2 .63 .79 r
.62548 .16187 m
.62548 .24978 L
.62597 .24978 L
.62597 .16187 L
s
.678 .847 .902 r
.62597 .16187 m
.62597 .25065 L
.62694 .25065 L
.62694 .16187 L
F
.2 .63 .79 r
.62597 .16187 m
.62597 .25065 L
.62694 .25065 L
.62694 .16187 L
s
.678 .847 .902 r
.62694 .16187 m
.62694 .25148 L
.62823 .25148 L
.62823 .16187 L
F
.2 .63 .79 r
.62694 .16187 m
.62694 .25148 L
.62823 .25148 L
.62823 .16187 L
s
.678 .847 .902 r
.62823 .16187 m
.62823 .25202 L
.62906 .25202 L
.62906 .16187 L
F
.2 .63 .79 r
.62823 .16187 m
.62823 .25202 L
.62906 .25202 L
.62906 .16187 L
s
.678 .847 .902 r
.62906 .16187 m
.62906 .25264 L
.62961 .25264 L
.62961 .16187 L
F
.2 .63 .79 r
.62906 .16187 m
.62906 .25264 L
.62961 .25264 L
.62961 .16187 L
s
.678 .847 .902 r
.62961 .16187 m
.62961 .25362 L
.63086 .25362 L
.63086 .16187 L
F
.2 .63 .79 r
.62961 .16187 m
.62961 .25362 L
.63086 .25362 L
.63086 .16187 L
s
.678 .847 .902 r
.63086 .16187 m
.63086 .25406 L
.63163 .25406 L
.63163 .16187 L
F
.2 .63 .79 r
.63086 .16187 m
.63086 .25406 L
.63163 .25406 L
.63163 .16187 L
s
.678 .847 .902 r
.63163 .16187 m
.63163 .25509 L
.63264 .25509 L
.63264 .16187 L
F
.2 .63 .79 r
.63163 .16187 m
.63163 .25509 L
.63264 .25509 L
.63264 .16187 L
s
.678 .847 .902 r
.63264 .16187 m
.63264 .25542 L
.63349 .25542 L
.63349 .16187 L
F
.2 .63 .79 r
.63264 .16187 m
.63264 .25542 L
.63349 .25542 L
.63349 .16187 L
s
.678 .847 .902 r
.63349 .16187 m
.63349 .25683 L
.63469 .25683 L
.63469 .16187 L
F
.2 .63 .79 r
.63349 .16187 m
.63349 .25683 L
.63469 .25683 L
.63469 .16187 L
s
.678 .847 .902 r
.63469 .16187 m
.63469 .25705 L
.63513 .25705 L
.63513 .16187 L
F
.2 .63 .79 r
.63469 .16187 m
.63469 .25705 L
.63513 .25705 L
.63513 .16187 L
s
.678 .847 .902 r
.63513 .16187 m
.63513 .2574 L
.63574 .2574 L
.63574 .16187 L
F
.2 .63 .79 r
.63513 .16187 m
.63513 .2574 L
.63574 .2574 L
.63574 .16187 L
s
.678 .847 .902 r
.63574 .16187 m
.63574 .25787 L
.6366 .25787 L
.6366 .16187 L
F
.2 .63 .79 r
.63574 .16187 m
.63574 .25787 L
.6366 .25787 L
.6366 .16187 L
s
.678 .847 .902 r
.6366 .16187 m
.6366 .25863 L
.63795 .25863 L
.63795 .16187 L
F
.2 .63 .79 r
.6366 .16187 m
.6366 .25863 L
.63795 .25863 L
.63795 .16187 L
s
.678 .847 .902 r
.63795 .16187 m
.63795 .25948 L
.63882 .25948 L
.63882 .16187 L
F
.2 .63 .79 r
.63795 .16187 m
.63795 .25948 L
.63882 .25948 L
.63882 .16187 L
s
.678 .847 .902 r
.63882 .16187 m
.63882 .26056 L
.63952 .26056 L
.63952 .16187 L
F
.2 .63 .79 r
.63882 .16187 m
.63882 .26056 L
.63952 .26056 L
.63952 .16187 L
s
.678 .847 .902 r
.63952 .16187 m
.63952 .26145 L
.64054 .26145 L
.64054 .16187 L
F
.2 .63 .79 r
.63952 .16187 m
.63952 .26145 L
.64054 .26145 L
.64054 .16187 L
s
.678 .847 .902 r
.64054 .16187 m
.64054 .26193 L
.64156 .26193 L
.64156 .16187 L
F
.2 .63 .79 r
.64054 .16187 m
.64054 .26193 L
.64156 .26193 L
.64156 .16187 L
s
.678 .847 .902 r
.64156 .16187 m
.64156 .26247 L
.64219 .26247 L
.64219 .16187 L
F
.2 .63 .79 r
.64156 .16187 m
.64156 .26247 L
.64219 .26247 L
.64219 .16187 L
s
.678 .847 .902 r
.64219 .16187 m
.64219 .26314 L
.64302 .26314 L
.64302 .16187 L
F
.2 .63 .79 r
.64219 .16187 m
.64219 .26314 L
.64302 .26314 L
.64302 .16187 L
s
.678 .847 .902 r
.64302 .16187 m
.64302 .26392 L
.64358 .26392 L
.64358 .16187 L
F
.2 .63 .79 r
.64302 .16187 m
.64302 .26392 L
.64358 .26392 L
.64358 .16187 L
s
.678 .847 .902 r
.64358 .16187 m
.64358 .26402 L
.64423 .26402 L
.64423 .16187 L
F
.2 .63 .79 r
.64358 .16187 m
.64358 .26402 L
.64423 .26402 L
.64423 .16187 L
s
.678 .847 .902 r
.64423 .16187 m
.64423 .26502 L
.64501 .26502 L
.64501 .16187 L
F
.2 .63 .79 r
.64423 .16187 m
.64423 .26502 L
.64501 .26502 L
.64501 .16187 L
s
.678 .847 .902 r
.64501 .16187 m
.64501 .26554 L
.64563 .26554 L
.64563 .16187 L
F
.2 .63 .79 r
.64501 .16187 m
.64501 .26554 L
.64563 .26554 L
.64563 .16187 L
s
.678 .847 .902 r
.64563 .16187 m
.64563 .26582 L
.64611 .26582 L
.64611 .16187 L
F
.2 .63 .79 r
.64563 .16187 m
.64563 .26582 L
.64611 .26582 L
.64611 .16187 L
s
.678 .847 .902 r
.64611 .16187 m
.64611 .26623 L
.64715 .26623 L
.64715 .16187 L
F
.2 .63 .79 r
.64611 .16187 m
.64611 .26623 L
.64715 .26623 L
.64715 .16187 L
s
.678 .847 .902 r
.64715 .16187 m
.64715 .26694 L
.64799 .26694 L
.64799 .16187 L
F
.2 .63 .79 r
.64715 .16187 m
.64715 .26694 L
.64799 .26694 L
.64799 .16187 L
s
.678 .847 .902 r
.64799 .16187 m
.64799 .26796 L
.64913 .26796 L
.64913 .16187 L
F
.2 .63 .79 r
.64799 .16187 m
.64799 .26796 L
.64913 .26796 L
.64913 .16187 L
s
.678 .847 .902 r
.64913 .16187 m
.64913 .26849 L
.65042 .26849 L
.65042 .16187 L
F
.2 .63 .79 r
.64913 .16187 m
.64913 .26849 L
.65042 .26849 L
.65042 .16187 L
s
.678 .847 .902 r
.65042 .16187 m
.65042 .26997 L
.65157 .26997 L
.65157 .16187 L
F
.2 .63 .79 r
.65042 .16187 m
.65042 .26997 L
.65157 .26997 L
.65157 .16187 L
s
.678 .847 .902 r
.65157 .16187 m
.65157 .27075 L
.65204 .27075 L
.65204 .16187 L
F
.2 .63 .79 r
.65157 .16187 m
.65157 .27075 L
.65204 .27075 L
.65204 .16187 L
s
.678 .847 .902 r
.65204 .16187 m
.65204 .27113 L
.65258 .27113 L
.65258 .16187 L
F
.2 .63 .79 r
.65204 .16187 m
.65204 .27113 L
.65258 .27113 L
.65258 .16187 L
s
.678 .847 .902 r
.65258 .16187 m
.65258 .27181 L
.65343 .27181 L
.65343 .16187 L
F
.2 .63 .79 r
.65258 .16187 m
.65258 .27181 L
.65343 .27181 L
.65343 .16187 L
s
.678 .847 .902 r
.65343 .16187 m
.65343 .27254 L
.65473 .27254 L
.65473 .16187 L
F
.2 .63 .79 r
.65343 .16187 m
.65343 .27254 L
.65473 .27254 L
.65473 .16187 L
s
.678 .847 .902 r
.65473 .16187 m
.65473 .27314 L
.65517 .27314 L
.65517 .16187 L
F
.2 .63 .79 r
.65473 .16187 m
.65473 .27314 L
.65517 .27314 L
.65517 .16187 L
s
.678 .847 .902 r
.65517 .16187 m
.65517 .27374 L
.65645 .27374 L
.65645 .16187 L
F
.2 .63 .79 r
.65517 .16187 m
.65517 .27374 L
.65645 .27374 L
.65645 .16187 L
s
.678 .847 .902 r
.65645 .16187 m
.65645 .27505 L
.6578 .27505 L
.6578 .16187 L
F
.2 .63 .79 r
.65645 .16187 m
.65645 .27505 L
.6578 .27505 L
.6578 .16187 L
s
.678 .847 .902 r
.6578 .16187 m
.6578 .27589 L
.6591 .27589 L
.6591 .16187 L
F
.2 .63 .79 r
.6578 .16187 m
.6578 .27589 L
.6591 .27589 L
.6591 .16187 L
s
.678 .847 .902 r
.6591 .16187 m
.6591 .27684 L
.66002 .27684 L
.66002 .16187 L
F
.2 .63 .79 r
.6591 .16187 m
.6591 .27684 L
.66002 .27684 L
.66002 .16187 L
s
.678 .847 .902 r
.66002 .16187 m
.66002 .2779 L
.66102 .2779 L
.66102 .16187 L
F
.2 .63 .79 r
.66002 .16187 m
.66002 .2779 L
.66102 .2779 L
.66102 .16187 L
s
.678 .847 .902 r
.66102 .16187 m
.66102 .27861 L
.66175 .27861 L
.66175 .16187 L
F
.2 .63 .79 r
.66102 .16187 m
.66102 .27861 L
.66175 .27861 L
.66175 .16187 L
s
.678 .847 .902 r
.66175 .16187 m
.66175 .27929 L
.66243 .27929 L
.66243 .16187 L
F
.2 .63 .79 r
.66175 .16187 m
.66175 .27929 L
.66243 .27929 L
.66243 .16187 L
s
.678 .847 .902 r
.66243 .16187 m
.66243 .27942 L
.66313 .27942 L
.66313 .16187 L
F
.2 .63 .79 r
.66243 .16187 m
.66243 .27942 L
.66313 .27942 L
.66313 .16187 L
s
.678 .847 .902 r
.66313 .16187 m
.66313 .28006 L
.66371 .28006 L
.66371 .16187 L
F
.2 .63 .79 r
.66313 .16187 m
.66313 .28006 L
.66371 .28006 L
.66371 .16187 L
s
.678 .847 .902 r
.66371 .16187 m
.66371 .28082 L
.66429 .28082 L
.66429 .16187 L
F
.2 .63 .79 r
.66371 .16187 m
.66371 .28082 L
.66429 .28082 L
.66429 .16187 L
s
.678 .847 .902 r
.66429 .16187 m
.66429 .28119 L
.66473 .28119 L
.66473 .16187 L
F
.2 .63 .79 r
.66429 .16187 m
.66429 .28119 L
.66473 .28119 L
.66473 .16187 L
s
.678 .847 .902 r
.66473 .16187 m
.66473 .28156 L
.666 .28156 L
.666 .16187 L
F
.2 .63 .79 r
.66473 .16187 m
.66473 .28156 L
.666 .28156 L
.666 .16187 L
s
.678 .847 .902 r
.666 .16187 m
.666 .28278 L
.66731 .28278 L
.66731 .16187 L
F
.2 .63 .79 r
.666 .16187 m
.666 .28278 L
.66731 .28278 L
.66731 .16187 L
s
.678 .847 .902 r
.66731 .16187 m
.66731 .28357 L
.66782 .28357 L
.66782 .16187 L
F
.2 .63 .79 r
.66731 .16187 m
.66731 .28357 L
.66782 .28357 L
.66782 .16187 L
s
.678 .847 .902 r
.66782 .16187 m
.66782 .28418 L
.66857 .28418 L
.66857 .16187 L
F
.2 .63 .79 r
.66782 .16187 m
.66782 .28418 L
.66857 .28418 L
.66857 .16187 L
s
.678 .847 .902 r
.66857 .16187 m
.66857 .28459 L
.66942 .28459 L
.66942 .16187 L
F
.2 .63 .79 r
.66857 .16187 m
.66857 .28459 L
.66942 .28459 L
.66942 .16187 L
s
.678 .847 .902 r
.66942 .16187 m
.66942 .28565 L
.66999 .28565 L
.66999 .16187 L
F
.2 .63 .79 r
.66942 .16187 m
.66942 .28565 L
.66999 .28565 L
.66999 .16187 L
s
.678 .847 .902 r
.66999 .16187 m
.66999 .28581 L
.67055 .28581 L
.67055 .16187 L
F
.2 .63 .79 r
.66999 .16187 m
.66999 .28581 L
.67055 .28581 L
.67055 .16187 L
s
.678 .847 .902 r
.67055 .16187 m
.67055 .28618 L
.67152 .28618 L
.67152 .16187 L
F
.2 .63 .79 r
.67055 .16187 m
.67055 .28618 L
.67152 .28618 L
.67152 .16187 L
s
.678 .847 .902 r
.67152 .16187 m
.67152 .2872 L
.67229 .2872 L
.67229 .16187 L
F
.2 .63 .79 r
.67152 .16187 m
.67152 .2872 L
.67229 .2872 L
.67229 .16187 L
s
.678 .847 .902 r
.67229 .16187 m
.67229 .28772 L
.67274 .28772 L
.67274 .16187 L
F
.2 .63 .79 r
.67229 .16187 m
.67229 .28772 L
.67274 .28772 L
.67274 .16187 L
s
.678 .847 .902 r
.67274 .16187 m
.67274 .28845 L
.67381 .28845 L
.67381 .16187 L
F
.2 .63 .79 r
.67274 .16187 m
.67274 .28845 L
.67381 .28845 L
.67381 .16187 L
s
.678 .847 .902 r
.67381 .16187 m
.67381 .28932 L
.67483 .28932 L
.67483 .16187 L
F
.2 .63 .79 r
.67381 .16187 m
.67381 .28932 L
.67483 .28932 L
.67483 .16187 L
s
.678 .847 .902 r
.67483 .16187 m
.67483 .28979 L
.67558 .28979 L
.67558 .16187 L
F
.2 .63 .79 r
.67483 .16187 m
.67483 .28979 L
.67558 .28979 L
.67558 .16187 L
s
.678 .847 .902 r
.67558 .16187 m
.67558 .29079 L
.67609 .29079 L
.67609 .16187 L
F
.2 .63 .79 r
.67558 .16187 m
.67558 .29079 L
.67609 .29079 L
.67609 .16187 L
s
.678 .847 .902 r
.67609 .16187 m
.67609 .2917 L
.67717 .2917 L
.67717 .16187 L
F
.2 .63 .79 r
.67609 .16187 m
.67609 .2917 L
.67717 .2917 L
.67717 .16187 L
s
.678 .847 .902 r
.67717 .16187 m
.67717 .2919 L
.67825 .2919 L
.67825 .16187 L
F
.2 .63 .79 r
.67717 .16187 m
.67717 .2919 L
.67825 .2919 L
.67825 .16187 L
s
.678 .847 .902 r
.67825 .16187 m
.67825 .29342 L
.67942 .29342 L
.67942 .16187 L
F
.2 .63 .79 r
.67825 .16187 m
.67825 .29342 L
.67942 .29342 L
.67942 .16187 L
s
.678 .847 .902 r
.67942 .16187 m
.67942 .29388 L
.68029 .29388 L
.68029 .16187 L
F
.2 .63 .79 r
.67942 .16187 m
.67942 .29388 L
.68029 .29388 L
.68029 .16187 L
s
.678 .847 .902 r
.68029 .16187 m
.68029 .29458 L
.68105 .29458 L
.68105 .16187 L
F
.2 .63 .79 r
.68029 .16187 m
.68029 .29458 L
.68105 .29458 L
.68105 .16187 L
s
.678 .847 .902 r
.68105 .16187 m
.68105 .29526 L
.68185 .29526 L
.68185 .16187 L
F
.2 .63 .79 r
.68105 .16187 m
.68105 .29526 L
.68185 .29526 L
.68185 .16187 L
s
.678 .847 .902 r
.68185 .16187 m
.68185 .29624 L
.68273 .29624 L
.68273 .16187 L
F
.2 .63 .79 r
.68185 .16187 m
.68185 .29624 L
.68273 .29624 L
.68273 .16187 L
s
.678 .847 .902 r
.68273 .16187 m
.68273 .29653 L
.68343 .29653 L
.68343 .16187 L
F
.2 .63 .79 r
.68273 .16187 m
.68273 .29653 L
.68343 .29653 L
.68343 .16187 L
s
.678 .847 .902 r
.68343 .16187 m
.68343 .29732 L
.68402 .29732 L
.68402 .16187 L
F
.2 .63 .79 r
.68343 .16187 m
.68343 .29732 L
.68402 .29732 L
.68402 .16187 L
s
.678 .847 .902 r
.68402 .16187 m
.68402 .29794 L
.68478 .29794 L
.68478 .16187 L
F
.2 .63 .79 r
.68402 .16187 m
.68402 .29794 L
.68478 .29794 L
.68478 .16187 L
s
.678 .847 .902 r
.68478 .16187 m
.68478 .29858 L
.68574 .29858 L
.68574 .16187 L
F
.2 .63 .79 r
.68478 .16187 m
.68478 .29858 L
.68574 .29858 L
.68574 .16187 L
s
.678 .847 .902 r
.68574 .16187 m
.68574 .29951 L
.68649 .29951 L
.68649 .16187 L
F
.2 .63 .79 r
.68574 .16187 m
.68574 .29951 L
.68649 .29951 L
.68649 .16187 L
s
.678 .847 .902 r
.68649 .16187 m
.68649 .29977 L
.68698 .29977 L
.68698 .16187 L
F
.2 .63 .79 r
.68649 .16187 m
.68649 .29977 L
.68698 .29977 L
.68698 .16187 L
s
.678 .847 .902 r
.68698 .16187 m
.68698 .30013 L
.6874 .30013 L
.6874 .16187 L
F
.2 .63 .79 r
.68698 .16187 m
.68698 .30013 L
.6874 .30013 L
.6874 .16187 L
s
.678 .847 .902 r
.6874 .16187 m
.6874 .3006 L
.68792 .3006 L
.68792 .16187 L
F
.2 .63 .79 r
.6874 .16187 m
.6874 .3006 L
.68792 .3006 L
.68792 .16187 L
s
.678 .847 .902 r
.68792 .16187 m
.68792 .30131 L
.6885 .30131 L
.6885 .16187 L
F
.2 .63 .79 r
.68792 .16187 m
.68792 .30131 L
.6885 .30131 L
.6885 .16187 L
s
.678 .847 .902 r
.6885 .16187 m
.6885 .30241 L
.68978 .30241 L
.68978 .16187 L
F
.2 .63 .79 r
.6885 .16187 m
.6885 .30241 L
.68978 .30241 L
.68978 .16187 L
s
.678 .847 .902 r
.68978 .16187 m
.68978 .30254 L
.69059 .30254 L
.69059 .16187 L
F
.2 .63 .79 r
.68978 .16187 m
.68978 .30254 L
.69059 .30254 L
.69059 .16187 L
s
.678 .847 .902 r
.69059 .16187 m
.69059 .30411 L
.69169 .30411 L
.69169 .16187 L
F
.2 .63 .79 r
.69059 .16187 m
.69059 .30411 L
.69169 .30411 L
.69169 .16187 L
s
.678 .847 .902 r
.69169 .16187 m
.69169 .30442 L
.69224 .30442 L
.69224 .16187 L
F
.2 .63 .79 r
.69169 .16187 m
.69169 .30442 L
.69224 .30442 L
.69224 .16187 L
s
.678 .847 .902 r
.69224 .16187 m
.69224 .30486 L
.69284 .30486 L
.69284 .16187 L
F
.2 .63 .79 r
.69224 .16187 m
.69224 .30486 L
.69284 .30486 L
.69284 .16187 L
s
.678 .847 .902 r
.69284 .16187 m
.69284 .3057 L
.69398 .3057 L
.69398 .16187 L
F
.2 .63 .79 r
.69284 .16187 m
.69284 .3057 L
.69398 .3057 L
.69398 .16187 L
s
.678 .847 .902 r
.69398 .16187 m
.69398 .30675 L
.69475 .30675 L
.69475 .16187 L
F
.2 .63 .79 r
.69398 .16187 m
.69398 .30675 L
.69475 .30675 L
.69475 .16187 L
s
.678 .847 .902 r
.69475 .16187 m
.69475 .30705 L
.69519 .30705 L
.69519 .16187 L
F
.2 .63 .79 r
.69475 .16187 m
.69475 .30705 L
.69519 .30705 L
.69519 .16187 L
s
.678 .847 .902 r
.69519 .16187 m
.69519 .30755 L
.69607 .30755 L
.69607 .16187 L
F
.2 .63 .79 r
.69519 .16187 m
.69519 .30755 L
.69607 .30755 L
.69607 .16187 L
s
.678 .847 .902 r
.69607 .16187 m
.69607 .30813 L
.69654 .30813 L
.69654 .16187 L
F
.2 .63 .79 r
.69607 .16187 m
.69607 .30813 L
.69654 .30813 L
.69654 .16187 L
s
.678 .847 .902 r
.69654 .16187 m
.69654 .30848 L
.69749 .30848 L
.69749 .16187 L
F
.2 .63 .79 r
.69654 .16187 m
.69654 .30848 L
.69749 .30848 L
.69749 .16187 L
s
.678 .847 .902 r
.69749 .16187 m
.69749 .30941 L
.69842 .30941 L
.69842 .16187 L
F
.2 .63 .79 r
.69749 .16187 m
.69749 .30941 L
.69842 .30941 L
.69842 .16187 L
s
.678 .847 .902 r
.69842 .16187 m
.69842 .3101 L
.69894 .3101 L
.69894 .16187 L
F
.2 .63 .79 r
.69842 .16187 m
.69842 .3101 L
.69894 .3101 L
.69894 .16187 L
s
.678 .847 .902 r
.69894 .16187 m
.69894 .31051 L
.69997 .31051 L
.69997 .16187 L
F
.2 .63 .79 r
.69894 .16187 m
.69894 .31051 L
.69997 .31051 L
.69997 .16187 L
s
.678 .847 .902 r
.69997 .16187 m
.69997 .31157 L
.70044 .31157 L
.70044 .16187 L
F
.2 .63 .79 r
.69997 .16187 m
.69997 .31157 L
.70044 .31157 L
.70044 .16187 L
s
.678 .847 .902 r
.70044 .16187 m
.70044 .31188 L
.70108 .31188 L
.70108 .16187 L
F
.2 .63 .79 r
.70044 .16187 m
.70044 .31188 L
.70108 .31188 L
.70108 .16187 L
s
.678 .847 .902 r
.70108 .16187 m
.70108 .31309 L
.70237 .31309 L
.70237 .16187 L
F
.2 .63 .79 r
.70108 .16187 m
.70108 .31309 L
.70237 .31309 L
.70237 .16187 L
s
.678 .847 .902 r
.70237 .16187 m
.70237 .31377 L
.70304 .31377 L
.70304 .16187 L
F
.2 .63 .79 r
.70237 .16187 m
.70237 .31377 L
.70304 .31377 L
.70304 .16187 L
s
.678 .847 .902 r
.70304 .16187 m
.70304 .31484 L
.70391 .31484 L
.70391 .16187 L
F
.2 .63 .79 r
.70304 .16187 m
.70304 .31484 L
.70391 .31484 L
.70391 .16187 L
s
.678 .847 .902 r
.70391 .16187 m
.70391 .3153 L
.70515 .3153 L
.70515 .16187 L
F
.2 .63 .79 r
.70391 .16187 m
.70391 .3153 L
.70515 .3153 L
.70515 .16187 L
s
.678 .847 .902 r
.70515 .16187 m
.70515 .31643 L
.70635 .31643 L
.70635 .16187 L
F
.2 .63 .79 r
.70515 .16187 m
.70515 .31643 L
.70635 .31643 L
.70635 .16187 L
s
.678 .847 .902 r
.70635 .16187 m
.70635 .31726 L
.70702 .31726 L
.70702 .16187 L
F
.2 .63 .79 r
.70635 .16187 m
.70635 .31726 L
.70702 .31726 L
.70702 .16187 L
s
.678 .847 .902 r
.70702 .16187 m
.70702 .31806 L
.70777 .31806 L
.70777 .16187 L
F
.2 .63 .79 r
.70702 .16187 m
.70702 .31806 L
.70777 .31806 L
.70777 .16187 L
s
.678 .847 .902 r
.70777 .16187 m
.70777 .31888 L
.70883 .31888 L
.70883 .16187 L
F
.2 .63 .79 r
.70777 .16187 m
.70777 .31888 L
.70883 .31888 L
.70883 .16187 L
s
.678 .847 .902 r
.70883 .16187 m
.70883 .31986 L
.71012 .31986 L
.71012 .16187 L
F
.2 .63 .79 r
.70883 .16187 m
.70883 .31986 L
.71012 .31986 L
.71012 .16187 L
s
.678 .847 .902 r
.71012 .16187 m
.71012 .32078 L
.71133 .32078 L
.71133 .16187 L
F
.2 .63 .79 r
.71012 .16187 m
.71012 .32078 L
.71133 .32078 L
.71133 .16187 L
s
.678 .847 .902 r
.71133 .16187 m
.71133 .32212 L
.71234 .32212 L
.71234 .16187 L
F
.2 .63 .79 r
.71133 .16187 m
.71133 .32212 L
.71234 .32212 L
.71234 .16187 L
s
.678 .847 .902 r
.71234 .16187 m
.71234 .32246 L
.71326 .32246 L
.71326 .16187 L
F
.2 .63 .79 r
.71234 .16187 m
.71234 .32246 L
.71326 .32246 L
.71326 .16187 L
s
.678 .847 .902 r
.71326 .16187 m
.71326 .32334 L
.71434 .32334 L
.71434 .16187 L
F
.2 .63 .79 r
.71326 .16187 m
.71326 .32334 L
.71434 .32334 L
.71434 .16187 L
s
.678 .847 .902 r
.71434 .16187 m
.71434 .32452 L
.71482 .32452 L
.71482 .16187 L
F
.2 .63 .79 r
.71434 .16187 m
.71434 .32452 L
.71482 .32452 L
.71482 .16187 L
s
.678 .847 .902 r
.71482 .16187 m
.71482 .32509 L
.71547 .32509 L
.71547 .16187 L
F
.2 .63 .79 r
.71482 .16187 m
.71482 .32509 L
.71547 .32509 L
.71547 .16187 L
s
.678 .847 .902 r
.71547 .16187 m
.71547 .32562 L
.71635 .32562 L
.71635 .16187 L
F
.2 .63 .79 r
.71547 .16187 m
.71547 .32562 L
.71635 .32562 L
.71635 .16187 L
s
.678 .847 .902 r
.71635 .16187 m
.71635 .32636 L
.71696 .32636 L
.71696 .16187 L
F
.2 .63 .79 r
.71635 .16187 m
.71635 .32636 L
.71696 .32636 L
.71696 .16187 L
s
.678 .847 .902 r
.71696 .16187 m
.71696 .3267 L
.71737 .3267 L
.71737 .16187 L
F
.2 .63 .79 r
.71696 .16187 m
.71696 .3267 L
.71737 .3267 L
.71737 .16187 L
s
.678 .847 .902 r
.71737 .16187 m
.71737 .32763 L
.71843 .32763 L
.71843 .16187 L
F
.2 .63 .79 r
.71737 .16187 m
.71737 .32763 L
.71843 .32763 L
.71843 .16187 L
s
.678 .847 .902 r
.71843 .16187 m
.71843 .32825 L
.71974 .32825 L
.71974 .16187 L
F
.2 .63 .79 r
.71843 .16187 m
.71843 .32825 L
.71974 .32825 L
.71974 .16187 L
s
.678 .847 .902 r
.71974 .16187 m
.71974 .32929 L
.72024 .32929 L
.72024 .16187 L
F
.2 .63 .79 r
.71974 .16187 m
.71974 .32929 L
.72024 .32929 L
.72024 .16187 L
s
.678 .847 .902 r
.72024 .16187 m
.72024 .3298 L
.72097 .3298 L
.72097 .16187 L
F
.2 .63 .79 r
.72024 .16187 m
.72024 .3298 L
.72097 .3298 L
.72097 .16187 L
s
.678 .847 .902 r
.72097 .16187 m
.72097 .33048 L
.72197 .33048 L
.72197 .16187 L
F
.2 .63 .79 r
.72097 .16187 m
.72097 .33048 L
.72197 .33048 L
.72197 .16187 L
s
.678 .847 .902 r
.72197 .16187 m
.72197 .33126 L
.72305 .33126 L
.72305 .16187 L
F
.2 .63 .79 r
.72197 .16187 m
.72197 .33126 L
.72305 .33126 L
.72305 .16187 L
s
.678 .847 .902 r
.72305 .16187 m
.72305 .332 L
.72361 .332 L
.72361 .16187 L
F
.2 .63 .79 r
.72305 .16187 m
.72305 .332 L
.72361 .332 L
.72361 .16187 L
s
.678 .847 .902 r
.72361 .16187 m
.72361 .33254 L
.72408 .33254 L
.72408 .16187 L
F
.2 .63 .79 r
.72361 .16187 m
.72361 .33254 L
.72408 .33254 L
.72408 .16187 L
s
.678 .847 .902 r
.72408 .16187 m
.72408 .33315 L
.72461 .33315 L
.72461 .16187 L
F
.2 .63 .79 r
.72408 .16187 m
.72408 .33315 L
.72461 .33315 L
.72461 .16187 L
s
.678 .847 .902 r
.72461 .16187 m
.72461 .33435 L
.72581 .33435 L
.72581 .16187 L
F
.2 .63 .79 r
.72461 .16187 m
.72461 .33435 L
.72581 .33435 L
.72581 .16187 L
s
.678 .847 .902 r
.72581 .16187 m
.72581 .33488 L
.72652 .33488 L
.72652 .16187 L
F
.2 .63 .79 r
.72581 .16187 m
.72581 .33488 L
.72652 .33488 L
.72652 .16187 L
s
.678 .847 .902 r
.72652 .16187 m
.72652 .33587 L
.72768 .33587 L
.72768 .16187 L
F
.2 .63 .79 r
.72652 .16187 m
.72652 .33587 L
.72768 .33587 L
.72768 .16187 L
s
.678 .847 .902 r
.72768 .16187 m
.72768 .33703 L
.72882 .33703 L
.72882 .16187 L
F
.2 .63 .79 r
.72768 .16187 m
.72768 .33703 L
.72882 .33703 L
.72882 .16187 L
s
.678 .847 .902 r
.72882 .16187 m
.72882 .33737 L
.72935 .33737 L
.72935 .16187 L
F
.2 .63 .79 r
.72882 .16187 m
.72882 .33737 L
.72935 .33737 L
.72935 .16187 L
s
.678 .847 .902 r
.72935 .16187 m
.72935 .33776 L
.73014 .33776 L
.73014 .16187 L
F
.2 .63 .79 r
.72935 .16187 m
.72935 .33776 L
.73014 .33776 L
.73014 .16187 L
s
.678 .847 .902 r
.73014 .16187 m
.73014 .33882 L
.73144 .33882 L
.73144 .16187 L
F
.2 .63 .79 r
.73014 .16187 m
.73014 .33882 L
.73144 .33882 L
.73144 .16187 L
s
.678 .847 .902 r
.73144 .16187 m
.73144 .33968 L
.73198 .33968 L
.73198 .16187 L
F
.2 .63 .79 r
.73144 .16187 m
.73144 .33968 L
.73198 .33968 L
.73198 .16187 L
s
.678 .847 .902 r
.73198 .16187 m
.73198 .34024 L
.73295 .34024 L
.73295 .16187 L
F
.2 .63 .79 r
.73198 .16187 m
.73198 .34024 L
.73295 .34024 L
.73295 .16187 L
s
.678 .847 .902 r
.73295 .16187 m
.73295 .34188 L
.734 .34188 L
.734 .16187 L
F
.2 .63 .79 r
.73295 .16187 m
.73295 .34188 L
.734 .34188 L
.734 .16187 L
s
.678 .847 .902 r
.734 .16187 m
.734 .34251 L
.73524 .34251 L
.73524 .16187 L
F
.2 .63 .79 r
.734 .16187 m
.734 .34251 L
.73524 .34251 L
.73524 .16187 L
s
.678 .847 .902 r
.73524 .16187 m
.73524 .34334 L
.73648 .34334 L
.73648 .16187 L
F
.2 .63 .79 r
.73524 .16187 m
.73524 .34334 L
.73648 .34334 L
.73648 .16187 L
s
.678 .847 .902 r
.73648 .16187 m
.73648 .34454 L
.73697 .34454 L
.73697 .16187 L
F
.2 .63 .79 r
.73648 .16187 m
.73648 .34454 L
.73697 .34454 L
.73697 .16187 L
s
.678 .847 .902 r
.73697 .16187 m
.73697 .34484 L
.73782 .34484 L
.73782 .16187 L
F
.2 .63 .79 r
.73697 .16187 m
.73697 .34484 L
.73782 .34484 L
.73782 .16187 L
s
.678 .847 .902 r
.73782 .16187 m
.73782 .34659 L
.73905 .34659 L
.73905 .16187 L
F
.2 .63 .79 r
.73782 .16187 m
.73782 .34659 L
.73905 .34659 L
.73905 .16187 L
s
.678 .847 .902 r
.73905 .16187 m
.73905 .34689 L
.73964 .34689 L
.73964 .16187 L
F
.2 .63 .79 r
.73905 .16187 m
.73905 .34689 L
.73964 .34689 L
.73964 .16187 L
s
.678 .847 .902 r
.73964 .16187 m
.73964 .34732 L
.74018 .34732 L
.74018 .16187 L
F
.2 .63 .79 r
.73964 .16187 m
.73964 .34732 L
.74018 .34732 L
.74018 .16187 L
s
.678 .847 .902 r
.74018 .16187 m
.74018 .34808 L
.74094 .34808 L
.74094 .16187 L
F
.2 .63 .79 r
.74018 .16187 m
.74018 .34808 L
.74094 .34808 L
.74094 .16187 L
s
.678 .847 .902 r
.74094 .16187 m
.74094 .34878 L
.74184 .34878 L
.74184 .16187 L
F
.2 .63 .79 r
.74094 .16187 m
.74094 .34878 L
.74184 .34878 L
.74184 .16187 L
s
.678 .847 .902 r
.74184 .16187 m
.74184 .35014 L
.74279 .35014 L
.74279 .16187 L
F
.2 .63 .79 r
.74184 .16187 m
.74184 .35014 L
.74279 .35014 L
.74279 .16187 L
s
.678 .847 .902 r
.74279 .16187 m
.74279 .35087 L
.74361 .35087 L
.74361 .16187 L
F
.2 .63 .79 r
.74279 .16187 m
.74279 .35087 L
.74361 .35087 L
.74361 .16187 L
s
.678 .847 .902 r
.74361 .16187 m
.74361 .3512 L
.74421 .3512 L
.74421 .16187 L
F
.2 .63 .79 r
.74361 .16187 m
.74361 .3512 L
.74421 .3512 L
.74421 .16187 L
s
.678 .847 .902 r
.74421 .16187 m
.74421 .35176 L
.74505 .35176 L
.74505 .16187 L
F
.2 .63 .79 r
.74421 .16187 m
.74421 .35176 L
.74505 .35176 L
.74505 .16187 L
s
.678 .847 .902 r
.74505 .16187 m
.74505 .35268 L
.74587 .35268 L
.74587 .16187 L
F
.2 .63 .79 r
.74505 .16187 m
.74505 .35268 L
.74587 .35268 L
.74587 .16187 L
s
.678 .847 .902 r
.74587 .16187 m
.74587 .3531 L
.74685 .3531 L
.74685 .16187 L
F
.2 .63 .79 r
.74587 .16187 m
.74587 .3531 L
.74685 .3531 L
.74685 .16187 L
s
.678 .847 .902 r
.74685 .16187 m
.74685 .35503 L
.74809 .35503 L
.74809 .16187 L
F
.2 .63 .79 r
.74685 .16187 m
.74685 .35503 L
.74809 .35503 L
.74809 .16187 L
s
.678 .847 .902 r
.74809 .16187 m
.74809 .35578 L
.74913 .35578 L
.74913 .16187 L
F
.2 .63 .79 r
.74809 .16187 m
.74809 .35578 L
.74913 .35578 L
.74913 .16187 L
s
.678 .847 .902 r
.74913 .16187 m
.74913 .35684 L
.75016 .35684 L
.75016 .16187 L
F
.2 .63 .79 r
.74913 .16187 m
.74913 .35684 L
.75016 .35684 L
.75016 .16187 L
s
.678 .847 .902 r
.75016 .16187 m
.75016 .35775 L
.75101 .35775 L
.75101 .16187 L
F
.2 .63 .79 r
.75016 .16187 m
.75016 .35775 L
.75101 .35775 L
.75101 .16187 L
s
.678 .847 .902 r
.75101 .16187 m
.75101 .35862 L
.75188 .35862 L
.75188 .16187 L
F
.2 .63 .79 r
.75101 .16187 m
.75101 .35862 L
.75188 .35862 L
.75188 .16187 L
s
.678 .847 .902 r
.75188 .16187 m
.75188 .35908 L
.75297 .35908 L
.75297 .16187 L
F
.2 .63 .79 r
.75188 .16187 m
.75188 .35908 L
.75297 .35908 L
.75297 .16187 L
s
.678 .847 .902 r
.75297 .16187 m
.75297 .36034 L
.75387 .36034 L
.75387 .16187 L
F
.2 .63 .79 r
.75297 .16187 m
.75297 .36034 L
.75387 .36034 L
.75387 .16187 L
s
.678 .847 .902 r
.75387 .16187 m
.75387 .36145 L
.75511 .36145 L
.75511 .16187 L
F
.2 .63 .79 r
.75387 .16187 m
.75387 .36145 L
.75511 .36145 L
.75511 .16187 L
s
.678 .847 .902 r
.75511 .16187 m
.75511 .36181 L
.75627 .36181 L
.75627 .16187 L
F
.2 .63 .79 r
.75511 .16187 m
.75511 .36181 L
.75627 .36181 L
.75627 .16187 L
s
.678 .847 .902 r
.75627 .16187 m
.75627 .36394 L
.75748 .36394 L
.75748 .16187 L
F
.2 .63 .79 r
.75627 .16187 m
.75627 .36394 L
.75748 .36394 L
.75748 .16187 L
s
.678 .847 .902 r
.75748 .16187 m
.75748 .36456 L
.7585 .36456 L
.7585 .16187 L
F
.2 .63 .79 r
.75748 .16187 m
.75748 .36456 L
.7585 .36456 L
.7585 .16187 L
s
.678 .847 .902 r
.7585 .16187 m
.7585 .36523 L
.75965 .36523 L
.75965 .16187 L
F
.2 .63 .79 r
.7585 .16187 m
.7585 .36523 L
.75965 .36523 L
.75965 .16187 L
s
.678 .847 .902 r
.75965 .16187 m
.75965 .36673 L
.76037 .36673 L
.76037 .16187 L
F
.2 .63 .79 r
.75965 .16187 m
.75965 .36673 L
.76037 .36673 L
.76037 .16187 L
s
.678 .847 .902 r
.76037 .16187 m
.76037 .3668 L
.7617 .3668 L
.7617 .16187 L
F
.2 .63 .79 r
.76037 .16187 m
.76037 .3668 L
.7617 .3668 L
.7617 .16187 L
s
.678 .847 .902 r
.7617 .16187 m
.7617 .3682 L
.76254 .3682 L
.76254 .16187 L
F
.2 .63 .79 r
.7617 .16187 m
.7617 .3682 L
.76254 .3682 L
.76254 .16187 L
s
.678 .847 .902 r
.76254 .16187 m
.76254 .36891 L
.76355 .36891 L
.76355 .16187 L
F
.2 .63 .79 r
.76254 .16187 m
.76254 .36891 L
.76355 .36891 L
.76355 .16187 L
s
.678 .847 .902 r
.76355 .16187 m
.76355 .37042 L
.76487 .37042 L
.76487 .16187 L
F
.2 .63 .79 r
.76355 .16187 m
.76355 .37042 L
.76487 .37042 L
.76487 .16187 L
s
.678 .847 .902 r
.76487 .16187 m
.76487 .37159 L
.76571 .37159 L
.76571 .16187 L
F
.2 .63 .79 r
.76487 .16187 m
.76487 .37159 L
.76571 .37159 L
.76571 .16187 L
s
.678 .847 .902 r
.76571 .16187 m
.76571 .37216 L
.76696 .37216 L
.76696 .16187 L
F
.2 .63 .79 r
.76571 .16187 m
.76571 .37216 L
.76696 .37216 L
.76696 .16187 L
s
.678 .847 .902 r
.76696 .16187 m
.76696 .37319 L
.76755 .37319 L
.76755 .16187 L
F
.2 .63 .79 r
.76696 .16187 m
.76696 .37319 L
.76755 .37319 L
.76755 .16187 L
s
.678 .847 .902 r
.76755 .16187 m
.76755 .37477 L
.76868 .37477 L
.76868 .16187 L
F
.2 .63 .79 r
.76755 .16187 m
.76755 .37477 L
.76868 .37477 L
.76868 .16187 L
s
.678 .847 .902 r
.76868 .16187 m
.76868 .37514 L
.77003 .37514 L
.77003 .16187 L
F
.2 .63 .79 r
.76868 .16187 m
.76868 .37514 L
.77003 .37514 L
.77003 .16187 L
s
.678 .847 .902 r
.77003 .16187 m
.77003 .37665 L
.77088 .37665 L
.77088 .16187 L
F
.2 .63 .79 r
.77003 .16187 m
.77003 .37665 L
.77088 .37665 L
.77088 .16187 L
s
.678 .847 .902 r
.77088 .16187 m
.77088 .37698 L
.77184 .37698 L
.77184 .16187 L
F
.2 .63 .79 r
.77088 .16187 m
.77088 .37698 L
.77184 .37698 L
.77184 .16187 L
s
.678 .847 .902 r
.77184 .16187 m
.77184 .37793 L
.77308 .37793 L
.77308 .16187 L
F
.2 .63 .79 r
.77184 .16187 m
.77184 .37793 L
.77308 .37793 L
.77308 .16187 L
s
.678 .847 .902 r
.77308 .16187 m
.77308 .37947 L
.7738 .37947 L
.7738 .16187 L
F
.2 .63 .79 r
.77308 .16187 m
.77308 .37947 L
.7738 .37947 L
.7738 .16187 L
s
.678 .847 .902 r
.7738 .16187 m
.7738 .38082 L
.77497 .38082 L
.77497 .16187 L
F
.2 .63 .79 r
.7738 .16187 m
.7738 .38082 L
.77497 .38082 L
.77497 .16187 L
s
.678 .847 .902 r
.77497 .16187 m
.77497 .381 L
.77549 .381 L
.77549 .16187 L
F
.2 .63 .79 r
.77497 .16187 m
.77497 .381 L
.77549 .381 L
.77549 .16187 L
s
.678 .847 .902 r
.77549 .16187 m
.77549 .38153 L
.77627 .38153 L
.77627 .16187 L
F
.2 .63 .79 r
.77549 .16187 m
.77549 .38153 L
.77627 .38153 L
.77627 .16187 L
s
.678 .847 .902 r
.77627 .16187 m
.77627 .38239 L
.77725 .38239 L
.77725 .16187 L
F
.2 .63 .79 r
.77627 .16187 m
.77627 .38239 L
.77725 .38239 L
.77725 .16187 L
s
.678 .847 .902 r
.77725 .16187 m
.77725 .38326 L
.77792 .38326 L
.77792 .16187 L
F
.2 .63 .79 r
.77725 .16187 m
.77725 .38326 L
.77792 .38326 L
.77792 .16187 L
s
.678 .847 .902 r
.77792 .16187 m
.77792 .38409 L
.77856 .38409 L
.77856 .16187 L
F
.2 .63 .79 r
.77792 .16187 m
.77792 .38409 L
.77856 .38409 L
.77856 .16187 L
s
.678 .847 .902 r
.77856 .16187 m
.77856 .38453 L
.77954 .38453 L
.77954 .16187 L
F
.2 .63 .79 r
.77856 .16187 m
.77856 .38453 L
.77954 .38453 L
.77954 .16187 L
s
.678 .847 .902 r
.77954 .16187 m
.77954 .38569 L
.78066 .38569 L
.78066 .16187 L
F
.2 .63 .79 r
.77954 .16187 m
.77954 .38569 L
.78066 .38569 L
.78066 .16187 L
s
.678 .847 .902 r
.78066 .16187 m
.78066 .38713 L
.78166 .38713 L
.78166 .16187 L
F
.2 .63 .79 r
.78066 .16187 m
.78066 .38713 L
.78166 .38713 L
.78166 .16187 L
s
.678 .847 .902 r
.78166 .16187 m
.78166 .38769 L
.78252 .38769 L
.78252 .16187 L
F
.2 .63 .79 r
.78166 .16187 m
.78166 .38769 L
.78252 .38769 L
.78252 .16187 L
s
.678 .847 .902 r
.78252 .16187 m
.78252 .3884 L
.78318 .3884 L
.78318 .16187 L
F
.2 .63 .79 r
.78252 .16187 m
.78252 .3884 L
.78318 .3884 L
.78318 .16187 L
s
.678 .847 .902 r
.78318 .16187 m
.78318 .38925 L
.78432 .38925 L
.78432 .16187 L
F
.2 .63 .79 r
.78318 .16187 m
.78318 .38925 L
.78432 .38925 L
.78432 .16187 L
s
.678 .847 .902 r
.78432 .16187 m
.78432 .39033 L
.78489 .39033 L
.78489 .16187 L
F
.2 .63 .79 r
.78432 .16187 m
.78432 .39033 L
.78489 .39033 L
.78489 .16187 L
s
.678 .847 .902 r
.78489 .16187 m
.78489 .39091 L
.78609 .39091 L
.78609 .16187 L
F
.2 .63 .79 r
.78489 .16187 m
.78489 .39091 L
.78609 .39091 L
.78609 .16187 L
s
.678 .847 .902 r
.78609 .16187 m
.78609 .3923 L
.78678 .3923 L
.78678 .16187 L
F
.2 .63 .79 r
.78609 .16187 m
.78609 .3923 L
.78678 .3923 L
.78678 .16187 L
s
.678 .847 .902 r
.78678 .16187 m
.78678 .39296 L
.7875 .39296 L
.7875 .16187 L
F
.2 .63 .79 r
.78678 .16187 m
.78678 .39296 L
.7875 .39296 L
.7875 .16187 L
s
.678 .847 .902 r
.7875 .16187 m
.7875 .39338 L
.78817 .39338 L
.78817 .16187 L
F
.2 .63 .79 r
.7875 .16187 m
.7875 .39338 L
.78817 .39338 L
.78817 .16187 L
s
.678 .847 .902 r
.78817 .16187 m
.78817 .39396 L
.78918 .39396 L
.78918 .16187 L
F
.2 .63 .79 r
.78817 .16187 m
.78817 .39396 L
.78918 .39396 L
.78918 .16187 L
s
.678 .847 .902 r
.78918 .16187 m
.78918 .39554 L
.7901 .39554 L
.7901 .16187 L
F
.2 .63 .79 r
.78918 .16187 m
.78918 .39554 L
.7901 .39554 L
.7901 .16187 L
s
.678 .847 .902 r
.7901 .16187 m
.7901 .39606 L
.79083 .39606 L
.79083 .16187 L
F
.2 .63 .79 r
.7901 .16187 m
.7901 .39606 L
.79083 .39606 L
.79083 .16187 L
s
.678 .847 .902 r
.79083 .16187 m
.79083 .39718 L
.792 .39718 L
.792 .16187 L
F
.2 .63 .79 r
.79083 .16187 m
.79083 .39718 L
.792 .39718 L
.792 .16187 L
s
.678 .847 .902 r
.792 .16187 m
.792 .39768 L
.79246 .39768 L
.79246 .16187 L
F
.2 .63 .79 r
.792 .16187 m
.792 .39768 L
.79246 .39768 L
.79246 .16187 L
s
.678 .847 .902 r
.79246 .16187 m
.79246 .3988 L
.79349 .3988 L
.79349 .16187 L
F
.2 .63 .79 r
.79246 .16187 m
.79246 .3988 L
.79349 .3988 L
.79349 .16187 L
s
.678 .847 .902 r
.79349 .16187 m
.79349 .39947 L
.79391 .39947 L
.79391 .16187 L
F
.2 .63 .79 r
.79349 .16187 m
.79349 .39947 L
.79391 .39947 L
.79391 .16187 L
s
.678 .847 .902 r
.79391 .16187 m
.79391 .39983 L
.79432 .39983 L
.79432 .16187 L
F
.2 .63 .79 r
.79391 .16187 m
.79391 .39983 L
.79432 .39983 L
.79432 .16187 L
s
.678 .847 .902 r
.79432 .16187 m
.79432 .40097 L
.79562 .40097 L
.79562 .16187 L
F
.2 .63 .79 r
.79432 .16187 m
.79432 .40097 L
.79562 .40097 L
.79562 .16187 L
s
.678 .847 .902 r
.79562 .16187 m
.79562 .40158 L
.79627 .40158 L
.79627 .16187 L
F
.2 .63 .79 r
.79562 .16187 m
.79562 .40158 L
.79627 .40158 L
.79627 .16187 L
s
.678 .847 .902 r
.79627 .16187 m
.79627 .40234 L
.79707 .40234 L
.79707 .16187 L
F
.2 .63 .79 r
.79627 .16187 m
.79627 .40234 L
.79707 .40234 L
.79707 .16187 L
s
.678 .847 .902 r
.79707 .16187 m
.79707 .40315 L
.79816 .40315 L
.79816 .16187 L
F
.2 .63 .79 r
.79707 .16187 m
.79707 .40315 L
.79816 .40315 L
.79816 .16187 L
s
.678 .847 .902 r
.79816 .16187 m
.79816 .40408 L
.79922 .40408 L
.79922 .16187 L
F
.2 .63 .79 r
.79816 .16187 m
.79816 .40408 L
.79922 .40408 L
.79922 .16187 L
s
.678 .847 .902 r
.79922 .16187 m
.79922 .40522 L
.80025 .40522 L
.80025 .16187 L
F
.2 .63 .79 r
.79922 .16187 m
.79922 .40522 L
.80025 .40522 L
.80025 .16187 L
s
.678 .847 .902 r
.80025 .16187 m
.80025 .40613 L
.80128 .40613 L
.80128 .16187 L
F
.2 .63 .79 r
.80025 .16187 m
.80025 .40613 L
.80128 .40613 L
.80128 .16187 L
s
.678 .847 .902 r
.80128 .16187 m
.80128 .40732 L
.80178 .40732 L
.80178 .16187 L
F
.2 .63 .79 r
.80128 .16187 m
.80128 .40732 L
.80178 .40732 L
.80178 .16187 L
s
.678 .847 .902 r
.80178 .16187 m
.80178 .40805 L
.8024 .40805 L
.8024 .16187 L
F
.2 .63 .79 r
.80178 .16187 m
.80178 .40805 L
.8024 .40805 L
.8024 .16187 L
s
.678 .847 .902 r
.8024 .16187 m
.8024 .40817 L
.80317 .40817 L
.80317 .16187 L
F
.2 .63 .79 r
.8024 .16187 m
.8024 .40817 L
.80317 .40817 L
.80317 .16187 L
s
.678 .847 .902 r
.80317 .16187 m
.80317 .40999 L
.80441 .40999 L
.80441 .16187 L
F
.2 .63 .79 r
.80317 .16187 m
.80317 .40999 L
.80441 .40999 L
.80441 .16187 L
s
.678 .847 .902 r
.80441 .16187 m
.80441 .41038 L
.8057 .41038 L
.8057 .16187 L
F
.2 .63 .79 r
.80441 .16187 m
.80441 .41038 L
.8057 .41038 L
.8057 .16187 L
s
.678 .847 .902 r
.8057 .16187 m
.8057 .41196 L
.80647 .41196 L
.80647 .16187 L
F
.2 .63 .79 r
.8057 .16187 m
.8057 .41196 L
.80647 .41196 L
.80647 .16187 L
s
.678 .847 .902 r
.80647 .16187 m
.80647 .4124 L
.80696 .4124 L
.80696 .16187 L
F
.2 .63 .79 r
.80647 .16187 m
.80647 .4124 L
.80696 .4124 L
.80696 .16187 L
s
.678 .847 .902 r
.80696 .16187 m
.80696 .41291 L
.80789 .41291 L
.80789 .16187 L
F
.2 .63 .79 r
.80696 .16187 m
.80696 .41291 L
.80789 .41291 L
.80789 .16187 L
s
.678 .847 .902 r
.80789 .16187 m
.80789 .4146 L
.80891 .4146 L
.80891 .16187 L
F
.2 .63 .79 r
.80789 .16187 m
.80789 .4146 L
.80891 .4146 L
.80891 .16187 L
s
.678 .847 .902 r
.80891 .16187 m
.80891 .41532 L
.81002 .41532 L
.81002 .16187 L
F
.2 .63 .79 r
.80891 .16187 m
.80891 .41532 L
.81002 .41532 L
.81002 .16187 L
s
.678 .847 .902 r
.81002 .16187 m
.81002 .41641 L
.81095 .41641 L
.81095 .16187 L
F
.2 .63 .79 r
.81002 .16187 m
.81002 .41641 L
.81095 .41641 L
.81095 .16187 L
s
.678 .847 .902 r
.81095 .16187 m
.81095 .41729 L
.81156 .41729 L
.81156 .16187 L
F
.2 .63 .79 r
.81095 .16187 m
.81095 .41729 L
.81156 .41729 L
.81156 .16187 L
s
.678 .847 .902 r
.81156 .16187 m
.81156 .41779 L
.81276 .41779 L
.81276 .16187 L
F
.2 .63 .79 r
.81156 .16187 m
.81156 .41779 L
.81276 .41779 L
.81276 .16187 L
s
.678 .847 .902 r
.81276 .16187 m
.81276 .41921 L
.81382 .41921 L
.81382 .16187 L
F
.2 .63 .79 r
.81276 .16187 m
.81276 .41921 L
.81382 .41921 L
.81382 .16187 L
s
.678 .847 .902 r
.81382 .16187 m
.81382 .42093 L
.81507 .42093 L
.81507 .16187 L
F
.2 .63 .79 r
.81382 .16187 m
.81382 .42093 L
.81507 .42093 L
.81507 .16187 L
s
.678 .847 .902 r
.81507 .16187 m
.81507 .42104 L
.81566 .42104 L
.81566 .16187 L
F
.2 .63 .79 r
.81507 .16187 m
.81507 .42104 L
.81566 .42104 L
.81566 .16187 L
s
.678 .847 .902 r
.81566 .16187 m
.81566 .42245 L
.81686 .42245 L
.81686 .16187 L
F
.2 .63 .79 r
.81566 .16187 m
.81566 .42245 L
.81686 .42245 L
.81686 .16187 L
s
.678 .847 .902 r
.81686 .16187 m
.81686 .42373 L
.81798 .42373 L
.81798 .16187 L
F
.2 .63 .79 r
.81686 .16187 m
.81686 .42373 L
.81798 .42373 L
.81798 .16187 L
s
.678 .847 .902 r
.81798 .16187 m
.81798 .4245 L
.81899 .4245 L
.81899 .16187 L
F
.2 .63 .79 r
.81798 .16187 m
.81798 .4245 L
.81899 .4245 L
.81899 .16187 L
s
.678 .847 .902 r
.81899 .16187 m
.81899 .42568 L
.82014 .42568 L
.82014 .16187 L
F
.2 .63 .79 r
.81899 .16187 m
.81899 .42568 L
.82014 .42568 L
.82014 .16187 L
s
.678 .847 .902 r
.82014 .16187 m
.82014 .42639 L
.82065 .42639 L
.82065 .16187 L
F
.2 .63 .79 r
.82014 .16187 m
.82014 .42639 L
.82065 .42639 L
.82065 .16187 L
s
.678 .847 .902 r
.82065 .16187 m
.82065 .42701 L
.82111 .42701 L
.82111 .16187 L
F
.2 .63 .79 r
.82065 .16187 m
.82065 .42701 L
.82111 .42701 L
.82111 .16187 L
s
.678 .847 .902 r
.82111 .16187 m
.82111 .42748 L
.82244 .42748 L
.82244 .16187 L
F
.2 .63 .79 r
.82111 .16187 m
.82111 .42748 L
.82244 .42748 L
.82244 .16187 L
s
.678 .847 .902 r
.82244 .16187 m
.82244 .42881 L
.82298 .42881 L
.82298 .16187 L
F
.2 .63 .79 r
.82244 .16187 m
.82244 .42881 L
.82298 .42881 L
.82298 .16187 L
s
.678 .847 .902 r
.82298 .16187 m
.82298 .42943 L
.82339 .42943 L
.82339 .16187 L
F
.2 .63 .79 r
.82298 .16187 m
.82298 .42943 L
.82339 .42943 L
.82339 .16187 L
s
.678 .847 .902 r
.82339 .16187 m
.82339 .43036 L
.82459 .43036 L
.82459 .16187 L
F
.2 .63 .79 r
.82339 .16187 m
.82339 .43036 L
.82459 .43036 L
.82459 .16187 L
s
.678 .847 .902 r
.82459 .16187 m
.82459 .43093 L
.82556 .43093 L
.82556 .16187 L
F
.2 .63 .79 r
.82459 .16187 m
.82459 .43093 L
.82556 .43093 L
.82556 .16187 L
s
.678 .847 .902 r
.82556 .16187 m
.82556 .43216 L
.8262 .43216 L
.8262 .16187 L
F
.2 .63 .79 r
.82556 .16187 m
.82556 .43216 L
.8262 .43216 L
.8262 .16187 L
s
.678 .847 .902 r
.8262 .16187 m
.8262 .43274 L
.82669 .43274 L
.82669 .16187 L
F
.2 .63 .79 r
.8262 .16187 m
.8262 .43274 L
.82669 .43274 L
.82669 .16187 L
s
.678 .847 .902 r
.82669 .16187 m
.82669 .43386 L
.82752 .43386 L
.82752 .16187 L
F
.2 .63 .79 r
.82669 .16187 m
.82669 .43386 L
.82752 .43386 L
.82752 .16187 L
s
.678 .847 .902 r
.82752 .16187 m
.82752 .43458 L
.82841 .43458 L
.82841 .16187 L
F
.2 .63 .79 r
.82752 .16187 m
.82752 .43458 L
.82841 .43458 L
.82841 .16187 L
s
.678 .847 .902 r
.82841 .16187 m
.82841 .43511 L
.82948 .43511 L
.82948 .16187 L
F
.2 .63 .79 r
.82841 .16187 m
.82841 .43511 L
.82948 .43511 L
.82948 .16187 L
s
.678 .847 .902 r
.82948 .16187 m
.82948 .43639 L
.8303 .43639 L
.8303 .16187 L
F
.2 .63 .79 r
.82948 .16187 m
.82948 .43639 L
.8303 .43639 L
.8303 .16187 L
s
.678 .847 .902 r
.8303 .16187 m
.8303 .43726 L
.83138 .43726 L
.83138 .16187 L
F
.2 .63 .79 r
.8303 .16187 m
.8303 .43726 L
.83138 .43726 L
.83138 .16187 L
s
.678 .847 .902 r
.83138 .16187 m
.83138 .43812 L
.83269 .43812 L
.83269 .16187 L
F
.2 .63 .79 r
.83138 .16187 m
.83138 .43812 L
.83269 .43812 L
.83269 .16187 L
s
.678 .847 .902 r
.83269 .16187 m
.83269 .43972 L
.83356 .43972 L
.83356 .16187 L
F
.2 .63 .79 r
.83269 .16187 m
.83269 .43972 L
.83356 .43972 L
.83356 .16187 L
s
.678 .847 .902 r
.83356 .16187 m
.83356 .44044 L
.83454 .44044 L
.83454 .16187 L
F
.2 .63 .79 r
.83356 .16187 m
.83356 .44044 L
.83454 .44044 L
.83454 .16187 L
s
.678 .847 .902 r
.83454 .16187 m
.83454 .44164 L
.83496 .44164 L
.83496 .16187 L
F
.2 .63 .79 r
.83454 .16187 m
.83454 .44164 L
.83496 .44164 L
.83496 .16187 L
s
.678 .847 .902 r
.83496 .16187 m
.83496 .44179 L
.83543 .44179 L
.83543 .16187 L
F
.2 .63 .79 r
.83496 .16187 m
.83496 .44179 L
.83543 .44179 L
.83543 .16187 L
s
.678 .847 .902 r
.83543 .16187 m
.83543 .44247 L
.83611 .44247 L
.83611 .16187 L
F
.2 .63 .79 r
.83543 .16187 m
.83543 .44247 L
.83611 .44247 L
.83611 .16187 L
s
.678 .847 .902 r
.83611 .16187 m
.83611 .44354 L
.83724 .44354 L
.83724 .16187 L
F
.2 .63 .79 r
.83611 .16187 m
.83611 .44354 L
.83724 .44354 L
.83724 .16187 L
s
.678 .847 .902 r
.83724 .16187 m
.83724 .44419 L
.8379 .44419 L
.8379 .16187 L
F
.2 .63 .79 r
.83724 .16187 m
.83724 .44419 L
.8379 .44419 L
.8379 .16187 L
s
.678 .847 .902 r
.8379 .16187 m
.8379 .44541 L
.83872 .44541 L
.83872 .16187 L
F
.2 .63 .79 r
.8379 .16187 m
.8379 .44541 L
.83872 .44541 L
.83872 .16187 L
s
.678 .847 .902 r
.83872 .16187 m
.83872 .44646 L
.8396 .44646 L
.8396 .16187 L
F
.2 .63 .79 r
.83872 .16187 m
.83872 .44646 L
.8396 .44646 L
.8396 .16187 L
s
.678 .847 .902 r
.8396 .16187 m
.8396 .44686 L
.84063 .44686 L
.84063 .16187 L
F
.2 .63 .79 r
.8396 .16187 m
.8396 .44686 L
.84063 .44686 L
.84063 .16187 L
s
.678 .847 .902 r
.84063 .16187 m
.84063 .44807 L
.84123 .44807 L
.84123 .16187 L
F
.2 .63 .79 r
.84063 .16187 m
.84063 .44807 L
.84123 .44807 L
.84123 .16187 L
s
.678 .847 .902 r
.84123 .16187 m
.84123 .4488 L
.84207 .4488 L
.84207 .16187 L
F
.2 .63 .79 r
.84123 .16187 m
.84123 .4488 L
.84207 .4488 L
.84207 .16187 L
s
.678 .847 .902 r
.84207 .16187 m
.84207 .44962 L
.84283 .44962 L
.84283 .16187 L
F
.2 .63 .79 r
.84207 .16187 m
.84207 .44962 L
.84283 .44962 L
.84283 .16187 L
s
.678 .847 .902 r
.84283 .16187 m
.84283 .45072 L
.84385 .45072 L
.84385 .16187 L
F
.2 .63 .79 r
.84283 .16187 m
.84283 .45072 L
.84385 .45072 L
.84385 .16187 L
s
.678 .847 .902 r
.84385 .16187 m
.84385 .4519 L
.84461 .4519 L
.84461 .16187 L
F
.2 .63 .79 r
.84385 .16187 m
.84385 .4519 L
.84461 .4519 L
.84461 .16187 L
s
.678 .847 .902 r
.84461 .16187 m
.84461 .4525 L
.84583 .4525 L
.84583 .16187 L
F
.2 .63 .79 r
.84461 .16187 m
.84461 .4525 L
.84583 .4525 L
.84583 .16187 L
s
.678 .847 .902 r
.84583 .16187 m
.84583 .45324 L
.84635 .45324 L
.84635 .16187 L
F
.2 .63 .79 r
.84583 .16187 m
.84583 .45324 L
.84635 .45324 L
.84635 .16187 L
s
.678 .847 .902 r
.84635 .16187 m
.84635 .454 L
.84729 .454 L
.84729 .16187 L
F
.2 .63 .79 r
.84635 .16187 m
.84635 .454 L
.84729 .454 L
.84729 .16187 L
s
.678 .847 .902 r
.84729 .16187 m
.84729 .45481 L
.84858 .45481 L
.84858 .16187 L
F
.2 .63 .79 r
.84729 .16187 m
.84729 .45481 L
.84858 .45481 L
.84858 .16187 L
s
.678 .847 .902 r
.84858 .16187 m
.84858 .45672 L
.84932 .45672 L
.84932 .16187 L
F
.2 .63 .79 r
.84858 .16187 m
.84858 .45672 L
.84932 .45672 L
.84932 .16187 L
s
.678 .847 .902 r
.84932 .16187 m
.84932 .45762 L
.85012 .45762 L
.85012 .16187 L
F
.2 .63 .79 r
.84932 .16187 m
.84932 .45762 L
.85012 .45762 L
.85012 .16187 L
s
.678 .847 .902 r
.85012 .16187 m
.85012 .4582 L
.85064 .4582 L
.85064 .16187 L
F
.2 .63 .79 r
.85012 .16187 m
.85012 .4582 L
.85064 .4582 L
.85064 .16187 L
s
.678 .847 .902 r
.85064 .16187 m
.85064 .45878 L
.85126 .45878 L
.85126 .16187 L
F
.2 .63 .79 r
.85064 .16187 m
.85064 .45878 L
.85126 .45878 L
.85126 .16187 L
s
.678 .847 .902 r
.85126 .16187 m
.85126 .45952 L
.85205 .45952 L
.85205 .16187 L
F
.2 .63 .79 r
.85126 .16187 m
.85126 .45952 L
.85205 .45952 L
.85205 .16187 L
s
.678 .847 .902 r
.85205 .16187 m
.85205 .46035 L
.85334 .46035 L
.85334 .16187 L
F
.2 .63 .79 r
.85205 .16187 m
.85205 .46035 L
.85334 .46035 L
.85334 .16187 L
s
.678 .847 .902 r
.85334 .16187 m
.85334 .46174 L
.85424 .46174 L
.85424 .16187 L
F
.2 .63 .79 r
.85334 .16187 m
.85334 .46174 L
.85424 .46174 L
.85424 .16187 L
s
.678 .847 .902 r
.85424 .16187 m
.85424 .46271 L
.85484 .46271 L
.85484 .16187 L
F
.2 .63 .79 r
.85424 .16187 m
.85424 .46271 L
.85484 .46271 L
.85484 .16187 L
s
.678 .847 .902 r
.85484 .16187 m
.85484 .46318 L
.85557 .46318 L
.85557 .16187 L
F
.2 .63 .79 r
.85484 .16187 m
.85484 .46318 L
.85557 .46318 L
.85557 .16187 L
s
.678 .847 .902 r
.85557 .16187 m
.85557 .46469 L
.85658 .46469 L
.85658 .16187 L
F
.2 .63 .79 r
.85557 .16187 m
.85557 .46469 L
.85658 .46469 L
.85658 .16187 L
s
.678 .847 .902 r
.85658 .16187 m
.85658 .46592 L
.8577 .46592 L
.8577 .16187 L
F
.2 .63 .79 r
.85658 .16187 m
.85658 .46592 L
.8577 .46592 L
.8577 .16187 L
s
.678 .847 .902 r
.8577 .16187 m
.8577 .46683 L
.859 .46683 L
.859 .16187 L
F
.2 .63 .79 r
.8577 .16187 m
.8577 .46683 L
.859 .46683 L
.859 .16187 L
s
.678 .847 .902 r
.859 .16187 m
.859 .4683 L
.86027 .4683 L
.86027 .16187 L
F
.2 .63 .79 r
.859 .16187 m
.859 .4683 L
.86027 .4683 L
.86027 .16187 L
s
.678 .847 .902 r
.86027 .16187 m
.86027 .46879 L
.8608 .46879 L
.8608 .16187 L
F
.2 .63 .79 r
.86027 .16187 m
.86027 .46879 L
.8608 .46879 L
.8608 .16187 L
s
.678 .847 .902 r
.8608 .16187 m
.8608 .46971 L
.86129 .46971 L
.86129 .16187 L
F
.2 .63 .79 r
.8608 .16187 m
.8608 .46971 L
.86129 .46971 L
.86129 .16187 L
s
.678 .847 .902 r
.86129 .16187 m
.86129 .46988 L
.8624 .46988 L
.8624 .16187 L
F
.2 .63 .79 r
.86129 .16187 m
.86129 .46988 L
.8624 .46988 L
.8624 .16187 L
s
.678 .847 .902 r
.8624 .16187 m
.8624 .4712 L
.86324 .4712 L
.86324 .16187 L
F
.2 .63 .79 r
.8624 .16187 m
.8624 .4712 L
.86324 .4712 L
.86324 .16187 L
s
.678 .847 .902 r
.86324 .16187 m
.86324 .47267 L
.86437 .47267 L
.86437 .16187 L
F
.2 .63 .79 r
.86324 .16187 m
.86324 .47267 L
.86437 .47267 L
.86437 .16187 L
s
.678 .847 .902 r
.86437 .16187 m
.86437 .47328 L
.8652 .47328 L
.8652 .16187 L
F
.2 .63 .79 r
.86437 .16187 m
.86437 .47328 L
.8652 .47328 L
.8652 .16187 L
s
.678 .847 .902 r
.8652 .16187 m
.8652 .47414 L
.86595 .47414 L
.86595 .16187 L
F
.2 .63 .79 r
.8652 .16187 m
.8652 .47414 L
.86595 .47414 L
.86595 .16187 L
s
.678 .847 .902 r
.86595 .16187 m
.86595 .47567 L
.86691 .47567 L
.86691 .16187 L
F
.2 .63 .79 r
.86595 .16187 m
.86595 .47567 L
.86691 .47567 L
.86691 .16187 L
s
.678 .847 .902 r
.86691 .16187 m
.86691 .47657 L
.86794 .47657 L
.86794 .16187 L
F
.2 .63 .79 r
.86691 .16187 m
.86691 .47657 L
.86794 .47657 L
.86794 .16187 L
s
.678 .847 .902 r
.86794 .16187 m
.86794 .47826 L
.86918 .47826 L
.86918 .16187 L
F
.2 .63 .79 r
.86794 .16187 m
.86794 .47826 L
.86918 .47826 L
.86918 .16187 L
s
.678 .847 .902 r
.86918 .16187 m
.86918 .47848 L
.87 .47848 L
.87 .16187 L
F
.2 .63 .79 r
.86918 .16187 m
.86918 .47848 L
.87 .47848 L
.87 .16187 L
s
.678 .847 .902 r
.87 .16187 m
.87 .48005 L
.87063 .48005 L
.87063 .16187 L
F
.2 .63 .79 r
.87 .16187 m
.87 .48005 L
.87063 .48005 L
.87063 .16187 L
s
.678 .847 .902 r
.87063 .16187 m
.87063 .48057 L
.87126 .48057 L
.87126 .16187 L
F
.2 .63 .79 r
.87063 .16187 m
.87063 .48057 L
.87126 .48057 L
.87126 .16187 L
s
.678 .847 .902 r
.87126 .16187 m
.87126 .48093 L
.87238 .48093 L
.87238 .16187 L
F
.2 .63 .79 r
.87126 .16187 m
.87126 .48093 L
.87238 .48093 L
.87238 .16187 L
s
.678 .847 .902 r
.87238 .16187 m
.87238 .48225 L
.87299 .48225 L
.87299 .16187 L
F
.2 .63 .79 r
.87238 .16187 m
.87238 .48225 L
.87299 .48225 L
.87299 .16187 L
s
.678 .847 .902 r
.87299 .16187 m
.87299 .48319 L
.87419 .48319 L
.87419 .16187 L
F
.2 .63 .79 r
.87299 .16187 m
.87299 .48319 L
.87419 .48319 L
.87419 .16187 L
s
.678 .847 .902 r
.87419 .16187 m
.87419 .48428 L
.87489 .48428 L
.87489 .16187 L
F
.2 .63 .79 r
.87419 .16187 m
.87419 .48428 L
.87489 .48428 L
.87489 .16187 L
s
.678 .847 .902 r
.87489 .16187 m
.87489 .48521 L
.87552 .48521 L
.87552 .16187 L
F
.2 .63 .79 r
.87489 .16187 m
.87489 .48521 L
.87552 .48521 L
.87552 .16187 L
s
.678 .847 .902 r
.87552 .16187 m
.87552 .48575 L
.87593 .48575 L
.87593 .16187 L
F
.2 .63 .79 r
.87552 .16187 m
.87552 .48575 L
.87593 .48575 L
.87593 .16187 L
s
.678 .847 .902 r
.87593 .16187 m
.87593 .48592 L
.8768 .48592 L
.8768 .16187 L
F
.2 .63 .79 r
.87593 .16187 m
.87593 .48592 L
.8768 .48592 L
.8768 .16187 L
s
.678 .847 .902 r
.8768 .16187 m
.8768 .48739 L
.87785 .48739 L
.87785 .16187 L
F
.2 .63 .79 r
.8768 .16187 m
.8768 .48739 L
.87785 .48739 L
.87785 .16187 L
s
.678 .847 .902 r
.87785 .16187 m
.87785 .4887 L
.87872 .4887 L
.87872 .16187 L
F
.2 .63 .79 r
.87785 .16187 m
.87785 .4887 L
.87872 .4887 L
.87872 .16187 L
s
.678 .847 .902 r
.87872 .16187 m
.87872 .48902 L
.87918 .48902 L
.87918 .16187 L
F
.2 .63 .79 r
.87872 .16187 m
.87872 .48902 L
.87918 .48902 L
.87918 .16187 L
s
.678 .847 .902 r
.87918 .16187 m
.87918 .48987 L
.88014 .48987 L
.88014 .16187 L
F
.2 .63 .79 r
.87918 .16187 m
.87918 .48987 L
.88014 .48987 L
.88014 .16187 L
s
.678 .847 .902 r
.88014 .16187 m
.88014 .49096 L
.88106 .49096 L
.88106 .16187 L
F
.2 .63 .79 r
.88014 .16187 m
.88014 .49096 L
.88106 .49096 L
.88106 .16187 L
s
.678 .847 .902 r
.88106 .16187 m
.88106 .49245 L
.88184 .49245 L
.88184 .16187 L
F
.2 .63 .79 r
.88106 .16187 m
.88106 .49245 L
.88184 .49245 L
.88184 .16187 L
s
.678 .847 .902 r
.88184 .16187 m
.88184 .49249 L
.88255 .49249 L
.88255 .16187 L
F
.2 .63 .79 r
.88184 .16187 m
.88184 .49249 L
.88255 .49249 L
.88255 .16187 L
s
.678 .847 .902 r
.88255 .16187 m
.88255 .49338 L
.88309 .49338 L
.88309 .16187 L
F
.2 .63 .79 r
.88255 .16187 m
.88255 .49338 L
.88309 .49338 L
.88309 .16187 L
s
.678 .847 .902 r
.88309 .16187 m
.88309 .49489 L
.88423 .49489 L
.88423 .16187 L
F
.2 .63 .79 r
.88309 .16187 m
.88309 .49489 L
.88423 .49489 L
.88423 .16187 L
s
.678 .847 .902 r
.88423 .16187 m
.88423 .49645 L
.88554 .49645 L
.88554 .16187 L
F
.2 .63 .79 r
.88423 .16187 m
.88423 .49645 L
.88554 .49645 L
.88554 .16187 L
s
.678 .847 .902 r
.88554 .16187 m
.88554 .49804 L
.88685 .49804 L
.88685 .16187 L
F
.2 .63 .79 r
.88554 .16187 m
.88554 .49804 L
.88685 .49804 L
.88685 .16187 L
s
.678 .847 .902 r
.88685 .16187 m
.88685 .49859 L
.88777 .49859 L
.88777 .16187 L
F
.2 .63 .79 r
.88685 .16187 m
.88685 .49859 L
.88777 .49859 L
.88777 .16187 L
s
.678 .847 .902 r
.88777 .16187 m
.88777 .49928 L
.8883 .49928 L
.8883 .16187 L
F
.2 .63 .79 r
.88777 .16187 m
.88777 .49928 L
.8883 .49928 L
.8883 .16187 L
s
.678 .847 .902 r
.8883 .16187 m
.8883 .49972 L
.88877 .49972 L
.88877 .16187 L
F
.2 .63 .79 r
.8883 .16187 m
.8883 .49972 L
.88877 .49972 L
.88877 .16187 L
s
.678 .847 .902 r
.88877 .16187 m
.88877 .50121 L
.88967 .50121 L
.88967 .16187 L
F
.2 .63 .79 r
.88877 .16187 m
.88877 .50121 L
.88967 .50121 L
.88967 .16187 L
s
.678 .847 .902 r
.88967 .16187 m
.88967 .50165 L
.89037 .50165 L
.89037 .16187 L
F
.2 .63 .79 r
.88967 .16187 m
.88967 .50165 L
.89037 .50165 L
.89037 .16187 L
s
.678 .847 .902 r
.89037 .16187 m
.89037 .50283 L
.89162 .50283 L
.89162 .16187 L
F
.2 .63 .79 r
.89037 .16187 m
.89037 .50283 L
.89162 .50283 L
.89162 .16187 L
s
.678 .847 .902 r
.89162 .16187 m
.89162 .50415 L
.89232 .50415 L
.89232 .16187 L
F
.2 .63 .79 r
.89162 .16187 m
.89162 .50415 L
.89232 .50415 L
.89232 .16187 L
s
.678 .847 .902 r
.89232 .16187 m
.89232 .50469 L
.89302 .50469 L
.89302 .16187 L
F
.2 .63 .79 r
.89232 .16187 m
.89232 .50469 L
.89302 .50469 L
.89302 .16187 L
s
.678 .847 .902 r
.89302 .16187 m
.89302 .50513 L
.89388 .50513 L
.89388 .16187 L
F
.2 .63 .79 r
.89302 .16187 m
.89302 .50513 L
.89388 .50513 L
.89388 .16187 L
s
.678 .847 .902 r
.89388 .16187 m
.89388 .50619 L
.89484 .50619 L
.89484 .16187 L
F
.2 .63 .79 r
.89388 .16187 m
.89388 .50619 L
.89484 .50619 L
.89484 .16187 L
s
.678 .847 .902 r
.89484 .16187 m
.89484 .50721 L
.89531 .50721 L
.89531 .16187 L
F
.2 .63 .79 r
.89484 .16187 m
.89484 .50721 L
.89531 .50721 L
.89531 .16187 L
s
.678 .847 .902 r
.89531 .16187 m
.89531 .50835 L
.89601 .50835 L
.89601 .16187 L
F
.2 .63 .79 r
.89531 .16187 m
.89531 .50835 L
.89601 .50835 L
.89601 .16187 L
s
.678 .847 .902 r
.89601 .16187 m
.89601 .50857 L
.89735 .50857 L
.89735 .16187 L
F
.2 .63 .79 r
.89601 .16187 m
.89601 .50857 L
.89735 .50857 L
.89735 .16187 L
s
.678 .847 .902 r
.89735 .16187 m
.89735 .51099 L
.89862 .51099 L
.89862 .16187 L
F
.2 .63 .79 r
.89735 .16187 m
.89735 .51099 L
.89862 .51099 L
.89862 .16187 L
s
.678 .847 .902 r
.89862 .16187 m
.89862 .51199 L
.89958 .51199 L
.89958 .16187 L
F
.2 .63 .79 r
.89862 .16187 m
.89862 .51199 L
.89958 .51199 L
.89958 .16187 L
s
.678 .847 .902 r
.89958 .16187 m
.89958 .51312 L
.90023 .51312 L
.90023 .16187 L
F
.2 .63 .79 r
.89958 .16187 m
.89958 .51312 L
.90023 .51312 L
.90023 .16187 L
s
.678 .847 .902 r
.90023 .16187 m
.90023 .51387 L
.901 .51387 L
.901 .16187 L
F
.2 .63 .79 r
.90023 .16187 m
.90023 .51387 L
.901 .51387 L
.901 .16187 L
s
.678 .847 .902 r
.901 .16187 m
.901 .51439 L
.90176 .51439 L
.90176 .16187 L
F
.2 .63 .79 r
.901 .16187 m
.901 .51439 L
.90176 .51439 L
.90176 .16187 L
s
.678 .847 .902 r
.90176 .16187 m
.90176 .51533 L
.90235 .51533 L
.90235 .16187 L
F
.2 .63 .79 r
.90176 .16187 m
.90176 .51533 L
.90235 .51533 L
.90235 .16187 L
s
.678 .847 .902 r
.90235 .16187 m
.90235 .51693 L
.90364 .51693 L
.90364 .16187 L
F
.2 .63 .79 r
.90235 .16187 m
.90235 .51693 L
.90364 .51693 L
.90364 .16187 L
s
.678 .847 .902 r
.90364 .16187 m
.90364 .5175 L
.90429 .5175 L
.90429 .16187 L
F
.2 .63 .79 r
.90364 .16187 m
.90364 .5175 L
.90429 .5175 L
.90429 .16187 L
s
.678 .847 .902 r
.90429 .16187 m
.90429 .51845 L
.90526 .51845 L
.90526 .16187 L
F
.2 .63 .79 r
.90429 .16187 m
.90429 .51845 L
.90526 .51845 L
.90526 .16187 L
s
.678 .847 .902 r
.90526 .16187 m
.90526 .51943 L
.90589 .51943 L
.90589 .16187 L
F
.2 .63 .79 r
.90526 .16187 m
.90526 .51943 L
.90589 .51943 L
.90589 .16187 L
s
.678 .847 .902 r
.90589 .16187 m
.90589 .52106 L
.90723 .52106 L
.90723 .16187 L
F
.2 .63 .79 r
.90589 .16187 m
.90589 .52106 L
.90723 .52106 L
.90723 .16187 L
s
.678 .847 .902 r
.90723 .16187 m
.90723 .52128 L
.90831 .52128 L
.90831 .16187 L
F
.2 .63 .79 r
.90723 .16187 m
.90723 .52128 L
.90831 .52128 L
.90831 .16187 L
s
.678 .847 .902 r
.90831 .16187 m
.90831 .52268 L
.90916 .52268 L
.90916 .16187 L
F
.2 .63 .79 r
.90831 .16187 m
.90831 .52268 L
.90916 .52268 L
.90916 .16187 L
s
.678 .847 .902 r
.90916 .16187 m
.90916 .52382 L
.90972 .52382 L
.90972 .16187 L
F
.2 .63 .79 r
.90916 .16187 m
.90916 .52382 L
.90972 .52382 L
.90972 .16187 L
s
.678 .847 .902 r
.90972 .16187 m
.90972 .52496 L
.91057 .52496 L
.91057 .16187 L
F
.2 .63 .79 r
.90972 .16187 m
.90972 .52496 L
.91057 .52496 L
.91057 .16187 L
s
.678 .847 .902 r
.91057 .16187 m
.91057 .52551 L
.91135 .52551 L
.91135 .16187 L
F
.2 .63 .79 r
.91057 .16187 m
.91057 .52551 L
.91135 .52551 L
.91135 .16187 L
s
.678 .847 .902 r
.91135 .16187 m
.91135 .52669 L
.91231 .52669 L
.91231 .16187 L
F
.2 .63 .79 r
.91135 .16187 m
.91135 .52669 L
.91231 .52669 L
.91231 .16187 L
s
.678 .847 .902 r
.91231 .16187 m
.91231 .52807 L
.91353 .52807 L
.91353 .16187 L
F
.2 .63 .79 r
.91231 .16187 m
.91231 .52807 L
.91353 .52807 L
.91353 .16187 L
s
.678 .847 .902 r
.91353 .16187 m
.91353 .52864 L
.91408 .52864 L
.91408 .16187 L
F
.2 .63 .79 r
.91353 .16187 m
.91353 .52864 L
.91408 .52864 L
.91408 .16187 L
s
.678 .847 .902 r
.91408 .16187 m
.91408 .52969 L
.91536 .52969 L
.91536 .16187 L
F
.2 .63 .79 r
.91408 .16187 m
.91408 .52969 L
.91536 .52969 L
.91536 .16187 L
s
.678 .847 .902 r
.91536 .16187 m
.91536 .53134 L
.91671 .53134 L
.91671 .16187 L
F
.2 .63 .79 r
.91536 .16187 m
.91536 .53134 L
.91671 .53134 L
.91671 .16187 L
s
.678 .847 .902 r
.91671 .16187 m
.91671 .53274 L
.91786 .53274 L
.91786 .16187 L
F
.2 .63 .79 r
.91671 .16187 m
.91671 .53274 L
.91786 .53274 L
.91786 .16187 L
s
.678 .847 .902 r
.91786 .16187 m
.91786 .53398 L
.91908 .53398 L
.91908 .16187 L
F
.2 .63 .79 r
.91786 .16187 m
.91786 .53398 L
.91908 .53398 L
.91908 .16187 L
s
.678 .847 .902 r
.91908 .16187 m
.91908 .5353 L
.92037 .5353 L
.92037 .16187 L
F
.2 .63 .79 r
.91908 .16187 m
.91908 .5353 L
.92037 .5353 L
.92037 .16187 L
s
.678 .847 .902 r
.92037 .16187 m
.92037 .53678 L
.92086 .53678 L
.92086 .16187 L
F
.2 .63 .79 r
.92037 .16187 m
.92037 .53678 L
.92086 .53678 L
.92086 .16187 L
s
.678 .847 .902 r
.92086 .16187 m
.92086 .53753 L
.92146 .53753 L
.92146 .16187 L
F
.2 .63 .79 r
.92086 .16187 m
.92086 .53753 L
.92146 .53753 L
.92146 .16187 L
s
.678 .847 .902 r
.92146 .16187 m
.92146 .53813 L
.92243 .53813 L
.92243 .16187 L
F
.2 .63 .79 r
.92146 .16187 m
.92146 .53813 L
.92243 .53813 L
.92243 .16187 L
s
.678 .847 .902 r
.92243 .16187 m
.92243 .5393 L
.92335 .5393 L
.92335 .16187 L
F
.2 .63 .79 r
.92243 .16187 m
.92243 .5393 L
.92335 .5393 L
.92335 .16187 L
s
.678 .847 .902 r
.92335 .16187 m
.92335 .54029 L
.92444 .54029 L
.92444 .16187 L
F
.2 .63 .79 r
.92335 .16187 m
.92335 .54029 L
.92444 .54029 L
.92444 .16187 L
s
.678 .847 .902 r
.92444 .16187 m
.92444 .54122 L
.92486 .54122 L
.92486 .16187 L
F
.2 .63 .79 r
.92444 .16187 m
.92444 .54122 L
.92486 .54122 L
.92486 .16187 L
s
.678 .847 .902 r
.92486 .16187 m
.92486 .54223 L
.92589 .54223 L
.92589 .16187 L
F
.2 .63 .79 r
.92486 .16187 m
.92486 .54223 L
.92589 .54223 L
.92589 .16187 L
s
.678 .847 .902 r
.92589 .16187 m
.92589 .54352 L
.92657 .54352 L
.92657 .16187 L
F
.2 .63 .79 r
.92589 .16187 m
.92589 .54352 L
.92657 .54352 L
.92657 .16187 L
s
.678 .847 .902 r
.92657 .16187 m
.92657 .54407 L
.9271 .54407 L
.9271 .16187 L
F
.2 .63 .79 r
.92657 .16187 m
.92657 .54407 L
.9271 .54407 L
.9271 .16187 L
s
.678 .847 .902 r
.9271 .16187 m
.9271 .54492 L
.92824 .54492 L
.92824 .16187 L
F
.2 .63 .79 r
.9271 .16187 m
.9271 .54492 L
.92824 .54492 L
.92824 .16187 L
s
.678 .847 .902 r
.92824 .16187 m
.92824 .54629 L
.92929 .54629 L
.92929 .16187 L
F
.2 .63 .79 r
.92824 .16187 m
.92824 .54629 L
.92929 .54629 L
.92929 .16187 L
s
.678 .847 .902 r
.92929 .16187 m
.92929 .5477 L
.93024 .5477 L
.93024 .16187 L
F
.2 .63 .79 r
.92929 .16187 m
.92929 .5477 L
.93024 .5477 L
.93024 .16187 L
s
.678 .847 .902 r
.93024 .16187 m
.93024 .5485 L
.93128 .5485 L
.93128 .16187 L
F
.2 .63 .79 r
.93024 .16187 m
.93024 .5485 L
.93128 .5485 L
.93128 .16187 L
s
.678 .847 .902 r
.93128 .16187 m
.93128 .5501 L
.93226 .5501 L
.93226 .16187 L
F
.2 .63 .79 r
.93128 .16187 m
.93128 .5501 L
.93226 .5501 L
.93226 .16187 L
s
.678 .847 .902 r
.93226 .16187 m
.93226 .55074 L
.93287 .55074 L
.93287 .16187 L
F
.2 .63 .79 r
.93226 .16187 m
.93226 .55074 L
.93287 .55074 L
.93287 .16187 L
s
.678 .847 .902 r
.93287 .16187 m
.93287 .55116 L
.93345 .55116 L
.93345 .16187 L
F
.2 .63 .79 r
.93287 .16187 m
.93287 .55116 L
.93345 .55116 L
.93345 .16187 L
s
.678 .847 .902 r
.93345 .16187 m
.93345 .55212 L
.93394 .55212 L
.93394 .16187 L
F
.2 .63 .79 r
.93345 .16187 m
.93345 .55212 L
.93394 .55212 L
.93394 .16187 L
s
.678 .847 .902 r
.93394 .16187 m
.93394 .55238 L
.93505 .55238 L
.93505 .16187 L
F
.2 .63 .79 r
.93394 .16187 m
.93394 .55238 L
.93505 .55238 L
.93505 .16187 L
s
.678 .847 .902 r
.93505 .16187 m
.93505 .55373 L
.93551 .55373 L
.93551 .16187 L
F
.2 .63 .79 r
.93505 .16187 m
.93505 .55373 L
.93551 .55373 L
.93551 .16187 L
s
.678 .847 .902 r
.93551 .16187 m
.93551 .55475 L
.93617 .55475 L
.93617 .16187 L
F
.2 .63 .79 r
.93551 .16187 m
.93551 .55475 L
.93617 .55475 L
.93617 .16187 L
s
.678 .847 .902 r
.93617 .16187 m
.93617 .55504 L
.93666 .55504 L
.93666 .16187 L
F
.2 .63 .79 r
.93617 .16187 m
.93617 .55504 L
.93666 .55504 L
.93666 .16187 L
s
.678 .847 .902 r
.93666 .16187 m
.93666 .55643 L
.93797 .55643 L
.93797 .16187 L
F
.2 .63 .79 r
.93666 .16187 m
.93666 .55643 L
.93797 .55643 L
.93797 .16187 L
s
.678 .847 .902 r
.93797 .16187 m
.93797 .55769 L
.93858 .55769 L
.93858 .16187 L
F
.2 .63 .79 r
.93797 .16187 m
.93797 .55769 L
.93858 .55769 L
.93858 .16187 L
s
.678 .847 .902 r
.93858 .16187 m
.93858 .55819 L
.9393 .55819 L
.9393 .16187 L
F
.2 .63 .79 r
.93858 .16187 m
.93858 .55819 L
.9393 .55819 L
.9393 .16187 L
s
.678 .847 .902 r
.9393 .16187 m
.9393 .55885 L
.93971 .55885 L
.93971 .16187 L
F
.2 .63 .79 r
.9393 .16187 m
.9393 .55885 L
.93971 .55885 L
.93971 .16187 L
s
.678 .847 .902 r
.93971 .16187 m
.93971 .56006 L
.94083 .56006 L
.94083 .16187 L
F
.2 .63 .79 r
.93971 .16187 m
.93971 .56006 L
.94083 .56006 L
.94083 .16187 L
s
.678 .847 .902 r
.94083 .16187 m
.94083 .56096 L
.94181 .56096 L
.94181 .16187 L
F
.2 .63 .79 r
.94083 .16187 m
.94083 .56096 L
.94181 .56096 L
.94181 .16187 L
s
.678 .847 .902 r
.94181 .16187 m
.94181 .56298 L
.94298 .56298 L
.94298 .16187 L
F
.2 .63 .79 r
.94181 .16187 m
.94181 .56298 L
.94298 .56298 L
.94298 .16187 L
s
.678 .847 .902 r
.94298 .16187 m
.94298 .56308 L
.94364 .56308 L
.94364 .16187 L
F
.2 .63 .79 r
.94298 .16187 m
.94298 .56308 L
.94364 .56308 L
.94364 .16187 L
s
.678 .847 .902 r
.94364 .16187 m
.94364 .5644 L
.94475 .5644 L
.94475 .16187 L
F
.2 .63 .79 r
.94364 .16187 m
.94364 .5644 L
.94475 .5644 L
.94475 .16187 L
s
.678 .847 .902 r
.94475 .16187 m
.94475 .56654 L
.94606 .56654 L
.94606 .16187 L
F
.2 .63 .79 r
.94475 .16187 m
.94475 .56654 L
.94606 .56654 L
.94606 .16187 L
s
.678 .847 .902 r
.94606 .16187 m
.94606 .56675 L
.94695 .56675 L
.94695 .16187 L
F
.2 .63 .79 r
.94606 .16187 m
.94606 .56675 L
.94695 .56675 L
.94695 .16187 L
s
.678 .847 .902 r
.94695 .16187 m
.94695 .56796 L
.94749 .56796 L
.94749 .16187 L
F
.2 .63 .79 r
.94695 .16187 m
.94695 .56796 L
.94749 .56796 L
.94749 .16187 L
s
.678 .847 .902 r
.94749 .16187 m
.94749 .56987 L
.94882 .56987 L
.94882 .16187 L
F
.2 .63 .79 r
.94749 .16187 m
.94749 .56987 L
.94882 .56987 L
.94882 .16187 L
s
.678 .847 .902 r
.94882 .16187 m
.94882 .57022 L
.94948 .57022 L
.94948 .16187 L
F
.2 .63 .79 r
.94882 .16187 m
.94882 .57022 L
.94948 .57022 L
.94948 .16187 L
s
.678 .847 .902 r
.94948 .16187 m
.94948 .57117 L
.95078 .57117 L
.95078 .16187 L
F
.2 .63 .79 r
.94948 .16187 m
.94948 .57117 L
.95078 .57117 L
.95078 .16187 L
s
.678 .847 .902 r
.95078 .16187 m
.95078 .57321 L
.95164 .57321 L
.95164 .16187 L
F
.2 .63 .79 r
.95078 .16187 m
.95078 .57321 L
.95164 .57321 L
.95164 .16187 L
s
.678 .847 .902 r
.95164 .16187 m
.95164 .57343 L
.95239 .57343 L
.95239 .16187 L
F
.2 .63 .79 r
.95164 .16187 m
.95164 .57343 L
.95239 .57343 L
.95239 .16187 L
s
.678 .847 .902 r
.95239 .16187 m
.95239 .57464 L
.95285 .57464 L
.95285 .16187 L
F
.2 .63 .79 r
.95239 .16187 m
.95239 .57464 L
.95285 .57464 L
.95285 .16187 L
s
.678 .847 .902 r
.95285 .16187 m
.95285 .57483 L
.95397 .57483 L
.95397 .16187 L
F
.2 .63 .79 r
.95285 .16187 m
.95285 .57483 L
.95397 .57483 L
.95397 .16187 L
s
.678 .847 .902 r
.95397 .16187 m
.95397 .57624 L
.95475 .57624 L
.95475 .16187 L
F
.2 .63 .79 r
.95397 .16187 m
.95397 .57624 L
.95475 .57624 L
.95475 .16187 L
s
.678 .847 .902 r
.95475 .16187 m
.95475 .5783 L
.95575 .5783 L
.95575 .16187 L
F
.2 .63 .79 r
.95475 .16187 m
.95475 .5783 L
.95575 .5783 L
.95575 .16187 L
s
.678 .847 .902 r
.95575 .16187 m
.95575 .5789 L
.9571 .5789 L
.9571 .16187 L
F
.2 .63 .79 r
.95575 .16187 m
.95575 .5789 L
.9571 .5789 L
.9571 .16187 L
s
.678 .847 .902 r
.9571 .16187 m
.9571 .58015 L
.95797 .58015 L
.95797 .16187 L
F
.2 .63 .79 r
.9571 .16187 m
.9571 .58015 L
.95797 .58015 L
.95797 .16187 L
s
.678 .847 .902 r
.95797 .16187 m
.95797 .58169 L
.95866 .58169 L
.95866 .16187 L
F
.2 .63 .79 r
.95797 .16187 m
.95797 .58169 L
.95866 .58169 L
.95866 .16187 L
s
.678 .847 .902 r
.95866 .16187 m
.95866 .58231 L
.95971 .58231 L
.95971 .16187 L
F
.2 .63 .79 r
.95866 .16187 m
.95866 .58231 L
.95971 .58231 L
.95971 .16187 L
s
.678 .847 .902 r
.95971 .16187 m
.95971 .58373 L
.96086 .58373 L
.96086 .16187 L
F
.2 .63 .79 r
.95971 .16187 m
.95971 .58373 L
.96086 .58373 L
.96086 .16187 L
s
.678 .847 .902 r
.96086 .16187 m
.96086 .58497 L
.96141 .58497 L
.96141 .16187 L
F
.2 .63 .79 r
.96086 .16187 m
.96086 .58497 L
.96141 .58497 L
.96141 .16187 L
s
.678 .847 .902 r
.96141 .16187 m
.96141 .58545 L
.9621 .58545 L
.9621 .16187 L
F
.2 .63 .79 r
.96141 .16187 m
.96141 .58545 L
.9621 .58545 L
.9621 .16187 L
s
.678 .847 .902 r
.9621 .16187 m
.9621 .58702 L
.96338 .58702 L
.96338 .16187 L
F
.2 .63 .79 r
.9621 .16187 m
.9621 .58702 L
.96338 .58702 L
.96338 .16187 L
s
.678 .847 .902 r
.96338 .16187 m
.96338 .58828 L
.96396 .58828 L
.96396 .16187 L
F
.2 .63 .79 r
.96338 .16187 m
.96338 .58828 L
.96396 .58828 L
.96396 .16187 L
s
.678 .847 .902 r
.96396 .16187 m
.96396 .5889 L
.9647 .5889 L
.9647 .16187 L
F
.2 .63 .79 r
.96396 .16187 m
.96396 .5889 L
.9647 .5889 L
.9647 .16187 L
s
.678 .847 .902 r
.9647 .16187 m
.9647 .58929 L
.96512 .58929 L
.96512 .16187 L
F
.2 .63 .79 r
.9647 .16187 m
.9647 .58929 L
.96512 .58929 L
.96512 .16187 L
s
.678 .847 .902 r
.96512 .16187 m
.96512 .58983 L
.96571 .58983 L
.96571 .16187 L
F
.2 .63 .79 r
.96512 .16187 m
.96512 .58983 L
.96571 .58983 L
.96571 .16187 L
s
.678 .847 .902 r
.96571 .16187 m
.96571 .59047 L
.96633 .59047 L
.96633 .16187 L
F
.2 .63 .79 r
.96571 .16187 m
.96571 .59047 L
.96633 .59047 L
.96633 .16187 L
s
.678 .847 .902 r
.96633 .16187 m
.96633 .59206 L
.96753 .59206 L
.96753 .16187 L
F
.2 .63 .79 r
.96633 .16187 m
.96633 .59206 L
.96753 .59206 L
.96753 .16187 L
s
.678 .847 .902 r
.96753 .16187 m
.96753 .59394 L
.96877 .59394 L
.96877 .16187 L
F
.2 .63 .79 r
.96753 .16187 m
.96753 .59394 L
.96877 .59394 L
.96877 .16187 L
s
.678 .847 .902 r
.96877 .16187 m
.96877 .59435 L
.96939 .59435 L
.96939 .16187 L
F
.2 .63 .79 r
.96877 .16187 m
.96877 .59435 L
.96939 .59435 L
.96939 .16187 L
s
.678 .847 .902 r
.96939 .16187 m
.96939 .59613 L
.9707 .59613 L
.9707 .16187 L
F
.2 .63 .79 r
.96939 .16187 m
.96939 .59613 L
.9707 .59613 L
.9707 .16187 L
s
.678 .847 .902 r
.9707 .16187 m
.9707 .59707 L
.97196 .59707 L
.97196 .16187 L
F
.2 .63 .79 r
.9707 .16187 m
.9707 .59707 L
.97196 .59707 L
.97196 .16187 L
s
.678 .847 .902 r
.97196 .16187 m
.97196 .59906 L
.97275 .59906 L
.97275 .16187 L
F
.2 .63 .79 r
.97196 .16187 m
.97196 .59906 L
.97275 .59906 L
.97275 .16187 L
s
.678 .847 .902 r
.97275 .16187 m
.97275 .59929 L
.97396 .59929 L
.97396 .16187 L
F
.2 .63 .79 r
.97275 .16187 m
.97275 .59929 L
.97396 .59929 L
.97396 .16187 L
s
.678 .847 .902 r
.97396 .16187 m
.97396 .6007 L
.97522 .6007 L
.97522 .16187 L
F
.2 .63 .79 r
.97396 .16187 m
.97396 .6007 L
.97522 .6007 L
.97522 .16187 L
s
.678 .847 .902 r
.97522 .16187 m
.97522 .60235 L
.97578 .60235 L
.97578 .16187 L
F
.2 .63 .79 r
.97522 .16187 m
.97522 .60235 L
.97578 .60235 L
.97578 .16187 L
s
.678 .847 .902 r
.97578 .16187 m
.97578 .60328 L
.97619 .60328 L
.97619 .16187 L
F
.2 .63 .79 r
.97578 .16187 m
.97578 .60328 L
.97619 .60328 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02398 .01472 Mdot
.02536 .01472 Mdot
.02613 .01472 Mdot
.02725 .01472 Mdot
.02798 .01473 Mdot
.02838 .01473 Mdot
.02952 .01474 Mdot
.03027 .01474 Mdot
.03096 .01475 Mdot
.03214 .01476 Mdot
.03239 .01476 Mdot
.03367 .01478 Mdot
.03466 .01479 Mdot
.03564 .01481 Mdot
.03617 .01481 Mdot
.0371 .01483 Mdot
.03772 .01484 Mdot
.0394 .01487 Mdot
.04007 .01489 Mdot
.04067 .0149 Mdot
.04122 .01491 Mdot
.04208 .01493 Mdot
.0424 .01494 Mdot
.04301 .01495 Mdot
.0437 .01497 Mdot
.0457 .01503 Mdot
.04642 .01505 Mdot
.0472 .01507 Mdot
.0481 .0151 Mdot
.04923 .01513 Mdot
.04948 .01514 Mdot
.05145 .01521 Mdot
.05185 .01523 Mdot
.05225 .01524 Mdot
.05293 .01527 Mdot
.05356 .01529 Mdot
.05456 .01533 Mdot
.05527 .01536 Mdot
.05667 .01542 Mdot
.05729 .01544 Mdot
.05825 .01548 Mdot
.0597 .01555 Mdot
.06046 .01559 Mdot
.0616 .01564 Mdot
.06287 .01571 Mdot
.0635 .01574 Mdot
.06498 .01581 Mdot
.06626 .01588 Mdot
.06704 .01593 Mdot
.0679 .01598 Mdot
.06842 .01601 Mdot
.06926 .01606 Mdot
.06981 .01609 Mdot
.07058 .01613 Mdot
.07078 .01615 Mdot
.07154 .01619 Mdot
.07191 .01622 Mdot
.07269 .01627 Mdot
.0731 .01629 Mdot
.0748 .0164 Mdot
.07541 .01644 Mdot
.07625 .0165 Mdot
.07685 .01654 Mdot
.07754 .01659 Mdot
.07797 .01662 Mdot
.07867 .01667 Mdot
.08011 .01677 Mdot
.08102 .01684 Mdot
.08147 .01687 Mdot
.08224 .01693 Mdot
.08326 .01701 Mdot
.08419 .01708 Mdot
.08451 .01711 Mdot
.08541 .01718 Mdot
.08591 .01722 Mdot
.08698 .0173 Mdot
.08772 .01737 Mdot
.08809 .0174 Mdot
.08888 .01746 Mdot
.08935 .0175 Mdot
.09058 .01761 Mdot
.09192 .01773 Mdot
.09241 .01777 Mdot
.09318 .01784 Mdot
.09414 .01793 Mdot
.09532 .01803 Mdot
.09602 .0181 Mdot
.09697 .01819 Mdot
.09849 .01833 Mdot
.0989 .01837 Mdot
.10053 .01853 Mdot
.1014 .01862 Mdot
.10261 .01875 Mdot
.10402 .01889 Mdot
.1056 .01906 Mdot
.10612 .01911 Mdot
.10757 .01927 Mdot
.10831 .01935 Mdot
.10887 .01941 Mdot
.10932 .01946 Mdot
.11094 .01964 Mdot
.11179 .01974 Mdot
.11208 .01977 Mdot
.11373 .01996 Mdot
.11432 .02003 Mdot
.11506 .02012 Mdot
.11537 .02016 Mdot
.11728 .02038 Mdot
.11753 .02041 Mdot
.11869 .02056 Mdot
.1194 .02065 Mdot
.1201 .02073 Mdot
.12081 .02082 Mdot
.12227 .02101 Mdot
.12387 .02121 Mdot
.12495 .02135 Mdot
.12583 .02147 Mdot
.12726 .02166 Mdot
.12781 .02173 Mdot
.12805 .02177 Mdot
.12882 .02187 Mdot
.12907 .02191 Mdot
.13012 .02205 Mdot
.13093 .02216 Mdot
.13165 .02226 Mdot
.13306 .02246 Mdot
.13408 .02261 Mdot
.13499 .02274 Mdot
.13635 .02293 Mdot
.13694 .02302 Mdot
.13844 .02324 Mdot
.13941 .02339 Mdot
.14015 .0235 Mdot
.14092 .02362 Mdot
.14184 .02376 Mdot
.14213 .0238 Mdot
.14317 .02396 Mdot
.14413 .02411 Mdot
.14503 .02425 Mdot
.14522 .02428 Mdot
.14587 .02438 Mdot
.14703 .02457 Mdot
.14787 .0247 Mdot
.14899 .02488 Mdot
.14948 .02496 Mdot
.15017 .02508 Mdot
.15095 .0252 Mdot
.15183 .02535 Mdot
.15289 .02553 Mdot
.15313 .02557 Mdot
.15548 .02597 Mdot
.15575 .02601 Mdot
.1567 .02617 Mdot
.15753 .02632 Mdot
.15834 .02646 Mdot
.15903 .02658 Mdot
.15966 .02669 Mdot
.16066 .02687 Mdot
.16132 .02699 Mdot
.16186 .02708 Mdot
.16254 .02721 Mdot
.16282 .02725 Mdot
.16364 .0274 Mdot
.16387 .02744 Mdot
.16448 .02756 Mdot
.16598 .02783 Mdot
.1675 .02811 Mdot
.16784 .02818 Mdot
.16862 .02832 Mdot
.17049 .02868 Mdot
.17105 .02878 Mdot
.17191 .02895 Mdot
.17231 .02903 Mdot
.17363 .02928 Mdot
.17437 .02942 Mdot
.17526 .0296 Mdot
.1768 .0299 Mdot
.17759 .03006 Mdot
.1779 .03012 Mdot
.17929 .0304 Mdot
.17959 .03046 Mdot
.18141 .03083 Mdot
.18199 .03095 Mdot
.18295 .03115 Mdot
.18388 .03134 Mdot
.18505 .03159 Mdot
.18598 .03178 Mdot
.18651 .03189 Mdot
.18737 .03208 Mdot
.1881 .03223 Mdot
.18947 .03252 Mdot
.19078 .03281 Mdot
.19121 .0329 Mdot
.19242 .03316 Mdot
.19321 .03334 Mdot
.19409 .03353 Mdot
.19533 .03381 Mdot
.19578 .03391 Mdot
.19622 .03401 Mdot
.197 .03418 Mdot
.19835 .03448 Mdot
.19925 .03469 Mdot
.19949 .03474 Mdot
.20054 .03498 Mdot
.20136 .03517 Mdot
.20254 .03544 Mdot
.20311 .03558 Mdot
.2039 .03576 Mdot
.20474 .03596 Mdot
.20504 .03603 Mdot
.20577 .0362 Mdot
.20682 .03645 Mdot
.20764 .03664 Mdot
.20947 .03708 Mdot
.21015 .03725 Mdot
.21138 .03755 Mdot
.21176 .03764 Mdot
.21296 .03793 Mdot
.2144 .03829 Mdot
.21553 .03857 Mdot
.21589 .03866 Mdot
.2172 .03898 Mdot
.21755 .03907 Mdot
.21863 .03935 Mdot
.21922 .03949 Mdot
.22032 .03977 Mdot
.22134 .04004 Mdot
.22175 .04014 Mdot
.22259 .04036 Mdot
.2236 .04062 Mdot
.22457 .04087 Mdot
.22529 .04106 Mdot
.22592 .04122 Mdot
.22642 .04136 Mdot
.22692 .04149 Mdot
.22737 .04161 Mdot
.22873 .04197 Mdot
.22976 .04224 Mdot
.23093 .04255 Mdot
.23118 .04262 Mdot
.23157 .04273 Mdot
.23224 .04291 Mdot
.23306 .04313 Mdot
.23452 .04353 Mdot
.23481 .04361 Mdot
.23573 .04386 Mdot
.23644 .04405 Mdot
.23807 .04451 Mdot
.2392 .04482 Mdot
.23988 .04501 Mdot
.24044 .04517 Mdot
.24133 .04542 Mdot
.24263 .04579 Mdot
.24336 .046 Mdot
.244 .04618 Mdot
.24503 .04647 Mdot
.24522 .04653 Mdot
.24657 .04692 Mdot
.24716 .04709 Mdot
.24775 .04726 Mdot
.24835 .04743 Mdot
.24897 .04761 Mdot
.24967 .04782 Mdot
.24993 .0479 Mdot
.25113 .04825 Mdot
.25245 .04864 Mdot
.25345 .04894 Mdot
.25446 .04924 Mdot
.25561 .04958 Mdot
.25628 .04978 Mdot
.25724 .05007 Mdot
.25842 .05044 Mdot
.25895 .0506 Mdot
.25972 .05083 Mdot
.26119 .05128 Mdot
.26149 .05137 Mdot
.26188 .05149 Mdot
.26375 .05207 Mdot
.26411 .05219 Mdot
.26515 .05251 Mdot
.26636 .05289 Mdot
.2664 .0529 Mdot
.26782 .05335 Mdot
.26819 .05347 Mdot
.26929 .05382 Mdot
.26986 .054 Mdot
.27101 .05437 Mdot
.27165 .05457 Mdot
.27238 .05481 Mdot
.27288 .05497 Mdot
.27358 .0552 Mdot
.27469 .05556 Mdot
.27558 .05585 Mdot
.27683 .05626 Mdot
.2782 .05671 Mdot
.27851 .05681 Mdot
.27932 .05708 Mdot
.28012 .05735 Mdot
.28018 .05737 Mdot
.28124 .05772 Mdot
.28223 .05805 Mdot
.28268 .0582 Mdot
.28417 .0587 Mdot
.28489 .05895 Mdot
.28556 .05917 Mdot
.2858 .05926 Mdot
.28755 .05986 Mdot
.28816 .06006 Mdot
.2892 .06042 Mdot
.2908 .06097 Mdot
.29144 .0612 Mdot
.29193 .06137 Mdot
.2927 .06164 Mdot
.29333 .06185 Mdot
.29416 .06214 Mdot
.2948 .06237 Mdot
.29608 .06282 Mdot
.29686 .0631 Mdot
.29792 .06347 Mdot
.29889 .06382 Mdot
.29972 .06412 Mdot
.29998 .06421 Mdot
.30101 .06458 Mdot
.30202 .06494 Mdot
.30222 .06501 Mdot
.3035 .06548 Mdot
.30362 .06552 Mdot
.30493 .066 Mdot
.30604 .06641 Mdot
.30784 .06707 Mdot
.30804 .06714 Mdot
.30846 .0673 Mdot
.30943 .06766 Mdot
.31072 .06813 Mdot
.31116 .0683 Mdot
.31218 .06868 Mdot
.31325 .06908 Mdot
.31396 .06935 Mdot
.31482 .06967 Mdot
.3152 .06982 Mdot
.31586 .07006 Mdot
.31673 .0704 Mdot
.31741 .07065 Mdot
.31848 .07106 Mdot
.31966 .07151 Mdot
.32045 .07182 Mdot
.32169 .0723 Mdot
.32269 .07268 Mdot
.32332 .07293 Mdot
.32444 .07336 Mdot
.32549 .07378 Mdot
.32584 .07391 Mdot
.327 .07437 Mdot
.32742 .07453 Mdot
.32772 .07465 Mdot
.32908 .07519 Mdot
.32949 .07535 Mdot
.33028 .07566 Mdot
.33139 .07611 Mdot
.33183 .07628 Mdot
.33298 .07674 Mdot
.33389 .07711 Mdot
.33391 .07712 Mdot
.33437 .0773 Mdot
.3352 .07764 Mdot
.33603 .07797 Mdot
.3375 .07857 Mdot
.33809 .07881 Mdot
.33942 .07936 Mdot
.33948 .07938 Mdot
.34036 .07974 Mdot
.34127 .08011 Mdot
.34286 .08077 Mdot
.34348 .08103 Mdot
.3445 .08145 Mdot
.3447 .08154 Mdot
.34683 .08243 Mdot
.34704 .08252 Mdot
.34805 .08294 Mdot
.34837 .08308 Mdot
.34928 .08346 Mdot
.35052 .08398 Mdot
.35202 .08462 Mdot
.35308 .08507 Mdot
.35361 .0853 Mdot
.3543 .08559 Mdot
.35563 .08617 Mdot
.35658 .08658 Mdot
.3569 .08672 Mdot
.35829 .08732 Mdot
.35904 .08764 Mdot
.35971 .08793 Mdot
.36039 .08823 Mdot
.36106 .08852 Mdot
.36229 .08907 Mdot
.36257 .08919 Mdot
.36391 .08978 Mdot
.36492 .09022 Mdot
.36627 .09082 Mdot
.36644 .0909 Mdot
.36774 .09148 Mdot
.36813 .09165 Mdot
.36859 .09186 Mdot
.36997 .09248 Mdot
.37016 .09256 Mdot
.37153 .09318 Mdot
.37208 .09343 Mdot
.37276 .09373 Mdot
.37417 .09437 Mdot
.37507 .09479 Mdot
.37546 .09496 Mdot
.37639 .09539 Mdot
.3778 .09603 Mdot
.37891 .09654 Mdot
.37954 .09683 Mdot
.38113 .09757 Mdot
.38132 .09766 Mdot
.38209 .09801 Mdot
.38266 .09828 Mdot
.3834 .09862 Mdot
.38404 .09892 Mdot
.38541 .09957 Mdot
.3859 .0998 Mdot
.38693 .10028 Mdot
.38721 .10041 Mdot
.38848 .10101 Mdot
.38941 .10146 Mdot
.39059 .10202 Mdot
.39075 .10209 Mdot
.39159 .10249 Mdot
.39255 .10295 Mdot
.39393 .10361 Mdot
.39492 .10409 Mdot
.39559 .10441 Mdot
.39717 .10518 Mdot
.39791 .10553 Mdot
.39839 .10577 Mdot
.39991 .10651 Mdot
.40064 .10687 Mdot
.40182 .10744 Mdot
.40214 .1076 Mdot
.40305 .10805 Mdot
.40376 .1084 Mdot
.40527 .10915 Mdot
.40577 .10939 Mdot
.40707 .11003 Mdot
.40784 .11042 Mdot
.40804 .11052 Mdot
.40867 .11084 Mdot
.41052 .11176 Mdot
.41079 .1119 Mdot
.4113 .11215 Mdot
.41226 .11264 Mdot
.4127 .11286 Mdot
.41296 .11299 Mdot
.41422 .11363 Mdot
.41523 .11414 Mdot
.41613 .1146 Mdot
.41684 .11496 Mdot
.41747 .11528 Mdot
.41882 .11597 Mdot
.41969 .11642 Mdot
.42073 .11695 Mdot
.42174 .11747 Mdot
.42279 .11802 Mdot
.42315 .1182 Mdot
.4239 .11859 Mdot
.42519 .11927 Mdot
.42598 .11967 Mdot
.42731 .12037 Mdot
.42812 .12079 Mdot
.42897 .12124 Mdot
.42952 .12153 Mdot
.43077 .12219 Mdot
.4316 .12263 Mdot
.43304 .12339 Mdot
.43366 .12372 Mdot
.43496 .12442 Mdot
.43529 .12459 Mdot
.43604 .12499 Mdot
.43691 .12546 Mdot
.43839 .12625 Mdot
.4391 .12663 Mdot
.43994 .12709 Mdot
.44017 .12721 Mdot
.44117 .12775 Mdot
.44159 .12798 Mdot
.4422 .12831 Mdot
.443 .12874 Mdot
.44378 .12917 Mdot
.44397 .12928 Mdot
.44478 .12972 Mdot
.44522 .12996 Mdot
.44625 .13052 Mdot
.44764 .13129 Mdot
.44811 .13155 Mdot
.44991 .13254 Mdot
.45048 .13285 Mdot
.45135 .13333 Mdot
.45244 .13394 Mdot
.45313 .13432 Mdot
.4542 .13492 Mdot
.45478 .13524 Mdot
.45579 .13581 Mdot
.4568 .13638 Mdot
.4575 .13677 Mdot
.45853 .13735 Mdot
.45966 .13799 Mdot
.46105 .13878 Mdot
.46227 .13947 Mdot
.46255 .13963 Mdot
.46347 .14016 Mdot
.46451 .14075 Mdot
.46542 .14127 Mdot
.46598 .14159 Mdot
.46731 .14236 Mdot
.46869 .14315 Mdot
.47001 .14392 Mdot
.47046 .14418 Mdot
.47168 .14489 Mdot
.47293 .14561 Mdot
.47325 .1458 Mdot
.47375 .14609 Mdot
.47481 .14671 Mdot
.47589 .14734 Mdot
.47687 .14792 Mdot
.47822 .14871 Mdot
.47899 .14917 Mdot
.47997 .14975 Mdot
.48106 .1504 Mdot
.48127 .15052 Mdot
.48261 .15131 Mdot
.4832 .15166 Mdot
.48435 .15236 Mdot
.48555 .15307 Mdot
.4857 .15316 Mdot
.48641 .15359 Mdot
.48831 .15473 Mdot
.48873 .15499 Mdot
.4894 .15539 Mdot
.4902 .15587 Mdot
.49141 .15661 Mdot
.49175 .15681 Mdot
.49346 .15785 Mdot
.49373 .15802 Mdot
.49483 .15869 Mdot
.49567 .1592 Mdot
.49703 .16004 Mdot
.49709 .16007 Mdot
.49775 .16048 Mdot
.4998 .16174 Mdot
.50027 .16203 Mdot
.50102 .1625 Mdot
.50153 .16281 Mdot
.50314 .16381 Mdot
.50409 .16441 Mdot
.5043 .16453 Mdot
.50482 .16486 Mdot
.50628 .16577 Mdot
.50747 .16652 Mdot
.50785 .16676 Mdot
.50893 .16744 Mdot
.5106 .16849 Mdot
.51085 .16865 Mdot
.51232 .16958 Mdot
.51272 .16983 Mdot
.51384 .17054 Mdot
.51423 .17079 Mdot
.51516 .17138 Mdot
.51593 .17188 Mdot
.51616 .17203 Mdot
.51718 .17268 Mdot
.51842 .17347 Mdot
.51916 .17395 Mdot
.51971 .1743 Mdot
.52033 .1747 Mdot
.52188 .1757 Mdot
.52218 .17589 Mdot
.52345 .17672 Mdot
.52386 .17698 Mdot
.52562 .17813 Mdot
.52607 .17842 Mdot
.52686 .17893 Mdot
.52724 .17918 Mdot
.52834 .1799 Mdot
.52867 .18012 Mdot
.5294 .1806 Mdot
.53038 .18124 Mdot
.53178 .18216 Mdot
.53191 .18225 Mdot
.53357 .18334 Mdot
.53449 .18395 Mdot
.53493 .18425 Mdot
.53603 .18498 Mdot
.53701 .18563 Mdot
.53774 .18612 Mdot
.53873 .18678 Mdot
.53939 .18722 Mdot
.53998 .18761 Mdot
.54138 .18855 Mdot
.54238 .18923 Mdot
.54308 .1897 Mdot
.54402 .19033 Mdot
.54451 .19066 Mdot
.54498 .19098 Mdot
.5459 .1916 Mdot
.54703 .19237 Mdot
.5473 .19255 Mdot
.54837 .19328 Mdot
.54873 .19352 Mdot
.54992 .19434 Mdot
.55028 .19458 Mdot
.55149 .19541 Mdot
.55207 .1958 Mdot
.55332 .19666 Mdot
.55346 .19676 Mdot
.55491 .19776 Mdot
.5563 .19872 Mdot
.55662 .19894 Mdot
.55781 .19976 Mdot
.55859 .20031 Mdot
.55954 .20096 Mdot
.56048 .20162 Mdot
.56147 .20231 Mdot
.56202 .2027 Mdot
.56254 .20306 Mdot
.56405 .20412 Mdot
.56429 .20428 Mdot
.5648 .20464 Mdot
.56615 .20559 Mdot
.56647 .20582 Mdot
.56718 .20632 Mdot
.5683 .20711 Mdot
.56892 .20755 Mdot
.56978 .20815 Mdot
.57046 .20863 Mdot
.5712 .20916 Mdot
.57229 .20993 Mdot
.57362 .21088 Mdot
.57414 .21125 Mdot
.57577 .21242 Mdot
.57644 .2129 Mdot
.57732 .21353 Mdot
.57864 .21448 Mdot
.5793 .21495 Mdot
.58072 .21598 Mdot
.58187 .21681 Mdot
.58276 .21746 Mdot
.58349 .21799 Mdot
.58431 .21859 Mdot
.58562 .21954 Mdot
.58606 .21986 Mdot
.58658 .22024 Mdot
.58795 .22124 Mdot
.58882 .22188 Mdot
.58932 .22224 Mdot
.59037 .22302 Mdot
.59076 .22331 Mdot
.59166 .22397 Mdot
.59254 .22462 Mdot
.59356 .22537 Mdot
.59501 .22644 Mdot
.59555 .22684 Mdot
.59659 .22762 Mdot
.59706 .22796 Mdot
.59744 .22825 Mdot
.59796 .22864 Mdot
.59893 .22936 Mdot
.6001 .23024 Mdot
.60128 .23112 Mdot
.60211 .23174 Mdot
.60302 .23242 Mdot
.60443 .23348 Mdot
.60508 .23398 Mdot
.60711 .23551 Mdot
.60733 .23568 Mdot
.60865 .23668 Mdot
.60992 .23764 Mdot
.61067 .23821 Mdot
.61185 .23911 Mdot
.61256 .23965 Mdot
.61303 .24001 Mdot
.6135 .24037 Mdot
.6157 .24206 Mdot
.61646 .24264 Mdot
.61775 .24364 Mdot
.61862 .24431 Mdot
.61996 .24534 Mdot
.62067 .24589 Mdot
.62115 .24627 Mdot
.62204 .24696 Mdot
.62319 .24785 Mdot
.62414 .24859 Mdot
.62524 .24944 Mdot
.62566 .24978 Mdot
.62678 .25065 Mdot
.62784 .25148 Mdot
.62853 .25202 Mdot
.62932 .25264 Mdot
.63056 .25362 Mdot
.63112 .25406 Mdot
.63243 .25509 Mdot
.63285 .25542 Mdot
.63462 .25683 Mdot
.6349 .25705 Mdot
.63534 .2574 Mdot
.63593 .25787 Mdot
.63689 .25863 Mdot
.63796 .25948 Mdot
.63931 .26056 Mdot
.64042 .26145 Mdot
.64102 .26193 Mdot
.64169 .26247 Mdot
.64253 .26314 Mdot
.6435 .26392 Mdot
.64363 .26402 Mdot
.64487 .26502 Mdot
.64551 .26554 Mdot
.64587 .26582 Mdot
.64636 .26623 Mdot
.64725 .26694 Mdot
.64851 .26796 Mdot
.64916 .26849 Mdot
.65098 .26997 Mdot
.65194 .27075 Mdot
.6524 .27113 Mdot
.65324 .27181 Mdot
.65413 .27254 Mdot
.65486 .27314 Mdot
.65559 .27374 Mdot
.6572 .27505 Mdot
.65822 .27589 Mdot
.65937 .27684 Mdot
.66064 .2779 Mdot
.6615 .27861 Mdot
.66233 .27929 Mdot
.66249 .27942 Mdot
.66326 .28006 Mdot
.66417 .28082 Mdot
.66462 .28119 Mdot
.66506 .28156 Mdot
.66652 .28278 Mdot
.66747 .28357 Mdot
.66821 .28418 Mdot
.66869 .28459 Mdot
.66995 .28565 Mdot
.67015 .28581 Mdot
.67059 .28618 Mdot
.6718 .2872 Mdot
.67242 .28772 Mdot
.67329 .28845 Mdot
.67432 .28932 Mdot
.67488 .28979 Mdot
.67606 .29079 Mdot
.67713 .2917 Mdot
.67736 .2919 Mdot
.67916 .29342 Mdot
.6797 .29388 Mdot
.68052 .29458 Mdot
.68131 .29526 Mdot
.68246 .29624 Mdot
.68281 .29653 Mdot
.68372 .29732 Mdot
.68445 .29794 Mdot
.6852 .29858 Mdot
.68628 .29951 Mdot
.68658 .29977 Mdot
.687 .30013 Mdot
.68755 .3006 Mdot
.68837 .30131 Mdot
.68965 .30241 Mdot
.68979 .30254 Mdot
.69161 .30411 Mdot
.69196 .30442 Mdot
.69247 .30486 Mdot
.69343 .3057 Mdot
.69464 .30675 Mdot
.69499 .30705 Mdot
.69556 .30755 Mdot
.69623 .30813 Mdot
.69663 .30848 Mdot
.6977 .30941 Mdot
.69848 .3101 Mdot
.69895 .31051 Mdot
.70016 .31157 Mdot
.70051 .31188 Mdot
.70188 .31309 Mdot
.70266 .31377 Mdot
.70387 .31484 Mdot
.7044 .3153 Mdot
.70568 .31643 Mdot
.70661 .31726 Mdot
.70752 .31806 Mdot
.70843 .31888 Mdot
.70953 .31986 Mdot
.71058 .32078 Mdot
.71207 .32212 Mdot
.71245 .32246 Mdot
.71344 .32334 Mdot
.71475 .32452 Mdot
.71539 .32509 Mdot
.71598 .32562 Mdot
.71681 .32636 Mdot
.71718 .3267 Mdot
.71821 .32763 Mdot
.7189 .32825 Mdot
.72005 .32929 Mdot
.72061 .3298 Mdot
.72137 .33048 Mdot
.72223 .33126 Mdot
.72305 .332 Mdot
.72364 .33254 Mdot
.72431 .33315 Mdot
.72563 .33435 Mdot
.72621 .33488 Mdot
.7273 .33587 Mdot
.72856 .33703 Mdot
.72894 .33737 Mdot
.72937 .33776 Mdot
.73052 .33882 Mdot
.73146 .33968 Mdot
.73207 .34024 Mdot
.73384 .34188 Mdot
.73454 .34251 Mdot
.73543 .34334 Mdot
.73673 .34454 Mdot
.73706 .34484 Mdot
.73894 .34659 Mdot
.73927 .34689 Mdot
.73972 .34732 Mdot
.74054 .34808 Mdot
.7413 .34878 Mdot
.74275 .35014 Mdot
.74353 .35087 Mdot
.74389 .3512 Mdot
.74449 .35176 Mdot
.74548 .35268 Mdot
.74592 .3531 Mdot
.74798 .35503 Mdot
.74878 .35578 Mdot
.7499 .35684 Mdot
.75087 .35775 Mdot
.75178 .35862 Mdot
.75228 .35908 Mdot
.75361 .36034 Mdot
.75477 .36145 Mdot
.75515 .36181 Mdot
.7574 .36394 Mdot
.75804 .36456 Mdot
.75875 .36523 Mdot
.76033 .36673 Mdot
.7604 .3668 Mdot
.76186 .3682 Mdot
.7626 .36891 Mdot
.76417 .37042 Mdot
.76539 .37159 Mdot
.76598 .37216 Mdot
.76705 .37319 Mdot
.76868 .37477 Mdot
.76907 .37514 Mdot
.77062 .37665 Mdot
.77096 .37698 Mdot
.77195 .37793 Mdot
.77353 .37947 Mdot
.77491 .38082 Mdot
.7751 .381 Mdot
.77564 .38153 Mdot
.77652 .38239 Mdot
.77741 .38326 Mdot
.77826 .38409 Mdot
.77871 .38453 Mdot
.7799 .38569 Mdot
.78136 .38713 Mdot
.78193 .38769 Mdot
.78266 .3884 Mdot
.78352 .38925 Mdot
.78461 .39033 Mdot
.7852 .39091 Mdot
.78661 .3923 Mdot
.78727 .39296 Mdot
.78769 .39338 Mdot
.78828 .39396 Mdot
.78987 .39554 Mdot
.79039 .39606 Mdot
.79152 .39718 Mdot
.79201 .39768 Mdot
.79314 .3988 Mdot
.79381 .39947 Mdot
.79417 .39983 Mdot
.79531 .40097 Mdot
.79592 .40158 Mdot
.79668 .40234 Mdot
.79749 .40315 Mdot
.79841 .40408 Mdot
.79954 .40522 Mdot
.80044 .40613 Mdot
.80163 .40732 Mdot
.80235 .40805 Mdot
.80247 .40817 Mdot
.80427 .40999 Mdot
.80465 .41038 Mdot
.8062 .41196 Mdot
.80664 .4124 Mdot
.80715 .41291 Mdot
.8088 .4146 Mdot
.80952 .41532 Mdot
.81058 .41641 Mdot
.81144 .41729 Mdot
.81193 .41779 Mdot
.81331 .41921 Mdot
.815 .42093 Mdot
.8151 .42104 Mdot
.81647 .42245 Mdot
.81771 .42373 Mdot
.81846 .4245 Mdot
.81961 .42568 Mdot
.82029 .42639 Mdot
.82089 .42701 Mdot
.82134 .42748 Mdot
.82263 .42881 Mdot
.82323 .42943 Mdot
.82413 .43036 Mdot
.82467 .43093 Mdot
.82586 .43216 Mdot
.82641 .43274 Mdot
.82749 .43386 Mdot
.82818 .43458 Mdot
.82869 .43511 Mdot
.82991 .43639 Mdot
.83074 .43726 Mdot
.83156 .43812 Mdot
.83308 .43972 Mdot
.83377 .44044 Mdot
.83491 .44164 Mdot
.83505 .44179 Mdot
.8357 .44247 Mdot
.83672 .44354 Mdot
.83732 .44419 Mdot
.83848 .44541 Mdot
.83948 .44646 Mdot
.83985 .44686 Mdot
.84099 .44807 Mdot
.84168 .4488 Mdot
.84246 .44962 Mdot
.84349 .45072 Mdot
.8446 .4519 Mdot
.84516 .4525 Mdot
.84586 .45324 Mdot
.84657 .454 Mdot
.84733 .45481 Mdot
.84911 .45672 Mdot
.84995 .45762 Mdot
.85049 .4582 Mdot
.85103 .45878 Mdot
.85172 .45952 Mdot
.85249 .46035 Mdot
.85378 .46174 Mdot
.85468 .46271 Mdot
.85512 .46318 Mdot
.85652 .46469 Mdot
.85765 .46592 Mdot
.8585 .46683 Mdot
.85986 .4683 Mdot
.86031 .46879 Mdot
.86115 .46971 Mdot
.86131 .46988 Mdot
.86252 .4712 Mdot
.86387 .47267 Mdot
.86443 .47328 Mdot
.86522 .47414 Mdot
.86661 .47567 Mdot
.86744 .47657 Mdot
.86898 .47826 Mdot
.86918 .47848 Mdot
.87061 .48005 Mdot
.87108 .48057 Mdot
.87141 .48093 Mdot
.87261 .48225 Mdot
.87346 .48319 Mdot
.87445 .48428 Mdot
.87529 .48521 Mdot
.87578 .48575 Mdot
.87593 .48592 Mdot
.87726 .48739 Mdot
.87844 .4887 Mdot
.87873 .48902 Mdot
.8795 .48987 Mdot
.88048 .49096 Mdot
.88182 .49245 Mdot
.88185 .49249 Mdot
.88265 .49338 Mdot
.88401 .49489 Mdot
.8854 .49645 Mdot
.88682 .49804 Mdot
.88731 .49859 Mdot
.88793 .49928 Mdot
.88832 .49972 Mdot
.88965 .50121 Mdot
.89004 .50165 Mdot
.89109 .50283 Mdot
.89227 .50415 Mdot
.89274 .50469 Mdot
.89314 .50513 Mdot
.89407 .50619 Mdot
.89497 .50721 Mdot
.89598 .50835 Mdot
.89618 .50857 Mdot
.89831 .51099 Mdot
.89919 .51199 Mdot
.90018 .51312 Mdot
.90084 .51387 Mdot
.9013 .51439 Mdot
.90213 .51533 Mdot
.90353 .51693 Mdot
.90403 .5175 Mdot
.90486 .51845 Mdot
.90572 .51943 Mdot
.90714 .52106 Mdot
.90733 .52128 Mdot
.90855 .52268 Mdot
.90954 .52382 Mdot
.91053 .52496 Mdot
.91101 .52551 Mdot
.91203 .52669 Mdot
.91323 .52807 Mdot
.91372 .52864 Mdot
.91464 .52969 Mdot
.91606 .53134 Mdot
.91727 .53274 Mdot
.91833 .53398 Mdot
.91947 .5353 Mdot
.92074 .53678 Mdot
.92139 .53753 Mdot
.9219 .53813 Mdot
.92291 .5393 Mdot
.92375 .54029 Mdot
.92455 .54122 Mdot
.92542 .54223 Mdot
.92651 .54352 Mdot
.92699 .54407 Mdot
.92771 .54492 Mdot
.92888 .54629 Mdot
.93008 .5477 Mdot
.93076 .5485 Mdot
.93212 .5501 Mdot
.93266 .55074 Mdot
.93302 .55116 Mdot
.93383 .55212 Mdot
.93405 .55238 Mdot
.93519 .55373 Mdot
.93605 .55475 Mdot
.9363 .55504 Mdot
.93747 .55643 Mdot
.93853 .55769 Mdot
.93895 .55819 Mdot
.93951 .55885 Mdot
.94053 .56006 Mdot
.94128 .56096 Mdot
.94297 .56298 Mdot
.94306 .56308 Mdot
.94416 .5644 Mdot
.94596 .56654 Mdot
.94613 .56675 Mdot
.94714 .56796 Mdot
.94874 .56987 Mdot
.94903 .57022 Mdot
.94982 .57117 Mdot
.95151 .57321 Mdot
.9517 .57343 Mdot
.9527 .57464 Mdot
.95285 .57483 Mdot
.95403 .57624 Mdot
.95573 .5783 Mdot
.95623 .5789 Mdot
.95726 .58015 Mdot
.95853 .58169 Mdot
.95904 .58231 Mdot
.96021 .58373 Mdot
.96122 .58497 Mdot
.96162 .58545 Mdot
.96291 .58702 Mdot
.96394 .58828 Mdot
.96445 .5889 Mdot
.96478 .58929 Mdot
.96522 .58983 Mdot
.96574 .59047 Mdot
.96704 .59206 Mdot
.96858 .59394 Mdot
.96891 .59435 Mdot
.97036 .59613 Mdot
.97112 .59707 Mdot
.97274 .59906 Mdot
.97293 .59929 Mdot
.97407 .6007 Mdot
.9754 .60235 Mdot
.97616 .60328 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1096) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00284483) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666628) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000030?[`iPD0
00000`3jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000050?[`iP80000000<0
n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2
000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P00
00040?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40
oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4
000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V0P0000030?[`iP<00000o`3jl>JM
0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H40000
00030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H20000
00D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`
iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000003o0?[`iY`0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0
n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000040?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000?l0n_3VW03jl>H10?ooo`007`3jl>H6000000@0n_3V
0P00000_0?[`iPD00000:03jl>H3000000`0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V
0`0000030?[`iP<00000103jl>H300000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0
n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00
000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H00000
0000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<0
0000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H10?ooo`00
8P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V
0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H20000
0080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H200000003
0?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP80
0000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000000000T0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
0000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP800000
1@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H000000000
00020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V
0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000
000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V
0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V1000
00030?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103j
l>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P00
00050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;
0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2
000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00003o
0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00000<0?[`
iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00003o0?[`
iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V0000
00000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`
iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0
000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H00000
01P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H30000
0080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V10000000
0`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H00000
0?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000@0n_3V0`0000030?[`iPD00000
0`3jl>H3000000@0n_3V100000030?[`iP@000000`3jl>H3000000@0n_3V0`00001[0?[`iP40oooo
000Q0?[`iP80000000<0n_3V0000000000001@000000103jl>H000000000000000020?[`iP800000
00<0n_3V0000000000002@3jl>H5000000T0n_3V0P00003O0?[`iP800000103jl>H200000080n_3V
0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP80
00000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00030?[`iP000000000000X0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
0080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H20000
00030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000050?[`iP80000000<0n_3V000000000000103jl>H20000
00D0n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3jl>H00`000000n_3V0?[`iP020000
06X0n_3V0@3oool00280n_3V0`00000Y0?[`iP800000gP3jl>H2000000@0n_3V0P0000020?[`iP80
00000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000
000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V
00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000`3jl>H2000000@0n_3V0P000000103jl>H000000000003jl>H6
000000030?[`iP000000000000@000000P3jl>H2000000030?[`iP000000000000D0n_3V0P00001Z
0?[`iP40oooo000R0?[`iP<000006P3jl>H5000000/0n_3V0P00003M0?[`iP@000000`3jl>H50000
0080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP0000000000
0000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02
000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000050?[`iP000000
00000?[`iP0000000P3jl>H200000080n_3V00<000000?[`iP3jl>H00P0000030?[`iP80000000<0
n_3V0000000000001@3jl>H2000006X0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000Z
0?[`iP800000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V
0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3j
l>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V
0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H0
0P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000050?[`iP8000000`3jl>H3000000<0n_3V00@000000?[`iP000000
00000`3jl>H010000000n_3V0000000000040?[`iP<00000103jl>H3000006/0n_3V0@3oool00200
n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H20000
00030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@000002
0?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`000000
0`3jl>H00000000000020?[`iP@000000P3jl>H3000000030?[`iP000000000000L000006@3jl>H2
000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000002
0?[`iP040000003jl>H00000000000<0n_3V00@000000?[`iP00000000000`3jl>H2000000030?[`
iP000000000000D0n_3V0P00001Z0?[`iP40oooo001=0?[`iP80000000<0n_3V000000000000g03j
l>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP8000008P3jl>H200000080n_3V0P00
000^0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000<0n_3V0`0000040?[`iP<000000`3jl>H2000000030?[`iP00000000000080n_3V00<0
00000?[`iP3jl>H00P00001Z0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P000006
0?[`iP800000103jl>H2000000H0n_3V0P00000I0?[`iP<0000000<0n_3V0000000000000P00000^
0?[`iP<000002`3jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P000005
0?[`iP800000103jl>H3000000@0n_3V0`00001[0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`
iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H0
00000?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3V
o`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P000000103jl>H000000?[`
iP0000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0
n_3V100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080
n_3V100000020?[`iP<0000000<0n_3V0000000000001P00000J0?[`iPH000000P3jl>H3000000<0
n_3V0`0000050?[`iP<00000/`3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D00000
00D0n_3V00000000000000000?[`iP04000000/0n_3V1@0000090?[`iP80000000<0n_3V00000000
0000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP04
0000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00
000;0?[`iPD000002`3jl>H2000000<0n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3j
l>H2000000030?[`iP00000000000;80n_3V0@3oool00280n_3V0`00000X0?[`iP80000000<0n_3V
000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P000006
0?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000
0`3jl>H00000000000030?[`iP@000006`3jl>H2000000<0n_3V0P0000000`3jl>H0000000000005
0?[`iP8000000P3jl>H2000000030?[`iP00000000000;80n_3V0@3oool00280n_3V0`0000090?[`
iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H40000
00<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP@000003@3jl>H5
000000/0n_3V0P0000030?[`iP80000000<0n_3V0000000000000`3jl>H400000080n_3V0P000000
0`3jl>H000000000002b0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000009`3jl>H20000
00030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H30000
00040?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000006`3j
l>H2000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3j
l>H400000;<0n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0
n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0
n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@00000
0P3jl>H5000000<0n_3V1@00000K0?[`iP8000000`3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000020?[`iP800000]@3jl>H10?ooo`00C@3jl>H2000000030?[`iP00
000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2000003P0n_3V1000
00030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P00
002d0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H2
000000H0n_3V0P00000b0?[`iP800000103jl>H3000000@0n_3V0`0000050?[`iP<00000/P3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0n_3V9P3o
on02000006`0oooP0P0000040?ooh0800000103oon02000006/0oooP1@00001Y0?ooh0D000000P3o
on02000000@0oooP0P00001[0?ooh0@000008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@00000
0?ooh03oon000000JP3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP000006`0
oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0070?ooh0040000003oon00oooP0000
06X0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03o
on000000JP3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP06X0oooP00<00000
0?ooh03oon00J`3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP06T0oooP00<00000
0?ooh03oon008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon00
10000000oooP0?ooh00000090?ooh0800000K@3oon000`000000oooP0?ooh01[0?ooh0030000003o
on00oooP00P0oooP0P00001]0?ooh0030000003oon00oooP0280oooP7P3jl>H10?ooo`007@3jl>HU
0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002@3oon000`000000oooP
0?ooh01/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon00203oon000`000000oooP
0?ooh01Z0?ooh0040000003oon00oooP000002<0oooP7P3jl>H10?ooo`007@3jl>HV0?ooh0800000
K03oon02000000X0oooP0`00001[0?ooh0800000K03oon02000000X0oooP0`00001[0?ooh0800000
903oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503o
on000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01a
0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a
0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00203oon0D00000?l0oooP
bP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?oo
h0060?ooh0030000003oon00oooP00L0oooP9000003o0?ooh;/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon04000000H0oooP0P00000J
0000oa800000o`3oon2^0?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iPX0oooP100000040?oo
h0030000003oon00oooP00H0oooP00<000000?ooh03oon00203oon0K000000P0003o4P00003o0?oo
h:T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03o
on001P3oon000`000000oooP0?ooh0090?ooh140cHDo4@00000:0000o`l00000o`3oon2R0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP
0?ooh0090?ooh200cHDo300000090000o`/00000o`3oon2M0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP:P3=QCl;000000P0003o2P00
003o0?ooh9H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon0b0<f5?`/000001@000?l:00000?l0oooPT@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh3T0cHDo2@0000050000
o`X00000o`3oon2<0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP?`3=QCl8000000D0003o2@00003o0?ooh8P0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon150<f5?`L00000
1@000?l900000?l0oooPP`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh4X0cHDo1`0000050000o`L00000o`3oon200?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPC`3=QCl7
000000@0003o2000003o0?ooh7/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon1D0<f5?`H000001@000?l700000?l0oooPM`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh5P0
cHDo1`0000040000o`H00000o`3oon1d0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPG03=QCl7000000@0003o1P00003o0?ooh700oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh600cHDo1`00
00030000o`H00000o`3oon1[0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon1T0<f5?`H0000010000?l600000?l0oooPJ@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh6P0cHDo1P0000030000
o`H00000o`3oon1V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooPJ`3=QCl6000000@0003o1@00003o0?ooh6<0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1_0<f5?`H00000
0`000?l500000?l0oooPH03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh780cHDo1P0000030000o`@00000o`3oon1N0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPM@3=QCl6
00000080003o1P00003o0?ooh5X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon1h0<f5?`D000000`000?l500000?l0oooPF03oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh7/0
cHDo1@0000030000o`D00000o`3oon1E0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPOP3=QCl500000080003o1P00003o0?ooh580oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on210<f5?`@000000`000?l600000?l0oooPC`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh8@0cHDo100000030000o`D00000o`3oon1=
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooPQ`3=QCl4000000<0003o1@00003o0?ooh4X0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2:0<f5?`@000000P000?l500000?l0
oooPB03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03000000T0oooP
S03=QCl4000000<0003o1@00003o0?ooh4<0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh8l0cHDo100000030000o`@00000o`3oon130?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPTP3=QCl4
00000080003o1@00003o0?ooh400oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon2D0<f5?`@000000`000?l400000?l0oooP?P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh9L0
cHDo100000030000o`@00000o`3oon0k0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPV@3=QCl500000080003o1000003o0?ooh3T0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on2L0<f5?`@000000P000?l400000?l0oooP=`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh9h0cHDo100000020000o`D00000o`3oon0d
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooPX03=QCl400000080003o1@00003o0?ooh380oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2S0<f5?`<000000`000?l400000?l0
oooP<03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh:D0cHDo100000020000o`@00000o`3oon0^0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPY`3=QCl400000080003o1@00
003o0?ooh2/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon2Y0<f5?`@000000P000?l400000?l0oooP:P3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh:`0cHDo0`0000030000
o`@00000o`3oon0W0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP[P3=QCl400000080003o1000003o0?ooh2D0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh;00cHDo100000020000o`@00000
o`3oon0Q0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on2b0<f5?`@000000P000?l300000?l0oooP8P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh;@0cHDo100000020000o`@00000o`3oon0O
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP]`3=QCl300000080003o1000003o0?ooh1d0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2h0<f5?`@000000P000?l400000?l0
oooP6`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh;X0cHDo100000020000o`@00000o`3oon0I0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP_03=QCl400000080003o0`00
003o0?ooh1P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon2n0<f5?`@000000P000?l400000?l0oooP5@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh<00cHDo100000020000
o`<00000o`3oon0D0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP`P3=QCl400000080003o0`00003o0?ooh180oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon340<f5?`@00000
0P000?l300000?l0oooP403oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh<H0cHDo100000000`000?l000000000000200000?l0oooP3P3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh009
0?ooh<P0cHDo0`0000020000o`<00000o`3oon0=0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPbP3=QCl300000080003o1000003o0?oo
h0X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh<`0
cHDo0`0000000`000?l000000000000200000?l0oooP1`3oon03000001P0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPc@3=QCl300000080003o1000003o0?ooh0L0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on3?0<f5?`<000000P000?l400000?l0oooP1@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=40cHDo0`0000020000o`<00000o`3oon04
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooPd`3=QCl3000000030000o`000000000000800000o`3oon020?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPe03=QCl300000080
003o1000003o0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooPeP3=QCl300000080003o1000003m0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPf03=QCl300000080003o0`00
003l0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPfP3=QCl3000000030000o`000000000000800000nP3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=`0cHDo0P0000020000
o`@00000n03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh=d0cHDo0`0000020000o`<00000m`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=l0cHDo0`0000000`000?l00000
0000000200000?D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P00
00080?ooh0030000003oon00oooP00T0oooPh03=QCl300000080003o0`00003d0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<0
00000?ooh03oon002@3oon3R0<f5?`<000000P000?l300000?80oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon04000000P0oooPi`00
00020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00
oooP000000L0oooP00<000000?ooh03oon00k`3oon03000000040000o`000000000000000>@0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?oo
h00000070?ooh0030000003oon00oooP0?00oooP0`0000020000o`<00000hP0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?oo
h03b0?ooh0<0000000<0003o0000000000000P00003P03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00l`3oon0300000080003o0`00003O
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00m@3oon03000000040000o`000000000000000=h0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03f0?ooh0<000000P000?l30000
0=`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03h0?ooh0<0000000<0003o0000000000000P00003J03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00nP3oon02000000030000
o`000000000000800000f@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?/0oooP0P0000020000o`@00000e`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?d0oooP0P000000
0`000?l000000000000200000=H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03n0?ooh08000000P000?l400000=@0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh040
oooP0P0000000`000?l000000000000200000=<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh080oooP0P0000020000o`@00000
d@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP103oon02000000030000o`000000000000800000d00cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon060?ooh003000000000?l0
003o00@00000cP0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon070?ooh080000000<0003o0000000000000P00003=03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon080?ooh080
00000P000?l400000</0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0X0oooP0P0000000`000?l000000000000200000<X0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh0/0oooP0P0000020000o`@00000b00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3@3oon02000000030000o`000000
000000800000a`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP3P3oon0200000080003o0`00003603>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0?0?ooh0<0
000000<0003o0000000000000P00003403>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0A0?ooh08000000P000?l300000<<0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh1<0oooP0P0000000`000?l000000000000200000<40<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP0P000002
0000o`<00000`00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP5@3oon03000000040000o`000000000000000;l0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h1L0oooP0P0000020000o`<00000_@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP603oon03000000040000o`00000000000000
0;`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0
oooP6@3oon0300000080003o0P00002k03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh1/0oooP0`00000010000?l0000000000000002i03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0L0?ooh0<0000000@0003o0000000000000000^00cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7@3oon0300000080003o
0P00002g03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0O0?ooh0<0000000@0003o0000000000000000]@0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP803o
on03000000040000o`000000000000000;@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh280oooP0P0000020000o`800000/`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP8`3oon03000000040000o`000000000000000;40<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2@0oooP0`000000
10000?l0000000000000002`03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0V0?ooh08000000P000?l200000:l0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h2L0oooP0`00000010000?l0000000000000002]03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0X0?ooh0<0000000@0003o0000
000000000000[00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP:P3oon0200000080003o0P00002[03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0[0?ooh0<0
000000@0003o0000000000000000Z@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<00000o`3oon0/0?ooh0<0000000@0003o0000000000000000Z00cXLX90?oo
h0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]0?ooh0<0
00000P000?l200000:L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh2l0oooP0`0000000`000?l000000000002V03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0`0?ooh0<0000000@0003o0000000000000000Y00cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<@3oon03000000040000o`00
0000000000000:<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh3<0oooP0P0000020000o`800000XP0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP=03oon03
000000030000o`00000000000:40<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3D0oooP0`0000000`000?l000000000002P03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0f0?ooh0<000000P000?l2000009h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP100000000`000?l00000
0000002M03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0i0?ooh0<0000000<0003o000000000000W00cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>P3oon03
000000030000o`000000000009/0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3/0oooP0`0000020000o`800000V@0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP?03oon04000000030000o`000000000009P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3h0oooP0`0000000`000?l00000
0000002G03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
003o0?ooh3l0oooP0`0000000`000?l000000000002F03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh400oooP0`00000010000?l0000000000000
002D03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon110?ooh0<0000000@0003o0000000000000000T`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@`3oon02
00000080003o0P00002B03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon140?ooh0<0000000<0003o000000000000T@0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPA@3oon03000000030000o`00000000000900<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4H0oooP0`0000000`000?l00000
0000002?03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon170?ooh0<0000000@0003o0000000000000000S@0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB@3o
on02000000040000o`0000000000000008`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4X0oooP0P00000010000?l000000000
0000002;03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1;0?ooh080000000@0003o0000000000000000RP0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPC03o
on02000000040000o`0000000000000008T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00o`3oon1=0?ooh08000000P00
0?l2000008P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon00
0`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPC`3oon02000000030000o`000000
000008L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`00
0000oooP0?ooh0060?ooh0@00000o`3oon1>0?ooh0<0000000@0003o0000000000000000Q@0cXLX8
0?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`00
0000oooP0?ooh03o0?ooh500oooP0`00000010000?l0000000000000002403>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`00
0000oooP0?ooh03o0?ooh580oooP0P00000010000?l0000000000000002303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP
0?l0oooPD`3oon02000000040000o`000000000000000880<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5@0oooP0P0000001000
0?l0000000000000002103>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1E0?ooh080000000@0003o0000000000000000P00cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPEP3oon02000000040000o`0000000000000007l0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5L0oooP0P0000020000
o`800000OP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPF@3oon02000000040000o`0000000000000007`0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5X0
oooP0P00000010000?l0000000000000001k03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1K0?ooh080000000@0003o00000000
00000000NP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPG03oon02000000040000o`0000000000000007T0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5d0
oooP0P00000010000?l0000000000000001h03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1N0?ooh080000000@0003o00000000
00000000M`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon1O0?ooh080000000@0003o0000000000000000MP0cXLX90?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?ooh080000000@0003o00000000
00000000M@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPH@3oon0200000080003o0P00001d03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1R0?ooh0<00000
00<0003o000000000000L`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPH`3oon03000000030000o`00000000000780<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6D0oooP0P00000010000?l0000000000000001`03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1V0?ooh080000000@0003o
0000000000000000K`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPI`3oon02000000040000o`0000000000000006h0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6P0oooP0P00000010000?l0000000000000001]03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Y0?ooh080000000@0003o
0000000000000000K00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPJP3oon02000000040000o`0000000000000006/0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6/0oooP0P00000010000?l0000000000000001Z03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1/0?ooh080000000@0003o
0000000000000000J@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPK@3oon02000000040000o`0000000000000006P0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh6h0oooP0P00000010000?l0000000000000001W03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh6l0oooP0P0000020000o`800000IP0cXLX9
0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1`0?oo
h0<0000000<0003o000000000000I@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL@3oon03000000030000o`000000000006@0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh7<0oooP0P0000000`000?l000000000001S03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1c0?ooh0<0000000<0
003o000000000000HP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPM03oon03000000030000o`00000000000640<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h7D0oooP0`0000000`000?l000000000001P03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1f0?ooh0<0000000<0003o00000000
0000G`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPM`3oon03000000030000o`000000000005h0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7T0oooP0P00
00000`000?l000000000001M03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1i0?ooh0<0000000<0003o000000000000G00cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPNP3oon03000000030000o`000000000005/0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP0P0000000`000?l0
00000000001J03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon1m0?ooh080000000<0003o000000000000F@0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon1n0?ooh080000000<0
003o000000000000F00cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1o0?ooh080000000<0003o000000000000E`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP03oon020000
00030000o`000000000005H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh840oooP0P0000000`000?l000000000001E03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon220?ooh080000000<0003o000000000000E00cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP`3oon02000000030000o`00
0000000005<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh8@0oooP0P0000000`000?l000000000001B03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon250?oo
h080000000<0003o000000000000D@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQP3oon02000000030000o`00000000000500
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh8L0oooP0P0000000`000?l000000000001?03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon280?ooh080000000<0
003o000000000000CP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPR03oon03000000030000o`000000000004d0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h8T0oooP0`0000000`000?l000000000001<03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2;0?ooh080000000<0003o00000000
0000B`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000
o`3oon2<0?ooh080000000<0003o000000000000BP0cXLX90?ooh0<00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2<0?ooh0<0000000<0003o000000000000B@0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPS@3oon03000000030000o`000000000004P0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8h0oooP0`0000000`00
0?l000000000001703>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2?0?ooh0<0000000<0003o000000000000AP0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
T03oon02000000040000o`0000000000000004D0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh940oooP0P00000010000?l00000
00000000001403>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2B0?ooh080000000@0003o0000000000000000@`0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
T`3oon02000000040000o`000000000000000480<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9@0oooP0P00000010000?l00000
00000000001103>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon2E0?ooh080000000@0003o0000000000000000@00cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
UP3oon02000000040000o`0000000000000003l0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9L0oooP0P00000010000?l00000
00000000000n03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP
100000070?ooh0030000003oon00oooP0?l0oooPV03oon02000000030000o`000000000003h0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?oo
h0080?ooh0030000003oon00oooP0?l0oooPV@3oon02000000030000o`000000000003d0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon000`000000oooP0?ooh007
0?ooh0@00000o`3oon2I0?ooh003000000000?l0000000800000?00cXLX80?ooh0@00000603oon0N
0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?oo
h9/0oooP00<000000000o`0000000P00000k03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?oo
h9/0oooP0P00000010000?l0000000000000000j03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPW03oon020000
00040000o`0000000000000003T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9d0oooP0P00000010000?l0000000000000000h
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2N0?ooh080000000@0003o0000000000000000=`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX03oon000`00
0000003o00000002000003H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:00oooP0P00000010000?l0000000000000000e03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2Q0?ooh080000000<0003o000000000000=@0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPXP3oon02000000030000
o`000000000003@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh:<0oooP0P0000000`000?l000000000000c03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2T
0?ooh080000000<0003o000000000000<P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon02000000030000o`0000000000
0340<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh:H0oooP0P0000000`000?l000000000000`03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh:L0oooP0P0000000`000?l00000
0000000_03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh:P0oooP0P0000000`000?l000000000000^03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Y0?ooh003000000000?l0
000000800000;@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPZ@3oon02000000040000o`0000000000000002`0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:X0oooP0P00000010000?l0000000000000000[03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2[0?ooh080000000@0003o0000
000000000000:P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP[03oon02000000040000o`0000000000000002T0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h:d0oooP0P0000000`000?l000000000000Y03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2^0?ooh080000000<0003o00000000
0000:00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP[`3oon02000000030000o`000000000002L0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;00oooP0P00
00000`000?l000000000000V03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2`0?ooh0<0000000<0003o0000000000009@0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooP/@3oon03000000030000o`000000000002@0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;80oooP0`0000000`000?l0
00000000000S03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
0`00003o0?ooh;<0oooP0`0000000`000?l0000003>QbP0R03>QbPT0oooP0`00000H0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;@0oooP0`0000000`000?l0000003>Q
bP0Q03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2e0?ooh080000000<0003o0000000000008@0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP]P3oon020000
00030000o`00000000000200<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh;L0oooP0P0000000`000?l000000000000O03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2g0?ooh0<0000000<0003o0000000000007P0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^03oon03000000030000o`00
0000000001d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;T0oooP0`0000000`000?l0000003>QbP0L03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?oo
h080000000<0003o000000000000700cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^`3oon02000000030000o`000000000001/0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh;`0oooP0P0000000`000?l000000000000J03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2m0?ooh080000000<0
003o0000000000006@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP_@3oon03000000030000o`000000000001P0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;h0oooP0`0000000`000?l000000000000G03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2o0?ooh080000000@0003o00000000
000000005P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon300?ooh080000000<0003o0000000000005P0cXLX90?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon310?ooh080000000<0003o000000000000
5@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP`P3oon02000000030000o`000000000001@0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<<0oooP0P000000
0`000?l000000000000C03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon330?ooh0<0000000<0003o0000000000004P0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPa03oon02000000040000o`000000000000000140<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<D0oooP0P00000010000?l0
000000000000000@03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon360?ooh080000000<0003o000000000000400cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
a`3oon02000000030000o`000000000000l0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<P0oooP0P0000000`000?l000000000
000>03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon390?ooh080000000<0003o0000000000003@0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPbP3oon000`00
0000003o00000002000000`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh<X0oooP0P00000010000?l0000000000000000;03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon3;0?ooh080000000@0003o00000000000000002P0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon3<0?ooh080000000<0003o00000000
00002P0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon3=0?ooh080000000<0003o0000000000002@0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPcP3oon02000000030000o`00
0000000000P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh<h0oooP0`0000000`000?l000000000000703>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3?0?oo
h080000000@0003o00000000000000001P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd03oon02000000030000o`0000000000
00H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh=40oooP0P0000000`000?l000000000000503>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3B0?ooh0800000
00<0003o000000000000100cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPdP3oon03000000030000o`000000000000<0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh=<0oooP0`0000000`000?l000000000000203>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3D0?ooh0<0000000@0003o0000
00000000<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh=D0oooP0P00000010000?l000000000000cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?oo
h=H0oooP0P0000000`000?l000000000000;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3G0?oo
h080000000<0003o0000000000002P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon3F0?ooh0<0000000<0003o0000003o
on001P3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HC0?ooh0030000003oon00oooP00D0oooP
00<000000?ooh03oon00o`3oon3H0?ooh0@000002P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooP
f@3oon02000000/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P00
00080?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01a0?oo
h0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?oo
h0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
5@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00g03jl>H400000080n_3V200000020?[`iP@0000000L0n_3V0000000000000000
0?[`iP000000n_3V00`0000000<0n_3V00000000000010000000103jl>H000000000000000080?[`
iPD00000103jl>H7000000030?[`iP000000n_3V00<000002@3jl>H500000080n_3V100000020?[`
iPD000004P3jl>H6000000H0n_3V00<000000?[`iP3jl>H0103jl>H3000000040?[`iP0000000000
00000>@0n_3V0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000030?[`
iP070000003jl>H000000000003jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000T0n_3V00@000000?[`iP3jl>H0n_3V
0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`iP800000203jl>H00`000000
n_3V0?[`iP050?[`iP80000000<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H2000000030?[`
iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@00000
0P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
3@3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V0080
00002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000`0n_3V1@0000050?[`iP80
00001P3jl>H5000000H0n_3V0`00003V0?[`iP40oooo003M0?[`iPD00000103jl>H2000000<0n_3V
1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`
iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP06
0?[`iP<00000iP3jl>H10?ooo`00g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H20000
0080n_3V0P0000001P3jl>H000000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P00
0000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V
0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0180n_3V0P0000080?[`iP030000
003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003U0?[`iP40oooo003M0?[`iP8000000P3j
l>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP000000000000D000000P3j
l>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H000000000
0007000000/0n_3V1@0000020?[`iP@000000P3jl>H3000000030?[`iP000000000001<0n_3V0P00
000?0?[`iP<0000000D0n_3V00000000000000000?[`iP0400000=l0n_3V0@3oool00=d0n_3V0P00
00020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H0603jl>H200000240n_3V1000
000H0?[`iP030000003jl>H0n_3V0=l0n_3V0@3oool00=`0n_3V1P0000040?[`iP800000;`3jl>H5
000001/0n_3V0`00000Q0?[`iP8000006@3jl>H00`000000n_3V0?[`iP3N0?[`iP40oooo003o0?[`
iWP0n_3V00<000000?[`iP3jl>H0g@3jl>H10?ooo`00o`3jl>Ie0?[`iP040000003jl>H0n_3V0000
0=l0n_3V0@3oool00?l0n_3VMP3jl>H200000>00n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02424 .01472 L
.02424 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02424 .01472 L
.02424 .16187 L
s
1 .894 .882 r
.02424 .16187 m
.02424 .01472 L
.02508 .01472 L
.02508 .16187 L
F
.804 .522 .247 r
.02424 .16187 m
.02424 .01472 L
.02508 .01472 L
.02508 .16187 L
s
1 .894 .882 r
.02508 .16187 m
.02508 .01472 L
.0255 .01472 L
.0255 .16187 L
F
.804 .522 .247 r
.02508 .16187 m
.02508 .01472 L
.0255 .01472 L
.0255 .16187 L
s
1 .894 .882 r
.0255 .16187 m
.0255 .01472 L
.02589 .01472 L
.02589 .16187 L
F
.804 .522 .247 r
.0255 .16187 m
.0255 .01472 L
.02589 .01472 L
.02589 .16187 L
s
1 .894 .882 r
.02589 .16187 m
.02589 .01472 L
.02678 .01472 L
.02678 .16187 L
F
.804 .522 .247 r
.02589 .16187 m
.02589 .01472 L
.02678 .01472 L
.02678 .16187 L
s
1 .894 .882 r
.02678 .16187 m
.02678 .01472 L
.02731 .01472 L
.02731 .16187 L
F
.804 .522 .247 r
.02678 .16187 m
.02678 .01472 L
.02731 .01472 L
.02731 .16187 L
s
1 .894 .882 r
.02731 .16187 m
.02731 .01472 L
.02797 .01472 L
.02797 .16187 L
F
.804 .522 .247 r
.02731 .16187 m
.02731 .01472 L
.02797 .01472 L
.02797 .16187 L
s
1 .894 .882 r
.02797 .16187 m
.02797 .01473 L
.02886 .01473 L
.02886 .16187 L
F
.804 .522 .247 r
.02797 .16187 m
.02797 .01473 L
.02886 .01473 L
.02886 .16187 L
s
1 .894 .882 r
.02886 .16187 m
.02886 .01473 L
.02929 .01473 L
.02929 .16187 L
F
.804 .522 .247 r
.02886 .16187 m
.02886 .01473 L
.02929 .01473 L
.02929 .16187 L
s
1 .894 .882 r
.02929 .16187 m
.02929 .01474 L
.02983 .01474 L
.02983 .16187 L
F
.804 .522 .247 r
.02929 .16187 m
.02929 .01474 L
.02983 .01474 L
.02983 .16187 L
s
1 .894 .882 r
.02983 .16187 m
.02983 .01474 L
.03074 .01474 L
.03074 .16187 L
F
.804 .522 .247 r
.02983 .16187 m
.02983 .01474 L
.03074 .01474 L
.03074 .16187 L
s
1 .894 .882 r
.03074 .16187 m
.03074 .01475 L
.03149 .01475 L
.03149 .16187 L
F
.804 .522 .247 r
.03074 .16187 m
.03074 .01475 L
.03149 .01475 L
.03149 .16187 L
s
1 .894 .882 r
.03149 .16187 m
.03149 .01476 L
.0318 .01476 L
.0318 .16187 L
F
.804 .522 .247 r
.03149 .16187 m
.03149 .01476 L
.0318 .01476 L
.0318 .16187 L
s
1 .894 .882 r
.0318 .16187 m
.0318 .01476 L
.03231 .01476 L
.03231 .16187 L
F
.804 .522 .247 r
.0318 .16187 m
.0318 .01476 L
.03231 .01476 L
.03231 .16187 L
s
1 .894 .882 r
.03231 .16187 m
.03231 .01477 L
.03278 .01477 L
.03278 .16187 L
F
.804 .522 .247 r
.03231 .16187 m
.03231 .01477 L
.03278 .01477 L
.03278 .16187 L
s
1 .894 .882 r
.03278 .16187 m
.03278 .01477 L
.03365 .01477 L
.03365 .16187 L
F
.804 .522 .247 r
.03278 .16187 m
.03278 .01477 L
.03365 .01477 L
.03365 .16187 L
s
1 .894 .882 r
.03365 .16187 m
.03365 .01478 L
.03452 .01478 L
.03452 .16187 L
F
.804 .522 .247 r
.03365 .16187 m
.03365 .01478 L
.03452 .01478 L
.03452 .16187 L
s
1 .894 .882 r
.03452 .16187 m
.03452 .01479 L
.03521 .01479 L
.03521 .16187 L
F
.804 .522 .247 r
.03452 .16187 m
.03452 .01479 L
.03521 .01479 L
.03521 .16187 L
s
1 .894 .882 r
.03521 .16187 m
.03521 .01481 L
.03617 .01481 L
.03617 .16187 L
F
.804 .522 .247 r
.03521 .16187 m
.03521 .01481 L
.03617 .01481 L
.03617 .16187 L
s
1 .894 .882 r
.03617 .16187 m
.03617 .01482 L
.03704 .01482 L
.03704 .16187 L
F
.804 .522 .247 r
.03617 .16187 m
.03617 .01482 L
.03704 .01482 L
.03704 .16187 L
s
1 .894 .882 r
.03704 .16187 m
.03704 .01483 L
.03781 .01483 L
.03781 .16187 L
F
.804 .522 .247 r
.03704 .16187 m
.03704 .01483 L
.03781 .01483 L
.03781 .16187 L
s
1 .894 .882 r
.03781 .16187 m
.03781 .01485 L
.03844 .01485 L
.03844 .16187 L
F
.804 .522 .247 r
.03781 .16187 m
.03781 .01485 L
.03844 .01485 L
.03844 .16187 L
s
1 .894 .882 r
.03844 .16187 m
.03844 .01486 L
.03916 .01486 L
.03916 .16187 L
F
.804 .522 .247 r
.03844 .16187 m
.03844 .01486 L
.03916 .01486 L
.03916 .16187 L
s
1 .894 .882 r
.03916 .16187 m
.03916 .01488 L
.04009 .01488 L
.04009 .16187 L
F
.804 .522 .247 r
.03916 .16187 m
.03916 .01488 L
.04009 .01488 L
.04009 .16187 L
s
1 .894 .882 r
.04009 .16187 m
.04009 .01489 L
.04074 .01489 L
.04074 .16187 L
F
.804 .522 .247 r
.04009 .16187 m
.04009 .01489 L
.04074 .01489 L
.04074 .16187 L
s
1 .894 .882 r
.04074 .16187 m
.04074 .01492 L
.04156 .01492 L
.04156 .16187 L
F
.804 .522 .247 r
.04074 .16187 m
.04074 .01492 L
.04156 .01492 L
.04156 .16187 L
s
1 .894 .882 r
.04156 .16187 m
.04156 .01493 L
.04217 .01493 L
.04217 .16187 L
F
.804 .522 .247 r
.04156 .16187 m
.04156 .01493 L
.04217 .01493 L
.04217 .16187 L
s
1 .894 .882 r
.04217 .16187 m
.04217 .01493 L
.04302 .01493 L
.04302 .16187 L
F
.804 .522 .247 r
.04217 .16187 m
.04217 .01493 L
.04302 .01493 L
.04302 .16187 L
s
1 .894 .882 r
.04302 .16187 m
.04302 .01496 L
.04381 .01496 L
.04381 .16187 L
F
.804 .522 .247 r
.04302 .16187 m
.04302 .01496 L
.04381 .01496 L
.04381 .16187 L
s
1 .894 .882 r
.04381 .16187 m
.04381 .01498 L
.04442 .01498 L
.04442 .16187 L
F
.804 .522 .247 r
.04381 .16187 m
.04381 .01498 L
.04442 .01498 L
.04442 .16187 L
s
1 .894 .882 r
.04442 .16187 m
.04442 .01499 L
.0454 .01499 L
.0454 .16187 L
F
.804 .522 .247 r
.04442 .16187 m
.04442 .01499 L
.0454 .01499 L
.0454 .16187 L
s
1 .894 .882 r
.0454 .16187 m
.0454 .01502 L
.04641 .01502 L
.04641 .16187 L
F
.804 .522 .247 r
.0454 .16187 m
.0454 .01502 L
.04641 .01502 L
.04641 .16187 L
s
1 .894 .882 r
.04641 .16187 m
.04641 .01506 L
.04707 .01506 L
.04707 .16187 L
F
.804 .522 .247 r
.04641 .16187 m
.04641 .01506 L
.04707 .01506 L
.04707 .16187 L
s
1 .894 .882 r
.04707 .16187 m
.04707 .01507 L
.04745 .01507 L
.04745 .16187 L
F
.804 .522 .247 r
.04707 .16187 m
.04707 .01507 L
.04745 .01507 L
.04745 .16187 L
s
1 .894 .882 r
.04745 .16187 m
.04745 .01508 L
.04784 .01508 L
.04784 .16187 L
F
.804 .522 .247 r
.04745 .16187 m
.04745 .01508 L
.04784 .01508 L
.04784 .16187 L
s
1 .894 .882 r
.04784 .16187 m
.04784 .0151 L
.0484 .0151 L
.0484 .16187 L
F
.804 .522 .247 r
.04784 .16187 m
.04784 .0151 L
.0484 .0151 L
.0484 .16187 L
s
1 .894 .882 r
.0484 .16187 m
.0484 .01512 L
.04906 .01512 L
.04906 .16187 L
F
.804 .522 .247 r
.0484 .16187 m
.0484 .01512 L
.04906 .01512 L
.04906 .16187 L
s
1 .894 .882 r
.04906 .16187 m
.04906 .01514 L
.04997 .01514 L
.04997 .16187 L
F
.804 .522 .247 r
.04906 .16187 m
.04906 .01514 L
.04997 .01514 L
.04997 .16187 L
s
1 .894 .882 r
.04997 .16187 m
.04997 .01518 L
.05092 .01518 L
.05092 .16187 L
F
.804 .522 .247 r
.04997 .16187 m
.04997 .01518 L
.05092 .01518 L
.05092 .16187 L
s
1 .894 .882 r
.05092 .16187 m
.05092 .01519 L
.05165 .01519 L
.05165 .16187 L
F
.804 .522 .247 r
.05092 .16187 m
.05092 .01519 L
.05165 .01519 L
.05165 .16187 L
s
1 .894 .882 r
.05165 .16187 m
.05165 .01524 L
.05247 .01524 L
.05247 .16187 L
F
.804 .522 .247 r
.05165 .16187 m
.05165 .01524 L
.05247 .01524 L
.05247 .16187 L
s
1 .894 .882 r
.05247 .16187 m
.05247 .01525 L
.05301 .01525 L
.05301 .16187 L
F
.804 .522 .247 r
.05247 .16187 m
.05247 .01525 L
.05301 .01525 L
.05301 .16187 L
s
1 .894 .882 r
.05301 .16187 m
.05301 .0153 L
.05402 .0153 L
.05402 .16187 L
F
.804 .522 .247 r
.05301 .16187 m
.05301 .0153 L
.05402 .0153 L
.05402 .16187 L
s
1 .894 .882 r
.05402 .16187 m
.05402 .01534 L
.05493 .01534 L
.05493 .16187 L
F
.804 .522 .247 r
.05402 .16187 m
.05402 .01534 L
.05493 .01534 L
.05493 .16187 L
s
1 .894 .882 r
.05493 .16187 m
.05493 .01535 L
.05529 .01535 L
.05529 .16187 L
F
.804 .522 .247 r
.05493 .16187 m
.05493 .01535 L
.05529 .01535 L
.05529 .16187 L
s
1 .894 .882 r
.05529 .16187 m
.05529 .01538 L
.05623 .01538 L
.05623 .16187 L
F
.804 .522 .247 r
.05529 .16187 m
.05529 .01538 L
.05623 .01538 L
.05623 .16187 L
s
1 .894 .882 r
.05623 .16187 m
.05623 .01541 L
.05683 .01541 L
.05683 .16187 L
F
.804 .522 .247 r
.05623 .16187 m
.05623 .01541 L
.05683 .01541 L
.05683 .16187 L
s
1 .894 .882 r
.05683 .16187 m
.05683 .01543 L
.05785 .01543 L
.05785 .16187 L
F
.804 .522 .247 r
.05683 .16187 m
.05683 .01543 L
.05785 .01543 L
.05785 .16187 L
s
1 .894 .882 r
.05785 .16187 m
.05785 .01548 L
.0586 .01548 L
.0586 .16187 L
F
.804 .522 .247 r
.05785 .16187 m
.05785 .01548 L
.0586 .01548 L
.0586 .16187 L
s
1 .894 .882 r
.0586 .16187 m
.0586 .01551 L
.05902 .01551 L
.05902 .16187 L
F
.804 .522 .247 r
.0586 .16187 m
.0586 .01551 L
.05902 .01551 L
.05902 .16187 L
s
1 .894 .882 r
.05902 .16187 m
.05902 .01555 L
.06005 .01555 L
.06005 .16187 L
F
.804 .522 .247 r
.05902 .16187 m
.05902 .01555 L
.06005 .01555 L
.06005 .16187 L
s
1 .894 .882 r
.06005 .16187 m
.06005 .01557 L
.06052 .01557 L
.06052 .16187 L
F
.804 .522 .247 r
.06005 .16187 m
.06005 .01557 L
.06052 .01557 L
.06052 .16187 L
s
1 .894 .882 r
.06052 .16187 m
.06052 .01559 L
.06152 .01559 L
.06152 .16187 L
F
.804 .522 .247 r
.06052 .16187 m
.06052 .01559 L
.06152 .01559 L
.06152 .16187 L
s
1 .894 .882 r
.06152 .16187 m
.06152 .01564 L
.06237 .01564 L
.06237 .16187 L
F
.804 .522 .247 r
.06152 .16187 m
.06152 .01564 L
.06237 .01564 L
.06237 .16187 L
s
1 .894 .882 r
.06237 .16187 m
.06237 .01569 L
.06273 .01569 L
.06273 .16187 L
F
.804 .522 .247 r
.06237 .16187 m
.06237 .01569 L
.06273 .01569 L
.06273 .16187 L
s
1 .894 .882 r
.06273 .16187 m
.06273 .0157 L
.06323 .0157 L
.06323 .16187 L
F
.804 .522 .247 r
.06273 .16187 m
.06273 .0157 L
.06323 .0157 L
.06323 .16187 L
s
1 .894 .882 r
.06323 .16187 m
.06323 .01574 L
.06387 .01574 L
.06387 .16187 L
F
.804 .522 .247 r
.06323 .16187 m
.06323 .01574 L
.06387 .01574 L
.06387 .16187 L
s
1 .894 .882 r
.06387 .16187 m
.06387 .01578 L
.06465 .01578 L
.06465 .16187 L
F
.804 .522 .247 r
.06387 .16187 m
.06387 .01578 L
.06465 .01578 L
.06465 .16187 L
s
1 .894 .882 r
.06465 .16187 m
.06465 .01581 L
.06566 .01581 L
.06566 .16187 L
F
.804 .522 .247 r
.06465 .16187 m
.06465 .01581 L
.06566 .01581 L
.06566 .16187 L
s
1 .894 .882 r
.06566 .16187 m
.06566 .0159 L
.06664 .0159 L
.06664 .16187 L
F
.804 .522 .247 r
.06566 .16187 m
.06566 .0159 L
.06664 .0159 L
.06664 .16187 L
s
1 .894 .882 r
.06664 .16187 m
.06664 .01595 L
.06765 .01595 L
.06765 .16187 L
F
.804 .522 .247 r
.06664 .16187 m
.06664 .01595 L
.06765 .01595 L
.06765 .16187 L
s
1 .894 .882 r
.06765 .16187 m
.06765 .01598 L
.06856 .01598 L
.06856 .16187 L
F
.804 .522 .247 r
.06765 .16187 m
.06765 .01598 L
.06856 .01598 L
.06856 .16187 L
s
1 .894 .882 r
.06856 .16187 m
.06856 .01603 L
.06894 .01603 L
.06894 .16187 L
F
.804 .522 .247 r
.06856 .16187 m
.06856 .01603 L
.06894 .01603 L
.06894 .16187 L
s
1 .894 .882 r
.06894 .16187 m
.06894 .01606 L
.06949 .01606 L
.06949 .16187 L
F
.804 .522 .247 r
.06894 .16187 m
.06894 .01606 L
.06949 .01606 L
.06949 .16187 L
s
1 .894 .882 r
.06949 .16187 m
.06949 .01608 L
.06999 .01608 L
.06999 .16187 L
F
.804 .522 .247 r
.06949 .16187 m
.06949 .01608 L
.06999 .01608 L
.06999 .16187 L
s
1 .894 .882 r
.06999 .16187 m
.06999 .01611 L
.07067 .01611 L
.07067 .16187 L
F
.804 .522 .247 r
.06999 .16187 m
.06999 .01611 L
.07067 .01611 L
.07067 .16187 L
s
1 .894 .882 r
.07067 .16187 m
.07067 .01616 L
.07107 .01616 L
.07107 .16187 L
F
.804 .522 .247 r
.07067 .16187 m
.07067 .01616 L
.07107 .01616 L
.07107 .16187 L
s
1 .894 .882 r
.07107 .16187 m
.07107 .01619 L
.07175 .01619 L
.07175 .16187 L
F
.804 .522 .247 r
.07107 .16187 m
.07107 .01619 L
.07175 .01619 L
.07175 .16187 L
s
1 .894 .882 r
.07175 .16187 m
.07175 .01623 L
.0722 .01623 L
.0722 .16187 L
F
.804 .522 .247 r
.07175 .16187 m
.07175 .01623 L
.0722 .01623 L
.0722 .16187 L
s
1 .894 .882 r
.0722 .16187 m
.0722 .01627 L
.07298 .01627 L
.07298 .16187 L
F
.804 .522 .247 r
.0722 .16187 m
.0722 .01627 L
.07298 .01627 L
.07298 .16187 L
s
1 .894 .882 r
.07298 .16187 m
.07298 .01632 L
.07381 .01632 L
.07381 .16187 L
F
.804 .522 .247 r
.07298 .16187 m
.07298 .01632 L
.07381 .01632 L
.07381 .16187 L
s
1 .894 .882 r
.07381 .16187 m
.07381 .01636 L
.07452 .01636 L
.07452 .16187 L
F
.804 .522 .247 r
.07381 .16187 m
.07381 .01636 L
.07452 .01636 L
.07452 .16187 L
s
1 .894 .882 r
.07452 .16187 m
.07452 .0164 L
.07525 .0164 L
.07525 .16187 L
F
.804 .522 .247 r
.07452 .16187 m
.07452 .0164 L
.07525 .0164 L
.07525 .16187 L
s
1 .894 .882 r
.07525 .16187 m
.07525 .01644 L
.07592 .01644 L
.07592 .16187 L
F
.804 .522 .247 r
.07525 .16187 m
.07525 .01644 L
.07592 .01644 L
.07592 .16187 L
s
1 .894 .882 r
.07592 .16187 m
.07592 .01653 L
.07675 .01653 L
.07675 .16187 L
F
.804 .522 .247 r
.07592 .16187 m
.07592 .01653 L
.07675 .01653 L
.07675 .16187 L
s
1 .894 .882 r
.07675 .16187 m
.07675 .01654 L
.07729 .01654 L
.07729 .16187 L
F
.804 .522 .247 r
.07675 .16187 m
.07675 .01654 L
.07729 .01654 L
.07729 .16187 L
s
1 .894 .882 r
.07729 .16187 m
.07729 .01659 L
.07807 .01659 L
.07807 .16187 L
F
.804 .522 .247 r
.07729 .16187 m
.07729 .01659 L
.07807 .01659 L
.07807 .16187 L
s
1 .894 .882 r
.07807 .16187 m
.07807 .01663 L
.07892 .01663 L
.07892 .16187 L
F
.804 .522 .247 r
.07807 .16187 m
.07807 .01663 L
.07892 .01663 L
.07892 .16187 L
s
1 .894 .882 r
.07892 .16187 m
.07892 .01671 L
.0797 .01671 L
.0797 .16187 L
F
.804 .522 .247 r
.07892 .16187 m
.07892 .01671 L
.0797 .01671 L
.0797 .16187 L
s
1 .894 .882 r
.0797 .16187 m
.0797 .01674 L
.08005 .01674 L
.08005 .16187 L
F
.804 .522 .247 r
.0797 .16187 m
.0797 .01674 L
.08005 .01674 L
.08005 .16187 L
s
1 .894 .882 r
.08005 .16187 m
.08005 .01679 L
.0805 .01679 L
.0805 .16187 L
F
.804 .522 .247 r
.08005 .16187 m
.08005 .01679 L
.0805 .01679 L
.0805 .16187 L
s
1 .894 .882 r
.0805 .16187 m
.0805 .01681 L
.08089 .01681 L
.08089 .16187 L
F
.804 .522 .247 r
.0805 .16187 m
.0805 .01681 L
.08089 .01681 L
.08089 .16187 L
s
1 .894 .882 r
.08089 .16187 m
.08089 .01684 L
.08169 .01684 L
.08169 .16187 L
F
.804 .522 .247 r
.08089 .16187 m
.08089 .01684 L
.08169 .01684 L
.08169 .16187 L
s
1 .894 .882 r
.08169 .16187 m
.08169 .0169 L
.08209 .0169 L
.08209 .16187 L
F
.804 .522 .247 r
.08169 .16187 m
.08169 .0169 L
.08209 .0169 L
.08209 .16187 L
s
1 .894 .882 r
.08209 .16187 m
.08209 .01695 L
.08257 .01695 L
.08257 .16187 L
F
.804 .522 .247 r
.08209 .16187 m
.08209 .01695 L
.08257 .01695 L
.08257 .16187 L
s
1 .894 .882 r
.08257 .16187 m
.08257 .01699 L
.08308 .01699 L
.08308 .16187 L
F
.804 .522 .247 r
.08257 .16187 m
.08257 .01699 L
.08308 .01699 L
.08308 .16187 L
s
1 .894 .882 r
.08308 .16187 m
.08308 .01702 L
.08381 .01702 L
.08381 .16187 L
F
.804 .522 .247 r
.08308 .16187 m
.08308 .01702 L
.08381 .01702 L
.08381 .16187 L
s
1 .894 .882 r
.08381 .16187 m
.08381 .01709 L
.08471 .01709 L
.08471 .16187 L
F
.804 .522 .247 r
.08381 .16187 m
.08381 .01709 L
.08471 .01709 L
.08471 .16187 L
s
1 .894 .882 r
.08471 .16187 m
.08471 .01717 L
.08571 .01717 L
.08571 .16187 L
F
.804 .522 .247 r
.08471 .16187 m
.08471 .01717 L
.08571 .01717 L
.08571 .16187 L
s
1 .894 .882 r
.08571 .16187 m
.08571 .01725 L
.08658 .01725 L
.08658 .16187 L
F
.804 .522 .247 r
.08571 .16187 m
.08571 .01725 L
.08658 .01725 L
.08658 .16187 L
s
1 .894 .882 r
.08658 .16187 m
.08658 .0173 L
.08723 .0173 L
.08723 .16187 L
F
.804 .522 .247 r
.08658 .16187 m
.08658 .0173 L
.08723 .0173 L
.08723 .16187 L
s
1 .894 .882 r
.08723 .16187 m
.08723 .01736 L
.08774 .01736 L
.08774 .16187 L
F
.804 .522 .247 r
.08723 .16187 m
.08723 .01736 L
.08774 .01736 L
.08774 .16187 L
s
1 .894 .882 r
.08774 .16187 m
.08774 .01744 L
.08861 .01744 L
.08861 .16187 L
F
.804 .522 .247 r
.08774 .16187 m
.08774 .01744 L
.08861 .01744 L
.08861 .16187 L
s
1 .894 .882 r
.08861 .16187 m
.08861 .01744 L
.08901 .01744 L
.08901 .16187 L
F
.804 .522 .247 r
.08861 .16187 m
.08861 .01744 L
.08901 .01744 L
.08901 .16187 L
s
1 .894 .882 r
.08901 .16187 m
.08901 .01754 L
.08987 .01754 L
.08987 .16187 L
F
.804 .522 .247 r
.08901 .16187 m
.08901 .01754 L
.08987 .01754 L
.08987 .16187 L
s
1 .894 .882 r
.08987 .16187 m
.08987 .01758 L
.09071 .01758 L
.09071 .16187 L
F
.804 .522 .247 r
.08987 .16187 m
.08987 .01758 L
.09071 .01758 L
.09071 .16187 L
s
1 .894 .882 r
.09071 .16187 m
.09071 .01764 L
.09115 .01764 L
.09115 .16187 L
F
.804 .522 .247 r
.09071 .16187 m
.09071 .01764 L
.09115 .01764 L
.09115 .16187 L
s
1 .894 .882 r
.09115 .16187 m
.09115 .01772 L
.09193 .01772 L
.09193 .16187 L
F
.804 .522 .247 r
.09115 .16187 m
.09115 .01772 L
.09193 .01772 L
.09193 .16187 L
s
1 .894 .882 r
.09193 .16187 m
.09193 .01773 L
.09226 .01773 L
.09226 .16187 L
F
.804 .522 .247 r
.09193 .16187 m
.09193 .01773 L
.09226 .01773 L
.09226 .16187 L
s
1 .894 .882 r
.09226 .16187 m
.09226 .01777 L
.09287 .01777 L
.09287 .16187 L
F
.804 .522 .247 r
.09226 .16187 m
.09226 .01777 L
.09287 .01777 L
.09287 .16187 L
s
1 .894 .882 r
.09287 .16187 m
.09287 .01783 L
.09357 .01783 L
.09357 .16187 L
F
.804 .522 .247 r
.09287 .16187 m
.09287 .01783 L
.09357 .01783 L
.09357 .16187 L
s
1 .894 .882 r
.09357 .16187 m
.09357 .01795 L
.09453 .01795 L
.09453 .16187 L
F
.804 .522 .247 r
.09357 .16187 m
.09357 .01795 L
.09453 .01795 L
.09453 .16187 L
s
1 .894 .882 r
.09453 .16187 m
.09453 .018 L
.09512 .018 L
.09512 .16187 L
F
.804 .522 .247 r
.09453 .16187 m
.09453 .018 L
.09512 .018 L
.09512 .16187 L
s
1 .894 .882 r
.09512 .16187 m
.09512 .01802 L
.09569 .01802 L
.09569 .16187 L
F
.804 .522 .247 r
.09512 .16187 m
.09512 .01802 L
.09569 .01802 L
.09569 .16187 L
s
1 .894 .882 r
.09569 .16187 m
.09569 .0181 L
.09625 .0181 L
.09625 .16187 L
F
.804 .522 .247 r
.09569 .16187 m
.09569 .0181 L
.09625 .0181 L
.09625 .16187 L
s
1 .894 .882 r
.09625 .16187 m
.09625 .01816 L
.09713 .01816 L
.09713 .16187 L
F
.804 .522 .247 r
.09625 .16187 m
.09625 .01816 L
.09713 .01816 L
.09713 .16187 L
s
1 .894 .882 r
.09713 .16187 m
.09713 .01825 L
.09795 .01825 L
.09795 .16187 L
F
.804 .522 .247 r
.09713 .16187 m
.09713 .01825 L
.09795 .01825 L
.09795 .16187 L
s
1 .894 .882 r
.09795 .16187 m
.09795 .01832 L
.09843 .01832 L
.09843 .16187 L
F
.804 .522 .247 r
.09795 .16187 m
.09795 .01832 L
.09843 .01832 L
.09843 .16187 L
s
1 .894 .882 r
.09843 .16187 m
.09843 .01835 L
.09883 .01835 L
.09883 .16187 L
F
.804 .522 .247 r
.09843 .16187 m
.09843 .01835 L
.09883 .01835 L
.09883 .16187 L
s
1 .894 .882 r
.09883 .16187 m
.09883 .0184 L
.0995 .0184 L
.0995 .16187 L
F
.804 .522 .247 r
.09883 .16187 m
.09883 .0184 L
.0995 .0184 L
.0995 .16187 L
s
1 .894 .882 r
.0995 .16187 m
.0995 .01844 L
.09991 .01844 L
.09991 .16187 L
F
.804 .522 .247 r
.0995 .16187 m
.0995 .01844 L
.09991 .01844 L
.09991 .16187 L
s
1 .894 .882 r
.09991 .16187 m
.09991 .01848 L
.10052 .01848 L
.10052 .16187 L
F
.804 .522 .247 r
.09991 .16187 m
.09991 .01848 L
.10052 .01848 L
.10052 .16187 L
s
1 .894 .882 r
.10052 .16187 m
.10052 .01853 L
.10096 .01853 L
.10096 .16187 L
F
.804 .522 .247 r
.10052 .16187 m
.10052 .01853 L
.10096 .01853 L
.10096 .16187 L
s
1 .894 .882 r
.10096 .16187 m
.10096 .01864 L
.10179 .01864 L
.10179 .16187 L
F
.804 .522 .247 r
.10096 .16187 m
.10096 .01864 L
.10179 .01864 L
.10179 .16187 L
s
1 .894 .882 r
.10179 .16187 m
.10179 .01871 L
.10259 .01871 L
.10259 .16187 L
F
.804 .522 .247 r
.10179 .16187 m
.10179 .01871 L
.10259 .01871 L
.10259 .16187 L
s
1 .894 .882 r
.10259 .16187 m
.10259 .01875 L
.103 .01875 L
.103 .16187 L
F
.804 .522 .247 r
.10259 .16187 m
.10259 .01875 L
.103 .01875 L
.103 .16187 L
s
1 .894 .882 r
.103 .16187 m
.103 .01879 L
.1036 .01879 L
.1036 .16187 L
F
.804 .522 .247 r
.103 .16187 m
.103 .01879 L
.1036 .01879 L
.1036 .16187 L
s
1 .894 .882 r
.1036 .16187 m
.1036 .0189 L
.10434 .0189 L
.10434 .16187 L
F
.804 .522 .247 r
.1036 .16187 m
.1036 .0189 L
.10434 .0189 L
.10434 .16187 L
s
1 .894 .882 r
.10434 .16187 m
.10434 .01899 L
.10533 .01899 L
.10533 .16187 L
F
.804 .522 .247 r
.10434 .16187 m
.10434 .01899 L
.10533 .01899 L
.10533 .16187 L
s
1 .894 .882 r
.10533 .16187 m
.10533 .01908 L
.10592 .01908 L
.10592 .16187 L
F
.804 .522 .247 r
.10533 .16187 m
.10533 .01908 L
.10592 .01908 L
.10592 .16187 L
s
1 .894 .882 r
.10592 .16187 m
.10592 .01911 L
.1064 .01911 L
.1064 .16187 L
F
.804 .522 .247 r
.10592 .16187 m
.10592 .01911 L
.1064 .01911 L
.1064 .16187 L
s
1 .894 .882 r
.1064 .16187 m
.1064 .01923 L
.1074 .01923 L
.1074 .16187 L
F
.804 .522 .247 r
.1064 .16187 m
.1064 .01923 L
.1074 .01923 L
.1074 .16187 L
s
1 .894 .882 r
.1074 .16187 m
.1074 .01932 L
.10836 .01932 L
.10836 .16187 L
F
.804 .522 .247 r
.1074 .16187 m
.1074 .01932 L
.10836 .01932 L
.10836 .16187 L
s
1 .894 .882 r
.10836 .16187 m
.10836 .01943 L
.10938 .01943 L
.10938 .16187 L
F
.804 .522 .247 r
.10836 .16187 m
.10836 .01943 L
.10938 .01943 L
.10938 .16187 L
s
1 .894 .882 r
.10938 .16187 m
.10938 .01948 L
.11019 .01948 L
.11019 .16187 L
F
.804 .522 .247 r
.10938 .16187 m
.10938 .01948 L
.11019 .01948 L
.11019 .16187 L
s
1 .894 .882 r
.11019 .16187 m
.11019 .01959 L
.11055 .01959 L
.11055 .16187 L
F
.804 .522 .247 r
.11019 .16187 m
.11019 .01959 L
.11055 .01959 L
.11055 .16187 L
s
1 .894 .882 r
.11055 .16187 m
.11055 .01967 L
.11123 .01967 L
.11123 .16187 L
F
.804 .522 .247 r
.11055 .16187 m
.11055 .01967 L
.11123 .01967 L
.11123 .16187 L
s
1 .894 .882 r
.11123 .16187 m
.11123 .01972 L
.11199 .01972 L
.11199 .16187 L
F
.804 .522 .247 r
.11123 .16187 m
.11123 .01972 L
.11199 .01972 L
.11199 .16187 L
s
1 .894 .882 r
.11199 .16187 m
.11199 .0198 L
.11254 .0198 L
.11254 .16187 L
F
.804 .522 .247 r
.11199 .16187 m
.11199 .0198 L
.11254 .0198 L
.11254 .16187 L
s
1 .894 .882 r
.11254 .16187 m
.11254 .01985 L
.11306 .01985 L
.11306 .16187 L
F
.804 .522 .247 r
.11254 .16187 m
.11254 .01985 L
.11306 .01985 L
.11306 .16187 L
s
1 .894 .882 r
.11306 .16187 m
.11306 .01993 L
.11395 .01993 L
.11395 .16187 L
F
.804 .522 .247 r
.11306 .16187 m
.11306 .01993 L
.11395 .01993 L
.11395 .16187 L
s
1 .894 .882 r
.11395 .16187 m
.11395 .02004 L
.11455 .02004 L
.11455 .16187 L
F
.804 .522 .247 r
.11395 .16187 m
.11395 .02004 L
.11455 .02004 L
.11455 .16187 L
s
1 .894 .882 r
.11455 .16187 m
.11455 .02011 L
.11501 .02011 L
.11501 .16187 L
F
.804 .522 .247 r
.11455 .16187 m
.11455 .02011 L
.11501 .02011 L
.11501 .16187 L
s
1 .894 .882 r
.11501 .16187 m
.11501 .02021 L
.11589 .02021 L
.11589 .16187 L
F
.804 .522 .247 r
.11501 .16187 m
.11501 .02021 L
.11589 .02021 L
.11589 .16187 L
s
1 .894 .882 r
.11589 .16187 m
.11589 .02025 L
.11669 .02025 L
.11669 .16187 L
F
.804 .522 .247 r
.11589 .16187 m
.11589 .02025 L
.11669 .02025 L
.11669 .16187 L
s
1 .894 .882 r
.11669 .16187 m
.11669 .02038 L
.11771 .02038 L
.11771 .16187 L
F
.804 .522 .247 r
.11669 .16187 m
.11669 .02038 L
.11771 .02038 L
.11771 .16187 L
s
1 .894 .882 r
.11771 .16187 m
.11771 .02047 L
.11804 .02047 L
.11804 .16187 L
F
.804 .522 .247 r
.11771 .16187 m
.11771 .02047 L
.11804 .02047 L
.11804 .16187 L
s
1 .894 .882 r
.11804 .16187 m
.11804 .02049 L
.1184 .02049 L
.1184 .16187 L
F
.804 .522 .247 r
.11804 .16187 m
.11804 .02049 L
.1184 .02049 L
.1184 .16187 L
s
1 .894 .882 r
.1184 .16187 m
.1184 .02062 L
.11943 .02062 L
.11943 .16187 L
F
.804 .522 .247 r
.1184 .16187 m
.1184 .02062 L
.11943 .02062 L
.11943 .16187 L
s
1 .894 .882 r
.11943 .16187 m
.11943 .02068 L
.12036 .02068 L
.12036 .16187 L
F
.804 .522 .247 r
.11943 .16187 m
.11943 .02068 L
.12036 .02068 L
.12036 .16187 L
s
1 .894 .882 r
.12036 .16187 m
.12036 .02085 L
.12112 .02085 L
.12112 .16187 L
F
.804 .522 .247 r
.12036 .16187 m
.12036 .02085 L
.12112 .02085 L
.12112 .16187 L
s
1 .894 .882 r
.12112 .16187 m
.12112 .0209 L
.12177 .0209 L
.12177 .16187 L
F
.804 .522 .247 r
.12112 .16187 m
.12112 .0209 L
.12177 .0209 L
.12177 .16187 L
s
1 .894 .882 r
.12177 .16187 m
.12177 .02095 L
.12213 .02095 L
.12213 .16187 L
F
.804 .522 .247 r
.12177 .16187 m
.12177 .02095 L
.12213 .02095 L
.12213 .16187 L
s
1 .894 .882 r
.12213 .16187 m
.12213 .02102 L
.12277 .02102 L
.12277 .16187 L
F
.804 .522 .247 r
.12213 .16187 m
.12213 .02102 L
.12277 .02102 L
.12277 .16187 L
s
1 .894 .882 r
.12277 .16187 m
.12277 .0211 L
.12337 .0211 L
.12337 .16187 L
F
.804 .522 .247 r
.12277 .16187 m
.12277 .0211 L
.12337 .0211 L
.12337 .16187 L
s
1 .894 .882 r
.12337 .16187 m
.12337 .02121 L
.12406 .02121 L
.12406 .16187 L
F
.804 .522 .247 r
.12337 .16187 m
.12337 .02121 L
.12406 .02121 L
.12406 .16187 L
s
1 .894 .882 r
.12406 .16187 m
.12406 .02126 L
.12449 .02126 L
.12449 .16187 L
F
.804 .522 .247 r
.12406 .16187 m
.12406 .02126 L
.12449 .02126 L
.12449 .16187 L
s
1 .894 .882 r
.12449 .16187 m
.12449 .02136 L
.12514 .02136 L
.12514 .16187 L
F
.804 .522 .247 r
.12449 .16187 m
.12449 .02136 L
.12514 .02136 L
.12514 .16187 L
s
1 .894 .882 r
.12514 .16187 m
.12514 .0214 L
.12598 .0214 L
.12598 .16187 L
F
.804 .522 .247 r
.12514 .16187 m
.12514 .0214 L
.12598 .0214 L
.12598 .16187 L
s
1 .894 .882 r
.12598 .16187 m
.12598 .02156 L
.12661 .02156 L
.12661 .16187 L
F
.804 .522 .247 r
.12598 .16187 m
.12598 .02156 L
.12661 .02156 L
.12661 .16187 L
s
1 .894 .882 r
.12661 .16187 m
.12661 .02161 L
.1274 .02161 L
.1274 .16187 L
F
.804 .522 .247 r
.12661 .16187 m
.12661 .02161 L
.1274 .02161 L
.1274 .16187 L
s
1 .894 .882 r
.1274 .16187 m
.1274 .02171 L
.12832 .02171 L
.12832 .16187 L
F
.804 .522 .247 r
.1274 .16187 m
.1274 .02171 L
.12832 .02171 L
.12832 .16187 L
s
1 .894 .882 r
.12832 .16187 m
.12832 .02185 L
.12891 .02185 L
.12891 .16187 L
F
.804 .522 .247 r
.12832 .16187 m
.12832 .02185 L
.12891 .02185 L
.12891 .16187 L
s
1 .894 .882 r
.12891 .16187 m
.12891 .0219 L
.12934 .0219 L
.12934 .16187 L
F
.804 .522 .247 r
.12891 .16187 m
.12891 .0219 L
.12934 .0219 L
.12934 .16187 L
s
1 .894 .882 r
.12934 .16187 m
.12934 .02206 L
.13027 .02206 L
.13027 .16187 L
F
.804 .522 .247 r
.12934 .16187 m
.12934 .02206 L
.13027 .02206 L
.13027 .16187 L
s
1 .894 .882 r
.13027 .16187 m
.13027 .02212 L
.13091 .02212 L
.13091 .16187 L
F
.804 .522 .247 r
.13027 .16187 m
.13027 .02212 L
.13091 .02212 L
.13091 .16187 L
s
1 .894 .882 r
.13091 .16187 m
.13091 .0222 L
.13135 .0222 L
.13135 .16187 L
F
.804 .522 .247 r
.13091 .16187 m
.13091 .0222 L
.13135 .0222 L
.13135 .16187 L
s
1 .894 .882 r
.13135 .16187 m
.13135 .02225 L
.13194 .02225 L
.13194 .16187 L
F
.804 .522 .247 r
.13135 .16187 m
.13135 .02225 L
.13194 .02225 L
.13194 .16187 L
s
1 .894 .882 r
.13194 .16187 m
.13194 .02234 L
.13238 .02234 L
.13238 .16187 L
F
.804 .522 .247 r
.13194 .16187 m
.13194 .02234 L
.13238 .02234 L
.13238 .16187 L
s
1 .894 .882 r
.13238 .16187 m
.13238 .02245 L
.13303 .02245 L
.13303 .16187 L
F
.804 .522 .247 r
.13238 .16187 m
.13238 .02245 L
.13303 .02245 L
.13303 .16187 L
s
1 .894 .882 r
.13303 .16187 m
.13303 .0225 L
.13346 .0225 L
.13346 .16187 L
F
.804 .522 .247 r
.13303 .16187 m
.13303 .0225 L
.13346 .0225 L
.13346 .16187 L
s
1 .894 .882 r
.13346 .16187 m
.13346 .02253 L
.13399 .02253 L
.13399 .16187 L
F
.804 .522 .247 r
.13346 .16187 m
.13346 .02253 L
.13399 .02253 L
.13399 .16187 L
s
1 .894 .882 r
.13399 .16187 m
.13399 .02265 L
.13443 .02265 L
.13443 .16187 L
F
.804 .522 .247 r
.13399 .16187 m
.13399 .02265 L
.13443 .02265 L
.13443 .16187 L
s
1 .894 .882 r
.13443 .16187 m
.13443 .02273 L
.1352 .02273 L
.1352 .16187 L
F
.804 .522 .247 r
.13443 .16187 m
.13443 .02273 L
.1352 .02273 L
.1352 .16187 L
s
1 .894 .882 r
.1352 .16187 m
.1352 .02285 L
.1359 .02285 L
.1359 .16187 L
F
.804 .522 .247 r
.1352 .16187 m
.1352 .02285 L
.1359 .02285 L
.1359 .16187 L
s
1 .894 .882 r
.1359 .16187 m
.1359 .02295 L
.13681 .02295 L
.13681 .16187 L
F
.804 .522 .247 r
.1359 .16187 m
.1359 .02295 L
.13681 .02295 L
.13681 .16187 L
s
1 .894 .882 r
.13681 .16187 m
.13681 .02305 L
.1372 .02305 L
.1372 .16187 L
F
.804 .522 .247 r
.13681 .16187 m
.13681 .02305 L
.1372 .02305 L
.1372 .16187 L
s
1 .894 .882 r
.1372 .16187 m
.1372 .02308 L
.13764 .02308 L
.13764 .16187 L
F
.804 .522 .247 r
.1372 .16187 m
.1372 .02308 L
.13764 .02308 L
.13764 .16187 L
s
1 .894 .882 r
.13764 .16187 m
.13764 .02315 L
.13805 .02315 L
.13805 .16187 L
F
.804 .522 .247 r
.13764 .16187 m
.13764 .02315 L
.13805 .02315 L
.13805 .16187 L
s
1 .894 .882 r
.13805 .16187 m
.13805 .02325 L
.13859 .02325 L
.13859 .16187 L
F
.804 .522 .247 r
.13805 .16187 m
.13805 .02325 L
.13859 .02325 L
.13859 .16187 L
s
1 .894 .882 r
.13859 .16187 m
.13859 .02333 L
.13958 .02333 L
.13958 .16187 L
F
.804 .522 .247 r
.13859 .16187 m
.13859 .02333 L
.13958 .02333 L
.13958 .16187 L
s
1 .894 .882 r
.13958 .16187 m
.13958 .02347 L
.14041 .02347 L
.14041 .16187 L
F
.804 .522 .247 r
.13958 .16187 m
.13958 .02347 L
.14041 .02347 L
.14041 .16187 L
s
1 .894 .882 r
.14041 .16187 m
.14041 .02356 L
.14102 .02356 L
.14102 .16187 L
F
.804 .522 .247 r
.14041 .16187 m
.14041 .02356 L
.14102 .02356 L
.14102 .16187 L
s
1 .894 .882 r
.14102 .16187 m
.14102 .02364 L
.14196 .02364 L
.14196 .16187 L
F
.804 .522 .247 r
.14102 .16187 m
.14102 .02364 L
.14196 .02364 L
.14196 .16187 L
s
1 .894 .882 r
.14196 .16187 m
.14196 .02378 L
.14247 .02378 L
.14247 .16187 L
F
.804 .522 .247 r
.14196 .16187 m
.14196 .02378 L
.14247 .02378 L
.14247 .16187 L
s
1 .894 .882 r
.14247 .16187 m
.14247 .02388 L
.14341 .02388 L
.14341 .16187 L
F
.804 .522 .247 r
.14247 .16187 m
.14247 .02388 L
.14341 .02388 L
.14341 .16187 L
s
1 .894 .882 r
.14341 .16187 m
.14341 .02403 L
.14373 .02403 L
.14373 .16187 L
F
.804 .522 .247 r
.14341 .16187 m
.14341 .02403 L
.14373 .02403 L
.14373 .16187 L
s
1 .894 .882 r
.14373 .16187 m
.14373 .02414 L
.14456 .02414 L
.14456 .16187 L
F
.804 .522 .247 r
.14373 .16187 m
.14373 .02414 L
.14456 .02414 L
.14456 .16187 L
s
1 .894 .882 r
.14456 .16187 m
.14456 .02419 L
.14518 .02419 L
.14518 .16187 L
F
.804 .522 .247 r
.14456 .16187 m
.14456 .02419 L
.14518 .02419 L
.14518 .16187 L
s
1 .894 .882 r
.14518 .16187 m
.14518 .02434 L
.14579 .02434 L
.14579 .16187 L
F
.804 .522 .247 r
.14518 .16187 m
.14518 .02434 L
.14579 .02434 L
.14579 .16187 L
s
1 .894 .882 r
.14579 .16187 m
.14579 .02451 L
.14671 .02451 L
.14671 .16187 L
F
.804 .522 .247 r
.14579 .16187 m
.14579 .02451 L
.14671 .02451 L
.14671 .16187 L
s
1 .894 .882 r
.14671 .16187 m
.14671 .02454 L
.14726 .02454 L
.14726 .16187 L
F
.804 .522 .247 r
.14671 .16187 m
.14671 .02454 L
.14726 .02454 L
.14726 .16187 L
s
1 .894 .882 r
.14726 .16187 m
.14726 .02464 L
.14775 .02464 L
.14775 .16187 L
F
.804 .522 .247 r
.14726 .16187 m
.14726 .02464 L
.14775 .02464 L
.14775 .16187 L
s
1 .894 .882 r
.14775 .16187 m
.14775 .0248 L
.14874 .0248 L
.14874 .16187 L
F
.804 .522 .247 r
.14775 .16187 m
.14775 .0248 L
.14874 .0248 L
.14874 .16187 L
s
1 .894 .882 r
.14874 .16187 m
.14874 .02488 L
.14954 .02488 L
.14954 .16187 L
F
.804 .522 .247 r
.14874 .16187 m
.14874 .02488 L
.14954 .02488 L
.14954 .16187 L
s
1 .894 .882 r
.14954 .16187 m
.14954 .02498 L
.14987 .02498 L
.14987 .16187 L
F
.804 .522 .247 r
.14954 .16187 m
.14954 .02498 L
.14987 .02498 L
.14987 .16187 L
s
1 .894 .882 r
.14987 .16187 m
.14987 .02506 L
.15024 .02506 L
.15024 .16187 L
F
.804 .522 .247 r
.14987 .16187 m
.14987 .02506 L
.15024 .02506 L
.15024 .16187 L
s
1 .894 .882 r
.15024 .16187 m
.15024 .02509 L
.15076 .02509 L
.15076 .16187 L
F
.804 .522 .247 r
.15024 .16187 m
.15024 .02509 L
.15076 .02509 L
.15076 .16187 L
s
1 .894 .882 r
.15076 .16187 m
.15076 .0252 L
.15118 .0252 L
.15118 .16187 L
F
.804 .522 .247 r
.15076 .16187 m
.15076 .0252 L
.15118 .0252 L
.15118 .16187 L
s
1 .894 .882 r
.15118 .16187 m
.15118 .02529 L
.15163 .02529 L
.15163 .16187 L
F
.804 .522 .247 r
.15118 .16187 m
.15118 .02529 L
.15163 .02529 L
.15163 .16187 L
s
1 .894 .882 r
.15163 .16187 m
.15163 .02545 L
.15264 .02545 L
.15264 .16187 L
F
.804 .522 .247 r
.15163 .16187 m
.15163 .02545 L
.15264 .02545 L
.15264 .16187 L
s
1 .894 .882 r
.15264 .16187 m
.15264 .02554 L
.15304 .02554 L
.15304 .16187 L
F
.804 .522 .247 r
.15264 .16187 m
.15264 .02554 L
.15304 .02554 L
.15304 .16187 L
s
1 .894 .882 r
.15304 .16187 m
.15304 .02561 L
.15336 .02561 L
.15336 .16187 L
F
.804 .522 .247 r
.15304 .16187 m
.15304 .02561 L
.15336 .02561 L
.15336 .16187 L
s
1 .894 .882 r
.15336 .16187 m
.15336 .02572 L
.1543 .02572 L
.1543 .16187 L
F
.804 .522 .247 r
.15336 .16187 m
.15336 .02572 L
.1543 .02572 L
.1543 .16187 L
s
1 .894 .882 r
.1543 .16187 m
.1543 .02578 L
.15463 .02578 L
.15463 .16187 L
F
.804 .522 .247 r
.1543 .16187 m
.1543 .02578 L
.15463 .02578 L
.15463 .16187 L
s
1 .894 .882 r
.15463 .16187 m
.15463 .02585 L
.15524 .02585 L
.15524 .16187 L
F
.804 .522 .247 r
.15463 .16187 m
.15463 .02585 L
.15524 .02585 L
.15524 .16187 L
s
1 .894 .882 r
.15524 .16187 m
.15524 .02602 L
.15599 .02602 L
.15599 .16187 L
F
.804 .522 .247 r
.15524 .16187 m
.15524 .02602 L
.15599 .02602 L
.15599 .16187 L
s
1 .894 .882 r
.15599 .16187 m
.15599 .02618 L
.15702 .02618 L
.15702 .16187 L
F
.804 .522 .247 r
.15599 .16187 m
.15599 .02618 L
.15702 .02618 L
.15702 .16187 L
s
1 .894 .882 r
.15702 .16187 m
.15702 .02628 L
.15788 .02628 L
.15788 .16187 L
F
.804 .522 .247 r
.15702 .16187 m
.15702 .02628 L
.15788 .02628 L
.15788 .16187 L
s
1 .894 .882 r
.15788 .16187 m
.15788 .02639 L
.15859 .02639 L
.15859 .16187 L
F
.804 .522 .247 r
.15788 .16187 m
.15788 .02639 L
.15859 .02639 L
.15859 .16187 L
s
1 .894 .882 r
.15859 .16187 m
.15859 .02651 L
.15932 .02651 L
.15932 .16187 L
F
.804 .522 .247 r
.15859 .16187 m
.15859 .02651 L
.15932 .02651 L
.15932 .16187 L
s
1 .894 .882 r
.15932 .16187 m
.15932 .02663 L
.15983 .02663 L
.15983 .16187 L
F
.804 .522 .247 r
.15932 .16187 m
.15932 .02663 L
.15983 .02663 L
.15983 .16187 L
s
1 .894 .882 r
.15983 .16187 m
.15983 .02674 L
.16037 .02674 L
.16037 .16187 L
F
.804 .522 .247 r
.15983 .16187 m
.15983 .02674 L
.16037 .02674 L
.16037 .16187 L
s
1 .894 .882 r
.16037 .16187 m
.16037 .02685 L
.16079 .02685 L
.16079 .16187 L
F
.804 .522 .247 r
.16037 .16187 m
.16037 .02685 L
.16079 .02685 L
.16079 .16187 L
s
1 .894 .882 r
.16079 .16187 m
.16079 .02691 L
.16164 .02691 L
.16164 .16187 L
F
.804 .522 .247 r
.16079 .16187 m
.16079 .02691 L
.16164 .02691 L
.16164 .16187 L
s
1 .894 .882 r
.16164 .16187 m
.16164 .02717 L
.16264 .02717 L
.16264 .16187 L
F
.804 .522 .247 r
.16164 .16187 m
.16164 .02717 L
.16264 .02717 L
.16264 .16187 L
s
1 .894 .882 r
.16264 .16187 m
.16264 .02727 L
.163 .02727 L
.163 .16187 L
F
.804 .522 .247 r
.16264 .16187 m
.16264 .02727 L
.163 .02727 L
.163 .16187 L
s
1 .894 .882 r
.163 .16187 m
.163 .02734 L
.16346 .02734 L
.16346 .16187 L
F
.804 .522 .247 r
.163 .16187 m
.163 .02734 L
.16346 .02734 L
.16346 .16187 L
s
1 .894 .882 r
.16346 .16187 m
.16346 .02742 L
.16382 .02742 L
.16382 .16187 L
F
.804 .522 .247 r
.16346 .16187 m
.16346 .02742 L
.16382 .02742 L
.16382 .16187 L
s
1 .894 .882 r
.16382 .16187 m
.16382 .02753 L
.1648 .02753 L
.1648 .16187 L
F
.804 .522 .247 r
.16382 .16187 m
.16382 .02753 L
.1648 .02753 L
.1648 .16187 L
s
1 .894 .882 r
.1648 .16187 m
.1648 .02764 L
.16582 .02764 L
.16582 .16187 L
F
.804 .522 .247 r
.1648 .16187 m
.1648 .02764 L
.16582 .02764 L
.16582 .16187 L
s
1 .894 .882 r
.16582 .16187 m
.16582 .02792 L
.1668 .02792 L
.1668 .16187 L
F
.804 .522 .247 r
.16582 .16187 m
.16582 .02792 L
.1668 .02792 L
.1668 .16187 L
s
1 .894 .882 r
.1668 .16187 m
.1668 .02805 L
.16777 .02805 L
.16777 .16187 L
F
.804 .522 .247 r
.1668 .16187 m
.1668 .02805 L
.16777 .02805 L
.16777 .16187 L
s
1 .894 .882 r
.16777 .16187 m
.16777 .02831 L
.16861 .02831 L
.16861 .16187 L
F
.804 .522 .247 r
.16777 .16187 m
.16777 .02831 L
.16861 .02831 L
.16861 .16187 L
s
1 .894 .882 r
.16861 .16187 m
.16861 .02834 L
.16894 .02834 L
.16894 .16187 L
F
.804 .522 .247 r
.16861 .16187 m
.16861 .02834 L
.16894 .02834 L
.16894 .16187 L
s
1 .894 .882 r
.16894 .16187 m
.16894 .02854 L
.16983 .02854 L
.16983 .16187 L
F
.804 .522 .247 r
.16894 .16187 m
.16894 .02854 L
.16983 .02854 L
.16983 .16187 L
s
1 .894 .882 r
.16983 .16187 m
.16983 .02863 L
.17079 .02863 L
.17079 .16187 L
F
.804 .522 .247 r
.16983 .16187 m
.16983 .02863 L
.17079 .02863 L
.17079 .16187 L
s
1 .894 .882 r
.17079 .16187 m
.17079 .02876 L
.17173 .02876 L
.17173 .16187 L
F
.804 .522 .247 r
.17079 .16187 m
.17079 .02876 L
.17173 .02876 L
.17173 .16187 L
s
1 .894 .882 r
.17173 .16187 m
.17173 .02892 L
.17276 .02892 L
.17276 .16187 L
F
.804 .522 .247 r
.17173 .16187 m
.17173 .02892 L
.17276 .02892 L
.17276 .16187 L
s
1 .894 .882 r
.17276 .16187 m
.17276 .02918 L
.17335 .02918 L
.17335 .16187 L
F
.804 .522 .247 r
.17276 .16187 m
.17276 .02918 L
.17335 .02918 L
.17335 .16187 L
s
1 .894 .882 r
.17335 .16187 m
.17335 .0293 L
.17386 .0293 L
.17386 .16187 L
F
.804 .522 .247 r
.17335 .16187 m
.17335 .0293 L
.17386 .0293 L
.17386 .16187 L
s
1 .894 .882 r
.17386 .16187 m
.17386 .02941 L
.17481 .02941 L
.17481 .16187 L
F
.804 .522 .247 r
.17386 .16187 m
.17386 .02941 L
.17481 .02941 L
.17481 .16187 L
s
1 .894 .882 r
.17481 .16187 m
.17481 .02958 L
.1753 .02958 L
.1753 .16187 L
F
.804 .522 .247 r
.17481 .16187 m
.17481 .02958 L
.1753 .02958 L
.1753 .16187 L
s
1 .894 .882 r
.1753 .16187 m
.1753 .0297 L
.17622 .0297 L
.17622 .16187 L
F
.804 .522 .247 r
.1753 .16187 m
.1753 .0297 L
.17622 .0297 L
.17622 .16187 L
s
1 .894 .882 r
.17622 .16187 m
.17622 .02988 L
.17703 .02988 L
.17703 .16187 L
F
.804 .522 .247 r
.17622 .16187 m
.17622 .02988 L
.17703 .02988 L
.17703 .16187 L
s
1 .894 .882 r
.17703 .16187 m
.17703 .03002 L
.17778 .03002 L
.17778 .16187 L
F
.804 .522 .247 r
.17703 .16187 m
.17703 .03002 L
.17778 .03002 L
.17778 .16187 L
s
1 .894 .882 r
.17778 .16187 m
.17778 .0302 L
.17876 .0302 L
.17876 .16187 L
F
.804 .522 .247 r
.17778 .16187 m
.17778 .0302 L
.17876 .0302 L
.17876 .16187 L
s
1 .894 .882 r
.17876 .16187 m
.17876 .03032 L
.17957 .03032 L
.17957 .16187 L
F
.804 .522 .247 r
.17876 .16187 m
.17876 .03032 L
.17957 .03032 L
.17957 .16187 L
s
1 .894 .882 r
.17957 .16187 m
.17957 .03056 L
.18057 .03056 L
.18057 .16187 L
F
.804 .522 .247 r
.17957 .16187 m
.17957 .03056 L
.18057 .03056 L
.18057 .16187 L
s
1 .894 .882 r
.18057 .16187 m
.18057 .03079 L
.18136 .03079 L
.18136 .16187 L
F
.804 .522 .247 r
.18057 .16187 m
.18057 .03079 L
.18136 .03079 L
.18136 .16187 L
s
1 .894 .882 r
.18136 .16187 m
.18136 .03097 L
.18229 .03097 L
.18229 .16187 L
F
.804 .522 .247 r
.18136 .16187 m
.18136 .03097 L
.18229 .03097 L
.18229 .16187 L
s
1 .894 .882 r
.18229 .16187 m
.18229 .03107 L
.18294 .03107 L
.18294 .16187 L
F
.804 .522 .247 r
.18229 .16187 m
.18229 .03107 L
.18294 .03107 L
.18294 .16187 L
s
1 .894 .882 r
.18294 .16187 m
.18294 .03128 L
.1839 .03128 L
.1839 .16187 L
F
.804 .522 .247 r
.18294 .16187 m
.18294 .03128 L
.1839 .03128 L
.1839 .16187 L
s
1 .894 .882 r
.1839 .16187 m
.1839 .0314 L
.18474 .0314 L
.18474 .16187 L
F
.804 .522 .247 r
.1839 .16187 m
.1839 .0314 L
.18474 .0314 L
.18474 .16187 L
s
1 .894 .882 r
.18474 .16187 m
.18474 .03165 L
.18568 .03165 L
.18568 .16187 L
F
.804 .522 .247 r
.18474 .16187 m
.18474 .03165 L
.18568 .03165 L
.18568 .16187 L
s
1 .894 .882 r
.18568 .16187 m
.18568 .03183 L
.18639 .03183 L
.18639 .16187 L
F
.804 .522 .247 r
.18568 .16187 m
.18568 .03183 L
.18639 .03183 L
.18639 .16187 L
s
1 .894 .882 r
.18639 .16187 m
.18639 .03193 L
.18742 .03193 L
.18742 .16187 L
F
.804 .522 .247 r
.18639 .16187 m
.18639 .03193 L
.18742 .03193 L
.18742 .16187 L
s
1 .894 .882 r
.18742 .16187 m
.18742 .03216 L
.18845 .03216 L
.18845 .16187 L
F
.804 .522 .247 r
.18742 .16187 m
.18742 .03216 L
.18845 .03216 L
.18845 .16187 L
s
1 .894 .882 r
.18845 .16187 m
.18845 .03236 L
.18937 .03236 L
.18937 .16187 L
F
.804 .522 .247 r
.18845 .16187 m
.18845 .03236 L
.18937 .03236 L
.18937 .16187 L
s
1 .894 .882 r
.18937 .16187 m
.18937 .03266 L
.19023 .03266 L
.19023 .16187 L
F
.804 .522 .247 r
.18937 .16187 m
.18937 .03266 L
.19023 .03266 L
.19023 .16187 L
s
1 .894 .882 r
.19023 .16187 m
.19023 .03276 L
.19062 .03276 L
.19062 .16187 L
F
.804 .522 .247 r
.19023 .16187 m
.19023 .03276 L
.19062 .03276 L
.19062 .16187 L
s
1 .894 .882 r
.19062 .16187 m
.19062 .03279 L
.19101 .03279 L
.19101 .16187 L
F
.804 .522 .247 r
.19062 .16187 m
.19062 .03279 L
.19101 .03279 L
.19101 .16187 L
s
1 .894 .882 r
.19101 .16187 m
.19101 .03291 L
.19194 .03291 L
.19194 .16187 L
F
.804 .522 .247 r
.19101 .16187 m
.19101 .03291 L
.19194 .03291 L
.19194 .16187 L
s
1 .894 .882 r
.19194 .16187 m
.19194 .03309 L
.19251 .03309 L
.19251 .16187 L
F
.804 .522 .247 r
.19194 .16187 m
.19194 .03309 L
.19251 .03309 L
.19251 .16187 L
s
1 .894 .882 r
.19251 .16187 m
.19251 .03322 L
.19342 .03322 L
.19342 .16187 L
F
.804 .522 .247 r
.19251 .16187 m
.19251 .03322 L
.19342 .03322 L
.19342 .16187 L
s
1 .894 .882 r
.19342 .16187 m
.19342 .03346 L
.19391 .03346 L
.19391 .16187 L
F
.804 .522 .247 r
.19342 .16187 m
.19342 .03346 L
.19391 .03346 L
.19391 .16187 L
s
1 .894 .882 r
.19391 .16187 m
.19391 .03358 L
.19466 .03358 L
.19466 .16187 L
F
.804 .522 .247 r
.19391 .16187 m
.19391 .03358 L
.19466 .03358 L
.19466 .16187 L
s
1 .894 .882 r
.19466 .16187 m
.19466 .03377 L
.19534 .03377 L
.19534 .16187 L
F
.804 .522 .247 r
.19466 .16187 m
.19466 .03377 L
.19534 .03377 L
.19534 .16187 L
s
1 .894 .882 r
.19534 .16187 m
.19534 .03386 L
.19575 .03386 L
.19575 .16187 L
F
.804 .522 .247 r
.19534 .16187 m
.19534 .03386 L
.19575 .03386 L
.19575 .16187 L
s
1 .894 .882 r
.19575 .16187 m
.19575 .03394 L
.19652 .03394 L
.19652 .16187 L
F
.804 .522 .247 r
.19575 .16187 m
.19575 .03394 L
.19652 .03394 L
.19652 .16187 L
s
1 .894 .882 r
.19652 .16187 m
.19652 .03408 L
.19734 .03408 L
.19734 .16187 L
F
.804 .522 .247 r
.19652 .16187 m
.19652 .03408 L
.19734 .03408 L
.19734 .16187 L
s
1 .894 .882 r
.19734 .16187 m
.19734 .03438 L
.19824 .03438 L
.19824 .16187 L
F
.804 .522 .247 r
.19734 .16187 m
.19734 .03438 L
.19824 .03438 L
.19824 .16187 L
s
1 .894 .882 r
.19824 .16187 m
.19824 .03447 L
.19868 .03447 L
.19868 .16187 L
F
.804 .522 .247 r
.19824 .16187 m
.19824 .03447 L
.19868 .03447 L
.19868 .16187 L
s
1 .894 .882 r
.19868 .16187 m
.19868 .03467 L
.19971 .03467 L
.19971 .16187 L
F
.804 .522 .247 r
.19868 .16187 m
.19868 .03467 L
.19971 .03467 L
.19971 .16187 L
s
1 .894 .882 r
.19971 .16187 m
.19971 .03486 L
.20063 .03486 L
.20063 .16187 L
F
.804 .522 .247 r
.19971 .16187 m
.19971 .03486 L
.20063 .03486 L
.20063 .16187 L
s
1 .894 .882 r
.20063 .16187 m
.20063 .03502 L
.20119 .03502 L
.20119 .16187 L
F
.804 .522 .247 r
.20063 .16187 m
.20063 .03502 L
.20119 .03502 L
.20119 .16187 L
s
1 .894 .882 r
.20119 .16187 m
.20119 .03518 L
.2017 .03518 L
.2017 .16187 L
F
.804 .522 .247 r
.20119 .16187 m
.20119 .03518 L
.2017 .03518 L
.2017 .16187 L
s
1 .894 .882 r
.2017 .16187 m
.2017 .03527 L
.2022 .03527 L
.2022 .16187 L
F
.804 .522 .247 r
.2017 .16187 m
.2017 .03527 L
.2022 .03527 L
.2022 .16187 L
s
1 .894 .882 r
.2022 .16187 m
.2022 .03552 L
.20322 .03552 L
.20322 .16187 L
F
.804 .522 .247 r
.2022 .16187 m
.2022 .03552 L
.20322 .03552 L
.20322 .16187 L
s
1 .894 .882 r
.20322 .16187 m
.20322 .03568 L
.2041 .03568 L
.2041 .16187 L
F
.804 .522 .247 r
.20322 .16187 m
.20322 .03568 L
.2041 .03568 L
.2041 .16187 L
s
1 .894 .882 r
.2041 .16187 m
.2041 .03583 L
.20462 .03583 L
.20462 .16187 L
F
.804 .522 .247 r
.2041 .16187 m
.2041 .03583 L
.20462 .03583 L
.20462 .16187 L
s
1 .894 .882 r
.20462 .16187 m
.20462 .03603 L
.20512 .03603 L
.20512 .16187 L
F
.804 .522 .247 r
.20462 .16187 m
.20462 .03603 L
.20512 .03603 L
.20512 .16187 L
s
1 .894 .882 r
.20512 .16187 m
.20512 .03609 L
.20553 .03609 L
.20553 .16187 L
F
.804 .522 .247 r
.20512 .16187 m
.20512 .03609 L
.20553 .03609 L
.20553 .16187 L
s
1 .894 .882 r
.20553 .16187 m
.20553 .03618 L
.20586 .03618 L
.20586 .16187 L
F
.804 .522 .247 r
.20553 .16187 m
.20553 .03618 L
.20586 .03618 L
.20586 .16187 L
s
1 .894 .882 r
.20586 .16187 m
.20586 .03626 L
.20631 .03626 L
.20631 .16187 L
F
.804 .522 .247 r
.20586 .16187 m
.20586 .03626 L
.20631 .03626 L
.20631 .16187 L
s
1 .894 .882 r
.20631 .16187 m
.20631 .03639 L
.20672 .03639 L
.20672 .16187 L
F
.804 .522 .247 r
.20631 .16187 m
.20631 .03639 L
.20672 .03639 L
.20672 .16187 L
s
1 .894 .882 r
.20672 .16187 m
.20672 .03644 L
.20724 .03644 L
.20724 .16187 L
F
.804 .522 .247 r
.20672 .16187 m
.20672 .03644 L
.20724 .03644 L
.20724 .16187 L
s
1 .894 .882 r
.20724 .16187 m
.20724 .0366 L
.20804 .0366 L
.20804 .16187 L
F
.804 .522 .247 r
.20724 .16187 m
.20724 .0366 L
.20804 .0366 L
.20804 .16187 L
s
1 .894 .882 r
.20804 .16187 m
.20804 .03676 L
.20861 .03676 L
.20861 .16187 L
F
.804 .522 .247 r
.20804 .16187 m
.20804 .03676 L
.20861 .03676 L
.20861 .16187 L
s
1 .894 .882 r
.20861 .16187 m
.20861 .03709 L
.20957 .03709 L
.20957 .16187 L
F
.804 .522 .247 r
.20861 .16187 m
.20861 .03709 L
.20957 .03709 L
.20957 .16187 L
s
1 .894 .882 r
.20957 .16187 m
.20957 .03722 L
.21037 .03722 L
.21037 .16187 L
F
.804 .522 .247 r
.20957 .16187 m
.20957 .03722 L
.21037 .03722 L
.21037 .16187 L
s
1 .894 .882 r
.21037 .16187 m
.21037 .03736 L
.2108 .03736 L
.2108 .16187 L
F
.804 .522 .247 r
.21037 .16187 m
.21037 .03736 L
.2108 .03736 L
.2108 .16187 L
s
1 .894 .882 r
.2108 .16187 m
.2108 .03747 L
.21127 .03747 L
.21127 .16187 L
F
.804 .522 .247 r
.2108 .16187 m
.2108 .03747 L
.21127 .03747 L
.21127 .16187 L
s
1 .894 .882 r
.21127 .16187 m
.21127 .0376 L
.21177 .0376 L
.21177 .16187 L
F
.804 .522 .247 r
.21127 .16187 m
.21127 .0376 L
.21177 .0376 L
.21177 .16187 L
s
1 .894 .882 r
.21177 .16187 m
.21177 .03777 L
.21279 .03777 L
.21279 .16187 L
F
.804 .522 .247 r
.21177 .16187 m
.21177 .03777 L
.21279 .03777 L
.21279 .16187 L
s
1 .894 .882 r
.21279 .16187 m
.21279 .03802 L
.21335 .03802 L
.21335 .16187 L
F
.804 .522 .247 r
.21279 .16187 m
.21279 .03802 L
.21335 .03802 L
.21335 .16187 L
s
1 .894 .882 r
.21335 .16187 m
.21335 .03807 L
.21369 .03807 L
.21369 .16187 L
F
.804 .522 .247 r
.21335 .16187 m
.21335 .03807 L
.21369 .03807 L
.21369 .16187 L
s
1 .894 .882 r
.21369 .16187 m
.21369 .03814 L
.21421 .03814 L
.21421 .16187 L
F
.804 .522 .247 r
.21369 .16187 m
.21369 .03814 L
.21421 .03814 L
.21421 .16187 L
s
1 .894 .882 r
.21421 .16187 m
.21421 .03826 L
.21461 .03826 L
.21461 .16187 L
F
.804 .522 .247 r
.21421 .16187 m
.21421 .03826 L
.21461 .03826 L
.21461 .16187 L
s
1 .894 .882 r
.21461 .16187 m
.21461 .0384 L
.21493 .0384 L
.21493 .16187 L
F
.804 .522 .247 r
.21461 .16187 m
.21461 .0384 L
.21493 .0384 L
.21493 .16187 L
s
1 .894 .882 r
.21493 .16187 m
.21493 .03843 L
.21579 .03843 L
.21579 .16187 L
F
.804 .522 .247 r
.21493 .16187 m
.21493 .03843 L
.21579 .03843 L
.21579 .16187 L
s
1 .894 .882 r
.21579 .16187 m
.21579 .03864 L
.21612 .03864 L
.21612 .16187 L
F
.804 .522 .247 r
.21579 .16187 m
.21579 .03864 L
.21612 .03864 L
.21612 .16187 L
s
1 .894 .882 r
.21612 .16187 m
.21612 .03877 L
.21654 .03877 L
.21654 .16187 L
F
.804 .522 .247 r
.21612 .16187 m
.21612 .03877 L
.21654 .03877 L
.21654 .16187 L
s
1 .894 .882 r
.21654 .16187 m
.21654 .03887 L
.21701 .03887 L
.21701 .16187 L
F
.804 .522 .247 r
.21654 .16187 m
.21654 .03887 L
.21701 .03887 L
.21701 .16187 L
s
1 .894 .882 r
.21701 .16187 m
.21701 .03909 L
.21766 .03909 L
.21766 .16187 L
F
.804 .522 .247 r
.21701 .16187 m
.21701 .03909 L
.21766 .03909 L
.21766 .16187 L
s
1 .894 .882 r
.21766 .16187 m
.21766 .03915 L
.21853 .03915 L
.21853 .16187 L
F
.804 .522 .247 r
.21766 .16187 m
.21766 .03915 L
.21853 .03915 L
.21853 .16187 L
s
1 .894 .882 r
.21853 .16187 m
.21853 .03933 L
.21884 .03933 L
.21884 .16187 L
F
.804 .522 .247 r
.21853 .16187 m
.21853 .03933 L
.21884 .03933 L
.21884 .16187 L
s
1 .894 .882 r
.21884 .16187 m
.21884 .03951 L
.21929 .03951 L
.21929 .16187 L
F
.804 .522 .247 r
.21884 .16187 m
.21884 .03951 L
.21929 .03951 L
.21929 .16187 L
s
1 .894 .882 r
.21929 .16187 m
.21929 .03959 L
.21981 .03959 L
.21981 .16187 L
F
.804 .522 .247 r
.21929 .16187 m
.21929 .03959 L
.21981 .03959 L
.21981 .16187 L
s
1 .894 .882 r
.21981 .16187 m
.21981 .03976 L
.22058 .03976 L
.22058 .16187 L
F
.804 .522 .247 r
.21981 .16187 m
.21981 .03976 L
.22058 .03976 L
.22058 .16187 L
s
1 .894 .882 r
.22058 .16187 m
.22058 .03985 L
.2214 .03985 L
.2214 .16187 L
F
.804 .522 .247 r
.22058 .16187 m
.22058 .03985 L
.2214 .03985 L
.2214 .16187 L
s
1 .894 .882 r
.2214 .16187 m
.2214 .04017 L
.22209 .04017 L
.22209 .16187 L
F
.804 .522 .247 r
.2214 .16187 m
.2214 .04017 L
.22209 .04017 L
.22209 .16187 L
s
1 .894 .882 r
.22209 .16187 m
.22209 .04034 L
.22307 .04034 L
.22307 .16187 L
F
.804 .522 .247 r
.22209 .16187 m
.22209 .04034 L
.22307 .04034 L
.22307 .16187 L
s
1 .894 .882 r
.22307 .16187 m
.22307 .04062 L
.22392 .04062 L
.22392 .16187 L
F
.804 .522 .247 r
.22307 .16187 m
.22307 .04062 L
.22392 .04062 L
.22392 .16187 L
s
1 .894 .882 r
.22392 .16187 m
.22392 .04074 L
.22425 .04074 L
.22425 .16187 L
F
.804 .522 .247 r
.22392 .16187 m
.22392 .04074 L
.22425 .04074 L
.22425 .16187 L
s
1 .894 .882 r
.22425 .16187 m
.22425 .04081 L
.22482 .04081 L
.22482 .16187 L
F
.804 .522 .247 r
.22425 .16187 m
.22425 .04081 L
.22482 .04081 L
.22482 .16187 L
s
1 .894 .882 r
.22482 .16187 m
.22482 .04112 L
.22564 .04112 L
.22564 .16187 L
F
.804 .522 .247 r
.22482 .16187 m
.22482 .04112 L
.22564 .04112 L
.22564 .16187 L
s
1 .894 .882 r
.22564 .16187 m
.22564 .04131 L
.22629 .04131 L
.22629 .16187 L
F
.804 .522 .247 r
.22564 .16187 m
.22564 .04131 L
.22629 .04131 L
.22629 .16187 L
s
1 .894 .882 r
.22629 .16187 m
.22629 .04141 L
.22665 .04141 L
.22665 .16187 L
F
.804 .522 .247 r
.22629 .16187 m
.22629 .04141 L
.22665 .04141 L
.22665 .16187 L
s
1 .894 .882 r
.22665 .16187 m
.22665 .04143 L
.22697 .04143 L
.22697 .16187 L
F
.804 .522 .247 r
.22665 .16187 m
.22665 .04143 L
.22697 .04143 L
.22697 .16187 L
s
1 .894 .882 r
.22697 .16187 m
.22697 .04157 L
.22776 .04157 L
.22776 .16187 L
F
.804 .522 .247 r
.22697 .16187 m
.22697 .04157 L
.22776 .04157 L
.22776 .16187 L
s
1 .894 .882 r
.22776 .16187 m
.22776 .04179 L
.22821 .04179 L
.22821 .16187 L
F
.804 .522 .247 r
.22776 .16187 m
.22776 .04179 L
.22821 .04179 L
.22821 .16187 L
s
1 .894 .882 r
.22821 .16187 m
.22821 .04203 L
.22919 .04203 L
.22919 .16187 L
F
.804 .522 .247 r
.22821 .16187 m
.22821 .04203 L
.22919 .04203 L
.22919 .16187 L
s
1 .894 .882 r
.22919 .16187 m
.22919 .04212 L
.22951 .04212 L
.22951 .16187 L
F
.804 .522 .247 r
.22919 .16187 m
.22919 .04212 L
.22951 .04212 L
.22951 .16187 L
s
1 .894 .882 r
.22951 .16187 m
.22951 .04224 L
.23047 .04224 L
.23047 .16187 L
F
.804 .522 .247 r
.22951 .16187 m
.22951 .04224 L
.23047 .04224 L
.23047 .16187 L
s
1 .894 .882 r
.23047 .16187 m
.23047 .0425 L
.2309 .0425 L
.2309 .16187 L
F
.804 .522 .247 r
.23047 .16187 m
.23047 .0425 L
.2309 .0425 L
.2309 .16187 L
s
1 .894 .882 r
.2309 .16187 m
.2309 .0426 L
.23178 .0426 L
.23178 .16187 L
F
.804 .522 .247 r
.2309 .16187 m
.2309 .0426 L
.23178 .0426 L
.23178 .16187 L
s
1 .894 .882 r
.23178 .16187 m
.23178 .04299 L
.23265 .04299 L
.23265 .16187 L
F
.804 .522 .247 r
.23178 .16187 m
.23178 .04299 L
.23265 .04299 L
.23265 .16187 L
s
1 .894 .882 r
.23265 .16187 m
.23265 .04308 L
.23328 .04308 L
.23328 .16187 L
F
.804 .522 .247 r
.23265 .16187 m
.23265 .04308 L
.23328 .04308 L
.23328 .16187 L
s
1 .894 .882 r
.23328 .16187 m
.23328 .04326 L
.23387 .04326 L
.23387 .16187 L
F
.804 .522 .247 r
.23328 .16187 m
.23328 .04326 L
.23387 .04326 L
.23387 .16187 L
s
1 .894 .882 r
.23387 .16187 m
.23387 .04337 L
.23475 .04337 L
.23475 .16187 L
F
.804 .522 .247 r
.23387 .16187 m
.23387 .04337 L
.23475 .04337 L
.23475 .16187 L
s
1 .894 .882 r
.23475 .16187 m
.23475 .04378 L
.23548 .04378 L
.23548 .16187 L
F
.804 .522 .247 r
.23475 .16187 m
.23475 .04378 L
.23548 .04378 L
.23548 .16187 L
s
1 .894 .882 r
.23548 .16187 m
.23548 .04388 L
.23591 .04388 L
.23591 .16187 L
F
.804 .522 .247 r
.23548 .16187 m
.23548 .04388 L
.23591 .04388 L
.23591 .16187 L
s
1 .894 .882 r
.23591 .16187 m
.23591 .04411 L
.23676 .04411 L
.23676 .16187 L
F
.804 .522 .247 r
.23591 .16187 m
.23591 .04411 L
.23676 .04411 L
.23676 .16187 L
s
1 .894 .882 r
.23676 .16187 m
.23676 .04415 L
.23712 .04415 L
.23712 .16187 L
F
.804 .522 .247 r
.23676 .16187 m
.23676 .04415 L
.23712 .04415 L
.23712 .16187 L
s
1 .894 .882 r
.23712 .16187 m
.23712 .04427 L
.23748 .04427 L
.23748 .16187 L
F
.804 .522 .247 r
.23712 .16187 m
.23712 .04427 L
.23748 .04427 L
.23748 .16187 L
s
1 .894 .882 r
.23748 .16187 m
.23748 .04439 L
.23797 .04439 L
.23797 .16187 L
F
.804 .522 .247 r
.23748 .16187 m
.23748 .04439 L
.23797 .04439 L
.23797 .16187 L
s
1 .894 .882 r
.23797 .16187 m
.23797 .0445 L
.23828 .0445 L
.23828 .16187 L
F
.804 .522 .247 r
.23797 .16187 m
.23797 .0445 L
.23828 .0445 L
.23828 .16187 L
s
1 .894 .882 r
.23828 .16187 m
.23828 .04462 L
.23862 .04462 L
.23862 .16187 L
F
.804 .522 .247 r
.23828 .16187 m
.23828 .04462 L
.23862 .04462 L
.23862 .16187 L
s
1 .894 .882 r
.23862 .16187 m
.23862 .04468 L
.23944 .04468 L
.23944 .16187 L
F
.804 .522 .247 r
.23862 .16187 m
.23862 .04468 L
.23944 .04468 L
.23944 .16187 L
s
1 .894 .882 r
.23944 .16187 m
.23944 .04498 L
.24014 .04498 L
.24014 .16187 L
F
.804 .522 .247 r
.23944 .16187 m
.23944 .04498 L
.24014 .04498 L
.24014 .16187 L
s
1 .894 .882 r
.24014 .16187 m
.24014 .04515 L
.24084 .04515 L
.24084 .16187 L
F
.804 .522 .247 r
.24014 .16187 m
.24014 .04515 L
.24084 .04515 L
.24084 .16187 L
s
1 .894 .882 r
.24084 .16187 m
.24084 .04546 L
.24186 .04546 L
.24186 .16187 L
F
.804 .522 .247 r
.24084 .16187 m
.24084 .04546 L
.24186 .04546 L
.24186 .16187 L
s
1 .894 .882 r
.24186 .16187 m
.24186 .04579 L
.24267 .04579 L
.24267 .16187 L
F
.804 .522 .247 r
.24186 .16187 m
.24186 .04579 L
.24267 .04579 L
.24267 .16187 L
s
1 .894 .882 r
.24267 .16187 m
.24267 .04584 L
.24362 .04584 L
.24362 .16187 L
F
.804 .522 .247 r
.24267 .16187 m
.24267 .04584 L
.24362 .04584 L
.24362 .16187 L
s
1 .894 .882 r
.24362 .16187 m
.24362 .04617 L
.24418 .04617 L
.24418 .16187 L
F
.804 .522 .247 r
.24362 .16187 m
.24362 .04617 L
.24418 .04617 L
.24418 .16187 L
s
1 .894 .882 r
.24418 .16187 m
.24418 .04632 L
.24452 .04632 L
.24452 .16187 L
F
.804 .522 .247 r
.24418 .16187 m
.24418 .04632 L
.24452 .04632 L
.24452 .16187 L
s
1 .894 .882 r
.24452 .16187 m
.24452 .04647 L
.24533 .04647 L
.24533 .16187 L
F
.804 .522 .247 r
.24452 .16187 m
.24452 .04647 L
.24533 .04647 L
.24533 .16187 L
s
1 .894 .882 r
.24533 .16187 m
.24533 .04682 L
.24635 .04682 L
.24635 .16187 L
F
.804 .522 .247 r
.24533 .16187 m
.24533 .04682 L
.24635 .04682 L
.24635 .16187 L
s
1 .894 .882 r
.24635 .16187 m
.24635 .04698 L
.2468 .04698 L
.2468 .16187 L
F
.804 .522 .247 r
.24635 .16187 m
.24635 .04698 L
.2468 .04698 L
.2468 .16187 L
s
1 .894 .882 r
.2468 .16187 m
.2468 .04707 L
.2473 .04707 L
.2473 .16187 L
F
.804 .522 .247 r
.2468 .16187 m
.2468 .04707 L
.2473 .04707 L
.2473 .16187 L
s
1 .894 .882 r
.2473 .16187 m
.2473 .04733 L
.24827 .04733 L
.24827 .16187 L
F
.804 .522 .247 r
.2473 .16187 m
.2473 .04733 L
.24827 .04733 L
.24827 .16187 L
s
1 .894 .882 r
.24827 .16187 m
.24827 .04752 L
.24897 .04752 L
.24897 .16187 L
F
.804 .522 .247 r
.24827 .16187 m
.24827 .04752 L
.24897 .04752 L
.24897 .16187 L
s
1 .894 .882 r
.24897 .16187 m
.24897 .04775 L
.24986 .04775 L
.24986 .16187 L
F
.804 .522 .247 r
.24897 .16187 m
.24897 .04775 L
.24986 .04775 L
.24986 .16187 L
s
1 .894 .882 r
.24986 .16187 m
.24986 .04798 L
.25051 .04798 L
.25051 .16187 L
F
.804 .522 .247 r
.24986 .16187 m
.24986 .04798 L
.25051 .04798 L
.25051 .16187 L
s
1 .894 .882 r
.25051 .16187 m
.25051 .04819 L
.25106 .04819 L
.25106 .16187 L
F
.804 .522 .247 r
.25051 .16187 m
.25051 .04819 L
.25106 .04819 L
.25106 .16187 L
s
1 .894 .882 r
.25106 .16187 m
.25106 .04836 L
.25164 .04836 L
.25164 .16187 L
F
.804 .522 .247 r
.25106 .16187 m
.25106 .04836 L
.25164 .04836 L
.25164 .16187 L
s
1 .894 .882 r
.25164 .16187 m
.25164 .04847 L
.25199 .04847 L
.25199 .16187 L
F
.804 .522 .247 r
.25164 .16187 m
.25164 .04847 L
.25199 .04847 L
.25199 .16187 L
s
1 .894 .882 r
.25199 .16187 m
.25199 .04859 L
.2526 .04859 L
.2526 .16187 L
F
.804 .522 .247 r
.25199 .16187 m
.25199 .04859 L
.2526 .04859 L
.2526 .16187 L
s
1 .894 .882 r
.2526 .16187 m
.2526 .04876 L
.2531 .04876 L
.2531 .16187 L
F
.804 .522 .247 r
.2526 .16187 m
.2526 .04876 L
.2531 .04876 L
.2531 .16187 L
s
1 .894 .882 r
.2531 .16187 m
.2531 .04888 L
.2535 .04888 L
.2535 .16187 L
F
.804 .522 .247 r
.2531 .16187 m
.2531 .04888 L
.2535 .04888 L
.2535 .16187 L
s
1 .894 .882 r
.2535 .16187 m
.2535 .049 L
.25385 .049 L
.25385 .16187 L
F
.804 .522 .247 r
.2535 .16187 m
.2535 .049 L
.25385 .049 L
.25385 .16187 L
s
1 .894 .882 r
.25385 .16187 m
.25385 .04921 L
.25443 .04921 L
.25443 .16187 L
F
.804 .522 .247 r
.25385 .16187 m
.25385 .04921 L
.25443 .04921 L
.25443 .16187 L
s
1 .894 .882 r
.25443 .16187 m
.25443 .04932 L
.25514 .04932 L
.25514 .16187 L
F
.804 .522 .247 r
.25443 .16187 m
.25443 .04932 L
.25514 .04932 L
.25514 .16187 L
s
1 .894 .882 r
.25514 .16187 m
.25514 .04965 L
.25588 .04965 L
.25588 .16187 L
F
.804 .522 .247 r
.25514 .16187 m
.25514 .04965 L
.25588 .04965 L
.25588 .16187 L
s
1 .894 .882 r
.25588 .16187 m
.25588 .04969 L
.25656 .04969 L
.25656 .16187 L
F
.804 .522 .247 r
.25588 .16187 m
.25588 .04969 L
.25656 .04969 L
.25656 .16187 L
s
1 .894 .882 r
.25656 .16187 m
.25656 .04992 L
.25716 .04992 L
.25716 .16187 L
F
.804 .522 .247 r
.25656 .16187 m
.25656 .04992 L
.25716 .04992 L
.25716 .16187 L
s
1 .894 .882 r
.25716 .16187 m
.25716 .05019 L
.25809 .05019 L
.25809 .16187 L
F
.804 .522 .247 r
.25716 .16187 m
.25716 .05019 L
.25809 .05019 L
.25809 .16187 L
s
1 .894 .882 r
.25809 .16187 m
.25809 .05054 L
.25892 .05054 L
.25892 .16187 L
F
.804 .522 .247 r
.25809 .16187 m
.25809 .05054 L
.25892 .05054 L
.25892 .16187 L
s
1 .894 .882 r
.25892 .16187 m
.25892 .05065 L
.25935 .05065 L
.25935 .16187 L
F
.804 .522 .247 r
.25892 .16187 m
.25892 .05065 L
.25935 .05065 L
.25935 .16187 L
s
1 .894 .882 r
.25935 .16187 m
.25935 .05078 L
.25992 .05078 L
.25992 .16187 L
F
.804 .522 .247 r
.25935 .16187 m
.25935 .05078 L
.25992 .05078 L
.25992 .16187 L
s
1 .894 .882 r
.25992 .16187 m
.25992 .05101 L
.26035 .05101 L
.26035 .16187 L
F
.804 .522 .247 r
.25992 .16187 m
.25992 .05101 L
.26035 .05101 L
.26035 .16187 L
s
1 .894 .882 r
.26035 .16187 m
.26035 .05127 L
.2612 .05127 L
.2612 .16187 L
F
.804 .522 .247 r
.26035 .16187 m
.26035 .05127 L
.2612 .05127 L
.2612 .16187 L
s
1 .894 .882 r
.2612 .16187 m
.2612 .05146 L
.26221 .05146 L
.26221 .16187 L
F
.804 .522 .247 r
.2612 .16187 m
.2612 .05146 L
.26221 .05146 L
.26221 .16187 L
s
1 .894 .882 r
.26221 .16187 m
.26221 .05169 L
.2626 .05169 L
.2626 .16187 L
F
.804 .522 .247 r
.26221 .16187 m
.26221 .05169 L
.2626 .05169 L
.2626 .16187 L
s
1 .894 .882 r
.2626 .16187 m
.2626 .05174 L
.2631 .05174 L
.2631 .16187 L
F
.804 .522 .247 r
.2626 .16187 m
.2626 .05174 L
.2631 .05174 L
.2631 .16187 L
s
1 .894 .882 r
.2631 .16187 m
.2631 .05193 L
.26355 .05193 L
.26355 .16187 L
F
.804 .522 .247 r
.2631 .16187 m
.2631 .05193 L
.26355 .05193 L
.26355 .16187 L
s
1 .894 .882 r
.26355 .16187 m
.26355 .05202 L
.26399 .05202 L
.26399 .16187 L
F
.804 .522 .247 r
.26355 .16187 m
.26355 .05202 L
.26399 .05202 L
.26399 .16187 L
s
1 .894 .882 r
.26399 .16187 m
.26399 .0522 L
.26475 .0522 L
.26475 .16187 L
F
.804 .522 .247 r
.26399 .16187 m
.26399 .0522 L
.26475 .0522 L
.26475 .16187 L
s
1 .894 .882 r
.26475 .16187 m
.26475 .05251 L
.26574 .05251 L
.26574 .16187 L
F
.804 .522 .247 r
.26475 .16187 m
.26475 .05251 L
.26574 .05251 L
.26574 .16187 L
s
1 .894 .882 r
.26574 .16187 m
.26574 .05289 L
.26665 .05289 L
.26665 .16187 L
F
.804 .522 .247 r
.26574 .16187 m
.26574 .05289 L
.26665 .05289 L
.26665 .16187 L
s
1 .894 .882 r
.26665 .16187 m
.26665 .05303 L
.26704 .05303 L
.26704 .16187 L
F
.804 .522 .247 r
.26665 .16187 m
.26665 .05303 L
.26704 .05303 L
.26704 .16187 L
s
1 .894 .882 r
.26704 .16187 m
.26704 .05321 L
.26751 .05321 L
.26751 .16187 L
F
.804 .522 .247 r
.26704 .16187 m
.26704 .05321 L
.26751 .05321 L
.26751 .16187 L
s
1 .894 .882 r
.26751 .16187 m
.26751 .05347 L
.26831 .05347 L
.26831 .16187 L
F
.804 .522 .247 r
.26751 .16187 m
.26751 .05347 L
.26831 .05347 L
.26831 .16187 L
s
1 .894 .882 r
.26831 .16187 m
.26831 .05357 L
.26912 .05357 L
.26912 .16187 L
F
.804 .522 .247 r
.26831 .16187 m
.26831 .05357 L
.26912 .05357 L
.26912 .16187 L
s
1 .894 .882 r
.26912 .16187 m
.26912 .05387 L
.26948 .05387 L
.26948 .16187 L
F
.804 .522 .247 r
.26912 .16187 m
.26912 .05387 L
.26948 .05387 L
.26948 .16187 L
s
1 .894 .882 r
.26948 .16187 m
.26948 .05413 L
.27041 .05413 L
.27041 .16187 L
F
.804 .522 .247 r
.26948 .16187 m
.26948 .05413 L
.27041 .05413 L
.27041 .16187 L
s
1 .894 .882 r
.27041 .16187 m
.27041 .05423 L
.27081 .05423 L
.27081 .16187 L
F
.804 .522 .247 r
.27041 .16187 m
.27041 .05423 L
.27081 .05423 L
.27081 .16187 L
s
1 .894 .882 r
.27081 .16187 m
.27081 .05434 L
.27119 .05434 L
.27119 .16187 L
F
.804 .522 .247 r
.27081 .16187 m
.27081 .05434 L
.27119 .05434 L
.27119 .16187 L
s
1 .894 .882 r
.27119 .16187 m
.27119 .05461 L
.27191 .05461 L
.27191 .16187 L
F
.804 .522 .247 r
.27119 .16187 m
.27119 .05461 L
.27191 .05461 L
.27191 .16187 L
s
1 .894 .882 r
.27191 .16187 m
.27191 .05478 L
.27255 .05478 L
.27255 .16187 L
F
.804 .522 .247 r
.27191 .16187 m
.27191 .05478 L
.27255 .05478 L
.27255 .16187 L
s
1 .894 .882 r
.27255 .16187 m
.27255 .05502 L
.27304 .05502 L
.27304 .16187 L
F
.804 .522 .247 r
.27255 .16187 m
.27255 .05502 L
.27304 .05502 L
.27304 .16187 L
s
1 .894 .882 r
.27304 .16187 m
.27304 .05511 L
.27363 .05511 L
.27363 .16187 L
F
.804 .522 .247 r
.27304 .16187 m
.27304 .05511 L
.27363 .05511 L
.27363 .16187 L
s
1 .894 .882 r
.27363 .16187 m
.27363 .05527 L
.27423 .05527 L
.27423 .16187 L
F
.804 .522 .247 r
.27363 .16187 m
.27363 .05527 L
.27423 .05527 L
.27423 .16187 L
s
1 .894 .882 r
.27423 .16187 m
.27423 .05543 L
.27461 .05543 L
.27461 .16187 L
F
.804 .522 .247 r
.27423 .16187 m
.27423 .05543 L
.27461 .05543 L
.27461 .16187 L
s
1 .894 .882 r
.27461 .16187 m
.27461 .05554 L
.27499 .05554 L
.27499 .16187 L
F
.804 .522 .247 r
.27461 .16187 m
.27461 .05554 L
.27499 .05554 L
.27499 .16187 L
s
1 .894 .882 r
.27499 .16187 m
.27499 .05579 L
.27577 .05579 L
.27577 .16187 L
F
.804 .522 .247 r
.27499 .16187 m
.27499 .05579 L
.27577 .05579 L
.27577 .16187 L
s
1 .894 .882 r
.27577 .16187 m
.27577 .05606 L
.27639 .05606 L
.27639 .16187 L
F
.804 .522 .247 r
.27577 .16187 m
.27577 .05606 L
.27639 .05606 L
.27639 .16187 L
s
1 .894 .882 r
.27639 .16187 m
.27639 .05626 L
.27742 .05626 L
.27742 .16187 L
F
.804 .522 .247 r
.27639 .16187 m
.27639 .05626 L
.27742 .05626 L
.27742 .16187 L
s
1 .894 .882 r
.27742 .16187 m
.27742 .05673 L
.27833 .05673 L
.27833 .16187 L
F
.804 .522 .247 r
.27742 .16187 m
.27742 .05673 L
.27833 .05673 L
.27833 .16187 L
s
1 .894 .882 r
.27833 .16187 m
.27833 .05677 L
.27897 .05677 L
.27897 .16187 L
F
.804 .522 .247 r
.27833 .16187 m
.27833 .05677 L
.27897 .05677 L
.27897 .16187 L
s
1 .894 .882 r
.27897 .16187 m
.27897 .05708 L
.27946 .05708 L
.27946 .16187 L
F
.804 .522 .247 r
.27897 .16187 m
.27897 .05708 L
.27946 .05708 L
.27946 .16187 L
s
1 .894 .882 r
.27946 .16187 m
.27946 .05717 L
.28004 .05717 L
.28004 .16187 L
F
.804 .522 .247 r
.27946 .16187 m
.27946 .05717 L
.28004 .05717 L
.28004 .16187 L
s
1 .894 .882 r
.28004 .16187 m
.28004 .05749 L
.28099 .05749 L
.28099 .16187 L
F
.804 .522 .247 r
.28004 .16187 m
.28004 .05749 L
.28099 .05749 L
.28099 .16187 L
s
1 .894 .882 r
.28099 .16187 m
.28099 .05775 L
.28176 .05775 L
.28176 .16187 L
F
.804 .522 .247 r
.28099 .16187 m
.28099 .05775 L
.28176 .05775 L
.28176 .16187 L
s
1 .894 .882 r
.28176 .16187 m
.28176 .05794 L
.28217 .05794 L
.28217 .16187 L
F
.804 .522 .247 r
.28176 .16187 m
.28176 .05794 L
.28217 .05794 L
.28217 .16187 L
s
1 .894 .882 r
.28217 .16187 m
.28217 .0581 L
.28258 .0581 L
.28258 .16187 L
F
.804 .522 .247 r
.28217 .16187 m
.28217 .0581 L
.28258 .0581 L
.28258 .16187 L
s
1 .894 .882 r
.28258 .16187 m
.28258 .05828 L
.28305 .05828 L
.28305 .16187 L
F
.804 .522 .247 r
.28258 .16187 m
.28258 .05828 L
.28305 .05828 L
.28305 .16187 L
s
1 .894 .882 r
.28305 .16187 m
.28305 .0584 L
.28404 .0584 L
.28404 .16187 L
F
.804 .522 .247 r
.28305 .16187 m
.28305 .0584 L
.28404 .0584 L
.28404 .16187 L
s
1 .894 .882 r
.28404 .16187 m
.28404 .05872 L
.2844 .05872 L
.2844 .16187 L
F
.804 .522 .247 r
.28404 .16187 m
.28404 .05872 L
.2844 .05872 L
.2844 .16187 L
s
1 .894 .882 r
.2844 .16187 m
.2844 .0589 L
.28493 .0589 L
.28493 .16187 L
F
.804 .522 .247 r
.2844 .16187 m
.2844 .0589 L
.28493 .0589 L
.28493 .16187 L
s
1 .894 .882 r
.28493 .16187 m
.28493 .05899 L
.2853 .05899 L
.2853 .16187 L
F
.804 .522 .247 r
.28493 .16187 m
.28493 .05899 L
.2853 .05899 L
.2853 .16187 L
s
1 .894 .882 r
.2853 .16187 m
.2853 .05938 L
.28623 .05938 L
.28623 .16187 L
F
.804 .522 .247 r
.2853 .16187 m
.2853 .05938 L
.28623 .05938 L
.28623 .16187 L
s
1 .894 .882 r
.28623 .16187 m
.28623 .05955 L
.28691 .05955 L
.28691 .16187 L
F
.804 .522 .247 r
.28623 .16187 m
.28623 .05955 L
.28691 .05955 L
.28691 .16187 L
s
1 .894 .882 r
.28691 .16187 m
.28691 .05967 L
.28783 .05967 L
.28783 .16187 L
F
.804 .522 .247 r
.28691 .16187 m
.28691 .05967 L
.28783 .05967 L
.28783 .16187 L
s
1 .894 .882 r
.28783 .16187 m
.28783 .06004 L
.28874 .06004 L
.28874 .16187 L
F
.804 .522 .247 r
.28783 .16187 m
.28783 .06004 L
.28874 .06004 L
.28874 .16187 L
s
1 .894 .882 r
.28874 .16187 m
.28874 .06037 L
.28938 .06037 L
.28938 .16187 L
F
.804 .522 .247 r
.28874 .16187 m
.28874 .06037 L
.28938 .06037 L
.28938 .16187 L
s
1 .894 .882 r
.28938 .16187 m
.28938 .06053 L
.28977 .06053 L
.28977 .16187 L
F
.804 .522 .247 r
.28938 .16187 m
.28938 .06053 L
.28977 .06053 L
.28977 .16187 L
s
1 .894 .882 r
.28977 .16187 m
.28977 .06089 L
.29063 .06089 L
.29063 .16187 L
F
.804 .522 .247 r
.28977 .16187 m
.28977 .06089 L
.29063 .06089 L
.29063 .16187 L
s
1 .894 .882 r
.29063 .16187 m
.29063 .06098 L
.29148 .06098 L
.29148 .16187 L
F
.804 .522 .247 r
.29063 .16187 m
.29063 .06098 L
.29148 .06098 L
.29148 .16187 L
s
1 .894 .882 r
.29148 .16187 m
.29148 .06151 L
.29237 .06151 L
.29237 .16187 L
F
.804 .522 .247 r
.29148 .16187 m
.29148 .06151 L
.29237 .06151 L
.29237 .16187 L
s
1 .894 .882 r
.29237 .16187 m
.29237 .0617 L
.29318 .0617 L
.29318 .16187 L
F
.804 .522 .247 r
.29237 .16187 m
.29237 .0617 L
.29318 .0617 L
.29318 .16187 L
s
1 .894 .882 r
.29318 .16187 m
.29318 .06195 L
.29404 .06195 L
.29404 .16187 L
F
.804 .522 .247 r
.29318 .16187 m
.29318 .06195 L
.29404 .06195 L
.29404 .16187 L
s
1 .894 .882 r
.29404 .16187 m
.29404 .06221 L
.29501 .06221 L
.29501 .16187 L
F
.804 .522 .247 r
.29404 .16187 m
.29404 .06221 L
.29501 .06221 L
.29501 .16187 L
s
1 .894 .882 r
.29501 .16187 m
.29501 .06262 L
.29558 .06262 L
.29558 .16187 L
F
.804 .522 .247 r
.29501 .16187 m
.29501 .06262 L
.29558 .06262 L
.29558 .16187 L
s
1 .894 .882 r
.29558 .16187 m
.29558 .06284 L
.2962 .06284 L
.2962 .16187 L
F
.804 .522 .247 r
.29558 .16187 m
.29558 .06284 L
.2962 .06284 L
.2962 .16187 L
s
1 .894 .882 r
.2962 .16187 m
.2962 .06292 L
.2968 .06292 L
.2968 .16187 L
F
.804 .522 .247 r
.2962 .16187 m
.2962 .06292 L
.2968 .06292 L
.2968 .16187 L
s
1 .894 .882 r
.2968 .16187 m
.2968 .06317 L
.29713 .06317 L
.29713 .16187 L
F
.804 .522 .247 r
.2968 .16187 m
.2968 .06317 L
.29713 .06317 L
.29713 .16187 L
s
1 .894 .882 r
.29713 .16187 m
.29713 .06332 L
.29796 .06332 L
.29796 .16187 L
F
.804 .522 .247 r
.29713 .16187 m
.29713 .06332 L
.29796 .06332 L
.29796 .16187 L
s
1 .894 .882 r
.29796 .16187 m
.29796 .06359 L
.29849 .06359 L
.29849 .16187 L
F
.804 .522 .247 r
.29796 .16187 m
.29796 .06359 L
.29849 .06359 L
.29849 .16187 L
s
1 .894 .882 r
.29849 .16187 m
.29849 .06381 L
.29898 .06381 L
.29898 .16187 L
F
.804 .522 .247 r
.29849 .16187 m
.29849 .06381 L
.29898 .06381 L
.29898 .16187 L
s
1 .894 .882 r
.29898 .16187 m
.29898 .06388 L
.29988 .06388 L
.29988 .16187 L
F
.804 .522 .247 r
.29898 .16187 m
.29898 .06388 L
.29988 .06388 L
.29988 .16187 L
s
1 .894 .882 r
.29988 .16187 m
.29988 .06424 L
.30076 .06424 L
.30076 .16187 L
F
.804 .522 .247 r
.29988 .16187 m
.29988 .06424 L
.30076 .06424 L
.30076 .16187 L
s
1 .894 .882 r
.30076 .16187 m
.30076 .0645 L
.30123 .0645 L
.30123 .16187 L
F
.804 .522 .247 r
.30076 .16187 m
.30076 .0645 L
.30123 .0645 L
.30123 .16187 L
s
1 .894 .882 r
.30123 .16187 m
.30123 .06469 L
.30223 .06469 L
.30223 .16187 L
F
.804 .522 .247 r
.30123 .16187 m
.30123 .06469 L
.30223 .06469 L
.30223 .16187 L
s
1 .894 .882 r
.30223 .16187 m
.30223 .06527 L
.30306 .06527 L
.30306 .16187 L
F
.804 .522 .247 r
.30223 .16187 m
.30223 .06527 L
.30306 .06527 L
.30306 .16187 L
s
1 .894 .882 r
.30306 .16187 m
.30306 .06542 L
.30405 .06542 L
.30405 .16187 L
F
.804 .522 .247 r
.30306 .16187 m
.30306 .06542 L
.30405 .06542 L
.30405 .16187 L
s
1 .894 .882 r
.30405 .16187 m
.30405 .06581 L
.30488 .06581 L
.30488 .16187 L
F
.804 .522 .247 r
.30405 .16187 m
.30405 .06581 L
.30488 .06581 L
.30488 .16187 L
s
1 .894 .882 r
.30488 .16187 m
.30488 .06612 L
.30528 .06612 L
.30528 .16187 L
F
.804 .522 .247 r
.30488 .16187 m
.30488 .06612 L
.30528 .06612 L
.30528 .16187 L
s
1 .894 .882 r
.30528 .16187 m
.30528 .06631 L
.30623 .06631 L
.30623 .16187 L
F
.804 .522 .247 r
.30528 .16187 m
.30528 .06631 L
.30623 .06631 L
.30623 .16187 L
s
1 .894 .882 r
.30623 .16187 m
.30623 .06667 L
.30689 .06667 L
.30689 .16187 L
F
.804 .522 .247 r
.30623 .16187 m
.30623 .06667 L
.30689 .06667 L
.30689 .16187 L
s
1 .894 .882 r
.30689 .16187 m
.30689 .06674 L
.30764 .06674 L
.30764 .16187 L
F
.804 .522 .247 r
.30689 .16187 m
.30689 .06674 L
.30764 .06674 L
.30764 .16187 L
s
1 .894 .882 r
.30764 .16187 m
.30764 .067 L
.30821 .067 L
.30821 .16187 L
F
.804 .522 .247 r
.30764 .16187 m
.30764 .067 L
.30821 .067 L
.30821 .16187 L
s
1 .894 .882 r
.30821 .16187 m
.30821 .06725 L
.30863 .06725 L
.30863 .16187 L
F
.804 .522 .247 r
.30821 .16187 m
.30821 .06725 L
.30863 .06725 L
.30863 .16187 L
s
1 .894 .882 r
.30863 .16187 m
.30863 .0676 L
.30943 .0676 L
.30943 .16187 L
F
.804 .522 .247 r
.30863 .16187 m
.30863 .0676 L
.30943 .0676 L
.30943 .16187 L
s
1 .894 .882 r
.30943 .16187 m
.30943 .06782 L
.3104 .06782 L
.3104 .16187 L
F
.804 .522 .247 r
.30943 .16187 m
.30943 .06782 L
.3104 .06782 L
.3104 .16187 L
s
1 .894 .882 r
.3104 .16187 m
.3104 .06817 L
.31116 .06817 L
.31116 .16187 L
F
.804 .522 .247 r
.3104 .16187 m
.3104 .06817 L
.31116 .06817 L
.31116 .16187 L
s
1 .894 .882 r
.31116 .16187 m
.31116 .0683 L
.31163 .0683 L
.31163 .16187 L
F
.804 .522 .247 r
.31116 .16187 m
.31116 .0683 L
.31163 .0683 L
.31163 .16187 L
s
1 .894 .882 r
.31163 .16187 m
.31163 .06867 L
.31217 .06867 L
.31217 .16187 L
F
.804 .522 .247 r
.31163 .16187 m
.31163 .06867 L
.31217 .06867 L
.31217 .16187 L
s
1 .894 .882 r
.31217 .16187 m
.31217 .06881 L
.31284 .06881 L
.31284 .16187 L
F
.804 .522 .247 r
.31217 .16187 m
.31217 .06881 L
.31284 .06881 L
.31284 .16187 L
s
1 .894 .882 r
.31284 .16187 m
.31284 .06897 L
.31331 .06897 L
.31331 .16187 L
F
.804 .522 .247 r
.31284 .16187 m
.31284 .06897 L
.31331 .06897 L
.31331 .16187 L
s
1 .894 .882 r
.31331 .16187 m
.31331 .06914 L
.31376 .06914 L
.31376 .16187 L
F
.804 .522 .247 r
.31331 .16187 m
.31331 .06914 L
.31376 .06914 L
.31376 .16187 L
s
1 .894 .882 r
.31376 .16187 m
.31376 .06942 L
.3145 .06942 L
.3145 .16187 L
F
.804 .522 .247 r
.31376 .16187 m
.31376 .06942 L
.3145 .06942 L
.3145 .16187 L
s
1 .894 .882 r
.3145 .16187 m
.3145 .06955 L
.31495 .06955 L
.31495 .16187 L
F
.804 .522 .247 r
.3145 .16187 m
.3145 .06955 L
.31495 .06955 L
.31495 .16187 L
s
1 .894 .882 r
.31495 .16187 m
.31495 .06991 L
.31597 .06991 L
.31597 .16187 L
F
.804 .522 .247 r
.31495 .16187 m
.31495 .06991 L
.31597 .06991 L
.31597 .16187 L
s
1 .894 .882 r
.31597 .16187 m
.31597 .07014 L
.31656 .07014 L
.31656 .16187 L
F
.804 .522 .247 r
.31597 .16187 m
.31597 .07014 L
.31656 .07014 L
.31656 .16187 L
s
1 .894 .882 r
.31656 .16187 m
.31656 .07043 L
.31746 .07043 L
.31746 .16187 L
F
.804 .522 .247 r
.31656 .16187 m
.31656 .07043 L
.31746 .07043 L
.31746 .16187 L
s
1 .894 .882 r
.31746 .16187 m
.31746 .07103 L
.31847 .07103 L
.31847 .16187 L
F
.804 .522 .247 r
.31746 .16187 m
.31746 .07103 L
.31847 .07103 L
.31847 .16187 L
s
1 .894 .882 r
.31847 .16187 m
.31847 .07111 L
.3188 .07111 L
.3188 .16187 L
F
.804 .522 .247 r
.31847 .16187 m
.31847 .07111 L
.3188 .07111 L
.3188 .16187 L
s
1 .894 .882 r
.3188 .16187 m
.3188 .07128 L
.31959 .07128 L
.31959 .16187 L
F
.804 .522 .247 r
.3188 .16187 m
.3188 .07128 L
.31959 .07128 L
.31959 .16187 L
s
1 .894 .882 r
.31959 .16187 m
.31959 .07149 L
.32053 .07149 L
.32053 .16187 L
F
.804 .522 .247 r
.31959 .16187 m
.31959 .07149 L
.32053 .07149 L
.32053 .16187 L
s
1 .894 .882 r
.32053 .16187 m
.32053 .07194 L
.32103 .07194 L
.32103 .16187 L
F
.804 .522 .247 r
.32053 .16187 m
.32053 .07194 L
.32103 .07194 L
.32103 .16187 L
s
1 .894 .882 r
.32103 .16187 m
.32103 .07221 L
.32199 .07221 L
.32199 .16187 L
F
.804 .522 .247 r
.32103 .16187 m
.32103 .07221 L
.32199 .07221 L
.32199 .16187 L
s
1 .894 .882 r
.32199 .16187 m
.32199 .07268 L
.32287 .07268 L
.32287 .16187 L
F
.804 .522 .247 r
.32199 .16187 m
.32199 .07268 L
.32287 .07268 L
.32287 .16187 L
s
1 .894 .882 r
.32287 .16187 m
.32287 .07281 L
.32346 .07281 L
.32346 .16187 L
F
.804 .522 .247 r
.32287 .16187 m
.32287 .07281 L
.32346 .07281 L
.32346 .16187 L
s
1 .894 .882 r
.32346 .16187 m
.32346 .07311 L
.32424 .07311 L
.32424 .16187 L
F
.804 .522 .247 r
.32346 .16187 m
.32346 .07311 L
.32424 .07311 L
.32424 .16187 L
s
1 .894 .882 r
.32424 .16187 m
.32424 .0734 L
.32494 .0734 L
.32494 .16187 L
F
.804 .522 .247 r
.32424 .16187 m
.32424 .0734 L
.32494 .0734 L
.32494 .16187 L
s
1 .894 .882 r
.32494 .16187 m
.32494 .0737 L
.32571 .0737 L
.32571 .16187 L
F
.804 .522 .247 r
.32494 .16187 m
.32494 .0737 L
.32571 .0737 L
.32571 .16187 L
s
1 .894 .882 r
.32571 .16187 m
.32571 .074 L
.32654 .074 L
.32654 .16187 L
F
.804 .522 .247 r
.32571 .16187 m
.32571 .074 L
.32654 .074 L
.32654 .16187 L
s
1 .894 .882 r
.32654 .16187 m
.32654 .07451 L
.32738 .07451 L
.32738 .16187 L
F
.804 .522 .247 r
.32654 .16187 m
.32654 .07451 L
.32738 .07451 L
.32738 .16187 L
s
1 .894 .882 r
.32738 .16187 m
.32738 .07485 L
.32837 .07485 L
.32837 .16187 L
F
.804 .522 .247 r
.32738 .16187 m
.32738 .07485 L
.32837 .07485 L
.32837 .16187 L
s
1 .894 .882 r
.32837 .16187 m
.32837 .07502 L
.32897 .07502 L
.32897 .16187 L
F
.804 .522 .247 r
.32837 .16187 m
.32837 .07502 L
.32897 .07502 L
.32897 .16187 L
s
1 .894 .882 r
.32897 .16187 m
.32897 .07526 L
.32957 .07526 L
.32957 .16187 L
F
.804 .522 .247 r
.32897 .16187 m
.32897 .07526 L
.32957 .07526 L
.32957 .16187 L
s
1 .894 .882 r
.32957 .16187 m
.32957 .07546 L
.33006 .07546 L
.33006 .16187 L
F
.804 .522 .247 r
.32957 .16187 m
.32957 .07546 L
.33006 .07546 L
.33006 .16187 L
s
1 .894 .882 r
.33006 .16187 m
.33006 .07578 L
.33089 .07578 L
.33089 .16187 L
F
.804 .522 .247 r
.33006 .16187 m
.33006 .07578 L
.33089 .07578 L
.33089 .16187 L
s
1 .894 .882 r
.33089 .16187 m
.33089 .07595 L
.33134 .07595 L
.33134 .16187 L
F
.804 .522 .247 r
.33089 .16187 m
.33089 .07595 L
.33134 .07595 L
.33134 .16187 L
s
1 .894 .882 r
.33134 .16187 m
.33134 .07643 L
.33224 .07643 L
.33224 .16187 L
F
.804 .522 .247 r
.33134 .16187 m
.33134 .07643 L
.33224 .07643 L
.33224 .16187 L
s
1 .894 .882 r
.33224 .16187 m
.33224 .0765 L
.33258 .0765 L
.33258 .16187 L
F
.804 .522 .247 r
.33224 .16187 m
.33224 .0765 L
.33258 .0765 L
.33258 .16187 L
s
1 .894 .882 r
.33258 .16187 m
.33258 .07662 L
.33343 .07662 L
.33343 .16187 L
F
.804 .522 .247 r
.33258 .16187 m
.33258 .07662 L
.33343 .07662 L
.33343 .16187 L
s
1 .894 .882 r
.33343 .16187 m
.33343 .07695 L
.33433 .07695 L
.33433 .16187 L
F
.804 .522 .247 r
.33343 .16187 m
.33343 .07695 L
.33433 .07695 L
.33433 .16187 L
s
1 .894 .882 r
.33433 .16187 m
.33433 .07756 L
.33536 .07756 L
.33536 .16187 L
F
.804 .522 .247 r
.33433 .16187 m
.33433 .07756 L
.33536 .07756 L
.33536 .16187 L
s
1 .894 .882 r
.33536 .16187 m
.33536 .07777 L
.33573 .07777 L
.33573 .16187 L
F
.804 .522 .247 r
.33536 .16187 m
.33536 .07777 L
.33573 .07777 L
.33573 .16187 L
s
1 .894 .882 r
.33573 .16187 m
.33573 .07809 L
.33657 .07809 L
.33657 .16187 L
F
.804 .522 .247 r
.33573 .16187 m
.33573 .07809 L
.33657 .07809 L
.33657 .16187 L
s
1 .894 .882 r
.33657 .16187 m
.33657 .07832 L
.33698 .07832 L
.33698 .16187 L
F
.804 .522 .247 r
.33657 .16187 m
.33657 .07832 L
.33698 .07832 L
.33698 .16187 L
s
1 .894 .882 r
.33698 .16187 m
.33698 .07847 L
.33739 .07847 L
.33739 .16187 L
F
.804 .522 .247 r
.33698 .16187 m
.33698 .07847 L
.33739 .07847 L
.33739 .16187 L
s
1 .894 .882 r
.33739 .16187 m
.33739 .07889 L
.3383 .07889 L
.3383 .16187 L
F
.804 .522 .247 r
.33739 .16187 m
.33739 .07889 L
.3383 .07889 L
.3383 .16187 L
s
1 .894 .882 r
.3383 .16187 m
.3383 .07899 L
.3392 .07899 L
.3392 .16187 L
F
.804 .522 .247 r
.3383 .16187 m
.3383 .07899 L
.3392 .07899 L
.3392 .16187 L
s
1 .894 .882 r
.3392 .16187 m
.3392 .07949 L
.33978 .07949 L
.33978 .16187 L
F
.804 .522 .247 r
.3392 .16187 m
.3392 .07949 L
.33978 .07949 L
.33978 .16187 L
s
1 .894 .882 r
.33978 .16187 m
.33978 .07964 L
.34062 .07964 L
.34062 .16187 L
F
.804 .522 .247 r
.33978 .16187 m
.33978 .07964 L
.34062 .07964 L
.34062 .16187 L
s
1 .894 .882 r
.34062 .16187 m
.34062 .07995 L
.34106 .07995 L
.34106 .16187 L
F
.804 .522 .247 r
.34062 .16187 m
.34062 .07995 L
.34106 .07995 L
.34106 .16187 L
s
1 .894 .882 r
.34106 .16187 m
.34106 .08021 L
.34157 .08021 L
.34157 .16187 L
F
.804 .522 .247 r
.34106 .16187 m
.34106 .08021 L
.34157 .08021 L
.34157 .16187 L
s
1 .894 .882 r
.34157 .16187 m
.34157 .08041 L
.34242 .08041 L
.34242 .16187 L
F
.804 .522 .247 r
.34157 .16187 m
.34157 .08041 L
.34242 .08041 L
.34242 .16187 L
s
1 .894 .882 r
.34242 .16187 m
.34242 .08072 L
.34275 .08072 L
.34275 .16187 L
F
.804 .522 .247 r
.34242 .16187 m
.34242 .08072 L
.34275 .08072 L
.34275 .16187 L
s
1 .894 .882 r
.34275 .16187 m
.34275 .08088 L
.34338 .08088 L
.34338 .16187 L
F
.804 .522 .247 r
.34275 .16187 m
.34275 .08088 L
.34338 .08088 L
.34338 .16187 L
s
1 .894 .882 r
.34338 .16187 m
.34338 .08122 L
.34394 .08122 L
.34394 .16187 L
F
.804 .522 .247 r
.34338 .16187 m
.34338 .08122 L
.34394 .08122 L
.34394 .16187 L
s
1 .894 .882 r
.34394 .16187 m
.34394 .08122 L
.34449 .08122 L
.34449 .16187 L
F
.804 .522 .247 r
.34394 .16187 m
.34394 .08122 L
.34449 .08122 L
.34449 .16187 L
s
1 .894 .882 r
.34449 .16187 m
.34449 .08162 L
.34525 .08162 L
.34525 .16187 L
F
.804 .522 .247 r
.34449 .16187 m
.34449 .08162 L
.34525 .08162 L
.34525 .16187 L
s
1 .894 .882 r
.34525 .16187 m
.34525 .0818 L
.34571 .0818 L
.34571 .16187 L
F
.804 .522 .247 r
.34525 .16187 m
.34525 .0818 L
.34571 .0818 L
.34571 .16187 L
s
1 .894 .882 r
.34571 .16187 m
.34571 .08208 L
.34648 .08208 L
.34648 .16187 L
F
.804 .522 .247 r
.34571 .16187 m
.34571 .08208 L
.34648 .08208 L
.34648 .16187 L
s
1 .894 .882 r
.34648 .16187 m
.34648 .08242 L
.34689 .08242 L
.34689 .16187 L
F
.804 .522 .247 r
.34648 .16187 m
.34648 .08242 L
.34689 .08242 L
.34689 .16187 L
s
1 .894 .882 r
.34689 .16187 m
.34689 .08266 L
.34779 .08266 L
.34779 .16187 L
F
.804 .522 .247 r
.34689 .16187 m
.34689 .08266 L
.34779 .08266 L
.34779 .16187 L
s
1 .894 .882 r
.34779 .16187 m
.34779 .08297 L
.3482 .08297 L
.3482 .16187 L
F
.804 .522 .247 r
.34779 .16187 m
.34779 .08297 L
.3482 .08297 L
.3482 .16187 L
s
1 .894 .882 r
.3482 .16187 m
.3482 .08312 L
.34916 .08312 L
.34916 .16187 L
F
.804 .522 .247 r
.3482 .16187 m
.3482 .08312 L
.34916 .08312 L
.34916 .16187 L
s
1 .894 .882 r
.34916 .16187 m
.34916 .08358 L
.34971 .08358 L
.34971 .16187 L
F
.804 .522 .247 r
.34916 .16187 m
.34916 .08358 L
.34971 .08358 L
.34971 .16187 L
s
1 .894 .882 r
.34971 .16187 m
.34971 .08398 L
.35061 .08398 L
.35061 .16187 L
F
.804 .522 .247 r
.34971 .16187 m
.34971 .08398 L
.35061 .08398 L
.35061 .16187 L
s
1 .894 .882 r
.35061 .16187 m
.35061 .08407 L
.35097 .08407 L
.35097 .16187 L
F
.804 .522 .247 r
.35061 .16187 m
.35061 .08407 L
.35097 .08407 L
.35097 .16187 L
s
1 .894 .882 r
.35097 .16187 m
.35097 .08428 L
.3514 .08428 L
.3514 .16187 L
F
.804 .522 .247 r
.35097 .16187 m
.35097 .08428 L
.3514 .08428 L
.3514 .16187 L
s
1 .894 .882 r
.3514 .16187 m
.3514 .08454 L
.35185 .08454 L
.35185 .16187 L
F
.804 .522 .247 r
.3514 .16187 m
.3514 .08454 L
.35185 .08454 L
.35185 .16187 L
s
1 .894 .882 r
.35185 .16187 m
.35185 .08463 L
.35265 .08463 L
.35265 .16187 L
F
.804 .522 .247 r
.35185 .16187 m
.35185 .08463 L
.35265 .08463 L
.35265 .16187 L
s
1 .894 .882 r
.35265 .16187 m
.35265 .08497 L
.35313 .08497 L
.35313 .16187 L
F
.804 .522 .247 r
.35265 .16187 m
.35265 .08497 L
.35313 .08497 L
.35313 .16187 L
s
1 .894 .882 r
.35313 .16187 m
.35313 .08518 L
.3537 .08518 L
.3537 .16187 L
F
.804 .522 .247 r
.35313 .16187 m
.35313 .08518 L
.3537 .08518 L
.3537 .16187 L
s
1 .894 .882 r
.3537 .16187 m
.3537 .08535 L
.3546 .08535 L
.3546 .16187 L
F
.804 .522 .247 r
.3537 .16187 m
.3537 .08535 L
.3546 .08535 L
.3546 .16187 L
s
1 .894 .882 r
.3546 .16187 m
.3546 .08609 L
.3556 .08609 L
.3556 .16187 L
F
.804 .522 .247 r
.3546 .16187 m
.3546 .08609 L
.3556 .08609 L
.3556 .16187 L
s
1 .894 .882 r
.3556 .16187 m
.3556 .08628 L
.35595 .08628 L
.35595 .16187 L
F
.804 .522 .247 r
.3556 .16187 m
.3556 .08628 L
.35595 .08628 L
.35595 .16187 L
s
1 .894 .882 r
.35595 .16187 m
.35595 .08638 L
.35632 .08638 L
.35632 .16187 L
F
.804 .522 .247 r
.35595 .16187 m
.35595 .08638 L
.35632 .08638 L
.35632 .16187 L
s
1 .894 .882 r
.35632 .16187 m
.35632 .08655 L
.35669 .08655 L
.35669 .16187 L
F
.804 .522 .247 r
.35632 .16187 m
.35632 .08655 L
.35669 .08655 L
.35669 .16187 L
s
1 .894 .882 r
.35669 .16187 m
.35669 .08698 L
.35767 .08698 L
.35767 .16187 L
F
.804 .522 .247 r
.35669 .16187 m
.35669 .08698 L
.35767 .08698 L
.35767 .16187 L
s
1 .894 .882 r
.35767 .16187 m
.35767 .08712 L
.35843 .08712 L
.35843 .16187 L
F
.804 .522 .247 r
.35767 .16187 m
.35767 .08712 L
.35843 .08712 L
.35843 .16187 L
s
1 .894 .882 r
.35843 .16187 m
.35843 .08756 L
.35927 .08756 L
.35927 .16187 L
F
.804 .522 .247 r
.35843 .16187 m
.35843 .08756 L
.35927 .08756 L
.35927 .16187 L
s
1 .894 .882 r
.35927 .16187 m
.35927 .08794 L
.36011 .08794 L
.36011 .16187 L
F
.804 .522 .247 r
.35927 .16187 m
.35927 .08794 L
.36011 .08794 L
.36011 .16187 L
s
1 .894 .882 r
.36011 .16187 m
.36011 .08818 L
.36064 .08818 L
.36064 .16187 L
F
.804 .522 .247 r
.36011 .16187 m
.36011 .08818 L
.36064 .08818 L
.36064 .16187 L
s
1 .894 .882 r
.36064 .16187 m
.36064 .08835 L
.36126 .08835 L
.36126 .16187 L
F
.804 .522 .247 r
.36064 .16187 m
.36064 .08835 L
.36126 .08835 L
.36126 .16187 L
s
1 .894 .882 r
.36126 .16187 m
.36126 .08863 L
.36164 .08863 L
.36164 .16187 L
F
.804 .522 .247 r
.36126 .16187 m
.36126 .08863 L
.36164 .08863 L
.36164 .16187 L
s
1 .894 .882 r
.36164 .16187 m
.36164 .08903 L
.36238 .08903 L
.36238 .16187 L
F
.804 .522 .247 r
.36164 .16187 m
.36164 .08903 L
.36238 .08903 L
.36238 .16187 L
s
1 .894 .882 r
.36238 .16187 m
.36238 .08933 L
.36305 .08933 L
.36305 .16187 L
F
.804 .522 .247 r
.36238 .16187 m
.36238 .08933 L
.36305 .08933 L
.36305 .16187 L
s
1 .894 .882 r
.36305 .16187 m
.36305 .08945 L
.36357 .08945 L
.36357 .16187 L
F
.804 .522 .247 r
.36305 .16187 m
.36305 .08945 L
.36357 .08945 L
.36357 .16187 L
s
1 .894 .882 r
.36357 .16187 m
.36357 .08979 L
.36403 .08979 L
.36403 .16187 L
F
.804 .522 .247 r
.36357 .16187 m
.36357 .08979 L
.36403 .08979 L
.36403 .16187 L
s
1 .894 .882 r
.36403 .16187 m
.36403 .08983 L
.36453 .08983 L
.36453 .16187 L
F
.804 .522 .247 r
.36403 .16187 m
.36403 .08983 L
.36453 .08983 L
.36453 .16187 L
s
1 .894 .882 r
.36453 .16187 m
.36453 .09036 L
.36533 .09036 L
.36533 .16187 L
F
.804 .522 .247 r
.36453 .16187 m
.36453 .09036 L
.36533 .09036 L
.36533 .16187 L
s
1 .894 .882 r
.36533 .16187 m
.36533 .09059 L
.3658 .09059 L
.3658 .16187 L
F
.804 .522 .247 r
.36533 .16187 m
.36533 .09059 L
.3658 .09059 L
.3658 .16187 L
s
1 .894 .882 r
.3658 .16187 m
.3658 .09065 L
.36613 .09065 L
.36613 .16187 L
F
.804 .522 .247 r
.3658 .16187 m
.3658 .09065 L
.36613 .09065 L
.36613 .16187 L
s
1 .894 .882 r
.36613 .16187 m
.36613 .09077 L
.3665 .09077 L
.3665 .16187 L
F
.804 .522 .247 r
.36613 .16187 m
.36613 .09077 L
.3665 .09077 L
.3665 .16187 L
s
1 .894 .882 r
.3665 .16187 m
.3665 .09121 L
.36753 .09121 L
.36753 .16187 L
F
.804 .522 .247 r
.3665 .16187 m
.3665 .09121 L
.36753 .09121 L
.36753 .16187 L
s
1 .894 .882 r
.36753 .16187 m
.36753 .09161 L
.36856 .09161 L
.36856 .16187 L
F
.804 .522 .247 r
.36753 .16187 m
.36753 .09161 L
.36856 .09161 L
.36856 .16187 L
s
1 .894 .882 r
.36856 .16187 m
.36856 .09217 L
.36936 .09217 L
.36936 .16187 L
F
.804 .522 .247 r
.36856 .16187 m
.36856 .09217 L
.36936 .09217 L
.36936 .16187 L
s
1 .894 .882 r
.36936 .16187 m
.36936 .09243 L
.36986 .09243 L
.36986 .16187 L
F
.804 .522 .247 r
.36936 .16187 m
.36936 .09243 L
.36986 .09243 L
.36986 .16187 L
s
1 .894 .882 r
.36986 .16187 m
.36986 .09255 L
.37021 .09255 L
.37021 .16187 L
F
.804 .522 .247 r
.36986 .16187 m
.36986 .09255 L
.37021 .09255 L
.37021 .16187 L
s
1 .894 .882 r
.37021 .16187 m
.37021 .09289 L
.37119 .09289 L
.37119 .16187 L
F
.804 .522 .247 r
.37021 .16187 m
.37021 .09289 L
.37119 .09289 L
.37119 .16187 L
s
1 .894 .882 r
.37119 .16187 m
.37119 .09316 L
.37193 .09316 L
.37193 .16187 L
F
.804 .522 .247 r
.37119 .16187 m
.37119 .09316 L
.37193 .09316 L
.37193 .16187 L
s
1 .894 .882 r
.37193 .16187 m
.37193 .09345 L
.37238 .09345 L
.37238 .16187 L
F
.804 .522 .247 r
.37193 .16187 m
.37193 .09345 L
.37238 .09345 L
.37238 .16187 L
s
1 .894 .882 r
.37238 .16187 m
.37238 .09373 L
.37278 .09373 L
.37278 .16187 L
F
.804 .522 .247 r
.37238 .16187 m
.37238 .09373 L
.37278 .09373 L
.37278 .16187 L
s
1 .894 .882 r
.37278 .16187 m
.37278 .09386 L
.37331 .09386 L
.37331 .16187 L
F
.804 .522 .247 r
.37278 .16187 m
.37278 .09386 L
.37331 .09386 L
.37331 .16187 L
s
1 .894 .882 r
.37331 .16187 m
.37331 .09437 L
.37425 .09437 L
.37425 .16187 L
F
.804 .522 .247 r
.37331 .16187 m
.37331 .09437 L
.37425 .09437 L
.37425 .16187 L
s
1 .894 .882 r
.37425 .16187 m
.37425 .09467 L
.37489 .09467 L
.37489 .16187 L
F
.804 .522 .247 r
.37425 .16187 m
.37425 .09467 L
.37489 .09467 L
.37489 .16187 L
s
1 .894 .882 r
.37489 .16187 m
.37489 .09495 L
.37579 .09495 L
.37579 .16187 L
F
.804 .522 .247 r
.37489 .16187 m
.37489 .09495 L
.37579 .09495 L
.37579 .16187 L
s
1 .894 .882 r
.37579 .16187 m
.37579 .09531 L
.37674 .09531 L
.37674 .16187 L
F
.804 .522 .247 r
.37579 .16187 m
.37579 .09531 L
.37674 .09531 L
.37674 .16187 L
s
1 .894 .882 r
.37674 .16187 m
.37674 .09586 L
.37761 .09586 L
.37761 .16187 L
F
.804 .522 .247 r
.37674 .16187 m
.37674 .09586 L
.37761 .09586 L
.37761 .16187 L
s
1 .894 .882 r
.37761 .16187 m
.37761 .09599 L
.37855 .09599 L
.37855 .16187 L
F
.804 .522 .247 r
.37761 .16187 m
.37761 .09599 L
.37855 .09599 L
.37855 .16187 L
s
1 .894 .882 r
.37855 .16187 m
.37855 .09658 L
.37909 .09658 L
.37909 .16187 L
F
.804 .522 .247 r
.37855 .16187 m
.37855 .09658 L
.37909 .09658 L
.37909 .16187 L
s
1 .894 .882 r
.37909 .16187 m
.37909 .09671 L
.37984 .09671 L
.37984 .16187 L
F
.804 .522 .247 r
.37909 .16187 m
.37909 .09671 L
.37984 .09671 L
.37984 .16187 L
s
1 .894 .882 r
.37984 .16187 m
.37984 .09728 L
.38055 .09728 L
.38055 .16187 L
F
.804 .522 .247 r
.37984 .16187 m
.37984 .09728 L
.38055 .09728 L
.38055 .16187 L
s
1 .894 .882 r
.38055 .16187 m
.38055 .09733 L
.3813 .09733 L
.3813 .16187 L
F
.804 .522 .247 r
.38055 .16187 m
.38055 .09733 L
.3813 .09733 L
.3813 .16187 L
s
1 .894 .882 r
.3813 .16187 m
.3813 .09799 L
.38208 .09799 L
.38208 .16187 L
F
.804 .522 .247 r
.3813 .16187 m
.3813 .09799 L
.38208 .09799 L
.38208 .16187 L
s
1 .894 .882 r
.38208 .16187 m
.38208 .09811 L
.38266 .09811 L
.38266 .16187 L
F
.804 .522 .247 r
.38208 .16187 m
.38208 .09811 L
.38266 .09811 L
.38266 .16187 L
s
1 .894 .882 r
.38266 .16187 m
.38266 .09851 L
.38335 .09851 L
.38335 .16187 L
F
.804 .522 .247 r
.38266 .16187 m
.38266 .09851 L
.38335 .09851 L
.38335 .16187 L
s
1 .894 .882 r
.38335 .16187 m
.38335 .09862 L
.38405 .09862 L
.38405 .16187 L
F
.804 .522 .247 r
.38335 .16187 m
.38335 .09862 L
.38405 .09862 L
.38405 .16187 L
s
1 .894 .882 r
.38405 .16187 m
.38405 .09905 L
.38483 .09905 L
.38483 .16187 L
F
.804 .522 .247 r
.38405 .16187 m
.38405 .09905 L
.38483 .09905 L
.38483 .16187 L
s
1 .894 .882 r
.38483 .16187 m
.38483 .09954 L
.38542 .09954 L
.38542 .16187 L
F
.804 .522 .247 r
.38483 .16187 m
.38483 .09954 L
.38542 .09954 L
.38542 .16187 L
s
1 .894 .882 r
.38542 .16187 m
.38542 .09992 L
.38635 .09992 L
.38635 .16187 L
F
.804 .522 .247 r
.38542 .16187 m
.38542 .09992 L
.38635 .09992 L
.38635 .16187 L
s
1 .894 .882 r
.38635 .16187 m
.38635 .10002 L
.38685 .10002 L
.38685 .16187 L
F
.804 .522 .247 r
.38635 .16187 m
.38635 .10002 L
.38685 .10002 L
.38685 .16187 L
s
1 .894 .882 r
.38685 .16187 m
.38685 .10044 L
.38759 .10044 L
.38759 .16187 L
F
.804 .522 .247 r
.38685 .16187 m
.38685 .10044 L
.38759 .10044 L
.38759 .16187 L
s
1 .894 .882 r
.38759 .16187 m
.38759 .10065 L
.38825 .10065 L
.38825 .16187 L
F
.804 .522 .247 r
.38759 .16187 m
.38759 .10065 L
.38825 .10065 L
.38825 .16187 L
s
1 .894 .882 r
.38825 .16187 m
.38825 .101 L
.38874 .101 L
.38874 .16187 L
F
.804 .522 .247 r
.38825 .16187 m
.38825 .101 L
.38874 .101 L
.38874 .16187 L
s
1 .894 .882 r
.38874 .16187 m
.38874 .10125 L
.3891 .10125 L
.3891 .16187 L
F
.804 .522 .247 r
.38874 .16187 m
.38874 .10125 L
.3891 .10125 L
.3891 .16187 L
s
1 .894 .882 r
.3891 .16187 m
.3891 .10151 L
.38976 .10151 L
.38976 .16187 L
F
.804 .522 .247 r
.3891 .16187 m
.3891 .10151 L
.38976 .10151 L
.38976 .16187 L
s
1 .894 .882 r
.38976 .16187 m
.38976 .10176 L
.39019 .10176 L
.39019 .16187 L
F
.804 .522 .247 r
.38976 .16187 m
.38976 .10176 L
.39019 .10176 L
.39019 .16187 L
s
1 .894 .882 r
.39019 .16187 m
.39019 .10196 L
.39078 .10196 L
.39078 .16187 L
F
.804 .522 .247 r
.39019 .16187 m
.39019 .10196 L
.39078 .10196 L
.39078 .16187 L
s
1 .894 .882 r
.39078 .16187 m
.39078 .10238 L
.39154 .10238 L
.39154 .16187 L
F
.804 .522 .247 r
.39078 .16187 m
.39078 .10238 L
.39154 .10238 L
.39154 .16187 L
s
1 .894 .882 r
.39154 .16187 m
.39154 .10249 L
.39232 .10249 L
.39232 .16187 L
F
.804 .522 .247 r
.39154 .16187 m
.39154 .10249 L
.39232 .10249 L
.39232 .16187 L
s
1 .894 .882 r
.39232 .16187 m
.39232 .1029 L
.39284 .1029 L
.39284 .16187 L
F
.804 .522 .247 r
.39232 .16187 m
.39232 .1029 L
.39284 .1029 L
.39284 .16187 L
s
1 .894 .882 r
.39284 .16187 m
.39284 .10335 L
.3936 .10335 L
.3936 .16187 L
F
.804 .522 .247 r
.39284 .16187 m
.39284 .10335 L
.3936 .10335 L
.3936 .16187 L
s
1 .894 .882 r
.3936 .16187 m
.3936 .10371 L
.39445 .10371 L
.39445 .16187 L
F
.804 .522 .247 r
.3936 .16187 m
.3936 .10371 L
.39445 .10371 L
.39445 .16187 L
s
1 .894 .882 r
.39445 .16187 m
.39445 .10392 L
.39501 .10392 L
.39501 .16187 L
F
.804 .522 .247 r
.39445 .16187 m
.39445 .10392 L
.39501 .10392 L
.39501 .16187 L
s
1 .894 .882 r
.39501 .16187 m
.39501 .10452 L
.39581 .10452 L
.39581 .16187 L
F
.804 .522 .247 r
.39501 .16187 m
.39501 .10452 L
.39581 .10452 L
.39581 .16187 L
s
1 .894 .882 r
.39581 .16187 m
.39581 .10465 L
.39617 .10465 L
.39617 .16187 L
F
.804 .522 .247 r
.39581 .16187 m
.39581 .10465 L
.39617 .10465 L
.39617 .16187 L
s
1 .894 .882 r
.39617 .16187 m
.39617 .1048 L
.39658 .1048 L
.39658 .16187 L
F
.804 .522 .247 r
.39617 .16187 m
.39617 .1048 L
.39658 .1048 L
.39658 .16187 L
s
1 .894 .882 r
.39658 .16187 m
.39658 .10499 L
.3974 .10499 L
.3974 .16187 L
F
.804 .522 .247 r
.39658 .16187 m
.39658 .10499 L
.3974 .10499 L
.3974 .16187 L
s
1 .894 .882 r
.3974 .16187 m
.3974 .10545 L
.39793 .10545 L
.39793 .16187 L
F
.804 .522 .247 r
.3974 .16187 m
.3974 .10545 L
.39793 .10545 L
.39793 .16187 L
s
1 .894 .882 r
.39793 .16187 m
.39793 .10556 L
.39863 .10556 L
.39863 .16187 L
F
.804 .522 .247 r
.39793 .16187 m
.39793 .10556 L
.39863 .10556 L
.39863 .16187 L
s
1 .894 .882 r
.39863 .16187 m
.39863 .10607 L
.39938 .10607 L
.39938 .16187 L
F
.804 .522 .247 r
.39863 .16187 m
.39863 .10607 L
.39938 .10607 L
.39938 .16187 L
s
1 .894 .882 r
.39938 .16187 m
.39938 .10641 L
.39974 .10641 L
.39974 .16187 L
F
.804 .522 .247 r
.39938 .16187 m
.39938 .10641 L
.39974 .10641 L
.39974 .16187 L
s
1 .894 .882 r
.39974 .16187 m
.39974 .10677 L
.4007 .10677 L
.4007 .16187 L
F
.804 .522 .247 r
.39974 .16187 m
.39974 .10677 L
.4007 .10677 L
.4007 .16187 L
s
1 .894 .882 r
.4007 .16187 m
.4007 .10699 L
.40151 .10699 L
.40151 .16187 L
F
.804 .522 .247 r
.4007 .16187 m
.4007 .10699 L
.40151 .10699 L
.40151 .16187 L
s
1 .894 .882 r
.40151 .16187 m
.40151 .10741 L
.40207 .10741 L
.40207 .16187 L
F
.804 .522 .247 r
.40151 .16187 m
.40151 .10741 L
.40207 .10741 L
.40207 .16187 L
s
1 .894 .882 r
.40207 .16187 m
.40207 .10768 L
.40272 .10768 L
.40272 .16187 L
F
.804 .522 .247 r
.40207 .16187 m
.40207 .10768 L
.40272 .10768 L
.40272 .16187 L
s
1 .894 .882 r
.40272 .16187 m
.40272 .10805 L
.40334 .10805 L
.40334 .16187 L
F
.804 .522 .247 r
.40272 .16187 m
.40272 .10805 L
.40334 .10805 L
.40334 .16187 L
s
1 .894 .882 r
.40334 .16187 m
.40334 .10846 L
.40397 .10846 L
.40397 .16187 L
F
.804 .522 .247 r
.40334 .16187 m
.40334 .10846 L
.40397 .10846 L
.40397 .16187 L
s
1 .894 .882 r
.40397 .16187 m
.40397 .1087 L
.40447 .1087 L
.40447 .16187 L
F
.804 .522 .247 r
.40397 .16187 m
.40397 .1087 L
.40447 .1087 L
.40447 .16187 L
s
1 .894 .882 r
.40447 .16187 m
.40447 .10885 L
.40478 .10885 L
.40478 .16187 L
F
.804 .522 .247 r
.40447 .16187 m
.40447 .10885 L
.40478 .10885 L
.40478 .16187 L
s
1 .894 .882 r
.40478 .16187 m
.40478 .10911 L
.40528 .10911 L
.40528 .16187 L
F
.804 .522 .247 r
.40478 .16187 m
.40478 .10911 L
.40528 .10911 L
.40528 .16187 L
s
1 .894 .882 r
.40528 .16187 m
.40528 .10921 L
.40563 .10921 L
.40563 .16187 L
F
.804 .522 .247 r
.40528 .16187 m
.40528 .10921 L
.40563 .10921 L
.40563 .16187 L
s
1 .894 .882 r
.40563 .16187 m
.40563 .10934 L
.40641 .10934 L
.40641 .16187 L
F
.804 .522 .247 r
.40563 .16187 m
.40563 .10934 L
.40641 .10934 L
.40641 .16187 L
s
1 .894 .882 r
.40641 .16187 m
.40641 .10989 L
.40697 .10989 L
.40697 .16187 L
F
.804 .522 .247 r
.40641 .16187 m
.40641 .10989 L
.40697 .10989 L
.40697 .16187 L
s
1 .894 .882 r
.40697 .16187 m
.40697 .1103 L
.40798 .1103 L
.40798 .16187 L
F
.804 .522 .247 r
.40697 .16187 m
.40697 .1103 L
.40798 .1103 L
.40798 .16187 L
s
1 .894 .882 r
.40798 .16187 m
.40798 .1107 L
.40861 .1107 L
.40861 .16187 L
F
.804 .522 .247 r
.40798 .16187 m
.40798 .1107 L
.40861 .1107 L
.40861 .16187 L
s
1 .894 .882 r
.40861 .16187 m
.40861 .11101 L
.40957 .11101 L
.40957 .16187 L
F
.804 .522 .247 r
.40861 .16187 m
.40861 .11101 L
.40957 .11101 L
.40957 .16187 L
s
1 .894 .882 r
.40957 .16187 m
.40957 .11151 L
.41061 .11151 L
.41061 .16187 L
F
.804 .522 .247 r
.40957 .16187 m
.40957 .11151 L
.41061 .11151 L
.41061 .16187 L
s
1 .894 .882 r
.41061 .16187 m
.41061 .11197 L
.41113 .11197 L
.41113 .16187 L
F
.804 .522 .247 r
.41061 .16187 m
.41061 .11197 L
.41113 .11197 L
.41113 .16187 L
s
1 .894 .882 r
.41113 .16187 m
.41113 .11233 L
.41171 .11233 L
.41171 .16187 L
F
.804 .522 .247 r
.41113 .16187 m
.41113 .11233 L
.41171 .11233 L
.41171 .16187 L
s
1 .894 .882 r
.41171 .16187 m
.41171 .11274 L
.41258 .11274 L
.41258 .16187 L
F
.804 .522 .247 r
.41171 .16187 m
.41171 .11274 L
.41258 .11274 L
.41258 .16187 L
s
1 .894 .882 r
.41258 .16187 m
.41258 .11284 L
.4131 .11284 L
.4131 .16187 L
F
.804 .522 .247 r
.41258 .16187 m
.41258 .11284 L
.4131 .11284 L
.4131 .16187 L
s
1 .894 .882 r
.4131 .16187 m
.4131 .11306 L
.41341 .11306 L
.41341 .16187 L
F
.804 .522 .247 r
.4131 .16187 m
.4131 .11306 L
.41341 .11306 L
.41341 .16187 L
s
1 .894 .882 r
.41341 .16187 m
.41341 .11361 L
.41432 .11361 L
.41432 .16187 L
F
.804 .522 .247 r
.41341 .16187 m
.41341 .11361 L
.41432 .11361 L
.41432 .16187 L
s
1 .894 .882 r
.41432 .16187 m
.41432 .11376 L
.41475 .11376 L
.41475 .16187 L
F
.804 .522 .247 r
.41432 .16187 m
.41432 .11376 L
.41475 .11376 L
.41475 .16187 L
s
1 .894 .882 r
.41475 .16187 m
.41475 .11395 L
.41522 .11395 L
.41522 .16187 L
F
.804 .522 .247 r
.41475 .16187 m
.41475 .11395 L
.41522 .11395 L
.41522 .16187 L
s
1 .894 .882 r
.41522 .16187 m
.41522 .11419 L
.41561 .11419 L
.41561 .16187 L
F
.804 .522 .247 r
.41522 .16187 m
.41522 .11419 L
.41561 .11419 L
.41561 .16187 L
s
1 .894 .882 r
.41561 .16187 m
.41561 .11445 L
.41601 .11445 L
.41601 .16187 L
F
.804 .522 .247 r
.41561 .16187 m
.41561 .11445 L
.41601 .11445 L
.41601 .16187 L
s
1 .894 .882 r
.41601 .16187 m
.41601 .11497 L
.41692 .11497 L
.41692 .16187 L
F
.804 .522 .247 r
.41601 .16187 m
.41601 .11497 L
.41692 .11497 L
.41692 .16187 L
s
1 .894 .882 r
.41692 .16187 m
.41692 .11539 L
.41778 .11539 L
.41778 .16187 L
F
.804 .522 .247 r
.41692 .16187 m
.41692 .11539 L
.41778 .11539 L
.41778 .16187 L
s
1 .894 .882 r
.41778 .16187 m
.41778 .11573 L
.41858 .11573 L
.41858 .16187 L
F
.804 .522 .247 r
.41778 .16187 m
.41778 .11573 L
.41858 .11573 L
.41858 .16187 L
s
1 .894 .882 r
.41858 .16187 m
.41858 .11616 L
.41939 .11616 L
.41939 .16187 L
F
.804 .522 .247 r
.41858 .16187 m
.41858 .11616 L
.41939 .11616 L
.41939 .16187 L
s
1 .894 .882 r
.41939 .16187 m
.41939 .11631 L
.42011 .11631 L
.42011 .16187 L
F
.804 .522 .247 r
.41939 .16187 m
.41939 .11631 L
.42011 .11631 L
.42011 .16187 L
s
1 .894 .882 r
.42011 .16187 m
.42011 .11672 L
.42097 .11672 L
.42097 .16187 L
F
.804 .522 .247 r
.42011 .16187 m
.42011 .11672 L
.42097 .11672 L
.42097 .16187 L
s
1 .894 .882 r
.42097 .16187 m
.42097 .11735 L
.42159 .11735 L
.42159 .16187 L
F
.804 .522 .247 r
.42097 .16187 m
.42097 .11735 L
.42159 .11735 L
.42159 .16187 L
s
1 .894 .882 r
.42159 .16187 m
.42159 .11754 L
.42235 .11754 L
.42235 .16187 L
F
.804 .522 .247 r
.42159 .16187 m
.42159 .11754 L
.42235 .11754 L
.42235 .16187 L
s
1 .894 .882 r
.42235 .16187 m
.42235 .11783 L
.42333 .11783 L
.42333 .16187 L
F
.804 .522 .247 r
.42235 .16187 m
.42235 .11783 L
.42333 .11783 L
.42333 .16187 L
s
1 .894 .882 r
.42333 .16187 m
.42333 .11847 L
.42394 .11847 L
.42394 .16187 L
F
.804 .522 .247 r
.42333 .16187 m
.42333 .11847 L
.42394 .11847 L
.42394 .16187 L
s
1 .894 .882 r
.42394 .16187 m
.42394 .11869 L
.42458 .11869 L
.42458 .16187 L
F
.804 .522 .247 r
.42394 .16187 m
.42394 .11869 L
.42458 .11869 L
.42458 .16187 L
s
1 .894 .882 r
.42458 .16187 m
.42458 .11911 L
.42502 .11911 L
.42502 .16187 L
F
.804 .522 .247 r
.42458 .16187 m
.42458 .11911 L
.42502 .11911 L
.42502 .16187 L
s
1 .894 .882 r
.42502 .16187 m
.42502 .11929 L
.42535 .11929 L
.42535 .16187 L
F
.804 .522 .247 r
.42502 .16187 m
.42502 .11929 L
.42535 .11929 L
.42535 .16187 L
s
1 .894 .882 r
.42535 .16187 m
.42535 .11939 L
.42596 .11939 L
.42596 .16187 L
F
.804 .522 .247 r
.42535 .16187 m
.42535 .11939 L
.42596 .11939 L
.42596 .16187 L
s
1 .894 .882 r
.42596 .16187 m
.42596 .1198 L
.42638 .1198 L
.42638 .16187 L
F
.804 .522 .247 r
.42596 .16187 m
.42596 .1198 L
.42638 .1198 L
.42638 .16187 L
s
1 .894 .882 r
.42638 .16187 m
.42638 .12027 L
.42729 .12027 L
.42729 .16187 L
F
.804 .522 .247 r
.42638 .16187 m
.42638 .12027 L
.42729 .12027 L
.42729 .16187 L
s
1 .894 .882 r
.42729 .16187 m
.42729 .12056 L
.42779 .12056 L
.42779 .16187 L
F
.804 .522 .247 r
.42729 .16187 m
.42729 .12056 L
.42779 .12056 L
.42779 .16187 L
s
1 .894 .882 r
.42779 .16187 m
.42779 .12082 L
.42819 .12082 L
.42819 .16187 L
F
.804 .522 .247 r
.42779 .16187 m
.42779 .12082 L
.42819 .12082 L
.42819 .16187 L
s
1 .894 .882 r
.42819 .16187 m
.42819 .12096 L
.42861 .12096 L
.42861 .16187 L
F
.804 .522 .247 r
.42819 .16187 m
.42819 .12096 L
.42861 .12096 L
.42861 .16187 L
s
1 .894 .882 r
.42861 .16187 m
.42861 .12157 L
.42964 .12157 L
.42964 .16187 L
F
.804 .522 .247 r
.42861 .16187 m
.42861 .12157 L
.42964 .12157 L
.42964 .16187 L
s
1 .894 .882 r
.42964 .16187 m
.42964 .12167 L
.43002 .12167 L
.43002 .16187 L
F
.804 .522 .247 r
.42964 .16187 m
.42964 .12167 L
.43002 .12167 L
.43002 .16187 L
s
1 .894 .882 r
.43002 .16187 m
.43002 .12215 L
.43098 .12215 L
.43098 .16187 L
F
.804 .522 .247 r
.43002 .16187 m
.43002 .12215 L
.43098 .12215 L
.43098 .16187 L
s
1 .894 .882 r
.43098 .16187 m
.43098 .12236 L
.43132 .12236 L
.43132 .16187 L
F
.804 .522 .247 r
.43098 .16187 m
.43098 .12236 L
.43132 .12236 L
.43132 .16187 L
s
1 .894 .882 r
.43132 .16187 m
.43132 .12265 L
.43226 .12265 L
.43226 .16187 L
F
.804 .522 .247 r
.43132 .16187 m
.43132 .12265 L
.43226 .12265 L
.43226 .16187 L
s
1 .894 .882 r
.43226 .16187 m
.43226 .1231 L
.43276 .1231 L
.43276 .16187 L
F
.804 .522 .247 r
.43226 .16187 m
.43226 .1231 L
.43276 .1231 L
.43276 .16187 L
s
1 .894 .882 r
.43276 .16187 m
.43276 .12342 L
.43318 .12342 L
.43318 .16187 L
F
.804 .522 .247 r
.43276 .16187 m
.43276 .12342 L
.43318 .12342 L
.43318 .16187 L
s
1 .894 .882 r
.43318 .16187 m
.43318 .12366 L
.43375 .12366 L
.43375 .16187 L
F
.804 .522 .247 r
.43318 .16187 m
.43318 .12366 L
.43375 .12366 L
.43375 .16187 L
s
1 .894 .882 r
.43375 .16187 m
.43375 .12391 L
.4342 .12391 L
.4342 .16187 L
F
.804 .522 .247 r
.43375 .16187 m
.43375 .12391 L
.4342 .12391 L
.4342 .16187 L
s
1 .894 .882 r
.4342 .16187 m
.4342 .12416 L
.43501 .12416 L
.43501 .16187 L
F
.804 .522 .247 r
.4342 .16187 m
.4342 .12416 L
.43501 .12416 L
.43501 .16187 L
s
1 .894 .882 r
.43501 .16187 m
.43501 .12464 L
.4356 .12464 L
.4356 .16187 L
F
.804 .522 .247 r
.43501 .16187 m
.43501 .12464 L
.4356 .12464 L
.4356 .16187 L
s
1 .894 .882 r
.4356 .16187 m
.4356 .12518 L
.4366 .12518 L
.4366 .16187 L
F
.804 .522 .247 r
.4356 .16187 m
.4356 .12518 L
.4366 .12518 L
.4366 .16187 L
s
1 .894 .882 r
.4366 .16187 m
.4366 .12538 L
.43732 .12538 L
.43732 .16187 L
F
.804 .522 .247 r
.4366 .16187 m
.4366 .12538 L
.43732 .12538 L
.43732 .16187 L
s
1 .894 .882 r
.43732 .16187 m
.43732 .1258 L
.43818 .1258 L
.43818 .16187 L
F
.804 .522 .247 r
.43732 .16187 m
.43732 .1258 L
.43818 .1258 L
.43818 .16187 L
s
1 .894 .882 r
.43818 .16187 m
.43818 .12618 L
.4392 .12618 L
.4392 .16187 L
F
.804 .522 .247 r
.43818 .16187 m
.43818 .12618 L
.4392 .12618 L
.4392 .16187 L
s
1 .894 .882 r
.4392 .16187 m
.4392 .12689 L
.43987 .12689 L
.43987 .16187 L
F
.804 .522 .247 r
.4392 .16187 m
.4392 .12689 L
.43987 .12689 L
.43987 .16187 L
s
1 .894 .882 r
.43987 .16187 m
.43987 .12721 L
.44045 .12721 L
.44045 .16187 L
F
.804 .522 .247 r
.43987 .16187 m
.43987 .12721 L
.44045 .12721 L
.44045 .16187 L
s
1 .894 .882 r
.44045 .16187 m
.44045 .12765 L
.4413 .12765 L
.4413 .16187 L
F
.804 .522 .247 r
.44045 .16187 m
.44045 .12765 L
.4413 .12765 L
.4413 .16187 L
s
1 .894 .882 r
.4413 .16187 m
.4413 .12819 L
.44202 .12819 L
.44202 .16187 L
F
.804 .522 .247 r
.4413 .16187 m
.4413 .12819 L
.44202 .12819 L
.44202 .16187 L
s
1 .894 .882 r
.44202 .16187 m
.44202 .1285 L
.44258 .1285 L
.44258 .16187 L
F
.804 .522 .247 r
.44202 .16187 m
.44202 .1285 L
.44258 .1285 L
.44258 .16187 L
s
1 .894 .882 r
.44258 .16187 m
.44258 .12879 L
.44329 .12879 L
.44329 .16187 L
F
.804 .522 .247 r
.44258 .16187 m
.44258 .12879 L
.44329 .12879 L
.44329 .16187 L
s
1 .894 .882 r
.44329 .16187 m
.44329 .1292 L
.44395 .1292 L
.44395 .16187 L
F
.804 .522 .247 r
.44329 .16187 m
.44329 .1292 L
.44395 .1292 L
.44395 .16187 L
s
1 .894 .882 r
.44395 .16187 m
.44395 .1296 L
.44458 .1296 L
.44458 .16187 L
F
.804 .522 .247 r
.44395 .16187 m
.44395 .1296 L
.44458 .1296 L
.44458 .16187 L
s
1 .894 .882 r
.44458 .16187 m
.44458 .12969 L
.44503 .12969 L
.44503 .16187 L
F
.804 .522 .247 r
.44458 .16187 m
.44458 .12969 L
.44503 .12969 L
.44503 .16187 L
s
1 .894 .882 r
.44503 .16187 m
.44503 .13015 L
.44575 .13015 L
.44575 .16187 L
F
.804 .522 .247 r
.44503 .16187 m
.44503 .13015 L
.44575 .13015 L
.44575 .16187 L
s
1 .894 .882 r
.44575 .16187 m
.44575 .13038 L
.44634 .13038 L
.44634 .16187 L
F
.804 .522 .247 r
.44575 .16187 m
.44575 .13038 L
.44634 .13038 L
.44634 .16187 L
s
1 .894 .882 r
.44634 .16187 m
.44634 .13067 L
.44705 .13067 L
.44705 .16187 L
F
.804 .522 .247 r
.44634 .16187 m
.44634 .13067 L
.44705 .13067 L
.44705 .16187 L
s
1 .894 .882 r
.44705 .16187 m
.44705 .13118 L
.44746 .13118 L
.44746 .16187 L
F
.804 .522 .247 r
.44705 .16187 m
.44705 .13118 L
.44746 .13118 L
.44746 .16187 L
s
1 .894 .882 r
.44746 .16187 m
.44746 .13136 L
.44827 .13136 L
.44827 .16187 L
F
.804 .522 .247 r
.44746 .16187 m
.44746 .13136 L
.44827 .13136 L
.44827 .16187 L
s
1 .894 .882 r
.44827 .16187 m
.44827 .13184 L
.44867 .13184 L
.44867 .16187 L
F
.804 .522 .247 r
.44827 .16187 m
.44827 .13184 L
.44867 .13184 L
.44867 .16187 L
s
1 .894 .882 r
.44867 .16187 m
.44867 .13201 L
.44928 .13201 L
.44928 .16187 L
F
.804 .522 .247 r
.44867 .16187 m
.44867 .13201 L
.44928 .13201 L
.44928 .16187 L
s
1 .894 .882 r
.44928 .16187 m
.44928 .13234 L
.45014 .13234 L
.45014 .16187 L
F
.804 .522 .247 r
.44928 .16187 m
.44928 .13234 L
.45014 .13234 L
.45014 .16187 L
s
1 .894 .882 r
.45014 .16187 m
.45014 .13297 L
.45082 .13297 L
.45082 .16187 L
F
.804 .522 .247 r
.45014 .16187 m
.45014 .13297 L
.45082 .13297 L
.45082 .16187 L
s
1 .894 .882 r
.45082 .16187 m
.45082 .13326 L
.45145 .13326 L
.45145 .16187 L
F
.804 .522 .247 r
.45082 .16187 m
.45082 .13326 L
.45145 .13326 L
.45145 .16187 L
s
1 .894 .882 r
.45145 .16187 m
.45145 .13354 L
.45177 .13354 L
.45177 .16187 L
F
.804 .522 .247 r
.45145 .16187 m
.45145 .13354 L
.45177 .13354 L
.45177 .16187 L
s
1 .894 .882 r
.45177 .16187 m
.45177 .13384 L
.45268 .13384 L
.45268 .16187 L
F
.804 .522 .247 r
.45177 .16187 m
.45177 .13384 L
.45268 .13384 L
.45268 .16187 L
s
1 .894 .882 r
.45268 .16187 m
.45268 .13439 L
.45368 .13439 L
.45368 .16187 L
F
.804 .522 .247 r
.45268 .16187 m
.45268 .13439 L
.45368 .13439 L
.45368 .16187 L
s
1 .894 .882 r
.45368 .16187 m
.45368 .13478 L
.45447 .13478 L
.45447 .16187 L
F
.804 .522 .247 r
.45368 .16187 m
.45368 .13478 L
.45447 .13478 L
.45447 .16187 L
s
1 .894 .882 r
.45447 .16187 m
.45447 .13522 L
.45481 .13522 L
.45481 .16187 L
F
.804 .522 .247 r
.45447 .16187 m
.45447 .13522 L
.45481 .13522 L
.45481 .16187 L
s
1 .894 .882 r
.45481 .16187 m
.45481 .13556 L
.45536 .13556 L
.45536 .16187 L
F
.804 .522 .247 r
.45481 .16187 m
.45481 .13556 L
.45536 .13556 L
.45536 .16187 L
s
1 .894 .882 r
.45536 .16187 m
.45536 .1356 L
.45608 .1356 L
.45608 .16187 L
F
.804 .522 .247 r
.45536 .16187 m
.45536 .1356 L
.45608 .1356 L
.45608 .16187 L
s
1 .894 .882 r
.45608 .16187 m
.45608 .13638 L
.45707 .13638 L
.45707 .16187 L
F
.804 .522 .247 r
.45608 .16187 m
.45608 .13638 L
.45707 .13638 L
.45707 .16187 L
s
1 .894 .882 r
.45707 .16187 m
.45707 .13684 L
.45772 .13684 L
.45772 .16187 L
F
.804 .522 .247 r
.45707 .16187 m
.45707 .13684 L
.45772 .13684 L
.45772 .16187 L
s
1 .894 .882 r
.45772 .16187 m
.45772 .13692 L
.45875 .13692 L
.45875 .16187 L
F
.804 .522 .247 r
.45772 .16187 m
.45772 .13692 L
.45875 .13692 L
.45875 .16187 L
s
1 .894 .882 r
.45875 .16187 m
.45875 .13754 L
.45907 .13754 L
.45907 .16187 L
F
.804 .522 .247 r
.45875 .16187 m
.45875 .13754 L
.45907 .13754 L
.45907 .16187 L
s
1 .894 .882 r
.45907 .16187 m
.45907 .13799 L
.45971 .13799 L
.45971 .16187 L
F
.804 .522 .247 r
.45907 .16187 m
.45907 .13799 L
.45971 .13799 L
.45971 .16187 L
s
1 .894 .882 r
.45971 .16187 m
.45971 .13818 L
.46004 .13818 L
.46004 .16187 L
F
.804 .522 .247 r
.45971 .16187 m
.45971 .13818 L
.46004 .13818 L
.46004 .16187 L
s
1 .894 .882 r
.46004 .16187 m
.46004 .13857 L
.46093 .13857 L
.46093 .16187 L
F
.804 .522 .247 r
.46004 .16187 m
.46004 .13857 L
.46093 .13857 L
.46093 .16187 L
s
1 .894 .882 r
.46093 .16187 m
.46093 .13894 L
.46157 .13894 L
.46157 .16187 L
F
.804 .522 .247 r
.46093 .16187 m
.46093 .13894 L
.46157 .13894 L
.46157 .16187 L
s
1 .894 .882 r
.46157 .16187 m
.46157 .13917 L
.46193 .13917 L
.46193 .16187 L
F
.804 .522 .247 r
.46157 .16187 m
.46157 .13917 L
.46193 .13917 L
.46193 .16187 L
s
1 .894 .882 r
.46193 .16187 m
.46193 .13949 L
.46259 .13949 L
.46259 .16187 L
F
.804 .522 .247 r
.46193 .16187 m
.46193 .13949 L
.46259 .13949 L
.46259 .16187 L
s
1 .894 .882 r
.46259 .16187 m
.46259 .13999 L
.46338 .13999 L
.46338 .16187 L
F
.804 .522 .247 r
.46259 .16187 m
.46259 .13999 L
.46338 .13999 L
.46338 .16187 L
s
1 .894 .882 r
.46338 .16187 m
.46338 .14021 L
.46424 .14021 L
.46424 .16187 L
F
.804 .522 .247 r
.46338 .16187 m
.46338 .14021 L
.46424 .14021 L
.46424 .16187 L
s
1 .894 .882 r
.46424 .16187 m
.46424 .1409 L
.46523 .1409 L
.46523 .16187 L
F
.804 .522 .247 r
.46424 .16187 m
.46424 .1409 L
.46523 .1409 L
.46523 .16187 L
s
1 .894 .882 r
.46523 .16187 m
.46523 .14119 L
.46559 .14119 L
.46559 .16187 L
F
.804 .522 .247 r
.46523 .16187 m
.46523 .14119 L
.46559 .14119 L
.46559 .16187 L
s
1 .894 .882 r
.46559 .16187 m
.46559 .1416 L
.46655 .1416 L
.46655 .16187 L
F
.804 .522 .247 r
.46559 .16187 m
.46559 .1416 L
.46655 .1416 L
.46655 .16187 L
s
1 .894 .882 r
.46655 .16187 m
.46655 .14204 L
.46704 .14204 L
.46704 .16187 L
F
.804 .522 .247 r
.46655 .16187 m
.46655 .14204 L
.46704 .14204 L
.46704 .16187 L
s
1 .894 .882 r
.46704 .16187 m
.46704 .14256 L
.46772 .14256 L
.46772 .16187 L
F
.804 .522 .247 r
.46704 .16187 m
.46704 .14256 L
.46772 .14256 L
.46772 .16187 L
s
1 .894 .882 r
.46772 .16187 m
.46772 .14265 L
.46807 .14265 L
.46807 .16187 L
F
.804 .522 .247 r
.46772 .16187 m
.46772 .14265 L
.46807 .14265 L
.46807 .16187 L
s
1 .894 .882 r
.46807 .16187 m
.46807 .14298 L
.46843 .14298 L
.46843 .16187 L
F
.804 .522 .247 r
.46807 .16187 m
.46807 .14298 L
.46843 .14298 L
.46843 .16187 L
s
1 .894 .882 r
.46843 .16187 m
.46843 .14326 L
.46897 .14326 L
.46897 .16187 L
F
.804 .522 .247 r
.46843 .16187 m
.46843 .14326 L
.46897 .14326 L
.46897 .16187 L
s
1 .894 .882 r
.46897 .16187 m
.46897 .14361 L
.46988 .14361 L
.46988 .16187 L
F
.804 .522 .247 r
.46897 .16187 m
.46897 .14361 L
.46988 .14361 L
.46988 .16187 L
s
1 .894 .882 r
.46988 .16187 m
.46988 .14393 L
.4702 .14393 L
.4702 .16187 L
F
.804 .522 .247 r
.46988 .16187 m
.46988 .14393 L
.4702 .14393 L
.4702 .16187 L
s
1 .894 .882 r
.4702 .16187 m
.4702 .14447 L
.47105 .14447 L
.47105 .16187 L
F
.804 .522 .247 r
.4702 .16187 m
.4702 .14447 L
.47105 .14447 L
.47105 .16187 L
s
1 .894 .882 r
.47105 .16187 m
.47105 .1449 L
.4719 .1449 L
.4719 .16187 L
F
.804 .522 .247 r
.47105 .16187 m
.47105 .1449 L
.4719 .1449 L
.4719 .16187 L
s
1 .894 .882 r
.4719 .16187 m
.4719 .14548 L
.47286 .14548 L
.47286 .16187 L
F
.804 .522 .247 r
.4719 .16187 m
.4719 .14548 L
.47286 .14548 L
.47286 .16187 L
s
1 .894 .882 r
.47286 .16187 m
.47286 .14585 L
.47356 .14585 L
.47356 .16187 L
F
.804 .522 .247 r
.47286 .16187 m
.47286 .14585 L
.47356 .14585 L
.47356 .16187 L
s
1 .894 .882 r
.47356 .16187 m
.47356 .14642 L
.47442 .14642 L
.47442 .16187 L
F
.804 .522 .247 r
.47356 .16187 m
.47356 .14642 L
.47442 .14642 L
.47442 .16187 L
s
1 .894 .882 r
.47442 .16187 m
.47442 .14668 L
.47526 .14668 L
.47526 .16187 L
F
.804 .522 .247 r
.47442 .16187 m
.47442 .14668 L
.47526 .14668 L
.47526 .16187 L
s
1 .894 .882 r
.47526 .16187 m
.47526 .14731 L
.47589 .14731 L
.47589 .16187 L
F
.804 .522 .247 r
.47526 .16187 m
.47526 .14731 L
.47589 .14731 L
.47589 .16187 L
s
1 .894 .882 r
.47589 .16187 m
.47589 .14767 L
.47657 .14767 L
.47657 .16187 L
F
.804 .522 .247 r
.47589 .16187 m
.47589 .14767 L
.47657 .14767 L
.47657 .16187 L
s
1 .894 .882 r
.47657 .16187 m
.47657 .14784 L
.47757 .14784 L
.47757 .16187 L
F
.804 .522 .247 r
.47657 .16187 m
.47657 .14784 L
.47757 .14784 L
.47757 .16187 L
s
1 .894 .882 r
.47757 .16187 m
.47757 .14857 L
.47808 .14857 L
.47808 .16187 L
F
.804 .522 .247 r
.47757 .16187 m
.47757 .14857 L
.47808 .14857 L
.47808 .16187 L
s
1 .894 .882 r
.47808 .16187 m
.47808 .14878 L
.47866 .14878 L
.47866 .16187 L
F
.804 .522 .247 r
.47808 .16187 m
.47808 .14878 L
.47866 .14878 L
.47866 .16187 L
s
1 .894 .882 r
.47866 .16187 m
.47866 .14902 L
.47901 .14902 L
.47901 .16187 L
F
.804 .522 .247 r
.47866 .16187 m
.47866 .14902 L
.47901 .14902 L
.47901 .16187 L
s
1 .894 .882 r
.47901 .16187 m
.47901 .14931 L
.47952 .14931 L
.47952 .16187 L
F
.804 .522 .247 r
.47901 .16187 m
.47901 .14931 L
.47952 .14931 L
.47952 .16187 L
s
1 .894 .882 r
.47952 .16187 m
.47952 .14971 L
.48021 .14971 L
.48021 .16187 L
F
.804 .522 .247 r
.47952 .16187 m
.47952 .14971 L
.48021 .14971 L
.48021 .16187 L
s
1 .894 .882 r
.48021 .16187 m
.48021 .15022 L
.48083 .15022 L
.48083 .16187 L
F
.804 .522 .247 r
.48021 .16187 m
.48021 .15022 L
.48083 .15022 L
.48083 .16187 L
s
1 .894 .882 r
.48083 .16187 m
.48083 .15033 L
.48185 .15033 L
.48185 .16187 L
F
.804 .522 .247 r
.48083 .16187 m
.48083 .15033 L
.48185 .15033 L
.48185 .16187 L
s
1 .894 .882 r
.48185 .16187 m
.48185 .15087 L
.48244 .15087 L
.48244 .16187 L
F
.804 .522 .247 r
.48185 .16187 m
.48185 .15087 L
.48244 .15087 L
.48244 .16187 L
s
1 .894 .882 r
.48244 .16187 m
.48244 .15125 L
.48295 .15125 L
.48295 .16187 L
F
.804 .522 .247 r
.48244 .16187 m
.48244 .15125 L
.48295 .15125 L
.48295 .16187 L
s
1 .894 .882 r
.48295 .16187 m
.48295 .15209 L
.48392 .15209 L
.48392 .16187 L
F
.804 .522 .247 r
.48295 .16187 m
.48295 .15209 L
.48392 .15209 L
.48392 .16187 L
s
1 .894 .882 r
.48392 .16187 m
.48392 .15259 L
.48491 .15259 L
.48491 .16187 L
F
.804 .522 .247 r
.48392 .16187 m
.48392 .15259 L
.48491 .15259 L
.48491 .16187 L
s
1 .894 .882 r
.48491 .16187 m
.48491 .15273 L
.48544 .15273 L
.48544 .16187 L
F
.804 .522 .247 r
.48491 .16187 m
.48491 .15273 L
.48544 .15273 L
.48544 .16187 L
s
1 .894 .882 r
.48544 .16187 m
.48544 .15318 L
.48645 .15318 L
.48645 .16187 L
F
.804 .522 .247 r
.48544 .16187 m
.48544 .15318 L
.48645 .15318 L
.48645 .16187 L
s
1 .894 .882 r
.48645 .16187 m
.48645 .15371 L
.48683 .15371 L
.48683 .16187 L
F
.804 .522 .247 r
.48645 .16187 m
.48645 .15371 L
.48683 .15371 L
.48683 .16187 L
s
1 .894 .882 r
.48683 .16187 m
.48683 .15403 L
.4878 .15403 L
.4878 .16187 L
F
.804 .522 .247 r
.48683 .16187 m
.48683 .15403 L
.4878 .15403 L
.4878 .16187 L
s
1 .894 .882 r
.4878 .16187 m
.4878 .15452 L
.48852 .15452 L
.48852 .16187 L
F
.804 .522 .247 r
.4878 .16187 m
.4878 .15452 L
.48852 .15452 L
.48852 .16187 L
s
1 .894 .882 r
.48852 .16187 m
.48852 .155 L
.489 .155 L
.489 .16187 L
F
.804 .522 .247 r
.48852 .16187 m
.48852 .155 L
.489 .155 L
.489 .16187 L
s
1 .894 .882 r
.489 .16187 m
.489 .1553 L
.48944 .1553 L
.48944 .16187 L
F
.804 .522 .247 r
.489 .16187 m
.489 .1553 L
.48944 .1553 L
.48944 .16187 L
s
1 .894 .882 r
.48944 .16187 m
.48944 .15564 L
.49002 .15564 L
.49002 .16187 L
F
.804 .522 .247 r
.48944 .16187 m
.48944 .15564 L
.49002 .15564 L
.49002 .16187 L
s
1 .894 .882 r
.49002 .16187 m
.49002 .15596 L
.49092 .15596 L
.49092 .16187 L
F
.804 .522 .247 r
.49002 .16187 m
.49002 .15596 L
.49092 .15596 L
.49092 .16187 L
s
1 .894 .882 r
.49092 .16187 m
.49092 .15635 L
.4916 .15635 L
.4916 .16187 L
F
.804 .522 .247 r
.49092 .16187 m
.49092 .15635 L
.4916 .15635 L
.4916 .16187 L
s
1 .894 .882 r
.4916 .16187 m
.4916 .15706 L
.49245 .15706 L
.49245 .16187 L
F
.804 .522 .247 r
.4916 .16187 m
.4916 .15706 L
.49245 .15706 L
.49245 .16187 L
s
1 .894 .882 r
.49245 .16187 m
.49245 .1577 L
.49337 .1577 L
.49337 .16187 L
F
.804 .522 .247 r
.49245 .16187 m
.49245 .1577 L
.49337 .1577 L
.49337 .16187 L
s
1 .894 .882 r
.49337 .16187 m
.49337 .15791 L
.49431 .15791 L
.49431 .16187 L
F
.804 .522 .247 r
.49337 .16187 m
.49337 .15791 L
.49431 .15791 L
.49431 .16187 L
s
1 .894 .882 r
.49431 .16187 m
.49431 .15846 L
.49479 .15846 L
.49479 .16187 L
F
.804 .522 .247 r
.49431 .16187 m
.49431 .15846 L
.49479 .15846 L
.49479 .16187 L
s
1 .894 .882 r
.49479 .16187 m
.49479 .15874 L
.49537 .15874 L
.49537 .16187 L
F
.804 .522 .247 r
.49479 .16187 m
.49479 .15874 L
.49537 .15874 L
.49537 .16187 L
s
1 .894 .882 r
.49537 .16187 m
.49537 .15934 L
.49626 .15934 L
.49626 .16187 L
F
.804 .522 .247 r
.49537 .16187 m
.49537 .15934 L
.49626 .15934 L
.49626 .16187 L
s
1 .894 .882 r
.49626 .16187 m
.49626 .15991 L
.49699 .15991 L
.49699 .16187 L
F
.804 .522 .247 r
.49626 .16187 m
.49626 .15991 L
.49699 .15991 L
.49699 .16187 L
s
1 .894 .882 r
.49699 .16187 m
.49699 .16039 L
.49782 .16039 L
.49782 .16187 L
F
.804 .522 .247 r
.49699 .16187 m
.49699 .16039 L
.49782 .16039 L
.49782 .16187 L
s
1 .894 .882 r
.49782 .16187 m
.49782 .16071 L
.49881 .16071 L
.49881 .16187 L
F
.804 .522 .247 r
.49782 .16187 m
.49782 .16071 L
.49881 .16071 L
.49881 .16187 L
s
1 .894 .882 r
.49881 .16187 m
.49881 .1614 L
.49972 .1614 L
.49972 .16187 L
F
.804 .522 .247 r
.49881 .16187 m
.49881 .1614 L
.49972 .1614 L
.49972 .16187 L
s
.678 .847 .902 r
.49972 .16187 m
.49972 .16191 L
.50018 .16191 L
.50018 .16187 L
F
.2 .63 .79 r
.49972 .16187 m
.49972 .16191 L
.50018 .16191 L
.50018 .16187 L
s
.678 .847 .902 r
.50018 .16187 m
.50018 .16221 L
.50081 .16221 L
.50081 .16187 L
F
.2 .63 .79 r
.50018 .16187 m
.50018 .16221 L
.50081 .16221 L
.50081 .16187 L
s
.678 .847 .902 r
.50081 .16187 m
.50081 .16243 L
.50113 .16243 L
.50113 .16187 L
F
.2 .63 .79 r
.50081 .16187 m
.50081 .16243 L
.50113 .16243 L
.50113 .16187 L
s
.678 .847 .902 r
.50113 .16187 m
.50113 .16295 L
.50209 .16295 L
.50209 .16187 L
F
.2 .63 .79 r
.50113 .16187 m
.50113 .16295 L
.50209 .16295 L
.50209 .16187 L
s
.678 .847 .902 r
.50209 .16187 m
.50209 .16354 L
.50306 .16354 L
.50306 .16187 L
F
.2 .63 .79 r
.50209 .16187 m
.50209 .16354 L
.50306 .16354 L
.50306 .16187 L
s
.678 .847 .902 r
.50306 .16187 m
.50306 .16389 L
.5037 .16389 L
.5037 .16187 L
F
.2 .63 .79 r
.50306 .16187 m
.50306 .16389 L
.5037 .16389 L
.5037 .16187 L
s
.678 .847 .902 r
.5037 .16187 m
.5037 .16471 L
.50469 .16471 L
.50469 .16187 L
F
.2 .63 .79 r
.5037 .16187 m
.5037 .16471 L
.50469 .16471 L
.50469 .16187 L
s
.678 .847 .902 r
.50469 .16187 m
.50469 .16498 L
.50572 .16498 L
.50572 .16187 L
F
.2 .63 .79 r
.50469 .16187 m
.50469 .16498 L
.50572 .16498 L
.50572 .16187 L
s
.678 .847 .902 r
.50572 .16187 m
.50572 .16556 L
.50627 .16556 L
.50627 .16187 L
F
.2 .63 .79 r
.50572 .16187 m
.50572 .16556 L
.50627 .16556 L
.50627 .16187 L
s
.678 .847 .902 r
.50627 .16187 m
.50627 .16601 L
.50674 .16601 L
.50674 .16187 L
F
.2 .63 .79 r
.50627 .16187 m
.50627 .16601 L
.50674 .16601 L
.50674 .16187 L
s
.678 .847 .902 r
.50674 .16187 m
.50674 .16622 L
.5076 .16622 L
.5076 .16187 L
F
.2 .63 .79 r
.50674 .16187 m
.50674 .16622 L
.5076 .16622 L
.5076 .16187 L
s
.678 .847 .902 r
.5076 .16187 m
.5076 .16692 L
.50836 .16692 L
.50836 .16187 L
F
.2 .63 .79 r
.5076 .16187 m
.5076 .16692 L
.50836 .16692 L
.50836 .16187 L
s
.678 .847 .902 r
.50836 .16187 m
.50836 .1671 L
.50905 .1671 L
.50905 .16187 L
F
.2 .63 .79 r
.50836 .16187 m
.50836 .1671 L
.50905 .1671 L
.50905 .16187 L
s
.678 .847 .902 r
.50905 .16187 m
.50905 .16788 L
.50988 .16788 L
.50988 .16187 L
F
.2 .63 .79 r
.50905 .16187 m
.50905 .16788 L
.50988 .16788 L
.50988 .16187 L
s
.678 .847 .902 r
.50988 .16187 m
.50988 .16816 L
.51019 .16816 L
.51019 .16187 L
F
.2 .63 .79 r
.50988 .16187 m
.50988 .16816 L
.51019 .16816 L
.51019 .16187 L
s
.678 .847 .902 r
.51019 .16187 m
.51019 .16869 L
.51106 .16869 L
.51106 .16187 L
F
.2 .63 .79 r
.51019 .16187 m
.51019 .16869 L
.51106 .16869 L
.51106 .16187 L
s
.678 .847 .902 r
.51106 .16187 m
.51106 .16921 L
.51185 .16921 L
.51185 .16187 L
F
.2 .63 .79 r
.51106 .16187 m
.51106 .16921 L
.51185 .16921 L
.51185 .16187 L
s
.678 .847 .902 r
.51185 .16187 m
.51185 .16945 L
.51251 .16945 L
.51251 .16187 L
F
.2 .63 .79 r
.51185 .16187 m
.51185 .16945 L
.51251 .16945 L
.51251 .16187 L
s
.678 .847 .902 r
.51251 .16187 m
.51251 .16991 L
.51329 .16991 L
.51329 .16187 L
F
.2 .63 .79 r
.51251 .16187 m
.51251 .16991 L
.51329 .16991 L
.51329 .16187 L
s
.678 .847 .902 r
.51329 .16187 m
.51329 .17035 L
.5143 .17035 L
.5143 .16187 L
F
.2 .63 .79 r
.51329 .16187 m
.51329 .17035 L
.5143 .17035 L
.5143 .16187 L
s
.678 .847 .902 r
.5143 .16187 m
.5143 .17085 L
.51466 .17085 L
.51466 .16187 L
F
.2 .63 .79 r
.5143 .16187 m
.5143 .17085 L
.51466 .17085 L
.51466 .16187 L
s
.678 .847 .902 r
.51466 .16187 m
.51466 .17143 L
.51553 .17143 L
.51553 .16187 L
F
.2 .63 .79 r
.51466 .16187 m
.51466 .17143 L
.51553 .17143 L
.51553 .16187 L
s
.678 .847 .902 r
.51553 .16187 m
.51553 .17168 L
.51636 .17168 L
.51636 .16187 L
F
.2 .63 .79 r
.51553 .16187 m
.51553 .17168 L
.51636 .17168 L
.51636 .16187 L
s
.678 .847 .902 r
.51636 .16187 m
.51636 .17235 L
.51676 .17235 L
.51676 .16187 L
F
.2 .63 .79 r
.51636 .16187 m
.51636 .17235 L
.51676 .17235 L
.51676 .16187 L
s
.678 .847 .902 r
.51676 .16187 m
.51676 .1726 L
.51771 .1726 L
.51771 .16187 L
F
.2 .63 .79 r
.51676 .16187 m
.51676 .1726 L
.51771 .1726 L
.51771 .16187 L
s
.678 .847 .902 r
.51771 .16187 m
.51771 .17303 L
.51826 .17303 L
.51826 .16187 L
F
.2 .63 .79 r
.51771 .16187 m
.51771 .17303 L
.51826 .17303 L
.51826 .16187 L
s
.678 .847 .902 r
.51826 .16187 m
.51826 .17378 L
.51907 .17378 L
.51907 .16187 L
F
.2 .63 .79 r
.51826 .16187 m
.51826 .17378 L
.51907 .17378 L
.51907 .16187 L
s
.678 .847 .902 r
.51907 .16187 m
.51907 .17392 L
.51955 .17392 L
.51955 .16187 L
F
.2 .63 .79 r
.51907 .16187 m
.51907 .17392 L
.51955 .17392 L
.51955 .16187 L
s
.678 .847 .902 r
.51955 .16187 m
.51955 .17464 L
.52056 .17464 L
.52056 .16187 L
F
.2 .63 .79 r
.51955 .16187 m
.51955 .17464 L
.52056 .17464 L
.52056 .16187 L
s
.678 .847 .902 r
.52056 .16187 m
.52056 .17529 L
.52151 .17529 L
.52151 .16187 L
F
.2 .63 .79 r
.52056 .16187 m
.52056 .17529 L
.52151 .17529 L
.52151 .16187 L
s
.678 .847 .902 r
.52151 .16187 m
.52151 .17596 L
.52237 .17596 L
.52237 .16187 L
F
.2 .63 .79 r
.52151 .16187 m
.52151 .17596 L
.52237 .17596 L
.52237 .16187 L
s
.678 .847 .902 r
.52237 .16187 m
.52237 .17627 L
.52285 .17627 L
.52285 .16187 L
F
.2 .63 .79 r
.52237 .16187 m
.52237 .17627 L
.52285 .17627 L
.52285 .16187 L
s
.678 .847 .902 r
.52285 .16187 m
.52285 .17646 L
.52363 .17646 L
.52363 .16187 L
F
.2 .63 .79 r
.52285 .16187 m
.52285 .17646 L
.52363 .17646 L
.52363 .16187 L
s
.678 .847 .902 r
.52363 .16187 m
.52363 .17729 L
.52441 .17729 L
.52441 .16187 L
F
.2 .63 .79 r
.52363 .16187 m
.52363 .17729 L
.52441 .17729 L
.52441 .16187 L
s
.678 .847 .902 r
.52441 .16187 m
.52441 .17746 L
.52472 .17746 L
.52472 .16187 L
F
.2 .63 .79 r
.52441 .16187 m
.52441 .17746 L
.52472 .17746 L
.52472 .16187 L
s
.678 .847 .902 r
.52472 .16187 m
.52472 .17761 L
.52548 .17761 L
.52548 .16187 L
F
.2 .63 .79 r
.52472 .16187 m
.52472 .17761 L
.52548 .17761 L
.52548 .16187 L
s
.678 .847 .902 r
.52548 .16187 m
.52548 .17809 L
.52588 .17809 L
.52588 .16187 L
F
.2 .63 .79 r
.52548 .16187 m
.52548 .17809 L
.52588 .17809 L
.52588 .16187 L
s
.678 .847 .902 r
.52588 .16187 m
.52588 .17842 L
.52686 .17842 L
.52686 .16187 L
F
.2 .63 .79 r
.52588 .16187 m
.52588 .17842 L
.52686 .17842 L
.52686 .16187 L
s
.678 .847 .902 r
.52686 .16187 m
.52686 .17913 L
.52717 .17913 L
.52717 .16187 L
F
.2 .63 .79 r
.52686 .16187 m
.52686 .17913 L
.52717 .17913 L
.52717 .16187 L
s
.678 .847 .902 r
.52717 .16187 m
.52717 .17932 L
.5281 .17932 L
.5281 .16187 L
F
.2 .63 .79 r
.52717 .16187 m
.52717 .17932 L
.5281 .17932 L
.5281 .16187 L
s
.678 .847 .902 r
.5281 .16187 m
.5281 .17989 L
.52874 .17989 L
.52874 .16187 L
F
.2 .63 .79 r
.5281 .16187 m
.5281 .17989 L
.52874 .17989 L
.52874 .16187 L
s
.678 .847 .902 r
.52874 .16187 m
.52874 .1805 L
.52938 .1805 L
.52938 .16187 L
F
.2 .63 .79 r
.52874 .16187 m
.52874 .1805 L
.52938 .1805 L
.52938 .16187 L
s
.678 .847 .902 r
.52938 .16187 m
.52938 .18079 L
.52995 .18079 L
.52995 .16187 L
F
.2 .63 .79 r
.52938 .16187 m
.52938 .18079 L
.52995 .18079 L
.52995 .16187 L
s
.678 .847 .902 r
.52995 .16187 m
.52995 .181 L
.5309 .181 L
.5309 .16187 L
F
.2 .63 .79 r
.52995 .16187 m
.52995 .181 L
.5309 .181 L
.5309 .16187 L
s
.678 .847 .902 r
.5309 .16187 m
.5309 .18168 L
.53148 .18168 L
.53148 .16187 L
F
.2 .63 .79 r
.5309 .16187 m
.5309 .18168 L
.53148 .18168 L
.53148 .16187 L
s
.678 .847 .902 r
.53148 .16187 m
.53148 .18205 L
.53228 .18205 L
.53228 .16187 L
F
.2 .63 .79 r
.53148 .16187 m
.53148 .18205 L
.53228 .18205 L
.53228 .16187 L
s
.678 .847 .902 r
.53228 .16187 m
.53228 .18272 L
.53307 .18272 L
.53307 .16187 L
F
.2 .63 .79 r
.53228 .16187 m
.53228 .18272 L
.53307 .18272 L
.53307 .16187 L
s
.678 .847 .902 r
.53307 .16187 m
.53307 .18318 L
.53392 .18318 L
.53392 .16187 L
F
.2 .63 .79 r
.53307 .16187 m
.53307 .18318 L
.53392 .18318 L
.53392 .16187 L
s
.678 .847 .902 r
.53392 .16187 m
.53392 .184 L
.5346 .184 L
.5346 .16187 L
F
.2 .63 .79 r
.53392 .16187 m
.53392 .184 L
.5346 .184 L
.5346 .16187 L
s
.678 .847 .902 r
.5346 .16187 m
.5346 .18407 L
.53516 .18407 L
.53516 .16187 L
F
.2 .63 .79 r
.5346 .16187 m
.5346 .18407 L
.53516 .18407 L
.53516 .16187 L
s
.678 .847 .902 r
.53516 .16187 m
.53516 .18483 L
.53617 .18483 L
.53617 .16187 L
F
.2 .63 .79 r
.53516 .16187 m
.53516 .18483 L
.53617 .18483 L
.53617 .16187 L
s
.678 .847 .902 r
.53617 .16187 m
.53617 .18515 L
.53685 .18515 L
.53685 .16187 L
F
.2 .63 .79 r
.53617 .16187 m
.53617 .18515 L
.53685 .18515 L
.53685 .16187 L
s
.678 .847 .902 r
.53685 .16187 m
.53685 .18565 L
.53755 .18565 L
.53755 .16187 L
F
.2 .63 .79 r
.53685 .16187 m
.53685 .18565 L
.53755 .18565 L
.53755 .16187 L
s
.678 .847 .902 r
.53755 .16187 m
.53755 .18616 L
.5382 .18616 L
.5382 .16187 L
F
.2 .63 .79 r
.53755 .16187 m
.53755 .18616 L
.5382 .18616 L
.5382 .16187 L
s
.678 .847 .902 r
.5382 .16187 m
.5382 .18665 L
.53866 .18665 L
.53866 .16187 L
F
.2 .63 .79 r
.5382 .16187 m
.5382 .18665 L
.53866 .18665 L
.53866 .16187 L
s
.678 .847 .902 r
.53866 .16187 m
.53866 .18686 L
.53917 .18686 L
.53917 .16187 L
F
.2 .63 .79 r
.53866 .16187 m
.53866 .18686 L
.53917 .18686 L
.53917 .16187 L
s
.678 .847 .902 r
.53917 .16187 m
.53917 .18708 L
.54013 .18708 L
.54013 .16187 L
F
.2 .63 .79 r
.53917 .16187 m
.53917 .18708 L
.54013 .18708 L
.54013 .16187 L
s
.678 .847 .902 r
.54013 .16187 m
.54013 .18801 L
.54103 .18801 L
.54103 .16187 L
F
.2 .63 .79 r
.54013 .16187 m
.54013 .18801 L
.54103 .18801 L
.54103 .16187 L
s
.678 .847 .902 r
.54103 .16187 m
.54103 .18836 L
.54149 .18836 L
.54149 .16187 L
F
.2 .63 .79 r
.54103 .16187 m
.54103 .18836 L
.54149 .18836 L
.54149 .16187 L
s
.678 .847 .902 r
.54149 .16187 m
.54149 .18876 L
.54228 .18876 L
.54228 .16187 L
F
.2 .63 .79 r
.54149 .16187 m
.54149 .18876 L
.54228 .18876 L
.54228 .16187 L
s
.678 .847 .902 r
.54228 .16187 m
.54228 .18963 L
.54316 .18963 L
.54316 .16187 L
F
.2 .63 .79 r
.54228 .16187 m
.54228 .18963 L
.54316 .18963 L
.54316 .16187 L
s
.678 .847 .902 r
.54316 .16187 m
.54316 .18994 L
.54411 .18994 L
.54411 .16187 L
F
.2 .63 .79 r
.54316 .16187 m
.54316 .18994 L
.54411 .18994 L
.54411 .16187 L
s
.678 .847 .902 r
.54411 .16187 m
.54411 .19044 L
.54456 .19044 L
.54456 .16187 L
F
.2 .63 .79 r
.54411 .16187 m
.54411 .19044 L
.54456 .19044 L
.54456 .16187 L
s
.678 .847 .902 r
.54456 .16187 m
.54456 .19127 L
.54547 .19127 L
.54547 .16187 L
F
.2 .63 .79 r
.54456 .16187 m
.54456 .19127 L
.54547 .19127 L
.54547 .16187 L
s
.678 .847 .902 r
.54547 .16187 m
.54547 .19147 L
.54601 .19147 L
.54601 .16187 L
F
.2 .63 .79 r
.54547 .16187 m
.54547 .19147 L
.54601 .19147 L
.54601 .16187 L
s
.678 .847 .902 r
.54601 .16187 m
.54601 .19189 L
.54663 .19189 L
.54663 .16187 L
F
.2 .63 .79 r
.54601 .16187 m
.54601 .19189 L
.54663 .19189 L
.54663 .16187 L
s
.678 .847 .902 r
.54663 .16187 m
.54663 .19249 L
.54755 .19249 L
.54755 .16187 L
F
.2 .63 .79 r
.54663 .16187 m
.54663 .19249 L
.54755 .19249 L
.54755 .16187 L
s
.678 .847 .902 r
.54755 .16187 m
.54755 .19332 L
.54854 .19332 L
.54854 .16187 L
F
.2 .63 .79 r
.54755 .16187 m
.54755 .19332 L
.54854 .19332 L
.54854 .16187 L
s
.678 .847 .902 r
.54854 .16187 m
.54854 .19353 L
.54953 .19353 L
.54953 .16187 L
F
.2 .63 .79 r
.54854 .16187 m
.54854 .19353 L
.54953 .19353 L
.54953 .16187 L
s
.678 .847 .902 r
.54953 .16187 m
.54953 .19428 L
.55039 .19428 L
.55039 .16187 L
F
.2 .63 .79 r
.54953 .16187 m
.54953 .19428 L
.55039 .19428 L
.55039 .16187 L
s
.678 .847 .902 r
.55039 .16187 m
.55039 .19471 L
.55084 .19471 L
.55084 .16187 L
F
.2 .63 .79 r
.55039 .16187 m
.55039 .19471 L
.55084 .19471 L
.55084 .16187 L
s
.678 .847 .902 r
.55084 .16187 m
.55084 .19514 L
.55128 .19514 L
.55128 .16187 L
F
.2 .63 .79 r
.55084 .16187 m
.55084 .19514 L
.55128 .19514 L
.55128 .16187 L
s
.678 .847 .902 r
.55128 .16187 m
.55128 .19538 L
.55191 .19538 L
.55191 .16187 L
F
.2 .63 .79 r
.55128 .16187 m
.55128 .19538 L
.55191 .19538 L
.55191 .16187 L
s
.678 .847 .902 r
.55191 .16187 m
.55191 .1958 L
.55252 .1958 L
.55252 .16187 L
F
.2 .63 .79 r
.55191 .16187 m
.55191 .1958 L
.55252 .1958 L
.55252 .16187 L
s
.678 .847 .902 r
.55252 .16187 m
.55252 .19629 L
.55299 .19629 L
.55299 .16187 L
F
.2 .63 .79 r
.55252 .16187 m
.55252 .19629 L
.55299 .19629 L
.55299 .16187 L
s
.678 .847 .902 r
.55299 .16187 m
.55299 .19665 L
.55379 .19665 L
.55379 .16187 L
F
.2 .63 .79 r
.55299 .16187 m
.55299 .19665 L
.55379 .19665 L
.55379 .16187 L
s
.678 .847 .902 r
.55379 .16187 m
.55379 .19764 L
.55475 .19764 L
.55475 .16187 L
F
.2 .63 .79 r
.55379 .16187 m
.55379 .19764 L
.55475 .19764 L
.55475 .16187 L
s
.678 .847 .902 r
.55475 .16187 m
.55475 .19823 L
.55575 .19823 L
.55575 .16187 L
F
.2 .63 .79 r
.55475 .16187 m
.55475 .19823 L
.55575 .19823 L
.55575 .16187 L
s
.678 .847 .902 r
.55575 .16187 m
.55575 .19852 L
.55607 .19852 L
.55607 .16187 L
F
.2 .63 .79 r
.55575 .16187 m
.55575 .19852 L
.55607 .19852 L
.55607 .16187 L
s
.678 .847 .902 r
.55607 .16187 m
.55607 .19856 L
.55666 .19856 L
.55666 .16187 L
F
.2 .63 .79 r
.55607 .16187 m
.55607 .19856 L
.55666 .19856 L
.55666 .16187 L
s
.678 .847 .902 r
.55666 .16187 m
.55666 .19918 L
.55697 .19918 L
.55697 .16187 L
F
.2 .63 .79 r
.55666 .16187 m
.55666 .19918 L
.55697 .19918 L
.55697 .16187 L
s
.678 .847 .902 r
.55697 .16187 m
.55697 .19928 L
.55738 .19928 L
.55738 .16187 L
F
.2 .63 .79 r
.55697 .16187 m
.55697 .19928 L
.55738 .19928 L
.55738 .16187 L
s
.678 .847 .902 r
.55738 .16187 m
.55738 .19989 L
.55828 .19989 L
.55828 .16187 L
F
.2 .63 .79 r
.55738 .16187 m
.55738 .19989 L
.55828 .19989 L
.55828 .16187 L
s
.678 .847 .902 r
.55828 .16187 m
.55828 .20053 L
.55912 .20053 L
.55912 .16187 L
F
.2 .63 .79 r
.55828 .16187 m
.55828 .20053 L
.55912 .20053 L
.55912 .16187 L
s
.678 .847 .902 r
.55912 .16187 m
.55912 .20073 L
.55959 .20073 L
.55959 .16187 L
F
.2 .63 .79 r
.55912 .16187 m
.55912 .20073 L
.55959 .20073 L
.55959 .16187 L
s
.678 .847 .902 r
.55959 .16187 m
.55959 .20102 L
.56009 .20102 L
.56009 .16187 L
F
.2 .63 .79 r
.55959 .16187 m
.55959 .20102 L
.56009 .20102 L
.56009 .16187 L
s
.678 .847 .902 r
.56009 .16187 m
.56009 .20161 L
.56085 .20161 L
.56085 .16187 L
F
.2 .63 .79 r
.56009 .16187 m
.56009 .20161 L
.56085 .20161 L
.56085 .16187 L
s
.678 .847 .902 r
.56085 .16187 m
.56085 .20242 L
.56181 .20242 L
.56181 .16187 L
F
.2 .63 .79 r
.56085 .16187 m
.56085 .20242 L
.56181 .20242 L
.56181 .16187 L
s
.678 .847 .902 r
.56181 .16187 m
.56181 .20304 L
.56278 .20304 L
.56278 .16187 L
F
.2 .63 .79 r
.56181 .16187 m
.56181 .20304 L
.56278 .20304 L
.56278 .16187 L
s
.678 .847 .902 r
.56278 .16187 m
.56278 .20357 L
.56369 .20357 L
.56369 .16187 L
F
.2 .63 .79 r
.56278 .16187 m
.56278 .20357 L
.56369 .20357 L
.56369 .16187 L
s
.678 .847 .902 r
.56369 .16187 m
.56369 .2044 L
.56456 .2044 L
.56456 .16187 L
F
.2 .63 .79 r
.56369 .16187 m
.56369 .2044 L
.56456 .2044 L
.56456 .16187 L
s
.678 .847 .902 r
.56456 .16187 m
.56456 .20513 L
.56557 .20513 L
.56557 .16187 L
F
.2 .63 .79 r
.56456 .16187 m
.56456 .20513 L
.56557 .20513 L
.56557 .16187 L
s
.678 .847 .902 r
.56557 .16187 m
.56557 .20556 L
.56658 .20556 L
.56658 .16187 L
F
.2 .63 .79 r
.56557 .16187 m
.56557 .20556 L
.56658 .20556 L
.56658 .16187 L
s
.678 .847 .902 r
.56658 .16187 m
.56658 .20594 L
.56694 .20594 L
.56694 .16187 L
F
.2 .63 .79 r
.56658 .16187 m
.56658 .20594 L
.56694 .20594 L
.56694 .16187 L
s
.678 .847 .902 r
.56694 .16187 m
.56694 .2065 L
.56768 .2065 L
.56768 .16187 L
F
.2 .63 .79 r
.56694 .16187 m
.56694 .2065 L
.56768 .2065 L
.56768 .16187 L
s
.678 .847 .902 r
.56768 .16187 m
.56768 .20688 L
.56855 .20688 L
.56855 .16187 L
F
.2 .63 .79 r
.56768 .16187 m
.56768 .20688 L
.56855 .20688 L
.56855 .16187 L
s
.678 .847 .902 r
.56855 .16187 m
.56855 .20742 L
.56925 .20742 L
.56925 .16187 L
F
.2 .63 .79 r
.56855 .16187 m
.56855 .20742 L
.56925 .20742 L
.56925 .16187 L
s
.678 .847 .902 r
.56925 .16187 m
.56925 .20831 L
.57003 .20831 L
.57003 .16187 L
F
.2 .63 .79 r
.56925 .16187 m
.56925 .20831 L
.57003 .20831 L
.57003 .16187 L
s
.678 .847 .902 r
.57003 .16187 m
.57003 .20839 L
.57061 .20839 L
.57061 .16187 L
F
.2 .63 .79 r
.57003 .16187 m
.57003 .20839 L
.57061 .20839 L
.57061 .16187 L
s
.678 .847 .902 r
.57061 .16187 m
.57061 .209 L
.571 .209 L
.571 .16187 L
F
.2 .63 .79 r
.57061 .16187 m
.57061 .209 L
.571 .209 L
.571 .16187 L
s
.678 .847 .902 r
.571 .16187 m
.571 .20917 L
.57177 .20917 L
.57177 .16187 L
F
.2 .63 .79 r
.571 .16187 m
.571 .20917 L
.57177 .20917 L
.57177 .16187 L
s
.678 .847 .902 r
.57177 .16187 m
.57177 .20963 L
.57259 .20963 L
.57259 .16187 L
F
.2 .63 .79 r
.57177 .16187 m
.57177 .20963 L
.57259 .20963 L
.57259 .16187 L
s
.678 .847 .902 r
.57259 .16187 m
.57259 .21028 L
.57315 .21028 L
.57315 .16187 L
F
.2 .63 .79 r
.57259 .16187 m
.57259 .21028 L
.57315 .21028 L
.57315 .16187 L
s
.678 .847 .902 r
.57315 .16187 m
.57315 .21111 L
.57399 .21111 L
.57399 .16187 L
F
.2 .63 .79 r
.57315 .16187 m
.57315 .21111 L
.57399 .21111 L
.57399 .16187 L
s
.678 .847 .902 r
.57399 .16187 m
.57399 .21131 L
.57476 .21131 L
.57476 .16187 L
F
.2 .63 .79 r
.57399 .16187 m
.57399 .21131 L
.57476 .21131 L
.57476 .16187 L
s
.678 .847 .902 r
.57476 .16187 m
.57476 .21209 L
.57547 .21209 L
.57547 .16187 L
F
.2 .63 .79 r
.57476 .16187 m
.57476 .21209 L
.57547 .21209 L
.57547 .16187 L
s
.678 .847 .902 r
.57547 .16187 m
.57547 .21254 L
.57617 .21254 L
.57617 .16187 L
F
.2 .63 .79 r
.57547 .16187 m
.57547 .21254 L
.57617 .21254 L
.57617 .16187 L
s
.678 .847 .902 r
.57617 .16187 m
.57617 .21275 L
.57649 .21275 L
.57649 .16187 L
F
.2 .63 .79 r
.57617 .16187 m
.57617 .21275 L
.57649 .21275 L
.57649 .16187 L
s
.678 .847 .902 r
.57649 .16187 m
.57649 .21298 L
.57709 .21298 L
.57709 .16187 L
F
.2 .63 .79 r
.57649 .16187 m
.57649 .21298 L
.57709 .21298 L
.57709 .16187 L
s
.678 .847 .902 r
.57709 .16187 m
.57709 .21364 L
.57762 .21364 L
.57762 .16187 L
F
.2 .63 .79 r
.57709 .16187 m
.57709 .21364 L
.57762 .21364 L
.57762 .16187 L
s
.678 .847 .902 r
.57762 .16187 m
.57762 .21386 L
.5786 .21386 L
.5786 .16187 L
F
.2 .63 .79 r
.57762 .16187 m
.57762 .21386 L
.5786 .21386 L
.5786 .16187 L
s
.678 .847 .902 r
.5786 .16187 m
.5786 .21456 L
.57898 .21456 L
.57898 .16187 L
F
.2 .63 .79 r
.5786 .16187 m
.5786 .21456 L
.57898 .21456 L
.57898 .16187 L
s
.678 .847 .902 r
.57898 .16187 m
.57898 .21491 L
.57966 .21491 L
.57966 .16187 L
F
.2 .63 .79 r
.57898 .16187 m
.57898 .21491 L
.57966 .21491 L
.57966 .16187 L
s
.678 .847 .902 r
.57966 .16187 m
.57966 .21529 L
.58031 .21529 L
.58031 .16187 L
F
.2 .63 .79 r
.57966 .16187 m
.57966 .21529 L
.58031 .21529 L
.58031 .16187 L
s
.678 .847 .902 r
.58031 .16187 m
.58031 .21577 L
.58073 .21577 L
.58073 .16187 L
F
.2 .63 .79 r
.58031 .16187 m
.58031 .21577 L
.58073 .21577 L
.58073 .16187 L
s
.678 .847 .902 r
.58073 .16187 m
.58073 .21612 L
.58114 .21612 L
.58114 .16187 L
F
.2 .63 .79 r
.58073 .16187 m
.58073 .21612 L
.58114 .21612 L
.58114 .16187 L
s
.678 .847 .902 r
.58114 .16187 m
.58114 .21671 L
.58184 .21671 L
.58184 .16187 L
F
.2 .63 .79 r
.58114 .16187 m
.58114 .21671 L
.58184 .21671 L
.58184 .16187 L
s
.678 .847 .902 r
.58184 .16187 m
.58184 .21721 L
.58245 .21721 L
.58245 .16187 L
F
.2 .63 .79 r
.58184 .16187 m
.58184 .21721 L
.58245 .21721 L
.58245 .16187 L
s
.678 .847 .902 r
.58245 .16187 m
.58245 .21753 L
.58316 .21753 L
.58316 .16187 L
F
.2 .63 .79 r
.58245 .16187 m
.58245 .21753 L
.58316 .21753 L
.58316 .16187 L
s
.678 .847 .902 r
.58316 .16187 m
.58316 .2178 L
.58373 .2178 L
.58373 .16187 L
F
.2 .63 .79 r
.58316 .16187 m
.58316 .2178 L
.58373 .2178 L
.58373 .16187 L
s
.678 .847 .902 r
.58373 .16187 m
.58373 .21859 L
.58476 .21859 L
.58476 .16187 L
F
.2 .63 .79 r
.58373 .16187 m
.58373 .21859 L
.58476 .21859 L
.58476 .16187 L
s
.678 .847 .902 r
.58476 .16187 m
.58476 .21892 L
.58563 .21892 L
.58563 .16187 L
F
.2 .63 .79 r
.58476 .16187 m
.58476 .21892 L
.58563 .21892 L
.58563 .16187 L
s
.678 .847 .902 r
.58563 .16187 m
.58563 .21969 L
.58608 .21969 L
.58608 .16187 L
F
.2 .63 .79 r
.58563 .16187 m
.58563 .21969 L
.58608 .21969 L
.58608 .16187 L
s
.678 .847 .902 r
.58608 .16187 m
.58608 .21993 L
.58657 .21993 L
.58657 .16187 L
F
.2 .63 .79 r
.58608 .16187 m
.58608 .21993 L
.58657 .21993 L
.58657 .16187 L
s
.678 .847 .902 r
.58657 .16187 m
.58657 .22035 L
.58714 .22035 L
.58714 .16187 L
F
.2 .63 .79 r
.58657 .16187 m
.58657 .22035 L
.58714 .22035 L
.58714 .16187 L
s
.678 .847 .902 r
.58714 .16187 m
.58714 .22088 L
.58749 .22088 L
.58749 .16187 L
F
.2 .63 .79 r
.58714 .16187 m
.58714 .22088 L
.58749 .22088 L
.58749 .16187 L
s
.678 .847 .902 r
.58749 .16187 m
.58749 .22098 L
.58842 .22098 L
.58842 .16187 L
F
.2 .63 .79 r
.58749 .16187 m
.58749 .22098 L
.58842 .22098 L
.58842 .16187 L
s
.678 .847 .902 r
.58842 .16187 m
.58842 .2217 L
.58911 .2217 L
.58911 .16187 L
F
.2 .63 .79 r
.58842 .16187 m
.58842 .2217 L
.58911 .2217 L
.58911 .16187 L
s
.678 .847 .902 r
.58911 .16187 m
.58911 .2227 L
.58994 .2227 L
.58994 .16187 L
F
.2 .63 .79 r
.58911 .16187 m
.58911 .2227 L
.58994 .2227 L
.58994 .16187 L
s
.678 .847 .902 r
.58994 .16187 m
.58994 .22276 L
.59062 .22276 L
.59062 .16187 L
F
.2 .63 .79 r
.58994 .16187 m
.58994 .22276 L
.59062 .22276 L
.59062 .16187 L
s
.678 .847 .902 r
.59062 .16187 m
.59062 .22337 L
.59115 .22337 L
.59115 .16187 L
F
.2 .63 .79 r
.59062 .16187 m
.59062 .22337 L
.59115 .22337 L
.59115 .16187 L
s
.678 .847 .902 r
.59115 .16187 m
.59115 .22361 L
.59184 .22361 L
.59184 .16187 L
F
.2 .63 .79 r
.59115 .16187 m
.59115 .22361 L
.59184 .22361 L
.59184 .16187 L
s
.678 .847 .902 r
.59184 .16187 m
.59184 .22445 L
.59238 .22445 L
.59238 .16187 L
F
.2 .63 .79 r
.59184 .16187 m
.59184 .22445 L
.59238 .22445 L
.59238 .16187 L
s
.678 .847 .902 r
.59238 .16187 m
.59238 .22463 L
.59283 .22463 L
.59283 .16187 L
F
.2 .63 .79 r
.59238 .16187 m
.59238 .22463 L
.59283 .22463 L
.59283 .16187 L
s
.678 .847 .902 r
.59283 .16187 m
.59283 .22496 L
.59342 .22496 L
.59342 .16187 L
F
.2 .63 .79 r
.59283 .16187 m
.59283 .22496 L
.59342 .22496 L
.59342 .16187 L
s
.678 .847 .902 r
.59342 .16187 m
.59342 .22558 L
.59405 .22558 L
.59405 .16187 L
F
.2 .63 .79 r
.59342 .16187 m
.59342 .22558 L
.59405 .22558 L
.59405 .16187 L
s
.678 .847 .902 r
.59405 .16187 m
.59405 .22607 L
.59494 .22607 L
.59494 .16187 L
F
.2 .63 .79 r
.59405 .16187 m
.59405 .22607 L
.59494 .22607 L
.59494 .16187 L
s
.678 .847 .902 r
.59494 .16187 m
.59494 .22655 L
.59577 .22655 L
.59577 .16187 L
F
.2 .63 .79 r
.59494 .16187 m
.59494 .22655 L
.59577 .22655 L
.59577 .16187 L
s
.678 .847 .902 r
.59577 .16187 m
.59577 .22702 L
.59626 .22702 L
.59626 .16187 L
F
.2 .63 .79 r
.59577 .16187 m
.59577 .22702 L
.59626 .22702 L
.59626 .16187 L
s
.678 .847 .902 r
.59626 .16187 m
.59626 .22745 L
.59678 .22745 L
.59678 .16187 L
F
.2 .63 .79 r
.59626 .16187 m
.59626 .22745 L
.59678 .22745 L
.59678 .16187 L
s
.678 .847 .902 r
.59678 .16187 m
.59678 .22801 L
.5973 .22801 L
.5973 .16187 L
F
.2 .63 .79 r
.59678 .16187 m
.59678 .22801 L
.5973 .22801 L
.5973 .16187 L
s
.678 .847 .902 r
.5973 .16187 m
.5973 .22825 L
.59783 .22825 L
.59783 .16187 L
F
.2 .63 .79 r
.5973 .16187 m
.5973 .22825 L
.59783 .22825 L
.59783 .16187 L
s
.678 .847 .902 r
.59783 .16187 m
.59783 .2288 L
.59863 .2288 L
.59863 .16187 L
F
.2 .63 .79 r
.59783 .16187 m
.59783 .2288 L
.59863 .2288 L
.59863 .16187 L
s
.678 .847 .902 r
.59863 .16187 m
.59863 .22922 L
.59961 .22922 L
.59961 .16187 L
F
.2 .63 .79 r
.59863 .16187 m
.59863 .22922 L
.59961 .22922 L
.59961 .16187 L
s
.678 .847 .902 r
.59961 .16187 m
.59961 .22991 L
.60014 .22991 L
.60014 .16187 L
F
.2 .63 .79 r
.59961 .16187 m
.59961 .22991 L
.60014 .22991 L
.60014 .16187 L
s
.678 .847 .902 r
.60014 .16187 m
.60014 .23041 L
.60084 .23041 L
.60084 .16187 L
F
.2 .63 .79 r
.60014 .16187 m
.60014 .23041 L
.60084 .23041 L
.60084 .16187 L
s
.678 .847 .902 r
.60084 .16187 m
.60084 .23079 L
.6015 .23079 L
.6015 .16187 L
F
.2 .63 .79 r
.60084 .16187 m
.60084 .23079 L
.6015 .23079 L
.6015 .16187 L
s
.678 .847 .902 r
.6015 .16187 m
.6015 .23186 L
.6023 .23186 L
.6023 .16187 L
F
.2 .63 .79 r
.6015 .16187 m
.6015 .23186 L
.6023 .23186 L
.6023 .16187 L
s
.678 .847 .902 r
.6023 .16187 m
.6023 .23249 L
.6033 .23249 L
.6033 .16187 L
F
.2 .63 .79 r
.6023 .16187 m
.6023 .23249 L
.6033 .23249 L
.6033 .16187 L
s
.678 .847 .902 r
.6033 .16187 m
.6033 .23282 L
.60395 .23282 L
.60395 .16187 L
F
.2 .63 .79 r
.6033 .16187 m
.6033 .23282 L
.60395 .23282 L
.60395 .16187 L
s
.678 .847 .902 r
.60395 .16187 m
.60395 .23365 L
.60472 .23365 L
.60472 .16187 L
F
.2 .63 .79 r
.60395 .16187 m
.60395 .23365 L
.60472 .23365 L
.60472 .16187 L
s
.678 .847 .902 r
.60472 .16187 m
.60472 .23394 L
.60514 .23394 L
.60514 .16187 L
F
.2 .63 .79 r
.60472 .16187 m
.60472 .23394 L
.60514 .23394 L
.60514 .16187 L
s
.678 .847 .902 r
.60514 .16187 m
.60514 .23431 L
.60562 .23431 L
.60562 .16187 L
F
.2 .63 .79 r
.60514 .16187 m
.60514 .23431 L
.60562 .23431 L
.60562 .16187 L
s
.678 .847 .902 r
.60562 .16187 m
.60562 .23459 L
.60663 .23459 L
.60663 .16187 L
F
.2 .63 .79 r
.60562 .16187 m
.60562 .23459 L
.60663 .23459 L
.60663 .16187 L
s
.678 .847 .902 r
.60663 .16187 m
.60663 .23534 L
.60718 .23534 L
.60718 .16187 L
F
.2 .63 .79 r
.60663 .16187 m
.60663 .23534 L
.60718 .23534 L
.60718 .16187 L
s
.678 .847 .902 r
.60718 .16187 m
.60718 .23597 L
.60794 .23597 L
.60794 .16187 L
F
.2 .63 .79 r
.60718 .16187 m
.60718 .23597 L
.60794 .23597 L
.60794 .16187 L
s
.678 .847 .902 r
.60794 .16187 m
.60794 .23683 L
.60892 .23683 L
.60892 .16187 L
F
.2 .63 .79 r
.60794 .16187 m
.60794 .23683 L
.60892 .23683 L
.60892 .16187 L
s
.678 .847 .902 r
.60892 .16187 m
.60892 .23745 L
.60979 .23745 L
.60979 .16187 L
F
.2 .63 .79 r
.60892 .16187 m
.60892 .23745 L
.60979 .23745 L
.60979 .16187 L
s
.678 .847 .902 r
.60979 .16187 m
.60979 .23766 L
.61078 .23766 L
.61078 .16187 L
F
.2 .63 .79 r
.60979 .16187 m
.60979 .23766 L
.61078 .23766 L
.61078 .16187 L
s
.678 .847 .902 r
.61078 .16187 m
.61078 .23831 L
.61124 .23831 L
.61124 .16187 L
F
.2 .63 .79 r
.61078 .16187 m
.61078 .23831 L
.61124 .23831 L
.61124 .16187 L
s
.678 .847 .902 r
.61124 .16187 m
.61124 .23877 L
.61162 .23877 L
.61162 .16187 L
F
.2 .63 .79 r
.61124 .16187 m
.61124 .23877 L
.61162 .23877 L
.61162 .16187 L
s
.678 .847 .902 r
.61162 .16187 m
.61162 .2391 L
.61197 .2391 L
.61197 .16187 L
F
.2 .63 .79 r
.61162 .16187 m
.61162 .2391 L
.61197 .2391 L
.61197 .16187 L
s
.678 .847 .902 r
.61197 .16187 m
.61197 .23929 L
.61279 .23929 L
.61279 .16187 L
F
.2 .63 .79 r
.61197 .16187 m
.61197 .23929 L
.61279 .23929 L
.61279 .16187 L
s
.678 .847 .902 r
.61279 .16187 m
.61279 .24043 L
.61376 .24043 L
.61376 .16187 L
F
.2 .63 .79 r
.61279 .16187 m
.61279 .24043 L
.61376 .24043 L
.61376 .16187 L
s
.678 .847 .902 r
.61376 .16187 m
.61376 .24109 L
.61466 .24109 L
.61466 .16187 L
F
.2 .63 .79 r
.61376 .16187 m
.61376 .24109 L
.61466 .24109 L
.61466 .16187 L
s
.678 .847 .902 r
.61466 .16187 m
.61466 .24149 L
.61552 .24149 L
.61552 .16187 L
F
.2 .63 .79 r
.61466 .16187 m
.61466 .24149 L
.61552 .24149 L
.61552 .16187 L
s
.678 .847 .902 r
.61552 .16187 m
.61552 .2421 L
.61585 .2421 L
.61585 .16187 L
F
.2 .63 .79 r
.61552 .16187 m
.61552 .2421 L
.61585 .2421 L
.61585 .16187 L
s
.678 .847 .902 r
.61585 .16187 m
.61585 .24272 L
.61686 .24272 L
.61686 .16187 L
F
.2 .63 .79 r
.61585 .16187 m
.61585 .24272 L
.61686 .24272 L
.61686 .16187 L
s
.678 .847 .902 r
.61686 .16187 m
.61686 .24331 L
.61756 .24331 L
.61756 .16187 L
F
.2 .63 .79 r
.61686 .16187 m
.61686 .24331 L
.61756 .24331 L
.61756 .16187 L
s
.678 .847 .902 r
.61756 .16187 m
.61756 .24351 L
.61802 .24351 L
.61802 .16187 L
F
.2 .63 .79 r
.61756 .16187 m
.61756 .24351 L
.61802 .24351 L
.61802 .16187 L
s
.678 .847 .902 r
.61802 .16187 m
.61802 .24422 L
.61873 .24422 L
.61873 .16187 L
F
.2 .63 .79 r
.61802 .16187 m
.61802 .24422 L
.61873 .24422 L
.61873 .16187 L
s
.678 .847 .902 r
.61873 .16187 m
.61873 .24469 L
.61925 .24469 L
.61925 .16187 L
F
.2 .63 .79 r
.61873 .16187 m
.61873 .24469 L
.61925 .24469 L
.61925 .16187 L
s
.678 .847 .902 r
.61925 .16187 m
.61925 .24528 L
.61999 .24528 L
.61999 .16187 L
F
.2 .63 .79 r
.61925 .16187 m
.61925 .24528 L
.61999 .24528 L
.61999 .16187 L
s
.678 .847 .902 r
.61999 .16187 m
.61999 .2458 L
.62083 .2458 L
.62083 .16187 L
F
.2 .63 .79 r
.61999 .16187 m
.61999 .2458 L
.62083 .2458 L
.62083 .16187 L
s
.678 .847 .902 r
.62083 .16187 m
.62083 .24661 L
.6218 .24661 L
.6218 .16187 L
F
.2 .63 .79 r
.62083 .16187 m
.62083 .24661 L
.6218 .24661 L
.6218 .16187 L
s
.678 .847 .902 r
.6218 .16187 m
.6218 .24678 L
.62221 .24678 L
.62221 .16187 L
F
.2 .63 .79 r
.6218 .16187 m
.6218 .24678 L
.62221 .24678 L
.62221 .16187 L
s
.678 .847 .902 r
.62221 .16187 m
.62221 .2471 L
.62278 .2471 L
.62278 .16187 L
F
.2 .63 .79 r
.62221 .16187 m
.62221 .2471 L
.62278 .2471 L
.62278 .16187 L
s
.678 .847 .902 r
.62278 .16187 m
.62278 .2478 L
.62365 .2478 L
.62365 .16187 L
F
.2 .63 .79 r
.62278 .16187 m
.62278 .2478 L
.62365 .2478 L
.62365 .16187 L
s
.678 .847 .902 r
.62365 .16187 m
.62365 .2484 L
.62439 .2484 L
.62439 .16187 L
F
.2 .63 .79 r
.62365 .16187 m
.62365 .2484 L
.62439 .2484 L
.62439 .16187 L
s
.678 .847 .902 r
.62439 .16187 m
.62439 .24895 L
.62506 .24895 L
.62506 .16187 L
F
.2 .63 .79 r
.62439 .16187 m
.62439 .24895 L
.62506 .24895 L
.62506 .16187 L
s
.678 .847 .902 r
.62506 .16187 m
.62506 .24936 L
.6257 .24936 L
.6257 .16187 L
F
.2 .63 .79 r
.62506 .16187 m
.62506 .24936 L
.6257 .24936 L
.6257 .16187 L
s
.678 .847 .902 r
.6257 .16187 m
.6257 .25022 L
.62672 .25022 L
.62672 .16187 L
F
.2 .63 .79 r
.6257 .16187 m
.6257 .25022 L
.62672 .25022 L
.62672 .16187 L
s
.678 .847 .902 r
.62672 .16187 m
.62672 .25071 L
.62751 .25071 L
.62751 .16187 L
F
.2 .63 .79 r
.62672 .16187 m
.62672 .25071 L
.62751 .25071 L
.62751 .16187 L
s
.678 .847 .902 r
.62751 .16187 m
.62751 .25134 L
.62804 .25134 L
.62804 .16187 L
F
.2 .63 .79 r
.62751 .16187 m
.62751 .25134 L
.62804 .25134 L
.62804 .16187 L
s
.678 .847 .902 r
.62804 .16187 m
.62804 .25194 L
.6286 .25194 L
.6286 .16187 L
F
.2 .63 .79 r
.62804 .16187 m
.62804 .25194 L
.6286 .25194 L
.6286 .16187 L
s
.678 .847 .902 r
.6286 .16187 m
.6286 .25277 L
.62958 .25277 L
.62958 .16187 L
F
.2 .63 .79 r
.6286 .16187 m
.6286 .25277 L
.62958 .25277 L
.62958 .16187 L
s
.678 .847 .902 r
.62958 .16187 m
.62958 .25288 L
.63058 .25288 L
.63058 .16187 L
F
.2 .63 .79 r
.62958 .16187 m
.62958 .25288 L
.63058 .25288 L
.63058 .16187 L
s
.678 .847 .902 r
.63058 .16187 m
.63058 .25386 L
.63118 .25386 L
.63118 .16187 L
F
.2 .63 .79 r
.63058 .16187 m
.63058 .25386 L
.63118 .25386 L
.63118 .16187 L
s
.678 .847 .902 r
.63118 .16187 m
.63118 .25462 L
.63188 .25462 L
.63188 .16187 L
F
.2 .63 .79 r
.63118 .16187 m
.63118 .25462 L
.63188 .25462 L
.63188 .16187 L
s
.678 .847 .902 r
.63188 .16187 m
.63188 .25485 L
.63231 .25485 L
.63231 .16187 L
F
.2 .63 .79 r
.63188 .16187 m
.63188 .25485 L
.63231 .25485 L
.63231 .16187 L
s
.678 .847 .902 r
.63231 .16187 m
.63231 .25527 L
.63329 .25527 L
.63329 .16187 L
F
.2 .63 .79 r
.63231 .16187 m
.63231 .25527 L
.63329 .25527 L
.63329 .16187 L
s
.678 .847 .902 r
.63329 .16187 m
.63329 .25615 L
.63392 .25615 L
.63392 .16187 L
F
.2 .63 .79 r
.63329 .16187 m
.63329 .25615 L
.63392 .25615 L
.63392 .16187 L
s
.678 .847 .902 r
.63392 .16187 m
.63392 .2565 L
.63495 .2565 L
.63495 .16187 L
F
.2 .63 .79 r
.63392 .16187 m
.63392 .2565 L
.63495 .2565 L
.63495 .16187 L
s
.678 .847 .902 r
.63495 .16187 m
.63495 .25749 L
.63596 .25749 L
.63596 .16187 L
F
.2 .63 .79 r
.63495 .16187 m
.63495 .25749 L
.63596 .25749 L
.63596 .16187 L
s
.678 .847 .902 r
.63596 .16187 m
.63596 .25819 L
.63654 .25819 L
.63654 .16187 L
F
.2 .63 .79 r
.63596 .16187 m
.63596 .25819 L
.63654 .25819 L
.63654 .16187 L
s
.678 .847 .902 r
.63654 .16187 m
.63654 .25836 L
.63696 .25836 L
.63696 .16187 L
F
.2 .63 .79 r
.63654 .16187 m
.63654 .25836 L
.63696 .25836 L
.63696 .16187 L
s
.678 .847 .902 r
.63696 .16187 m
.63696 .25889 L
.63756 .25889 L
.63756 .16187 L
F
.2 .63 .79 r
.63696 .16187 m
.63696 .25889 L
.63756 .25889 L
.63756 .16187 L
s
.678 .847 .902 r
.63756 .16187 m
.63756 .25948 L
.63804 .25948 L
.63804 .16187 L
F
.2 .63 .79 r
.63756 .16187 m
.63756 .25948 L
.63804 .25948 L
.63804 .16187 L
s
.678 .847 .902 r
.63804 .16187 m
.63804 .25999 L
.63868 .25999 L
.63868 .16187 L
F
.2 .63 .79 r
.63804 .16187 m
.63804 .25999 L
.63868 .25999 L
.63868 .16187 L
s
.678 .847 .902 r
.63868 .16187 m
.63868 .26006 L
.63901 .26006 L
.63901 .16187 L
F
.2 .63 .79 r
.63868 .16187 m
.63868 .26006 L
.63901 .26006 L
.63901 .16187 L
s
.678 .847 .902 r
.63901 .16187 m
.63901 .26042 L
.63935 .26042 L
.63935 .16187 L
F
.2 .63 .79 r
.63901 .16187 m
.63901 .26042 L
.63935 .26042 L
.63935 .16187 L
s
.678 .847 .902 r
.63935 .16187 m
.63935 .26082 L
.64 .26082 L
.64 .16187 L
F
.2 .63 .79 r
.63935 .16187 m
.63935 .26082 L
.64 .26082 L
.64 .16187 L
s
.678 .847 .902 r
.64 .16187 m
.64 .2615 L
.64093 .2615 L
.64093 .16187 L
F
.2 .63 .79 r
.64 .16187 m
.64 .2615 L
.64093 .2615 L
.64093 .16187 L
s
.678 .847 .902 r
.64093 .16187 m
.64093 .26224 L
.64162 .26224 L
.64162 .16187 L
F
.2 .63 .79 r
.64093 .16187 m
.64093 .26224 L
.64162 .26224 L
.64162 .16187 L
s
.678 .847 .902 r
.64162 .16187 m
.64162 .26256 L
.64236 .26256 L
.64236 .16187 L
F
.2 .63 .79 r
.64162 .16187 m
.64162 .26256 L
.64236 .26256 L
.64236 .16187 L
s
.678 .847 .902 r
.64236 .16187 m
.64236 .26349 L
.64302 .26349 L
.64302 .16187 L
F
.2 .63 .79 r
.64236 .16187 m
.64236 .26349 L
.64302 .26349 L
.64302 .16187 L
s
.678 .847 .902 r
.64302 .16187 m
.64302 .26366 L
.64348 .26366 L
.64348 .16187 L
F
.2 .63 .79 r
.64302 .16187 m
.64302 .26366 L
.64348 .26366 L
.64348 .16187 L
s
.678 .847 .902 r
.64348 .16187 m
.64348 .26406 L
.64395 .26406 L
.64395 .16187 L
F
.2 .63 .79 r
.64348 .16187 m
.64348 .26406 L
.64395 .26406 L
.64395 .16187 L
s
.678 .847 .902 r
.64395 .16187 m
.64395 .2645 L
.64443 .2645 L
.64443 .16187 L
F
.2 .63 .79 r
.64395 .16187 m
.64395 .2645 L
.64443 .2645 L
.64443 .16187 L
s
.678 .847 .902 r
.64443 .16187 m
.64443 .26468 L
.64514 .26468 L
.64514 .16187 L
F
.2 .63 .79 r
.64443 .16187 m
.64443 .26468 L
.64514 .26468 L
.64514 .16187 L
s
.678 .847 .902 r
.64514 .16187 m
.64514 .26537 L
.64564 .26537 L
.64564 .16187 L
F
.2 .63 .79 r
.64514 .16187 m
.64514 .26537 L
.64564 .26537 L
.64564 .16187 L
s
.678 .847 .902 r
.64564 .16187 m
.64564 .26633 L
.64654 .26633 L
.64654 .16187 L
F
.2 .63 .79 r
.64564 .16187 m
.64564 .26633 L
.64654 .26633 L
.64654 .16187 L
s
.678 .847 .902 r
.64654 .16187 m
.64654 .26679 L
.64737 .26679 L
.64737 .16187 L
F
.2 .63 .79 r
.64654 .16187 m
.64654 .26679 L
.64737 .26679 L
.64737 .16187 L
s
.678 .847 .902 r
.64737 .16187 m
.64737 .26726 L
.64796 .26726 L
.64796 .16187 L
F
.2 .63 .79 r
.64737 .16187 m
.64737 .26726 L
.64796 .26726 L
.64796 .16187 L
s
.678 .847 .902 r
.64796 .16187 m
.64796 .26795 L
.64851 .26795 L
.64851 .16187 L
F
.2 .63 .79 r
.64796 .16187 m
.64796 .26795 L
.64851 .26795 L
.64851 .16187 L
s
.678 .847 .902 r
.64851 .16187 m
.64851 .26805 L
.6491 .26805 L
.6491 .16187 L
F
.2 .63 .79 r
.64851 .16187 m
.64851 .26805 L
.6491 .26805 L
.6491 .16187 L
s
.678 .847 .902 r
.6491 .16187 m
.6491 .26868 L
.64992 .26868 L
.64992 .16187 L
F
.2 .63 .79 r
.6491 .16187 m
.6491 .26868 L
.64992 .26868 L
.64992 .16187 L
s
.678 .847 .902 r
.64992 .16187 m
.64992 .26959 L
.65055 .26959 L
.65055 .16187 L
F
.2 .63 .79 r
.64992 .16187 m
.64992 .26959 L
.65055 .26959 L
.65055 .16187 L
s
.678 .847 .902 r
.65055 .16187 m
.65055 .26988 L
.65155 .26988 L
.65155 .16187 L
F
.2 .63 .79 r
.65055 .16187 m
.65055 .26988 L
.65155 .26988 L
.65155 .16187 L
s
.678 .847 .902 r
.65155 .16187 m
.65155 .2705 L
.65203 .2705 L
.65203 .16187 L
F
.2 .63 .79 r
.65155 .16187 m
.65155 .2705 L
.65203 .2705 L
.65203 .16187 L
s
.678 .847 .902 r
.65203 .16187 m
.65203 .27123 L
.65256 .27123 L
.65256 .16187 L
F
.2 .63 .79 r
.65203 .16187 m
.65203 .27123 L
.65256 .27123 L
.65256 .16187 L
s
.678 .847 .902 r
.65256 .16187 m
.65256 .2713 L
.65302 .2713 L
.65302 .16187 L
F
.2 .63 .79 r
.65256 .16187 m
.65256 .2713 L
.65302 .2713 L
.65302 .16187 L
s
.678 .847 .902 r
.65302 .16187 m
.65302 .27188 L
.65369 .27188 L
.65369 .16187 L
F
.2 .63 .79 r
.65302 .16187 m
.65302 .27188 L
.65369 .27188 L
.65369 .16187 L
s
.678 .847 .902 r
.65369 .16187 m
.65369 .27224 L
.65416 .27224 L
.65416 .16187 L
F
.2 .63 .79 r
.65369 .16187 m
.65369 .27224 L
.65416 .27224 L
.65416 .16187 L
s
.678 .847 .902 r
.65416 .16187 m
.65416 .27279 L
.65466 .27279 L
.65466 .16187 L
F
.2 .63 .79 r
.65416 .16187 m
.65416 .27279 L
.65466 .27279 L
.65466 .16187 L
s
.678 .847 .902 r
.65466 .16187 m
.65466 .27343 L
.6555 .27343 L
.6555 .16187 L
F
.2 .63 .79 r
.65466 .16187 m
.65466 .27343 L
.6555 .27343 L
.6555 .16187 L
s
.678 .847 .902 r
.6555 .16187 m
.6555 .27425 L
.65627 .27425 L
.65627 .16187 L
F
.2 .63 .79 r
.6555 .16187 m
.6555 .27425 L
.65627 .27425 L
.65627 .16187 L
s
.678 .847 .902 r
.65627 .16187 m
.65627 .27461 L
.65709 .27461 L
.65709 .16187 L
F
.2 .63 .79 r
.65627 .16187 m
.65627 .27461 L
.65709 .27461 L
.65709 .16187 L
s
.678 .847 .902 r
.65709 .16187 m
.65709 .27516 L
.65788 .27516 L
.65788 .16187 L
F
.2 .63 .79 r
.65709 .16187 m
.65709 .27516 L
.65788 .27516 L
.65788 .16187 L
s
.678 .847 .902 r
.65788 .16187 m
.65788 .27592 L
.65838 .27592 L
.65838 .16187 L
F
.2 .63 .79 r
.65788 .16187 m
.65788 .27592 L
.65838 .27592 L
.65838 .16187 L
s
.678 .847 .902 r
.65838 .16187 m
.65838 .27632 L
.65899 .27632 L
.65899 .16187 L
F
.2 .63 .79 r
.65838 .16187 m
.65838 .27632 L
.65899 .27632 L
.65899 .16187 L
s
.678 .847 .902 r
.65899 .16187 m
.65899 .27656 L
.65966 .27656 L
.65966 .16187 L
F
.2 .63 .79 r
.65899 .16187 m
.65899 .27656 L
.65966 .27656 L
.65966 .16187 L
s
.678 .847 .902 r
.65966 .16187 m
.65966 .27745 L
.66028 .27745 L
.66028 .16187 L
F
.2 .63 .79 r
.65966 .16187 m
.65966 .27745 L
.66028 .27745 L
.66028 .16187 L
s
.678 .847 .902 r
.66028 .16187 m
.66028 .27807 L
.6611 .27807 L
.6611 .16187 L
F
.2 .63 .79 r
.66028 .16187 m
.66028 .27807 L
.6611 .27807 L
.6611 .16187 L
s
.678 .847 .902 r
.6611 .16187 m
.6611 .27836 L
.66152 .27836 L
.66152 .16187 L
F
.2 .63 .79 r
.6611 .16187 m
.6611 .27836 L
.66152 .27836 L
.66152 .16187 L
s
.678 .847 .902 r
.66152 .16187 m
.66152 .27869 L
.66232 .27869 L
.66232 .16187 L
F
.2 .63 .79 r
.66152 .16187 m
.66152 .27869 L
.66232 .27869 L
.66232 .16187 L
s
.678 .847 .902 r
.66232 .16187 m
.66232 .27934 L
.66316 .27934 L
.66316 .16187 L
F
.2 .63 .79 r
.66232 .16187 m
.66232 .27934 L
.66316 .27934 L
.66316 .16187 L
s
.678 .847 .902 r
.66316 .16187 m
.66316 .28009 L
.66369 .28009 L
.66369 .16187 L
F
.2 .63 .79 r
.66316 .16187 m
.66316 .28009 L
.66369 .28009 L
.66369 .16187 L
s
.678 .847 .902 r
.66369 .16187 m
.66369 .28064 L
.6646 .28064 L
.6646 .16187 L
F
.2 .63 .79 r
.66369 .16187 m
.66369 .28064 L
.6646 .28064 L
.6646 .16187 L
s
.678 .847 .902 r
.6646 .16187 m
.6646 .28158 L
.66512 .28158 L
.66512 .16187 L
F
.2 .63 .79 r
.6646 .16187 m
.6646 .28158 L
.66512 .28158 L
.66512 .16187 L
s
.678 .847 .902 r
.66512 .16187 m
.66512 .2818 L
.66544 .2818 L
.66544 .16187 L
F
.2 .63 .79 r
.66512 .16187 m
.66512 .2818 L
.66544 .2818 L
.66544 .16187 L
s
.678 .847 .902 r
.66544 .16187 m
.66544 .2821 L
.66639 .2821 L
.66639 .16187 L
F
.2 .63 .79 r
.66544 .16187 m
.66544 .2821 L
.66639 .2821 L
.66639 .16187 L
s
.678 .847 .902 r
.66639 .16187 m
.66639 .28343 L
.66734 .28343 L
.66734 .16187 L
F
.2 .63 .79 r
.66639 .16187 m
.66639 .28343 L
.66734 .28343 L
.66734 .16187 L
s
.678 .847 .902 r
.66734 .16187 m
.66734 .28367 L
.66768 .28367 L
.66768 .16187 L
F
.2 .63 .79 r
.66734 .16187 m
.66734 .28367 L
.66768 .28367 L
.66768 .16187 L
s
.678 .847 .902 r
.66768 .16187 m
.66768 .28429 L
.66851 .28429 L
.66851 .16187 L
F
.2 .63 .79 r
.66768 .16187 m
.66768 .28429 L
.66851 .28429 L
.66851 .16187 L
s
.678 .847 .902 r
.66851 .16187 m
.66851 .28455 L
.66931 .28455 L
.66931 .16187 L
F
.2 .63 .79 r
.66851 .16187 m
.66851 .28455 L
.66931 .28455 L
.66931 .16187 L
s
.678 .847 .902 r
.66931 .16187 m
.66931 .28535 L
.6699 .28535 L
.6699 .16187 L
F
.2 .63 .79 r
.66931 .16187 m
.66931 .28535 L
.6699 .28535 L
.6699 .16187 L
s
.678 .847 .902 r
.6699 .16187 m
.6699 .28605 L
.67081 .28605 L
.67081 .16187 L
F
.2 .63 .79 r
.6699 .16187 m
.6699 .28605 L
.67081 .28605 L
.67081 .16187 L
s
.678 .847 .902 r
.67081 .16187 m
.67081 .28649 L
.67145 .28649 L
.67145 .16187 L
F
.2 .63 .79 r
.67081 .16187 m
.67081 .28649 L
.67145 .28649 L
.67145 .16187 L
s
.678 .847 .902 r
.67145 .16187 m
.67145 .28732 L
.67244 .28732 L
.67244 .16187 L
F
.2 .63 .79 r
.67145 .16187 m
.67145 .28732 L
.67244 .28732 L
.67244 .16187 L
s
.678 .847 .902 r
.67244 .16187 m
.67244 .28815 L
.6733 .28815 L
.6733 .16187 L
F
.2 .63 .79 r
.67244 .16187 m
.67244 .28815 L
.6733 .28815 L
.6733 .16187 L
s
.678 .847 .902 r
.6733 .16187 m
.6733 .2885 L
.6737 .2885 L
.6737 .16187 L
F
.2 .63 .79 r
.6733 .16187 m
.6733 .2885 L
.6737 .2885 L
.6737 .16187 L
s
.678 .847 .902 r
.6737 .16187 m
.6737 .28949 L
.67457 .28949 L
.67457 .16187 L
F
.2 .63 .79 r
.6737 .16187 m
.6737 .28949 L
.67457 .28949 L
.67457 .16187 L
s
.678 .847 .902 r
.67457 .16187 m
.67457 .29006 L
.67538 .29006 L
.67538 .16187 L
F
.2 .63 .79 r
.67457 .16187 m
.67457 .29006 L
.67538 .29006 L
.67538 .16187 L
s
.678 .847 .902 r
.67538 .16187 m
.67538 .29068 L
.67594 .29068 L
.67594 .16187 L
F
.2 .63 .79 r
.67538 .16187 m
.67538 .29068 L
.67594 .29068 L
.67594 .16187 L
s
.678 .847 .902 r
.67594 .16187 m
.67594 .29073 L
.67671 .29073 L
.67671 .16187 L
F
.2 .63 .79 r
.67594 .16187 m
.67594 .29073 L
.67671 .29073 L
.67671 .16187 L
s
.678 .847 .902 r
.67671 .16187 m
.67671 .29144 L
.67727 .29144 L
.67727 .16187 L
F
.2 .63 .79 r
.67671 .16187 m
.67671 .29144 L
.67727 .29144 L
.67727 .16187 L
s
.678 .847 .902 r
.67727 .16187 m
.67727 .29187 L
.6783 .29187 L
.6783 .16187 L
F
.2 .63 .79 r
.67727 .16187 m
.67727 .29187 L
.6783 .29187 L
.6783 .16187 L
s
.678 .847 .902 r
.6783 .16187 m
.6783 .29296 L
.67873 .29296 L
.67873 .16187 L
F
.2 .63 .79 r
.6783 .16187 m
.6783 .29296 L
.67873 .29296 L
.67873 .16187 L
s
.678 .847 .902 r
.67873 .16187 m
.67873 .29389 L
.67975 .29389 L
.67975 .16187 L
F
.2 .63 .79 r
.67873 .16187 m
.67873 .29389 L
.67975 .29389 L
.67975 .16187 L
s
.678 .847 .902 r
.67975 .16187 m
.67975 .29401 L
.68051 .29401 L
.68051 .16187 L
F
.2 .63 .79 r
.67975 .16187 m
.67975 .29401 L
.68051 .29401 L
.68051 .16187 L
s
.678 .847 .902 r
.68051 .16187 m
.68051 .29513 L
.68131 .29513 L
.68131 .16187 L
F
.2 .63 .79 r
.68051 .16187 m
.68051 .29513 L
.68131 .29513 L
.68131 .16187 L
s
.678 .847 .902 r
.68131 .16187 m
.68131 .29547 L
.68187 .29547 L
.68187 .16187 L
F
.2 .63 .79 r
.68131 .16187 m
.68131 .29547 L
.68187 .29547 L
.68187 .16187 L
s
.678 .847 .902 r
.68187 .16187 m
.68187 .29576 L
.68268 .29576 L
.68268 .16187 L
F
.2 .63 .79 r
.68187 .16187 m
.68187 .29576 L
.68268 .29576 L
.68268 .16187 L
s
.678 .847 .902 r
.68268 .16187 m
.68268 .29668 L
.68343 .29668 L
.68343 .16187 L
F
.2 .63 .79 r
.68268 .16187 m
.68268 .29668 L
.68343 .29668 L
.68343 .16187 L
s
.678 .847 .902 r
.68343 .16187 m
.68343 .29747 L
.68432 .29747 L
.68432 .16187 L
F
.2 .63 .79 r
.68343 .16187 m
.68343 .29747 L
.68432 .29747 L
.68432 .16187 L
s
.678 .847 .902 r
.68432 .16187 m
.68432 .2981 L
.68496 .2981 L
.68496 .16187 L
F
.2 .63 .79 r
.68432 .16187 m
.68432 .2981 L
.68496 .2981 L
.68496 .16187 L
s
.678 .847 .902 r
.68496 .16187 m
.68496 .29857 L
.68574 .29857 L
.68574 .16187 L
F
.2 .63 .79 r
.68496 .16187 m
.68496 .29857 L
.68574 .29857 L
.68574 .16187 L
s
.678 .847 .902 r
.68574 .16187 m
.68574 .29955 L
.6867 .29955 L
.6867 .16187 L
F
.2 .63 .79 r
.68574 .16187 m
.68574 .29955 L
.6867 .29955 L
.6867 .16187 L
s
.678 .847 .902 r
.6867 .16187 m
.6867 .29999 L
.6871 .29999 L
.6871 .16187 L
F
.2 .63 .79 r
.6867 .16187 m
.6867 .29999 L
.6871 .29999 L
.6871 .16187 L
s
.678 .847 .902 r
.6871 .16187 m
.6871 .30053 L
.68747 .30053 L
.68747 .16187 L
F
.2 .63 .79 r
.6871 .16187 m
.6871 .30053 L
.68747 .30053 L
.68747 .16187 L
s
.678 .847 .902 r
.68747 .16187 m
.68747 .30107 L
.68836 .30107 L
.68836 .16187 L
F
.2 .63 .79 r
.68747 .16187 m
.68747 .30107 L
.68836 .30107 L
.68836 .16187 L
s
.678 .847 .902 r
.68836 .16187 m
.68836 .30151 L
.68899 .30151 L
.68899 .16187 L
F
.2 .63 .79 r
.68836 .16187 m
.68836 .30151 L
.68899 .30151 L
.68899 .16187 L
s
.678 .847 .902 r
.68899 .16187 m
.68899 .30218 L
.68944 .30218 L
.68944 .16187 L
F
.2 .63 .79 r
.68899 .16187 m
.68899 .30218 L
.68944 .30218 L
.68944 .16187 L
s
.678 .847 .902 r
.68944 .16187 m
.68944 .30243 L
.68999 .30243 L
.68999 .16187 L
F
.2 .63 .79 r
.68944 .16187 m
.68944 .30243 L
.68999 .30243 L
.68999 .16187 L
s
.678 .847 .902 r
.68999 .16187 m
.68999 .30311 L
.69079 .30311 L
.69079 .16187 L
F
.2 .63 .79 r
.68999 .16187 m
.68999 .30311 L
.69079 .30311 L
.69079 .16187 L
s
.678 .847 .902 r
.69079 .16187 m
.69079 .30371 L
.69158 .30371 L
.69158 .16187 L
F
.2 .63 .79 r
.69079 .16187 m
.69079 .30371 L
.69158 .30371 L
.69158 .16187 L
s
.678 .847 .902 r
.69158 .16187 m
.69158 .30414 L
.69225 .30414 L
.69225 .16187 L
F
.2 .63 .79 r
.69158 .16187 m
.69158 .30414 L
.69225 .30414 L
.69225 .16187 L
s
.678 .847 .902 r
.69225 .16187 m
.69225 .30506 L
.69328 .30506 L
.69328 .16187 L
F
.2 .63 .79 r
.69225 .16187 m
.69225 .30506 L
.69328 .30506 L
.69328 .16187 L
s
.678 .847 .902 r
.69328 .16187 m
.69328 .30572 L
.69362 .30572 L
.69362 .16187 L
F
.2 .63 .79 r
.69328 .16187 m
.69328 .30572 L
.69362 .30572 L
.69362 .16187 L
s
.678 .847 .902 r
.69362 .16187 m
.69362 .30597 L
.69417 .30597 L
.69417 .16187 L
F
.2 .63 .79 r
.69362 .16187 m
.69362 .30597 L
.69417 .30597 L
.69417 .16187 L
s
.678 .847 .902 r
.69417 .16187 m
.69417 .30635 L
.69484 .30635 L
.69484 .16187 L
F
.2 .63 .79 r
.69417 .16187 m
.69417 .30635 L
.69484 .30635 L
.69484 .16187 L
s
.678 .847 .902 r
.69484 .16187 m
.69484 .30747 L
.69575 .30747 L
.69575 .16187 L
F
.2 .63 .79 r
.69484 .16187 m
.69484 .30747 L
.69575 .30747 L
.69575 .16187 L
s
.678 .847 .902 r
.69575 .16187 m
.69575 .30789 L
.69611 .30789 L
.69611 .16187 L
F
.2 .63 .79 r
.69575 .16187 m
.69575 .30789 L
.69611 .30789 L
.69611 .16187 L
s
.678 .847 .902 r
.69611 .16187 m
.69611 .3081 L
.69694 .3081 L
.69694 .16187 L
F
.2 .63 .79 r
.69611 .16187 m
.69611 .3081 L
.69694 .3081 L
.69694 .16187 L
s
.678 .847 .902 r
.69694 .16187 m
.69694 .30891 L
.69784 .30891 L
.69784 .16187 L
F
.2 .63 .79 r
.69694 .16187 m
.69694 .30891 L
.69784 .30891 L
.69784 .16187 L
s
.678 .847 .902 r
.69784 .16187 m
.69784 .30968 L
.6985 .30968 L
.6985 .16187 L
F
.2 .63 .79 r
.69784 .16187 m
.69784 .30968 L
.6985 .30968 L
.6985 .16187 L
s
.678 .847 .902 r
.6985 .16187 m
.6985 .31038 L
.69908 .31038 L
.69908 .16187 L
F
.2 .63 .79 r
.6985 .16187 m
.6985 .31038 L
.69908 .31038 L
.69908 .16187 L
s
.678 .847 .902 r
.69908 .16187 m
.69908 .31087 L
.69947 .31087 L
.69947 .16187 L
F
.2 .63 .79 r
.69908 .16187 m
.69908 .31087 L
.69947 .31087 L
.69947 .16187 L
s
.678 .847 .902 r
.69947 .16187 m
.69947 .31116 L
.69979 .31116 L
.69979 .16187 L
F
.2 .63 .79 r
.69947 .16187 m
.69947 .31116 L
.69979 .31116 L
.69979 .16187 L
s
.678 .847 .902 r
.69979 .16187 m
.69979 .31146 L
.70011 .31146 L
.70011 .16187 L
F
.2 .63 .79 r
.69979 .16187 m
.69979 .31146 L
.70011 .31146 L
.70011 .16187 L
s
.678 .847 .902 r
.70011 .16187 m
.70011 .31171 L
.70096 .31171 L
.70096 .16187 L
F
.2 .63 .79 r
.70011 .16187 m
.70011 .31171 L
.70096 .31171 L
.70096 .16187 L
s
.678 .847 .902 r
.70096 .16187 m
.70096 .31232 L
.70143 .31232 L
.70143 .16187 L
F
.2 .63 .79 r
.70096 .16187 m
.70096 .31232 L
.70143 .31232 L
.70143 .16187 L
s
.678 .847 .902 r
.70143 .16187 m
.70143 .31296 L
.70239 .31296 L
.70239 .16187 L
F
.2 .63 .79 r
.70143 .16187 m
.70143 .31296 L
.70239 .31296 L
.70239 .16187 L
s
.678 .847 .902 r
.70239 .16187 m
.70239 .31419 L
.70338 .31419 L
.70338 .16187 L
F
.2 .63 .79 r
.70239 .16187 m
.70239 .31419 L
.70338 .31419 L
.70338 .16187 L
s
.678 .847 .902 r
.70338 .16187 m
.70338 .31487 L
.70436 .31487 L
.70436 .16187 L
F
.2 .63 .79 r
.70338 .16187 m
.70338 .31487 L
.70436 .31487 L
.70436 .16187 L
s
.678 .847 .902 r
.70436 .16187 m
.70436 .31583 L
.70523 .31583 L
.70523 .16187 L
F
.2 .63 .79 r
.70436 .16187 m
.70436 .31583 L
.70523 .31583 L
.70523 .16187 L
s
.678 .847 .902 r
.70523 .16187 m
.70523 .31638 L
.70605 .31638 L
.70605 .16187 L
F
.2 .63 .79 r
.70523 .16187 m
.70523 .31638 L
.70605 .31638 L
.70605 .16187 L
s
.678 .847 .902 r
.70605 .16187 m
.70605 .317 L
.70681 .317 L
.70681 .16187 L
F
.2 .63 .79 r
.70605 .16187 m
.70605 .317 L
.70681 .317 L
.70681 .16187 L
s
.678 .847 .902 r
.70681 .16187 m
.70681 .31785 L
.7073 .31785 L
.7073 .16187 L
F
.2 .63 .79 r
.70681 .16187 m
.70681 .31785 L
.7073 .31785 L
.7073 .16187 L
s
.678 .847 .902 r
.7073 .16187 m
.7073 .31797 L
.70769 .31797 L
.70769 .16187 L
F
.2 .63 .79 r
.7073 .16187 m
.7073 .31797 L
.70769 .31797 L
.70769 .16187 L
s
.678 .847 .902 r
.70769 .16187 m
.70769 .31837 L
.70815 .31837 L
.70815 .16187 L
F
.2 .63 .79 r
.70769 .16187 m
.70769 .31837 L
.70815 .31837 L
.70815 .16187 L
s
.678 .847 .902 r
.70815 .16187 m
.70815 .31924 L
.70891 .31924 L
.70891 .16187 L
F
.2 .63 .79 r
.70815 .16187 m
.70815 .31924 L
.70891 .31924 L
.70891 .16187 L
s
.678 .847 .902 r
.70891 .16187 m
.70891 .31948 L
.70937 .31948 L
.70937 .16187 L
F
.2 .63 .79 r
.70891 .16187 m
.70891 .31948 L
.70937 .31948 L
.70937 .16187 L
s
.678 .847 .902 r
.70937 .16187 m
.70937 .31975 L
.71025 .31975 L
.71025 .16187 L
F
.2 .63 .79 r
.70937 .16187 m
.70937 .31975 L
.71025 .31975 L
.71025 .16187 L
s
.678 .847 .902 r
.71025 .16187 m
.71025 .32075 L
.71107 .32075 L
.71107 .16187 L
F
.2 .63 .79 r
.71025 .16187 m
.71025 .32075 L
.71107 .32075 L
.71107 .16187 L
s
.678 .847 .902 r
.71107 .16187 m
.71107 .3214 L
.71196 .3214 L
.71196 .16187 L
F
.2 .63 .79 r
.71107 .16187 m
.71107 .3214 L
.71196 .3214 L
.71196 .16187 L
s
.678 .847 .902 r
.71196 .16187 m
.71196 .32234 L
.71237 .32234 L
.71237 .16187 L
F
.2 .63 .79 r
.71196 .16187 m
.71196 .32234 L
.71237 .32234 L
.71237 .16187 L
s
.678 .847 .902 r
.71237 .16187 m
.71237 .32269 L
.71274 .32269 L
.71274 .16187 L
F
.2 .63 .79 r
.71237 .16187 m
.71237 .32269 L
.71274 .32269 L
.71274 .16187 L
s
.678 .847 .902 r
.71274 .16187 m
.71274 .32283 L
.71369 .32283 L
.71369 .16187 L
F
.2 .63 .79 r
.71274 .16187 m
.71274 .32283 L
.71369 .32283 L
.71369 .16187 L
s
.678 .847 .902 r
.71369 .16187 m
.71369 .32404 L
.71423 .32404 L
.71423 .16187 L
F
.2 .63 .79 r
.71369 .16187 m
.71369 .32404 L
.71423 .32404 L
.71423 .16187 L
s
.678 .847 .902 r
.71423 .16187 m
.71423 .32433 L
.7151 .32433 L
.7151 .16187 L
F
.2 .63 .79 r
.71423 .16187 m
.71423 .32433 L
.7151 .32433 L
.7151 .16187 L
s
.678 .847 .902 r
.7151 .16187 m
.7151 .32503 L
.7161 .32503 L
.7161 .16187 L
F
.2 .63 .79 r
.7151 .16187 m
.7151 .32503 L
.7161 .32503 L
.7161 .16187 L
s
.678 .847 .902 r
.7161 .16187 m
.7161 .32612 L
.71705 .32612 L
.71705 .16187 L
F
.2 .63 .79 r
.7161 .16187 m
.7161 .32612 L
.71705 .32612 L
.71705 .16187 L
s
.678 .847 .902 r
.71705 .16187 m
.71705 .32668 L
.71758 .32668 L
.71758 .16187 L
F
.2 .63 .79 r
.71705 .16187 m
.71705 .32668 L
.71758 .32668 L
.71758 .16187 L
s
.678 .847 .902 r
.71758 .16187 m
.71758 .32709 L
.71791 .32709 L
.71791 .16187 L
F
.2 .63 .79 r
.71758 .16187 m
.71758 .32709 L
.71791 .32709 L
.71791 .16187 L
s
.678 .847 .902 r
.71791 .16187 m
.71791 .32744 L
.71875 .32744 L
.71875 .16187 L
F
.2 .63 .79 r
.71791 .16187 m
.71791 .32744 L
.71875 .32744 L
.71875 .16187 L
s
.678 .847 .902 r
.71875 .16187 m
.71875 .32825 L
.71978 .32825 L
.71978 .16187 L
F
.2 .63 .79 r
.71875 .16187 m
.71875 .32825 L
.71978 .32825 L
.71978 .16187 L
s
.678 .847 .902 r
.71978 .16187 m
.71978 .32928 L
.72036 .32928 L
.72036 .16187 L
F
.2 .63 .79 r
.71978 .16187 m
.71978 .32928 L
.72036 .32928 L
.72036 .16187 L
s
.678 .847 .902 r
.72036 .16187 m
.72036 .32977 L
.72074 .32977 L
.72074 .16187 L
F
.2 .63 .79 r
.72036 .16187 m
.72036 .32977 L
.72074 .32977 L
.72074 .16187 L
s
.678 .847 .902 r
.72074 .16187 m
.72074 .33026 L
.72174 .33026 L
.72174 .16187 L
F
.2 .63 .79 r
.72074 .16187 m
.72074 .33026 L
.72174 .33026 L
.72174 .16187 L
s
.678 .847 .902 r
.72174 .16187 m
.72174 .33114 L
.72226 .33114 L
.72226 .16187 L
F
.2 .63 .79 r
.72174 .16187 m
.72174 .33114 L
.72226 .33114 L
.72226 .16187 L
s
.678 .847 .902 r
.72226 .16187 m
.72226 .33137 L
.72312 .33137 L
.72312 .16187 L
F
.2 .63 .79 r
.72226 .16187 m
.72226 .33137 L
.72312 .33137 L
.72312 .16187 L
s
.678 .847 .902 r
.72312 .16187 m
.72312 .33259 L
.72405 .33259 L
.72405 .16187 L
F
.2 .63 .79 r
.72312 .16187 m
.72312 .33259 L
.72405 .33259 L
.72405 .16187 L
s
.678 .847 .902 r
.72405 .16187 m
.72405 .333 L
.72497 .333 L
.72497 .16187 L
F
.2 .63 .79 r
.72405 .16187 m
.72405 .333 L
.72497 .333 L
.72497 .16187 L
s
.678 .847 .902 r
.72497 .16187 m
.72497 .33385 L
.72534 .33385 L
.72534 .16187 L
F
.2 .63 .79 r
.72497 .16187 m
.72497 .33385 L
.72534 .33385 L
.72534 .16187 L
s
.678 .847 .902 r
.72534 .16187 m
.72534 .33415 L
.72575 .33415 L
.72575 .16187 L
F
.2 .63 .79 r
.72534 .16187 m
.72534 .33415 L
.72575 .33415 L
.72575 .16187 L
s
.678 .847 .902 r
.72575 .16187 m
.72575 .33459 L
.72653 .33459 L
.72653 .16187 L
F
.2 .63 .79 r
.72575 .16187 m
.72575 .33459 L
.72653 .33459 L
.72653 .16187 L
s
.678 .847 .902 r
.72653 .16187 m
.72653 .33519 L
.72688 .33519 L
.72688 .16187 L
F
.2 .63 .79 r
.72653 .16187 m
.72653 .33519 L
.72688 .33519 L
.72688 .16187 L
s
.678 .847 .902 r
.72688 .16187 m
.72688 .33599 L
.72746 .33599 L
.72746 .16187 L
F
.2 .63 .79 r
.72688 .16187 m
.72688 .33599 L
.72746 .33599 L
.72746 .16187 L
s
.678 .847 .902 r
.72746 .16187 m
.72746 .33651 L
.72801 .33651 L
.72801 .16187 L
F
.2 .63 .79 r
.72746 .16187 m
.72746 .33651 L
.72801 .33651 L
.72801 .16187 L
s
.678 .847 .902 r
.72801 .16187 m
.72801 .33671 L
.72869 .33671 L
.72869 .16187 L
F
.2 .63 .79 r
.72801 .16187 m
.72801 .33671 L
.72869 .33671 L
.72869 .16187 L
s
.678 .847 .902 r
.72869 .16187 m
.72869 .33726 L
.72972 .33726 L
.72972 .16187 L
F
.2 .63 .79 r
.72869 .16187 m
.72869 .33726 L
.72972 .33726 L
.72972 .16187 L
s
.678 .847 .902 r
.72972 .16187 m
.72972 .33857 L
.73038 .33857 L
.73038 .16187 L
F
.2 .63 .79 r
.72972 .16187 m
.72972 .33857 L
.73038 .33857 L
.73038 .16187 L
s
.678 .847 .902 r
.73038 .16187 m
.73038 .33869 L
.7307 .33869 L
.7307 .16187 L
F
.2 .63 .79 r
.73038 .16187 m
.73038 .33869 L
.7307 .33869 L
.7307 .16187 L
s
.678 .847 .902 r
.7307 .16187 m
.7307 .33972 L
.73155 .33972 L
.73155 .16187 L
F
.2 .63 .79 r
.7307 .16187 m
.7307 .33972 L
.73155 .33972 L
.73155 .16187 L
s
.678 .847 .902 r
.73155 .16187 m
.73155 .34004 L
.73188 .34004 L
.73188 .16187 L
F
.2 .63 .79 r
.73155 .16187 m
.73155 .34004 L
.73188 .34004 L
.73188 .16187 L
s
.678 .847 .902 r
.73188 .16187 m
.73188 .34031 L
.73263 .34031 L
.73263 .16187 L
F
.2 .63 .79 r
.73188 .16187 m
.73188 .34031 L
.73263 .34031 L
.73263 .16187 L
s
.678 .847 .902 r
.73263 .16187 m
.73263 .34136 L
.73346 .34136 L
.73346 .16187 L
F
.2 .63 .79 r
.73263 .16187 m
.73263 .34136 L
.73346 .34136 L
.73346 .16187 L
s
.678 .847 .902 r
.73346 .16187 m
.73346 .34215 L
.73429 .34215 L
.73429 .16187 L
F
.2 .63 .79 r
.73346 .16187 m
.73346 .34215 L
.73429 .34215 L
.73429 .16187 L
s
.678 .847 .902 r
.73429 .16187 m
.73429 .34266 L
.73481 .34266 L
.73481 .16187 L
F
.2 .63 .79 r
.73429 .16187 m
.73429 .34266 L
.73481 .34266 L
.73481 .16187 L
s
.678 .847 .902 r
.73481 .16187 m
.73481 .34291 L
.73557 .34291 L
.73557 .16187 L
F
.2 .63 .79 r
.73481 .16187 m
.73481 .34291 L
.73557 .34291 L
.73557 .16187 L
s
.678 .847 .902 r
.73557 .16187 m
.73557 .34365 L
.73613 .34365 L
.73613 .16187 L
F
.2 .63 .79 r
.73557 .16187 m
.73557 .34365 L
.73613 .34365 L
.73613 .16187 L
s
.678 .847 .902 r
.73613 .16187 m
.73613 .34416 L
.73689 .34416 L
.73689 .16187 L
F
.2 .63 .79 r
.73613 .16187 m
.73613 .34416 L
.73689 .34416 L
.73689 .16187 L
s
.678 .847 .902 r
.73689 .16187 m
.73689 .34489 L
.73745 .34489 L
.73745 .16187 L
F
.2 .63 .79 r
.73689 .16187 m
.73689 .34489 L
.73745 .34489 L
.73745 .16187 L
s
.678 .847 .902 r
.73745 .16187 m
.73745 .34547 L
.738 .34547 L
.738 .16187 L
F
.2 .63 .79 r
.73745 .16187 m
.73745 .34547 L
.738 .34547 L
.738 .16187 L
s
.678 .847 .902 r
.738 .16187 m
.738 .34588 L
.73873 .34588 L
.73873 .16187 L
F
.2 .63 .79 r
.738 .16187 m
.738 .34588 L
.73873 .34588 L
.73873 .16187 L
s
.678 .847 .902 r
.73873 .16187 m
.73873 .34689 L
.73959 .34689 L
.73959 .16187 L
F
.2 .63 .79 r
.73873 .16187 m
.73873 .34689 L
.73959 .34689 L
.73959 .16187 L
s
.678 .847 .902 r
.73959 .16187 m
.73959 .34738 L
.74027 .34738 L
.74027 .16187 L
F
.2 .63 .79 r
.73959 .16187 m
.73959 .34738 L
.74027 .34738 L
.74027 .16187 L
s
.678 .847 .902 r
.74027 .16187 m
.74027 .34792 L
.74076 .34792 L
.74076 .16187 L
F
.2 .63 .79 r
.74027 .16187 m
.74027 .34792 L
.74076 .34792 L
.74076 .16187 L
s
.678 .847 .902 r
.74076 .16187 m
.74076 .34831 L
.7414 .34831 L
.7414 .16187 L
F
.2 .63 .79 r
.74076 .16187 m
.74076 .34831 L
.7414 .34831 L
.7414 .16187 L
s
.678 .847 .902 r
.7414 .16187 m
.7414 .34903 L
.74179 .34903 L
.74179 .16187 L
F
.2 .63 .79 r
.7414 .16187 m
.7414 .34903 L
.74179 .34903 L
.74179 .16187 L
s
.678 .847 .902 r
.74179 .16187 m
.74179 .34938 L
.74243 .34938 L
.74243 .16187 L
F
.2 .63 .79 r
.74179 .16187 m
.74179 .34938 L
.74243 .34938 L
.74243 .16187 L
s
.678 .847 .902 r
.74243 .16187 m
.74243 .35007 L
.74337 .35007 L
.74337 .16187 L
F
.2 .63 .79 r
.74243 .16187 m
.74243 .35007 L
.74337 .35007 L
.74337 .16187 L
s
.678 .847 .902 r
.74337 .16187 m
.74337 .35074 L
.74377 .35074 L
.74377 .16187 L
F
.2 .63 .79 r
.74337 .16187 m
.74337 .35074 L
.74377 .35074 L
.74377 .16187 L
s
.678 .847 .902 r
.74377 .16187 m
.74377 .35118 L
.74451 .35118 L
.74451 .16187 L
F
.2 .63 .79 r
.74377 .16187 m
.74377 .35118 L
.74451 .35118 L
.74451 .16187 L
s
.678 .847 .902 r
.74451 .16187 m
.74451 .35185 L
.74516 .35185 L
.74516 .16187 L
F
.2 .63 .79 r
.74451 .16187 m
.74451 .35185 L
.74516 .35185 L
.74516 .16187 L
s
.678 .847 .902 r
.74516 .16187 m
.74516 .35264 L
.74575 .35264 L
.74575 .16187 L
F
.2 .63 .79 r
.74516 .16187 m
.74516 .35264 L
.74575 .35264 L
.74575 .16187 L
s
.678 .847 .902 r
.74575 .16187 m
.74575 .35296 L
.74614 .35296 L
.74614 .16187 L
F
.2 .63 .79 r
.74575 .16187 m
.74575 .35296 L
.74614 .35296 L
.74614 .16187 L
s
.678 .847 .902 r
.74614 .16187 m
.74614 .35346 L
.74707 .35346 L
.74707 .16187 L
F
.2 .63 .79 r
.74614 .16187 m
.74614 .35346 L
.74707 .35346 L
.74707 .16187 L
s
.678 .847 .902 r
.74707 .16187 m
.74707 .3543 L
.7477 .3543 L
.7477 .16187 L
F
.2 .63 .79 r
.74707 .16187 m
.74707 .3543 L
.7477 .3543 L
.7477 .16187 L
s
.678 .847 .902 r
.7477 .16187 m
.7477 .35486 L
.74857 .35486 L
.74857 .16187 L
F
.2 .63 .79 r
.7477 .16187 m
.7477 .35486 L
.74857 .35486 L
.74857 .16187 L
s
.678 .847 .902 r
.74857 .16187 m
.74857 .35574 L
.74917 .35574 L
.74917 .16187 L
F
.2 .63 .79 r
.74857 .16187 m
.74857 .35574 L
.74917 .35574 L
.74917 .16187 L
s
.678 .847 .902 r
.74917 .16187 m
.74917 .35629 L
.74958 .35629 L
.74958 .16187 L
F
.2 .63 .79 r
.74917 .16187 m
.74917 .35629 L
.74958 .35629 L
.74958 .16187 L
s
.678 .847 .902 r
.74958 .16187 m
.74958 .3567 L
.74999 .3567 L
.74999 .16187 L
F
.2 .63 .79 r
.74958 .16187 m
.74958 .3567 L
.74999 .3567 L
.74999 .16187 L
s
.678 .847 .902 r
.74999 .16187 m
.74999 .35729 L
.75042 .35729 L
.75042 .16187 L
F
.2 .63 .79 r
.74999 .16187 m
.74999 .35729 L
.75042 .35729 L
.75042 .16187 L
s
.678 .847 .902 r
.75042 .16187 m
.75042 .35763 L
.75077 .35763 L
.75077 .16187 L
F
.2 .63 .79 r
.75042 .16187 m
.75042 .35763 L
.75077 .35763 L
.75077 .16187 L
s
.678 .847 .902 r
.75077 .16187 m
.75077 .35773 L
.75146 .35773 L
.75146 .16187 L
F
.2 .63 .79 r
.75077 .16187 m
.75077 .35773 L
.75146 .35773 L
.75146 .16187 L
s
.678 .847 .902 r
.75146 .16187 m
.75146 .35833 L
.75235 .35833 L
.75235 .16187 L
F
.2 .63 .79 r
.75146 .16187 m
.75146 .35833 L
.75235 .35833 L
.75235 .16187 L
s
.678 .847 .902 r
.75235 .16187 m
.75235 .35949 L
.75326 .35949 L
.75326 .16187 L
F
.2 .63 .79 r
.75235 .16187 m
.75235 .35949 L
.75326 .35949 L
.75326 .16187 L
s
.678 .847 .902 r
.75326 .16187 m
.75326 .36043 L
.75391 .36043 L
.75391 .16187 L
F
.2 .63 .79 r
.75326 .16187 m
.75326 .36043 L
.75391 .36043 L
.75391 .16187 L
s
.678 .847 .902 r
.75391 .16187 m
.75391 .36103 L
.75478 .36103 L
.75478 .16187 L
F
.2 .63 .79 r
.75391 .16187 m
.75391 .36103 L
.75478 .36103 L
.75478 .16187 L
s
.678 .847 .902 r
.75478 .16187 m
.75478 .36181 L
.7553 .36181 L
.7553 .16187 L
F
.2 .63 .79 r
.75478 .16187 m
.75478 .36181 L
.7553 .36181 L
.7553 .16187 L
s
.678 .847 .902 r
.7553 .16187 m
.7553 .36206 L
.75603 .36206 L
.75603 .16187 L
F
.2 .63 .79 r
.7553 .16187 m
.7553 .36206 L
.75603 .36206 L
.75603 .16187 L
s
.678 .847 .902 r
.75603 .16187 m
.75603 .36283 L
.75635 .36283 L
.75635 .16187 L
F
.2 .63 .79 r
.75603 .16187 m
.75603 .36283 L
.75635 .36283 L
.75635 .16187 L
s
.678 .847 .902 r
.75635 .16187 m
.75635 .36298 L
.75714 .36298 L
.75714 .16187 L
F
.2 .63 .79 r
.75635 .16187 m
.75635 .36298 L
.75714 .36298 L
.75714 .16187 L
s
.678 .847 .902 r
.75714 .16187 m
.75714 .36412 L
.75806 .36412 L
.75806 .16187 L
F
.2 .63 .79 r
.75714 .16187 m
.75714 .36412 L
.75806 .36412 L
.75806 .16187 L
s
.678 .847 .902 r
.75806 .16187 m
.75806 .36528 L
.75888 .36528 L
.75888 .16187 L
F
.2 .63 .79 r
.75806 .16187 m
.75806 .36528 L
.75888 .36528 L
.75888 .16187 L
s
.678 .847 .902 r
.75888 .16187 m
.75888 .36587 L
.75983 .36587 L
.75983 .16187 L
F
.2 .63 .79 r
.75888 .16187 m
.75888 .36587 L
.75983 .36587 L
.75983 .16187 L
s
.678 .847 .902 r
.75983 .16187 m
.75983 .36658 L
.7602 .36658 L
.7602 .16187 L
F
.2 .63 .79 r
.75983 .16187 m
.75983 .36658 L
.7602 .36658 L
.7602 .16187 L
s
.678 .847 .902 r
.7602 .16187 m
.7602 .36682 L
.76078 .36682 L
.76078 .16187 L
F
.2 .63 .79 r
.7602 .16187 m
.7602 .36682 L
.76078 .36682 L
.76078 .16187 L
s
.678 .847 .902 r
.76078 .16187 m
.76078 .3674 L
.76131 .3674 L
.76131 .16187 L
F
.2 .63 .79 r
.76078 .16187 m
.76078 .3674 L
.76131 .3674 L
.76131 .16187 L
s
.678 .847 .902 r
.76131 .16187 m
.76131 .36811 L
.7622 .36811 L
.7622 .16187 L
F
.2 .63 .79 r
.76131 .16187 m
.76131 .36811 L
.7622 .36811 L
.7622 .16187 L
s
.678 .847 .902 r
.7622 .16187 m
.7622 .36885 L
.76266 .36885 L
.76266 .16187 L
F
.2 .63 .79 r
.7622 .16187 m
.7622 .36885 L
.76266 .36885 L
.76266 .16187 L
s
.678 .847 .902 r
.76266 .16187 m
.76266 .36912 L
.76365 .36912 L
.76365 .16187 L
F
.2 .63 .79 r
.76266 .16187 m
.76266 .36912 L
.76365 .36912 L
.76365 .16187 L
s
.678 .847 .902 r
.76365 .16187 m
.76365 .37014 L
.76434 .37014 L
.76434 .16187 L
F
.2 .63 .79 r
.76365 .16187 m
.76365 .37014 L
.76434 .37014 L
.76434 .16187 L
s
.678 .847 .902 r
.76434 .16187 m
.76434 .37073 L
.76494 .37073 L
.76494 .16187 L
F
.2 .63 .79 r
.76434 .16187 m
.76434 .37073 L
.76494 .37073 L
.76494 .16187 L
s
.678 .847 .902 r
.76494 .16187 m
.76494 .37129 L
.76531 .37129 L
.76531 .16187 L
F
.2 .63 .79 r
.76494 .16187 m
.76494 .37129 L
.76531 .37129 L
.76531 .16187 L
s
.678 .847 .902 r
.76531 .16187 m
.76531 .37213 L
.76619 .37213 L
.76619 .16187 L
F
.2 .63 .79 r
.76531 .16187 m
.76531 .37213 L
.76619 .37213 L
.76619 .16187 L
s
.678 .847 .902 r
.76619 .16187 m
.76619 .3726 L
.76677 .3726 L
.76677 .16187 L
F
.2 .63 .79 r
.76619 .16187 m
.76619 .3726 L
.76677 .3726 L
.76677 .16187 L
s
.678 .847 .902 r
.76677 .16187 m
.76677 .3731 L
.76733 .3731 L
.76733 .16187 L
F
.2 .63 .79 r
.76677 .16187 m
.76677 .3731 L
.76733 .3731 L
.76733 .16187 L
s
.678 .847 .902 r
.76733 .16187 m
.76733 .37364 L
.76804 .37364 L
.76804 .16187 L
F
.2 .63 .79 r
.76733 .16187 m
.76733 .37364 L
.76804 .37364 L
.76804 .16187 L
s
.678 .847 .902 r
.76804 .16187 m
.76804 .37485 L
.76907 .37485 L
.76907 .16187 L
F
.2 .63 .79 r
.76804 .16187 m
.76804 .37485 L
.76907 .37485 L
.76907 .16187 L
s
.678 .847 .902 r
.76907 .16187 m
.76907 .37517 L
.76977 .37517 L
.76977 .16187 L
F
.2 .63 .79 r
.76907 .16187 m
.76907 .37517 L
.76977 .37517 L
.76977 .16187 L
s
.678 .847 .902 r
.76977 .16187 m
.76977 .37642 L
.77072 .37642 L
.77072 .16187 L
F
.2 .63 .79 r
.76977 .16187 m
.76977 .37642 L
.77072 .37642 L
.77072 .16187 L
s
.678 .847 .902 r
.77072 .16187 m
.77072 .3774 L
.7716 .3774 L
.7716 .16187 L
F
.2 .63 .79 r
.77072 .16187 m
.77072 .3774 L
.7716 .3774 L
.7716 .16187 L
s
.678 .847 .902 r
.7716 .16187 m
.7716 .37836 L
.77241 .37836 L
.77241 .16187 L
F
.2 .63 .79 r
.7716 .16187 m
.7716 .37836 L
.77241 .37836 L
.77241 .16187 L
s
.678 .847 .902 r
.77241 .16187 m
.77241 .37923 L
.77342 .37923 L
.77342 .16187 L
F
.2 .63 .79 r
.77241 .16187 m
.77241 .37923 L
.77342 .37923 L
.77342 .16187 L
s
.678 .847 .902 r
.77342 .16187 m
.77342 .37938 L
.77437 .37938 L
.77437 .16187 L
F
.2 .63 .79 r
.77342 .16187 m
.77342 .37938 L
.77437 .37938 L
.77437 .16187 L
s
.678 .847 .902 r
.77437 .16187 m
.77437 .38056 L
.77476 .38056 L
.77476 .16187 L
F
.2 .63 .79 r
.77437 .16187 m
.77437 .38056 L
.77476 .38056 L
.77476 .16187 L
s
.678 .847 .902 r
.77476 .16187 m
.77476 .38111 L
.77569 .38111 L
.77569 .16187 L
F
.2 .63 .79 r
.77476 .16187 m
.77476 .38111 L
.77569 .38111 L
.77569 .16187 L
s
.678 .847 .902 r
.77569 .16187 m
.77569 .38204 L
.77619 .38204 L
.77619 .16187 L
F
.2 .63 .79 r
.77569 .16187 m
.77569 .38204 L
.77619 .38204 L
.77619 .16187 L
s
.678 .847 .902 r
.77619 .16187 m
.77619 .38251 L
.77722 .38251 L
.77722 .16187 L
F
.2 .63 .79 r
.77619 .16187 m
.77619 .38251 L
.77722 .38251 L
.77722 .16187 L
s
.678 .847 .902 r
.77722 .16187 m
.77722 .38334 L
.77756 .38334 L
.77756 .16187 L
F
.2 .63 .79 r
.77722 .16187 m
.77722 .38334 L
.77756 .38334 L
.77756 .16187 L
s
.678 .847 .902 r
.77756 .16187 m
.77756 .38347 L
.77822 .38347 L
.77822 .16187 L
F
.2 .63 .79 r
.77756 .16187 m
.77756 .38347 L
.77822 .38347 L
.77822 .16187 L
s
.678 .847 .902 r
.77822 .16187 m
.77822 .38455 L
.77922 .38455 L
.77922 .16187 L
F
.2 .63 .79 r
.77822 .16187 m
.77822 .38455 L
.77922 .38455 L
.77922 .16187 L
s
.678 .847 .902 r
.77922 .16187 m
.77922 .38544 L
.77967 .38544 L
.77967 .16187 L
F
.2 .63 .79 r
.77922 .16187 m
.77922 .38544 L
.77967 .38544 L
.77967 .16187 L
s
.678 .847 .902 r
.77967 .16187 m
.77967 .38555 L
.78058 .38555 L
.78058 .16187 L
F
.2 .63 .79 r
.77967 .16187 m
.77967 .38555 L
.78058 .38555 L
.78058 .16187 L
s
.678 .847 .902 r
.78058 .16187 m
.78058 .38703 L
.78129 .38703 L
.78129 .16187 L
F
.2 .63 .79 r
.78058 .16187 m
.78058 .38703 L
.78129 .38703 L
.78129 .16187 L
s
.678 .847 .902 r
.78129 .16187 m
.78129 .38717 L
.78191 .38717 L
.78191 .16187 L
F
.2 .63 .79 r
.78129 .16187 m
.78129 .38717 L
.78191 .38717 L
.78191 .16187 L
s
.678 .847 .902 r
.78191 .16187 m
.78191 .38826 L
.7828 .38826 L
.7828 .16187 L
F
.2 .63 .79 r
.78191 .16187 m
.78191 .38826 L
.7828 .38826 L
.7828 .16187 L
s
.678 .847 .902 r
.7828 .16187 m
.7828 .38914 L
.78365 .38914 L
.78365 .16187 L
F
.2 .63 .79 r
.7828 .16187 m
.7828 .38914 L
.78365 .38914 L
.78365 .16187 L
s
.678 .847 .902 r
.78365 .16187 m
.78365 .38958 L
.78451 .38958 L
.78451 .16187 L
F
.2 .63 .79 r
.78365 .16187 m
.78365 .38958 L
.78451 .38958 L
.78451 .16187 L
s
.678 .847 .902 r
.78451 .16187 m
.78451 .39049 L
.78486 .39049 L
.78486 .16187 L
F
.2 .63 .79 r
.78451 .16187 m
.78451 .39049 L
.78486 .39049 L
.78486 .16187 L
s
.678 .847 .902 r
.78486 .16187 m
.78486 .39079 L
.7855 .39079 L
.7855 .16187 L
F
.2 .63 .79 r
.78486 .16187 m
.78486 .39079 L
.7855 .39079 L
.7855 .16187 L
s
.678 .847 .902 r
.7855 .16187 m
.7855 .39141 L
.78596 .39141 L
.78596 .16187 L
F
.2 .63 .79 r
.7855 .16187 m
.7855 .39141 L
.78596 .39141 L
.78596 .16187 L
s
.678 .847 .902 r
.78596 .16187 m
.78596 .39211 L
.78682 .39211 L
.78682 .16187 L
F
.2 .63 .79 r
.78596 .16187 m
.78596 .39211 L
.78682 .39211 L
.78682 .16187 L
s
.678 .847 .902 r
.78682 .16187 m
.78682 .393 L
.78751 .393 L
.78751 .16187 L
F
.2 .63 .79 r
.78682 .16187 m
.78682 .393 L
.78751 .393 L
.78751 .16187 L
s
.678 .847 .902 r
.78751 .16187 m
.78751 .39369 L
.78822 .39369 L
.78822 .16187 L
F
.2 .63 .79 r
.78751 .16187 m
.78751 .39369 L
.78822 .39369 L
.78822 .16187 L
s
.678 .847 .902 r
.78822 .16187 m
.78822 .39433 L
.78885 .39433 L
.78885 .16187 L
F
.2 .63 .79 r
.78822 .16187 m
.78822 .39433 L
.78885 .39433 L
.78885 .16187 L
s
.678 .847 .902 r
.78885 .16187 m
.78885 .39472 L
.7892 .39472 L
.7892 .16187 L
F
.2 .63 .79 r
.78885 .16187 m
.78885 .39472 L
.7892 .39472 L
.7892 .16187 L
s
.678 .847 .902 r
.7892 .16187 m
.7892 .39548 L
.78992 .39548 L
.78992 .16187 L
F
.2 .63 .79 r
.7892 .16187 m
.7892 .39548 L
.78992 .39548 L
.78992 .16187 L
s
.678 .847 .902 r
.78992 .16187 m
.78992 .39613 L
.79072 .39613 L
.79072 .16187 L
F
.2 .63 .79 r
.78992 .16187 m
.78992 .39613 L
.79072 .39613 L
.79072 .16187 L
s
.678 .847 .902 r
.79072 .16187 m
.79072 .3969 L
.79126 .3969 L
.79126 .16187 L
F
.2 .63 .79 r
.79072 .16187 m
.79072 .3969 L
.79126 .3969 L
.79126 .16187 L
s
.678 .847 .902 r
.79126 .16187 m
.79126 .39696 L
.79173 .39696 L
.79173 .16187 L
F
.2 .63 .79 r
.79126 .16187 m
.79126 .39696 L
.79173 .39696 L
.79173 .16187 L
s
.678 .847 .902 r
.79173 .16187 m
.79173 .39785 L
.79226 .39785 L
.79226 .16187 L
F
.2 .63 .79 r
.79173 .16187 m
.79173 .39785 L
.79226 .39785 L
.79226 .16187 L
s
.678 .847 .902 r
.79226 .16187 m
.79226 .3981 L
.79306 .3981 L
.79306 .16187 L
F
.2 .63 .79 r
.79226 .16187 m
.79226 .3981 L
.79306 .3981 L
.79306 .16187 L
s
.678 .847 .902 r
.79306 .16187 m
.79306 .39879 L
.79358 .39879 L
.79358 .16187 L
F
.2 .63 .79 r
.79306 .16187 m
.79306 .39879 L
.79358 .39879 L
.79358 .16187 L
s
.678 .847 .902 r
.79358 .16187 m
.79358 .40003 L
.79441 .40003 L
.79441 .16187 L
F
.2 .63 .79 r
.79358 .16187 m
.79358 .40003 L
.79441 .40003 L
.79441 .16187 L
s
.678 .847 .902 r
.79441 .16187 m
.79441 .40028 L
.79498 .40028 L
.79498 .16187 L
F
.2 .63 .79 r
.79441 .16187 m
.79441 .40028 L
.79498 .40028 L
.79498 .16187 L
s
.678 .847 .902 r
.79498 .16187 m
.79498 .40084 L
.79564 .40084 L
.79564 .16187 L
F
.2 .63 .79 r
.79498 .16187 m
.79498 .40084 L
.79564 .40084 L
.79564 .16187 L
s
.678 .847 .902 r
.79564 .16187 m
.79564 .40133 L
.79628 .40133 L
.79628 .16187 L
F
.2 .63 .79 r
.79564 .16187 m
.79564 .40133 L
.79628 .40133 L
.79628 .16187 L
s
.678 .847 .902 r
.79628 .16187 m
.79628 .40194 L
.79672 .40194 L
.79672 .16187 L
F
.2 .63 .79 r
.79628 .16187 m
.79628 .40194 L
.79672 .40194 L
.79672 .16187 L
s
.678 .847 .902 r
.79672 .16187 m
.79672 .40257 L
.7977 .40257 L
.7977 .16187 L
F
.2 .63 .79 r
.79672 .16187 m
.79672 .40257 L
.7977 .40257 L
.7977 .16187 L
s
.678 .847 .902 r
.7977 .16187 m
.7977 .40388 L
.79851 .40388 L
.79851 .16187 L
F
.2 .63 .79 r
.7977 .16187 m
.7977 .40388 L
.79851 .40388 L
.79851 .16187 L
s
.678 .847 .902 r
.79851 .16187 m
.79851 .40446 L
.79933 .40446 L
.79933 .16187 L
F
.2 .63 .79 r
.79851 .16187 m
.79851 .40446 L
.79933 .40446 L
.79933 .16187 L
s
.678 .847 .902 r
.79933 .16187 m
.79933 .40548 L
.79994 .40548 L
.79994 .16187 L
F
.2 .63 .79 r
.79933 .16187 m
.79933 .40548 L
.79994 .40548 L
.79994 .16187 L
s
.678 .847 .902 r
.79994 .16187 m
.79994 .40604 L
.80089 .40604 L
.80089 .16187 L
F
.2 .63 .79 r
.79994 .16187 m
.79994 .40604 L
.80089 .40604 L
.80089 .16187 L
s
.678 .847 .902 r
.80089 .16187 m
.80089 .40672 L
.80137 .40672 L
.80137 .16187 L
F
.2 .63 .79 r
.80089 .16187 m
.80089 .40672 L
.80137 .40672 L
.80137 .16187 L
s
.678 .847 .902 r
.80137 .16187 m
.80137 .40766 L
.80204 .40766 L
.80204 .16187 L
F
.2 .63 .79 r
.80137 .16187 m
.80137 .40766 L
.80204 .40766 L
.80204 .16187 L
s
.678 .847 .902 r
.80204 .16187 m
.80204 .40794 L
.80282 .40794 L
.80282 .16187 L
F
.2 .63 .79 r
.80204 .16187 m
.80204 .40794 L
.80282 .40794 L
.80282 .16187 L
s
.678 .847 .902 r
.80282 .16187 m
.80282 .40895 L
.80339 .40895 L
.80339 .16187 L
F
.2 .63 .79 r
.80282 .16187 m
.80282 .40895 L
.80339 .40895 L
.80339 .16187 L
s
.678 .847 .902 r
.80339 .16187 m
.80339 .4096 L
.8042 .4096 L
.8042 .16187 L
F
.2 .63 .79 r
.80339 .16187 m
.80339 .4096 L
.8042 .4096 L
.8042 .16187 L
s
.678 .847 .902 r
.8042 .16187 m
.8042 .41 L
.80456 .41 L
.80456 .16187 L
F
.2 .63 .79 r
.8042 .16187 m
.8042 .41 L
.80456 .41 L
.80456 .16187 L
s
.678 .847 .902 r
.80456 .16187 m
.80456 .41081 L
.80529 .41081 L
.80529 .16187 L
F
.2 .63 .79 r
.80456 .16187 m
.80456 .41081 L
.80529 .41081 L
.80529 .16187 L
s
.678 .847 .902 r
.80529 .16187 m
.80529 .41183 L
.80618 .41183 L
.80618 .16187 L
F
.2 .63 .79 r
.80529 .16187 m
.80529 .41183 L
.80618 .41183 L
.80618 .16187 L
s
.678 .847 .902 r
.80618 .16187 m
.80618 .41223 L
.80649 .41223 L
.80649 .16187 L
F
.2 .63 .79 r
.80618 .16187 m
.80618 .41223 L
.80649 .41223 L
.80649 .16187 L
s
.678 .847 .902 r
.80649 .16187 m
.80649 .41247 L
.80735 .41247 L
.80735 .16187 L
F
.2 .63 .79 r
.80649 .16187 m
.80649 .41247 L
.80735 .41247 L
.80735 .16187 L
s
.678 .847 .902 r
.80735 .16187 m
.80735 .4135 L
.80793 .4135 L
.80793 .16187 L
F
.2 .63 .79 r
.80735 .16187 m
.80735 .4135 L
.80793 .4135 L
.80793 .16187 L
s
.678 .847 .902 r
.80793 .16187 m
.80793 .41372 L
.8086 .41372 L
.8086 .16187 L
F
.2 .63 .79 r
.80793 .16187 m
.80793 .41372 L
.8086 .41372 L
.8086 .16187 L
s
.678 .847 .902 r
.8086 .16187 m
.8086 .41478 L
.80914 .41478 L
.80914 .16187 L
F
.2 .63 .79 r
.8086 .16187 m
.8086 .41478 L
.80914 .41478 L
.80914 .16187 L
s
.678 .847 .902 r
.80914 .16187 m
.80914 .41503 L
.80979 .41503 L
.80979 .16187 L
F
.2 .63 .79 r
.80914 .16187 m
.80914 .41503 L
.80979 .41503 L
.80979 .16187 L
s
.678 .847 .902 r
.80979 .16187 m
.80979 .41615 L
.81058 .41615 L
.81058 .16187 L
F
.2 .63 .79 r
.80979 .16187 m
.80979 .41615 L
.81058 .41615 L
.81058 .16187 L
s
.678 .847 .902 r
.81058 .16187 m
.81058 .41668 L
.81099 .41668 L
.81099 .16187 L
F
.2 .63 .79 r
.81058 .16187 m
.81058 .41668 L
.81099 .41668 L
.81099 .16187 L
s
.678 .847 .902 r
.81099 .16187 m
.81099 .4172 L
.81191 .4172 L
.81191 .16187 L
F
.2 .63 .79 r
.81099 .16187 m
.81099 .4172 L
.81191 .4172 L
.81191 .16187 L
s
.678 .847 .902 r
.81191 .16187 m
.81191 .41779 L
.81223 .41779 L
.81223 .16187 L
F
.2 .63 .79 r
.81191 .16187 m
.81191 .41779 L
.81223 .41779 L
.81223 .16187 L
s
.678 .847 .902 r
.81223 .16187 m
.81223 .41855 L
.81289 .41855 L
.81289 .16187 L
F
.2 .63 .79 r
.81223 .16187 m
.81223 .41855 L
.81289 .41855 L
.81289 .16187 L
s
.678 .847 .902 r
.81289 .16187 m
.81289 .41899 L
.81334 .41899 L
.81334 .16187 L
F
.2 .63 .79 r
.81289 .16187 m
.81289 .41899 L
.81334 .41899 L
.81334 .16187 L
s
.678 .847 .902 r
.81334 .16187 m
.81334 .41957 L
.81377 .41957 L
.81377 .16187 L
F
.2 .63 .79 r
.81334 .16187 m
.81334 .41957 L
.81377 .41957 L
.81377 .16187 L
s
.678 .847 .902 r
.81377 .16187 m
.81377 .42008 L
.8143 .42008 L
.8143 .16187 L
F
.2 .63 .79 r
.81377 .16187 m
.81377 .42008 L
.8143 .42008 L
.8143 .16187 L
s
.678 .847 .902 r
.8143 .16187 m
.8143 .42055 L
.81466 .42055 L
.81466 .16187 L
F
.2 .63 .79 r
.8143 .16187 m
.8143 .42055 L
.81466 .42055 L
.81466 .16187 L
s
.678 .847 .902 r
.81466 .16187 m
.81466 .4206 L
.81521 .4206 L
.81521 .16187 L
F
.2 .63 .79 r
.81466 .16187 m
.81466 .4206 L
.81521 .4206 L
.81521 .16187 L
s
.678 .847 .902 r
.81521 .16187 m
.81521 .42163 L
.81618 .42163 L
.81618 .16187 L
F
.2 .63 .79 r
.81521 .16187 m
.81521 .42163 L
.81618 .42163 L
.81618 .16187 L
s
.678 .847 .902 r
.81618 .16187 m
.81618 .42294 L
.81708 .42294 L
.81708 .16187 L
F
.2 .63 .79 r
.81618 .16187 m
.81618 .42294 L
.81708 .42294 L
.81708 .16187 L
s
.678 .847 .902 r
.81708 .16187 m
.81708 .42348 L
.81769 .42348 L
.81769 .16187 L
F
.2 .63 .79 r
.81708 .16187 m
.81708 .42348 L
.81769 .42348 L
.81769 .16187 L
s
.678 .847 .902 r
.81769 .16187 m
.81769 .424 L
.81871 .424 L
.81871 .16187 L
F
.2 .63 .79 r
.81769 .16187 m
.81769 .424 L
.81871 .424 L
.81871 .16187 L
s
.678 .847 .902 r
.81871 .16187 m
.81871 .42518 L
.81919 .42518 L
.81919 .16187 L
F
.2 .63 .79 r
.81871 .16187 m
.81871 .42518 L
.81919 .42518 L
.81919 .16187 L
s
.678 .847 .902 r
.81919 .16187 m
.81919 .42582 L
.82003 .42582 L
.82003 .16187 L
F
.2 .63 .79 r
.81919 .16187 m
.81919 .42582 L
.82003 .42582 L
.82003 .16187 L
s
.678 .847 .902 r
.82003 .16187 m
.82003 .42702 L
.82095 .42702 L
.82095 .16187 L
F
.2 .63 .79 r
.82003 .16187 m
.82003 .42702 L
.82095 .42702 L
.82095 .16187 L
s
.678 .847 .902 r
.82095 .16187 m
.82095 .42725 L
.82139 .42725 L
.82139 .16187 L
F
.2 .63 .79 r
.82095 .16187 m
.82095 .42725 L
.82139 .42725 L
.82139 .16187 L
s
.678 .847 .902 r
.82139 .16187 m
.82139 .42798 L
.82187 .42798 L
.82187 .16187 L
F
.2 .63 .79 r
.82139 .16187 m
.82139 .42798 L
.82187 .42798 L
.82187 .16187 L
s
.678 .847 .902 r
.82187 .16187 m
.82187 .42844 L
.82289 .42844 L
.82289 .16187 L
F
.2 .63 .79 r
.82187 .16187 m
.82187 .42844 L
.82289 .42844 L
.82289 .16187 L
s
.678 .847 .902 r
.82289 .16187 m
.82289 .42928 L
.82353 .42928 L
.82353 .16187 L
F
.2 .63 .79 r
.82289 .16187 m
.82289 .42928 L
.82353 .42928 L
.82353 .16187 L
s
.678 .847 .902 r
.82353 .16187 m
.82353 .43006 L
.82435 .43006 L
.82435 .16187 L
F
.2 .63 .79 r
.82353 .16187 m
.82353 .43006 L
.82435 .43006 L
.82435 .16187 L
s
.678 .847 .902 r
.82435 .16187 m
.82435 .43082 L
.82531 .43082 L
.82531 .16187 L
F
.2 .63 .79 r
.82435 .16187 m
.82435 .43082 L
.82531 .43082 L
.82531 .16187 L
s
.678 .847 .902 r
.82531 .16187 m
.82531 .43179 L
.82599 .43179 L
.82599 .16187 L
F
.2 .63 .79 r
.82531 .16187 m
.82531 .43179 L
.82599 .43179 L
.82599 .16187 L
s
.678 .847 .902 r
.82599 .16187 m
.82599 .43289 L
.82689 .43289 L
.82689 .16187 L
F
.2 .63 .79 r
.82599 .16187 m
.82599 .43289 L
.82689 .43289 L
.82689 .16187 L
s
.678 .847 .902 r
.82689 .16187 m
.82689 .43377 L
.8276 .43377 L
.8276 .16187 L
F
.2 .63 .79 r
.82689 .16187 m
.82689 .43377 L
.8276 .43377 L
.8276 .16187 L
s
.678 .847 .902 r
.8276 .16187 m
.8276 .43429 L
.82796 .43429 L
.82796 .16187 L
F
.2 .63 .79 r
.8276 .16187 m
.8276 .43429 L
.82796 .43429 L
.82796 .16187 L
s
.678 .847 .902 r
.82796 .16187 m
.82796 .43449 L
.82863 .43449 L
.82863 .16187 L
F
.2 .63 .79 r
.82796 .16187 m
.82796 .43449 L
.82863 .43449 L
.82863 .16187 L
s
.678 .847 .902 r
.82863 .16187 m
.82863 .43559 L
.82917 .43559 L
.82917 .16187 L
F
.2 .63 .79 r
.82863 .16187 m
.82863 .43559 L
.82917 .43559 L
.82917 .16187 L
s
.678 .847 .902 r
.82917 .16187 m
.82917 .43577 L
.82975 .43577 L
.82975 .16187 L
F
.2 .63 .79 r
.82917 .16187 m
.82917 .43577 L
.82975 .43577 L
.82975 .16187 L
s
.678 .847 .902 r
.82975 .16187 m
.82975 .43628 L
.83071 .43628 L
.83071 .16187 L
F
.2 .63 .79 r
.82975 .16187 m
.82975 .43628 L
.83071 .43628 L
.83071 .16187 L
s
.678 .847 .902 r
.83071 .16187 m
.83071 .43745 L
.83116 .43745 L
.83116 .16187 L
F
.2 .63 .79 r
.83071 .16187 m
.83071 .43745 L
.83116 .43745 L
.83116 .16187 L
s
.678 .847 .902 r
.83116 .16187 m
.83116 .43773 L
.83166 .43773 L
.83166 .16187 L
F
.2 .63 .79 r
.83116 .16187 m
.83116 .43773 L
.83166 .43773 L
.83166 .16187 L
s
.678 .847 .902 r
.83166 .16187 m
.83166 .4383 L
.83199 .4383 L
.83199 .16187 L
F
.2 .63 .79 r
.83166 .16187 m
.83166 .4383 L
.83199 .4383 L
.83199 .16187 L
s
.678 .847 .902 r
.83199 .16187 m
.83199 .4392 L
.83302 .4392 L
.83302 .16187 L
F
.2 .63 .79 r
.83199 .16187 m
.83199 .4392 L
.83302 .4392 L
.83302 .16187 L
s
.678 .847 .902 r
.83302 .16187 m
.83302 .44002 L
.83361 .44002 L
.83361 .16187 L
F
.2 .63 .79 r
.83302 .16187 m
.83302 .44002 L
.83361 .44002 L
.83361 .16187 L
s
.678 .847 .902 r
.83361 .16187 m
.83361 .44065 L
.83453 .44065 L
.83453 .16187 L
F
.2 .63 .79 r
.83361 .16187 m
.83361 .44065 L
.83453 .44065 L
.83453 .16187 L
s
.678 .847 .902 r
.83453 .16187 m
.83453 .44158 L
.83487 .44158 L
.83487 .16187 L
F
.2 .63 .79 r
.83453 .16187 m
.83453 .44158 L
.83487 .44158 L
.83487 .16187 L
s
.678 .847 .902 r
.83487 .16187 m
.83487 .44225 L
.83573 .44225 L
.83573 .16187 L
F
.2 .63 .79 r
.83487 .16187 m
.83487 .44225 L
.83573 .44225 L
.83573 .16187 L
s
.678 .847 .902 r
.83573 .16187 m
.83573 .44328 L
.83652 .44328 L
.83652 .16187 L
F
.2 .63 .79 r
.83573 .16187 m
.83573 .44328 L
.83652 .44328 L
.83652 .16187 L
s
.678 .847 .902 r
.83652 .16187 m
.83652 .44382 L
.83755 .44382 L
.83755 .16187 L
F
.2 .63 .79 r
.83652 .16187 m
.83652 .44382 L
.83755 .44382 L
.83755 .16187 L
s
.678 .847 .902 r
.83755 .16187 m
.83755 .44498 L
.83849 .44498 L
.83849 .16187 L
F
.2 .63 .79 r
.83755 .16187 m
.83755 .44498 L
.83849 .44498 L
.83849 .16187 L
s
.678 .847 .902 r
.83849 .16187 m
.83849 .446 L
.83919 .446 L
.83919 .16187 L
F
.2 .63 .79 r
.83849 .16187 m
.83849 .446 L
.83919 .446 L
.83919 .16187 L
s
.678 .847 .902 r
.83919 .16187 m
.83919 .44661 L
.83999 .44661 L
.83999 .16187 L
F
.2 .63 .79 r
.83919 .16187 m
.83919 .44661 L
.83999 .44661 L
.83999 .16187 L
s
.678 .847 .902 r
.83999 .16187 m
.83999 .4471 L
.84069 .4471 L
.84069 .16187 L
F
.2 .63 .79 r
.83999 .16187 m
.83999 .4471 L
.84069 .4471 L
.84069 .16187 L
s
.678 .847 .902 r
.84069 .16187 m
.84069 .44784 L
.84112 .44784 L
.84112 .16187 L
F
.2 .63 .79 r
.84069 .16187 m
.84069 .44784 L
.84112 .44784 L
.84112 .16187 L
s
.678 .847 .902 r
.84112 .16187 m
.84112 .44867 L
.84189 .44867 L
.84189 .16187 L
F
.2 .63 .79 r
.84112 .16187 m
.84112 .44867 L
.84189 .44867 L
.84189 .16187 L
s
.678 .847 .902 r
.84189 .16187 m
.84189 .44914 L
.84232 .44914 L
.84232 .16187 L
F
.2 .63 .79 r
.84189 .16187 m
.84189 .44914 L
.84232 .44914 L
.84232 .16187 L
s
.678 .847 .902 r
.84232 .16187 m
.84232 .44993 L
.84316 .44993 L
.84316 .16187 L
F
.2 .63 .79 r
.84232 .16187 m
.84232 .44993 L
.84316 .44993 L
.84316 .16187 L
s
.678 .847 .902 r
.84316 .16187 m
.84316 .45076 L
.84392 .45076 L
.84392 .16187 L
F
.2 .63 .79 r
.84316 .16187 m
.84316 .45076 L
.84392 .45076 L
.84392 .16187 L
s
.678 .847 .902 r
.84392 .16187 m
.84392 .45175 L
.84464 .45175 L
.84464 .16187 L
F
.2 .63 .79 r
.84392 .16187 m
.84392 .45175 L
.84464 .45175 L
.84464 .16187 L
s
.678 .847 .902 r
.84464 .16187 m
.84464 .45201 L
.84543 .45201 L
.84543 .16187 L
F
.2 .63 .79 r
.84464 .16187 m
.84464 .45201 L
.84543 .45201 L
.84543 .16187 L
s
.678 .847 .902 r
.84543 .16187 m
.84543 .45315 L
.84604 .45315 L
.84604 .16187 L
F
.2 .63 .79 r
.84543 .16187 m
.84543 .45315 L
.84604 .45315 L
.84604 .16187 L
s
.678 .847 .902 r
.84604 .16187 m
.84604 .45356 L
.84653 .45356 L
.84653 .16187 L
F
.2 .63 .79 r
.84604 .16187 m
.84604 .45356 L
.84653 .45356 L
.84653 .16187 L
s
.678 .847 .902 r
.84653 .16187 m
.84653 .45454 L
.84733 .45454 L
.84733 .16187 L
F
.2 .63 .79 r
.84653 .16187 m
.84653 .45454 L
.84733 .45454 L
.84733 .16187 L
s
.678 .847 .902 r
.84733 .16187 m
.84733 .45524 L
.84797 .45524 L
.84797 .16187 L
F
.2 .63 .79 r
.84733 .16187 m
.84733 .45524 L
.84797 .45524 L
.84797 .16187 L
s
.678 .847 .902 r
.84797 .16187 m
.84797 .45574 L
.8484 .45574 L
.8484 .16187 L
F
.2 .63 .79 r
.84797 .16187 m
.84797 .45574 L
.8484 .45574 L
.8484 .16187 L
s
.678 .847 .902 r
.8484 .16187 m
.8484 .45646 L
.84887 .45646 L
.84887 .16187 L
F
.2 .63 .79 r
.8484 .16187 m
.8484 .45646 L
.84887 .45646 L
.84887 .16187 L
s
.678 .847 .902 r
.84887 .16187 m
.84887 .45655 L
.84967 .45655 L
.84967 .16187 L
F
.2 .63 .79 r
.84887 .16187 m
.84887 .45655 L
.84967 .45655 L
.84967 .16187 L
s
.678 .847 .902 r
.84967 .16187 m
.84967 .45733 L
.85004 .45733 L
.85004 .16187 L
F
.2 .63 .79 r
.84967 .16187 m
.84967 .45733 L
.85004 .45733 L
.85004 .16187 L
s
.678 .847 .902 r
.85004 .16187 m
.85004 .45779 L
.85059 .45779 L
.85059 .16187 L
F
.2 .63 .79 r
.85004 .16187 m
.85004 .45779 L
.85059 .45779 L
.85059 .16187 L
s
.678 .847 .902 r
.85059 .16187 m
.85059 .45832 L
.85102 .45832 L
.85102 .16187 L
F
.2 .63 .79 r
.85059 .16187 m
.85059 .45832 L
.85102 .45832 L
.85102 .16187 L
s
.678 .847 .902 r
.85102 .16187 m
.85102 .45917 L
.852 .45917 L
.852 .16187 L
F
.2 .63 .79 r
.85102 .16187 m
.85102 .45917 L
.852 .45917 L
.852 .16187 L
s
.678 .847 .902 r
.852 .16187 m
.852 .45987 L
.85261 .45987 L
.85261 .16187 L
F
.2 .63 .79 r
.852 .16187 m
.852 .45987 L
.85261 .45987 L
.85261 .16187 L
s
.678 .847 .902 r
.85261 .16187 m
.85261 .46088 L
.85316 .46088 L
.85316 .16187 L
F
.2 .63 .79 r
.85261 .16187 m
.85261 .46088 L
.85316 .46088 L
.85316 .16187 L
s
.678 .847 .902 r
.85316 .16187 m
.85316 .46134 L
.85369 .46134 L
.85369 .16187 L
F
.2 .63 .79 r
.85316 .16187 m
.85316 .46134 L
.85369 .46134 L
.85369 .16187 L
s
.678 .847 .902 r
.85369 .16187 m
.85369 .46202 L
.85428 .46202 L
.85428 .16187 L
F
.2 .63 .79 r
.85369 .16187 m
.85369 .46202 L
.85428 .46202 L
.85428 .16187 L
s
.678 .847 .902 r
.85428 .16187 m
.85428 .46277 L
.85513 .46277 L
.85513 .16187 L
F
.2 .63 .79 r
.85428 .16187 m
.85428 .46277 L
.85513 .46277 L
.85513 .16187 L
s
.678 .847 .902 r
.85513 .16187 m
.85513 .46371 L
.85601 .46371 L
.85601 .16187 L
F
.2 .63 .79 r
.85513 .16187 m
.85513 .46371 L
.85601 .46371 L
.85601 .16187 L
s
.678 .847 .902 r
.85601 .16187 m
.85601 .46427 L
.85642 .46427 L
.85642 .16187 L
F
.2 .63 .79 r
.85601 .16187 m
.85601 .46427 L
.85642 .46427 L
.85642 .16187 L
s
.678 .847 .902 r
.85642 .16187 m
.85642 .46461 L
.85728 .46461 L
.85728 .16187 L
F
.2 .63 .79 r
.85642 .16187 m
.85642 .46461 L
.85728 .46461 L
.85728 .16187 L
s
.678 .847 .902 r
.85728 .16187 m
.85728 .46573 L
.85801 .46573 L
.85801 .16187 L
F
.2 .63 .79 r
.85728 .16187 m
.85728 .46573 L
.85801 .46573 L
.85801 .16187 L
s
.678 .847 .902 r
.85801 .16187 m
.85801 .46632 L
.85836 .46632 L
.85836 .16187 L
F
.2 .63 .79 r
.85801 .16187 m
.85801 .46632 L
.85836 .46632 L
.85836 .16187 L
s
.678 .847 .902 r
.85836 .16187 m
.85836 .46729 L
.85905 .46729 L
.85905 .16187 L
F
.2 .63 .79 r
.85836 .16187 m
.85836 .46729 L
.85905 .46729 L
.85905 .16187 L
s
.678 .847 .902 r
.85905 .16187 m
.85905 .46757 L
.85949 .46757 L
.85949 .16187 L
F
.2 .63 .79 r
.85905 .16187 m
.85905 .46757 L
.85949 .46757 L
.85949 .16187 L
s
.678 .847 .902 r
.85949 .16187 m
.85949 .46813 L
.86047 .46813 L
.86047 .16187 L
F
.2 .63 .79 r
.85949 .16187 m
.85949 .46813 L
.86047 .46813 L
.86047 .16187 L
s
.678 .847 .902 r
.86047 .16187 m
.86047 .46938 L
.86125 .46938 L
.86125 .16187 L
F
.2 .63 .79 r
.86047 .16187 m
.86047 .46938 L
.86125 .46938 L
.86125 .16187 L
s
.678 .847 .902 r
.86125 .16187 m
.86125 .47014 L
.86175 .47014 L
.86175 .16187 L
F
.2 .63 .79 r
.86125 .16187 m
.86125 .47014 L
.86175 .47014 L
.86175 .16187 L
s
.678 .847 .902 r
.86175 .16187 m
.86175 .47082 L
.86244 .47082 L
.86244 .16187 L
F
.2 .63 .79 r
.86175 .16187 m
.86175 .47082 L
.86244 .47082 L
.86244 .16187 L
s
.678 .847 .902 r
.86244 .16187 m
.86244 .47152 L
.86308 .47152 L
.86308 .16187 L
F
.2 .63 .79 r
.86244 .16187 m
.86244 .47152 L
.86308 .47152 L
.86308 .16187 L
s
.678 .847 .902 r
.86308 .16187 m
.86308 .4725 L
.86374 .4725 L
.86374 .16187 L
F
.2 .63 .79 r
.86308 .16187 m
.86308 .4725 L
.86374 .4725 L
.86374 .16187 L
s
.678 .847 .902 r
.86374 .16187 m
.86374 .47275 L
.86409 .47275 L
.86409 .16187 L
F
.2 .63 .79 r
.86374 .16187 m
.86374 .47275 L
.86409 .47275 L
.86409 .16187 L
s
.678 .847 .902 r
.86409 .16187 m
.86409 .47341 L
.865 .47341 L
.865 .16187 L
F
.2 .63 .79 r
.86409 .16187 m
.86409 .47341 L
.865 .47341 L
.865 .16187 L
s
.678 .847 .902 r
.865 .16187 m
.865 .47427 L
.8656 .47427 L
.8656 .16187 L
F
.2 .63 .79 r
.865 .16187 m
.865 .47427 L
.8656 .47427 L
.8656 .16187 L
s
.678 .847 .902 r
.8656 .16187 m
.8656 .47494 L
.86601 .47494 L
.86601 .16187 L
F
.2 .63 .79 r
.8656 .16187 m
.8656 .47494 L
.86601 .47494 L
.86601 .16187 L
s
.678 .847 .902 r
.86601 .16187 m
.86601 .47558 L
.86697 .47558 L
.86697 .16187 L
F
.2 .63 .79 r
.86601 .16187 m
.86601 .47558 L
.86697 .47558 L
.86697 .16187 L
s
.678 .847 .902 r
.86697 .16187 m
.86697 .47618 L
.86794 .47618 L
.86794 .16187 L
F
.2 .63 .79 r
.86697 .16187 m
.86697 .47618 L
.86794 .47618 L
.86794 .16187 L
s
.678 .847 .902 r
.86794 .16187 m
.86794 .47765 L
.86895 .47765 L
.86895 .16187 L
F
.2 .63 .79 r
.86794 .16187 m
.86794 .47765 L
.86895 .47765 L
.86895 .16187 L
s
.678 .847 .902 r
.86895 .16187 m
.86895 .47838 L
.86986 .47838 L
.86986 .16187 L
F
.2 .63 .79 r
.86895 .16187 m
.86895 .47838 L
.86986 .47838 L
.86986 .16187 L
s
.678 .847 .902 r
.86986 .16187 m
.86986 .47927 L
.87059 .47927 L
.87059 .16187 L
F
.2 .63 .79 r
.86986 .16187 m
.86986 .47927 L
.87059 .47927 L
.87059 .16187 L
s
.678 .847 .902 r
.87059 .16187 m
.87059 .48043 L
.87128 .48043 L
.87128 .16187 L
F
.2 .63 .79 r
.87059 .16187 m
.87059 .48043 L
.87128 .48043 L
.87128 .16187 L
s
.678 .847 .902 r
.87128 .16187 m
.87128 .48128 L
.87176 .48128 L
.87176 .16187 L
F
.2 .63 .79 r
.87128 .16187 m
.87128 .48128 L
.87176 .48128 L
.87176 .16187 L
s
.678 .847 .902 r
.87176 .16187 m
.87176 .48153 L
.87209 .48153 L
.87209 .16187 L
F
.2 .63 .79 r
.87176 .16187 m
.87176 .48153 L
.87209 .48153 L
.87209 .16187 L
s
.678 .847 .902 r
.87209 .16187 m
.87209 .48222 L
.87273 .48222 L
.87273 .16187 L
F
.2 .63 .79 r
.87209 .16187 m
.87209 .48222 L
.87273 .48222 L
.87273 .16187 L
s
.678 .847 .902 r
.87273 .16187 m
.87273 .48286 L
.8736 .48286 L
.8736 .16187 L
F
.2 .63 .79 r
.87273 .16187 m
.87273 .48286 L
.8736 .48286 L
.8736 .16187 L
s
.678 .847 .902 r
.8736 .16187 m
.8736 .4839 L
.87437 .4839 L
.87437 .16187 L
F
.2 .63 .79 r
.8736 .16187 m
.8736 .4839 L
.87437 .4839 L
.87437 .16187 L
s
.678 .847 .902 r
.87437 .16187 m
.87437 .48483 L
.87539 .48483 L
.87539 .16187 L
F
.2 .63 .79 r
.87437 .16187 m
.87437 .48483 L
.87539 .48483 L
.87539 .16187 L
s
.678 .847 .902 r
.87539 .16187 m
.87539 .48637 L
.87638 .48637 L
.87638 .16187 L
F
.2 .63 .79 r
.87539 .16187 m
.87539 .48637 L
.87638 .48637 L
.87638 .16187 L
s
.678 .847 .902 r
.87638 .16187 m
.87638 .48658 L
.87712 .48658 L
.87712 .16187 L
F
.2 .63 .79 r
.87638 .16187 m
.87638 .48658 L
.87712 .48658 L
.87712 .16187 L
s
.678 .847 .902 r
.87712 .16187 m
.87712 .48764 L
.87794 .48764 L
.87794 .16187 L
F
.2 .63 .79 r
.87712 .16187 m
.87712 .48764 L
.87794 .48764 L
.87794 .16187 L
s
.678 .847 .902 r
.87794 .16187 m
.87794 .4882 L
.8785 .4882 L
.8785 .16187 L
F
.2 .63 .79 r
.87794 .16187 m
.87794 .4882 L
.8785 .4882 L
.8785 .16187 L
s
.678 .847 .902 r
.8785 .16187 m
.8785 .48909 L
.87929 .48909 L
.87929 .16187 L
F
.2 .63 .79 r
.8785 .16187 m
.8785 .48909 L
.87929 .48909 L
.87929 .16187 L
s
.678 .847 .902 r
.87929 .16187 m
.87929 .48988 L
.87966 .48988 L
.87966 .16187 L
F
.2 .63 .79 r
.87929 .16187 m
.87929 .48988 L
.87966 .48988 L
.87966 .16187 L
s
.678 .847 .902 r
.87966 .16187 m
.87966 .49052 L
.88015 .49052 L
.88015 .16187 L
F
.2 .63 .79 r
.87966 .16187 m
.87966 .49052 L
.88015 .49052 L
.88015 .16187 L
s
.678 .847 .902 r
.88015 .16187 m
.88015 .49072 L
.88109 .49072 L
.88109 .16187 L
F
.2 .63 .79 r
.88015 .16187 m
.88015 .49072 L
.88109 .49072 L
.88109 .16187 L
s
.678 .847 .902 r
.88109 .16187 m
.88109 .49228 L
.88184 .49228 L
.88184 .16187 L
F
.2 .63 .79 r
.88109 .16187 m
.88109 .49228 L
.88184 .49228 L
.88184 .16187 L
s
.678 .847 .902 r
.88184 .16187 m
.88184 .49252 L
.88232 .49252 L
.88232 .16187 L
F
.2 .63 .79 r
.88184 .16187 m
.88184 .49252 L
.88232 .49252 L
.88232 .16187 L
s
.678 .847 .902 r
.88232 .16187 m
.88232 .49332 L
.88326 .49332 L
.88326 .16187 L
F
.2 .63 .79 r
.88232 .16187 m
.88232 .49332 L
.88326 .49332 L
.88326 .16187 L
s
.678 .847 .902 r
.88326 .16187 m
.88326 .49431 L
.88409 .49431 L
.88409 .16187 L
F
.2 .63 .79 r
.88326 .16187 m
.88326 .49431 L
.88409 .49431 L
.88409 .16187 L
s
.678 .847 .902 r
.88409 .16187 m
.88409 .49519 L
.88492 .49519 L
.88492 .16187 L
F
.2 .63 .79 r
.88409 .16187 m
.88409 .49519 L
.88492 .49519 L
.88492 .16187 L
s
.678 .847 .902 r
.88492 .16187 m
.88492 .4965 L
.88547 .4965 L
.88547 .16187 L
F
.2 .63 .79 r
.88492 .16187 m
.88492 .4965 L
.88547 .4965 L
.88547 .16187 L
s
.678 .847 .902 r
.88547 .16187 m
.88547 .49739 L
.88642 .49739 L
.88642 .16187 L
F
.2 .63 .79 r
.88547 .16187 m
.88547 .49739 L
.88642 .49739 L
.88642 .16187 L
s
.678 .847 .902 r
.88642 .16187 m
.88642 .49772 L
.88739 .49772 L
.88739 .16187 L
F
.2 .63 .79 r
.88642 .16187 m
.88642 .49772 L
.88739 .49772 L
.88739 .16187 L
s
.678 .847 .902 r
.88739 .16187 m
.88739 .49874 L
.8878 .49874 L
.8878 .16187 L
F
.2 .63 .79 r
.88739 .16187 m
.88739 .49874 L
.8878 .49874 L
.8878 .16187 L
s
.678 .847 .902 r
.8878 .16187 m
.8878 .49957 L
.88869 .49957 L
.88869 .16187 L
F
.2 .63 .79 r
.8878 .16187 m
.8878 .49957 L
.88869 .49957 L
.88869 .16187 L
s
.678 .847 .902 r
.88869 .16187 m
.88869 .50091 L
.88948 .50091 L
.88948 .16187 L
F
.2 .63 .79 r
.88869 .16187 m
.88869 .50091 L
.88948 .50091 L
.88948 .16187 L
s
.678 .847 .902 r
.88948 .16187 m
.88948 .50156 L
.89042 .50156 L
.89042 .16187 L
F
.2 .63 .79 r
.88948 .16187 m
.88948 .50156 L
.89042 .50156 L
.89042 .16187 L
s
.678 .847 .902 r
.89042 .16187 m
.89042 .50242 L
.89122 .50242 L
.89122 .16187 L
F
.2 .63 .79 r
.89042 .16187 m
.89042 .50242 L
.89122 .50242 L
.89122 .16187 L
s
.678 .847 .902 r
.89122 .16187 m
.89122 .50334 L
.89156 .50334 L
.89156 .16187 L
F
.2 .63 .79 r
.89122 .16187 m
.89122 .50334 L
.89156 .50334 L
.89156 .16187 L
s
.678 .847 .902 r
.89156 .16187 m
.89156 .50344 L
.89188 .50344 L
.89188 .16187 L
F
.2 .63 .79 r
.89156 .16187 m
.89156 .50344 L
.89188 .50344 L
.89188 .16187 L
s
.678 .847 .902 r
.89188 .16187 m
.89188 .50474 L
.89284 .50474 L
.89284 .16187 L
F
.2 .63 .79 r
.89188 .16187 m
.89188 .50474 L
.89284 .50474 L
.89284 .16187 L
s
.678 .847 .902 r
.89284 .16187 m
.89284 .50521 L
.89369 .50521 L
.89369 .16187 L
F
.2 .63 .79 r
.89284 .16187 m
.89284 .50521 L
.89369 .50521 L
.89369 .16187 L
s
.678 .847 .902 r
.89369 .16187 m
.89369 .50629 L
.89433 .50629 L
.89433 .16187 L
F
.2 .63 .79 r
.89369 .16187 m
.89369 .50629 L
.89433 .50629 L
.89433 .16187 L
s
.678 .847 .902 r
.89433 .16187 m
.89433 .50694 L
.89486 .50694 L
.89486 .16187 L
F
.2 .63 .79 r
.89433 .16187 m
.89433 .50694 L
.89486 .50694 L
.89486 .16187 L
s
.678 .847 .902 r
.89486 .16187 m
.89486 .50777 L
.89556 .50777 L
.89556 .16187 L
F
.2 .63 .79 r
.89486 .16187 m
.89486 .50777 L
.89556 .50777 L
.89556 .16187 L
s
.678 .847 .902 r
.89556 .16187 m
.89556 .5079 L
.89594 .5079 L
.89594 .16187 L
F
.2 .63 .79 r
.89556 .16187 m
.89556 .5079 L
.89594 .5079 L
.89594 .16187 L
s
.678 .847 .902 r
.89594 .16187 m
.89594 .50839 L
.89652 .50839 L
.89652 .16187 L
F
.2 .63 .79 r
.89594 .16187 m
.89594 .50839 L
.89652 .50839 L
.89652 .16187 L
s
.678 .847 .902 r
.89652 .16187 m
.89652 .50932 L
.89687 .50932 L
.89687 .16187 L
F
.2 .63 .79 r
.89652 .16187 m
.89652 .50932 L
.89687 .50932 L
.89687 .16187 L
s
.678 .847 .902 r
.89687 .16187 m
.89687 .51004 L
.89767 .51004 L
.89767 .16187 L
F
.2 .63 .79 r
.89687 .16187 m
.89687 .51004 L
.89767 .51004 L
.89767 .16187 L
s
.678 .847 .902 r
.89767 .16187 m
.89767 .51048 L
.89834 .51048 L
.89834 .16187 L
F
.2 .63 .79 r
.89767 .16187 m
.89767 .51048 L
.89834 .51048 L
.89834 .16187 L
s
.678 .847 .902 r
.89834 .16187 m
.89834 .51104 L
.89875 .51104 L
.89875 .16187 L
F
.2 .63 .79 r
.89834 .16187 m
.89834 .51104 L
.89875 .51104 L
.89875 .16187 L
s
.678 .847 .902 r
.89875 .16187 m
.89875 .5118 L
.8992 .5118 L
.8992 .16187 L
F
.2 .63 .79 r
.89875 .16187 m
.89875 .5118 L
.8992 .5118 L
.8992 .16187 L
s
.678 .847 .902 r
.8992 .16187 m
.8992 .51252 L
.9002 .51252 L
.9002 .16187 L
F
.2 .63 .79 r
.8992 .16187 m
.8992 .51252 L
.9002 .51252 L
.9002 .16187 L
s
.678 .847 .902 r
.9002 .16187 m
.9002 .51319 L
.90106 .51319 L
.90106 .16187 L
F
.2 .63 .79 r
.9002 .16187 m
.9002 .51319 L
.90106 .51319 L
.90106 .16187 L
s
.678 .847 .902 r
.90106 .16187 m
.90106 .5142 L
.90196 .5142 L
.90196 .16187 L
F
.2 .63 .79 r
.90106 .16187 m
.90106 .5142 L
.90196 .5142 L
.90196 .16187 L
s
.678 .847 .902 r
.90196 .16187 m
.90196 .51562 L
.9025 .51562 L
.9025 .16187 L
F
.2 .63 .79 r
.90196 .16187 m
.90196 .51562 L
.9025 .51562 L
.9025 .16187 L
s
.678 .847 .902 r
.9025 .16187 m
.9025 .51589 L
.90285 .51589 L
.90285 .16187 L
F
.2 .63 .79 r
.9025 .16187 m
.9025 .51589 L
.90285 .51589 L
.90285 .16187 L
s
.678 .847 .902 r
.90285 .16187 m
.90285 .51693 L
.90361 .51693 L
.90361 .16187 L
F
.2 .63 .79 r
.90285 .16187 m
.90285 .51693 L
.90361 .51693 L
.90361 .16187 L
s
.678 .847 .902 r
.90361 .16187 m
.90361 .51725 L
.90393 .51725 L
.90393 .16187 L
F
.2 .63 .79 r
.90361 .16187 m
.90361 .51725 L
.90393 .51725 L
.90393 .16187 L
s
.678 .847 .902 r
.90393 .16187 m
.90393 .5182 L
.9047 .5182 L
.9047 .16187 L
F
.2 .63 .79 r
.90393 .16187 m
.90393 .5182 L
.9047 .5182 L
.9047 .16187 L
s
.678 .847 .902 r
.9047 .16187 m
.9047 .5187 L
.90515 .5187 L
.90515 .16187 L
F
.2 .63 .79 r
.9047 .16187 m
.9047 .5187 L
.90515 .5187 L
.90515 .16187 L
s
.678 .847 .902 r
.90515 .16187 m
.90515 .51936 L
.90615 .51936 L
.90615 .16187 L
F
.2 .63 .79 r
.90515 .16187 m
.90515 .51936 L
.90615 .51936 L
.90615 .16187 L
s
.678 .847 .902 r
.90615 .16187 m
.90615 .52073 L
.90716 .52073 L
.90716 .16187 L
F
.2 .63 .79 r
.90615 .16187 m
.90615 .52073 L
.90716 .52073 L
.90716 .16187 L
s
.678 .847 .902 r
.90716 .16187 m
.90716 .52169 L
.90792 .52169 L
.90792 .16187 L
F
.2 .63 .79 r
.90716 .16187 m
.90716 .52169 L
.90792 .52169 L
.90792 .16187 L
s
.678 .847 .902 r
.90792 .16187 m
.90792 .5225 L
.90846 .5225 L
.90846 .16187 L
F
.2 .63 .79 r
.90792 .16187 m
.90792 .5225 L
.90846 .5225 L
.90846 .16187 L
s
.678 .847 .902 r
.90846 .16187 m
.90846 .52261 L
.90891 .52261 L
.90891 .16187 L
F
.2 .63 .79 r
.90846 .16187 m
.90846 .52261 L
.90891 .52261 L
.90891 .16187 L
s
.678 .847 .902 r
.90891 .16187 m
.90891 .52384 L
.9096 .52384 L
.9096 .16187 L
F
.2 .63 .79 r
.90891 .16187 m
.90891 .52384 L
.9096 .52384 L
.9096 .16187 L
s
.678 .847 .902 r
.9096 .16187 m
.9096 .52446 L
.91014 .52446 L
.91014 .16187 L
F
.2 .63 .79 r
.9096 .16187 m
.9096 .52446 L
.91014 .52446 L
.91014 .16187 L
s
.678 .847 .902 r
.91014 .16187 m
.91014 .52451 L
.911 .52451 L
.911 .16187 L
F
.2 .63 .79 r
.91014 .16187 m
.91014 .52451 L
.911 .52451 L
.911 .16187 L
s
.678 .847 .902 r
.911 .16187 m
.911 .52551 L
.91139 .52551 L
.91139 .16187 L
F
.2 .63 .79 r
.911 .16187 m
.911 .52551 L
.91139 .52551 L
.91139 .16187 L
s
.678 .847 .902 r
.91139 .16187 m
.91139 .52633 L
.9118 .52633 L
.9118 .16187 L
F
.2 .63 .79 r
.91139 .16187 m
.91139 .52633 L
.9118 .52633 L
.9118 .16187 L
s
.678 .847 .902 r
.9118 .16187 m
.9118 .52643 L
.9123 .52643 L
.9123 .16187 L
F
.2 .63 .79 r
.9118 .16187 m
.9118 .52643 L
.9123 .52643 L
.9123 .16187 L
s
.678 .847 .902 r
.9123 .16187 m
.9123 .52711 L
.91268 .52711 L
.91268 .16187 L
F
.2 .63 .79 r
.9123 .16187 m
.9123 .52711 L
.91268 .52711 L
.91268 .16187 L
s
.678 .847 .902 r
.91268 .16187 m
.91268 .52807 L
.91343 .52807 L
.91343 .16187 L
F
.2 .63 .79 r
.91268 .16187 m
.91268 .52807 L
.91343 .52807 L
.91343 .16187 L
s
.678 .847 .902 r
.91343 .16187 m
.91343 .52858 L
.91375 .52858 L
.91375 .16187 L
F
.2 .63 .79 r
.91343 .16187 m
.91343 .52858 L
.91375 .52858 L
.91375 .16187 L
s
.678 .847 .902 r
.91375 .16187 m
.91375 .52884 L
.91411 .52884 L
.91411 .16187 L
F
.2 .63 .79 r
.91375 .16187 m
.91375 .52884 L
.91411 .52884 L
.91411 .16187 L
s
.678 .847 .902 r
.91411 .16187 m
.91411 .52946 L
.91452 .52946 L
.91452 .16187 L
F
.2 .63 .79 r
.91411 .16187 m
.91411 .52946 L
.91452 .52946 L
.91452 .16187 L
s
.678 .847 .902 r
.91452 .16187 m
.91452 .53029 L
.91545 .53029 L
.91545 .16187 L
F
.2 .63 .79 r
.91452 .16187 m
.91452 .53029 L
.91545 .53029 L
.91545 .16187 L
s
.678 .847 .902 r
.91545 .16187 m
.91545 .53099 L
.9159 .53099 L
.9159 .16187 L
F
.2 .63 .79 r
.91545 .16187 m
.91545 .53099 L
.9159 .53099 L
.9159 .16187 L
s
.678 .847 .902 r
.9159 .16187 m
.9159 .53178 L
.91676 .53178 L
.91676 .16187 L
F
.2 .63 .79 r
.9159 .16187 m
.9159 .53178 L
.91676 .53178 L
.91676 .16187 L
s
.678 .847 .902 r
.91676 .16187 m
.91676 .53235 L
.91712 .53235 L
.91712 .16187 L
F
.2 .63 .79 r
.91676 .16187 m
.91676 .53235 L
.91712 .53235 L
.91712 .16187 L
s
.678 .847 .902 r
.91712 .16187 m
.91712 .53301 L
.9176 .53301 L
.9176 .16187 L
F
.2 .63 .79 r
.91712 .16187 m
.91712 .53301 L
.9176 .53301 L
.9176 .16187 L
s
.678 .847 .902 r
.9176 .16187 m
.9176 .53316 L
.91805 .53316 L
.91805 .16187 L
F
.2 .63 .79 r
.9176 .16187 m
.9176 .53316 L
.91805 .53316 L
.91805 .16187 L
s
.678 .847 .902 r
.91805 .16187 m
.91805 .53398 L
.91845 .53398 L
.91845 .16187 L
F
.2 .63 .79 r
.91805 .16187 m
.91805 .53398 L
.91845 .53398 L
.91845 .16187 L
s
.678 .847 .902 r
.91845 .16187 m
.91845 .53482 L
.9194 .53482 L
.9194 .16187 L
F
.2 .63 .79 r
.91845 .16187 m
.91845 .53482 L
.9194 .53482 L
.9194 .16187 L
s
.678 .847 .902 r
.9194 .16187 m
.9194 .53538 L
.91992 .53538 L
.91992 .16187 L
F
.2 .63 .79 r
.9194 .16187 m
.9194 .53538 L
.91992 .53538 L
.91992 .16187 L
s
.678 .847 .902 r
.91992 .16187 m
.91992 .53602 L
.92039 .53602 L
.92039 .16187 L
F
.2 .63 .79 r
.91992 .16187 m
.91992 .53602 L
.92039 .53602 L
.92039 .16187 L
s
.678 .847 .902 r
.92039 .16187 m
.92039 .53638 L
.92105 .53638 L
.92105 .16187 L
F
.2 .63 .79 r
.92039 .16187 m
.92039 .53638 L
.92105 .53638 L
.92105 .16187 L
s
.678 .847 .902 r
.92105 .16187 m
.92105 .5378 L
.92178 .5378 L
.92178 .16187 L
F
.2 .63 .79 r
.92105 .16187 m
.92105 .5378 L
.92178 .5378 L
.92178 .16187 L
s
.678 .847 .902 r
.92178 .16187 m
.92178 .53808 L
.92216 .53808 L
.92216 .16187 L
F
.2 .63 .79 r
.92178 .16187 m
.92178 .53808 L
.92216 .53808 L
.92216 .16187 L
s
.678 .847 .902 r
.92216 .16187 m
.92216 .53883 L
.92298 .53883 L
.92298 .16187 L
F
.2 .63 .79 r
.92216 .16187 m
.92216 .53883 L
.92298 .53883 L
.92298 .16187 L
s
.678 .847 .902 r
.92298 .16187 m
.92298 .53943 L
.92342 .53943 L
.92342 .16187 L
F
.2 .63 .79 r
.92298 .16187 m
.92298 .53943 L
.92342 .53943 L
.92342 .16187 L
s
.678 .847 .902 r
.92342 .16187 m
.92342 .5407 L
.92431 .5407 L
.92431 .16187 L
F
.2 .63 .79 r
.92342 .16187 m
.92342 .5407 L
.92431 .5407 L
.92431 .16187 L
s
.678 .847 .902 r
.92431 .16187 m
.92431 .54117 L
.92534 .54117 L
.92534 .16187 L
F
.2 .63 .79 r
.92431 .16187 m
.92431 .54117 L
.92534 .54117 L
.92534 .16187 L
s
.678 .847 .902 r
.92534 .16187 m
.92534 .54265 L
.92606 .54265 L
.92606 .16187 L
F
.2 .63 .79 r
.92534 .16187 m
.92534 .54265 L
.92606 .54265 L
.92606 .16187 L
s
.678 .847 .902 r
.92606 .16187 m
.92606 .54307 L
.92703 .54307 L
.92703 .16187 L
F
.2 .63 .79 r
.92606 .16187 m
.92606 .54307 L
.92703 .54307 L
.92703 .16187 L
s
.678 .847 .902 r
.92703 .16187 m
.92703 .54461 L
.92786 .54461 L
.92786 .16187 L
F
.2 .63 .79 r
.92703 .16187 m
.92703 .54461 L
.92786 .54461 L
.92786 .16187 L
s
.678 .847 .902 r
.92786 .16187 m
.92786 .54541 L
.92845 .54541 L
.92845 .16187 L
F
.2 .63 .79 r
.92786 .16187 m
.92786 .54541 L
.92845 .54541 L
.92845 .16187 L
s
.678 .847 .902 r
.92845 .16187 m
.92845 .54648 L
.92916 .54648 L
.92916 .16187 L
F
.2 .63 .79 r
.92845 .16187 m
.92845 .54648 L
.92916 .54648 L
.92916 .16187 L
s
.678 .847 .902 r
.92916 .16187 m
.92916 .54733 L
.93008 .54733 L
.93008 .16187 L
F
.2 .63 .79 r
.92916 .16187 m
.92916 .54733 L
.93008 .54733 L
.93008 .16187 L
s
.678 .847 .902 r
.93008 .16187 m
.93008 .54831 L
.93081 .54831 L
.93081 .16187 L
F
.2 .63 .79 r
.93008 .16187 m
.93008 .54831 L
.93081 .54831 L
.93081 .16187 L
s
.678 .847 .902 r
.93081 .16187 m
.93081 .54919 L
.9315 .54919 L
.9315 .16187 L
F
.2 .63 .79 r
.93081 .16187 m
.93081 .54919 L
.9315 .54919 L
.9315 .16187 L
s
.678 .847 .902 r
.9315 .16187 m
.9315 .54947 L
.93207 .54947 L
.93207 .16187 L
F
.2 .63 .79 r
.9315 .16187 m
.9315 .54947 L
.93207 .54947 L
.93207 .16187 L
s
.678 .847 .902 r
.93207 .16187 m
.93207 .55006 L
.93244 .55006 L
.93244 .16187 L
F
.2 .63 .79 r
.93207 .16187 m
.93207 .55006 L
.93244 .55006 L
.93244 .16187 L
s
.678 .847 .902 r
.93244 .16187 m
.93244 .55067 L
.93313 .55067 L
.93313 .16187 L
F
.2 .63 .79 r
.93244 .16187 m
.93244 .55067 L
.93313 .55067 L
.93313 .16187 L
s
.678 .847 .902 r
.93313 .16187 m
.93313 .55189 L
.93365 .55189 L
.93365 .16187 L
F
.2 .63 .79 r
.93313 .16187 m
.93313 .55189 L
.93365 .55189 L
.93365 .16187 L
s
.678 .847 .902 r
.93365 .16187 m
.93365 .55195 L
.93408 .55195 L
.93408 .16187 L
F
.2 .63 .79 r
.93365 .16187 m
.93365 .55195 L
.93408 .55195 L
.93408 .16187 L
s
.678 .847 .902 r
.93408 .16187 m
.93408 .5528 L
.93509 .5528 L
.93509 .16187 L
F
.2 .63 .79 r
.93408 .16187 m
.93408 .5528 L
.93509 .5528 L
.93509 .16187 L
s
.678 .847 .902 r
.93509 .16187 m
.93509 .55414 L
.93586 .55414 L
.93586 .16187 L
F
.2 .63 .79 r
.93509 .16187 m
.93509 .55414 L
.93586 .55414 L
.93586 .16187 L
s
.678 .847 .902 r
.93586 .16187 m
.93586 .55538 L
.93689 .55538 L
.93689 .16187 L
F
.2 .63 .79 r
.93586 .16187 m
.93586 .55538 L
.93689 .55538 L
.93689 .16187 L
s
.678 .847 .902 r
.93689 .16187 m
.93689 .55658 L
.93789 .55658 L
.93789 .16187 L
F
.2 .63 .79 r
.93689 .16187 m
.93689 .55658 L
.93789 .55658 L
.93789 .16187 L
s
.678 .847 .902 r
.93789 .16187 m
.93789 .55716 L
.93855 .55716 L
.93855 .16187 L
F
.2 .63 .79 r
.93789 .16187 m
.93789 .55716 L
.93855 .55716 L
.93855 .16187 L
s
.678 .847 .902 r
.93855 .16187 m
.93855 .55804 L
.9389 .55804 L
.9389 .16187 L
F
.2 .63 .79 r
.93855 .16187 m
.93855 .55804 L
.9389 .55804 L
.9389 .16187 L
s
.678 .847 .902 r
.9389 .16187 m
.9389 .55869 L
.93986 .55869 L
.93986 .16187 L
F
.2 .63 .79 r
.9389 .16187 m
.9389 .55869 L
.93986 .55869 L
.93986 .16187 L
s
.678 .847 .902 r
.93986 .16187 m
.93986 .55944 L
.94035 .55944 L
.94035 .16187 L
F
.2 .63 .79 r
.93986 .16187 m
.93986 .55944 L
.94035 .55944 L
.94035 .16187 L
s
.678 .847 .902 r
.94035 .16187 m
.94035 .55998 L
.94088 .55998 L
.94088 .16187 L
F
.2 .63 .79 r
.94035 .16187 m
.94035 .55998 L
.94088 .55998 L
.94088 .16187 L
s
.678 .847 .902 r
.94088 .16187 m
.94088 .5605 L
.94137 .5605 L
.94137 .16187 L
F
.2 .63 .79 r
.94088 .16187 m
.94088 .5605 L
.94137 .5605 L
.94137 .16187 L
s
.678 .847 .902 r
.94137 .16187 m
.94137 .56142 L
.94234 .56142 L
.94234 .16187 L
F
.2 .63 .79 r
.94137 .16187 m
.94137 .56142 L
.94234 .56142 L
.94234 .16187 L
s
.678 .847 .902 r
.94234 .16187 m
.94234 .56288 L
.94315 .56288 L
.94315 .16187 L
F
.2 .63 .79 r
.94234 .16187 m
.94234 .56288 L
.94315 .56288 L
.94315 .16187 L
s
.678 .847 .902 r
.94315 .16187 m
.94315 .56328 L
.94374 .56328 L
.94374 .16187 L
F
.2 .63 .79 r
.94315 .16187 m
.94315 .56328 L
.94374 .56328 L
.94374 .16187 L
s
.678 .847 .902 r
.94374 .16187 m
.94374 .56433 L
.94444 .56433 L
.94444 .16187 L
F
.2 .63 .79 r
.94374 .16187 m
.94374 .56433 L
.94444 .56433 L
.94444 .16187 L
s
.678 .847 .902 r
.94444 .16187 m
.94444 .56543 L
.94513 .56543 L
.94513 .16187 L
F
.2 .63 .79 r
.94444 .16187 m
.94444 .56543 L
.94513 .56543 L
.94513 .16187 L
s
.678 .847 .902 r
.94513 .16187 m
.94513 .56597 L
.94554 .56597 L
.94554 .16187 L
F
.2 .63 .79 r
.94513 .16187 m
.94513 .56597 L
.94554 .56597 L
.94554 .16187 L
s
.678 .847 .902 r
.94554 .16187 m
.94554 .56644 L
.94625 .56644 L
.94625 .16187 L
F
.2 .63 .79 r
.94554 .16187 m
.94554 .56644 L
.94625 .56644 L
.94625 .16187 L
s
.678 .847 .902 r
.94625 .16187 m
.94625 .56788 L
.94724 .56788 L
.94724 .16187 L
F
.2 .63 .79 r
.94625 .16187 m
.94625 .56788 L
.94724 .56788 L
.94724 .16187 L
s
.678 .847 .902 r
.94724 .16187 m
.94724 .56811 L
.94756 .56811 L
.94756 .16187 L
F
.2 .63 .79 r
.94724 .16187 m
.94724 .56811 L
.94756 .56811 L
.94756 .16187 L
s
.678 .847 .902 r
.94756 .16187 m
.94756 .5692 L
.94843 .5692 L
.94843 .16187 L
F
.2 .63 .79 r
.94756 .16187 m
.94756 .5692 L
.94843 .5692 L
.94843 .16187 L
s
.678 .847 .902 r
.94843 .16187 m
.94843 .56985 L
.94908 .56985 L
.94908 .16187 L
F
.2 .63 .79 r
.94843 .16187 m
.94843 .56985 L
.94908 .56985 L
.94908 .16187 L
s
.678 .847 .902 r
.94908 .16187 m
.94908 .57074 L
.9497 .57074 L
.9497 .16187 L
F
.2 .63 .79 r
.94908 .16187 m
.94908 .57074 L
.9497 .57074 L
.9497 .16187 L
s
.678 .847 .902 r
.9497 .16187 m
.9497 .57114 L
.95053 .57114 L
.95053 .16187 L
F
.2 .63 .79 r
.9497 .16187 m
.9497 .57114 L
.95053 .57114 L
.95053 .16187 L
s
.678 .847 .902 r
.95053 .16187 m
.95053 .5726 L
.95129 .5726 L
.95129 .16187 L
F
.2 .63 .79 r
.95053 .16187 m
.95053 .5726 L
.95129 .5726 L
.95129 .16187 L
s
.678 .847 .902 r
.95129 .16187 m
.95129 .57304 L
.95196 .57304 L
.95196 .16187 L
F
.2 .63 .79 r
.95129 .16187 m
.95129 .57304 L
.95196 .57304 L
.95196 .16187 L
s
.678 .847 .902 r
.95196 .16187 m
.95196 .57377 L
.95285 .57377 L
.95285 .16187 L
F
.2 .63 .79 r
.95196 .16187 m
.95196 .57377 L
.95285 .57377 L
.95285 .16187 L
s
.678 .847 .902 r
.95285 .16187 m
.95285 .57523 L
.95368 .57523 L
.95368 .16187 L
F
.2 .63 .79 r
.95285 .16187 m
.95285 .57523 L
.95368 .57523 L
.95368 .16187 L
s
.678 .847 .902 r
.95368 .16187 m
.95368 .5767 L
.95448 .5767 L
.95448 .16187 L
F
.2 .63 .79 r
.95368 .16187 m
.95368 .5767 L
.95448 .5767 L
.95448 .16187 L
s
.678 .847 .902 r
.95448 .16187 m
.95448 .57711 L
.9548 .57711 L
.9548 .16187 L
F
.2 .63 .79 r
.95448 .16187 m
.95448 .57711 L
.9548 .57711 L
.9548 .16187 L
s
.678 .847 .902 r
.9548 .16187 m
.9548 .5774 L
.95565 .5774 L
.95565 .16187 L
F
.2 .63 .79 r
.9548 .16187 m
.9548 .5774 L
.95565 .5774 L
.95565 .16187 L
s
.678 .847 .902 r
.95565 .16187 m
.95565 .5792 L
.95655 .5792 L
.95655 .16187 L
F
.2 .63 .79 r
.95565 .16187 m
.95565 .5792 L
.95655 .5792 L
.95655 .16187 L
s
.678 .847 .902 r
.95655 .16187 m
.95655 .57976 L
.95717 .57976 L
.95717 .16187 L
F
.2 .63 .79 r
.95655 .16187 m
.95655 .57976 L
.95717 .57976 L
.95717 .16187 L
s
.678 .847 .902 r
.95717 .16187 m
.95717 .58066 L
.958 .58066 L
.958 .16187 L
F
.2 .63 .79 r
.95717 .16187 m
.95717 .58066 L
.958 .58066 L
.958 .16187 L
s
.678 .847 .902 r
.958 .16187 m
.958 .5812 L
.95867 .5812 L
.95867 .16187 L
F
.2 .63 .79 r
.958 .16187 m
.958 .5812 L
.95867 .5812 L
.95867 .16187 L
s
.678 .847 .902 r
.95867 .16187 m
.95867 .58257 L
.95963 .58257 L
.95963 .16187 L
F
.2 .63 .79 r
.95867 .16187 m
.95867 .58257 L
.95963 .58257 L
.95963 .16187 L
s
.678 .847 .902 r
.95963 .16187 m
.95963 .58401 L
.96048 .58401 L
.96048 .16187 L
F
.2 .63 .79 r
.95963 .16187 m
.95963 .58401 L
.96048 .58401 L
.96048 .16187 L
s
.678 .847 .902 r
.96048 .16187 m
.96048 .58438 L
.96102 .58438 L
.96102 .16187 L
F
.2 .63 .79 r
.96048 .16187 m
.96048 .58438 L
.96102 .58438 L
.96102 .16187 L
s
.678 .847 .902 r
.96102 .16187 m
.96102 .58553 L
.96203 .58553 L
.96203 .16187 L
F
.2 .63 .79 r
.96102 .16187 m
.96102 .58553 L
.96203 .58553 L
.96203 .16187 L
s
.678 .847 .902 r
.96203 .16187 m
.96203 .58649 L
.96262 .58649 L
.96262 .16187 L
F
.2 .63 .79 r
.96203 .16187 m
.96203 .58649 L
.96262 .58649 L
.96262 .16187 L
s
.678 .847 .902 r
.96262 .16187 m
.96262 .58676 L
.96337 .58676 L
.96337 .16187 L
F
.2 .63 .79 r
.96262 .16187 m
.96262 .58676 L
.96337 .58676 L
.96337 .16187 L
s
.678 .847 .902 r
.96337 .16187 m
.96337 .58759 L
.96423 .58759 L
.96423 .16187 L
F
.2 .63 .79 r
.96337 .16187 m
.96337 .58759 L
.96423 .58759 L
.96423 .16187 L
s
.678 .847 .902 r
.96423 .16187 m
.96423 .58896 L
.96456 .58896 L
.96456 .16187 L
F
.2 .63 .79 r
.96423 .16187 m
.96423 .58896 L
.96456 .58896 L
.96456 .16187 L
s
.678 .847 .902 r
.96456 .16187 m
.96456 .58951 L
.96515 .58951 L
.96515 .16187 L
F
.2 .63 .79 r
.96456 .16187 m
.96456 .58951 L
.96515 .58951 L
.96515 .16187 L
s
.678 .847 .902 r
.96515 .16187 m
.96515 .59019 L
.96605 .59019 L
.96605 .16187 L
F
.2 .63 .79 r
.96515 .16187 m
.96515 .59019 L
.96605 .59019 L
.96605 .16187 L
s
.678 .847 .902 r
.96605 .16187 m
.96605 .59122 L
.96658 .59122 L
.96658 .16187 L
F
.2 .63 .79 r
.96605 .16187 m
.96605 .59122 L
.96658 .59122 L
.96658 .16187 L
s
.678 .847 .902 r
.96658 .16187 m
.96658 .59171 L
.96732 .59171 L
.96732 .16187 L
F
.2 .63 .79 r
.96658 .16187 m
.96658 .59171 L
.96732 .59171 L
.96732 .16187 L
s
.678 .847 .902 r
.96732 .16187 m
.96732 .59295 L
.96811 .59295 L
.96811 .16187 L
F
.2 .63 .79 r
.96732 .16187 m
.96732 .59295 L
.96811 .59295 L
.96811 .16187 L
s
.678 .847 .902 r
.96811 .16187 m
.96811 .59381 L
.96857 .59381 L
.96857 .16187 L
F
.2 .63 .79 r
.96811 .16187 m
.96811 .59381 L
.96857 .59381 L
.96857 .16187 L
s
.678 .847 .902 r
.96857 .16187 m
.96857 .59443 L
.96946 .59443 L
.96946 .16187 L
F
.2 .63 .79 r
.96857 .16187 m
.96857 .59443 L
.96946 .59443 L
.96946 .16187 L
s
.678 .847 .902 r
.96946 .16187 m
.96946 .59526 L
.97035 .59526 L
.97035 .16187 L
F
.2 .63 .79 r
.96946 .16187 m
.96946 .59526 L
.97035 .59526 L
.97035 .16187 L
s
.678 .847 .902 r
.97035 .16187 m
.97035 .5963 L
.97135 .5963 L
.97135 .16187 L
F
.2 .63 .79 r
.97035 .16187 m
.97035 .5963 L
.97135 .5963 L
.97135 .16187 L
s
.678 .847 .902 r
.97135 .16187 m
.97135 .59808 L
.97204 .59808 L
.97204 .16187 L
F
.2 .63 .79 r
.97135 .16187 m
.97135 .59808 L
.97204 .59808 L
.97204 .16187 L
s
.678 .847 .902 r
.97204 .16187 m
.97204 .59888 L
.97292 .59888 L
.97292 .16187 L
F
.2 .63 .79 r
.97204 .16187 m
.97204 .59888 L
.97292 .59888 L
.97292 .16187 L
s
.678 .847 .902 r
.97292 .16187 m
.97292 .59971 L
.97327 .59971 L
.97327 .16187 L
F
.2 .63 .79 r
.97292 .16187 m
.97292 .59971 L
.97327 .59971 L
.97327 .16187 L
s
.678 .847 .902 r
.97327 .16187 m
.97327 .59983 L
.97368 .59983 L
.97368 .16187 L
F
.2 .63 .79 r
.97327 .16187 m
.97327 .59983 L
.97368 .59983 L
.97368 .16187 L
s
.678 .847 .902 r
.97368 .16187 m
.97368 .60033 L
.97406 .60033 L
.97406 .16187 L
F
.2 .63 .79 r
.97368 .16187 m
.97368 .60033 L
.97406 .60033 L
.97406 .16187 L
s
.678 .847 .902 r
.97406 .16187 m
.97406 .60069 L
.97443 .60069 L
.97443 .16187 L
F
.2 .63 .79 r
.97406 .16187 m
.97406 .60069 L
.97443 .60069 L
.97443 .16187 L
s
.678 .847 .902 r
.97443 .16187 m
.97443 .60184 L
.97514 .60184 L
.97514 .16187 L
F
.2 .63 .79 r
.97443 .16187 m
.97443 .60184 L
.97514 .60184 L
.97514 .16187 L
s
.678 .847 .902 r
.97514 .16187 m
.97514 .60239 L
.97562 .60239 L
.97562 .16187 L
F
.2 .63 .79 r
.97514 .16187 m
.97514 .60239 L
.97562 .60239 L
.97562 .16187 L
s
.678 .847 .902 r
.97562 .16187 m
.97562 .60282 L
.97619 .60282 L
.97619 .16187 L
F
.2 .63 .79 r
.97562 .16187 m
.97562 .60282 L
.97619 .60282 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02414 .01472 Mdot
.02473 .01472 Mdot
.02544 .01472 Mdot
.02579 .01472 Mdot
.02678 .01472 Mdot
.02708 .01472 Mdot
.02762 .01472 Mdot
.0288 .01473 Mdot
.02916 .01473 Mdot
.02982 .01474 Mdot
.03056 .01474 Mdot
.03129 .01475 Mdot
.03177 .01476 Mdot
.0319 .01476 Mdot
.03271 .01477 Mdot
.03297 .01477 Mdot
.03373 .01478 Mdot
.03462 .01479 Mdot
.03589 .01481 Mdot
.03628 .01482 Mdot
.03705 .01483 Mdot
.03818 .01485 Mdot
.03878 .01486 Mdot
.03987 .01488 Mdot
.04025 .01489 Mdot
.04156 .01492 Mdot
.04194 .01493 Mdot
.04218 .01493 Mdot
.04322 .01496 Mdot
.04408 .01498 Mdot
.04457 .01499 Mdot
.04548 .01502 Mdot
.04678 .01506 Mdot
.04725 .01507 Mdot
.04758 .01508 Mdot
.04803 .0151 Mdot
.04885 .01512 Mdot
.04931 .01514 Mdot
.05044 .01518 Mdot
.051 .01519 Mdot
.05213 .01524 Mdot
.05255 .01525 Mdot
.05381 .0153 Mdot
.05492 .01534 Mdot
.05514 .01535 Mdot
.0558 .01538 Mdot
.05642 .01541 Mdot
.05707 .01543 Mdot
.05809 .01548 Mdot
.05883 .01551 Mdot
.05974 .01555 Mdot
.06015 .01557 Mdot
.0606 .01559 Mdot
.06162 .01564 Mdot
.06257 .01569 Mdot
.0628 .0157 Mdot
.06357 .01574 Mdot
.06438 .01578 Mdot
.06486 .01581 Mdot
.06645 .0159 Mdot
.0675 .01595 Mdot
.068 .01598 Mdot
.06883 .01603 Mdot
.06932 .01606 Mdot
.06962 .01608 Mdot
.07016 .01611 Mdot
.07104 .01616 Mdot
.07155 .01619 Mdot
.07206 .01623 Mdot
.07275 .01627 Mdot
.07348 .01632 Mdot
.07414 .01636 Mdot
.07478 .0164 Mdot
.07535 .01644 Mdot
.07666 .01653 Mdot
.07688 .01654 Mdot
.07751 .01659 Mdot
.0781 .01663 Mdot
.07919 .01671 Mdot
.07974 .01674 Mdot
.08039 .01679 Mdot
.08065 .01681 Mdot
.081 .01684 Mdot
.08181 .0169 Mdot
.08252 .01695 Mdot
.08308 .01699 Mdot
.0834 .01702 Mdot
.08435 .01709 Mdot
.08535 .01717 Mdot
.08636 .01725 Mdot
.08691 .0173 Mdot
.0877 .01736 Mdot
.08857 .01744 Mdot
.08863 .01744 Mdot
.08979 .01754 Mdot
.09024 .01758 Mdot
.09097 .01764 Mdot
.09185 .01772 Mdot
.09193 .01773 Mdot
.09238 .01777 Mdot
.09309 .01783 Mdot
.09439 .01795 Mdot
.09492 .018 Mdot
.09517 .01802 Mdot
.096 .0181 Mdot
.09667 .01816 Mdot
.09757 .01825 Mdot
.09833 .01832 Mdot
.09869 .01835 Mdot
.09916 .0184 Mdot
.09955 .01844 Mdot
.10003 .01848 Mdot
.10053 .01853 Mdot
.10157 .01864 Mdot
.10227 .01871 Mdot
.10271 .01875 Mdot
.10304 .01879 Mdot
.10412 .0189 Mdot
.10502 .01899 Mdot
.10582 .01908 Mdot
.10615 .01911 Mdot
.1072 .01923 Mdot
.10804 .01932 Mdot
.10901 .01943 Mdot
.10952 .01948 Mdot
.11053 .01959 Mdot
.11122 .01967 Mdot
.11164 .01972 Mdot
.11233 .0198 Mdot
.11278 .01985 Mdot
.11346 .01993 Mdot
.1144 .02004 Mdot
.11499 .02011 Mdot
.11587 .02021 Mdot
.11616 .02025 Mdot
.11725 .02038 Mdot
.11802 .02047 Mdot
.11812 .02049 Mdot
.11916 .02062 Mdot
.11968 .02068 Mdot
.12102 .02085 Mdot
.12147 .0209 Mdot
.12179 .02095 Mdot
.12241 .02102 Mdot
.123 .0211 Mdot
.12388 .02121 Mdot
.12423 .02126 Mdot
.12501 .02136 Mdot
.12532 .0214 Mdot
.12649 .02156 Mdot
.12692 .02161 Mdot
.12764 .02171 Mdot
.12868 .02185 Mdot
.12906 .0219 Mdot
.13022 .02206 Mdot
.1306 .02212 Mdot
.1312 .0222 Mdot
.13157 .02225 Mdot
.13221 .02234 Mdot
.13301 .02245 Mdot
.13333 .0225 Mdot
.13353 .02253 Mdot
.13438 .02265 Mdot
.13497 .02273 Mdot
.13579 .02285 Mdot
.13644 .02295 Mdot
.13713 .02305 Mdot
.13732 .02308 Mdot
.13783 .02315 Mdot
.13851 .02325 Mdot
.13902 .02333 Mdot
.13996 .02347 Mdot
.14055 .02356 Mdot
.14105 .02364 Mdot
.14198 .02378 Mdot
.14266 .02388 Mdot
.14362 .02403 Mdot
.14431 .02414 Mdot
.14462 .02419 Mdot
.1456 .02434 Mdot
.1467 .02451 Mdot
.14688 .02454 Mdot
.1475 .02464 Mdot
.14846 .0248 Mdot
.14896 .02488 Mdot
.1496 .02498 Mdot
.15009 .02506 Mdot
.15025 .02509 Mdot
.15095 .0252 Mdot
.15145 .02529 Mdot
.15242 .02545 Mdot
.15294 .02554 Mdot
.15336 .02561 Mdot
.15406 .02572 Mdot
.15441 .02578 Mdot
.15481 .02585 Mdot
.15579 .02602 Mdot
.15671 .02618 Mdot
.15728 .02628 Mdot
.15794 .02639 Mdot
.15866 .02651 Mdot
.15932 .02663 Mdot
.15995 .02674 Mdot
.16054 .02685 Mdot
.16088 .02691 Mdot
.16233 .02717 Mdot
.1629 .02727 Mdot
.16332 .02734 Mdot
.16376 .02742 Mdot
.16431 .02753 Mdot
.16493 .02764 Mdot
.16648 .02792 Mdot
.16718 .02805 Mdot
.16854 .02831 Mdot
.16873 .02834 Mdot
.16976 .02854 Mdot
.17023 .02863 Mdot
.17095 .02876 Mdot
.17174 .02892 Mdot
.17313 .02918 Mdot
.1737 .0293 Mdot
.17432 .02941 Mdot
.17516 .02958 Mdot
.17579 .0297 Mdot
.1767 .02988 Mdot
.17738 .03002 Mdot
.17827 .0302 Mdot
.17886 .03032 Mdot
.18006 .03056 Mdot
.18119 .03079 Mdot
.18207 .03097 Mdot
.18258 .03107 Mdot
.18357 .03128 Mdot
.18413 .0314 Mdot
.18533 .03165 Mdot
.18623 .03183 Mdot
.18666 .03193 Mdot
.18779 .03216 Mdot
.18871 .03236 Mdot
.19011 .03266 Mdot
.19056 .03276 Mdot
.19069 .03279 Mdot
.19126 .03291 Mdot
.19208 .03309 Mdot
.19266 .03322 Mdot
.19377 .03346 Mdot
.19433 .03358 Mdot
.19515 .03377 Mdot
.19558 .03386 Mdot
.19594 .03394 Mdot
.19658 .03408 Mdot
.19787 .03438 Mdot
.19828 .03447 Mdot
.19916 .03467 Mdot
.19998 .03486 Mdot
.20071 .03502 Mdot
.20141 .03518 Mdot
.2018 .03527 Mdot
.20288 .03552 Mdot
.20354 .03568 Mdot
.20418 .03583 Mdot
.20503 .03603 Mdot
.20528 .03609 Mdot
.2057 .03618 Mdot
.20601 .03626 Mdot
.20658 .03639 Mdot
.20678 .03644 Mdot
.20745 .0366 Mdot
.20813 .03676 Mdot
.20951 .03709 Mdot
.21002 .03722 Mdot
.21061 .03736 Mdot
.21108 .03747 Mdot
.21162 .0376 Mdot
.21228 .03777 Mdot
.21333 .03802 Mdot
.21352 .03807 Mdot
.21381 .03814 Mdot
.21429 .03826 Mdot
.21487 .0384 Mdot
.21499 .03843 Mdot
.2158 .03864 Mdot
.21634 .03877 Mdot
.21675 .03887 Mdot
.2176 .03909 Mdot
.21785 .03915 Mdot
.21857 .03933 Mdot
.21927 .03951 Mdot
.2196 .03959 Mdot
.22024 .03976 Mdot
.2206 .03985 Mdot
.22188 .04017 Mdot
.22252 .04034 Mdot
.2236 .04062 Mdot
.22407 .04074 Mdot
.22433 .04081 Mdot
.22551 .04112 Mdot
.22625 .04131 Mdot
.22664 .04141 Mdot
.2267 .04143 Mdot
.22724 .04157 Mdot
.22807 .04179 Mdot
.22896 .04203 Mdot
.2293 .04212 Mdot
.22976 .04224 Mdot
.23075 .0425 Mdot
.2311 .0426 Mdot
.23255 .04299 Mdot
.23287 .04308 Mdot
.23354 .04326 Mdot
.23395 .04337 Mdot
.23543 .04378 Mdot
.23581 .04388 Mdot
.23665 .04411 Mdot
.23679 .04415 Mdot
.23721 .04427 Mdot
.23764 .04439 Mdot
.23804 .0445 Mdot
.23848 .04462 Mdot
.23871 .04468 Mdot
.23978 .04498 Mdot
.24036 .04515 Mdot
.24149 .04546 Mdot
.24263 .04579 Mdot
.2428 .04584 Mdot
.24397 .04617 Mdot
.24448 .04632 Mdot
.24501 .04647 Mdot
.24622 .04682 Mdot
.24678 .04698 Mdot
.24712 .04707 Mdot
.24799 .04733 Mdot
.24863 .04752 Mdot
.24944 .04775 Mdot
.25022 .04798 Mdot
.25094 .04819 Mdot
.2515 .04836 Mdot
.25188 .04847 Mdot
.25229 .04859 Mdot
.25286 .04876 Mdot
.25327 .04888 Mdot
.25365 .049 Mdot
.25436 .04921 Mdot
.25473 .04932 Mdot
.25585 .04965 Mdot
.25596 .04969 Mdot
.25671 .04992 Mdot
.2576 .05019 Mdot
.25877 .05054 Mdot
.25914 .05065 Mdot
.25957 .05078 Mdot
.2603 .05101 Mdot
.26115 .05127 Mdot
.26175 .05146 Mdot
.2625 .05169 Mdot
.26268 .05174 Mdot
.26329 .05193 Mdot
.26356 .05202 Mdot
.26414 .0522 Mdot
.26513 .05251 Mdot
.26634 .05289 Mdot
.26679 .05303 Mdot
.26738 .05321 Mdot
.26819 .05347 Mdot
.26849 .05357 Mdot
.26946 .05387 Mdot
.27025 .05413 Mdot
.27058 .05423 Mdot
.27091 .05434 Mdot
.27176 .05461 Mdot
.27227 .05478 Mdot
.27302 .05502 Mdot
.27331 .05511 Mdot
.27381 .05527 Mdot
.2743 .05543 Mdot
.27464 .05554 Mdot
.27539 .05579 Mdot
.27623 .05606 Mdot
.27683 .05626 Mdot
.27825 .05673 Mdot
.27839 .05677 Mdot
.27932 .05708 Mdot
.27959 .05717 Mdot
.28055 .05749 Mdot
.28133 .05775 Mdot
.28191 .05794 Mdot
.28238 .0581 Mdot
.2829 .05828 Mdot
.28326 .0584 Mdot
.2842 .05872 Mdot
.28476 .0589 Mdot
.28502 .05899 Mdot
.28617 .05938 Mdot
.28667 .05955 Mdot
.28701 .05967 Mdot
.2881 .06004 Mdot
.28905 .06037 Mdot
.28952 .06053 Mdot
.29057 .06089 Mdot
.29081 .06098 Mdot
.29234 .06151 Mdot
.29287 .0617 Mdot
.29361 .06195 Mdot
.29433 .06221 Mdot
.29551 .06262 Mdot
.29614 .06284 Mdot
.29637 .06292 Mdot
.29705 .06317 Mdot
.29749 .06332 Mdot
.29824 .06359 Mdot
.29886 .06381 Mdot
.29905 .06388 Mdot
.30007 .06424 Mdot
.3008 .0645 Mdot
.30131 .06469 Mdot
.30292 .06527 Mdot
.30334 .06542 Mdot
.30442 .06581 Mdot
.30526 .06612 Mdot
.30579 .06631 Mdot
.30675 .06667 Mdot
.30695 .06674 Mdot
.30766 .067 Mdot
.30834 .06725 Mdot
.30928 .0676 Mdot
.30987 .06782 Mdot
.31081 .06817 Mdot
.31116 .0683 Mdot
.31214 .06867 Mdot
.31254 .06881 Mdot
.31296 .06897 Mdot
.31342 .06914 Mdot
.31414 .06942 Mdot
.31451 .06955 Mdot
.31546 .06991 Mdot
.31606 .07014 Mdot
.31683 .07043 Mdot
.3184 .07103 Mdot
.31861 .07111 Mdot
.31905 .07128 Mdot
.31961 .07149 Mdot
.32077 .07194 Mdot
.32145 .07221 Mdot
.32268 .07268 Mdot
.323 .07281 Mdot
.32378 .07311 Mdot
.32452 .0734 Mdot
.32531 .0737 Mdot
.32606 .074 Mdot
.32735 .07451 Mdot
.32823 .07485 Mdot
.32865 .07502 Mdot
.32925 .07526 Mdot
.32977 .07546 Mdot
.33055 .07578 Mdot
.33099 .07595 Mdot
.3322 .07643 Mdot
.33237 .0765 Mdot
.33267 .07662 Mdot
.33349 .07695 Mdot
.33502 .07756 Mdot
.33554 .07777 Mdot
.33631 .07809 Mdot
.33688 .07832 Mdot
.33724 .07847 Mdot
.33827 .07889 Mdot
.33852 .07899 Mdot
.33975 .07949 Mdot
.34013 .07964 Mdot
.34087 .07995 Mdot
.3415 .08021 Mdot
.34198 .08041 Mdot
.34274 .08072 Mdot
.34312 .08088 Mdot
.34393 .08122 Mdot
.34394 .08122 Mdot
.34489 .08162 Mdot
.34534 .0818 Mdot
.346 .08208 Mdot
.3468 .08242 Mdot
.34739 .08266 Mdot
.34812 .08297 Mdot
.34847 .08312 Mdot
.34956 .08358 Mdot
.35052 .08398 Mdot
.35073 .08407 Mdot
.35122 .08428 Mdot
.35184 .08454 Mdot
.35205 .08463 Mdot
.35283 .08497 Mdot
.35333 .08518 Mdot
.35374 .08535 Mdot
.35544 .08609 Mdot
.35589 .08628 Mdot
.35614 .08638 Mdot
.35653 .08655 Mdot
.35752 .08698 Mdot
.35783 .08712 Mdot
.35885 .08756 Mdot
.35973 .08794 Mdot
.36029 .08818 Mdot
.36065 .08835 Mdot
.36131 .08863 Mdot
.3622 .08903 Mdot
.3629 .08933 Mdot
.36316 .08945 Mdot
.36395 .08979 Mdot
.36404 .08983 Mdot
.36522 .09036 Mdot
.36574 .09059 Mdot
.36588 .09065 Mdot
.36615 .09077 Mdot
.36714 .09121 Mdot
.36805 .09161 Mdot
.36928 .09217 Mdot
.36986 .09243 Mdot
.37013 .09255 Mdot
.37088 .09289 Mdot
.37149 .09316 Mdot
.37212 .09345 Mdot
.37275 .09373 Mdot
.37303 .09386 Mdot
.37416 .09437 Mdot
.37481 .09467 Mdot
.37543 .09495 Mdot
.37623 .09531 Mdot
.37742 .09586 Mdot
.37772 .09599 Mdot
.379 .09658 Mdot
.37928 .09671 Mdot
.38051 .09728 Mdot
.38062 .09733 Mdot
.38204 .09799 Mdot
.3823 .09811 Mdot
.38315 .09851 Mdot
.38339 .09862 Mdot
.38432 .09905 Mdot
.38535 .09954 Mdot
.38617 .09992 Mdot
.38638 .10002 Mdot
.38728 .10044 Mdot
.38771 .10065 Mdot
.38844 .101 Mdot
.38897 .10125 Mdot
.38953 .10151 Mdot
.39006 .10176 Mdot
.39048 .10196 Mdot
.39135 .10238 Mdot
.39158 .10249 Mdot
.39245 .1029 Mdot
.39338 .10335 Mdot
.39414 .10371 Mdot
.39458 .10392 Mdot
.39581 .10452 Mdot
.39609 .10465 Mdot
.3964 .1048 Mdot
.3968 .10499 Mdot
.39773 .10545 Mdot
.39796 .10556 Mdot
.399 .10607 Mdot
.39971 .10641 Mdot
.40045 .10677 Mdot
.4009 .10699 Mdot
.40176 .10741 Mdot
.40229 .10768 Mdot
.40306 .10805 Mdot
.40388 .10846 Mdot
.40437 .1087 Mdot
.40469 .10885 Mdot
.4052 .10911 Mdot
.40541 .10921 Mdot
.40567 .10934 Mdot
.40677 .10989 Mdot
.40759 .1103 Mdot
.4084 .1107 Mdot
.40901 .11101 Mdot
.41001 .11151 Mdot
.41093 .11197 Mdot
.41166 .11233 Mdot
.41246 .11274 Mdot
.41266 .11284 Mdot
.4131 .11306 Mdot
.41419 .11361 Mdot
.41448 .11376 Mdot
.41486 .11395 Mdot
.41532 .11419 Mdot
.41585 .11445 Mdot
.41687 .11497 Mdot
.41769 .11539 Mdot
.41835 .11573 Mdot
.41919 .11616 Mdot
.41948 .11631 Mdot
.42028 .11672 Mdot
.4215 .11735 Mdot
.42188 .11754 Mdot
.42242 .11783 Mdot
.42367 .11847 Mdot
.42409 .11869 Mdot
.4249 .11911 Mdot
.42524 .11929 Mdot
.42543 .11939 Mdot
.42622 .1198 Mdot
.42712 .12027 Mdot
.42768 .12056 Mdot
.42817 .12082 Mdot
.42844 .12096 Mdot
.42959 .12157 Mdot
.42979 .12167 Mdot
.4307 .12215 Mdot
.4311 .12236 Mdot
.43165 .12265 Mdot
.4325 .1231 Mdot
.4331 .12342 Mdot
.43355 .12366 Mdot
.43402 .12391 Mdot
.43447 .12416 Mdot
.43538 .12464 Mdot
.43639 .12518 Mdot
.43676 .12538 Mdot
.43755 .1258 Mdot
.43825 .12618 Mdot
.43957 .12689 Mdot
.44017 .12721 Mdot
.44097 .12765 Mdot
.44198 .12819 Mdot
.44254 .1285 Mdot
.44308 .12879 Mdot
.44384 .1292 Mdot
.44457 .1296 Mdot
.44473 .12969 Mdot
.44556 .13015 Mdot
.446 .13038 Mdot
.44653 .13067 Mdot
.44744 .13118 Mdot
.44778 .13136 Mdot
.44865 .13184 Mdot
.44895 .13201 Mdot
.44956 .13234 Mdot
.45069 .13297 Mdot
.45121 .13326 Mdot
.45172 .13354 Mdot
.45225 .13384 Mdot
.45325 .13439 Mdot
.45395 .13478 Mdot
.45474 .13522 Mdot
.45535 .13556 Mdot
.45541 .1356 Mdot
.45681 .13638 Mdot
.45762 .13684 Mdot
.45776 .13692 Mdot
.45887 .13754 Mdot
.45965 .13799 Mdot
.45999 .13818 Mdot
.46068 .13857 Mdot
.46133 .13894 Mdot
.46174 .13917 Mdot
.46231 .13949 Mdot
.46317 .13999 Mdot
.46357 .14021 Mdot
.46477 .1409 Mdot
.46528 .14119 Mdot
.46599 .1416 Mdot
.46676 .14204 Mdot
.46767 .14256 Mdot
.46782 .14265 Mdot
.46839 .14298 Mdot
.46889 .14326 Mdot
.46949 .14361 Mdot
.47004 .14393 Mdot
.47097 .14447 Mdot
.47171 .1449 Mdot
.4727 .14548 Mdot
.47333 .14585 Mdot
.47431 .14642 Mdot
.47476 .14668 Mdot
.47584 .14731 Mdot
.47645 .14767 Mdot
.47673 .14784 Mdot
.47797 .14857 Mdot
.47834 .14878 Mdot
.47875 .14902 Mdot
.47922 .14931 Mdot
.47991 .14971 Mdot
.48078 .15022 Mdot
.48095 .15033 Mdot
.48186 .15087 Mdot
.48251 .15125 Mdot
.48392 .15209 Mdot
.48474 .15259 Mdot
.48498 .15273 Mdot
.48573 .15318 Mdot
.48661 .15371 Mdot
.48714 .15403 Mdot
.48796 .15452 Mdot
.48876 .155 Mdot
.48926 .1553 Mdot
.48982 .15564 Mdot
.49034 .15596 Mdot
.49099 .15635 Mdot
.49216 .15706 Mdot
.49322 .1577 Mdot
.49356 .15791 Mdot
.49446 .15846 Mdot
.49492 .15874 Mdot
.4959 .15934 Mdot
.49683 .15991 Mdot
.49761 .16039 Mdot
.49813 .16071 Mdot
.49925 .1614 Mdot
.50007 .16191 Mdot
.50056 .16221 Mdot
.50091 .16243 Mdot
.50175 .16295 Mdot
.50271 .16354 Mdot
.50326 .16389 Mdot
.50458 .16471 Mdot
.50502 .16498 Mdot
.50595 .16556 Mdot
.50665 .16601 Mdot
.507 .16622 Mdot
.5081 .16692 Mdot
.5084 .1671 Mdot
.50964 .16788 Mdot
.51008 .16816 Mdot
.51092 .16869 Mdot
.51174 .16921 Mdot
.51212 .16945 Mdot
.51284 .16991 Mdot
.51353 .17035 Mdot
.51433 .17085 Mdot
.51523 .17143 Mdot
.51562 .17168 Mdot
.51667 .17235 Mdot
.51706 .1726 Mdot
.51773 .17303 Mdot
.5189 .17378 Mdot
.51913 .17392 Mdot
.52024 .17464 Mdot
.52124 .17529 Mdot
.52229 .17596 Mdot
.52275 .17627 Mdot
.52306 .17646 Mdot
.52433 .17729 Mdot
.5246 .17746 Mdot
.52483 .17761 Mdot
.52556 .17809 Mdot
.52607 .17842 Mdot
.52716 .17913 Mdot
.52745 .17932 Mdot
.52832 .17989 Mdot
.52925 .1805 Mdot
.52969 .18079 Mdot
.53001 .181 Mdot
.53105 .18168 Mdot
.5316 .18205 Mdot
.53263 .18272 Mdot
.53333 .18318 Mdot
.53456 .184 Mdot
.53466 .18407 Mdot
.5358 .18483 Mdot
.53629 .18515 Mdot
.53704 .18565 Mdot
.53781 .18616 Mdot
.53854 .18665 Mdot
.53886 .18686 Mdot
.53918 .18708 Mdot
.54058 .18801 Mdot
.5411 .18836 Mdot
.54169 .18876 Mdot
.54298 .18963 Mdot
.54344 .18994 Mdot
.54418 .19044 Mdot
.54542 .19127 Mdot
.54571 .19147 Mdot
.54632 .19189 Mdot
.54721 .19249 Mdot
.54843 .19332 Mdot
.54874 .19353 Mdot
.54983 .19428 Mdot
.55048 .19471 Mdot
.5511 .19514 Mdot
.55144 .19538 Mdot
.55205 .1958 Mdot
.55278 .19629 Mdot
.55331 .19665 Mdot
.55474 .19764 Mdot
.55559 .19823 Mdot
.55601 .19852 Mdot
.55607 .19856 Mdot
.55697 .19918 Mdot
.55712 .19928 Mdot
.55799 .19989 Mdot
.55892 .20053 Mdot
.55921 .20073 Mdot
.55962 .20102 Mdot
.56047 .20161 Mdot
.56163 .20242 Mdot
.56252 .20304 Mdot
.56328 .20357 Mdot
.56445 .2044 Mdot
.56549 .20513 Mdot
.56611 .20556 Mdot
.56665 .20594 Mdot
.56745 .2065 Mdot
.56798 .20688 Mdot
.56874 .20742 Mdot
.57 .20831 Mdot
.57011 .20839 Mdot
.57098 .209 Mdot
.57122 .20917 Mdot
.57187 .20963 Mdot
.57278 .21028 Mdot
.57393 .21111 Mdot
.57421 .21131 Mdot
.57531 .21209 Mdot
.57593 .21254 Mdot
.57623 .21275 Mdot
.57655 .21298 Mdot
.57747 .21364 Mdot
.57777 .21386 Mdot
.57874 .21456 Mdot
.57924 .21491 Mdot
.57976 .21529 Mdot
.58043 .21577 Mdot
.58092 .21612 Mdot
.58173 .21671 Mdot
.58242 .21721 Mdot
.58286 .21753 Mdot
.58322 .2178 Mdot
.58432 .21859 Mdot
.58477 .21892 Mdot
.58582 .21969 Mdot
.58616 .21993 Mdot
.58673 .22035 Mdot
.58745 .22088 Mdot
.58759 .22098 Mdot
.58857 .2217 Mdot
.58994 .2227 Mdot
.59002 .22276 Mdot
.59086 .22337 Mdot
.59118 .22361 Mdot
.59232 .22445 Mdot
.59256 .22463 Mdot
.59301 .22496 Mdot
.59384 .22558 Mdot
.5945 .22607 Mdot
.59515 .22655 Mdot
.59579 .22702 Mdot
.59637 .22745 Mdot
.59712 .22801 Mdot
.59745 .22825 Mdot
.59818 .2288 Mdot
.59874 .22922 Mdot
.59966 .22991 Mdot
.60033 .23041 Mdot
.60084 .23079 Mdot
.60227 .23186 Mdot
.6031 .23249 Mdot
.60355 .23282 Mdot
.60464 .23365 Mdot
.60503 .23394 Mdot
.60553 .23431 Mdot
.6059 .23459 Mdot
.60688 .23534 Mdot
.60771 .23597 Mdot
.60885 .23683 Mdot
.60967 .23745 Mdot
.60995 .23766 Mdot
.6108 .23831 Mdot
.6114 .23877 Mdot
.61184 .2391 Mdot
.61209 .23929 Mdot
.61358 .24043 Mdot
.61444 .24109 Mdot
.61495 .24149 Mdot
.61575 .2421 Mdot
.61656 .24272 Mdot
.61732 .24331 Mdot
.61759 .24351 Mdot
.61851 .24422 Mdot
.61912 .24469 Mdot
.61988 .24528 Mdot
.62055 .2458 Mdot
.6216 .24661 Mdot
.62181 .24678 Mdot
.62223 .2471 Mdot
.62312 .2478 Mdot
.62389 .2484 Mdot
.6246 .24895 Mdot
.62513 .24936 Mdot
.62623 .25022 Mdot
.62686 .25071 Mdot
.62766 .25134 Mdot
.62843 .25194 Mdot
.62949 .25277 Mdot
.62962 .25288 Mdot
.63086 .25386 Mdot
.63183 .25462 Mdot
.63212 .25485 Mdot
.63265 .25527 Mdot
.63377 .25615 Mdot
.6342 .2565 Mdot
.63546 .25749 Mdot
.63634 .25819 Mdot
.63655 .25836 Mdot
.63721 .25889 Mdot
.63796 .25948 Mdot
.63859 .25999 Mdot
.63868 .26006 Mdot
.63913 .26042 Mdot
.63964 .26082 Mdot
.64049 .2615 Mdot
.64141 .26224 Mdot
.64181 .26256 Mdot
.64297 .26349 Mdot
.64318 .26366 Mdot
.64367 .26406 Mdot
.64422 .2645 Mdot
.64445 .26468 Mdot
.6453 .26537 Mdot
.6465 .26633 Mdot
.64707 .26679 Mdot
.64764 .26726 Mdot
.6485 .26795 Mdot
.64862 .26805 Mdot
.6494 .26868 Mdot
.65052 .26959 Mdot
.65087 .26988 Mdot
.65163 .2705 Mdot
.65253 .27123 Mdot
.65261 .2713 Mdot
.65333 .27188 Mdot
.65376 .27224 Mdot
.65444 .27279 Mdot
.65522 .27343 Mdot
.65621 .27425 Mdot
.65665 .27461 Mdot
.65732 .27516 Mdot
.65825 .27592 Mdot
.65873 .27632 Mdot
.65903 .27656 Mdot
.66011 .27745 Mdot
.66086 .27807 Mdot
.66121 .27836 Mdot
.66161 .27869 Mdot
.66239 .27934 Mdot
.66329 .28009 Mdot
.66395 .28064 Mdot
.66508 .28158 Mdot
.66536 .2818 Mdot
.66571 .2821 Mdot
.6673 .28343 Mdot
.6676 .28367 Mdot
.66833 .28429 Mdot
.66864 .28455 Mdot
.6696 .28535 Mdot
.67043 .28605 Mdot
.67096 .28649 Mdot
.67195 .28732 Mdot
.67293 .28815 Mdot
.67334 .2885 Mdot
.67451 .28949 Mdot
.6752 .29006 Mdot
.67593 .29068 Mdot
.67598 .29073 Mdot
.67683 .29144 Mdot
.67733 .29187 Mdot
.67862 .29296 Mdot
.67971 .29389 Mdot
.67984 .29401 Mdot
.68116 .29513 Mdot
.68156 .29547 Mdot
.6819 .29576 Mdot
.68298 .29668 Mdot
.6839 .29747 Mdot
.68464 .2981 Mdot
.68519 .29857 Mdot
.68632 .29955 Mdot
.68684 .29999 Mdot
.68746 .30053 Mdot
.68809 .30107 Mdot
.6886 .30151 Mdot
.68937 .30218 Mdot
.68967 .30243 Mdot
.69045 .30311 Mdot
.69114 .30371 Mdot
.69164 .30414 Mdot
.6927 .30506 Mdot
.69346 .30572 Mdot
.69375 .30597 Mdot
.69419 .30635 Mdot
.69547 .30747 Mdot
.69595 .30789 Mdot
.6962 .3081 Mdot
.69712 .30891 Mdot
.698 .30968 Mdot
.6988 .31038 Mdot
.69936 .31087 Mdot
.69969 .31116 Mdot
.70004 .31146 Mdot
.70031 .31171 Mdot
.70101 .31232 Mdot
.70174 .31296 Mdot
.70314 .31419 Mdot
.7039 .31487 Mdot
.705 .31583 Mdot
.70561 .31638 Mdot
.70631 .317 Mdot
.70727 .31785 Mdot
.70741 .31797 Mdot
.70786 .31837 Mdot
.70884 .31924 Mdot
.70911 .31948 Mdot
.70941 .31975 Mdot
.71054 .32075 Mdot
.71126 .3214 Mdot
.71232 .32234 Mdot
.71271 .32269 Mdot
.71287 .32283 Mdot
.71422 .32404 Mdot
.71454 .32433 Mdot
.71532 .32503 Mdot
.71654 .32612 Mdot
.71716 .32668 Mdot
.71762 .32709 Mdot
.71801 .32744 Mdot
.7189 .32825 Mdot
.72004 .32928 Mdot
.72058 .32977 Mdot
.72113 .33026 Mdot
.72209 .33114 Mdot
.72235 .33137 Mdot
.7237 .33259 Mdot
.72415 .333 Mdot
.72508 .33385 Mdot
.72542 .33415 Mdot
.72589 .33459 Mdot
.72655 .33519 Mdot
.72743 .33599 Mdot
.728 .33651 Mdot
.72822 .33671 Mdot
.72882 .33726 Mdot
.73025 .33857 Mdot
.73038 .33869 Mdot
.73151 .33972 Mdot
.73185 .34004 Mdot
.73214 .34031 Mdot
.73329 .34136 Mdot
.73414 .34215 Mdot
.7347 .34266 Mdot
.73496 .34291 Mdot
.73576 .34365 Mdot
.73632 .34416 Mdot
.73711 .34489 Mdot
.73773 .34547 Mdot
.73817 .34588 Mdot
.73927 .34689 Mdot
.73979 .34738 Mdot
.74038 .34792 Mdot
.74079 .34831 Mdot
.74157 .34903 Mdot
.74194 .34938 Mdot
.74268 .35007 Mdot
.7434 .35074 Mdot
.74387 .35118 Mdot
.74459 .35185 Mdot
.74543 .35264 Mdot
.74578 .35296 Mdot
.74631 .35346 Mdot
.7472 .3543 Mdot
.74779 .35486 Mdot
.74873 .35574 Mdot
.74931 .35629 Mdot
.74976 .3567 Mdot
.75038 .35729 Mdot
.75074 .35763 Mdot
.75084 .35773 Mdot
.75148 .35833 Mdot
.7527 .35949 Mdot
.7537 .36043 Mdot
.75433 .36103 Mdot
.75516 .36181 Mdot
.75542 .36206 Mdot
.75623 .36283 Mdot
.75638 .36298 Mdot
.75759 .36412 Mdot
.7588 .36528 Mdot
.75943 .36587 Mdot
.76016 .36658 Mdot
.76041 .36682 Mdot
.76102 .3674 Mdot
.76177 .36811 Mdot
.76253 .36885 Mdot
.76282 .36912 Mdot
.76388 .37014 Mdot
.76449 .37073 Mdot
.76508 .37129 Mdot
.76595 .37213 Mdot
.76644 .3726 Mdot
.76696 .3731 Mdot
.76752 .37364 Mdot
.76876 .37485 Mdot
.7691 .37517 Mdot
.77039 .37642 Mdot
.7714 .3774 Mdot
.77239 .37836 Mdot
.77329 .37923 Mdot
.77343 .37938 Mdot
.77465 .38056 Mdot
.77521 .38111 Mdot
.77617 .38204 Mdot
.77664 .38251 Mdot
.77749 .38334 Mdot
.77763 .38347 Mdot
.77873 .38455 Mdot
.77964 .38544 Mdot
.77975 .38555 Mdot
.78126 .38703 Mdot
.7814 .38717 Mdot
.78251 .38826 Mdot
.78341 .38914 Mdot
.78385 .38958 Mdot
.78478 .39049 Mdot
.78508 .39079 Mdot
.78571 .39141 Mdot
.78641 .39211 Mdot
.78731 .393 Mdot
.788 .39369 Mdot
.78865 .39433 Mdot
.78904 .39472 Mdot
.78981 .39548 Mdot
.79046 .39613 Mdot
.79124 .3969 Mdot
.7913 .39696 Mdot
.79219 .39785 Mdot
.79244 .3981 Mdot
.79313 .39879 Mdot
.79437 .40003 Mdot
.79462 .40028 Mdot
.79518 .40084 Mdot
.79567 .40133 Mdot
.79628 .40194 Mdot
.7969 .40257 Mdot
.79821 .40388 Mdot
.79878 .40446 Mdot
.79981 .40548 Mdot
.80036 .40604 Mdot
.80103 .40672 Mdot
.80196 .40766 Mdot
.80224 .40794 Mdot
.80324 .40895 Mdot
.80388 .4096 Mdot
.80427 .41 Mdot
.80508 .41081 Mdot
.80609 .41183 Mdot
.80647 .41223 Mdot
.80671 .41247 Mdot
.80772 .4135 Mdot
.80794 .41372 Mdot
.80898 .41478 Mdot
.80922 .41503 Mdot
.81033 .41615 Mdot
.81085 .41668 Mdot
.81135 .4172 Mdot
.81193 .41779 Mdot
.81267 .41855 Mdot
.8131 .41899 Mdot
.81367 .41957 Mdot
.81416 .42008 Mdot
.81462 .42055 Mdot
.81467 .4206 Mdot
.81567 .42163 Mdot
.81695 .42294 Mdot
.81748 .42348 Mdot
.81798 .424 Mdot
.81912 .42518 Mdot
.81974 .42582 Mdot
.8209 .42702 Mdot
.82112 .42725 Mdot
.82183 .42798 Mdot
.82227 .42844 Mdot
.82309 .42928 Mdot
.82383 .43006 Mdot
.82456 .43082 Mdot
.8255 .43179 Mdot
.82655 .43289 Mdot
.8274 .43377 Mdot
.82789 .43429 Mdot
.82809 .43449 Mdot
.82915 .43559 Mdot
.82932 .43577 Mdot
.8298 .43628 Mdot
.83092 .43745 Mdot
.83118 .43773 Mdot
.83174 .4383 Mdot
.83259 .4392 Mdot
.83337 .44002 Mdot
.83397 .44065 Mdot
.83486 .44158 Mdot
.83549 .44225 Mdot
.83647 .44328 Mdot
.83698 .44382 Mdot
.83808 .44498 Mdot
.83904 .446 Mdot
.83962 .44661 Mdot
.84008 .4471 Mdot
.84077 .44784 Mdot
.84156 .44867 Mdot
.84201 .44914 Mdot
.84275 .44993 Mdot
.84352 .45076 Mdot
.84445 .45175 Mdot
.8447 .45201 Mdot
.84577 .45315 Mdot
.84615 .45356 Mdot
.84708 .45454 Mdot
.84773 .45524 Mdot
.8482 .45574 Mdot
.84887 .45646 Mdot
.84895 .45655 Mdot
.84968 .45733 Mdot
.85011 .45779 Mdot
.85061 .45832 Mdot
.85139 .45917 Mdot
.85205 .45987 Mdot
.85299 .46088 Mdot
.85342 .46134 Mdot
.85404 .46202 Mdot
.85474 .46277 Mdot
.85561 .46371 Mdot
.85613 .46427 Mdot
.85644 .46461 Mdot
.85748 .46573 Mdot
.85803 .46632 Mdot
.85892 .46729 Mdot
.85918 .46757 Mdot
.85969 .46813 Mdot
.86085 .46938 Mdot
.86154 .47014 Mdot
.86217 .47082 Mdot
.86282 .47152 Mdot
.86371 .4725 Mdot
.86395 .47275 Mdot
.86455 .47341 Mdot
.86534 .47427 Mdot
.86595 .47494 Mdot
.86654 .47558 Mdot
.86709 .47618 Mdot
.86843 .47765 Mdot
.86909 .47838 Mdot
.86991 .47927 Mdot
.87096 .48043 Mdot
.87173 .48128 Mdot
.87196 .48153 Mdot
.87259 .48222 Mdot
.87316 .48286 Mdot
.87411 .4839 Mdot
.87495 .48483 Mdot
.87634 .48637 Mdot
.87653 .48658 Mdot
.87749 .48764 Mdot
.87799 .4882 Mdot
.8788 .48909 Mdot
.87951 .48988 Mdot
.88008 .49052 Mdot
.88026 .49072 Mdot
.88167 .49228 Mdot
.88188 .49252 Mdot
.8826 .49332 Mdot
.88349 .49431 Mdot
.88428 .49519 Mdot
.88545 .4965 Mdot
.88625 .49739 Mdot
.88654 .49772 Mdot
.88745 .49874 Mdot
.88819 .49957 Mdot
.88938 .50091 Mdot
.88996 .50156 Mdot
.89073 .50242 Mdot
.89154 .50334 Mdot
.89163 .50344 Mdot
.89279 .50474 Mdot
.8932 .50521 Mdot
.89416 .50629 Mdot
.89474 .50694 Mdot
.89547 .50777 Mdot
.89559 .5079 Mdot
.89602 .50839 Mdot
.89684 .50932 Mdot
.89747 .51004 Mdot
.89786 .51048 Mdot
.89835 .51104 Mdot
.89902 .5118 Mdot
.89966 .51252 Mdot
.90025 .51319 Mdot
.90113 .5142 Mdot
.90238 .51562 Mdot
.90261 .51589 Mdot
.90353 .51693 Mdot
.90381 .51725 Mdot
.90464 .5182 Mdot
.90507 .5187 Mdot
.90566 .51936 Mdot
.90685 .52073 Mdot
.90769 .52169 Mdot
.90839 .5225 Mdot
.90849 .52261 Mdot
.90956 .52384 Mdot
.9101 .52446 Mdot
.91014 .52451 Mdot
.91101 .52551 Mdot
.91172 .52633 Mdot
.91181 .52643 Mdot
.9124 .52711 Mdot
.91323 .52807 Mdot
.91368 .52858 Mdot
.9139 .52884 Mdot
.91444 .52946 Mdot
.91515 .53029 Mdot
.91576 .53099 Mdot
.91644 .53178 Mdot
.91693 .53235 Mdot
.9175 .53301 Mdot
.91763 .53316 Mdot
.91833 .53398 Mdot
.91906 .53482 Mdot
.91954 .53538 Mdot
.92009 .53602 Mdot
.9204 .53638 Mdot
.92162 .5378 Mdot
.92186 .53808 Mdot
.92251 .53883 Mdot
.92302 .53943 Mdot
.92411 .5407 Mdot
.9245 .54117 Mdot
.92578 .54265 Mdot
.92613 .54307 Mdot
.92745 .54461 Mdot
.92812 .54541 Mdot
.92904 .54648 Mdot
.92976 .54733 Mdot
.93059 .54831 Mdot
.93134 .54919 Mdot
.93158 .54947 Mdot
.93208 .55006 Mdot
.9326 .55067 Mdot
.93364 .55189 Mdot
.93368 .55195 Mdot
.9344 .5528 Mdot
.93553 .55414 Mdot
.93658 .55538 Mdot
.9376 .55658 Mdot
.93808 .55716 Mdot
.93883 .55804 Mdot
.93937 .55869 Mdot
.94 .55944 Mdot
.94046 .55998 Mdot
.9409 .5605 Mdot
.94167 .56142 Mdot
.94289 .56288 Mdot
.94323 .56328 Mdot
.94411 .56433 Mdot
.94503 .56543 Mdot
.94548 .56597 Mdot
.94588 .56644 Mdot
.94707 .56788 Mdot
.94727 .56811 Mdot
.94817 .5692 Mdot
.94872 .56985 Mdot
.94946 .57074 Mdot
.94979 .57114 Mdot
.951 .5726 Mdot
.95137 .57304 Mdot
.95198 .57377 Mdot
.95319 .57523 Mdot
.95441 .5767 Mdot
.95474 .57711 Mdot
.95499 .5774 Mdot
.95647 .5792 Mdot
.95694 .57976 Mdot
.95768 .58066 Mdot
.95812 .5812 Mdot
.95926 .58257 Mdot
.96044 .58401 Mdot
.96075 .58438 Mdot
.96169 .58553 Mdot
.96248 .58649 Mdot
.9627 .58676 Mdot
.96338 .58759 Mdot
.9645 .58896 Mdot
.96495 .58951 Mdot
.96551 .59019 Mdot
.96635 .59122 Mdot
.96675 .59171 Mdot
.96776 .59295 Mdot
.96847 .59381 Mdot
.96897 .59443 Mdot
.96965 .59526 Mdot
.97049 .5963 Mdot
.97195 .59808 Mdot
.9726 .59888 Mdot
.97326 .59971 Mdot
.97336 .59983 Mdot
.97377 .60033 Mdot
.97406 .60069 Mdot
.975 .60184 Mdot
.97544 .60239 Mdot
.97579 .60282 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1408) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0021736) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666618) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000030?[`iPH0
00000P3jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0
n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2
000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00
00030?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40
oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4
000000<0n_3V100000030?[`iP@000000`3jl>H4000000D0n_3V0P0000040?[`iP<00000o`3jl>JM
0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H40000
00030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H20000
00D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`
iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001`3jl>H2000000<0n_3V0P0000000`3j
l>H000000000003o0?[`iY`0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0
n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0n_3V0P0000050?[`iP80
00001@3jl>H2000000D0n_3V0P0000040?[`iP@000000`3jl>H2000000030?[`iP00000000000?l0
n_3VW03jl>H10?ooo`007`3jl>H6000000@0n_3V0P00000_0?[`iPD00000:03jl>H3000000`0n_3V
0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP800000103jl>H300000?l0n_3V
W@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V
5`3jl>H10?ooo`00803jl>H6000000050?[`iP00000000000000003jl>H00`0000020?[`iP<00000
0`3jl>H4000000<0n_3V0P000000103jl>H000000000003jl>H5000000<0n_3V3000000_0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<0
00001@3jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP8000000P3jl>H010000000n_3V0000000000030?[`iP050000003jl>H000000000
003jl>H00`0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP8000008P3jl>H50000
00T0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`
iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP80
00001@3jl>H200000080n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP80
0000<03jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`00
8P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H6000000030?[`
iP00000000000080n_3V0P0000020?[`iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD00000
2@3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3j
l>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H200000080n_3V0P00
0000103jl>H000000000003jl>H300000080n_3V0`0000000`3jl>H000000?[`iP040?[`iP800000
0`3jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP@000000`3jl>H4000000<0n_3V
100000030?[`iP@000000`3jl>H4000000H0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00
00030?[`iPD000000P3jl>H5000000<0n_3V100000030?[`iP80000000<0n_3V0000000000001000
00000`3jl>H00000000000020?[`iP@00000103jl>H200000300n_3V0P0000000`3jl>H000000000
00090?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000P0n_3V0P00
003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;0?[`iP8000008P3jl>H200000300n_3V0P000000
0`3jl>H000000000000:0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2
000000@0n_3V00<000000?[`iP3jl>H00P00003o0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`
iP800000803jl>H400000340n_3V0`00000<0?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`
iP<00000103jl>H300000080n_3V1@00003o0?[`iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H20000
00030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0
n_3V00@000000?[`iP000000n_3V0P0000020?[`iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`
iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0000000000002000000050?[`iP000000n_3V0000
003jl>H00`0000020?[`iP030000003jl>H0000001P0n_3V1@00003K0?[`iP@00000103jl>H;0000
00@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H30000
00040?[`iP0000000000000000P0n_3V100000000`3jl>H00000000000020?[`iP@000000P3jl>H5
000000070?[`iP00000000000000003jl>H000000?[`iP03000001P0n_3V0`0000040?[`iP800000
1@3jl>H3000000@0n_3V0`0000030?[`iPD000000P3jl>H6000000<0n_3V0P0000040?[`iP<00000
103jl>H300000780n_3V0@3oool00240n_3V0P0000000`3jl>H0000000000005000000040?[`iP00
0000000000000080n_3V0P0000000`3jl>H00000000000090?[`iPD000002@3jl>H200000=l0n_3V
0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V
0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H200000080n_3V0P0000000`3j
l>H00000000000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP020000
00T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000L0n_3V0P0000050?[`
iP8000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H000000000001a0?[`
iP40oooo000R0?[`iP<00000:@3jl>H200000=h0n_3V0P0000040?[`iP8000000P3jl>H200000080
n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000
003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP020000
01P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000<0n_3V0P0000060?[`iP8000001@3jl>H2000000H0n_3V0P0000020?[`
iP80000000<0n_3V000000000000L@3jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP80
0000g@3jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0
n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`
iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP0000000000
00T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H20000
00D0n_3V0P0000050?[`iP8000001P3jl>H200000080n_3V0P0000000`3jl>H000000000001a0?[`
iP40oooo000Q0?[`iP80000000<0n_3V000000000000:P3jl>H200000=`0n_3V0P0000000`3jl>H0
0000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H20000
00@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000
000000002P3jl>H3000000040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V0`000000
0`3jl>H000000?[`iP02000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000
000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H2
000000@0n_3V0P0000060?[`iP8000000`3jl>H3000000<0n_3V1000001b0?[`iP40oooo000P0?[`
iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3j
l>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0
n_3V0000000000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P00
00000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000040?[`iP8000001P3jl>H2000000D0n_3V0P00
00020?[`iP800000M03jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`iP800000;P3jl>H2
000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP00000000000080n_3V100000030?[`iP030000003jl>H0
n_3V008000000P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P00001c0?[`iP40oooo001>0?[`
iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000I0?[`
iP<0000000<0n_3V0000000000000P00000^0?[`iP<000002`3jl>H3000000@0n_3V0`0000040?[`
iP<000001@3jl>H2000000<0n_3V1@0000030?[`iP<000001@3jl>H300000740n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2
000000030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool0
02L0n_3V00D000000?[`iP000000n_3V000000020?[`iP040000003jl>H0n_3V00000080n_3V00<0
00000?[`iP3jl>H0o`3jl>Ko0?[`iR80n_3V0@3oool00200n_3V0`0000000`3jl>H0000000000002
000000040?[`iP000000n_3V00000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V
0?[`iP0G0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V
0`0000020?[`iPH000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000006000001X0n_3V
1P0000020?[`iP@000000`3jl>H3000000@0n_3V0`00002c0?[`iP40oooo000Q0?[`iP80000000<0
n_3V0000000000001@0000001@3jl>H00000000000000000n_3V00@000002`3jl>H5000000T0n_3V
0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP800000
1@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000
n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP0000000000
0?[`iP8000000P3jl>H2000000/0n_3V1@00000;0?[`iP8000001@3jl>H2000000<0n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V000000000000/P3jl>H10?ooo`008P3jl>H30000
02P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`
iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000K0?[`iP8000000P3jl>H60000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000/P3jl>H10?oo
o`008P3jl>H3000000T0n_3V00<000000?[`iP3jl>H03P3jl>H5000000T0n_3V0P0000000`3jl>H0
00000000003L0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0
n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V00000000
0000n_3V1000000=0?[`iPD000002`3jl>H200000080n_3V00<000000?[`iP3jl>H00P0000030?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000;80n_3V0@3oool00240
n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0n_3V000000000000g03jl>H200000003
0?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`
iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103j
l>H000000000003jl>H200000080n_3V0P00000K0?[`iP8000000`3jl>H010000000n_3V00000000
00030?[`iP80000000<0n_3V0000000000000`3jl>H300000;<0n_3V0@3oool00200n_3V0`000000
103jl>H0000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00
000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@00000
0`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000<0n_3V1@00000K0?[`iP800000
0`3jl>H010000000n_3V0000000000030?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000;80n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP800000
00<0n_3V000000000000403jl>H2000000`0n_3V0P00000h0?[`iP@00000103jl>H3000000<0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000/P3jl>H10?ooo`00CP3j
l>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<P3j
l>H2000000D0n_3V0P0000040?[`iP<00000103jl>H300000;<0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iRH0oooP0P00001/0?ooh0800000
103oon02000000@0oooP0P00001[0?ooh0D00000J@3oon0500000080oooP0P0000040?ooh0800000
J`3oon04000002<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP
00@000000?ooh03oon000000203oon0010000000oooP0?ooh000001/0?ooh0030000003oon00oooP
06/0oooP00<000000?ooh03oon001`3oon0010000000oooP0?ooh000001Z0?ooh0030000003oon00
oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@00000
0?ooh03oon0000002`3oon000`000000oooP0?ooh01Z0?ooh0030000003oon00oooP06/0oooP00<0
00000?ooh03oon002P3oon000`000000oooP0?ooh01Y0?ooh0030000003oon00oooP02<0oooP7P3j
l>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000
2@3oon02000006d0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh0080?ooh0800000
K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?oo
h000001Z0?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03oon00K03oon000`000000
oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00JP3oon0010000000
oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0n_3V9P3oon02000006`0oooP0P00000:0?ooh0<0
0000J`3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000002@0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
5@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00
503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`000000oooP0?oo
h01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?oo
h0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00
oooP1@0000060?ooh0030000003oon00oooP00P0oooP5000003o0?ooh<X0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP
0?ooh0070?ooh2@00000o`3oon2k0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HB0?ooh0030000003oon00oooP00H0oooP100000060?ooh08000006P000?lB00000?l0oooP[P3o
on04000001P0oooP7P3jl>H10?ooo`007@3jl>H:0?ooh0@00000103oon000`000000oooP0?ooh006
0?ooh0030000003oon00oooP00P0oooP6`0000080000oa800000o`3oon2Y0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?oo
h03oon002@3oon0A0<f5?a4000002P000?l?00000?l0oooPXP3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3oon0P0<f5?``0
00002@000?l<00000?l0oooPW03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh2X0cHDo2`0000080000o`T00000o`3oon2G0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP<P3=
QCl;000000D0003o2P00003o0?ooh940oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon0i0<f5?`T000001@000?l:00000?l0oooPS03oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h3l0cHDo200000050000o`T00000o`3oon280?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPA@3=QCl7000000D0003o2@00003o0?ooh8<0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon1:0<f5?`L000001@000?l800000?l0oooPO`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh4l0cHDo1`0000040000o`P00000o`3o
on1k0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPD`3=QCl7000000D0003o1`00003o0?ooh7L0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1H0<f5?`L0000010000?l60000
0?l0oooPM03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh5`0cHDo1`0000040000o`H00000o`3oon1`0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon1P0<f5?`L000000`000?l600000?l0oooP
J`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPI03=
QCl6000000@0003o1@00003o0?ooh6X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon1W0<f5?`L000000`000?l600000?l0oooPIP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h6/0cHDo1P0000040000o`D00000o`3oon1S0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPKP3=QCl7000000<0003o1@00003o0?ooh600
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon1b0<f5?`H000000`000?l500000?l0oooPG@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh7D0cHDo1P0000020000o`H00000o`3o
on1J0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPN03=QCl5000000<0003o1P00003o0?ooh5L0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1k0<f5?`D000000`000?l60000
0?l0oooPE03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh7h0cHDo1@0000020000o`H00000o`3oon1B0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPP@3=QCl4000000<0003o
1P00003o0?ooh4l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon240<f5?`@000000`000?l500000?l0oooPC@3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh8L0cHDo10000003
0000o`D00000o`3oon1:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooPRP3=QCl400000080003o1P00003o0?ooh4L0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh8`0cHDo100000030000o`D0
0000o`3oon130?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon2?0<f5?`@000000`000?l500000?l0oooP@P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh940cHDo1@0000020000o`D00000o`3o
on100?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPU03=QCl4000000<0003o1@00003o0?ooh3d0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2G0<f5?`@000000`000?l40000
0?l0oooP>`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh9T0cHDo1@0000020000o`@00000o`3oon0i0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPW03=QCl400000080003o
1@00003o0?ooh3H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon2N0<f5?`@000000P000?l500000?l0oooP=03oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh:00cHDo10000002
0000o`D00000o`3oon0b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooPX`3=QCl3000000<0003o1000003o0?ooh300oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2U0<f5?`@0
00000P000?l400000?l0oooP;P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh:L0cHDo100000020000o`@00000o`3oon0/0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPZ@3=
QCl400000080003o1@00003o0?ooh2T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon2/0<f5?`<000000`000?l400000?l0oooP9`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h:h0cHDo100000020000o`@00000o`3oon0U0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<000002@3oon2`0<f5?`@000000P000?l400000?l0oooP8@3oon03000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP/P3=QCl400000080003o
1000003o0?ooh240oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon2d0<f5?`@000000P000?l400000?l0oooP7`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh;H0cHDo10000002
0000o`@00000o`3oon0M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP^03=QCl400000080003o1000003o0?ooh1/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2j0<f5?`@0
00000P000?l400000?l0oooP6@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh;`0cHDo100000020000o`<00000o`3oon0H0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP_P3=
QCl400000080003o1000003o0?ooh1D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon300<f5?`@000000P000?l300000?l0oooP503oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h<80cHDo100000020000o`<00000o`3oon0B0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPa03=QCl400000080003o0`00003o0?ooh100
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon360<f5?`@0000000<0003o0000000000000P00003o0?ooh0h0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon380<f5?`<000000P00
0?l400000?l0oooP303oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh<X0cHDo0`0000020000o`@00000o`3oon0:0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon3;0<f5?`@0000000<0003o0000
000000000P00003o0?ooh0L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh<d0cHDo0`0000020000o`@00000o`3oon070?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPc`3=QCl300000080003o
1000003o0?ooh0D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon3A0<f5?`<000000P000?l400000?l0oooP0`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=<0cHDo0`000000
0`000?l000000000000200000?l0oooP0P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=D0cHDo0P0000020000o`@00000o`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=H0
cHDo0`0000020000o`@00000o@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh=P0cHDo0`0000020000o`@00000n`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=X0cHDo0`00
00000`000?l000000000000200000?X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon3L0<f5?`8000000P000?l400000?P0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon3M0<f5
?`<000000P000?l400000?H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon3O0<f5?`<0000000<0003o0000000000000P00003e0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP
0?ooh0090?ooh>00cHDo0`0000020000o`<00000m03oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP
hP3=QCl300000080003o0`00003b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>H@0?ooh0040000003oon00oooP000000L0oooP100000080?ooh>L000000P000?oX000000P0oooP
1000000H0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000
003oon00oooP0>h0oooP1000000010000?l0000000000000003T03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000
oooP0?ooh03`0?ooh0<000000P000?l300000>80<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00lP3oon03000000030000
o`000000000000800000h00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?<0oooP0`0000020000o`<00000g`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?D0oooP0`000000
0`000?l000000000000200000=d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03g0?ooh08000000P000?l300000=`0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03h0?ooh0<0
000000<0003o0000000000000P00003J03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00nP3oon02000000030000o`000000000000800000
f@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?/0oooP0P0000020000o`@00000e`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?d0oooP0P0000000`000?l0000000000002
00000=H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03n0?ooh08000000P000?l300000=D0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh040oooP0P0000000`000?l0
00000000000300000=80<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh080oooP0P0000020000o`@00000d@0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP103o
on02000000030000o`000000000000800000d00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon050?ooh08000000P000?l400000<h0<j7:2@3oon03
000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP1`3oon020000
00030000o`000000000000800000c@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP203oon0200000080003o1000003;03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0:0?ooh080000000<0003o0000000000000P00003:03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0;0?ooh08000000P00
0?l300000<T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh0`0oooP0`0000000`000?l000000000000200000<L0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h0h0oooP0P0000020000o`@00000a@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3`3oon03000000030000o`00000000000080
0000a00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP4@3oon0200000080003o0`00003303>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0B0?ooh0<0000000<0
003o0000000000000P00003103>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0D0?ooh08000000P000?l300000<00<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h1D0oooP0`00000010000?l0000000000000002o03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0G0?ooh08000000P000?l30000
0;d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh1P0oooP0`00000010000?l0000000000000002l03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh1T0oooP0`0000020000o`80
0000^`0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0K0?ooh0<0000000@0003o0000000000000000^@0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP703oon03000000040000
o`000000000000000;P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh1h0oooP0P0000020000o`<00000]P0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7`3o
on03000000040000o`000000000000000;D0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh200oooP0`00000010000?l000000000
0000002d03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0Q0?ooh0<000000P000?l200000;<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2<0oooP0`000000
10000?l0000000000000002a03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0T0?ooh0<0000000@0003o0000000000000000/00c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP9@3oon0300000080003o0`00002^03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0W0?ooh0<0000000@0003o0000
000000000000[@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP:03oon03000000040000o`000000000000000:`0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h2T0oooP0`0000020000o`800000Z`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:`3oon03000000040000o`00000000000000
0:T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0
oooP;03oon03000000040000o`000000000000000:P0<j7:2@3oon03000001P0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;@3oon0300000080003o0P00002W03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0_0?ooh0<0000000<0003o000000000000YP0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<03oon03000000040000o`00
0000000000000:@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh340oooP0`00000010000?l0000000000000002S03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0c0?ooh08000000P000?l200000:80<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3@0oooP0`0000000`000?l000000000002Q
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0e0?ooh0<0000000@0003o0000000000000000W`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP=P3oon030000
0080003o0P00002N03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0g0?ooh0@0000000<0003o000000000000W@0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
>@3oon03000000030000o`000000000009`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3X0oooP0`0000000`000?l000000000
002K03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0k0?ooh0<000000P000?l2000009T0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3`0oooP100000000`00
0?l000000000002H03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0m0?ooh0@0000000<0003o000000000000U`0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0o0?ooh0<00000
00<0003o000000000000UP0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon100?ooh0<0000000<0003o000000000000U@0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@@3oon03
000000040000o`0000000000000009<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4<0oooP0P0000020000o`800000TP0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPA03oon03000000030000o`00000000000940<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4D0oooP0`0000000`000?l0
00000000002@03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon160?ooh0<0000000<0003o000000000000S`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPA`3o
on03000000040000o`0000000000000008d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4P0oooP0`00000010000?l000000000
0000002<03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1:0?ooh080000000@0003o0000000000000000R`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB`3o
on02000000040000o`0000000000000008X0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4`0oooP0P00000010000?l000000000
0000002903>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@00
00060?ooh0030000003oon00oooP0?l0oooPC@3oon0200000080003o0P00002803>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon00
0`000000oooP0?ooh03o0?ooh4h0oooP0`00000010000?l0000000000000002603>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon04
00000?l0oooPCP3oon03000000040000o`0000000000000008D0<j7:203oon04000001P0oooP7P3j
l>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1A
0?ooh080000000@0003o0000000000000000Q00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon1B
0?ooh080000000@0003o0000000000000000P`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh5<0oooP0P000000
10000?l0000000000000002203>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1D0?ooh080000000@0003o0000000000000000P@0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPE@3oon02000000040000o`000000000000000800<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5H0oooP0P000000
10000?l0000000000000001o03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1G0?ooh08000000P000?l3000007d0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h5P0oooP0`00000010000?l0000000000000001l03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1J0?ooh080000000@0003o0000
000000000000N`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPF`3oon02000000040000o`0000000000000007X0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h5`0oooP0P00000010000?l0000000000000001i03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1M0?ooh080000000@0003o0000
000000000000N00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPGP3oon02000000040000o`0000000000000007L0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPG`3oon020000
00040000o`0000000000000007H0<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPH03oon02000000040000o`0000000000000007D0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h640oooP0P0000020000o`800000M00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPHP3oon03000000040000o`00000000000000
0780<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh6<0oooP0`00000010000?l0000000000000001a03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1U0?ooh080
000000@0003o0000000000000000L00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPIP3oon02000000040000o`00000000000000
06l0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh6L0oooP0P00000010000?l0000000000000001^03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1X0?ooh080
000000@0003o0000000000000000K@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ@3oon02000000040000o`00000000000000
06`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh6X0oooP0P00000010000?l0000000000000001[03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1[0?ooh080
000000@0003o0000000000000000JP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK03oon02000000040000o`00000000000000
06T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh6d0oooP0P00000010000?l0000000000000001X03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1^0?ooh080
000000@0003o0000000000000000I`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<00000o`3oon1_0?ooh08000000P000?l2000006H0<j7:2@3oon03000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL03oon03000000030000
o`000000000006D0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh740oooP0`0000000`000?l000000000001T03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1b
0?ooh0<0000000<0003o000000000000H`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL`3oon03000000030000o`0000000000
0680<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh7@0oooP0`0000000`000?l000000000001Q03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1f0?ooh0800000
00<0003o000000000000H00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPMP3oon03000000030000o`000000000005l0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7L0oooP0`0000000`000?l000000000001N03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1i0?ooh080000000<0003o0000
00000000G@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPN@3oon03000000030000o`000000000005`0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7X0oooP
0`0000000`000?l000000000001K03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1k0?ooh0<0000000<0003o000000000000FP0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPO@3oon02000000030000o`000000000005T0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPOP3oon02000000030000o`0000000000
05P0<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPO`3oon02000000030000o`000000000005L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh800oooP0P0000000`000?l00000
0000001F03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon200?ooh0<0000000<0003o000000000000E@0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP@3oon03
000000030000o`000000000005@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh880oooP0`0000000`000?l000000000001C03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon230?ooh0<0000000<0003o000000000000DP0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQ03oon03000000030000
o`00000000000540<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8D0oooP0`0000000`000?l000000000001@03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon26
0?ooh0<0000000<0003o000000000000C`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQ`3oon03000000030000o`0000000000
04h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh8P0oooP0`0000000`000?l000000000001=03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon290?ooh0<00000
00<0003o000000000000C00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPRP3oon03000000030000o`000000000004/0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPR`3oon03
000000030000o`000000000004X0<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPS03oon03000000030000o`000000000004T0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8d0
oooP0`0000000`000?l000000000001803>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2>0?ooh0<0000000<0003o000000000000
A`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPS`3oon03000000030000o`000000000004H0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh900oooP0P000000
10000?l0000000000000001503>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2A0?ooh080000000@0003o0000000000000000A00c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPTP3oon02000000040000o`0000000000000004<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9<0oooP0P000000
10000?l0000000000000001203>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2D0?ooh080000000@0003o0000000000000000@@0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPU@3oon02000000030000o`00000000000440<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9H0oooP0P0000000`00
0?l000000000001003>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2G0?ooh080000000@0003o0000000000000000?P0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0@000001`3oon000`000000
oooP0?ooh03o0?ooh9P0oooP0P00000010000?l0000000000000000m03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00<000000?ooh03oon00203oon000`000000
oooP0?ooh03o0?ooh9T0oooP0P0000000`000?l000000000000m03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP00<000000?ooh03oon001`3oon0400000?l0oooP
V@3oon000`000000003o00000002000003`0<j7:203oon04000001P0oooP7P3jl>H10?ooo`007@3j
l>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00o`3oon2K0?ooh00300000000
0?l0000000800000>`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@
0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon2L0?ooh00300000000
0?l0000000800000>P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA
0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh9`0oooP0P00000010000?l0000000000000
000i03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2M0?ooh080000000@0003o0000000000000000>00cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW`3oon00
0`000000003o00000002000003L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9l0oooP0P00000010000?l0000000000000000f
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2P0?ooh080000000@0003o0000000000000000=@0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX@3oon020000
00040000o`0000000000000003@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:80oooP0P00000010000?l0000000000000000c
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2S0?ooh080000000@0003o0000000000000000<P0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY03oon020000
00040000o`000000000000000340<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:D0oooP0P0000000`000?l000000000000a03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2V0?ooh080000000<0003o000000000000<00cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon2W0?ooh080000000<0003o000000000000
;`0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2X0?ooh080000000<0003o000000000000;P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ03oon02000000040000o`000000
0000000002d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:T0oooP0P00000010000?l0000000000000000/03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Z
0?ooh080000000@0003o0000000000000000:`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ`3oon02000000040000o`000000
0000000002X0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:`0oooP0P00000010000?l0000000000000000Y03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2]
0?ooh080000000<0003o000000000000:@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[P3oon02000000030000o`0000000000
02P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh:l0oooP0P0000000`000?l000000000000W03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2`0?ooh0800000
00<0003o0000000000009P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP/03oon03000000030000o`000000000002D0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh;40oooP0`0000000`000?l000000000000T03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2b0?ooh0<0000000<0003o0000
000000008`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon2c0?ooh0<0000000<0003o0000000000008P0cXLX90?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2d0?ooh0<0000000<0003o000000000000
8@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP]@3oon02000000030000o`00000000000240<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;H0oooP0P000000
0`000?l000000000000P03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh080000000<0003o0000000000007`0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP]`3oon03000000030000o`000000000001h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;P0oooP0`0000000`000?l00000
0000000M03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2i0?ooh0<0000000<0003o000000000000700cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^P3oon02
000000040000o`0000000000000001/0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;/0oooP0P0000000`000?l000000000000K
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2l0?ooh080000000<0003o0000000000006P0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_@3oon0200000003
0000o`000000000001T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh;h0oooP0P0000000`000?l000000000000H03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on2n0?ooh0<0000000<0003o0000000000005`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_`3oon02000000040000o`000000
0000000001H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03
00000?l0oooP`03oon02000000030000o`000000000001H0<j7:2@3oon03000001P0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`@3oon02000000030000o`0000000000
01D0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh<80oooP0P0000000`000?l000000000000D03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon330?ooh0800000
00<0003o0000000000004`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPa03oon02000000030000o`00000000000180<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<D0oooP00<000000000o`0000000P00000A03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon350?ooh080000000@0003o0000
000000000000400cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPaP3oon02000000030000o`00000000000100<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<L0
oooP0P0000000`000?l000000000000?03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon380?ooh080000000<0003o000000000000
3P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPb@3oon02000000030000o`000000000000d0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<T0oooP0P000000
10000?l0000000000000000<03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3:0?ooh080000000@0003o00000000000000002`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPb`3oon02000000030000o`000000000000/0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooPc03oon02000000030000o`0000000000
00X0<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPc@3oon02000000030000o`000000000000T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<h0oooP0P0000000`000?l00000
0000000803>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon3?0?ooh080000000<0003o0000000000001`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPc`3oon02
000000030000o`000000000000L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=00oooP0P0000000`000?l000000000000603>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon3A0?ooh080000000<0003o0000000000001@0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPdP3oon02000000030000
o`000000000000@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh=<0oooP0P0000000`000?l000000000000303>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3C
0?ooh0<0000000<0003o0000000000000P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPe03oon03000000040000o`000000<j7:
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon3E0?ooh080000000@0003o000000000000<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon00o`3oon3F0?oo
h080000000<0003o0000000000002`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPe`3oon020000
00030000o`000000000000X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80
oooP00<000000?ooh03oon001P3oon0400000?l0oooPeP3oon03000000030000o`000000oooP00H0
oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4`3oon000`000000oooP0?ooh0050?ooh0030000
003oon00oooP0?l0oooPf03oon04000000X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh=T0oooP
0P00000;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203o
on000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`00
0000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh003
0000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh003
0000003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP
00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP
00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on3o00000>X00000603oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00=`0n_3V100000020?[`iPP000000P3jl>H4000000070?[`iP00000000000000003jl>H0
00000?[`iP0<000000030?[`iP000000000000@0000000@0n_3V0000000000000000203jl>H50000
00@0n_3V1`0000000`3jl>H000000?[`iP03000000T0n_3V1@0000020?[`iP@000000P3jl>H50000
0180n_3V1P0000060?[`iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H0000000000000003T
0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000`3jl>H01`00
0000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V0?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`iP3j
l>H01@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000000`3jl>H00000
000000040?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V
0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000d0n_3V
0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000<0?[`iPD000001@3jl>H2000000H0
n_3V1@0000060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H5000000@0n_3V0P0000030?[`iPH00000
00H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP8000005P3jl>H2000000P0n_3V00<000000?[`iP3jl>H01P3jl>H3
00000>H0n_3V0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`
iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0
n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP800000
0P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP0B0?[`iP800000203jl>H00`000000n_3V
0?[`iP050?[`iP80000000<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H200000080n_3V0P00
00000`3jl>H0000000000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V1000
00020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00
000;0?[`iPD000000P3jl>H400000080n_3V0`0000000`3jl>H000000000000C0?[`iP8000003`3j
l>H3000000050?[`iP00000000000000003jl>H01000003O0?[`iP40oooo003M0?[`iP8000000P3j
l>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V01P0n_3V0P00000Q0?[`iP@00000603j
l>H00`000000n_3V0?[`iP3O0?[`iP40oooo003L0?[`iPH00000103jl>H2000002l0n_3V1@00000K
0?[`iP<000008@3jl>H2000001T0n_3V00<000000?[`iP3jl>H0gP3jl>H10?ooo`00o`3jl>Ih0?[`
iP030000003jl>H0n_3V0=d0n_3V0@3oool00?l0n_3VM@3jl>H010000000n_3V0?[`iP00003O0?[`
iP40oooo003o0?[`iWH0n_3V0P00003P0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02434 .01472 L
.02434 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02434 .01472 L
.02434 .16187 L
s
1 .894 .882 r
.02434 .16187 m
.02434 .01472 L
.02466 .01472 L
.02466 .16187 L
F
.804 .522 .247 r
.02434 .16187 m
.02434 .01472 L
.02466 .01472 L
.02466 .16187 L
s
1 .894 .882 r
.02466 .16187 m
.02466 .01472 L
.02539 .01472 L
.02539 .16187 L
F
.804 .522 .247 r
.02466 .16187 m
.02466 .01472 L
.02539 .01472 L
.02539 .16187 L
s
1 .894 .882 r
.02539 .16187 m
.02539 .01472 L
.02574 .01472 L
.02574 .16187 L
F
.804 .522 .247 r
.02539 .16187 m
.02539 .01472 L
.02574 .01472 L
.02574 .16187 L
s
1 .894 .882 r
.02574 .16187 m
.02574 .01472 L
.02627 .01472 L
.02627 .16187 L
F
.804 .522 .247 r
.02574 .16187 m
.02574 .01472 L
.02627 .01472 L
.02627 .16187 L
s
1 .894 .882 r
.02627 .16187 m
.02627 .01472 L
.02668 .01472 L
.02668 .16187 L
F
.804 .522 .247 r
.02627 .16187 m
.02627 .01472 L
.02668 .01472 L
.02668 .16187 L
s
1 .894 .882 r
.02668 .16187 m
.02668 .01472 L
.02704 .01472 L
.02704 .16187 L
F
.804 .522 .247 r
.02668 .16187 m
.02668 .01472 L
.02704 .01472 L
.02704 .16187 L
s
1 .894 .882 r
.02704 .16187 m
.02704 .01472 L
.02773 .01472 L
.02773 .16187 L
F
.804 .522 .247 r
.02704 .16187 m
.02704 .01472 L
.02773 .01472 L
.02773 .16187 L
s
1 .894 .882 r
.02773 .16187 m
.02773 .01473 L
.02849 .01473 L
.02849 .16187 L
F
.804 .522 .247 r
.02773 .16187 m
.02773 .01473 L
.02849 .01473 L
.02849 .16187 L
s
1 .894 .882 r
.02849 .16187 m
.02849 .01473 L
.02878 .01473 L
.02878 .16187 L
F
.804 .522 .247 r
.02849 .16187 m
.02849 .01473 L
.02878 .01473 L
.02878 .16187 L
s
1 .894 .882 r
.02878 .16187 m
.02878 .01473 L
.02938 .01473 L
.02938 .16187 L
F
.804 .522 .247 r
.02878 .16187 m
.02878 .01473 L
.02938 .01473 L
.02938 .16187 L
s
1 .894 .882 r
.02938 .16187 m
.02938 .01474 L
.02963 .01474 L
.02963 .16187 L
F
.804 .522 .247 r
.02938 .16187 m
.02938 .01474 L
.02963 .01474 L
.02963 .16187 L
s
1 .894 .882 r
.02963 .16187 m
.02963 .01474 L
.03014 .01474 L
.03014 .16187 L
F
.804 .522 .247 r
.02963 .16187 m
.02963 .01474 L
.03014 .01474 L
.03014 .16187 L
s
1 .894 .882 r
.03014 .16187 m
.03014 .01474 L
.03087 .01474 L
.03087 .16187 L
F
.804 .522 .247 r
.03014 .16187 m
.03014 .01474 L
.03087 .01474 L
.03087 .16187 L
s
1 .894 .882 r
.03087 .16187 m
.03087 .01475 L
.03139 .01475 L
.03139 .16187 L
F
.804 .522 .247 r
.03087 .16187 m
.03087 .01475 L
.03139 .01475 L
.03139 .16187 L
s
1 .894 .882 r
.03139 .16187 m
.03139 .01475 L
.03172 .01475 L
.03172 .16187 L
F
.804 .522 .247 r
.03139 .16187 m
.03139 .01475 L
.03172 .01475 L
.03172 .16187 L
s
1 .894 .882 r
.03172 .16187 m
.03172 .01476 L
.03244 .01476 L
.03244 .16187 L
F
.804 .522 .247 r
.03172 .16187 m
.03172 .01476 L
.03244 .01476 L
.03244 .16187 L
s
1 .894 .882 r
.03244 .16187 m
.03244 .01477 L
.03318 .01477 L
.03318 .16187 L
F
.804 .522 .247 r
.03244 .16187 m
.03244 .01477 L
.03318 .01477 L
.03318 .16187 L
s
1 .894 .882 r
.03318 .16187 m
.03318 .01477 L
.03357 .01477 L
.03357 .16187 L
F
.804 .522 .247 r
.03318 .16187 m
.03318 .01477 L
.03357 .01477 L
.03357 .16187 L
s
1 .894 .882 r
.03357 .16187 m
.03357 .01478 L
.03432 .01478 L
.03432 .16187 L
F
.804 .522 .247 r
.03357 .16187 m
.03357 .01478 L
.03432 .01478 L
.03432 .16187 L
s
1 .894 .882 r
.03432 .16187 m
.03432 .01479 L
.03504 .01479 L
.03504 .16187 L
F
.804 .522 .247 r
.03432 .16187 m
.03432 .01479 L
.03504 .01479 L
.03504 .16187 L
s
1 .894 .882 r
.03504 .16187 m
.03504 .0148 L
.03533 .0148 L
.03533 .16187 L
F
.804 .522 .247 r
.03504 .16187 m
.03504 .0148 L
.03533 .0148 L
.03533 .16187 L
s
1 .894 .882 r
.03533 .16187 m
.03533 .01481 L
.03594 .01481 L
.03594 .16187 L
F
.804 .522 .247 r
.03533 .16187 m
.03533 .01481 L
.03594 .01481 L
.03594 .16187 L
s
1 .894 .882 r
.03594 .16187 m
.03594 .01481 L
.03653 .01481 L
.03653 .16187 L
F
.804 .522 .247 r
.03594 .16187 m
.03594 .01481 L
.03653 .01481 L
.03653 .16187 L
s
1 .894 .882 r
.03653 .16187 m
.03653 .01483 L
.03695 .01483 L
.03695 .16187 L
F
.804 .522 .247 r
.03653 .16187 m
.03653 .01483 L
.03695 .01483 L
.03695 .16187 L
s
1 .894 .882 r
.03695 .16187 m
.03695 .01483 L
.03773 .01483 L
.03773 .16187 L
F
.804 .522 .247 r
.03695 .16187 m
.03695 .01483 L
.03773 .01483 L
.03773 .16187 L
s
1 .894 .882 r
.03773 .16187 m
.03773 .01485 L
.03841 .01485 L
.03841 .16187 L
F
.804 .522 .247 r
.03773 .16187 m
.03773 .01485 L
.03841 .01485 L
.03841 .16187 L
s
1 .894 .882 r
.03841 .16187 m
.03841 .01486 L
.0389 .01486 L
.0389 .16187 L
F
.804 .522 .247 r
.03841 .16187 m
.03841 .01486 L
.0389 .01486 L
.0389 .16187 L
s
1 .894 .882 r
.0389 .16187 m
.0389 .01488 L
.0396 .01488 L
.0396 .16187 L
F
.804 .522 .247 r
.0389 .16187 m
.0389 .01488 L
.0396 .01488 L
.0396 .16187 L
s
1 .894 .882 r
.0396 .16187 m
.0396 .01488 L
.04021 .01488 L
.04021 .16187 L
F
.804 .522 .247 r
.0396 .16187 m
.0396 .01488 L
.04021 .01488 L
.04021 .16187 L
s
1 .894 .882 r
.04021 .16187 m
.04021 .0149 L
.04078 .0149 L
.04078 .16187 L
F
.804 .522 .247 r
.04021 .16187 m
.04021 .0149 L
.04078 .0149 L
.04078 .16187 L
s
1 .894 .882 r
.04078 .16187 m
.04078 .0149 L
.04138 .0149 L
.04138 .16187 L
F
.804 .522 .247 r
.04078 .16187 m
.04078 .0149 L
.04138 .0149 L
.04138 .16187 L
s
1 .894 .882 r
.04138 .16187 m
.04138 .01493 L
.04212 .01493 L
.04212 .16187 L
F
.804 .522 .247 r
.04138 .16187 m
.04138 .01493 L
.04212 .01493 L
.04212 .16187 L
s
1 .894 .882 r
.04212 .16187 m
.04212 .01494 L
.04269 .01494 L
.04269 .16187 L
F
.804 .522 .247 r
.04212 .16187 m
.04212 .01494 L
.04269 .01494 L
.04269 .16187 L
s
1 .894 .882 r
.04269 .16187 m
.04269 .01495 L
.04346 .01495 L
.04346 .16187 L
F
.804 .522 .247 r
.04269 .16187 m
.04269 .01495 L
.04346 .01495 L
.04346 .16187 L
s
1 .894 .882 r
.04346 .16187 m
.04346 .01497 L
.04406 .01497 L
.04406 .16187 L
F
.804 .522 .247 r
.04346 .16187 m
.04346 .01497 L
.04406 .01497 L
.04406 .16187 L
s
1 .894 .882 r
.04406 .16187 m
.04406 .01499 L
.04454 .01499 L
.04454 .16187 L
F
.804 .522 .247 r
.04406 .16187 m
.04406 .01499 L
.04454 .01499 L
.04454 .16187 L
s
1 .894 .882 r
.04454 .16187 m
.04454 .01501 L
.04518 .01501 L
.04518 .16187 L
F
.804 .522 .247 r
.04454 .16187 m
.04454 .01501 L
.04518 .01501 L
.04518 .16187 L
s
1 .894 .882 r
.04518 .16187 m
.04518 .01502 L
.04567 .01502 L
.04567 .16187 L
F
.804 .522 .247 r
.04518 .16187 m
.04518 .01502 L
.04567 .01502 L
.04567 .16187 L
s
1 .894 .882 r
.04567 .16187 m
.04567 .01503 L
.04619 .01503 L
.04619 .16187 L
F
.804 .522 .247 r
.04567 .16187 m
.04567 .01503 L
.04619 .01503 L
.04619 .16187 L
s
1 .894 .882 r
.04619 .16187 m
.04619 .01505 L
.04675 .01505 L
.04675 .16187 L
F
.804 .522 .247 r
.04619 .16187 m
.04619 .01505 L
.04675 .01505 L
.04675 .16187 L
s
1 .894 .882 r
.04675 .16187 m
.04675 .01506 L
.04745 .01506 L
.04745 .16187 L
F
.804 .522 .247 r
.04675 .16187 m
.04675 .01506 L
.04745 .01506 L
.04745 .16187 L
s
1 .894 .882 r
.04745 .16187 m
.04745 .01508 L
.04779 .01508 L
.04779 .16187 L
F
.804 .522 .247 r
.04745 .16187 m
.04745 .01508 L
.04779 .01508 L
.04779 .16187 L
s
1 .894 .882 r
.04779 .16187 m
.04779 .0151 L
.04837 .0151 L
.04837 .16187 L
F
.804 .522 .247 r
.04779 .16187 m
.04779 .0151 L
.04837 .0151 L
.04837 .16187 L
s
1 .894 .882 r
.04837 .16187 m
.04837 .01512 L
.04902 .01512 L
.04902 .16187 L
F
.804 .522 .247 r
.04837 .16187 m
.04837 .01512 L
.04902 .01512 L
.04902 .16187 L
s
1 .894 .882 r
.04902 .16187 m
.04902 .01513 L
.04968 .01513 L
.04968 .16187 L
F
.804 .522 .247 r
.04902 .16187 m
.04902 .01513 L
.04968 .01513 L
.04968 .16187 L
s
1 .894 .882 r
.04968 .16187 m
.04968 .01516 L
.05022 .01516 L
.05022 .16187 L
F
.804 .522 .247 r
.04968 .16187 m
.04968 .01516 L
.05022 .01516 L
.05022 .16187 L
s
1 .894 .882 r
.05022 .16187 m
.05022 .01519 L
.05101 .01519 L
.05101 .16187 L
F
.804 .522 .247 r
.05022 .16187 m
.05022 .01519 L
.05101 .01519 L
.05101 .16187 L
s
1 .894 .882 r
.05101 .16187 m
.05101 .01521 L
.05148 .01521 L
.05148 .16187 L
F
.804 .522 .247 r
.05101 .16187 m
.05101 .01521 L
.05148 .01521 L
.05148 .16187 L
s
1 .894 .882 r
.05148 .16187 m
.05148 .01524 L
.05216 .01524 L
.05216 .16187 L
F
.804 .522 .247 r
.05148 .16187 m
.05148 .01524 L
.05216 .01524 L
.05216 .16187 L
s
1 .894 .882 r
.05216 .16187 m
.05216 .01526 L
.05283 .01526 L
.05283 .16187 L
F
.804 .522 .247 r
.05216 .16187 m
.05216 .01526 L
.05283 .01526 L
.05283 .16187 L
s
1 .894 .882 r
.05283 .16187 m
.05283 .01527 L
.05338 .01527 L
.05338 .16187 L
F
.804 .522 .247 r
.05283 .16187 m
.05283 .01527 L
.05338 .01527 L
.05338 .16187 L
s
1 .894 .882 r
.05338 .16187 m
.05338 .0153 L
.05396 .0153 L
.05396 .16187 L
F
.804 .522 .247 r
.05338 .16187 m
.05338 .0153 L
.05396 .0153 L
.05396 .16187 L
s
1 .894 .882 r
.05396 .16187 m
.05396 .01532 L
.05428 .01532 L
.05428 .16187 L
F
.804 .522 .247 r
.05396 .16187 m
.05396 .01532 L
.05428 .01532 L
.05428 .16187 L
s
1 .894 .882 r
.05428 .16187 m
.05428 .01532 L
.05462 .01532 L
.05462 .16187 L
F
.804 .522 .247 r
.05428 .16187 m
.05428 .01532 L
.05462 .01532 L
.05462 .16187 L
s
1 .894 .882 r
.05462 .16187 m
.05462 .01534 L
.05537 .01534 L
.05537 .16187 L
F
.804 .522 .247 r
.05462 .16187 m
.05462 .01534 L
.05537 .01534 L
.05537 .16187 L
s
1 .894 .882 r
.05537 .16187 m
.05537 .01537 L
.05601 .01537 L
.05601 .16187 L
F
.804 .522 .247 r
.05537 .16187 m
.05537 .01537 L
.05601 .01537 L
.05601 .16187 L
s
1 .894 .882 r
.05601 .16187 m
.05601 .0154 L
.05657 .0154 L
.05657 .16187 L
F
.804 .522 .247 r
.05601 .16187 m
.05601 .0154 L
.05657 .0154 L
.05657 .16187 L
s
1 .894 .882 r
.05657 .16187 m
.05657 .01543 L
.05695 .01543 L
.05695 .16187 L
F
.804 .522 .247 r
.05657 .16187 m
.05657 .01543 L
.05695 .01543 L
.05695 .16187 L
s
1 .894 .882 r
.05695 .16187 m
.05695 .01543 L
.05734 .01543 L
.05734 .16187 L
F
.804 .522 .247 r
.05695 .16187 m
.05695 .01543 L
.05734 .01543 L
.05734 .16187 L
s
1 .894 .882 r
.05734 .16187 m
.05734 .01546 L
.05775 .01546 L
.05775 .16187 L
F
.804 .522 .247 r
.05734 .16187 m
.05734 .01546 L
.05775 .01546 L
.05775 .16187 L
s
1 .894 .882 r
.05775 .16187 m
.05775 .01548 L
.05847 .01548 L
.05847 .16187 L
F
.804 .522 .247 r
.05775 .16187 m
.05775 .01548 L
.05847 .01548 L
.05847 .16187 L
s
1 .894 .882 r
.05847 .16187 m
.05847 .0155 L
.05917 .0155 L
.05917 .16187 L
F
.804 .522 .247 r
.05847 .16187 m
.05847 .0155 L
.05917 .0155 L
.05917 .16187 L
s
1 .894 .882 r
.05917 .16187 m
.05917 .01555 L
.05985 .01555 L
.05985 .16187 L
F
.804 .522 .247 r
.05917 .16187 m
.05917 .01555 L
.05985 .01555 L
.05985 .16187 L
s
1 .894 .882 r
.05985 .16187 m
.05985 .01556 L
.06051 .01556 L
.06051 .16187 L
F
.804 .522 .247 r
.05985 .16187 m
.05985 .01556 L
.06051 .01556 L
.06051 .16187 L
s
1 .894 .882 r
.06051 .16187 m
.06051 .01559 L
.06077 .01559 L
.06077 .16187 L
F
.804 .522 .247 r
.06051 .16187 m
.06051 .01559 L
.06077 .01559 L
.06077 .16187 L
s
1 .894 .882 r
.06077 .16187 m
.06077 .01563 L
.06136 .01563 L
.06136 .16187 L
F
.804 .522 .247 r
.06077 .16187 m
.06077 .01563 L
.06136 .01563 L
.06136 .16187 L
s
1 .894 .882 r
.06136 .16187 m
.06136 .01564 L
.06172 .01564 L
.06172 .16187 L
F
.804 .522 .247 r
.06136 .16187 m
.06136 .01564 L
.06172 .01564 L
.06172 .16187 L
s
1 .894 .882 r
.06172 .16187 m
.06172 .01566 L
.06252 .01566 L
.06252 .16187 L
F
.804 .522 .247 r
.06172 .16187 m
.06172 .01566 L
.06252 .01566 L
.06252 .16187 L
s
1 .894 .882 r
.06252 .16187 m
.06252 .01569 L
.06293 .01569 L
.06293 .16187 L
F
.804 .522 .247 r
.06252 .16187 m
.06252 .01569 L
.06293 .01569 L
.06293 .16187 L
s
1 .894 .882 r
.06293 .16187 m
.06293 .01571 L
.06323 .01571 L
.06323 .16187 L
F
.804 .522 .247 r
.06293 .16187 m
.06293 .01571 L
.06323 .01571 L
.06323 .16187 L
s
1 .894 .882 r
.06323 .16187 m
.06323 .01573 L
.0636 .01573 L
.0636 .16187 L
F
.804 .522 .247 r
.06323 .16187 m
.06323 .01573 L
.0636 .01573 L
.0636 .16187 L
s
1 .894 .882 r
.0636 .16187 m
.0636 .01576 L
.06417 .01576 L
.06417 .16187 L
F
.804 .522 .247 r
.0636 .16187 m
.0636 .01576 L
.06417 .01576 L
.06417 .16187 L
s
1 .894 .882 r
.06417 .16187 m
.06417 .01577 L
.06471 .01577 L
.06471 .16187 L
F
.804 .522 .247 r
.06417 .16187 m
.06417 .01577 L
.06471 .01577 L
.06471 .16187 L
s
1 .894 .882 r
.06471 .16187 m
.06471 .01581 L
.06514 .01581 L
.06514 .16187 L
F
.804 .522 .247 r
.06471 .16187 m
.06471 .01581 L
.06514 .01581 L
.06514 .16187 L
s
1 .894 .882 r
.06514 .16187 m
.06514 .01585 L
.06577 .01585 L
.06577 .16187 L
F
.804 .522 .247 r
.06514 .16187 m
.06514 .01585 L
.06577 .01585 L
.06577 .16187 L
s
1 .894 .882 r
.06577 .16187 m
.06577 .01589 L
.06658 .01589 L
.06658 .16187 L
F
.804 .522 .247 r
.06577 .16187 m
.06577 .01589 L
.06658 .01589 L
.06658 .16187 L
s
1 .894 .882 r
.06658 .16187 m
.06658 .0159 L
.06704 .0159 L
.06704 .16187 L
F
.804 .522 .247 r
.06658 .16187 m
.06658 .0159 L
.06704 .0159 L
.06704 .16187 L
s
1 .894 .882 r
.06704 .16187 m
.06704 .01594 L
.06737 .01594 L
.06737 .16187 L
F
.804 .522 .247 r
.06704 .16187 m
.06704 .01594 L
.06737 .01594 L
.06737 .16187 L
s
1 .894 .882 r
.06737 .16187 m
.06737 .01596 L
.06805 .01596 L
.06805 .16187 L
F
.804 .522 .247 r
.06737 .16187 m
.06737 .01596 L
.06805 .01596 L
.06805 .16187 L
s
1 .894 .882 r
.06805 .16187 m
.06805 .016 L
.06846 .016 L
.06846 .16187 L
F
.804 .522 .247 r
.06805 .16187 m
.06805 .016 L
.06846 .016 L
.06846 .16187 L
s
1 .894 .882 r
.06846 .16187 m
.06846 .01604 L
.06918 .01604 L
.06918 .16187 L
F
.804 .522 .247 r
.06846 .16187 m
.06846 .01604 L
.06918 .01604 L
.06918 .16187 L
s
1 .894 .882 r
.06918 .16187 m
.06918 .01608 L
.06994 .01608 L
.06994 .16187 L
F
.804 .522 .247 r
.06918 .16187 m
.06918 .01608 L
.06994 .01608 L
.06994 .16187 L
s
1 .894 .882 r
.06994 .16187 m
.06994 .0161 L
.07046 .0161 L
.07046 .16187 L
F
.804 .522 .247 r
.06994 .16187 m
.06994 .0161 L
.07046 .0161 L
.07046 .16187 L
s
1 .894 .882 r
.07046 .16187 m
.07046 .01614 L
.07071 .01614 L
.07071 .16187 L
F
.804 .522 .247 r
.07046 .16187 m
.07046 .01614 L
.07071 .01614 L
.07071 .16187 L
s
1 .894 .882 r
.07071 .16187 m
.07071 .01615 L
.07151 .01615 L
.07151 .16187 L
F
.804 .522 .247 r
.07071 .16187 m
.07071 .01615 L
.07151 .01615 L
.07151 .16187 L
s
1 .894 .882 r
.07151 .16187 m
.07151 .0162 L
.07181 .0162 L
.07181 .16187 L
F
.804 .522 .247 r
.07151 .16187 m
.07151 .0162 L
.07181 .0162 L
.07181 .16187 L
s
1 .894 .882 r
.07181 .16187 m
.07181 .01624 L
.07246 .01624 L
.07246 .16187 L
F
.804 .522 .247 r
.07181 .16187 m
.07181 .01624 L
.07246 .01624 L
.07246 .16187 L
s
1 .894 .882 r
.07246 .16187 m
.07246 .01627 L
.07286 .01627 L
.07286 .16187 L
F
.804 .522 .247 r
.07246 .16187 m
.07246 .01627 L
.07286 .01627 L
.07286 .16187 L
s
1 .894 .882 r
.07286 .16187 m
.07286 .01632 L
.07365 .01632 L
.07365 .16187 L
F
.804 .522 .247 r
.07286 .16187 m
.07286 .01632 L
.07365 .01632 L
.07365 .16187 L
s
1 .894 .882 r
.07365 .16187 m
.07365 .01634 L
.07416 .01634 L
.07416 .16187 L
F
.804 .522 .247 r
.07365 .16187 m
.07365 .01634 L
.07416 .01634 L
.07416 .16187 L
s
1 .894 .882 r
.07416 .16187 m
.07416 .01639 L
.0747 .01639 L
.0747 .16187 L
F
.804 .522 .247 r
.07416 .16187 m
.07416 .01639 L
.0747 .01639 L
.0747 .16187 L
s
1 .894 .882 r
.0747 .16187 m
.0747 .01641 L
.0751 .01641 L
.0751 .16187 L
F
.804 .522 .247 r
.0747 .16187 m
.0747 .01641 L
.0751 .01641 L
.0751 .16187 L
s
1 .894 .882 r
.0751 .16187 m
.0751 .01646 L
.07571 .01646 L
.07571 .16187 L
F
.804 .522 .247 r
.0751 .16187 m
.0751 .01646 L
.07571 .01646 L
.07571 .16187 L
s
1 .894 .882 r
.07571 .16187 m
.07571 .01647 L
.07617 .01647 L
.07617 .16187 L
F
.804 .522 .247 r
.07571 .16187 m
.07571 .01647 L
.07617 .01647 L
.07617 .16187 L
s
1 .894 .882 r
.07617 .16187 m
.07617 .01651 L
.07659 .01651 L
.07659 .16187 L
F
.804 .522 .247 r
.07617 .16187 m
.07617 .01651 L
.07659 .01651 L
.07659 .16187 L
s
1 .894 .882 r
.07659 .16187 m
.07659 .01656 L
.07722 .01656 L
.07722 .16187 L
F
.804 .522 .247 r
.07659 .16187 m
.07659 .01656 L
.07722 .01656 L
.07722 .16187 L
s
1 .894 .882 r
.07722 .16187 m
.07722 .01658 L
.07754 .01658 L
.07754 .16187 L
F
.804 .522 .247 r
.07722 .16187 m
.07722 .01658 L
.07754 .01658 L
.07754 .16187 L
s
1 .894 .882 r
.07754 .16187 m
.07754 .0166 L
.07781 .0166 L
.07781 .16187 L
F
.804 .522 .247 r
.07754 .16187 m
.07754 .0166 L
.07781 .0166 L
.07781 .16187 L
s
1 .894 .882 r
.07781 .16187 m
.07781 .01665 L
.0784 .01665 L
.0784 .16187 L
F
.804 .522 .247 r
.07781 .16187 m
.07781 .01665 L
.0784 .01665 L
.0784 .16187 L
s
1 .894 .882 r
.0784 .16187 m
.0784 .01669 L
.07903 .01669 L
.07903 .16187 L
F
.804 .522 .247 r
.0784 .16187 m
.0784 .01669 L
.07903 .01669 L
.07903 .16187 L
s
1 .894 .882 r
.07903 .16187 m
.07903 .01672 L
.0797 .01672 L
.0797 .16187 L
F
.804 .522 .247 r
.07903 .16187 m
.07903 .01672 L
.0797 .01672 L
.0797 .16187 L
s
1 .894 .882 r
.0797 .16187 m
.0797 .01675 L
.08044 .01675 L
.08044 .16187 L
F
.804 .522 .247 r
.0797 .16187 m
.0797 .01675 L
.08044 .01675 L
.08044 .16187 L
s
1 .894 .882 r
.08044 .16187 m
.08044 .01683 L
.08116 .01683 L
.08116 .16187 L
F
.804 .522 .247 r
.08044 .16187 m
.08044 .01683 L
.08116 .01683 L
.08116 .16187 L
s
1 .894 .882 r
.08116 .16187 m
.08116 .01686 L
.08163 .01686 L
.08163 .16187 L
F
.804 .522 .247 r
.08116 .16187 m
.08116 .01686 L
.08163 .01686 L
.08163 .16187 L
s
1 .894 .882 r
.08163 .16187 m
.08163 .01694 L
.08238 .01694 L
.08238 .16187 L
F
.804 .522 .247 r
.08163 .16187 m
.08163 .01694 L
.08238 .01694 L
.08238 .16187 L
s
1 .894 .882 r
.08238 .16187 m
.08238 .01698 L
.08317 .01698 L
.08317 .16187 L
F
.804 .522 .247 r
.08238 .16187 m
.08238 .01698 L
.08317 .01698 L
.08317 .16187 L
s
1 .894 .882 r
.08317 .16187 m
.08317 .01701 L
.08361 .01701 L
.08361 .16187 L
F
.804 .522 .247 r
.08317 .16187 m
.08317 .01701 L
.08361 .01701 L
.08361 .16187 L
s
1 .894 .882 r
.08361 .16187 m
.08361 .01705 L
.08407 .01705 L
.08407 .16187 L
F
.804 .522 .247 r
.08361 .16187 m
.08361 .01705 L
.08407 .01705 L
.08407 .16187 L
s
1 .894 .882 r
.08407 .16187 m
.08407 .01713 L
.08483 .01713 L
.08483 .16187 L
F
.804 .522 .247 r
.08407 .16187 m
.08407 .01713 L
.08483 .01713 L
.08483 .16187 L
s
1 .894 .882 r
.08483 .16187 m
.08483 .01714 L
.08557 .01714 L
.08557 .16187 L
F
.804 .522 .247 r
.08483 .16187 m
.08483 .01714 L
.08557 .01714 L
.08557 .16187 L
s
1 .894 .882 r
.08557 .16187 m
.08557 .01722 L
.08616 .01722 L
.08616 .16187 L
F
.804 .522 .247 r
.08557 .16187 m
.08557 .01722 L
.08616 .01722 L
.08616 .16187 L
s
1 .894 .882 r
.08616 .16187 m
.08616 .01726 L
.08646 .01726 L
.08646 .16187 L
F
.804 .522 .247 r
.08616 .16187 m
.08616 .01726 L
.08646 .01726 L
.08646 .16187 L
s
1 .894 .882 r
.08646 .16187 m
.08646 .01726 L
.08725 .01726 L
.08725 .16187 L
F
.804 .522 .247 r
.08646 .16187 m
.08646 .01726 L
.08725 .01726 L
.08725 .16187 L
s
1 .894 .882 r
.08725 .16187 m
.08725 .01735 L
.08771 .01735 L
.08771 .16187 L
F
.804 .522 .247 r
.08725 .16187 m
.08725 .01735 L
.08771 .01735 L
.08771 .16187 L
s
1 .894 .882 r
.08771 .16187 m
.08771 .01739 L
.088 .01739 L
.088 .16187 L
F
.804 .522 .247 r
.08771 .16187 m
.08771 .01739 L
.088 .01739 L
.088 .16187 L
s
1 .894 .882 r
.088 .16187 m
.088 .01741 L
.08872 .01741 L
.08872 .16187 L
F
.804 .522 .247 r
.088 .16187 m
.088 .01741 L
.08872 .01741 L
.08872 .16187 L
s
1 .894 .882 r
.08872 .16187 m
.08872 .01746 L
.08913 .01746 L
.08913 .16187 L
F
.804 .522 .247 r
.08872 .16187 m
.08872 .01746 L
.08913 .01746 L
.08913 .16187 L
s
1 .894 .882 r
.08913 .16187 m
.08913 .0175 L
.08937 .0175 L
.08937 .16187 L
F
.804 .522 .247 r
.08913 .16187 m
.08913 .0175 L
.08937 .0175 L
.08937 .16187 L
s
1 .894 .882 r
.08937 .16187 m
.08937 .01752 L
.09006 .01752 L
.09006 .16187 L
F
.804 .522 .247 r
.08937 .16187 m
.08937 .01752 L
.09006 .01752 L
.09006 .16187 L
s
1 .894 .882 r
.09006 .16187 m
.09006 .01758 L
.09038 .01758 L
.09038 .16187 L
F
.804 .522 .247 r
.09006 .16187 m
.09006 .01758 L
.09038 .01758 L
.09038 .16187 L
s
1 .894 .882 r
.09038 .16187 m
.09038 .01761 L
.09072 .01761 L
.09072 .16187 L
F
.804 .522 .247 r
.09038 .16187 m
.09038 .01761 L
.09072 .01761 L
.09072 .16187 L
s
1 .894 .882 r
.09072 .16187 m
.09072 .01769 L
.0915 .01769 L
.0915 .16187 L
F
.804 .522 .247 r
.09072 .16187 m
.09072 .01769 L
.0915 .01769 L
.0915 .16187 L
s
1 .894 .882 r
.0915 .16187 m
.0915 .0177 L
.09183 .0177 L
.09183 .16187 L
F
.804 .522 .247 r
.0915 .16187 m
.0915 .0177 L
.09183 .0177 L
.09183 .16187 L
s
1 .894 .882 r
.09183 .16187 m
.09183 .01774 L
.09233 .01774 L
.09233 .16187 L
F
.804 .522 .247 r
.09183 .16187 m
.09183 .01774 L
.09233 .01774 L
.09233 .16187 L
s
1 .894 .882 r
.09233 .16187 m
.09233 .0178 L
.09281 .0178 L
.09281 .16187 L
F
.804 .522 .247 r
.09233 .16187 m
.09233 .0178 L
.09281 .0178 L
.09281 .16187 L
s
1 .894 .882 r
.09281 .16187 m
.09281 .01782 L
.09309 .01782 L
.09309 .16187 L
F
.804 .522 .247 r
.09281 .16187 m
.09281 .01782 L
.09309 .01782 L
.09309 .16187 L
s
1 .894 .882 r
.09309 .16187 m
.09309 .01785 L
.09351 .01785 L
.09351 .16187 L
F
.804 .522 .247 r
.09309 .16187 m
.09309 .01785 L
.09351 .01785 L
.09351 .16187 L
s
1 .894 .882 r
.09351 .16187 m
.09351 .01787 L
.09379 .01787 L
.09379 .16187 L
F
.804 .522 .247 r
.09351 .16187 m
.09351 .01787 L
.09379 .01787 L
.09379 .16187 L
s
1 .894 .882 r
.09379 .16187 m
.09379 .01794 L
.09432 .01794 L
.09432 .16187 L
F
.804 .522 .247 r
.09379 .16187 m
.09379 .01794 L
.09432 .01794 L
.09432 .16187 L
s
1 .894 .882 r
.09432 .16187 m
.09432 .01795 L
.09462 .01795 L
.09462 .16187 L
F
.804 .522 .247 r
.09432 .16187 m
.09432 .01795 L
.09462 .01795 L
.09462 .16187 L
s
1 .894 .882 r
.09462 .16187 m
.09462 .01799 L
.0954 .01799 L
.0954 .16187 L
F
.804 .522 .247 r
.09462 .16187 m
.09462 .01799 L
.0954 .01799 L
.0954 .16187 L
s
1 .894 .882 r
.0954 .16187 m
.0954 .01808 L
.09603 .01808 L
.09603 .16187 L
F
.804 .522 .247 r
.0954 .16187 m
.0954 .01808 L
.09603 .01808 L
.09603 .16187 L
s
1 .894 .882 r
.09603 .16187 m
.09603 .0181 L
.0966 .0181 L
.0966 .16187 L
F
.804 .522 .247 r
.09603 .16187 m
.09603 .0181 L
.0966 .0181 L
.0966 .16187 L
s
1 .894 .882 r
.0966 .16187 m
.0966 .01816 L
.09698 .01816 L
.09698 .16187 L
F
.804 .522 .247 r
.0966 .16187 m
.0966 .01816 L
.09698 .01816 L
.09698 .16187 L
s
1 .894 .882 r
.09698 .16187 m
.09698 .01821 L
.09741 .01821 L
.09741 .16187 L
F
.804 .522 .247 r
.09698 .16187 m
.09698 .01821 L
.09741 .01821 L
.09741 .16187 L
s
1 .894 .882 r
.09741 .16187 m
.09741 .01828 L
.09798 .01828 L
.09798 .16187 L
F
.804 .522 .247 r
.09741 .16187 m
.09741 .01828 L
.09798 .01828 L
.09798 .16187 L
s
1 .894 .882 r
.09798 .16187 m
.09798 .01834 L
.09857 .01834 L
.09857 .16187 L
F
.804 .522 .247 r
.09798 .16187 m
.09798 .01834 L
.09857 .01834 L
.09857 .16187 L
s
1 .894 .882 r
.09857 .16187 m
.09857 .01837 L
.09929 .01837 L
.09929 .16187 L
F
.804 .522 .247 r
.09857 .16187 m
.09857 .01837 L
.09929 .01837 L
.09929 .16187 L
s
1 .894 .882 r
.09929 .16187 m
.09929 .01844 L
.09968 .01844 L
.09968 .16187 L
F
.804 .522 .247 r
.09929 .16187 m
.09929 .01844 L
.09968 .01844 L
.09968 .16187 L
s
1 .894 .882 r
.09968 .16187 m
.09968 .01849 L
.10033 .01849 L
.10033 .16187 L
F
.804 .522 .247 r
.09968 .16187 m
.09968 .01849 L
.10033 .01849 L
.10033 .16187 L
s
1 .894 .882 r
.10033 .16187 m
.10033 .01855 L
.10076 .01855 L
.10076 .16187 L
F
.804 .522 .247 r
.10033 .16187 m
.10033 .01855 L
.10076 .01855 L
.10076 .16187 L
s
1 .894 .882 r
.10076 .16187 m
.10076 .01861 L
.10148 .01861 L
.10148 .16187 L
F
.804 .522 .247 r
.10076 .16187 m
.10076 .01861 L
.10148 .01861 L
.10148 .16187 L
s
1 .894 .882 r
.10148 .16187 m
.10148 .01865 L
.10199 .01865 L
.10199 .16187 L
F
.804 .522 .247 r
.10148 .16187 m
.10148 .01865 L
.10199 .01865 L
.10199 .16187 L
s
1 .894 .882 r
.10199 .16187 m
.10199 .01869 L
.10256 .01869 L
.10256 .16187 L
F
.804 .522 .247 r
.10199 .16187 m
.10199 .01869 L
.10256 .01869 L
.10256 .16187 L
s
1 .894 .882 r
.10256 .16187 m
.10256 .01875 L
.10289 .01875 L
.10289 .16187 L
F
.804 .522 .247 r
.10256 .16187 m
.10256 .01875 L
.10289 .01875 L
.10289 .16187 L
s
1 .894 .882 r
.10289 .16187 m
.10289 .01883 L
.10364 .01883 L
.10364 .16187 L
F
.804 .522 .247 r
.10289 .16187 m
.10289 .01883 L
.10364 .01883 L
.10364 .16187 L
s
1 .894 .882 r
.10364 .16187 m
.10364 .01886 L
.10406 .01886 L
.10406 .16187 L
F
.804 .522 .247 r
.10364 .16187 m
.10364 .01886 L
.10406 .01886 L
.10406 .16187 L
s
1 .894 .882 r
.10406 .16187 m
.10406 .01891 L
.10437 .01891 L
.10437 .16187 L
F
.804 .522 .247 r
.10406 .16187 m
.10406 .01891 L
.10437 .01891 L
.10437 .16187 L
s
1 .894 .882 r
.10437 .16187 m
.10437 .01895 L
.10503 .01895 L
.10503 .16187 L
F
.804 .522 .247 r
.10437 .16187 m
.10437 .01895 L
.10503 .01895 L
.10503 .16187 L
s
1 .894 .882 r
.10503 .16187 m
.10503 .019 L
.10574 .019 L
.10574 .16187 L
F
.804 .522 .247 r
.10503 .16187 m
.10503 .019 L
.10574 .019 L
.10574 .16187 L
s
1 .894 .882 r
.10574 .16187 m
.10574 .01909 L
.10598 .01909 L
.10598 .16187 L
F
.804 .522 .247 r
.10574 .16187 m
.10574 .01909 L
.10598 .01909 L
.10598 .16187 L
s
1 .894 .882 r
.10598 .16187 m
.10598 .01911 L
.10625 .01911 L
.10625 .16187 L
F
.804 .522 .247 r
.10598 .16187 m
.10598 .01911 L
.10625 .01911 L
.10625 .16187 L
s
1 .894 .882 r
.10625 .16187 m
.10625 .01914 L
.10663 .01914 L
.10663 .16187 L
F
.804 .522 .247 r
.10625 .16187 m
.10625 .01914 L
.10663 .01914 L
.10663 .16187 L
s
1 .894 .882 r
.10663 .16187 m
.10663 .01922 L
.10728 .01922 L
.10728 .16187 L
F
.804 .522 .247 r
.10663 .16187 m
.10663 .01922 L
.10728 .01922 L
.10728 .16187 L
s
1 .894 .882 r
.10728 .16187 m
.10728 .01924 L
.10755 .01924 L
.10755 .16187 L
F
.804 .522 .247 r
.10728 .16187 m
.10728 .01924 L
.10755 .01924 L
.10755 .16187 L
s
1 .894 .882 r
.10755 .16187 m
.10755 .0193 L
.108 .0193 L
.108 .16187 L
F
.804 .522 .247 r
.10755 .16187 m
.10755 .0193 L
.108 .0193 L
.108 .16187 L
s
1 .894 .882 r
.108 .16187 m
.108 .01934 L
.10861 .01934 L
.10861 .16187 L
F
.804 .522 .247 r
.108 .16187 m
.108 .01934 L
.10861 .01934 L
.10861 .16187 L
s
1 .894 .882 r
.10861 .16187 m
.10861 .01942 L
.10913 .01942 L
.10913 .16187 L
F
.804 .522 .247 r
.10861 .16187 m
.10861 .01942 L
.10913 .01942 L
.10913 .16187 L
s
1 .894 .882 r
.10913 .16187 m
.10913 .01949 L
.10977 .01949 L
.10977 .16187 L
F
.804 .522 .247 r
.10913 .16187 m
.10913 .01949 L
.10977 .01949 L
.10977 .16187 L
s
1 .894 .882 r
.10977 .16187 m
.10977 .01956 L
.11046 .01956 L
.11046 .16187 L
F
.804 .522 .247 r
.10977 .16187 m
.10977 .01956 L
.11046 .01956 L
.11046 .16187 L
s
1 .894 .882 r
.11046 .16187 m
.11046 .0196 L
.11071 .0196 L
.11071 .16187 L
F
.804 .522 .247 r
.11046 .16187 m
.11046 .0196 L
.11071 .0196 L
.11071 .16187 L
s
1 .894 .882 r
.11071 .16187 m
.11071 .01964 L
.11132 .01964 L
.11132 .16187 L
F
.804 .522 .247 r
.11071 .16187 m
.11071 .01964 L
.11132 .01964 L
.11132 .16187 L
s
1 .894 .882 r
.11132 .16187 m
.11132 .01969 L
.11182 .01969 L
.11182 .16187 L
F
.804 .522 .247 r
.11132 .16187 m
.11132 .01969 L
.11182 .01969 L
.11182 .16187 L
s
1 .894 .882 r
.11182 .16187 m
.11182 .01977 L
.1121 .01977 L
.1121 .16187 L
F
.804 .522 .247 r
.11182 .16187 m
.11182 .01977 L
.1121 .01977 L
.1121 .16187 L
s
1 .894 .882 r
.1121 .16187 m
.1121 .01982 L
.11273 .01982 L
.11273 .16187 L
F
.804 .522 .247 r
.1121 .16187 m
.1121 .01982 L
.11273 .01982 L
.11273 .16187 L
s
1 .894 .882 r
.11273 .16187 m
.11273 .0199 L
.11343 .0199 L
.11343 .16187 L
F
.804 .522 .247 r
.11273 .16187 m
.11273 .0199 L
.11343 .0199 L
.11343 .16187 L
s
1 .894 .882 r
.11343 .16187 m
.11343 .01998 L
.11422 .01998 L
.11422 .16187 L
F
.804 .522 .247 r
.11343 .16187 m
.11343 .01998 L
.11422 .01998 L
.11422 .16187 L
s
1 .894 .882 r
.11422 .16187 m
.11422 .02007 L
.11474 .02007 L
.11474 .16187 L
F
.804 .522 .247 r
.11422 .16187 m
.11422 .02007 L
.11474 .02007 L
.11474 .16187 L
s
1 .894 .882 r
.11474 .16187 m
.11474 .02011 L
.11528 .02011 L
.11528 .16187 L
F
.804 .522 .247 r
.11474 .16187 m
.11474 .02011 L
.11528 .02011 L
.11528 .16187 L
s
1 .894 .882 r
.11528 .16187 m
.11528 .02022 L
.11604 .02022 L
.11604 .16187 L
F
.804 .522 .247 r
.11528 .16187 m
.11528 .02022 L
.11604 .02022 L
.11604 .16187 L
s
1 .894 .882 r
.11604 .16187 m
.11604 .02027 L
.11666 .02027 L
.11666 .16187 L
F
.804 .522 .247 r
.11604 .16187 m
.11604 .02027 L
.11666 .02027 L
.11666 .16187 L
s
1 .894 .882 r
.11666 .16187 m
.11666 .02033 L
.11711 .02033 L
.11711 .16187 L
F
.804 .522 .247 r
.11666 .16187 m
.11666 .02033 L
.11711 .02033 L
.11711 .16187 L
s
1 .894 .882 r
.11711 .16187 m
.11711 .02037 L
.11779 .02037 L
.11779 .16187 L
F
.804 .522 .247 r
.11711 .16187 m
.11711 .02037 L
.11779 .02037 L
.11779 .16187 L
s
1 .894 .882 r
.11779 .16187 m
.11779 .02048 L
.11808 .02048 L
.11808 .16187 L
F
.804 .522 .247 r
.11779 .16187 m
.11779 .02048 L
.11808 .02048 L
.11808 .16187 L
s
1 .894 .882 r
.11808 .16187 m
.11808 .02055 L
.1187 .02055 L
.1187 .16187 L
F
.804 .522 .247 r
.11808 .16187 m
.11808 .02055 L
.1187 .02055 L
.1187 .16187 L
s
1 .894 .882 r
.1187 .16187 m
.1187 .02057 L
.11912 .02057 L
.11912 .16187 L
F
.804 .522 .247 r
.1187 .16187 m
.1187 .02057 L
.11912 .02057 L
.11912 .16187 L
s
1 .894 .882 r
.11912 .16187 m
.11912 .02065 L
.11967 .02065 L
.11967 .16187 L
F
.804 .522 .247 r
.11912 .16187 m
.11912 .02065 L
.11967 .02065 L
.11967 .16187 L
s
1 .894 .882 r
.11967 .16187 m
.11967 .02068 L
.12012 .02068 L
.12012 .16187 L
F
.804 .522 .247 r
.11967 .16187 m
.11967 .02068 L
.12012 .02068 L
.12012 .16187 L
s
1 .894 .882 r
.12012 .16187 m
.12012 .02078 L
.12071 .02078 L
.12071 .16187 L
F
.804 .522 .247 r
.12012 .16187 m
.12012 .02078 L
.12071 .02078 L
.12071 .16187 L
s
1 .894 .882 r
.12071 .16187 m
.12071 .02086 L
.12149 .02086 L
.12149 .16187 L
F
.804 .522 .247 r
.12071 .16187 m
.12071 .02086 L
.12149 .02086 L
.12149 .16187 L
s
1 .894 .882 r
.12149 .16187 m
.12149 .02092 L
.12224 .02092 L
.12224 .16187 L
F
.804 .522 .247 r
.12149 .16187 m
.12149 .02092 L
.12224 .02092 L
.12224 .16187 L
s
1 .894 .882 r
.12224 .16187 m
.12224 .02103 L
.12297 .02103 L
.12297 .16187 L
F
.804 .522 .247 r
.12224 .16187 m
.12224 .02103 L
.12297 .02103 L
.12297 .16187 L
s
1 .894 .882 r
.12297 .16187 m
.12297 .02118 L
.12373 .02118 L
.12373 .16187 L
F
.804 .522 .247 r
.12297 .16187 m
.12297 .02118 L
.12373 .02118 L
.12373 .16187 L
s
1 .894 .882 r
.12373 .16187 m
.12373 .02123 L
.12406 .02123 L
.12406 .16187 L
F
.804 .522 .247 r
.12373 .16187 m
.12373 .02123 L
.12406 .02123 L
.12406 .16187 L
s
1 .894 .882 r
.12406 .16187 m
.12406 .0213 L
.1248 .0213 L
.1248 .16187 L
F
.804 .522 .247 r
.12406 .16187 m
.12406 .0213 L
.1248 .0213 L
.1248 .16187 L
s
1 .894 .882 r
.1248 .16187 m
.1248 .02138 L
.12517 .02138 L
.12517 .16187 L
F
.804 .522 .247 r
.1248 .16187 m
.1248 .02138 L
.12517 .02138 L
.12517 .16187 L
s
1 .894 .882 r
.12517 .16187 m
.12517 .02144 L
.12567 .02144 L
.12567 .16187 L
F
.804 .522 .247 r
.12517 .16187 m
.12517 .02144 L
.12567 .02144 L
.12567 .16187 L
s
1 .894 .882 r
.12567 .16187 m
.12567 .02148 L
.12596 .02148 L
.12596 .16187 L
F
.804 .522 .247 r
.12567 .16187 m
.12567 .02148 L
.12596 .02148 L
.12596 .16187 L
s
1 .894 .882 r
.12596 .16187 m
.12596 .02153 L
.12631 .02153 L
.12631 .16187 L
F
.804 .522 .247 r
.12596 .16187 m
.12596 .02153 L
.12631 .02153 L
.12631 .16187 L
s
1 .894 .882 r
.12631 .16187 m
.12631 .02155 L
.12679 .02155 L
.12679 .16187 L
F
.804 .522 .247 r
.12631 .16187 m
.12631 .02155 L
.12679 .02155 L
.12679 .16187 L
s
1 .894 .882 r
.12679 .16187 m
.12679 .02161 L
.1273 .02161 L
.1273 .16187 L
F
.804 .522 .247 r
.12679 .16187 m
.12679 .02161 L
.1273 .02161 L
.1273 .16187 L
s
1 .894 .882 r
.1273 .16187 m
.1273 .02167 L
.12788 .02167 L
.12788 .16187 L
F
.804 .522 .247 r
.1273 .16187 m
.1273 .02167 L
.12788 .02167 L
.12788 .16187 L
s
1 .894 .882 r
.12788 .16187 m
.12788 .02179 L
.1285 .02179 L
.1285 .16187 L
F
.804 .522 .247 r
.12788 .16187 m
.12788 .02179 L
.1285 .02179 L
.1285 .16187 L
s
1 .894 .882 r
.1285 .16187 m
.1285 .02186 L
.12903 .02186 L
.12903 .16187 L
F
.804 .522 .247 r
.1285 .16187 m
.1285 .02186 L
.12903 .02186 L
.12903 .16187 L
s
1 .894 .882 r
.12903 .16187 m
.12903 .02197 L
.12973 .02197 L
.12973 .16187 L
F
.804 .522 .247 r
.12903 .16187 m
.12903 .02197 L
.12973 .02197 L
.12973 .16187 L
s
1 .894 .882 r
.12973 .16187 m
.12973 .02203 L
.1301 .02203 L
.1301 .16187 L
F
.804 .522 .247 r
.12973 .16187 m
.12973 .02203 L
.1301 .02203 L
.1301 .16187 L
s
1 .894 .882 r
.1301 .16187 m
.1301 .0221 L
.13084 .0221 L
.13084 .16187 L
F
.804 .522 .247 r
.1301 .16187 m
.1301 .0221 L
.13084 .0221 L
.13084 .16187 L
s
1 .894 .882 r
.13084 .16187 m
.13084 .02219 L
.13132 .02219 L
.13132 .16187 L
F
.804 .522 .247 r
.13084 .16187 m
.13084 .02219 L
.13132 .02219 L
.13132 .16187 L
s
1 .894 .882 r
.13132 .16187 m
.13132 .02226 L
.13166 .02226 L
.13166 .16187 L
F
.804 .522 .247 r
.13132 .16187 m
.13132 .02226 L
.13166 .02226 L
.13166 .16187 L
s
1 .894 .882 r
.13166 .16187 m
.13166 .02231 L
.1324 .02231 L
.1324 .16187 L
F
.804 .522 .247 r
.13166 .16187 m
.13166 .02231 L
.1324 .02231 L
.1324 .16187 L
s
1 .894 .882 r
.1324 .16187 m
.1324 .02237 L
.13284 .02237 L
.13284 .16187 L
F
.804 .522 .247 r
.1324 .16187 m
.1324 .02237 L
.13284 .02237 L
.13284 .16187 L
s
1 .894 .882 r
.13284 .16187 m
.13284 .02245 L
.13311 .02245 L
.13311 .16187 L
F
.804 .522 .247 r
.13284 .16187 m
.13284 .02245 L
.13311 .02245 L
.13311 .16187 L
s
1 .894 .882 r
.13311 .16187 m
.13311 .02249 L
.13367 .02249 L
.13367 .16187 L
F
.804 .522 .247 r
.13311 .16187 m
.13311 .02249 L
.13367 .02249 L
.13367 .16187 L
s
1 .894 .882 r
.13367 .16187 m
.13367 .02265 L
.13443 .02265 L
.13443 .16187 L
F
.804 .522 .247 r
.13367 .16187 m
.13367 .02265 L
.13443 .02265 L
.13443 .16187 L
s
1 .894 .882 r
.13443 .16187 m
.13443 .02272 L
.13493 .02272 L
.13493 .16187 L
F
.804 .522 .247 r
.13443 .16187 m
.13443 .02272 L
.13493 .02272 L
.13493 .16187 L
s
1 .894 .882 r
.13493 .16187 m
.13493 .02275 L
.13528 .02275 L
.13528 .16187 L
F
.804 .522 .247 r
.13493 .16187 m
.13493 .02275 L
.13528 .02275 L
.13528 .16187 L
s
1 .894 .882 r
.13528 .16187 m
.13528 .02281 L
.13588 .02281 L
.13588 .16187 L
F
.804 .522 .247 r
.13528 .16187 m
.13528 .02281 L
.13588 .02281 L
.13588 .16187 L
s
1 .894 .882 r
.13588 .16187 m
.13588 .02287 L
.13656 .02287 L
.13656 .16187 L
F
.804 .522 .247 r
.13588 .16187 m
.13588 .02287 L
.13656 .02287 L
.13656 .16187 L
s
1 .894 .882 r
.13656 .16187 m
.13656 .02299 L
.13713 .02299 L
.13713 .16187 L
F
.804 .522 .247 r
.13656 .16187 m
.13656 .02299 L
.13713 .02299 L
.13713 .16187 L
s
1 .894 .882 r
.13713 .16187 m
.13713 .0231 L
.13791 .0231 L
.13791 .16187 L
F
.804 .522 .247 r
.13713 .16187 m
.13713 .0231 L
.13791 .0231 L
.13791 .16187 L
s
1 .894 .882 r
.13791 .16187 m
.13791 .02319 L
.13826 .02319 L
.13826 .16187 L
F
.804 .522 .247 r
.13791 .16187 m
.13791 .02319 L
.13826 .02319 L
.13826 .16187 L
s
1 .894 .882 r
.13826 .16187 m
.13826 .02322 L
.13889 .02322 L
.13889 .16187 L
F
.804 .522 .247 r
.13826 .16187 m
.13826 .02322 L
.13889 .02322 L
.13889 .16187 L
s
1 .894 .882 r
.13889 .16187 m
.13889 .02333 L
.13935 .02333 L
.13935 .16187 L
F
.804 .522 .247 r
.13889 .16187 m
.13889 .02333 L
.13935 .02333 L
.13935 .16187 L
s
1 .894 .882 r
.13935 .16187 m
.13935 .02339 L
.13989 .02339 L
.13989 .16187 L
F
.804 .522 .247 r
.13935 .16187 m
.13935 .02339 L
.13989 .02339 L
.13989 .16187 L
s
1 .894 .882 r
.13989 .16187 m
.13989 .02349 L
.14053 .02349 L
.14053 .16187 L
F
.804 .522 .247 r
.13989 .16187 m
.13989 .02349 L
.14053 .02349 L
.14053 .16187 L
s
1 .894 .882 r
.14053 .16187 m
.14053 .02356 L
.14083 .02356 L
.14083 .16187 L
F
.804 .522 .247 r
.14053 .16187 m
.14053 .02356 L
.14083 .02356 L
.14083 .16187 L
s
1 .894 .882 r
.14083 .16187 m
.14083 .02368 L
.14148 .02368 L
.14148 .16187 L
F
.804 .522 .247 r
.14083 .16187 m
.14083 .02368 L
.14148 .02368 L
.14148 .16187 L
s
1 .894 .882 r
.14148 .16187 m
.14148 .02373 L
.14174 .02373 L
.14174 .16187 L
F
.804 .522 .247 r
.14148 .16187 m
.14148 .02373 L
.14174 .02373 L
.14174 .16187 L
s
1 .894 .882 r
.14174 .16187 m
.14174 .02381 L
.14248 .02381 L
.14248 .16187 L
F
.804 .522 .247 r
.14174 .16187 m
.14174 .02381 L
.14248 .02381 L
.14248 .16187 L
s
1 .894 .882 r
.14248 .16187 m
.14248 .0239 L
.14322 .0239 L
.14322 .16187 L
F
.804 .522 .247 r
.14248 .16187 m
.14248 .0239 L
.14322 .0239 L
.14322 .16187 L
s
1 .894 .882 r
.14322 .16187 m
.14322 .02399 L
.14394 .02399 L
.14394 .16187 L
F
.804 .522 .247 r
.14322 .16187 m
.14322 .02399 L
.14394 .02399 L
.14394 .16187 L
s
1 .894 .882 r
.14394 .16187 m
.14394 .02408 L
.14452 .02408 L
.14452 .16187 L
F
.804 .522 .247 r
.14394 .16187 m
.14394 .02408 L
.14452 .02408 L
.14452 .16187 L
s
1 .894 .882 r
.14452 .16187 m
.14452 .02424 L
.14516 .02424 L
.14516 .16187 L
F
.804 .522 .247 r
.14452 .16187 m
.14452 .02424 L
.14516 .02424 L
.14516 .16187 L
s
1 .894 .882 r
.14516 .16187 m
.14516 .02431 L
.1454 .02431 L
.1454 .16187 L
F
.804 .522 .247 r
.14516 .16187 m
.14516 .02431 L
.1454 .02431 L
.1454 .16187 L
s
1 .894 .882 r
.1454 .16187 m
.1454 .02433 L
.14593 .02433 L
.14593 .16187 L
F
.804 .522 .247 r
.1454 .16187 m
.1454 .02433 L
.14593 .02433 L
.14593 .16187 L
s
1 .894 .882 r
.14593 .16187 m
.14593 .02443 L
.14647 .02443 L
.14647 .16187 L
F
.804 .522 .247 r
.14593 .16187 m
.14593 .02443 L
.14647 .02443 L
.14647 .16187 L
s
1 .894 .882 r
.14647 .16187 m
.14647 .0245 L
.1468 .0245 L
.1468 .16187 L
F
.804 .522 .247 r
.14647 .16187 m
.14647 .0245 L
.1468 .0245 L
.1468 .16187 L
s
1 .894 .882 r
.1468 .16187 m
.1468 .02458 L
.14709 .02458 L
.14709 .16187 L
F
.804 .522 .247 r
.1468 .16187 m
.1468 .02458 L
.14709 .02458 L
.14709 .16187 L
s
1 .894 .882 r
.14709 .16187 m
.14709 .02459 L
.14735 .02459 L
.14735 .16187 L
F
.804 .522 .247 r
.14709 .16187 m
.14709 .02459 L
.14735 .02459 L
.14735 .16187 L
s
1 .894 .882 r
.14735 .16187 m
.14735 .02462 L
.1478 .02462 L
.1478 .16187 L
F
.804 .522 .247 r
.14735 .16187 m
.14735 .02462 L
.1478 .02462 L
.1478 .16187 L
s
1 .894 .882 r
.1478 .16187 m
.1478 .02469 L
.14833 .02469 L
.14833 .16187 L
F
.804 .522 .247 r
.1478 .16187 m
.1478 .02469 L
.14833 .02469 L
.14833 .16187 L
s
1 .894 .882 r
.14833 .16187 m
.14833 .02484 L
.14874 .02484 L
.14874 .16187 L
F
.804 .522 .247 r
.14833 .16187 m
.14833 .02484 L
.14874 .02484 L
.14874 .16187 L
s
1 .894 .882 r
.14874 .16187 m
.14874 .02485 L
.14925 .02485 L
.14925 .16187 L
F
.804 .522 .247 r
.14874 .16187 m
.14874 .02485 L
.14925 .02485 L
.14925 .16187 L
s
1 .894 .882 r
.14925 .16187 m
.14925 .02497 L
.14972 .02497 L
.14972 .16187 L
F
.804 .522 .247 r
.14925 .16187 m
.14925 .02497 L
.14972 .02497 L
.14972 .16187 L
s
1 .894 .882 r
.14972 .16187 m
.14972 .02504 L
.15015 .02504 L
.15015 .16187 L
F
.804 .522 .247 r
.14972 .16187 m
.14972 .02504 L
.15015 .02504 L
.15015 .16187 L
s
1 .894 .882 r
.15015 .16187 m
.15015 .02515 L
.15073 .02515 L
.15073 .16187 L
F
.804 .522 .247 r
.15015 .16187 m
.15015 .02515 L
.15073 .02515 L
.15073 .16187 L
s
1 .894 .882 r
.15073 .16187 m
.15073 .0252 L
.15102 .0252 L
.15102 .16187 L
F
.804 .522 .247 r
.15073 .16187 m
.15073 .0252 L
.15102 .0252 L
.15102 .16187 L
s
1 .894 .882 r
.15102 .16187 m
.15102 .02526 L
.15176 .02526 L
.15176 .16187 L
F
.804 .522 .247 r
.15102 .16187 m
.15102 .02526 L
.15176 .02526 L
.15176 .16187 L
s
1 .894 .882 r
.15176 .16187 m
.15176 .02535 L
.15235 .02535 L
.15235 .16187 L
F
.804 .522 .247 r
.15176 .16187 m
.15176 .02535 L
.15235 .02535 L
.15235 .16187 L
s
1 .894 .882 r
.15235 .16187 m
.15235 .02551 L
.15288 .02551 L
.15288 .16187 L
F
.804 .522 .247 r
.15235 .16187 m
.15235 .02551 L
.15288 .02551 L
.15288 .16187 L
s
1 .894 .882 r
.15288 .16187 m
.15288 .02559 L
.15332 .02559 L
.15332 .16187 L
F
.804 .522 .247 r
.15288 .16187 m
.15288 .02559 L
.15332 .02559 L
.15332 .16187 L
s
1 .894 .882 r
.15332 .16187 m
.15332 .02568 L
.15405 .02568 L
.15405 .16187 L
F
.804 .522 .247 r
.15332 .16187 m
.15332 .02568 L
.15405 .02568 L
.15405 .16187 L
s
1 .894 .882 r
.15405 .16187 m
.15405 .02578 L
.15471 .02578 L
.15471 .16187 L
F
.804 .522 .247 r
.15405 .16187 m
.15405 .02578 L
.15471 .02578 L
.15471 .16187 L
s
1 .894 .882 r
.15471 .16187 m
.15471 .02588 L
.1553 .02588 L
.1553 .16187 L
F
.804 .522 .247 r
.15471 .16187 m
.15471 .02588 L
.1553 .02588 L
.1553 .16187 L
s
1 .894 .882 r
.1553 .16187 m
.1553 .026 L
.15583 .026 L
.15583 .16187 L
F
.804 .522 .247 r
.1553 .16187 m
.1553 .026 L
.15583 .026 L
.15583 .16187 L
s
1 .894 .882 r
.15583 .16187 m
.15583 .02607 L
.15622 .02607 L
.15622 .16187 L
F
.804 .522 .247 r
.15583 .16187 m
.15583 .02607 L
.15622 .02607 L
.15622 .16187 L
s
1 .894 .882 r
.15622 .16187 m
.15622 .02613 L
.15648 .02613 L
.15648 .16187 L
F
.804 .522 .247 r
.15622 .16187 m
.15622 .02613 L
.15648 .02613 L
.15648 .16187 L
s
1 .894 .882 r
.15648 .16187 m
.15648 .02619 L
.15707 .02619 L
.15707 .16187 L
F
.804 .522 .247 r
.15648 .16187 m
.15648 .02619 L
.15707 .02619 L
.15707 .16187 L
s
1 .894 .882 r
.15707 .16187 m
.15707 .02626 L
.15733 .02626 L
.15733 .16187 L
F
.804 .522 .247 r
.15707 .16187 m
.15707 .02626 L
.15733 .02626 L
.15733 .16187 L
s
1 .894 .882 r
.15733 .16187 m
.15733 .02631 L
.15798 .02631 L
.15798 .16187 L
F
.804 .522 .247 r
.15733 .16187 m
.15733 .02631 L
.15798 .02631 L
.15798 .16187 L
s
1 .894 .882 r
.15798 .16187 m
.15798 .02645 L
.15871 .02645 L
.15871 .16187 L
F
.804 .522 .247 r
.15798 .16187 m
.15798 .02645 L
.15871 .02645 L
.15871 .16187 L
s
1 .894 .882 r
.15871 .16187 m
.15871 .02658 L
.15926 .02658 L
.15926 .16187 L
F
.804 .522 .247 r
.15871 .16187 m
.15871 .02658 L
.15926 .02658 L
.15926 .16187 L
s
1 .894 .882 r
.15926 .16187 m
.15926 .02665 L
.16005 .02665 L
.16005 .16187 L
F
.804 .522 .247 r
.15926 .16187 m
.15926 .02665 L
.16005 .02665 L
.16005 .16187 L
s
1 .894 .882 r
.16005 .16187 m
.16005 .02677 L
.1605 .02677 L
.1605 .16187 L
F
.804 .522 .247 r
.16005 .16187 m
.16005 .02677 L
.1605 .02677 L
.1605 .16187 L
s
1 .894 .882 r
.1605 .16187 m
.1605 .02687 L
.16095 .02687 L
.16095 .16187 L
F
.804 .522 .247 r
.1605 .16187 m
.1605 .02687 L
.16095 .02687 L
.16095 .16187 L
s
1 .894 .882 r
.16095 .16187 m
.16095 .02696 L
.16132 .02696 L
.16132 .16187 L
F
.804 .522 .247 r
.16095 .16187 m
.16095 .02696 L
.16132 .02696 L
.16132 .16187 L
s
1 .894 .882 r
.16132 .16187 m
.16132 .027 L
.16186 .027 L
.16186 .16187 L
F
.804 .522 .247 r
.16132 .16187 m
.16132 .027 L
.16186 .027 L
.16186 .16187 L
s
1 .894 .882 r
.16186 .16187 m
.16186 .02716 L
.16264 .02716 L
.16264 .16187 L
F
.804 .522 .247 r
.16186 .16187 m
.16186 .02716 L
.16264 .02716 L
.16264 .16187 L
s
1 .894 .882 r
.16264 .16187 m
.16264 .02727 L
.1629 .02727 L
.1629 .16187 L
F
.804 .522 .247 r
.16264 .16187 m
.16264 .02727 L
.1629 .02727 L
.1629 .16187 L
s
1 .894 .882 r
.1629 .16187 m
.1629 .02735 L
.1635 .02735 L
.1635 .16187 L
F
.804 .522 .247 r
.1629 .16187 m
.1629 .02735 L
.1635 .02735 L
.1635 .16187 L
s
1 .894 .882 r
.1635 .16187 m
.1635 .02742 L
.16399 .02742 L
.16399 .16187 L
F
.804 .522 .247 r
.1635 .16187 m
.1635 .02742 L
.16399 .02742 L
.16399 .16187 L
s
1 .894 .882 r
.16399 .16187 m
.16399 .02748 L
.16428 .02748 L
.16428 .16187 L
F
.804 .522 .247 r
.16399 .16187 m
.16399 .02748 L
.16428 .02748 L
.16428 .16187 L
s
1 .894 .882 r
.16428 .16187 m
.16428 .02759 L
.16475 .02759 L
.16475 .16187 L
F
.804 .522 .247 r
.16428 .16187 m
.16428 .02759 L
.16475 .02759 L
.16475 .16187 L
s
1 .894 .882 r
.16475 .16187 m
.16475 .02766 L
.16506 .02766 L
.16506 .16187 L
F
.804 .522 .247 r
.16475 .16187 m
.16475 .02766 L
.16506 .02766 L
.16506 .16187 L
s
1 .894 .882 r
.16506 .16187 m
.16506 .02769 L
.16535 .02769 L
.16535 .16187 L
F
.804 .522 .247 r
.16506 .16187 m
.16506 .02769 L
.16535 .02769 L
.16535 .16187 L
s
1 .894 .882 r
.16535 .16187 m
.16535 .02775 L
.16572 .02775 L
.16572 .16187 L
F
.804 .522 .247 r
.16535 .16187 m
.16535 .02775 L
.16572 .02775 L
.16572 .16187 L
s
1 .894 .882 r
.16572 .16187 m
.16572 .02782 L
.16634 .02782 L
.16634 .16187 L
F
.804 .522 .247 r
.16572 .16187 m
.16572 .02782 L
.16634 .02782 L
.16634 .16187 L
s
1 .894 .882 r
.16634 .16187 m
.16634 .02795 L
.16687 .02795 L
.16687 .16187 L
F
.804 .522 .247 r
.16634 .16187 m
.16634 .02795 L
.16687 .02795 L
.16687 .16187 L
s
1 .894 .882 r
.16687 .16187 m
.16687 .02809 L
.16743 .02809 L
.16743 .16187 L
F
.804 .522 .247 r
.16687 .16187 m
.16687 .02809 L
.16743 .02809 L
.16743 .16187 L
s
1 .894 .882 r
.16743 .16187 m
.16743 .02823 L
.16822 .02823 L
.16822 .16187 L
F
.804 .522 .247 r
.16743 .16187 m
.16743 .02823 L
.16822 .02823 L
.16822 .16187 L
s
1 .894 .882 r
.16822 .16187 m
.16822 .0283 L
.16882 .0283 L
.16882 .16187 L
F
.804 .522 .247 r
.16822 .16187 m
.16822 .0283 L
.16882 .0283 L
.16882 .16187 L
s
1 .894 .882 r
.16882 .16187 m
.16882 .02836 L
.16956 .02836 L
.16956 .16187 L
F
.804 .522 .247 r
.16882 .16187 m
.16882 .02836 L
.16956 .02836 L
.16956 .16187 L
s
1 .894 .882 r
.16956 .16187 m
.16956 .02854 L
.17011 .02854 L
.17011 .16187 L
F
.804 .522 .247 r
.16956 .16187 m
.16956 .02854 L
.17011 .02854 L
.17011 .16187 L
s
1 .894 .882 r
.17011 .16187 m
.17011 .02865 L
.17049 .02865 L
.17049 .16187 L
F
.804 .522 .247 r
.17011 .16187 m
.17011 .02865 L
.17049 .02865 L
.17049 .16187 L
s
1 .894 .882 r
.17049 .16187 m
.17049 .02869 L
.17117 .02869 L
.17117 .16187 L
F
.804 .522 .247 r
.17049 .16187 m
.17049 .02869 L
.17117 .02869 L
.17117 .16187 L
s
1 .894 .882 r
.17117 .16187 m
.17117 .02885 L
.1716 .02885 L
.1716 .16187 L
F
.804 .522 .247 r
.17117 .16187 m
.17117 .02885 L
.1716 .02885 L
.1716 .16187 L
s
1 .894 .882 r
.1716 .16187 m
.1716 .02891 L
.17217 .02891 L
.17217 .16187 L
F
.804 .522 .247 r
.1716 .16187 m
.1716 .02891 L
.17217 .02891 L
.17217 .16187 L
s
1 .894 .882 r
.17217 .16187 m
.17217 .02907 L
.17291 .02907 L
.17291 .16187 L
F
.804 .522 .247 r
.17217 .16187 m
.17217 .02907 L
.17291 .02907 L
.17291 .16187 L
s
1 .894 .882 r
.17291 .16187 m
.17291 .02921 L
.17338 .02921 L
.17338 .16187 L
F
.804 .522 .247 r
.17291 .16187 m
.17291 .02921 L
.17338 .02921 L
.17338 .16187 L
s
1 .894 .882 r
.17338 .16187 m
.17338 .02929 L
.17368 .02929 L
.17368 .16187 L
F
.804 .522 .247 r
.17338 .16187 m
.17338 .02929 L
.17368 .02929 L
.17368 .16187 L
s
1 .894 .882 r
.17368 .16187 m
.17368 .02929 L
.17396 .02929 L
.17396 .16187 L
F
.804 .522 .247 r
.17368 .16187 m
.17368 .02929 L
.17396 .02929 L
.17396 .16187 L
s
1 .894 .882 r
.17396 .16187 m
.17396 .02948 L
.17472 .02948 L
.17472 .16187 L
F
.804 .522 .247 r
.17396 .16187 m
.17396 .02948 L
.17472 .02948 L
.17472 .16187 L
s
1 .894 .882 r
.17472 .16187 m
.17472 .02957 L
.17517 .02957 L
.17517 .16187 L
F
.804 .522 .247 r
.17472 .16187 m
.17472 .02957 L
.17517 .02957 L
.17517 .16187 L
s
1 .894 .882 r
.17517 .16187 m
.17517 .0296 L
.17568 .0296 L
.17568 .16187 L
F
.804 .522 .247 r
.17517 .16187 m
.17517 .0296 L
.17568 .0296 L
.17568 .16187 L
s
1 .894 .882 r
.17568 .16187 m
.17568 .02975 L
.17628 .02975 L
.17628 .16187 L
F
.804 .522 .247 r
.17568 .16187 m
.17568 .02975 L
.17628 .02975 L
.17628 .16187 L
s
1 .894 .882 r
.17628 .16187 m
.17628 .0299 L
.177 .0299 L
.177 .16187 L
F
.804 .522 .247 r
.17628 .16187 m
.17628 .0299 L
.177 .0299 L
.177 .16187 L
s
1 .894 .882 r
.177 .16187 m
.177 .02995 L
.17778 .02995 L
.17778 .16187 L
F
.804 .522 .247 r
.177 .16187 m
.177 .02995 L
.17778 .02995 L
.17778 .16187 L
s
1 .894 .882 r
.17778 .16187 m
.17778 .03012 L
.17822 .03012 L
.17822 .16187 L
F
.804 .522 .247 r
.17778 .16187 m
.17778 .03012 L
.17822 .03012 L
.17822 .16187 L
s
1 .894 .882 r
.17822 .16187 m
.17822 .0303 L
.17877 .0303 L
.17877 .16187 L
F
.804 .522 .247 r
.17822 .16187 m
.17822 .0303 L
.17877 .0303 L
.17877 .16187 L
s
1 .894 .882 r
.17877 .16187 m
.17877 .03032 L
.17936 .03032 L
.17936 .16187 L
F
.804 .522 .247 r
.17877 .16187 m
.17877 .03032 L
.17936 .03032 L
.17936 .16187 L
s
1 .894 .882 r
.17936 .16187 m
.17936 .03048 L
.17976 .03048 L
.17976 .16187 L
F
.804 .522 .247 r
.17936 .16187 m
.17936 .03048 L
.17976 .03048 L
.17976 .16187 L
s
1 .894 .882 r
.17976 .16187 m
.17976 .0306 L
.18049 .0306 L
.18049 .16187 L
F
.804 .522 .247 r
.17976 .16187 m
.17976 .0306 L
.18049 .0306 L
.18049 .16187 L
s
1 .894 .882 r
.18049 .16187 m
.18049 .03066 L
.18128 .03066 L
.18128 .16187 L
F
.804 .522 .247 r
.18049 .16187 m
.18049 .03066 L
.18128 .03066 L
.18128 .16187 L
s
1 .894 .882 r
.18128 .16187 m
.18128 .03085 L
.18189 .03085 L
.18189 .16187 L
F
.804 .522 .247 r
.18128 .16187 m
.18128 .03085 L
.18189 .03085 L
.18189 .16187 L
s
1 .894 .882 r
.18189 .16187 m
.18189 .03096 L
.1825 .03096 L
.1825 .16187 L
F
.804 .522 .247 r
.18189 .16187 m
.18189 .03096 L
.1825 .03096 L
.1825 .16187 L
s
1 .894 .882 r
.1825 .16187 m
.1825 .03117 L
.18329 .03117 L
.18329 .16187 L
F
.804 .522 .247 r
.1825 .16187 m
.1825 .03117 L
.18329 .03117 L
.18329 .16187 L
s
1 .894 .882 r
.18329 .16187 m
.18329 .03129 L
.18377 .03129 L
.18377 .16187 L
F
.804 .522 .247 r
.18329 .16187 m
.18329 .03129 L
.18377 .03129 L
.18377 .16187 L
s
1 .894 .882 r
.18377 .16187 m
.18377 .03139 L
.18424 .03139 L
.18424 .16187 L
F
.804 .522 .247 r
.18377 .16187 m
.18377 .03139 L
.18424 .03139 L
.18424 .16187 L
s
1 .894 .882 r
.18424 .16187 m
.18424 .03144 L
.18498 .03144 L
.18498 .16187 L
F
.804 .522 .247 r
.18424 .16187 m
.18424 .03144 L
.18498 .03144 L
.18498 .16187 L
s
1 .894 .882 r
.18498 .16187 m
.18498 .0316 L
.18558 .0316 L
.18558 .16187 L
F
.804 .522 .247 r
.18498 .16187 m
.18498 .0316 L
.18558 .0316 L
.18558 .16187 L
s
1 .894 .882 r
.18558 .16187 m
.18558 .03178 L
.1863 .03178 L
.1863 .16187 L
F
.804 .522 .247 r
.18558 .16187 m
.18558 .03178 L
.1863 .03178 L
.1863 .16187 L
s
1 .894 .882 r
.1863 .16187 m
.1863 .03187 L
.18684 .03187 L
.18684 .16187 L
F
.804 .522 .247 r
.1863 .16187 m
.1863 .03187 L
.18684 .03187 L
.18684 .16187 L
s
1 .894 .882 r
.18684 .16187 m
.18684 .03201 L
.18735 .03201 L
.18735 .16187 L
F
.804 .522 .247 r
.18684 .16187 m
.18684 .03201 L
.18735 .03201 L
.18735 .16187 L
s
1 .894 .882 r
.18735 .16187 m
.18735 .0321 L
.18789 .0321 L
.18789 .16187 L
F
.804 .522 .247 r
.18735 .16187 m
.18735 .0321 L
.18789 .0321 L
.18789 .16187 L
s
1 .894 .882 r
.18789 .16187 m
.18789 .03226 L
.18858 .03226 L
.18858 .16187 L
F
.804 .522 .247 r
.18789 .16187 m
.18789 .03226 L
.18858 .03226 L
.18858 .16187 L
s
1 .894 .882 r
.18858 .16187 m
.18858 .03237 L
.18916 .03237 L
.18916 .16187 L
F
.804 .522 .247 r
.18858 .16187 m
.18858 .03237 L
.18916 .03237 L
.18916 .16187 L
s
1 .894 .882 r
.18916 .16187 m
.18916 .0325 L
.18947 .0325 L
.18947 .16187 L
F
.804 .522 .247 r
.18916 .16187 m
.18916 .0325 L
.18947 .0325 L
.18947 .16187 L
s
1 .894 .882 r
.18947 .16187 m
.18947 .03253 L
.18974 .03253 L
.18974 .16187 L
F
.804 .522 .247 r
.18947 .16187 m
.18947 .03253 L
.18974 .03253 L
.18974 .16187 L
s
1 .894 .882 r
.18974 .16187 m
.18974 .03265 L
.19007 .03265 L
.19007 .16187 L
F
.804 .522 .247 r
.18974 .16187 m
.18974 .03265 L
.19007 .03265 L
.19007 .16187 L
s
1 .894 .882 r
.19007 .16187 m
.19007 .03274 L
.19074 .03274 L
.19074 .16187 L
F
.804 .522 .247 r
.19007 .16187 m
.19007 .03274 L
.19074 .03274 L
.19074 .16187 L
s
1 .894 .882 r
.19074 .16187 m
.19074 .03284 L
.19108 .03284 L
.19108 .16187 L
F
.804 .522 .247 r
.19074 .16187 m
.19074 .03284 L
.19108 .03284 L
.19108 .16187 L
s
1 .894 .882 r
.19108 .16187 m
.19108 .03299 L
.19171 .03299 L
.19171 .16187 L
F
.804 .522 .247 r
.19108 .16187 m
.19108 .03299 L
.19171 .03299 L
.19171 .16187 L
s
1 .894 .882 r
.19171 .16187 m
.19171 .03313 L
.1923 .03313 L
.1923 .16187 L
F
.804 .522 .247 r
.19171 .16187 m
.19171 .03313 L
.1923 .03313 L
.1923 .16187 L
s
1 .894 .882 r
.1923 .16187 m
.1923 .03316 L
.19262 .03316 L
.19262 .16187 L
F
.804 .522 .247 r
.1923 .16187 m
.1923 .03316 L
.19262 .03316 L
.19262 .16187 L
s
1 .894 .882 r
.19262 .16187 m
.19262 .03335 L
.19336 .03335 L
.19336 .16187 L
F
.804 .522 .247 r
.19262 .16187 m
.19262 .03335 L
.19336 .03335 L
.19336 .16187 L
s
1 .894 .882 r
.19336 .16187 m
.19336 .0334 L
.19408 .0334 L
.19408 .16187 L
F
.804 .522 .247 r
.19336 .16187 m
.19336 .0334 L
.19408 .0334 L
.19408 .16187 L
s
1 .894 .882 r
.19408 .16187 m
.19408 .03364 L
.19469 .03364 L
.19469 .16187 L
F
.804 .522 .247 r
.19408 .16187 m
.19408 .03364 L
.19469 .03364 L
.19469 .16187 L
s
1 .894 .882 r
.19469 .16187 m
.19469 .03378 L
.1952 .03378 L
.1952 .16187 L
F
.804 .522 .247 r
.19469 .16187 m
.19469 .03378 L
.1952 .03378 L
.1952 .16187 L
s
1 .894 .882 r
.1952 .16187 m
.1952 .03383 L
.19558 .03383 L
.19558 .16187 L
F
.804 .522 .247 r
.1952 .16187 m
.1952 .03383 L
.19558 .03383 L
.19558 .16187 L
s
1 .894 .882 r
.19558 .16187 m
.19558 .03394 L
.19631 .03394 L
.19631 .16187 L
F
.804 .522 .247 r
.19558 .16187 m
.19558 .03394 L
.19631 .03394 L
.19631 .16187 L
s
1 .894 .882 r
.19631 .16187 m
.19631 .03403 L
.19668 .03403 L
.19668 .16187 L
F
.804 .522 .247 r
.19631 .16187 m
.19631 .03403 L
.19668 .03403 L
.19668 .16187 L
s
1 .894 .882 r
.19668 .16187 m
.19668 .03413 L
.19696 .03413 L
.19696 .16187 L
F
.804 .522 .247 r
.19668 .16187 m
.19668 .03413 L
.19696 .03413 L
.19696 .16187 L
s
1 .894 .882 r
.19696 .16187 m
.19696 .03422 L
.19741 .03422 L
.19741 .16187 L
F
.804 .522 .247 r
.19696 .16187 m
.19696 .03422 L
.19741 .03422 L
.19741 .16187 L
s
1 .894 .882 r
.19741 .16187 m
.19741 .0343 L
.19778 .0343 L
.19778 .16187 L
F
.804 .522 .247 r
.19741 .16187 m
.19741 .0343 L
.19778 .0343 L
.19778 .16187 L
s
1 .894 .882 r
.19778 .16187 m
.19778 .03441 L
.19824 .03441 L
.19824 .16187 L
F
.804 .522 .247 r
.19778 .16187 m
.19778 .03441 L
.19824 .03441 L
.19824 .16187 L
s
1 .894 .882 r
.19824 .16187 m
.19824 .03447 L
.19878 .03447 L
.19878 .16187 L
F
.804 .522 .247 r
.19824 .16187 m
.19824 .03447 L
.19878 .03447 L
.19878 .16187 L
s
1 .894 .882 r
.19878 .16187 m
.19878 .03459 L
.19953 .03459 L
.19953 .16187 L
F
.804 .522 .247 r
.19878 .16187 m
.19878 .03459 L
.19953 .03459 L
.19953 .16187 L
s
1 .894 .882 r
.19953 .16187 m
.19953 .03475 L
.20017 .03475 L
.20017 .16187 L
F
.804 .522 .247 r
.19953 .16187 m
.19953 .03475 L
.20017 .03475 L
.20017 .16187 L
s
1 .894 .882 r
.20017 .16187 m
.20017 .03491 L
.20075 .03491 L
.20075 .16187 L
F
.804 .522 .247 r
.20017 .16187 m
.20017 .03491 L
.20075 .03491 L
.20075 .16187 L
s
1 .894 .882 r
.20075 .16187 m
.20075 .03518 L
.20152 .03518 L
.20152 .16187 L
F
.804 .522 .247 r
.20075 .16187 m
.20075 .03518 L
.20152 .03518 L
.20152 .16187 L
s
1 .894 .882 r
.20152 .16187 m
.20152 .03528 L
.2022 .03528 L
.2022 .16187 L
F
.804 .522 .247 r
.20152 .16187 m
.20152 .03528 L
.2022 .03528 L
.2022 .16187 L
s
1 .894 .882 r
.2022 .16187 m
.2022 .03549 L
.20281 .03549 L
.20281 .16187 L
F
.804 .522 .247 r
.2022 .16187 m
.2022 .03549 L
.20281 .03549 L
.20281 .16187 L
s
1 .894 .882 r
.20281 .16187 m
.20281 .03553 L
.2033 .03553 L
.2033 .16187 L
F
.804 .522 .247 r
.20281 .16187 m
.20281 .03553 L
.2033 .03553 L
.2033 .16187 L
s
1 .894 .882 r
.2033 .16187 m
.2033 .03564 L
.20364 .03564 L
.20364 .16187 L
F
.804 .522 .247 r
.2033 .16187 m
.2033 .03564 L
.20364 .03564 L
.20364 .16187 L
s
1 .894 .882 r
.20364 .16187 m
.20364 .03582 L
.20423 .03582 L
.20423 .16187 L
F
.804 .522 .247 r
.20364 .16187 m
.20364 .03582 L
.20423 .03582 L
.20423 .16187 L
s
1 .894 .882 r
.20423 .16187 m
.20423 .03602 L
.20502 .03602 L
.20502 .16187 L
F
.804 .522 .247 r
.20423 .16187 m
.20423 .03602 L
.20502 .03602 L
.20502 .16187 L
s
1 .894 .882 r
.20502 .16187 m
.20502 .03606 L
.20572 .03606 L
.20572 .16187 L
F
.804 .522 .247 r
.20502 .16187 m
.20502 .03606 L
.20572 .03606 L
.20572 .16187 L
s
1 .894 .882 r
.20572 .16187 m
.20572 .03625 L
.20598 .03625 L
.20598 .16187 L
F
.804 .522 .247 r
.20572 .16187 m
.20572 .03625 L
.20598 .03625 L
.20598 .16187 L
s
1 .894 .882 r
.20598 .16187 m
.20598 .0364 L
.20664 .0364 L
.20664 .16187 L
F
.804 .522 .247 r
.20598 .16187 m
.20598 .0364 L
.20664 .0364 L
.20664 .16187 L
s
1 .894 .882 r
.20664 .16187 m
.20664 .03647 L
.20695 .03647 L
.20695 .16187 L
F
.804 .522 .247 r
.20664 .16187 m
.20664 .03647 L
.20695 .03647 L
.20695 .16187 L
s
1 .894 .882 r
.20695 .16187 m
.20695 .03651 L
.20729 .03651 L
.20729 .16187 L
F
.804 .522 .247 r
.20695 .16187 m
.20695 .03651 L
.20729 .03651 L
.20729 .16187 L
s
1 .894 .882 r
.20729 .16187 m
.20729 .03668 L
.20784 .03668 L
.20784 .16187 L
F
.804 .522 .247 r
.20729 .16187 m
.20729 .03668 L
.20784 .03668 L
.20784 .16187 L
s
1 .894 .882 r
.20784 .16187 m
.20784 .03674 L
.20837 .03674 L
.20837 .16187 L
F
.804 .522 .247 r
.20784 .16187 m
.20784 .03674 L
.20837 .03674 L
.20837 .16187 L
s
1 .894 .882 r
.20837 .16187 m
.20837 .03685 L
.20876 .03685 L
.20876 .16187 L
F
.804 .522 .247 r
.20837 .16187 m
.20837 .03685 L
.20876 .03685 L
.20876 .16187 L
s
1 .894 .882 r
.20876 .16187 m
.20876 .03698 L
.20952 .03698 L
.20952 .16187 L
F
.804 .522 .247 r
.20876 .16187 m
.20876 .03698 L
.20952 .03698 L
.20952 .16187 L
s
1 .894 .882 r
.20952 .16187 m
.20952 .03717 L
.21005 .03717 L
.21005 .16187 L
F
.804 .522 .247 r
.20952 .16187 m
.20952 .03717 L
.21005 .03717 L
.21005 .16187 L
s
1 .894 .882 r
.21005 .16187 m
.21005 .03729 L
.21036 .03729 L
.21036 .16187 L
F
.804 .522 .247 r
.21005 .16187 m
.21005 .03729 L
.21036 .03729 L
.21036 .16187 L
s
1 .894 .882 r
.21036 .16187 m
.21036 .0373 L
.21062 .0373 L
.21062 .16187 L
F
.804 .522 .247 r
.21036 .16187 m
.21036 .0373 L
.21062 .0373 L
.21062 .16187 L
s
1 .894 .882 r
.21062 .16187 m
.21062 .03747 L
.21117 .03747 L
.21117 .16187 L
F
.804 .522 .247 r
.21062 .16187 m
.21062 .03747 L
.21117 .03747 L
.21117 .16187 L
s
1 .894 .882 r
.21117 .16187 m
.21117 .03759 L
.21196 .03759 L
.21196 .16187 L
F
.804 .522 .247 r
.21117 .16187 m
.21117 .03759 L
.21196 .03759 L
.21196 .16187 L
s
1 .894 .882 r
.21196 .16187 m
.21196 .03776 L
.21234 .03776 L
.21234 .16187 L
F
.804 .522 .247 r
.21196 .16187 m
.21196 .03776 L
.21234 .03776 L
.21234 .16187 L
s
1 .894 .882 r
.21234 .16187 m
.21234 .03778 L
.21276 .03778 L
.21276 .16187 L
F
.804 .522 .247 r
.21234 .16187 m
.21234 .03778 L
.21276 .03778 L
.21276 .16187 L
s
1 .894 .882 r
.21276 .16187 m
.21276 .03801 L
.21353 .03801 L
.21353 .16187 L
F
.804 .522 .247 r
.21276 .16187 m
.21276 .03801 L
.21353 .03801 L
.21353 .16187 L
s
1 .894 .882 r
.21353 .16187 m
.21353 .03812 L
.2138 .03812 L
.2138 .16187 L
F
.804 .522 .247 r
.21353 .16187 m
.21353 .03812 L
.2138 .03812 L
.2138 .16187 L
s
1 .894 .882 r
.2138 .16187 m
.2138 .03818 L
.2143 .03818 L
.2143 .16187 L
F
.804 .522 .247 r
.2138 .16187 m
.2138 .03818 L
.2143 .03818 L
.2143 .16187 L
s
1 .894 .882 r
.2143 .16187 m
.2143 .03829 L
.21493 .03829 L
.21493 .16187 L
F
.804 .522 .247 r
.2143 .16187 m
.2143 .03829 L
.21493 .03829 L
.21493 .16187 L
s
1 .894 .882 r
.21493 .16187 m
.21493 .03849 L
.21545 .03849 L
.21545 .16187 L
F
.804 .522 .247 r
.21493 .16187 m
.21493 .03849 L
.21545 .03849 L
.21545 .16187 L
s
1 .894 .882 r
.21545 .16187 m
.21545 .03862 L
.21618 .03862 L
.21618 .16187 L
F
.804 .522 .247 r
.21545 .16187 m
.21545 .03862 L
.21618 .03862 L
.21618 .16187 L
s
1 .894 .882 r
.21618 .16187 m
.21618 .03882 L
.2169 .03882 L
.2169 .16187 L
F
.804 .522 .247 r
.21618 .16187 m
.21618 .03882 L
.2169 .03882 L
.2169 .16187 L
s
1 .894 .882 r
.2169 .16187 m
.2169 .03893 L
.21755 .03893 L
.21755 .16187 L
F
.804 .522 .247 r
.2169 .16187 m
.2169 .03893 L
.21755 .03893 L
.21755 .16187 L
s
1 .894 .882 r
.21755 .16187 m
.21755 .03912 L
.21818 .03912 L
.21818 .16187 L
F
.804 .522 .247 r
.21755 .16187 m
.21755 .03912 L
.21818 .03912 L
.21818 .16187 L
s
1 .894 .882 r
.21818 .16187 m
.21818 .03932 L
.21889 .03932 L
.21889 .16187 L
F
.804 .522 .247 r
.21818 .16187 m
.21818 .03932 L
.21889 .03932 L
.21889 .16187 L
s
1 .894 .882 r
.21889 .16187 m
.21889 .03945 L
.21918 .03945 L
.21918 .16187 L
F
.804 .522 .247 r
.21889 .16187 m
.21889 .03945 L
.21918 .03945 L
.21918 .16187 L
s
1 .894 .882 r
.21918 .16187 m
.21918 .03953 L
.21977 .03953 L
.21977 .16187 L
F
.804 .522 .247 r
.21918 .16187 m
.21918 .03953 L
.21977 .03953 L
.21977 .16187 L
s
1 .894 .882 r
.21977 .16187 m
.21977 .03975 L
.2203 .03975 L
.2203 .16187 L
F
.804 .522 .247 r
.21977 .16187 m
.21977 .03975 L
.2203 .03975 L
.2203 .16187 L
s
1 .894 .882 r
.2203 .16187 m
.2203 .03983 L
.2207 .03983 L
.2207 .16187 L
F
.804 .522 .247 r
.2203 .16187 m
.2203 .03983 L
.2207 .03983 L
.2207 .16187 L
s
1 .894 .882 r
.2207 .16187 m
.2207 .0399 L
.22128 .0399 L
.22128 .16187 L
F
.804 .522 .247 r
.2207 .16187 m
.2207 .0399 L
.22128 .0399 L
.22128 .16187 L
s
1 .894 .882 r
.22128 .16187 m
.22128 .04013 L
.22171 .04013 L
.22171 .16187 L
F
.804 .522 .247 r
.22128 .16187 m
.22128 .04013 L
.22171 .04013 L
.22171 .16187 L
s
1 .894 .882 r
.22171 .16187 m
.22171 .04021 L
.22229 .04021 L
.22229 .16187 L
F
.804 .522 .247 r
.22171 .16187 m
.22171 .04021 L
.22229 .04021 L
.22229 .16187 L
s
1 .894 .882 r
.22229 .16187 m
.22229 .04045 L
.22297 .04045 L
.22297 .16187 L
F
.804 .522 .247 r
.22229 .16187 m
.22229 .04045 L
.22297 .04045 L
.22297 .16187 L
s
1 .894 .882 r
.22297 .16187 m
.22297 .0405 L
.22348 .0405 L
.22348 .16187 L
F
.804 .522 .247 r
.22297 .16187 m
.22297 .0405 L
.22348 .0405 L
.22348 .16187 L
s
1 .894 .882 r
.22348 .16187 m
.22348 .04069 L
.22389 .04069 L
.22389 .16187 L
F
.804 .522 .247 r
.22348 .16187 m
.22348 .04069 L
.22389 .04069 L
.22389 .16187 L
s
1 .894 .882 r
.22389 .16187 m
.22389 .04075 L
.22417 .04075 L
.22417 .16187 L
F
.804 .522 .247 r
.22389 .16187 m
.22389 .04075 L
.22417 .04075 L
.22417 .16187 L
s
1 .894 .882 r
.22417 .16187 m
.22417 .04085 L
.22487 .04085 L
.22487 .16187 L
F
.804 .522 .247 r
.22417 .16187 m
.22417 .04085 L
.22487 .04085 L
.22487 .16187 L
s
1 .894 .882 r
.22487 .16187 m
.22487 .041 L
.22524 .041 L
.22524 .16187 L
F
.804 .522 .247 r
.22487 .16187 m
.22487 .041 L
.22524 .041 L
.22524 .16187 L
s
1 .894 .882 r
.22524 .16187 m
.22524 .04123 L
.22603 .04123 L
.22603 .16187 L
F
.804 .522 .247 r
.22524 .16187 m
.22524 .04123 L
.22603 .04123 L
.22603 .16187 L
s
1 .894 .882 r
.22603 .16187 m
.22603 .04126 L
.22634 .04126 L
.22634 .16187 L
F
.804 .522 .247 r
.22603 .16187 m
.22603 .04126 L
.22634 .04126 L
.22634 .16187 L
s
1 .894 .882 r
.22634 .16187 m
.22634 .04148 L
.22702 .04148 L
.22702 .16187 L
F
.804 .522 .247 r
.22634 .16187 m
.22634 .04148 L
.22702 .04148 L
.22702 .16187 L
s
1 .894 .882 r
.22702 .16187 m
.22702 .04155 L
.2277 .04155 L
.2277 .16187 L
F
.804 .522 .247 r
.22702 .16187 m
.22702 .04155 L
.2277 .04155 L
.2277 .16187 L
s
1 .894 .882 r
.2277 .16187 m
.2277 .04177 L
.22811 .04177 L
.22811 .16187 L
F
.804 .522 .247 r
.2277 .16187 m
.2277 .04177 L
.22811 .04177 L
.22811 .16187 L
s
1 .894 .882 r
.22811 .16187 m
.22811 .04188 L
.2287 .04188 L
.2287 .16187 L
F
.804 .522 .247 r
.22811 .16187 m
.22811 .04188 L
.2287 .04188 L
.2287 .16187 L
s
1 .894 .882 r
.2287 .16187 m
.2287 .04204 L
.22945 .04204 L
.22945 .16187 L
F
.804 .522 .247 r
.2287 .16187 m
.2287 .04204 L
.22945 .04204 L
.22945 .16187 L
s
1 .894 .882 r
.22945 .16187 m
.22945 .04231 L
.23022 .04231 L
.23022 .16187 L
F
.804 .522 .247 r
.22945 .16187 m
.22945 .04231 L
.23022 .04231 L
.23022 .16187 L
s
1 .894 .882 r
.23022 .16187 m
.23022 .04245 L
.23079 .04245 L
.23079 .16187 L
F
.804 .522 .247 r
.23022 .16187 m
.23022 .04245 L
.23079 .04245 L
.23079 .16187 L
s
1 .894 .882 r
.23079 .16187 m
.23079 .04257 L
.23157 .04257 L
.23157 .16187 L
F
.804 .522 .247 r
.23079 .16187 m
.23079 .04257 L
.23157 .04257 L
.23157 .16187 L
s
1 .894 .882 r
.23157 .16187 m
.23157 .04279 L
.23184 .04279 L
.23184 .16187 L
F
.804 .522 .247 r
.23157 .16187 m
.23157 .04279 L
.23184 .04279 L
.23184 .16187 L
s
1 .894 .882 r
.23184 .16187 m
.23184 .04285 L
.23256 .04285 L
.23256 .16187 L
F
.804 .522 .247 r
.23184 .16187 m
.23184 .04285 L
.23256 .04285 L
.23256 .16187 L
s
1 .894 .882 r
.23256 .16187 m
.23256 .04305 L
.23335 .04305 L
.23335 .16187 L
F
.804 .522 .247 r
.23256 .16187 m
.23256 .04305 L
.23335 .04305 L
.23335 .16187 L
s
1 .894 .882 r
.23335 .16187 m
.23335 .04326 L
.23383 .04326 L
.23383 .16187 L
F
.804 .522 .247 r
.23335 .16187 m
.23335 .04326 L
.23383 .04326 L
.23383 .16187 L
s
1 .894 .882 r
.23383 .16187 m
.23383 .0434 L
.23452 .0434 L
.23452 .16187 L
F
.804 .522 .247 r
.23383 .16187 m
.23383 .0434 L
.23452 .0434 L
.23452 .16187 L
s
1 .894 .882 r
.23452 .16187 m
.23452 .04353 L
.2349 .04353 L
.2349 .16187 L
F
.804 .522 .247 r
.23452 .16187 m
.23452 .04353 L
.2349 .04353 L
.2349 .16187 L
s
1 .894 .882 r
.2349 .16187 m
.2349 .04368 L
.2355 .04368 L
.2355 .16187 L
F
.804 .522 .247 r
.2349 .16187 m
.2349 .04368 L
.2355 .04368 L
.2355 .16187 L
s
1 .894 .882 r
.2355 .16187 m
.2355 .04397 L
.23621 .04397 L
.23621 .16187 L
F
.804 .522 .247 r
.2355 .16187 m
.2355 .04397 L
.23621 .04397 L
.23621 .16187 L
s
1 .894 .882 r
.23621 .16187 m
.23621 .04402 L
.23646 .04402 L
.23646 .16187 L
F
.804 .522 .247 r
.23621 .16187 m
.23621 .04402 L
.23646 .04402 L
.23646 .16187 L
s
1 .894 .882 r
.23646 .16187 m
.23646 .0442 L
.23715 .0442 L
.23715 .16187 L
F
.804 .522 .247 r
.23646 .16187 m
.23646 .0442 L
.23715 .0442 L
.23715 .16187 L
s
1 .894 .882 r
.23715 .16187 m
.23715 .04429 L
.23757 .04429 L
.23757 .16187 L
F
.804 .522 .247 r
.23715 .16187 m
.23715 .04429 L
.23757 .04429 L
.23757 .16187 L
s
1 .894 .882 r
.23757 .16187 m
.23757 .04439 L
.23824 .04439 L
.23824 .16187 L
F
.804 .522 .247 r
.23757 .16187 m
.23757 .04439 L
.23824 .04439 L
.23824 .16187 L
s
1 .894 .882 r
.23824 .16187 m
.23824 .04465 L
.2386 .04465 L
.2386 .16187 L
F
.804 .522 .247 r
.23824 .16187 m
.23824 .04465 L
.2386 .04465 L
.2386 .16187 L
s
1 .894 .882 r
.2386 .16187 m
.2386 .04468 L
.23916 .04468 L
.23916 .16187 L
F
.804 .522 .247 r
.2386 .16187 m
.2386 .04468 L
.23916 .04468 L
.23916 .16187 L
s
1 .894 .882 r
.23916 .16187 m
.23916 .04487 L
.2396 .04487 L
.2396 .16187 L
F
.804 .522 .247 r
.23916 .16187 m
.23916 .04487 L
.2396 .04487 L
.2396 .16187 L
s
1 .894 .882 r
.2396 .16187 m
.2396 .04495 L
.2402 .04495 L
.2402 .16187 L
F
.804 .522 .247 r
.2396 .16187 m
.2396 .04495 L
.2402 .04495 L
.2402 .16187 L
s
1 .894 .882 r
.2402 .16187 m
.2402 .04512 L
.24069 .04512 L
.24069 .16187 L
F
.804 .522 .247 r
.2402 .16187 m
.2402 .04512 L
.24069 .04512 L
.24069 .16187 L
s
1 .894 .882 r
.24069 .16187 m
.24069 .04543 L
.24138 .04543 L
.24138 .16187 L
F
.804 .522 .247 r
.24069 .16187 m
.24069 .04543 L
.24138 .04543 L
.24138 .16187 L
s
1 .894 .882 r
.24138 .16187 m
.24138 .04549 L
.24166 .04549 L
.24166 .16187 L
F
.804 .522 .247 r
.24138 .16187 m
.24138 .04549 L
.24166 .04549 L
.24166 .16187 L
s
1 .894 .882 r
.24166 .16187 m
.24166 .04555 L
.2419 .04555 L
.2419 .16187 L
F
.804 .522 .247 r
.24166 .16187 m
.24166 .04555 L
.2419 .04555 L
.2419 .16187 L
s
1 .894 .882 r
.2419 .16187 m
.2419 .04569 L
.24245 .04569 L
.24245 .16187 L
F
.804 .522 .247 r
.2419 .16187 m
.2419 .04569 L
.24245 .04569 L
.24245 .16187 L
s
1 .894 .882 r
.24245 .16187 m
.24245 .04578 L
.24318 .04578 L
.24318 .16187 L
F
.804 .522 .247 r
.24245 .16187 m
.24245 .04578 L
.24318 .04578 L
.24318 .16187 L
s
1 .894 .882 r
.24318 .16187 m
.24318 .04596 L
.24369 .04596 L
.24369 .16187 L
F
.804 .522 .247 r
.24318 .16187 m
.24318 .04596 L
.24369 .04596 L
.24369 .16187 L
s
1 .894 .882 r
.24369 .16187 m
.24369 .04611 L
.24396 .04611 L
.24396 .16187 L
F
.804 .522 .247 r
.24369 .16187 m
.24369 .04611 L
.24396 .04611 L
.24396 .16187 L
s
1 .894 .882 r
.24396 .16187 m
.24396 .04629 L
.24448 .04629 L
.24448 .16187 L
F
.804 .522 .247 r
.24396 .16187 m
.24396 .04629 L
.24448 .04629 L
.24448 .16187 L
s
1 .894 .882 r
.24448 .16187 m
.24448 .04639 L
.24473 .04639 L
.24473 .16187 L
F
.804 .522 .247 r
.24448 .16187 m
.24448 .04639 L
.24473 .04639 L
.24473 .16187 L
s
1 .894 .882 r
.24473 .16187 m
.24473 .04652 L
.24526 .04652 L
.24526 .16187 L
F
.804 .522 .247 r
.24473 .16187 m
.24473 .04652 L
.24526 .04652 L
.24526 .16187 L
s
1 .894 .882 r
.24526 .16187 m
.24526 .04669 L
.24586 .04669 L
.24586 .16187 L
F
.804 .522 .247 r
.24526 .16187 m
.24526 .04669 L
.24586 .04669 L
.24586 .16187 L
s
1 .894 .882 r
.24586 .16187 m
.24586 .0468 L
.2465 .0468 L
.2465 .16187 L
F
.804 .522 .247 r
.24586 .16187 m
.24586 .0468 L
.2465 .0468 L
.2465 .16187 L
s
1 .894 .882 r
.2465 .16187 m
.2465 .04707 L
.24717 .04707 L
.24717 .16187 L
F
.804 .522 .247 r
.2465 .16187 m
.2465 .04707 L
.24717 .04707 L
.24717 .16187 L
s
1 .894 .882 r
.24717 .16187 m
.24717 .04721 L
.24791 .04721 L
.24791 .16187 L
F
.804 .522 .247 r
.24717 .16187 m
.24717 .04721 L
.24791 .04721 L
.24791 .16187 L
s
1 .894 .882 r
.24791 .16187 m
.24791 .04731 L
.24861 .04731 L
.24861 .16187 L
F
.804 .522 .247 r
.24791 .16187 m
.24791 .04731 L
.24861 .04731 L
.24861 .16187 L
s
1 .894 .882 r
.24861 .16187 m
.24861 .04752 L
.24924 .04752 L
.24924 .16187 L
F
.804 .522 .247 r
.24861 .16187 m
.24861 .04752 L
.24924 .04752 L
.24924 .16187 L
s
1 .894 .882 r
.24924 .16187 m
.24924 .04773 L
.25003 .04773 L
.25003 .16187 L
F
.804 .522 .247 r
.24924 .16187 m
.24924 .04773 L
.25003 .04773 L
.25003 .16187 L
s
1 .894 .882 r
.25003 .16187 m
.25003 .04796 L
.25058 .04796 L
.25058 .16187 L
F
.804 .522 .247 r
.25003 .16187 m
.25003 .04796 L
.25058 .04796 L
.25058 .16187 L
s
1 .894 .882 r
.25058 .16187 m
.25058 .04816 L
.25086 .04816 L
.25086 .16187 L
F
.804 .522 .247 r
.25058 .16187 m
.25058 .04816 L
.25086 .04816 L
.25086 .16187 L
s
1 .894 .882 r
.25086 .16187 m
.25086 .04819 L
.25138 .04819 L
.25138 .16187 L
F
.804 .522 .247 r
.25086 .16187 m
.25086 .04819 L
.25138 .04819 L
.25138 .16187 L
s
1 .894 .882 r
.25138 .16187 m
.25138 .04846 L
.25184 .04846 L
.25184 .16187 L
F
.804 .522 .247 r
.25138 .16187 m
.25138 .04846 L
.25184 .04846 L
.25184 .16187 L
s
1 .894 .882 r
.25184 .16187 m
.25184 .04854 L
.2522 .04854 L
.2522 .16187 L
F
.804 .522 .247 r
.25184 .16187 m
.25184 .04854 L
.2522 .04854 L
.2522 .16187 L
s
1 .894 .882 r
.2522 .16187 m
.2522 .04868 L
.25268 .04868 L
.25268 .16187 L
F
.804 .522 .247 r
.2522 .16187 m
.2522 .04868 L
.25268 .04868 L
.25268 .16187 L
s
1 .894 .882 r
.25268 .16187 m
.25268 .04871 L
.25295 .04871 L
.25295 .16187 L
F
.804 .522 .247 r
.25268 .16187 m
.25268 .04871 L
.25295 .04871 L
.25295 .16187 L
s
1 .894 .882 r
.25295 .16187 m
.25295 .04896 L
.25354 .04896 L
.25354 .16187 L
F
.804 .522 .247 r
.25295 .16187 m
.25295 .04896 L
.25354 .04896 L
.25354 .16187 L
s
1 .894 .882 r
.25354 .16187 m
.25354 .04896 L
.25386 .04896 L
.25386 .16187 L
F
.804 .522 .247 r
.25354 .16187 m
.25354 .04896 L
.25386 .04896 L
.25386 .16187 L
s
1 .894 .882 r
.25386 .16187 m
.25386 .04909 L
.25434 .04909 L
.25434 .16187 L
F
.804 .522 .247 r
.25386 .16187 m
.25386 .04909 L
.25434 .04909 L
.25434 .16187 L
s
1 .894 .882 r
.25434 .16187 m
.25434 .04925 L
.25488 .04925 L
.25488 .16187 L
F
.804 .522 .247 r
.25434 .16187 m
.25434 .04925 L
.25488 .04925 L
.25488 .16187 L
s
1 .894 .882 r
.25488 .16187 m
.25488 .04951 L
.25553 .04951 L
.25553 .16187 L
F
.804 .522 .247 r
.25488 .16187 m
.25488 .04951 L
.25553 .04951 L
.25553 .16187 L
s
1 .894 .882 r
.25553 .16187 m
.25553 .04973 L
.25615 .04973 L
.25615 .16187 L
F
.804 .522 .247 r
.25553 .16187 m
.25553 .04973 L
.25615 .04973 L
.25615 .16187 L
s
1 .894 .882 r
.25615 .16187 m
.25615 .04987 L
.2566 .04987 L
.2566 .16187 L
F
.804 .522 .247 r
.25615 .16187 m
.25615 .04987 L
.2566 .04987 L
.2566 .16187 L
s
1 .894 .882 r
.2566 .16187 m
.2566 .04992 L
.25686 .04992 L
.25686 .16187 L
F
.804 .522 .247 r
.2566 .16187 m
.2566 .04992 L
.25686 .04992 L
.25686 .16187 L
s
1 .894 .882 r
.25686 .16187 m
.25686 .05011 L
.25751 .05011 L
.25751 .16187 L
F
.804 .522 .247 r
.25686 .16187 m
.25686 .05011 L
.25751 .05011 L
.25751 .16187 L
s
1 .894 .882 r
.25751 .16187 m
.25751 .05016 L
.25784 .05016 L
.25784 .16187 L
F
.804 .522 .247 r
.25751 .16187 m
.25751 .05016 L
.25784 .05016 L
.25784 .16187 L
s
1 .894 .882 r
.25784 .16187 m
.25784 .05027 L
.25849 .05027 L
.25849 .16187 L
F
.804 .522 .247 r
.25784 .16187 m
.25784 .05027 L
.25849 .05027 L
.25849 .16187 L
s
1 .894 .882 r
.25849 .16187 m
.25849 .05046 L
.25893 .05046 L
.25893 .16187 L
F
.804 .522 .247 r
.25849 .16187 m
.25849 .05046 L
.25893 .05046 L
.25893 .16187 L
s
1 .894 .882 r
.25893 .16187 m
.25893 .05079 L
.25971 .05079 L
.25971 .16187 L
F
.804 .522 .247 r
.25893 .16187 m
.25893 .05079 L
.25971 .05079 L
.25971 .16187 L
s
1 .894 .882 r
.25971 .16187 m
.25971 .05089 L
.26011 .05089 L
.26011 .16187 L
F
.804 .522 .247 r
.25971 .16187 m
.25971 .05089 L
.26011 .05089 L
.26011 .16187 L
s
1 .894 .882 r
.26011 .16187 m
.26011 .05096 L
.26087 .05096 L
.26087 .16187 L
F
.804 .522 .247 r
.26011 .16187 m
.26011 .05096 L
.26087 .05096 L
.26087 .16187 L
s
1 .894 .882 r
.26087 .16187 m
.26087 .05136 L
.26148 .05136 L
.26148 .16187 L
F
.804 .522 .247 r
.26087 .16187 m
.26087 .05136 L
.26148 .05136 L
.26148 .16187 L
s
1 .894 .882 r
.26148 .16187 m
.26148 .05154 L
.26228 .05154 L
.26228 .16187 L
F
.804 .522 .247 r
.26148 .16187 m
.26148 .05154 L
.26228 .05154 L
.26228 .16187 L
s
1 .894 .882 r
.26228 .16187 m
.26228 .05168 L
.26294 .05168 L
.26294 .16187 L
F
.804 .522 .247 r
.26228 .16187 m
.26228 .05168 L
.26294 .05168 L
.26294 .16187 L
s
1 .894 .882 r
.26294 .16187 m
.26294 .05186 L
.26367 .05186 L
.26367 .16187 L
F
.804 .522 .247 r
.26294 .16187 m
.26294 .05186 L
.26367 .05186 L
.26367 .16187 L
s
1 .894 .882 r
.26367 .16187 m
.26367 .05213 L
.264 .05213 L
.264 .16187 L
F
.804 .522 .247 r
.26367 .16187 m
.26367 .05213 L
.264 .05213 L
.264 .16187 L
s
1 .894 .882 r
.264 .16187 m
.264 .05228 L
.26457 .05228 L
.26457 .16187 L
F
.804 .522 .247 r
.264 .16187 m
.264 .05228 L
.26457 .05228 L
.26457 .16187 L
s
1 .894 .882 r
.26457 .16187 m
.26457 .05243 L
.26511 .05243 L
.26511 .16187 L
F
.804 .522 .247 r
.26457 .16187 m
.26457 .05243 L
.26511 .05243 L
.26511 .16187 L
s
1 .894 .882 r
.26511 .16187 m
.26511 .05256 L
.2656 .05256 L
.2656 .16187 L
F
.804 .522 .247 r
.26511 .16187 m
.26511 .05256 L
.2656 .05256 L
.2656 .16187 L
s
1 .894 .882 r
.2656 .16187 m
.2656 .05272 L
.2659 .05272 L
.2659 .16187 L
F
.804 .522 .247 r
.2656 .16187 m
.2656 .05272 L
.2659 .05272 L
.2659 .16187 L
s
1 .894 .882 r
.2659 .16187 m
.2659 .05293 L
.2667 .05293 L
.2667 .16187 L
F
.804 .522 .247 r
.2659 .16187 m
.2659 .05293 L
.2667 .05293 L
.2667 .16187 L
s
1 .894 .882 r
.2667 .16187 m
.2667 .05308 L
.26716 .05308 L
.26716 .16187 L
F
.804 .522 .247 r
.2667 .16187 m
.2667 .05308 L
.26716 .05308 L
.26716 .16187 L
s
1 .894 .882 r
.26716 .16187 m
.26716 .05316 L
.26742 .05316 L
.26742 .16187 L
F
.804 .522 .247 r
.26716 .16187 m
.26716 .05316 L
.26742 .05316 L
.26742 .16187 L
s
1 .894 .882 r
.26742 .16187 m
.26742 .0533 L
.26799 .0533 L
.26799 .16187 L
F
.804 .522 .247 r
.26742 .16187 m
.26742 .0533 L
.26799 .0533 L
.26799 .16187 L
s
1 .894 .882 r
.26799 .16187 m
.26799 .05352 L
.26837 .05352 L
.26837 .16187 L
F
.804 .522 .247 r
.26799 .16187 m
.26799 .05352 L
.26837 .05352 L
.26837 .16187 L
s
1 .894 .882 r
.26837 .16187 m
.26837 .05366 L
.26901 .05366 L
.26901 .16187 L
F
.804 .522 .247 r
.26837 .16187 m
.26837 .05366 L
.26901 .05366 L
.26901 .16187 L
s
1 .894 .882 r
.26901 .16187 m
.26901 .05378 L
.26963 .05378 L
.26963 .16187 L
F
.804 .522 .247 r
.26901 .16187 m
.26901 .05378 L
.26963 .05378 L
.26963 .16187 L
s
1 .894 .882 r
.26963 .16187 m
.26963 .05409 L
.27018 .05409 L
.27018 .16187 L
F
.804 .522 .247 r
.26963 .16187 m
.26963 .05409 L
.27018 .05409 L
.27018 .16187 L
s
1 .894 .882 r
.27018 .16187 m
.27018 .05414 L
.27072 .05414 L
.27072 .16187 L
F
.804 .522 .247 r
.27018 .16187 m
.27018 .05414 L
.27072 .05414 L
.27072 .16187 L
s
1 .894 .882 r
.27072 .16187 m
.27072 .05439 L
.27128 .05439 L
.27128 .16187 L
F
.804 .522 .247 r
.27072 .16187 m
.27072 .05439 L
.27128 .05439 L
.27128 .16187 L
s
1 .894 .882 r
.27128 .16187 m
.27128 .0545 L
.27205 .0545 L
.27205 .16187 L
F
.804 .522 .247 r
.27128 .16187 m
.27128 .0545 L
.27205 .0545 L
.27205 .16187 L
s
1 .894 .882 r
.27205 .16187 m
.27205 .05481 L
.27241 .05481 L
.27241 .16187 L
F
.804 .522 .247 r
.27205 .16187 m
.27205 .05481 L
.27241 .05481 L
.27241 .16187 L
s
1 .894 .882 r
.27241 .16187 m
.27241 .05488 L
.27297 .05488 L
.27297 .16187 L
F
.804 .522 .247 r
.27241 .16187 m
.27241 .05488 L
.27297 .05488 L
.27297 .16187 L
s
1 .894 .882 r
.27297 .16187 m
.27297 .05502 L
.27337 .05502 L
.27337 .16187 L
F
.804 .522 .247 r
.27297 .16187 m
.27297 .05502 L
.27337 .05502 L
.27337 .16187 L
s
1 .894 .882 r
.27337 .16187 m
.27337 .05514 L
.27363 .05514 L
.27363 .16187 L
F
.804 .522 .247 r
.27337 .16187 m
.27337 .05514 L
.27363 .05514 L
.27363 .16187 L
s
1 .894 .882 r
.27363 .16187 m
.27363 .05539 L
.27418 .05539 L
.27418 .16187 L
F
.804 .522 .247 r
.27363 .16187 m
.27363 .05539 L
.27418 .05539 L
.27418 .16187 L
s
1 .894 .882 r
.27418 .16187 m
.27418 .05552 L
.27475 .05552 L
.27475 .16187 L
F
.804 .522 .247 r
.27418 .16187 m
.27418 .05552 L
.27475 .05552 L
.27475 .16187 L
s
1 .894 .882 r
.27475 .16187 m
.27475 .05573 L
.2753 .05573 L
.2753 .16187 L
F
.804 .522 .247 r
.27475 .16187 m
.27475 .05573 L
.2753 .05573 L
.2753 .16187 L
s
1 .894 .882 r
.2753 .16187 m
.2753 .05587 L
.27564 .05587 L
.27564 .16187 L
F
.804 .522 .247 r
.2753 .16187 m
.2753 .05587 L
.27564 .05587 L
.27564 .16187 L
s
1 .894 .882 r
.27564 .16187 m
.27564 .0559 L
.2761 .0559 L
.2761 .16187 L
F
.804 .522 .247 r
.27564 .16187 m
.27564 .0559 L
.2761 .0559 L
.2761 .16187 L
s
1 .894 .882 r
.2761 .16187 m
.2761 .05628 L
.2769 .05628 L
.2769 .16187 L
F
.804 .522 .247 r
.2761 .16187 m
.2761 .05628 L
.2769 .05628 L
.2769 .16187 L
s
1 .894 .882 r
.2769 .16187 m
.2769 .0563 L
.27716 .0563 L
.27716 .16187 L
F
.804 .522 .247 r
.2769 .16187 m
.2769 .0563 L
.27716 .0563 L
.27716 .16187 L
s
1 .894 .882 r
.27716 .16187 m
.27716 .0565 L
.27781 .0565 L
.27781 .16187 L
F
.804 .522 .247 r
.27716 .16187 m
.27716 .0565 L
.27781 .0565 L
.27781 .16187 L
s
1 .894 .882 r
.27781 .16187 m
.27781 .05665 L
.27822 .05665 L
.27822 .16187 L
F
.804 .522 .247 r
.27781 .16187 m
.27781 .05665 L
.27822 .05665 L
.27822 .16187 L
s
1 .894 .882 r
.27822 .16187 m
.27822 .05679 L
.27902 .05679 L
.27902 .16187 L
F
.804 .522 .247 r
.27822 .16187 m
.27822 .05679 L
.27902 .05679 L
.27902 .16187 L
s
1 .894 .882 r
.27902 .16187 m
.27902 .05712 L
.27964 .05712 L
.27964 .16187 L
F
.804 .522 .247 r
.27902 .16187 m
.27902 .05712 L
.27964 .05712 L
.27964 .16187 L
s
1 .894 .882 r
.27964 .16187 m
.27964 .05728 L
.28027 .05728 L
.28027 .16187 L
F
.804 .522 .247 r
.27964 .16187 m
.27964 .05728 L
.28027 .05728 L
.28027 .16187 L
s
1 .894 .882 r
.28027 .16187 m
.28027 .05741 L
.28091 .05741 L
.28091 .16187 L
F
.804 .522 .247 r
.28027 .16187 m
.28027 .05741 L
.28091 .05741 L
.28091 .16187 L
s
1 .894 .882 r
.28091 .16187 m
.28091 .05768 L
.28158 .05768 L
.28158 .16187 L
F
.804 .522 .247 r
.28091 .16187 m
.28091 .05768 L
.28158 .05768 L
.28158 .16187 L
s
1 .894 .882 r
.28158 .16187 m
.28158 .05784 L
.28235 .05784 L
.28235 .16187 L
F
.804 .522 .247 r
.28158 .16187 m
.28158 .05784 L
.28235 .05784 L
.28235 .16187 L
s
1 .894 .882 r
.28235 .16187 m
.28235 .05811 L
.28261 .05811 L
.28261 .16187 L
F
.804 .522 .247 r
.28235 .16187 m
.28235 .05811 L
.28261 .05811 L
.28261 .16187 L
s
1 .894 .882 r
.28261 .16187 m
.28261 .05819 L
.28294 .05819 L
.28294 .16187 L
F
.804 .522 .247 r
.28261 .16187 m
.28261 .05819 L
.28294 .05819 L
.28294 .16187 L
s
1 .894 .882 r
.28294 .16187 m
.28294 .05831 L
.28331 .05831 L
.28331 .16187 L
F
.804 .522 .247 r
.28294 .16187 m
.28294 .05831 L
.28331 .05831 L
.28331 .16187 L
s
1 .894 .882 r
.28331 .16187 m
.28331 .05848 L
.28378 .05848 L
.28378 .16187 L
F
.804 .522 .247 r
.28331 .16187 m
.28331 .05848 L
.28378 .05848 L
.28378 .16187 L
s
1 .894 .882 r
.28378 .16187 m
.28378 .05858 L
.28406 .05858 L
.28406 .16187 L
F
.804 .522 .247 r
.28378 .16187 m
.28378 .05858 L
.28406 .05858 L
.28406 .16187 L
s
1 .894 .882 r
.28406 .16187 m
.28406 .05872 L
.28485 .05872 L
.28485 .16187 L
F
.804 .522 .247 r
.28406 .16187 m
.28406 .05872 L
.28485 .05872 L
.28485 .16187 L
s
1 .894 .882 r
.28485 .16187 m
.28485 .05909 L
.28546 .05909 L
.28546 .16187 L
F
.804 .522 .247 r
.28485 .16187 m
.28485 .05909 L
.28546 .05909 L
.28546 .16187 L
s
1 .894 .882 r
.28546 .16187 m
.28546 .05917 L
.28577 .05917 L
.28577 .16187 L
F
.804 .522 .247 r
.28546 .16187 m
.28546 .05917 L
.28577 .05917 L
.28577 .16187 L
s
1 .894 .882 r
.28577 .16187 m
.28577 .05933 L
.28604 .05933 L
.28604 .16187 L
F
.804 .522 .247 r
.28577 .16187 m
.28577 .05933 L
.28604 .05933 L
.28604 .16187 L
s
1 .894 .882 r
.28604 .16187 m
.28604 .05937 L
.28652 .05937 L
.28652 .16187 L
F
.804 .522 .247 r
.28604 .16187 m
.28604 .05937 L
.28652 .05937 L
.28652 .16187 L
s
1 .894 .882 r
.28652 .16187 m
.28652 .05951 L
.28681 .05951 L
.28681 .16187 L
F
.804 .522 .247 r
.28652 .16187 m
.28652 .05951 L
.28681 .05951 L
.28681 .16187 L
s
1 .894 .882 r
.28681 .16187 m
.28681 .05969 L
.28736 .05969 L
.28736 .16187 L
F
.804 .522 .247 r
.28681 .16187 m
.28681 .05969 L
.28736 .05969 L
.28736 .16187 L
s
1 .894 .882 r
.28736 .16187 m
.28736 .06002 L
.28811 .06002 L
.28811 .16187 L
F
.804 .522 .247 r
.28736 .16187 m
.28736 .06002 L
.28811 .06002 L
.28811 .16187 L
s
1 .894 .882 r
.28811 .16187 m
.28811 .06013 L
.28836 .06013 L
.28836 .16187 L
F
.804 .522 .247 r
.28811 .16187 m
.28811 .06013 L
.28836 .06013 L
.28836 .16187 L
s
1 .894 .882 r
.28836 .16187 m
.28836 .06014 L
.28866 .06014 L
.28866 .16187 L
F
.804 .522 .247 r
.28836 .16187 m
.28836 .06014 L
.28866 .06014 L
.28866 .16187 L
s
1 .894 .882 r
.28866 .16187 m
.28866 .06028 L
.2892 .06028 L
.2892 .16187 L
F
.804 .522 .247 r
.28866 .16187 m
.28866 .06028 L
.2892 .06028 L
.2892 .16187 L
s
1 .894 .882 r
.2892 .16187 m
.2892 .06045 L
.28953 .06045 L
.28953 .16187 L
F
.804 .522 .247 r
.2892 .16187 m
.2892 .06045 L
.28953 .06045 L
.28953 .16187 L
s
1 .894 .882 r
.28953 .16187 m
.28953 .06065 L
.29019 .06065 L
.29019 .16187 L
F
.804 .522 .247 r
.28953 .16187 m
.28953 .06065 L
.29019 .06065 L
.29019 .16187 L
s
1 .894 .882 r
.29019 .16187 m
.29019 .06085 L
.29049 .06085 L
.29049 .16187 L
F
.804 .522 .247 r
.29019 .16187 m
.29019 .06085 L
.29049 .06085 L
.29049 .16187 L
s
1 .894 .882 r
.29049 .16187 m
.29049 .06101 L
.29122 .06101 L
.29122 .16187 L
F
.804 .522 .247 r
.29049 .16187 m
.29049 .06101 L
.29122 .06101 L
.29122 .16187 L
s
1 .894 .882 r
.29122 .16187 m
.29122 .06127 L
.29173 .06127 L
.29173 .16187 L
F
.804 .522 .247 r
.29122 .16187 m
.29122 .06127 L
.29173 .06127 L
.29173 .16187 L
s
1 .894 .882 r
.29173 .16187 m
.29173 .06134 L
.29199 .06134 L
.29199 .16187 L
F
.804 .522 .247 r
.29173 .16187 m
.29173 .06134 L
.29199 .06134 L
.29199 .16187 L
s
1 .894 .882 r
.29199 .16187 m
.29199 .06147 L
.29243 .06147 L
.29243 .16187 L
F
.804 .522 .247 r
.29199 .16187 m
.29199 .06147 L
.29243 .06147 L
.29243 .16187 L
s
1 .894 .882 r
.29243 .16187 m
.29243 .06169 L
.29319 .06169 L
.29319 .16187 L
F
.804 .522 .247 r
.29243 .16187 m
.29243 .06169 L
.29319 .06169 L
.29319 .16187 L
s
1 .894 .882 r
.29319 .16187 m
.29319 .06191 L
.29368 .06191 L
.29368 .16187 L
F
.804 .522 .247 r
.29319 .16187 m
.29319 .06191 L
.29368 .06191 L
.29368 .16187 L
s
1 .894 .882 r
.29368 .16187 m
.29368 .06206 L
.29442 .06206 L
.29442 .16187 L
F
.804 .522 .247 r
.29368 .16187 m
.29368 .06206 L
.29442 .06206 L
.29442 .16187 L
s
1 .894 .882 r
.29442 .16187 m
.29442 .06228 L
.29473 .06228 L
.29473 .16187 L
F
.804 .522 .247 r
.29442 .16187 m
.29442 .06228 L
.29473 .06228 L
.29473 .16187 L
s
1 .894 .882 r
.29473 .16187 m
.29473 .06237 L
.29527 .06237 L
.29527 .16187 L
F
.804 .522 .247 r
.29473 .16187 m
.29473 .06237 L
.29527 .06237 L
.29527 .16187 L
s
1 .894 .882 r
.29527 .16187 m
.29527 .06263 L
.29572 .06263 L
.29572 .16187 L
F
.804 .522 .247 r
.29527 .16187 m
.29527 .06263 L
.29572 .06263 L
.29572 .16187 L
s
1 .894 .882 r
.29572 .16187 m
.29572 .06272 L
.29647 .06272 L
.29647 .16187 L
F
.804 .522 .247 r
.29572 .16187 m
.29572 .06272 L
.29647 .06272 L
.29647 .16187 L
s
1 .894 .882 r
.29647 .16187 m
.29647 .06308 L
.29698 .06308 L
.29698 .16187 L
F
.804 .522 .247 r
.29647 .16187 m
.29647 .06308 L
.29698 .06308 L
.29698 .16187 L
s
1 .894 .882 r
.29698 .16187 m
.29698 .06328 L
.29746 .06328 L
.29746 .16187 L
F
.804 .522 .247 r
.29698 .16187 m
.29698 .06328 L
.29746 .06328 L
.29746 .16187 L
s
1 .894 .882 r
.29746 .16187 m
.29746 .06341 L
.29788 .06341 L
.29788 .16187 L
F
.804 .522 .247 r
.29746 .16187 m
.29746 .06341 L
.29788 .06341 L
.29788 .16187 L
s
1 .894 .882 r
.29788 .16187 m
.29788 .06363 L
.2984 .06363 L
.2984 .16187 L
F
.804 .522 .247 r
.29788 .16187 m
.29788 .06363 L
.2984 .06363 L
.2984 .16187 L
s
1 .894 .882 r
.2984 .16187 m
.2984 .06374 L
.29886 .06374 L
.29886 .16187 L
F
.804 .522 .247 r
.2984 .16187 m
.2984 .06374 L
.29886 .06374 L
.29886 .16187 L
s
1 .894 .882 r
.29886 .16187 m
.29886 .06389 L
.29958 .06389 L
.29958 .16187 L
F
.804 .522 .247 r
.29886 .16187 m
.29886 .06389 L
.29958 .06389 L
.29958 .16187 L
s
1 .894 .882 r
.29958 .16187 m
.29958 .0642 L
.30007 .0642 L
.30007 .16187 L
F
.804 .522 .247 r
.29958 .16187 m
.29958 .0642 L
.30007 .0642 L
.30007 .16187 L
s
1 .894 .882 r
.30007 .16187 m
.30007 .06441 L
.30057 .06441 L
.30057 .16187 L
F
.804 .522 .247 r
.30007 .16187 m
.30007 .06441 L
.30057 .06441 L
.30057 .16187 L
s
1 .894 .882 r
.30057 .16187 m
.30057 .0645 L
.30098 .0645 L
.30098 .16187 L
F
.804 .522 .247 r
.30057 .16187 m
.30057 .0645 L
.30098 .0645 L
.30098 .16187 L
s
1 .894 .882 r
.30098 .16187 m
.30098 .06458 L
.30141 .06458 L
.30141 .16187 L
F
.804 .522 .247 r
.30098 .16187 m
.30098 .06458 L
.30141 .06458 L
.30141 .16187 L
s
1 .894 .882 r
.30141 .16187 m
.30141 .0648 L
.3018 .0648 L
.3018 .16187 L
F
.804 .522 .247 r
.30141 .16187 m
.30141 .0648 L
.3018 .0648 L
.3018 .16187 L
s
1 .894 .882 r
.3018 .16187 m
.3018 .06497 L
.30245 .06497 L
.30245 .16187 L
F
.804 .522 .247 r
.3018 .16187 m
.3018 .06497 L
.30245 .06497 L
.30245 .16187 L
s
1 .894 .882 r
.30245 .16187 m
.30245 .06519 L
.30281 .06519 L
.30281 .16187 L
F
.804 .522 .247 r
.30245 .16187 m
.30245 .06519 L
.30281 .06519 L
.30281 .16187 L
s
1 .894 .882 r
.30281 .16187 m
.30281 .06532 L
.30331 .06532 L
.30331 .16187 L
F
.804 .522 .247 r
.30281 .16187 m
.30281 .06532 L
.30331 .06532 L
.30331 .16187 L
s
1 .894 .882 r
.30331 .16187 m
.30331 .06558 L
.304 .06558 L
.304 .16187 L
F
.804 .522 .247 r
.30331 .16187 m
.30331 .06558 L
.304 .06558 L
.304 .16187 L
s
1 .894 .882 r
.304 .16187 m
.304 .06567 L
.30463 .06567 L
.30463 .16187 L
F
.804 .522 .247 r
.304 .16187 m
.304 .06567 L
.30463 .06567 L
.30463 .16187 L
s
1 .894 .882 r
.30463 .16187 m
.30463 .06593 L
.30536 .06593 L
.30536 .16187 L
F
.804 .522 .247 r
.30463 .16187 m
.30463 .06593 L
.30536 .06593 L
.30536 .16187 L
s
1 .894 .882 r
.30536 .16187 m
.30536 .06635 L
.30591 .06635 L
.30591 .16187 L
F
.804 .522 .247 r
.30536 .16187 m
.30536 .06635 L
.30591 .06635 L
.30591 .16187 L
s
1 .894 .882 r
.30591 .16187 m
.30591 .06637 L
.30634 .06637 L
.30634 .16187 L
F
.804 .522 .247 r
.30591 .16187 m
.30591 .06637 L
.30634 .06637 L
.30634 .16187 L
s
1 .894 .882 r
.30634 .16187 m
.30634 .0667 L
.30705 .0667 L
.30705 .16187 L
F
.804 .522 .247 r
.30634 .16187 m
.30634 .0667 L
.30705 .0667 L
.30705 .16187 L
s
1 .894 .882 r
.30705 .16187 m
.30705 .06695 L
.3077 .06695 L
.3077 .16187 L
F
.804 .522 .247 r
.30705 .16187 m
.30705 .06695 L
.3077 .06695 L
.3077 .16187 L
s
1 .894 .882 r
.3077 .16187 m
.3077 .06709 L
.30795 .06709 L
.30795 .16187 L
F
.804 .522 .247 r
.3077 .16187 m
.3077 .06709 L
.30795 .06709 L
.30795 .16187 L
s
1 .894 .882 r
.30795 .16187 m
.30795 .06726 L
.30875 .06726 L
.30875 .16187 L
F
.804 .522 .247 r
.30795 .16187 m
.30795 .06726 L
.30875 .06726 L
.30875 .16187 L
s
1 .894 .882 r
.30875 .16187 m
.30875 .06757 L
.30951 .06757 L
.30951 .16187 L
F
.804 .522 .247 r
.30875 .16187 m
.30875 .06757 L
.30951 .06757 L
.30951 .16187 L
s
1 .894 .882 r
.30951 .16187 m
.30951 .06769 L
.3099 .06769 L
.3099 .16187 L
F
.804 .522 .247 r
.30951 .16187 m
.30951 .06769 L
.3099 .06769 L
.3099 .16187 L
s
1 .894 .882 r
.3099 .16187 m
.3099 .06783 L
.31048 .06783 L
.31048 .16187 L
F
.804 .522 .247 r
.3099 .16187 m
.3099 .06783 L
.31048 .06783 L
.31048 .16187 L
s
1 .894 .882 r
.31048 .16187 m
.31048 .06824 L
.3111 .06824 L
.3111 .16187 L
F
.804 .522 .247 r
.31048 .16187 m
.31048 .06824 L
.3111 .06824 L
.3111 .16187 L
s
1 .894 .882 r
.3111 .16187 m
.3111 .0684 L
.31158 .0684 L
.31158 .16187 L
F
.804 .522 .247 r
.3111 .16187 m
.3111 .0684 L
.31158 .0684 L
.31158 .16187 L
s
1 .894 .882 r
.31158 .16187 m
.31158 .06859 L
.31231 .06859 L
.31231 .16187 L
F
.804 .522 .247 r
.31158 .16187 m
.31158 .06859 L
.31231 .06859 L
.31231 .16187 L
s
1 .894 .882 r
.31231 .16187 m
.31231 .06889 L
.31297 .06889 L
.31297 .16187 L
F
.804 .522 .247 r
.31231 .16187 m
.31231 .06889 L
.31297 .06889 L
.31297 .16187 L
s
1 .894 .882 r
.31297 .16187 m
.31297 .06898 L
.31336 .06898 L
.31336 .16187 L
F
.804 .522 .247 r
.31297 .16187 m
.31297 .06898 L
.31336 .06898 L
.31336 .16187 L
s
1 .894 .882 r
.31336 .16187 m
.31336 .06935 L
.31414 .06935 L
.31414 .16187 L
F
.804 .522 .247 r
.31336 .16187 m
.31336 .06935 L
.31414 .06935 L
.31414 .16187 L
s
1 .894 .882 r
.31414 .16187 m
.31414 .06963 L
.31471 .06963 L
.31471 .16187 L
F
.804 .522 .247 r
.31414 .16187 m
.31414 .06963 L
.31471 .06963 L
.31471 .16187 L
s
1 .894 .882 r
.31471 .16187 m
.31471 .06974 L
.31518 .06974 L
.31518 .16187 L
F
.804 .522 .247 r
.31471 .16187 m
.31471 .06974 L
.31518 .06974 L
.31518 .16187 L
s
1 .894 .882 r
.31518 .16187 m
.31518 .06997 L
.31598 .06997 L
.31598 .16187 L
F
.804 .522 .247 r
.31518 .16187 m
.31518 .06997 L
.31598 .06997 L
.31598 .16187 L
s
1 .894 .882 r
.31598 .16187 m
.31598 .07016 L
.31635 .07016 L
.31635 .16187 L
F
.804 .522 .247 r
.31598 .16187 m
.31598 .07016 L
.31635 .07016 L
.31635 .16187 L
s
1 .894 .882 r
.31635 .16187 m
.31635 .07031 L
.3168 .07031 L
.3168 .16187 L
F
.804 .522 .247 r
.31635 .16187 m
.31635 .07031 L
.3168 .07031 L
.3168 .16187 L
s
1 .894 .882 r
.3168 .16187 m
.3168 .07045 L
.31758 .07045 L
.31758 .16187 L
F
.804 .522 .247 r
.3168 .16187 m
.3168 .07045 L
.31758 .07045 L
.31758 .16187 L
s
1 .894 .882 r
.31758 .16187 m
.31758 .07083 L
.31794 .07083 L
.31794 .16187 L
F
.804 .522 .247 r
.31758 .16187 m
.31758 .07083 L
.31794 .07083 L
.31794 .16187 L
s
1 .894 .882 r
.31794 .16187 m
.31794 .07092 L
.31849 .07092 L
.31849 .16187 L
F
.804 .522 .247 r
.31794 .16187 m
.31794 .07092 L
.31849 .07092 L
.31849 .16187 L
s
1 .894 .882 r
.31849 .16187 m
.31849 .0711 L
.31902 .0711 L
.31902 .16187 L
F
.804 .522 .247 r
.31849 .16187 m
.31849 .0711 L
.31902 .0711 L
.31902 .16187 L
s
1 .894 .882 r
.31902 .16187 m
.31902 .07129 L
.31949 .07129 L
.31949 .16187 L
F
.804 .522 .247 r
.31902 .16187 m
.31902 .07129 L
.31949 .07129 L
.31949 .16187 L
s
1 .894 .882 r
.31949 .16187 m
.31949 .07166 L
.32021 .07166 L
.32021 .16187 L
F
.804 .522 .247 r
.31949 .16187 m
.31949 .07166 L
.32021 .07166 L
.32021 .16187 L
s
1 .894 .882 r
.32021 .16187 m
.32021 .07188 L
.32087 .07188 L
.32087 .16187 L
F
.804 .522 .247 r
.32021 .16187 m
.32021 .07188 L
.32087 .07188 L
.32087 .16187 L
s
1 .894 .882 r
.32087 .16187 m
.32087 .07209 L
.32155 .07209 L
.32155 .16187 L
F
.804 .522 .247 r
.32087 .16187 m
.32087 .07209 L
.32155 .07209 L
.32155 .16187 L
s
1 .894 .882 r
.32155 .16187 m
.32155 .0723 L
.32202 .0723 L
.32202 .16187 L
F
.804 .522 .247 r
.32155 .16187 m
.32155 .0723 L
.32202 .0723 L
.32202 .16187 L
s
1 .894 .882 r
.32202 .16187 m
.32202 .0725 L
.32275 .0725 L
.32275 .16187 L
F
.804 .522 .247 r
.32202 .16187 m
.32202 .0725 L
.32275 .0725 L
.32275 .16187 L
s
1 .894 .882 r
.32275 .16187 m
.32275 .07298 L
.32345 .07298 L
.32345 .16187 L
F
.804 .522 .247 r
.32275 .16187 m
.32275 .07298 L
.32345 .07298 L
.32345 .16187 L
s
1 .894 .882 r
.32345 .16187 m
.32345 .07305 L
.32399 .07305 L
.32399 .16187 L
F
.804 .522 .247 r
.32345 .16187 m
.32345 .07305 L
.32399 .07305 L
.32399 .16187 L
s
1 .894 .882 r
.32399 .16187 m
.32399 .07327 L
.32468 .07327 L
.32468 .16187 L
F
.804 .522 .247 r
.32399 .16187 m
.32399 .07327 L
.32468 .07327 L
.32468 .16187 L
s
1 .894 .882 r
.32468 .16187 m
.32468 .07352 L
.32503 .07352 L
.32503 .16187 L
F
.804 .522 .247 r
.32468 .16187 m
.32468 .07352 L
.32503 .07352 L
.32503 .16187 L
s
1 .894 .882 r
.32503 .16187 m
.32503 .07365 L
.3255 .07365 L
.3255 .16187 L
F
.804 .522 .247 r
.32503 .16187 m
.32503 .07365 L
.3255 .07365 L
.3255 .16187 L
s
1 .894 .882 r
.3255 .16187 m
.3255 .07399 L
.32611 .07399 L
.32611 .16187 L
F
.804 .522 .247 r
.3255 .16187 m
.3255 .07399 L
.32611 .07399 L
.32611 .16187 L
s
1 .894 .882 r
.32611 .16187 m
.32611 .07409 L
.32638 .07409 L
.32638 .16187 L
F
.804 .522 .247 r
.32611 .16187 m
.32611 .07409 L
.32638 .07409 L
.32638 .16187 L
s
1 .894 .882 r
.32638 .16187 m
.32638 .07424 L
.32716 .07424 L
.32716 .16187 L
F
.804 .522 .247 r
.32638 .16187 m
.32638 .07424 L
.32716 .07424 L
.32716 .16187 L
s
1 .894 .882 r
.32716 .16187 m
.32716 .07453 L
.32765 .07453 L
.32765 .16187 L
F
.804 .522 .247 r
.32716 .16187 m
.32716 .07453 L
.32765 .07453 L
.32765 .16187 L
s
1 .894 .882 r
.32765 .16187 m
.32765 .07472 L
.32793 .07472 L
.32793 .16187 L
F
.804 .522 .247 r
.32765 .16187 m
.32765 .07472 L
.32793 .07472 L
.32793 .16187 L
s
1 .894 .882 r
.32793 .16187 m
.32793 .07475 L
.32854 .07475 L
.32854 .16187 L
F
.804 .522 .247 r
.32793 .16187 m
.32793 .07475 L
.32854 .07475 L
.32854 .16187 L
s
1 .894 .882 r
.32854 .16187 m
.32854 .07524 L
.32932 .07524 L
.32932 .16187 L
F
.804 .522 .247 r
.32854 .16187 m
.32854 .07524 L
.32932 .07524 L
.32932 .16187 L
s
1 .894 .882 r
.32932 .16187 m
.32932 .07531 L
.32968 .07531 L
.32968 .16187 L
F
.804 .522 .247 r
.32932 .16187 m
.32932 .07531 L
.32968 .07531 L
.32968 .16187 L
s
1 .894 .882 r
.32968 .16187 m
.32968 .07557 L
.33033 .07557 L
.33033 .16187 L
F
.804 .522 .247 r
.32968 .16187 m
.32968 .07557 L
.33033 .07557 L
.33033 .16187 L
s
1 .894 .882 r
.33033 .16187 m
.33033 .07592 L
.33096 .07592 L
.33096 .16187 L
F
.804 .522 .247 r
.33033 .16187 m
.33033 .07592 L
.33096 .07592 L
.33096 .16187 L
s
1 .894 .882 r
.33096 .16187 m
.33096 .07594 L
.33163 .07594 L
.33163 .16187 L
F
.804 .522 .247 r
.33096 .16187 m
.33096 .07594 L
.33163 .07594 L
.33163 .16187 L
s
1 .894 .882 r
.33163 .16187 m
.33163 .07642 L
.33225 .07642 L
.33225 .16187 L
F
.804 .522 .247 r
.33163 .16187 m
.33163 .07642 L
.33225 .07642 L
.33225 .16187 L
s
1 .894 .882 r
.33225 .16187 m
.33225 .07651 L
.3326 .07651 L
.3326 .16187 L
F
.804 .522 .247 r
.33225 .16187 m
.33225 .07651 L
.3326 .07651 L
.3326 .16187 L
s
1 .894 .882 r
.3326 .16187 m
.3326 .07672 L
.333 .07672 L
.333 .16187 L
F
.804 .522 .247 r
.3326 .16187 m
.3326 .07672 L
.333 .07672 L
.333 .16187 L
s
1 .894 .882 r
.333 .16187 m
.333 .07683 L
.33376 .07683 L
.33376 .16187 L
F
.804 .522 .247 r
.333 .16187 m
.333 .07683 L
.33376 .07683 L
.33376 .16187 L
s
1 .894 .882 r
.33376 .16187 m
.33376 .07715 L
.33453 .07715 L
.33453 .16187 L
F
.804 .522 .247 r
.33376 .16187 m
.33376 .07715 L
.33453 .07715 L
.33453 .16187 L
s
1 .894 .882 r
.33453 .16187 m
.33453 .07756 L
.33501 .07756 L
.33501 .16187 L
F
.804 .522 .247 r
.33453 .16187 m
.33453 .07756 L
.33501 .07756 L
.33501 .16187 L
s
1 .894 .882 r
.33501 .16187 m
.33501 .07771 L
.33575 .07771 L
.33575 .16187 L
F
.804 .522 .247 r
.33501 .16187 m
.33501 .07771 L
.33575 .07771 L
.33575 .16187 L
s
1 .894 .882 r
.33575 .16187 m
.33575 .07786 L
.33602 .07786 L
.33602 .16187 L
F
.804 .522 .247 r
.33575 .16187 m
.33575 .07786 L
.33602 .07786 L
.33602 .16187 L
s
1 .894 .882 r
.33602 .16187 m
.33602 .07801 L
.33633 .07801 L
.33633 .16187 L
F
.804 .522 .247 r
.33602 .16187 m
.33602 .07801 L
.33633 .07801 L
.33633 .16187 L
s
1 .894 .882 r
.33633 .16187 m
.33633 .07828 L
.33708 .07828 L
.33708 .16187 L
F
.804 .522 .247 r
.33633 .16187 m
.33633 .07828 L
.33708 .07828 L
.33708 .16187 L
s
1 .894 .882 r
.33708 .16187 m
.33708 .07842 L
.33737 .07842 L
.33737 .16187 L
F
.804 .522 .247 r
.33708 .16187 m
.33708 .07842 L
.33737 .07842 L
.33737 .16187 L
s
1 .894 .882 r
.33737 .16187 m
.33737 .07869 L
.33809 .07869 L
.33809 .16187 L
F
.804 .522 .247 r
.33737 .16187 m
.33737 .07869 L
.33809 .07869 L
.33809 .16187 L
s
1 .894 .882 r
.33809 .16187 m
.33809 .07882 L
.33875 .07882 L
.33875 .16187 L
F
.804 .522 .247 r
.33809 .16187 m
.33809 .07882 L
.33875 .07882 L
.33875 .16187 L
s
1 .894 .882 r
.33875 .16187 m
.33875 .0792 L
.33912 .0792 L
.33912 .16187 L
F
.804 .522 .247 r
.33875 .16187 m
.33875 .0792 L
.33912 .0792 L
.33912 .16187 L
s
1 .894 .882 r
.33912 .16187 m
.33912 .07929 L
.33938 .07929 L
.33938 .16187 L
F
.804 .522 .247 r
.33912 .16187 m
.33912 .07929 L
.33938 .07929 L
.33938 .16187 L
s
1 .894 .882 r
.33938 .16187 m
.33938 .0794 L
.34014 .0794 L
.34014 .16187 L
F
.804 .522 .247 r
.33938 .16187 m
.33938 .0794 L
.34014 .0794 L
.34014 .16187 L
s
1 .894 .882 r
.34014 .16187 m
.34014 .07973 L
.34055 .07973 L
.34055 .16187 L
F
.804 .522 .247 r
.34014 .16187 m
.34014 .07973 L
.34055 .07973 L
.34055 .16187 L
s
1 .894 .882 r
.34055 .16187 m
.34055 .07994 L
.34088 .07994 L
.34088 .16187 L
F
.804 .522 .247 r
.34055 .16187 m
.34055 .07994 L
.34088 .07994 L
.34088 .16187 L
s
1 .894 .882 r
.34088 .16187 m
.34088 .08005 L
.34134 .08005 L
.34134 .16187 L
F
.804 .522 .247 r
.34088 .16187 m
.34088 .08005 L
.34134 .08005 L
.34134 .16187 L
s
1 .894 .882 r
.34134 .16187 m
.34134 .08025 L
.34212 .08025 L
.34212 .16187 L
F
.804 .522 .247 r
.34134 .16187 m
.34134 .08025 L
.34212 .08025 L
.34212 .16187 L
s
1 .894 .882 r
.34212 .16187 m
.34212 .0805 L
.34242 .0805 L
.34242 .16187 L
F
.804 .522 .247 r
.34212 .16187 m
.34212 .0805 L
.34242 .0805 L
.34242 .16187 L
s
1 .894 .882 r
.34242 .16187 m
.34242 .08065 L
.34291 .08065 L
.34291 .16187 L
F
.804 .522 .247 r
.34242 .16187 m
.34242 .08065 L
.34291 .08065 L
.34291 .16187 L
s
1 .894 .882 r
.34291 .16187 m
.34291 .08094 L
.34354 .08094 L
.34354 .16187 L
F
.804 .522 .247 r
.34291 .16187 m
.34291 .08094 L
.34354 .08094 L
.34354 .16187 L
s
1 .894 .882 r
.34354 .16187 m
.34354 .0811 L
.3439 .0811 L
.3439 .16187 L
F
.804 .522 .247 r
.34354 .16187 m
.34354 .0811 L
.3439 .0811 L
.3439 .16187 L
s
1 .894 .882 r
.3439 .16187 m
.3439 .08128 L
.34438 .08128 L
.34438 .16187 L
F
.804 .522 .247 r
.3439 .16187 m
.3439 .08128 L
.34438 .08128 L
.34438 .16187 L
s
1 .894 .882 r
.34438 .16187 m
.34438 .08154 L
.34476 .08154 L
.34476 .16187 L
F
.804 .522 .247 r
.34438 .16187 m
.34438 .08154 L
.34476 .08154 L
.34476 .16187 L
s
1 .894 .882 r
.34476 .16187 m
.34476 .08171 L
.34523 .08171 L
.34523 .16187 L
F
.804 .522 .247 r
.34476 .16187 m
.34476 .08171 L
.34523 .08171 L
.34523 .16187 L
s
1 .894 .882 r
.34523 .16187 m
.34523 .08176 L
.34564 .08176 L
.34564 .16187 L
F
.804 .522 .247 r
.34523 .16187 m
.34523 .08176 L
.34564 .08176 L
.34564 .16187 L
s
1 .894 .882 r
.34564 .16187 m
.34564 .08195 L
.34615 .08195 L
.34615 .16187 L
F
.804 .522 .247 r
.34564 .16187 m
.34564 .08195 L
.34615 .08195 L
.34615 .16187 L
s
1 .894 .882 r
.34615 .16187 m
.34615 .08242 L
.34687 .08242 L
.34687 .16187 L
F
.804 .522 .247 r
.34615 .16187 m
.34615 .08242 L
.34687 .08242 L
.34687 .16187 L
s
1 .894 .882 r
.34687 .16187 m
.34687 .0825 L
.34741 .0825 L
.34741 .16187 L
F
.804 .522 .247 r
.34687 .16187 m
.34687 .0825 L
.34741 .0825 L
.34741 .16187 L
s
1 .894 .882 r
.34741 .16187 m
.34741 .08267 L
.34779 .08267 L
.34779 .16187 L
F
.804 .522 .247 r
.34741 .16187 m
.34741 .08267 L
.34779 .08267 L
.34779 .16187 L
s
1 .894 .882 r
.34779 .16187 m
.34779 .08298 L
.34823 .08298 L
.34823 .16187 L
F
.804 .522 .247 r
.34779 .16187 m
.34779 .08298 L
.34823 .08298 L
.34823 .16187 L
s
1 .894 .882 r
.34823 .16187 m
.34823 .08312 L
.349 .08312 L
.349 .16187 L
F
.804 .522 .247 r
.34823 .16187 m
.34823 .08312 L
.349 .08312 L
.349 .16187 L
s
1 .894 .882 r
.349 .16187 m
.349 .08335 L
.3495 .08335 L
.3495 .16187 L
F
.804 .522 .247 r
.349 .16187 m
.349 .08335 L
.3495 .08335 L
.3495 .16187 L
s
1 .894 .882 r
.3495 .16187 m
.3495 .08364 L
.34997 .08364 L
.34997 .16187 L
F
.804 .522 .247 r
.3495 .16187 m
.3495 .08364 L
.34997 .08364 L
.34997 .16187 L
s
1 .894 .882 r
.34997 .16187 m
.34997 .08394 L
.35055 .08394 L
.35055 .16187 L
F
.804 .522 .247 r
.34997 .16187 m
.34997 .08394 L
.35055 .08394 L
.35055 .16187 L
s
1 .894 .882 r
.35055 .16187 m
.35055 .08415 L
.3512 .08415 L
.3512 .16187 L
F
.804 .522 .247 r
.35055 .16187 m
.35055 .08415 L
.3512 .08415 L
.3512 .16187 L
s
1 .894 .882 r
.3512 .16187 m
.3512 .08437 L
.35167 .08437 L
.35167 .16187 L
F
.804 .522 .247 r
.3512 .16187 m
.3512 .08437 L
.35167 .08437 L
.35167 .16187 L
s
1 .894 .882 r
.35167 .16187 m
.35167 .08453 L
.35219 .08453 L
.35219 .16187 L
F
.804 .522 .247 r
.35167 .16187 m
.35167 .08453 L
.35219 .08453 L
.35219 .16187 L
s
1 .894 .882 r
.35219 .16187 m
.35219 .08475 L
.3526 .08475 L
.3526 .16187 L
F
.804 .522 .247 r
.35219 .16187 m
.35219 .08475 L
.3526 .08475 L
.3526 .16187 L
s
1 .894 .882 r
.3526 .16187 m
.3526 .08503 L
.35316 .08503 L
.35316 .16187 L
F
.804 .522 .247 r
.3526 .16187 m
.3526 .08503 L
.35316 .08503 L
.35316 .16187 L
s
1 .894 .882 r
.35316 .16187 m
.35316 .08522 L
.35342 .08522 L
.35342 .16187 L
F
.804 .522 .247 r
.35316 .16187 m
.35316 .08522 L
.35342 .08522 L
.35342 .16187 L
s
1 .894 .882 r
.35342 .16187 m
.35342 .08544 L
.35396 .08544 L
.35396 .16187 L
F
.804 .522 .247 r
.35342 .16187 m
.35342 .08544 L
.35396 .08544 L
.35396 .16187 L
s
1 .894 .882 r
.35396 .16187 m
.35396 .08545 L
.35432 .08545 L
.35432 .16187 L
F
.804 .522 .247 r
.35396 .16187 m
.35396 .08545 L
.35432 .08545 L
.35432 .16187 L
s
1 .894 .882 r
.35432 .16187 m
.35432 .08566 L
.35464 .08566 L
.35464 .16187 L
F
.804 .522 .247 r
.35432 .16187 m
.35432 .08566 L
.35464 .08566 L
.35464 .16187 L
s
1 .894 .882 r
.35464 .16187 m
.35464 .08581 L
.35507 .08581 L
.35507 .16187 L
F
.804 .522 .247 r
.35464 .16187 m
.35464 .08581 L
.35507 .08581 L
.35507 .16187 L
s
1 .894 .882 r
.35507 .16187 m
.35507 .08604 L
.35549 .08604 L
.35549 .16187 L
F
.804 .522 .247 r
.35507 .16187 m
.35507 .08604 L
.35549 .08604 L
.35549 .16187 L
s
1 .894 .882 r
.35549 .16187 m
.35549 .08629 L
.35618 .08629 L
.35618 .16187 L
F
.804 .522 .247 r
.35549 .16187 m
.35549 .08629 L
.35618 .08629 L
.35618 .16187 L
s
1 .894 .882 r
.35618 .16187 m
.35618 .08656 L
.35693 .08656 L
.35693 .16187 L
F
.804 .522 .247 r
.35618 .16187 m
.35618 .08656 L
.35693 .08656 L
.35693 .16187 L
s
1 .894 .882 r
.35693 .16187 m
.35693 .08694 L
.35769 .08694 L
.35769 .16187 L
F
.804 .522 .247 r
.35693 .16187 m
.35693 .08694 L
.35769 .08694 L
.35769 .16187 L
s
1 .894 .882 r
.35769 .16187 m
.35769 .08712 L
.35794 .08712 L
.35794 .16187 L
F
.804 .522 .247 r
.35769 .16187 m
.35769 .08712 L
.35794 .08712 L
.35794 .16187 L
s
1 .894 .882 r
.35794 .16187 m
.35794 .08726 L
.35837 .08726 L
.35837 .16187 L
F
.804 .522 .247 r
.35794 .16187 m
.35794 .08726 L
.35837 .08726 L
.35837 .16187 L
s
1 .894 .882 r
.35837 .16187 m
.35837 .08742 L
.35864 .08742 L
.35864 .16187 L
F
.804 .522 .247 r
.35837 .16187 m
.35837 .08742 L
.35864 .08742 L
.35864 .16187 L
s
1 .894 .882 r
.35864 .16187 m
.35864 .08755 L
.35911 .08755 L
.35911 .16187 L
F
.804 .522 .247 r
.35864 .16187 m
.35864 .08755 L
.35911 .08755 L
.35911 .16187 L
s
1 .894 .882 r
.35911 .16187 m
.35911 .08784 L
.35978 .08784 L
.35978 .16187 L
F
.804 .522 .247 r
.35911 .16187 m
.35911 .08784 L
.35978 .08784 L
.35978 .16187 L
s
1 .894 .882 r
.35978 .16187 m
.35978 .08821 L
.36057 .08821 L
.36057 .16187 L
F
.804 .522 .247 r
.35978 .16187 m
.35978 .08821 L
.36057 .08821 L
.36057 .16187 L
s
1 .894 .882 r
.36057 .16187 m
.36057 .08834 L
.36088 .08834 L
.36088 .16187 L
F
.804 .522 .247 r
.36057 .16187 m
.36057 .08834 L
.36088 .08834 L
.36088 .16187 L
s
1 .894 .882 r
.36088 .16187 m
.36088 .08857 L
.36166 .08857 L
.36166 .16187 L
F
.804 .522 .247 r
.36088 .16187 m
.36088 .08857 L
.36166 .08857 L
.36166 .16187 L
s
1 .894 .882 r
.36166 .16187 m
.36166 .08881 L
.3621 .08881 L
.3621 .16187 L
F
.804 .522 .247 r
.36166 .16187 m
.36166 .08881 L
.3621 .08881 L
.3621 .16187 L
s
1 .894 .882 r
.3621 .16187 m
.3621 .08916 L
.36256 .08916 L
.36256 .16187 L
F
.804 .522 .247 r
.3621 .16187 m
.3621 .08916 L
.36256 .08916 L
.36256 .16187 L
s
1 .894 .882 r
.36256 .16187 m
.36256 .08932 L
.36302 .08932 L
.36302 .16187 L
F
.804 .522 .247 r
.36256 .16187 m
.36256 .08932 L
.36302 .08932 L
.36302 .16187 L
s
1 .894 .882 r
.36302 .16187 m
.36302 .0896 L
.36357 .0896 L
.36357 .16187 L
F
.804 .522 .247 r
.36302 .16187 m
.36302 .0896 L
.36357 .0896 L
.36357 .16187 L
s
1 .894 .882 r
.36357 .16187 m
.36357 .0899 L
.36431 .0899 L
.36431 .16187 L
F
.804 .522 .247 r
.36357 .16187 m
.36357 .0899 L
.36431 .0899 L
.36431 .16187 L
s
1 .894 .882 r
.36431 .16187 m
.36431 .09003 L
.36459 .09003 L
.36459 .16187 L
F
.804 .522 .247 r
.36431 .16187 m
.36431 .09003 L
.36459 .09003 L
.36459 .16187 L
s
1 .894 .882 r
.36459 .16187 m
.36459 .09039 L
.3653 .09039 L
.3653 .16187 L
F
.804 .522 .247 r
.36459 .16187 m
.36459 .09039 L
.3653 .09039 L
.3653 .16187 L
s
1 .894 .882 r
.3653 .16187 m
.3653 .09061 L
.36583 .09061 L
.36583 .16187 L
F
.804 .522 .247 r
.3653 .16187 m
.3653 .09061 L
.36583 .09061 L
.36583 .16187 L
s
1 .894 .882 r
.36583 .16187 m
.36583 .0908 L
.36627 .0908 L
.36627 .16187 L
F
.804 .522 .247 r
.36583 .16187 m
.36583 .0908 L
.36627 .0908 L
.36627 .16187 L
s
1 .894 .882 r
.36627 .16187 m
.36627 .09101 L
.367 .09101 L
.367 .16187 L
F
.804 .522 .247 r
.36627 .16187 m
.36627 .09101 L
.367 .09101 L
.367 .16187 L
s
1 .894 .882 r
.367 .16187 m
.367 .09132 L
.36763 .09132 L
.36763 .16187 L
F
.804 .522 .247 r
.367 .16187 m
.367 .09132 L
.36763 .09132 L
.36763 .16187 L
s
1 .894 .882 r
.36763 .16187 m
.36763 .09151 L
.36797 .09151 L
.36797 .16187 L
F
.804 .522 .247 r
.36763 .16187 m
.36763 .09151 L
.36797 .09151 L
.36797 .16187 L
s
1 .894 .882 r
.36797 .16187 m
.36797 .09161 L
.36824 .09161 L
.36824 .16187 L
F
.804 .522 .247 r
.36797 .16187 m
.36797 .09161 L
.36824 .09161 L
.36824 .16187 L
s
1 .894 .882 r
.36824 .16187 m
.36824 .09182 L
.36852 .09182 L
.36852 .16187 L
F
.804 .522 .247 r
.36824 .16187 m
.36824 .09182 L
.36852 .09182 L
.36852 .16187 L
s
1 .894 .882 r
.36852 .16187 m
.36852 .09186 L
.36921 .09186 L
.36921 .16187 L
F
.804 .522 .247 r
.36852 .16187 m
.36852 .09186 L
.36921 .09186 L
.36921 .16187 L
s
1 .894 .882 r
.36921 .16187 m
.36921 .09228 L
.3696 .09228 L
.3696 .16187 L
F
.804 .522 .247 r
.36921 .16187 m
.36921 .09228 L
.3696 .09228 L
.3696 .16187 L
s
1 .894 .882 r
.3696 .16187 m
.3696 .09238 L
.36985 .09238 L
.36985 .16187 L
F
.804 .522 .247 r
.3696 .16187 m
.3696 .09238 L
.36985 .09238 L
.36985 .16187 L
s
1 .894 .882 r
.36985 .16187 m
.36985 .09256 L
.37051 .09256 L
.37051 .16187 L
F
.804 .522 .247 r
.36985 .16187 m
.36985 .09256 L
.37051 .09256 L
.37051 .16187 L
s
1 .894 .882 r
.37051 .16187 m
.37051 .09288 L
.37118 .09288 L
.37118 .16187 L
F
.804 .522 .247 r
.37051 .16187 m
.37051 .09288 L
.37118 .09288 L
.37118 .16187 L
s
1 .894 .882 r
.37118 .16187 m
.37118 .09317 L
.3719 .09317 L
.3719 .16187 L
F
.804 .522 .247 r
.37118 .16187 m
.37118 .09317 L
.3719 .09317 L
.3719 .16187 L
s
1 .894 .882 r
.3719 .16187 m
.3719 .09335 L
.3723 .09335 L
.3723 .16187 L
F
.804 .522 .247 r
.3719 .16187 m
.3719 .09335 L
.3723 .09335 L
.3723 .16187 L
s
1 .894 .882 r
.3723 .16187 m
.3723 .09375 L
.37297 .09375 L
.37297 .16187 L
F
.804 .522 .247 r
.3723 .16187 m
.3723 .09375 L
.37297 .09375 L
.37297 .16187 L
s
1 .894 .882 r
.37297 .16187 m
.37297 .09391 L
.37357 .09391 L
.37357 .16187 L
F
.804 .522 .247 r
.37297 .16187 m
.37297 .09391 L
.37357 .09391 L
.37357 .16187 L
s
1 .894 .882 r
.37357 .16187 m
.37357 .09413 L
.37432 .09413 L
.37432 .16187 L
F
.804 .522 .247 r
.37357 .16187 m
.37357 .09413 L
.37432 .09413 L
.37432 .16187 L
s
1 .894 .882 r
.37432 .16187 m
.37432 .09476 L
.37508 .09476 L
.37508 .16187 L
F
.804 .522 .247 r
.37432 .16187 m
.37432 .09476 L
.37508 .09476 L
.37508 .16187 L
s
1 .894 .882 r
.37508 .16187 m
.37508 .09496 L
.37553 .09496 L
.37553 .16187 L
F
.804 .522 .247 r
.37508 .16187 m
.37508 .09496 L
.37553 .09496 L
.37553 .16187 L
s
1 .894 .882 r
.37553 .16187 m
.37553 .0951 L
.37592 .0951 L
.37592 .16187 L
F
.804 .522 .247 r
.37553 .16187 m
.37553 .0951 L
.37592 .0951 L
.37592 .16187 L
s
1 .894 .882 r
.37592 .16187 m
.37592 .09521 L
.37636 .09521 L
.37636 .16187 L
F
.804 .522 .247 r
.37592 .16187 m
.37592 .09521 L
.37636 .09521 L
.37636 .16187 L
s
1 .894 .882 r
.37636 .16187 m
.37636 .09538 L
.37663 .09538 L
.37663 .16187 L
F
.804 .522 .247 r
.37636 .16187 m
.37636 .09538 L
.37663 .09538 L
.37663 .16187 L
s
1 .894 .882 r
.37663 .16187 m
.37663 .09554 L
.37703 .09554 L
.37703 .16187 L
F
.804 .522 .247 r
.37663 .16187 m
.37663 .09554 L
.37703 .09554 L
.37703 .16187 L
s
1 .894 .882 r
.37703 .16187 m
.37703 .09582 L
.37752 .09582 L
.37752 .16187 L
F
.804 .522 .247 r
.37703 .16187 m
.37703 .09582 L
.37752 .09582 L
.37752 .16187 L
s
1 .894 .882 r
.37752 .16187 m
.37752 .096 L
.37824 .096 L
.37824 .16187 L
F
.804 .522 .247 r
.37752 .16187 m
.37752 .096 L
.37824 .096 L
.37824 .16187 L
s
1 .894 .882 r
.37824 .16187 m
.37824 .09628 L
.37887 .09628 L
.37887 .16187 L
F
.804 .522 .247 r
.37824 .16187 m
.37824 .09628 L
.37887 .09628 L
.37887 .16187 L
s
1 .894 .882 r
.37887 .16187 m
.37887 .09668 L
.37936 .09668 L
.37936 .16187 L
F
.804 .522 .247 r
.37887 .16187 m
.37887 .09668 L
.37936 .09668 L
.37936 .16187 L
s
1 .894 .882 r
.37936 .16187 m
.37936 .09675 L
.38002 .09675 L
.38002 .16187 L
F
.804 .522 .247 r
.37936 .16187 m
.37936 .09675 L
.38002 .09675 L
.38002 .16187 L
s
1 .894 .882 r
.38002 .16187 m
.38002 .09728 L
.38063 .09728 L
.38063 .16187 L
F
.804 .522 .247 r
.38002 .16187 m
.38002 .09728 L
.38063 .09728 L
.38063 .16187 L
s
1 .894 .882 r
.38063 .16187 m
.38063 .0976 L
.38125 .0976 L
.38125 .16187 L
F
.804 .522 .247 r
.38063 .16187 m
.38063 .0976 L
.38125 .0976 L
.38125 .16187 L
s
1 .894 .882 r
.38125 .16187 m
.38125 .09778 L
.3817 .09778 L
.3817 .16187 L
F
.804 .522 .247 r
.38125 .16187 m
.38125 .09778 L
.3817 .09778 L
.3817 .16187 L
s
1 .894 .882 r
.3817 .16187 m
.3817 .09816 L
.38247 .09816 L
.38247 .16187 L
F
.804 .522 .247 r
.3817 .16187 m
.3817 .09816 L
.38247 .09816 L
.38247 .16187 L
s
1 .894 .882 r
.38247 .16187 m
.38247 .0984 L
.38295 .0984 L
.38295 .16187 L
F
.804 .522 .247 r
.38247 .16187 m
.38247 .0984 L
.38295 .0984 L
.38295 .16187 L
s
1 .894 .882 r
.38295 .16187 m
.38295 .0985 L
.38355 .0985 L
.38355 .16187 L
F
.804 .522 .247 r
.38295 .16187 m
.38295 .0985 L
.38355 .0985 L
.38355 .16187 L
s
1 .894 .882 r
.38355 .16187 m
.38355 .09877 L
.38414 .09877 L
.38414 .16187 L
F
.804 .522 .247 r
.38355 .16187 m
.38355 .09877 L
.38414 .09877 L
.38414 .16187 L
s
1 .894 .882 r
.38414 .16187 m
.38414 .09903 L
.38449 .09903 L
.38449 .16187 L
F
.804 .522 .247 r
.38414 .16187 m
.38414 .09903 L
.38449 .09903 L
.38449 .16187 L
s
1 .894 .882 r
.38449 .16187 m
.38449 .09926 L
.38505 .09926 L
.38505 .16187 L
F
.804 .522 .247 r
.38449 .16187 m
.38449 .09926 L
.38505 .09926 L
.38505 .16187 L
s
1 .894 .882 r
.38505 .16187 m
.38505 .09945 L
.3855 .09945 L
.3855 .16187 L
F
.804 .522 .247 r
.38505 .16187 m
.38505 .09945 L
.3855 .09945 L
.3855 .16187 L
s
1 .894 .882 r
.3855 .16187 m
.3855 .09979 L
.38623 .09979 L
.38623 .16187 L
F
.804 .522 .247 r
.3855 .16187 m
.3855 .09979 L
.38623 .09979 L
.38623 .16187 L
s
1 .894 .882 r
.38623 .16187 m
.38623 .09997 L
.38679 .09997 L
.38679 .16187 L
F
.804 .522 .247 r
.38623 .16187 m
.38623 .09997 L
.38679 .09997 L
.38679 .16187 L
s
1 .894 .882 r
.38679 .16187 m
.38679 .10033 L
.3874 .10033 L
.3874 .16187 L
F
.804 .522 .247 r
.38679 .16187 m
.38679 .10033 L
.3874 .10033 L
.3874 .16187 L
s
1 .894 .882 r
.3874 .16187 m
.3874 .10059 L
.3879 .10059 L
.3879 .16187 L
F
.804 .522 .247 r
.3874 .16187 m
.3874 .10059 L
.3879 .10059 L
.3879 .16187 L
s
1 .894 .882 r
.3879 .16187 m
.3879 .1009 L
.38842 .1009 L
.38842 .16187 L
F
.804 .522 .247 r
.3879 .16187 m
.3879 .1009 L
.38842 .1009 L
.38842 .16187 L
s
1 .894 .882 r
.38842 .16187 m
.38842 .10107 L
.38883 .10107 L
.38883 .16187 L
F
.804 .522 .247 r
.38842 .16187 m
.38842 .10107 L
.38883 .10107 L
.38883 .16187 L
s
1 .894 .882 r
.38883 .16187 m
.38883 .10122 L
.38925 .10122 L
.38925 .16187 L
F
.804 .522 .247 r
.38883 .16187 m
.38883 .10122 L
.38925 .10122 L
.38925 .16187 L
s
1 .894 .882 r
.38925 .16187 m
.38925 .10144 L
.38972 .10144 L
.38972 .16187 L
F
.804 .522 .247 r
.38925 .16187 m
.38925 .10144 L
.38972 .10144 L
.38972 .16187 L
s
1 .894 .882 r
.38972 .16187 m
.38972 .10167 L
.39007 .10167 L
.39007 .16187 L
F
.804 .522 .247 r
.38972 .16187 m
.38972 .10167 L
.39007 .10167 L
.39007 .16187 L
s
1 .894 .882 r
.39007 .16187 m
.39007 .10205 L
.3908 .10205 L
.3908 .16187 L
F
.804 .522 .247 r
.39007 .16187 m
.39007 .10205 L
.3908 .10205 L
.3908 .16187 L
s
1 .894 .882 r
.3908 .16187 m
.3908 .10233 L
.39132 .10233 L
.39132 .16187 L
F
.804 .522 .247 r
.3908 .16187 m
.3908 .10233 L
.39132 .10233 L
.39132 .16187 L
s
1 .894 .882 r
.39132 .16187 m
.39132 .1024 L
.39196 .1024 L
.39196 .16187 L
F
.804 .522 .247 r
.39132 .16187 m
.39132 .1024 L
.39196 .1024 L
.39196 .16187 L
s
1 .894 .882 r
.39196 .16187 m
.39196 .1029 L
.39263 .1029 L
.39263 .16187 L
F
.804 .522 .247 r
.39196 .16187 m
.39196 .1029 L
.39263 .1029 L
.39263 .16187 L
s
1 .894 .882 r
.39263 .16187 m
.39263 .10311 L
.39294 .10311 L
.39294 .16187 L
F
.804 .522 .247 r
.39263 .16187 m
.39263 .10311 L
.39294 .10311 L
.39294 .16187 L
s
1 .894 .882 r
.39294 .16187 m
.39294 .10317 L
.39365 .10317 L
.39365 .16187 L
F
.804 .522 .247 r
.39294 .16187 m
.39294 .10317 L
.39365 .10317 L
.39365 .16187 L
s
1 .894 .882 r
.39365 .16187 m
.39365 .1035 L
.39392 .1035 L
.39392 .16187 L
F
.804 .522 .247 r
.39365 .16187 m
.39365 .1035 L
.39392 .1035 L
.39392 .16187 L
s
1 .894 .882 r
.39392 .16187 m
.39392 .10383 L
.39438 .10383 L
.39438 .16187 L
F
.804 .522 .247 r
.39392 .16187 m
.39392 .10383 L
.39438 .10383 L
.39438 .16187 L
s
1 .894 .882 r
.39438 .16187 m
.39438 .10398 L
.39472 .10398 L
.39472 .16187 L
F
.804 .522 .247 r
.39438 .16187 m
.39438 .10398 L
.39472 .10398 L
.39472 .16187 L
s
1 .894 .882 r
.39472 .16187 m
.39472 .10403 L
.3952 .10403 L
.3952 .16187 L
F
.804 .522 .247 r
.39472 .16187 m
.39472 .10403 L
.3952 .10403 L
.3952 .16187 L
s
1 .894 .882 r
.3952 .16187 m
.3952 .10443 L
.39567 .10443 L
.39567 .16187 L
F
.804 .522 .247 r
.3952 .16187 m
.3952 .10443 L
.39567 .10443 L
.39567 .16187 L
s
1 .894 .882 r
.39567 .16187 m
.39567 .10469 L
.39635 .10469 L
.39635 .16187 L
F
.804 .522 .247 r
.39567 .16187 m
.39567 .10469 L
.39635 .10469 L
.39635 .16187 L
s
1 .894 .882 r
.39635 .16187 m
.39635 .10499 L
.39715 .10499 L
.39715 .16187 L
F
.804 .522 .247 r
.39635 .16187 m
.39635 .10499 L
.39715 .10499 L
.39715 .16187 L
s
1 .894 .882 r
.39715 .16187 m
.39715 .1054 L
.39788 .1054 L
.39788 .16187 L
F
.804 .522 .247 r
.39715 .16187 m
.39715 .1054 L
.39788 .1054 L
.39788 .16187 L
s
1 .894 .882 r
.39788 .16187 m
.39788 .1056 L
.39814 .1056 L
.39814 .16187 L
F
.804 .522 .247 r
.39788 .16187 m
.39788 .1056 L
.39814 .1056 L
.39814 .16187 L
s
1 .894 .882 r
.39814 .16187 m
.39814 .10572 L
.3989 .10572 L
.3989 .16187 L
F
.804 .522 .247 r
.39814 .16187 m
.39814 .10572 L
.3989 .10572 L
.3989 .16187 L
s
1 .894 .882 r
.3989 .16187 m
.3989 .10613 L
.39938 .10613 L
.39938 .16187 L
F
.804 .522 .247 r
.3989 .16187 m
.3989 .10613 L
.39938 .10613 L
.39938 .16187 L
s
1 .894 .882 r
.39938 .16187 m
.39938 .1063 L
.39974 .1063 L
.39974 .16187 L
F
.804 .522 .247 r
.39938 .16187 m
.39938 .1063 L
.39974 .1063 L
.39974 .16187 L
s
1 .894 .882 r
.39974 .16187 m
.39974 .10651 L
.40031 .10651 L
.40031 .16187 L
F
.804 .522 .247 r
.39974 .16187 m
.39974 .10651 L
.40031 .10651 L
.40031 .16187 L
s
1 .894 .882 r
.40031 .16187 m
.40031 .10683 L
.40079 .10683 L
.40079 .16187 L
F
.804 .522 .247 r
.40031 .16187 m
.40031 .10683 L
.40079 .10683 L
.40079 .16187 L
s
1 .894 .882 r
.40079 .16187 m
.40079 .10695 L
.40111 .10695 L
.40111 .16187 L
F
.804 .522 .247 r
.40079 .16187 m
.40079 .10695 L
.40111 .10695 L
.40111 .16187 L
s
1 .894 .882 r
.40111 .16187 m
.40111 .10713 L
.40185 .10713 L
.40185 .16187 L
F
.804 .522 .247 r
.40111 .16187 m
.40111 .10713 L
.40185 .10713 L
.40185 .16187 L
s
1 .894 .882 r
.40185 .16187 m
.40185 .10746 L
.40219 .10746 L
.40219 .16187 L
F
.804 .522 .247 r
.40185 .16187 m
.40185 .10746 L
.40219 .10746 L
.40219 .16187 L
s
1 .894 .882 r
.40219 .16187 m
.40219 .10765 L
.40257 .10765 L
.40257 .16187 L
F
.804 .522 .247 r
.40219 .16187 m
.40219 .10765 L
.40257 .10765 L
.40257 .16187 L
s
1 .894 .882 r
.40257 .16187 m
.40257 .10786 L
.40296 .10786 L
.40296 .16187 L
F
.804 .522 .247 r
.40257 .16187 m
.40257 .10786 L
.40296 .10786 L
.40296 .16187 L
s
1 .894 .882 r
.40296 .16187 m
.40296 .10805 L
.40343 .10805 L
.40343 .16187 L
F
.804 .522 .247 r
.40296 .16187 m
.40296 .10805 L
.40343 .10805 L
.40343 .16187 L
s
1 .894 .882 r
.40343 .16187 m
.40343 .10846 L
.40393 .10846 L
.40393 .16187 L
F
.804 .522 .247 r
.40343 .16187 m
.40343 .10846 L
.40393 .10846 L
.40393 .16187 L
s
1 .894 .882 r
.40393 .16187 m
.40393 .10859 L
.40445 .10859 L
.40445 .16187 L
F
.804 .522 .247 r
.40393 .16187 m
.40393 .10859 L
.40445 .10859 L
.40445 .16187 L
s
1 .894 .882 r
.40445 .16187 m
.40445 .10881 L
.40477 .10881 L
.40477 .16187 L
F
.804 .522 .247 r
.40445 .16187 m
.40445 .10881 L
.40477 .10881 L
.40477 .16187 L
s
1 .894 .882 r
.40477 .16187 m
.40477 .10893 L
.40534 .10893 L
.40534 .16187 L
F
.804 .522 .247 r
.40477 .16187 m
.40477 .10893 L
.40534 .10893 L
.40534 .16187 L
s
1 .894 .882 r
.40534 .16187 m
.40534 .10934 L
.40582 .10934 L
.40582 .16187 L
F
.804 .522 .247 r
.40534 .16187 m
.40534 .10934 L
.40582 .10934 L
.40582 .16187 L
s
1 .894 .882 r
.40582 .16187 m
.40582 .10948 L
.40611 .10948 L
.40611 .16187 L
F
.804 .522 .247 r
.40582 .16187 m
.40582 .10948 L
.40611 .10948 L
.40611 .16187 L
s
1 .894 .882 r
.40611 .16187 m
.40611 .10977 L
.4069 .10977 L
.4069 .16187 L
F
.804 .522 .247 r
.40611 .16187 m
.40611 .10977 L
.4069 .10977 L
.4069 .16187 L
s
1 .894 .882 r
.4069 .16187 m
.4069 .11011 L
.40723 .11011 L
.40723 .16187 L
F
.804 .522 .247 r
.4069 .16187 m
.4069 .11011 L
.40723 .11011 L
.40723 .16187 L
s
1 .894 .882 r
.40723 .16187 m
.40723 .11021 L
.40748 .11021 L
.40748 .16187 L
F
.804 .522 .247 r
.40723 .16187 m
.40723 .11021 L
.40748 .11021 L
.40748 .16187 L
s
1 .894 .882 r
.40748 .16187 m
.40748 .11039 L
.4079 .11039 L
.4079 .16187 L
F
.804 .522 .247 r
.40748 .16187 m
.40748 .11039 L
.4079 .11039 L
.4079 .16187 L
s
1 .894 .882 r
.4079 .16187 m
.4079 .11057 L
.40814 .11057 L
.40814 .16187 L
F
.804 .522 .247 r
.4079 .16187 m
.4079 .11057 L
.40814 .11057 L
.40814 .16187 L
s
1 .894 .882 r
.40814 .16187 m
.40814 .11063 L
.40854 .11063 L
.40854 .16187 L
F
.804 .522 .247 r
.40814 .16187 m
.40814 .11063 L
.40854 .11063 L
.40854 .16187 L
s
1 .894 .882 r
.40854 .16187 m
.40854 .11082 L
.40934 .11082 L
.40934 .16187 L
F
.804 .522 .247 r
.40854 .16187 m
.40854 .11082 L
.40934 .11082 L
.40934 .16187 L
s
1 .894 .882 r
.40934 .16187 m
.40934 .11129 L
.4098 .11129 L
.4098 .16187 L
F
.804 .522 .247 r
.40934 .16187 m
.40934 .11129 L
.4098 .11129 L
.4098 .16187 L
s
1 .894 .882 r
.4098 .16187 m
.4098 .11154 L
.41037 .11154 L
.41037 .16187 L
F
.804 .522 .247 r
.4098 .16187 m
.4098 .11154 L
.41037 .11154 L
.41037 .16187 L
s
1 .894 .882 r
.41037 .16187 m
.41037 .11169 L
.41066 .11169 L
.41066 .16187 L
F
.804 .522 .247 r
.41037 .16187 m
.41037 .11169 L
.41066 .11169 L
.41066 .16187 L
s
1 .894 .882 r
.41066 .16187 m
.41066 .11203 L
.41113 .11203 L
.41113 .16187 L
F
.804 .522 .247 r
.41066 .16187 m
.41066 .11203 L
.41113 .11203 L
.41113 .16187 L
s
1 .894 .882 r
.41113 .16187 m
.41113 .11245 L
.41192 .11245 L
.41192 .16187 L
F
.804 .522 .247 r
.41113 .16187 m
.41113 .11245 L
.41192 .11245 L
.41192 .16187 L
s
1 .894 .882 r
.41192 .16187 m
.41192 .11257 L
.41241 .11257 L
.41241 .16187 L
F
.804 .522 .247 r
.41192 .16187 m
.41192 .11257 L
.41241 .11257 L
.41241 .16187 L
s
1 .894 .882 r
.41241 .16187 m
.41241 .11288 L
.41276 .11288 L
.41276 .16187 L
F
.804 .522 .247 r
.41241 .16187 m
.41241 .11288 L
.41276 .11288 L
.41276 .16187 L
s
1 .894 .882 r
.41276 .16187 m
.41276 .11304 L
.41313 .11304 L
.41313 .16187 L
F
.804 .522 .247 r
.41276 .16187 m
.41276 .11304 L
.41313 .11304 L
.41313 .16187 L
s
1 .894 .882 r
.41313 .16187 m
.41313 .11334 L
.41379 .11334 L
.41379 .16187 L
F
.804 .522 .247 r
.41313 .16187 m
.41313 .11334 L
.41379 .11334 L
.41379 .16187 L
s
1 .894 .882 r
.41379 .16187 m
.41379 .11344 L
.41413 .11344 L
.41413 .16187 L
F
.804 .522 .247 r
.41379 .16187 m
.41379 .11344 L
.41413 .11344 L
.41413 .16187 L
s
1 .894 .882 r
.41413 .16187 m
.41413 .11383 L
.41482 .11383 L
.41482 .16187 L
F
.804 .522 .247 r
.41413 .16187 m
.41413 .11383 L
.41482 .11383 L
.41482 .16187 L
s
1 .894 .882 r
.41482 .16187 m
.41482 .11425 L
.41549 .11425 L
.41549 .16187 L
F
.804 .522 .247 r
.41482 .16187 m
.41482 .11425 L
.41549 .11425 L
.41549 .16187 L
s
1 .894 .882 r
.41549 .16187 m
.41549 .11434 L
.41588 .11434 L
.41588 .16187 L
F
.804 .522 .247 r
.41549 .16187 m
.41549 .11434 L
.41588 .11434 L
.41588 .16187 L
s
1 .894 .882 r
.41588 .16187 m
.41588 .11457 L
.41614 .11457 L
.41614 .16187 L
F
.804 .522 .247 r
.41588 .16187 m
.41588 .11457 L
.41614 .11457 L
.41614 .16187 L
s
1 .894 .882 r
.41614 .16187 m
.41614 .11471 L
.41651 .11471 L
.41651 .16187 L
F
.804 .522 .247 r
.41614 .16187 m
.41614 .11471 L
.41651 .11471 L
.41651 .16187 L
s
1 .894 .882 r
.41651 .16187 m
.41651 .11484 L
.41693 .11484 L
.41693 .16187 L
F
.804 .522 .247 r
.41651 .16187 m
.41651 .11484 L
.41693 .11484 L
.41693 .16187 L
s
1 .894 .882 r
.41693 .16187 m
.41693 .11517 L
.41728 .11517 L
.41728 .16187 L
F
.804 .522 .247 r
.41693 .16187 m
.41693 .11517 L
.41728 .11517 L
.41728 .16187 L
s
1 .894 .882 r
.41728 .16187 m
.41728 .11521 L
.41754 .11521 L
.41754 .16187 L
F
.804 .522 .247 r
.41728 .16187 m
.41728 .11521 L
.41754 .11521 L
.41754 .16187 L
s
1 .894 .882 r
.41754 .16187 m
.41754 .11541 L
.41784 .11541 L
.41784 .16187 L
F
.804 .522 .247 r
.41754 .16187 m
.41754 .11541 L
.41784 .11541 L
.41784 .16187 L
s
1 .894 .882 r
.41784 .16187 m
.41784 .11556 L
.41825 .11556 L
.41825 .16187 L
F
.804 .522 .247 r
.41784 .16187 m
.41784 .11556 L
.41825 .11556 L
.41825 .16187 L
s
1 .894 .882 r
.41825 .16187 m
.41825 .11576 L
.41899 .11576 L
.41899 .16187 L
F
.804 .522 .247 r
.41825 .16187 m
.41825 .11576 L
.41899 .11576 L
.41899 .16187 L
s
1 .894 .882 r
.41899 .16187 m
.41899 .11609 L
.41925 .11609 L
.41925 .16187 L
F
.804 .522 .247 r
.41899 .16187 m
.41899 .11609 L
.41925 .11609 L
.41925 .16187 L
s
1 .894 .882 r
.41925 .16187 m
.41925 .11631 L
.41995 .11631 L
.41995 .16187 L
F
.804 .522 .247 r
.41925 .16187 m
.41925 .11631 L
.41995 .11631 L
.41995 .16187 L
s
1 .894 .882 r
.41995 .16187 m
.41995 .11662 L
.42037 .11662 L
.42037 .16187 L
F
.804 .522 .247 r
.41995 .16187 m
.41995 .11662 L
.42037 .11662 L
.42037 .16187 L
s
1 .894 .882 r
.42037 .16187 m
.42037 .11695 L
.42089 .11695 L
.42089 .16187 L
F
.804 .522 .247 r
.42037 .16187 m
.42037 .11695 L
.42089 .11695 L
.42089 .16187 L
s
1 .894 .882 r
.42089 .16187 m
.42089 .11723 L
.42139 .11723 L
.42139 .16187 L
F
.804 .522 .247 r
.42089 .16187 m
.42089 .11723 L
.42139 .11723 L
.42139 .16187 L
s
1 .894 .882 r
.42139 .16187 m
.42139 .11739 L
.42205 .11739 L
.42205 .16187 L
F
.804 .522 .247 r
.42139 .16187 m
.42139 .11739 L
.42205 .11739 L
.42205 .16187 L
s
1 .894 .882 r
.42205 .16187 m
.42205 .11782 L
.4228 .11782 L
.4228 .16187 L
F
.804 .522 .247 r
.42205 .16187 m
.42205 .11782 L
.4228 .11782 L
.4228 .16187 L
s
1 .894 .882 r
.4228 .16187 m
.4228 .11823 L
.42334 .11823 L
.42334 .16187 L
F
.804 .522 .247 r
.4228 .16187 m
.4228 .11823 L
.42334 .11823 L
.42334 .16187 L
s
1 .894 .882 r
.42334 .16187 m
.42334 .11835 L
.42359 .11835 L
.42359 .16187 L
F
.804 .522 .247 r
.42334 .16187 m
.42334 .11835 L
.42359 .11835 L
.42359 .16187 L
s
1 .894 .882 r
.42359 .16187 m
.42359 .11854 L
.42414 .11854 L
.42414 .16187 L
F
.804 .522 .247 r
.42359 .16187 m
.42359 .11854 L
.42414 .11854 L
.42414 .16187 L
s
1 .894 .882 r
.42414 .16187 m
.42414 .11893 L
.42477 .11893 L
.42477 .16187 L
F
.804 .522 .247 r
.42414 .16187 m
.42414 .11893 L
.42477 .11893 L
.42477 .16187 L
s
1 .894 .882 r
.42477 .16187 m
.42477 .11937 L
.42545 .11937 L
.42545 .16187 L
F
.804 .522 .247 r
.42477 .16187 m
.42477 .11937 L
.42545 .11937 L
.42545 .16187 L
s
1 .894 .882 r
.42545 .16187 m
.42545 .11946 L
.42617 .11946 L
.42617 .16187 L
F
.804 .522 .247 r
.42545 .16187 m
.42545 .11946 L
.42617 .11946 L
.42617 .16187 L
s
1 .894 .882 r
.42617 .16187 m
.42617 .12 L
.42683 .12 L
.42683 .16187 L
F
.804 .522 .247 r
.42617 .16187 m
.42617 .12 L
.42683 .12 L
.42683 .16187 L
s
1 .894 .882 r
.42683 .16187 m
.42683 .12041 L
.4276 .12041 L
.4276 .16187 L
F
.804 .522 .247 r
.42683 .16187 m
.42683 .12041 L
.4276 .12041 L
.4276 .16187 L
s
1 .894 .882 r
.4276 .16187 m
.4276 .12068 L
.42813 .12068 L
.42813 .16187 L
F
.804 .522 .247 r
.4276 .16187 m
.4276 .12068 L
.42813 .12068 L
.42813 .16187 L
s
1 .894 .882 r
.42813 .16187 m
.42813 .12096 L
.42884 .12096 L
.42884 .16187 L
F
.804 .522 .247 r
.42813 .16187 m
.42813 .12096 L
.42884 .12096 L
.42884 .16187 L
s
1 .894 .882 r
.42884 .16187 m
.42884 .12119 L
.42937 .12119 L
.42937 .16187 L
F
.804 .522 .247 r
.42884 .16187 m
.42884 .12119 L
.42937 .12119 L
.42937 .16187 L
s
1 .894 .882 r
.42937 .16187 m
.42937 .1216 L
.42996 .1216 L
.42996 .16187 L
F
.804 .522 .247 r
.42937 .16187 m
.42937 .1216 L
.42996 .1216 L
.42996 .16187 L
s
1 .894 .882 r
.42996 .16187 m
.42996 .12191 L
.43039 .12191 L
.43039 .16187 L
F
.804 .522 .247 r
.42996 .16187 m
.42996 .12191 L
.43039 .12191 L
.43039 .16187 L
s
1 .894 .882 r
.43039 .16187 m
.43039 .12206 L
.43107 .12206 L
.43107 .16187 L
F
.804 .522 .247 r
.43039 .16187 m
.43039 .12206 L
.43107 .12206 L
.43107 .16187 L
s
1 .894 .882 r
.43107 .16187 m
.43107 .12246 L
.43155 .12246 L
.43155 .16187 L
F
.804 .522 .247 r
.43107 .16187 m
.43107 .12246 L
.43155 .12246 L
.43155 .16187 L
s
1 .894 .882 r
.43155 .16187 m
.43155 .12261 L
.43197 .12261 L
.43197 .16187 L
F
.804 .522 .247 r
.43155 .16187 m
.43155 .12261 L
.43197 .12261 L
.43197 .16187 L
s
1 .894 .882 r
.43197 .16187 m
.43197 .12294 L
.43247 .12294 L
.43247 .16187 L
F
.804 .522 .247 r
.43197 .16187 m
.43197 .12294 L
.43247 .12294 L
.43247 .16187 L
s
1 .894 .882 r
.43247 .16187 m
.43247 .12343 L
.43313 .12343 L
.43313 .16187 L
F
.804 .522 .247 r
.43247 .16187 m
.43247 .12343 L
.43313 .12343 L
.43313 .16187 L
s
1 .894 .882 r
.43313 .16187 m
.43313 .12348 L
.43371 .12348 L
.43371 .16187 L
F
.804 .522 .247 r
.43313 .16187 m
.43313 .12348 L
.43371 .12348 L
.43371 .16187 L
s
1 .894 .882 r
.43371 .16187 m
.43371 .12384 L
.43396 .12384 L
.43396 .16187 L
F
.804 .522 .247 r
.43371 .16187 m
.43371 .12384 L
.43396 .12384 L
.43396 .16187 L
s
1 .894 .882 r
.43396 .16187 m
.43396 .12419 L
.43475 .12419 L
.43475 .16187 L
F
.804 .522 .247 r
.43396 .16187 m
.43396 .12419 L
.43475 .12419 L
.43475 .16187 L
s
1 .894 .882 r
.43475 .16187 m
.43475 .12435 L
.43514 .12435 L
.43514 .16187 L
F
.804 .522 .247 r
.43475 .16187 m
.43475 .12435 L
.43514 .12435 L
.43514 .16187 L
s
1 .894 .882 r
.43514 .16187 m
.43514 .12484 L
.43587 .12484 L
.43587 .16187 L
F
.804 .522 .247 r
.43514 .16187 m
.43514 .12484 L
.43587 .12484 L
.43587 .16187 L
s
1 .894 .882 r
.43587 .16187 m
.43587 .12494 L
.43618 .12494 L
.43618 .16187 L
F
.804 .522 .247 r
.43587 .16187 m
.43587 .12494 L
.43618 .12494 L
.43618 .16187 L
s
1 .894 .882 r
.43618 .16187 m
.43618 .12533 L
.43668 .12533 L
.43668 .16187 L
F
.804 .522 .247 r
.43618 .16187 m
.43618 .12533 L
.43668 .12533 L
.43668 .16187 L
s
1 .894 .882 r
.43668 .16187 m
.43668 .12551 L
.43706 .12551 L
.43706 .16187 L
F
.804 .522 .247 r
.43668 .16187 m
.43668 .12551 L
.43706 .12551 L
.43706 .16187 L
s
1 .894 .882 r
.43706 .16187 m
.43706 .12565 L
.43748 .12565 L
.43748 .16187 L
F
.804 .522 .247 r
.43706 .16187 m
.43706 .12565 L
.43748 .12565 L
.43748 .16187 L
s
1 .894 .882 r
.43748 .16187 m
.43748 .12591 L
.43796 .12591 L
.43796 .16187 L
F
.804 .522 .247 r
.43748 .16187 m
.43748 .12591 L
.43796 .12591 L
.43796 .16187 L
s
1 .894 .882 r
.43796 .16187 m
.43796 .12604 L
.43859 .12604 L
.43859 .16187 L
F
.804 .522 .247 r
.43796 .16187 m
.43796 .12604 L
.43859 .12604 L
.43859 .16187 L
s
1 .894 .882 r
.43859 .16187 m
.43859 .12654 L
.43906 .12654 L
.43906 .16187 L
F
.804 .522 .247 r
.43859 .16187 m
.43859 .12654 L
.43906 .12654 L
.43906 .16187 L
s
1 .894 .882 r
.43906 .16187 m
.43906 .12686 L
.43963 .12686 L
.43963 .16187 L
F
.804 .522 .247 r
.43906 .16187 m
.43906 .12686 L
.43963 .12686 L
.43963 .16187 L
s
1 .894 .882 r
.43963 .16187 m
.43963 .12716 L
.44015 .12716 L
.44015 .16187 L
F
.804 .522 .247 r
.43963 .16187 m
.43963 .12716 L
.44015 .12716 L
.44015 .16187 L
s
1 .894 .882 r
.44015 .16187 m
.44015 .12729 L
.44049 .12729 L
.44049 .16187 L
F
.804 .522 .247 r
.44015 .16187 m
.44015 .12729 L
.44049 .12729 L
.44049 .16187 L
s
1 .894 .882 r
.44049 .16187 m
.44049 .12746 L
.44106 .12746 L
.44106 .16187 L
F
.804 .522 .247 r
.44049 .16187 m
.44049 .12746 L
.44106 .12746 L
.44106 .16187 L
s
1 .894 .882 r
.44106 .16187 m
.44106 .1278 L
.44134 .1278 L
.44134 .16187 L
F
.804 .522 .247 r
.44106 .16187 m
.44106 .1278 L
.44134 .1278 L
.44134 .16187 L
s
1 .894 .882 r
.44134 .16187 m
.44134 .128 L
.44207 .128 L
.44207 .16187 L
F
.804 .522 .247 r
.44134 .16187 m
.44134 .128 L
.44207 .128 L
.44207 .16187 L
s
1 .894 .882 r
.44207 .16187 m
.44207 .12857 L
.44279 .12857 L
.44279 .16187 L
F
.804 .522 .247 r
.44207 .16187 m
.44207 .12857 L
.44279 .12857 L
.44279 .16187 L
s
1 .894 .882 r
.44279 .16187 m
.44279 .12865 L
.44349 .12865 L
.44349 .16187 L
F
.804 .522 .247 r
.44279 .16187 m
.44279 .12865 L
.44349 .12865 L
.44349 .16187 L
s
1 .894 .882 r
.44349 .16187 m
.44349 .1291 L
.44409 .1291 L
.44409 .16187 L
F
.804 .522 .247 r
.44349 .16187 m
.44349 .1291 L
.44409 .1291 L
.44409 .16187 L
s
1 .894 .882 r
.44409 .16187 m
.44409 .12945 L
.44465 .12945 L
.44465 .16187 L
F
.804 .522 .247 r
.44409 .16187 m
.44409 .12945 L
.44465 .12945 L
.44465 .16187 L
s
1 .894 .882 r
.44465 .16187 m
.44465 .12975 L
.44511 .12975 L
.44511 .16187 L
F
.804 .522 .247 r
.44465 .16187 m
.44465 .12975 L
.44511 .12975 L
.44511 .16187 L
s
1 .894 .882 r
.44511 .16187 m
.44511 .12991 L
.44539 .12991 L
.44539 .16187 L
F
.804 .522 .247 r
.44511 .16187 m
.44511 .12991 L
.44539 .12991 L
.44539 .16187 L
s
1 .894 .882 r
.44539 .16187 m
.44539 .13007 L
.44566 .13007 L
.44566 .16187 L
F
.804 .522 .247 r
.44539 .16187 m
.44539 .13007 L
.44566 .13007 L
.44566 .16187 L
s
1 .894 .882 r
.44566 .16187 m
.44566 .1304 L
.44621 .1304 L
.44621 .16187 L
F
.804 .522 .247 r
.44566 .16187 m
.44566 .1304 L
.44621 .1304 L
.44621 .16187 L
s
1 .894 .882 r
.44621 .16187 m
.44621 .13068 L
.44669 .13068 L
.44669 .16187 L
F
.804 .522 .247 r
.44621 .16187 m
.44621 .13068 L
.44669 .13068 L
.44669 .16187 L
s
1 .894 .882 r
.44669 .16187 m
.44669 .13109 L
.44738 .13109 L
.44738 .16187 L
F
.804 .522 .247 r
.44669 .16187 m
.44669 .13109 L
.44738 .13109 L
.44738 .16187 L
s
1 .894 .882 r
.44738 .16187 m
.44738 .1312 L
.44772 .1312 L
.44772 .16187 L
F
.804 .522 .247 r
.44738 .16187 m
.44738 .1312 L
.44772 .1312 L
.44772 .16187 L
s
1 .894 .882 r
.44772 .16187 m
.44772 .13145 L
.44822 .13145 L
.44822 .16187 L
F
.804 .522 .247 r
.44772 .16187 m
.44772 .13145 L
.44822 .13145 L
.44822 .16187 L
s
1 .894 .882 r
.44822 .16187 m
.44822 .13191 L
.449 .13191 L
.449 .16187 L
F
.804 .522 .247 r
.44822 .16187 m
.44822 .13191 L
.449 .13191 L
.449 .16187 L
s
1 .894 .882 r
.449 .16187 m
.449 .13234 L
.44955 .13234 L
.44955 .16187 L
F
.804 .522 .247 r
.449 .16187 m
.449 .13234 L
.44955 .13234 L
.44955 .16187 L
s
1 .894 .882 r
.44955 .16187 m
.44955 .13266 L
.45028 .13266 L
.45028 .16187 L
F
.804 .522 .247 r
.44955 .16187 m
.44955 .13266 L
.45028 .13266 L
.45028 .16187 L
s
1 .894 .882 r
.45028 .16187 m
.45028 .13286 L
.45053 .13286 L
.45053 .16187 L
F
.804 .522 .247 r
.45028 .16187 m
.45028 .13286 L
.45053 .13286 L
.45053 .16187 L
s
1 .894 .882 r
.45053 .16187 m
.45053 .13302 L
.45093 .13302 L
.45093 .16187 L
F
.804 .522 .247 r
.45053 .16187 m
.45053 .13302 L
.45093 .13302 L
.45093 .16187 L
s
1 .894 .882 r
.45093 .16187 m
.45093 .13316 L
.45125 .13316 L
.45125 .16187 L
F
.804 .522 .247 r
.45093 .16187 m
.45093 .13316 L
.45125 .13316 L
.45125 .16187 L
s
1 .894 .882 r
.45125 .16187 m
.45125 .1335 L
.45166 .1335 L
.45166 .16187 L
F
.804 .522 .247 r
.45125 .16187 m
.45125 .1335 L
.45166 .1335 L
.45166 .16187 L
s
1 .894 .882 r
.45166 .16187 m
.45166 .1338 L
.45219 .1338 L
.45219 .16187 L
F
.804 .522 .247 r
.45166 .16187 m
.45166 .1338 L
.45219 .1338 L
.45219 .16187 L
s
1 .894 .882 r
.45219 .16187 m
.45219 .13383 L
.4525 .13383 L
.4525 .16187 L
F
.804 .522 .247 r
.45219 .16187 m
.45219 .13383 L
.4525 .13383 L
.4525 .16187 L
s
1 .894 .882 r
.4525 .16187 m
.4525 .13399 L
.45305 .13399 L
.45305 .16187 L
F
.804 .522 .247 r
.4525 .16187 m
.4525 .13399 L
.45305 .13399 L
.45305 .16187 L
s
1 .894 .882 r
.45305 .16187 m
.45305 .13433 L
.45343 .13433 L
.45343 .16187 L
F
.804 .522 .247 r
.45305 .16187 m
.45305 .13433 L
.45343 .13433 L
.45343 .16187 L
s
1 .894 .882 r
.45343 .16187 m
.45343 .1347 L
.45403 .1347 L
.45403 .16187 L
F
.804 .522 .247 r
.45343 .16187 m
.45343 .1347 L
.45403 .1347 L
.45403 .16187 L
s
1 .894 .882 r
.45403 .16187 m
.45403 .1349 L
.45443 .1349 L
.45443 .16187 L
F
.804 .522 .247 r
.45403 .16187 m
.45403 .1349 L
.45443 .1349 L
.45443 .16187 L
s
1 .894 .882 r
.45443 .16187 m
.45443 .13505 L
.45508 .13505 L
.45508 .16187 L
F
.804 .522 .247 r
.45443 .16187 m
.45443 .13505 L
.45508 .13505 L
.45508 .16187 L
s
1 .894 .882 r
.45508 .16187 m
.45508 .13574 L
.45567 .13574 L
.45567 .16187 L
F
.804 .522 .247 r
.45508 .16187 m
.45508 .13574 L
.45567 .13574 L
.45567 .16187 L
s
1 .894 .882 r
.45567 .16187 m
.45567 .13578 L
.45595 .13578 L
.45595 .16187 L
F
.804 .522 .247 r
.45567 .16187 m
.45567 .13578 L
.45595 .13578 L
.45595 .16187 L
s
1 .894 .882 r
.45595 .16187 m
.45595 .13628 L
.45669 .13628 L
.45669 .16187 L
F
.804 .522 .247 r
.45595 .16187 m
.45595 .13628 L
.45669 .13628 L
.45669 .16187 L
s
1 .894 .882 r
.45669 .16187 m
.45669 .13665 L
.45731 .13665 L
.45731 .16187 L
F
.804 .522 .247 r
.45669 .16187 m
.45669 .13665 L
.45731 .13665 L
.45731 .16187 L
s
1 .894 .882 r
.45731 .16187 m
.45731 .13694 L
.45787 .13694 L
.45787 .16187 L
F
.804 .522 .247 r
.45731 .16187 m
.45731 .13694 L
.45787 .13694 L
.45787 .16187 L
s
1 .894 .882 r
.45787 .16187 m
.45787 .13716 L
.45842 .13716 L
.45842 .16187 L
F
.804 .522 .247 r
.45787 .16187 m
.45787 .13716 L
.45842 .13716 L
.45842 .16187 L
s
1 .894 .882 r
.45842 .16187 m
.45842 .13735 L
.45892 .13735 L
.45892 .16187 L
F
.804 .522 .247 r
.45842 .16187 m
.45842 .13735 L
.45892 .13735 L
.45892 .16187 L
s
1 .894 .882 r
.45892 .16187 m
.45892 .13761 L
.45966 .13761 L
.45966 .16187 L
F
.804 .522 .247 r
.45892 .16187 m
.45892 .13761 L
.45966 .13761 L
.45966 .16187 L
s
1 .894 .882 r
.45966 .16187 m
.45966 .13814 L
.46011 .13814 L
.46011 .16187 L
F
.804 .522 .247 r
.45966 .16187 m
.45966 .13814 L
.46011 .13814 L
.46011 .16187 L
s
1 .894 .882 r
.46011 .16187 m
.46011 .13828 L
.46041 .13828 L
.46041 .16187 L
F
.804 .522 .247 r
.46011 .16187 m
.46011 .13828 L
.46041 .13828 L
.46041 .16187 L
s
1 .894 .882 r
.46041 .16187 m
.46041 .13856 L
.46094 .13856 L
.46094 .16187 L
F
.804 .522 .247 r
.46041 .16187 m
.46041 .13856 L
.46094 .13856 L
.46094 .16187 L
s
1 .894 .882 r
.46094 .16187 m
.46094 .13874 L
.46137 .13874 L
.46137 .16187 L
F
.804 .522 .247 r
.46094 .16187 m
.46094 .13874 L
.46137 .13874 L
.46137 .16187 L
s
1 .894 .882 r
.46137 .16187 m
.46137 .13919 L
.4619 .13919 L
.4619 .16187 L
F
.804 .522 .247 r
.46137 .16187 m
.46137 .13919 L
.4619 .13919 L
.4619 .16187 L
s
1 .894 .882 r
.4619 .16187 m
.4619 .13931 L
.46218 .13931 L
.46218 .16187 L
F
.804 .522 .247 r
.4619 .16187 m
.4619 .13931 L
.46218 .13931 L
.46218 .16187 L
s
1 .894 .882 r
.46218 .16187 m
.46218 .1396 L
.46255 .1396 L
.46255 .16187 L
F
.804 .522 .247 r
.46218 .16187 m
.46218 .1396 L
.46255 .1396 L
.46255 .16187 L
s
1 .894 .882 r
.46255 .16187 m
.46255 .13979 L
.46291 .13979 L
.46291 .16187 L
F
.804 .522 .247 r
.46255 .16187 m
.46255 .13979 L
.46291 .13979 L
.46291 .16187 L
s
1 .894 .882 r
.46291 .16187 m
.46291 .14 L
.46327 .14 L
.46327 .16187 L
F
.804 .522 .247 r
.46291 .16187 m
.46291 .14 L
.46327 .14 L
.46327 .16187 L
s
1 .894 .882 r
.46327 .16187 m
.46327 .14015 L
.46383 .14015 L
.46383 .16187 L
F
.804 .522 .247 r
.46327 .16187 m
.46327 .14015 L
.46383 .14015 L
.46383 .16187 L
s
1 .894 .882 r
.46383 .16187 m
.46383 .14048 L
.46414 .14048 L
.46414 .16187 L
F
.804 .522 .247 r
.46383 .16187 m
.46383 .14048 L
.46414 .14048 L
.46414 .16187 L
s
1 .894 .882 r
.46414 .16187 m
.46414 .14079 L
.46475 .14079 L
.46475 .16187 L
F
.804 .522 .247 r
.46414 .16187 m
.46414 .14079 L
.46475 .14079 L
.46475 .16187 L
s
1 .894 .882 r
.46475 .16187 m
.46475 .14112 L
.46554 .14112 L
.46554 .16187 L
F
.804 .522 .247 r
.46475 .16187 m
.46475 .14112 L
.46554 .14112 L
.46554 .16187 L
s
1 .894 .882 r
.46554 .16187 m
.46554 .14165 L
.4663 .14165 L
.4663 .16187 L
F
.804 .522 .247 r
.46554 .16187 m
.46554 .14165 L
.4663 .14165 L
.4663 .16187 L
s
1 .894 .882 r
.4663 .16187 m
.4663 .14193 L
.46702 .14193 L
.46702 .16187 L
F
.804 .522 .247 r
.4663 .16187 m
.4663 .14193 L
.46702 .14193 L
.46702 .16187 L
s
1 .894 .882 r
.46702 .16187 m
.46702 .1425 L
.46779 .1425 L
.46779 .16187 L
F
.804 .522 .247 r
.46702 .16187 m
.46702 .1425 L
.46779 .1425 L
.46779 .16187 L
s
1 .894 .882 r
.46779 .16187 m
.46779 .14277 L
.46824 .14277 L
.46824 .16187 L
F
.804 .522 .247 r
.46779 .16187 m
.46779 .14277 L
.46824 .14277 L
.46824 .16187 L
s
1 .894 .882 r
.46824 .16187 m
.46824 .14308 L
.46895 .14308 L
.46895 .16187 L
F
.804 .522 .247 r
.46824 .16187 m
.46824 .14308 L
.46895 .14308 L
.46895 .16187 L
s
1 .894 .882 r
.46895 .16187 m
.46895 .14352 L
.46974 .14352 L
.46974 .16187 L
F
.804 .522 .247 r
.46895 .16187 m
.46895 .14352 L
.46974 .14352 L
.46974 .16187 L
s
1 .894 .882 r
.46974 .16187 m
.46974 .14393 L
.47013 .14393 L
.47013 .16187 L
F
.804 .522 .247 r
.46974 .16187 m
.46974 .14393 L
.47013 .14393 L
.47013 .16187 L
s
1 .894 .882 r
.47013 .16187 m
.47013 .14426 L
.47082 .14426 L
.47082 .16187 L
F
.804 .522 .247 r
.47013 .16187 m
.47013 .14426 L
.47082 .14426 L
.47082 .16187 L
s
1 .894 .882 r
.47082 .16187 m
.47082 .1446 L
.47124 .1446 L
.47124 .16187 L
F
.804 .522 .247 r
.47082 .16187 m
.47082 .1446 L
.47124 .1446 L
.47124 .16187 L
s
1 .894 .882 r
.47124 .16187 m
.47124 .14471 L
.47176 .14471 L
.47176 .16187 L
F
.804 .522 .247 r
.47124 .16187 m
.47124 .14471 L
.47176 .14471 L
.47176 .16187 L
s
1 .894 .882 r
.47176 .16187 m
.47176 .14511 L
.47222 .14511 L
.47222 .16187 L
F
.804 .522 .247 r
.47176 .16187 m
.47176 .14511 L
.47222 .14511 L
.47222 .16187 L
s
1 .894 .882 r
.47222 .16187 m
.47222 .14523 L
.4727 .14523 L
.4727 .16187 L
F
.804 .522 .247 r
.47222 .16187 m
.47222 .14523 L
.4727 .14523 L
.4727 .16187 L
s
1 .894 .882 r
.4727 .16187 m
.4727 .14563 L
.47307 .14563 L
.47307 .16187 L
F
.804 .522 .247 r
.4727 .16187 m
.4727 .14563 L
.47307 .14563 L
.47307 .16187 L
s
1 .894 .882 r
.47307 .16187 m
.47307 .14605 L
.47387 .14605 L
.47387 .16187 L
F
.804 .522 .247 r
.47307 .16187 m
.47307 .14605 L
.47387 .14605 L
.47387 .16187 L
s
1 .894 .882 r
.47387 .16187 m
.47387 .14625 L
.47414 .14625 L
.47414 .16187 L
F
.804 .522 .247 r
.47387 .16187 m
.47387 .14625 L
.47414 .14625 L
.47414 .16187 L
s
1 .894 .882 r
.47414 .16187 m
.47414 .14647 L
.4749 .14647 L
.4749 .16187 L
F
.804 .522 .247 r
.47414 .16187 m
.47414 .14647 L
.4749 .14647 L
.4749 .16187 L
s
1 .894 .882 r
.4749 .16187 m
.4749 .14683 L
.47522 .14683 L
.47522 .16187 L
F
.804 .522 .247 r
.4749 .16187 m
.4749 .14683 L
.47522 .14683 L
.47522 .16187 L
s
1 .894 .882 r
.47522 .16187 m
.47522 .14731 L
.47589 .14731 L
.47589 .16187 L
F
.804 .522 .247 r
.47522 .16187 m
.47522 .14731 L
.47589 .14731 L
.47589 .16187 L
s
1 .894 .882 r
.47589 .16187 m
.47589 .14768 L
.47661 .14768 L
.47661 .16187 L
F
.804 .522 .247 r
.47589 .16187 m
.47589 .14768 L
.47661 .14768 L
.47661 .16187 L
s
1 .894 .882 r
.47661 .16187 m
.47661 .14798 L
.47725 .14798 L
.47725 .16187 L
F
.804 .522 .247 r
.47661 .16187 m
.47661 .14798 L
.47725 .14798 L
.47725 .16187 L
s
1 .894 .882 r
.47725 .16187 m
.47725 .14816 L
.47782 .14816 L
.47782 .16187 L
F
.804 .522 .247 r
.47725 .16187 m
.47725 .14816 L
.47782 .14816 L
.47782 .16187 L
s
1 .894 .882 r
.47782 .16187 m
.47782 .14856 L
.47843 .14856 L
.47843 .16187 L
F
.804 .522 .247 r
.47782 .16187 m
.47782 .14856 L
.47843 .14856 L
.47843 .16187 L
s
1 .894 .882 r
.47843 .16187 m
.47843 .14885 L
.47877 .14885 L
.47877 .16187 L
F
.804 .522 .247 r
.47843 .16187 m
.47843 .14885 L
.47877 .14885 L
.47877 .16187 L
s
1 .894 .882 r
.47877 .16187 m
.47877 .14906 L
.47943 .14906 L
.47943 .16187 L
F
.804 .522 .247 r
.47877 .16187 m
.47877 .14906 L
.47943 .14906 L
.47943 .16187 L
s
1 .894 .882 r
.47943 .16187 m
.47943 .14955 L
.48005 .14955 L
.48005 .16187 L
F
.804 .522 .247 r
.47943 .16187 m
.47943 .14955 L
.48005 .14955 L
.48005 .16187 L
s
1 .894 .882 r
.48005 .16187 m
.48005 .15015 L
.48074 .15015 L
.48074 .16187 L
F
.804 .522 .247 r
.48005 .16187 m
.48005 .15015 L
.48074 .15015 L
.48074 .16187 L
s
1 .894 .882 r
.48074 .16187 m
.48074 .15029 L
.48113 .15029 L
.48113 .16187 L
F
.804 .522 .247 r
.48074 .16187 m
.48074 .15029 L
.48113 .15029 L
.48113 .16187 L
s
1 .894 .882 r
.48113 .16187 m
.48113 .15057 L
.48158 .15057 L
.48158 .16187 L
F
.804 .522 .247 r
.48113 .16187 m
.48113 .15057 L
.48158 .15057 L
.48158 .16187 L
s
1 .894 .882 r
.48158 .16187 m
.48158 .15107 L
.4823 .15107 L
.4823 .16187 L
F
.804 .522 .247 r
.48158 .16187 m
.48158 .15107 L
.4823 .15107 L
.4823 .16187 L
s
1 .894 .882 r
.4823 .16187 m
.4823 .15129 L
.48301 .15129 L
.48301 .16187 L
F
.804 .522 .247 r
.4823 .16187 m
.4823 .15129 L
.48301 .15129 L
.48301 .16187 L
s
1 .894 .882 r
.48301 .16187 m
.48301 .15164 L
.48325 .15164 L
.48325 .16187 L
F
.804 .522 .247 r
.48301 .16187 m
.48301 .15164 L
.48325 .15164 L
.48325 .16187 L
s
1 .894 .882 r
.48325 .16187 m
.48325 .15198 L
.4838 .15198 L
.4838 .16187 L
F
.804 .522 .247 r
.48325 .16187 m
.48325 .15198 L
.4838 .15198 L
.4838 .16187 L
s
1 .894 .882 r
.4838 .16187 m
.4838 .15203 L
.48435 .15203 L
.48435 .16187 L
F
.804 .522 .247 r
.4838 .16187 m
.4838 .15203 L
.48435 .15203 L
.48435 .16187 L
s
1 .894 .882 r
.48435 .16187 m
.48435 .15239 L
.48478 .15239 L
.48478 .16187 L
F
.804 .522 .247 r
.48435 .16187 m
.48435 .15239 L
.48478 .15239 L
.48478 .16187 L
s
1 .894 .882 r
.48478 .16187 m
.48478 .15294 L
.48537 .15294 L
.48537 .16187 L
F
.804 .522 .247 r
.48478 .16187 m
.48478 .15294 L
.48537 .15294 L
.48537 .16187 L
s
1 .894 .882 r
.48537 .16187 m
.48537 .15311 L
.48569 .15311 L
.48569 .16187 L
F
.804 .522 .247 r
.48537 .16187 m
.48537 .15311 L
.48569 .15311 L
.48569 .16187 L
s
1 .894 .882 r
.48569 .16187 m
.48569 .15323 L
.48611 .15323 L
.48611 .16187 L
F
.804 .522 .247 r
.48569 .16187 m
.48569 .15323 L
.48611 .15323 L
.48611 .16187 L
s
1 .894 .882 r
.48611 .16187 m
.48611 .1535 L
.48655 .1535 L
.48655 .16187 L
F
.804 .522 .247 r
.48611 .16187 m
.48611 .1535 L
.48655 .1535 L
.48655 .16187 L
s
1 .894 .882 r
.48655 .16187 m
.48655 .15379 L
.48711 .15379 L
.48711 .16187 L
F
.804 .522 .247 r
.48655 .16187 m
.48655 .15379 L
.48711 .15379 L
.48711 .16187 L
s
1 .894 .882 r
.48711 .16187 m
.48711 .1541 L
.48748 .1541 L
.48748 .16187 L
F
.804 .522 .247 r
.48711 .16187 m
.48711 .1541 L
.48748 .1541 L
.48748 .16187 L
s
1 .894 .882 r
.48748 .16187 m
.48748 .15442 L
.48782 .15442 L
.48782 .16187 L
F
.804 .522 .247 r
.48748 .16187 m
.48748 .15442 L
.48782 .15442 L
.48782 .16187 L
s
1 .894 .882 r
.48782 .16187 m
.48782 .15459 L
.48839 .15459 L
.48839 .16187 L
F
.804 .522 .247 r
.48782 .16187 m
.48782 .15459 L
.48839 .15459 L
.48839 .16187 L
s
1 .894 .882 r
.48839 .16187 m
.48839 .155 L
.48905 .155 L
.48905 .16187 L
F
.804 .522 .247 r
.48839 .16187 m
.48839 .155 L
.48905 .155 L
.48905 .16187 L
s
1 .894 .882 r
.48905 .16187 m
.48905 .15544 L
.48958 .15544 L
.48958 .16187 L
F
.804 .522 .247 r
.48905 .16187 m
.48905 .15544 L
.48958 .15544 L
.48958 .16187 L
s
1 .894 .882 r
.48958 .16187 m
.48958 .1558 L
.49016 .1558 L
.49016 .16187 L
F
.804 .522 .247 r
.48958 .16187 m
.48958 .1558 L
.49016 .1558 L
.49016 .16187 L
s
1 .894 .882 r
.49016 .16187 m
.49016 .15596 L
.49092 .15596 L
.49092 .16187 L
F
.804 .522 .247 r
.49016 .16187 m
.49016 .15596 L
.49092 .15596 L
.49092 .16187 L
s
1 .894 .882 r
.49092 .16187 m
.49092 .15647 L
.49148 .15647 L
.49148 .16187 L
F
.804 .522 .247 r
.49092 .16187 m
.49092 .15647 L
.49148 .15647 L
.49148 .16187 L
s
1 .894 .882 r
.49148 .16187 m
.49148 .15697 L
.49216 .15697 L
.49216 .16187 L
F
.804 .522 .247 r
.49148 .16187 m
.49148 .15697 L
.49216 .15697 L
.49216 .16187 L
s
1 .894 .882 r
.49216 .16187 m
.49216 .15731 L
.49292 .15731 L
.49292 .16187 L
F
.804 .522 .247 r
.49216 .16187 m
.49216 .15731 L
.49292 .15731 L
.49292 .16187 L
s
1 .894 .882 r
.49292 .16187 m
.49292 .1576 L
.49324 .1576 L
.49324 .16187 L
F
.804 .522 .247 r
.49292 .16187 m
.49292 .1576 L
.49324 .1576 L
.49324 .16187 L
s
1 .894 .882 r
.49324 .16187 m
.49324 .15775 L
.49365 .15775 L
.49365 .16187 L
F
.804 .522 .247 r
.49324 .16187 m
.49324 .15775 L
.49365 .15775 L
.49365 .16187 L
s
1 .894 .882 r
.49365 .16187 m
.49365 .15805 L
.49413 .15805 L
.49413 .16187 L
F
.804 .522 .247 r
.49365 .16187 m
.49365 .15805 L
.49413 .15805 L
.49413 .16187 L
s
1 .894 .882 r
.49413 .16187 m
.49413 .15838 L
.49442 .15838 L
.49442 .16187 L
F
.804 .522 .247 r
.49413 .16187 m
.49413 .15838 L
.49442 .15838 L
.49442 .16187 L
s
1 .894 .882 r
.49442 .16187 m
.49442 .15844 L
.49483 .15844 L
.49483 .16187 L
F
.804 .522 .247 r
.49442 .16187 m
.49442 .15844 L
.49483 .15844 L
.49483 .16187 L
s
1 .894 .882 r
.49483 .16187 m
.49483 .15882 L
.49524 .15882 L
.49524 .16187 L
F
.804 .522 .247 r
.49483 .16187 m
.49483 .15882 L
.49524 .15882 L
.49524 .16187 L
s
1 .894 .882 r
.49524 .16187 m
.49524 .15912 L
.49597 .15912 L
.49597 .16187 L
F
.804 .522 .247 r
.49524 .16187 m
.49524 .15912 L
.49597 .15912 L
.49597 .16187 L
s
1 .894 .882 r
.49597 .16187 m
.49597 .15961 L
.49652 .15961 L
.49652 .16187 L
F
.804 .522 .247 r
.49597 .16187 m
.49597 .15961 L
.49652 .15961 L
.49652 .16187 L
s
1 .894 .882 r
.49652 .16187 m
.49652 .16015 L
.49731 .16015 L
.49731 .16187 L
F
.804 .522 .247 r
.49652 .16187 m
.49652 .16015 L
.49731 .16015 L
.49731 .16187 L
s
1 .894 .882 r
.49731 .16187 m
.49731 .16044 L
.49794 .16044 L
.49794 .16187 L
F
.804 .522 .247 r
.49731 .16187 m
.49731 .16044 L
.49794 .16044 L
.49794 .16187 L
s
1 .894 .882 r
.49794 .16187 m
.49794 .16086 L
.49859 .16086 L
.49859 .16187 L
F
.804 .522 .247 r
.49794 .16187 m
.49794 .16086 L
.49859 .16086 L
.49859 .16187 L
s
1 .894 .882 r
.49859 .16187 m
.49859 .16108 L
.49895 .16108 L
.49895 .16187 L
F
.804 .522 .247 r
.49859 .16187 m
.49859 .16108 L
.49895 .16108 L
.49895 .16187 L
s
1 .894 .882 r
.49895 .16187 m
.49895 .16141 L
.49955 .16141 L
.49955 .16187 L
F
.804 .522 .247 r
.49895 .16187 m
.49895 .16141 L
.49955 .16141 L
.49955 .16187 L
s
1 .894 .882 r
.49955 .16187 m
.49955 .16164 L
.49986 .16164 L
.49986 .16187 L
F
.804 .522 .247 r
.49955 .16187 m
.49955 .16164 L
.49986 .16164 L
.49986 .16187 L
s
1 .894 .882 r
.49986 .16187 m
.49986 .16186 L
.50039 .16186 L
.50039 .16187 L
F
.804 .522 .247 r
.49986 .16187 m
.49986 .16186 L
.50039 .16186 L
.50039 .16187 L
s
.678 .847 .902 r
.50039 .16187 m
.50039 .16218 L
.50065 .16218 L
.50065 .16187 L
F
.2 .63 .79 r
.50039 .16187 m
.50039 .16218 L
.50065 .16218 L
.50065 .16187 L
s
.678 .847 .902 r
.50065 .16187 m
.50065 .16228 L
.50093 .16228 L
.50093 .16187 L
F
.2 .63 .79 r
.50065 .16187 m
.50065 .16228 L
.50093 .16228 L
.50093 .16187 L
s
.678 .847 .902 r
.50093 .16187 m
.50093 .16263 L
.50138 .16263 L
.50138 .16187 L
F
.2 .63 .79 r
.50093 .16187 m
.50093 .16263 L
.50138 .16263 L
.50138 .16187 L
s
.678 .847 .902 r
.50138 .16187 m
.50138 .16278 L
.50163 .16278 L
.50163 .16187 L
F
.2 .63 .79 r
.50138 .16187 m
.50138 .16278 L
.50163 .16278 L
.50163 .16187 L
s
.678 .847 .902 r
.50163 .16187 m
.50163 .16304 L
.50211 .16304 L
.50211 .16187 L
F
.2 .63 .79 r
.50163 .16187 m
.50163 .16304 L
.50211 .16304 L
.50211 .16187 L
s
.678 .847 .902 r
.50211 .16187 m
.50211 .16334 L
.50243 .16334 L
.50243 .16187 L
F
.2 .63 .79 r
.50211 .16187 m
.50211 .16334 L
.50243 .16334 L
.50243 .16187 L
s
.678 .847 .902 r
.50243 .16187 m
.50243 .16346 L
.50313 .16346 L
.50313 .16187 L
F
.2 .63 .79 r
.50243 .16187 m
.50243 .16346 L
.50313 .16346 L
.50313 .16187 L
s
.678 .847 .902 r
.50313 .16187 m
.50313 .16396 L
.5035 .16396 L
.5035 .16187 L
F
.2 .63 .79 r
.50313 .16187 m
.50313 .16396 L
.5035 .16396 L
.5035 .16187 L
s
.678 .847 .902 r
.5035 .16187 m
.5035 .16405 L
.50403 .16405 L
.50403 .16187 L
F
.2 .63 .79 r
.5035 .16187 m
.5035 .16405 L
.50403 .16405 L
.50403 .16187 L
s
.678 .847 .902 r
.50403 .16187 m
.50403 .16444 L
.50428 .16444 L
.50428 .16187 L
F
.2 .63 .79 r
.50403 .16187 m
.50403 .16444 L
.50428 .16444 L
.50428 .16187 L
s
.678 .847 .902 r
.50428 .16187 m
.50428 .16455 L
.5048 .16455 L
.5048 .16187 L
F
.2 .63 .79 r
.50428 .16187 m
.50428 .16455 L
.5048 .16455 L
.5048 .16187 L
s
.678 .847 .902 r
.5048 .16187 m
.5048 .16502 L
.50551 .16502 L
.50551 .16187 L
F
.2 .63 .79 r
.5048 .16187 m
.5048 .16502 L
.50551 .16502 L
.50551 .16187 L
s
.678 .847 .902 r
.50551 .16187 m
.50551 .1654 L
.506 .1654 L
.506 .16187 L
F
.2 .63 .79 r
.50551 .16187 m
.50551 .1654 L
.506 .1654 L
.506 .16187 L
s
.678 .847 .902 r
.506 .16187 m
.506 .16577 L
.50664 .16577 L
.50664 .16187 L
F
.2 .63 .79 r
.506 .16187 m
.506 .16577 L
.50664 .16577 L
.50664 .16187 L
s
.678 .847 .902 r
.50664 .16187 m
.50664 .16612 L
.50699 .16612 L
.50699 .16187 L
F
.2 .63 .79 r
.50664 .16187 m
.50664 .16612 L
.50699 .16612 L
.50699 .16187 L
s
.678 .847 .902 r
.50699 .16187 m
.50699 .1667 L
.50778 .1667 L
.50778 .16187 L
F
.2 .63 .79 r
.50699 .16187 m
.50699 .1667 L
.50778 .1667 L
.50778 .16187 L
s
.678 .847 .902 r
.50778 .16187 m
.50778 .16703 L
.50852 .16703 L
.50852 .16187 L
F
.2 .63 .79 r
.50778 .16187 m
.50778 .16703 L
.50852 .16703 L
.50852 .16187 L
s
.678 .847 .902 r
.50852 .16187 m
.50852 .16741 L
.50919 .16741 L
.50919 .16187 L
F
.2 .63 .79 r
.50852 .16187 m
.50852 .16741 L
.50919 .16741 L
.50919 .16187 L
s
.678 .847 .902 r
.50919 .16187 m
.50919 .16791 L
.50971 .16791 L
.50971 .16187 L
F
.2 .63 .79 r
.50919 .16187 m
.50919 .16791 L
.50971 .16791 L
.50971 .16187 L
s
.678 .847 .902 r
.50971 .16187 m
.50971 .168 L
.51009 .168 L
.51009 .16187 L
F
.2 .63 .79 r
.50971 .16187 m
.50971 .168 L
.51009 .168 L
.51009 .16187 L
s
.678 .847 .902 r
.51009 .16187 m
.51009 .16829 L
.51072 .16829 L
.51072 .16187 L
F
.2 .63 .79 r
.51009 .16187 m
.51009 .16829 L
.51072 .16829 L
.51072 .16187 L
s
.678 .847 .902 r
.51072 .16187 m
.51072 .16857 L
.51102 .16857 L
.51102 .16187 L
F
.2 .63 .79 r
.51072 .16187 m
.51072 .16857 L
.51102 .16857 L
.51102 .16187 L
s
.678 .847 .902 r
.51102 .16187 m
.51102 .16896 L
.51149 .16896 L
.51149 .16187 L
F
.2 .63 .79 r
.51102 .16187 m
.51102 .16896 L
.51149 .16896 L
.51149 .16187 L
s
.678 .847 .902 r
.51149 .16187 m
.51149 .16907 L
.51213 .16907 L
.51213 .16187 L
F
.2 .63 .79 r
.51149 .16187 m
.51149 .16907 L
.51213 .16907 L
.51213 .16187 L
s
.678 .847 .902 r
.51213 .16187 m
.51213 .16979 L
.51275 .16979 L
.51275 .16187 L
F
.2 .63 .79 r
.51213 .16187 m
.51213 .16979 L
.51275 .16979 L
.51275 .16187 L
s
.678 .847 .902 r
.51275 .16187 m
.51275 .17001 L
.51301 .17001 L
.51301 .16187 L
F
.2 .63 .79 r
.51275 .16187 m
.51275 .17001 L
.51301 .17001 L
.51301 .16187 L
s
.678 .847 .902 r
.51301 .16187 m
.51301 .17002 L
.51327 .17002 L
.51327 .16187 L
F
.2 .63 .79 r
.51301 .16187 m
.51301 .17002 L
.51327 .17002 L
.51327 .16187 L
s
.678 .847 .902 r
.51327 .16187 m
.51327 .17044 L
.51391 .17044 L
.51391 .16187 L
F
.2 .63 .79 r
.51327 .16187 m
.51327 .17044 L
.51391 .17044 L
.51391 .16187 L
s
.678 .847 .902 r
.51391 .16187 m
.51391 .17066 L
.51428 .17066 L
.51428 .16187 L
F
.2 .63 .79 r
.51391 .16187 m
.51391 .17066 L
.51428 .17066 L
.51428 .16187 L
s
.678 .847 .902 r
.51428 .16187 m
.51428 .1709 L
.51503 .1709 L
.51503 .16187 L
F
.2 .63 .79 r
.51428 .16187 m
.51428 .1709 L
.51503 .1709 L
.51503 .16187 L
s
.678 .847 .902 r
.51503 .16187 m
.51503 .1715 L
.5154 .1715 L
.5154 .16187 L
F
.2 .63 .79 r
.51503 .16187 m
.51503 .1715 L
.5154 .1715 L
.5154 .16187 L
s
.678 .847 .902 r
.5154 .16187 m
.5154 .17186 L
.51591 .17186 L
.51591 .16187 L
F
.2 .63 .79 r
.5154 .16187 m
.5154 .17186 L
.51591 .17186 L
.51591 .16187 L
s
.678 .847 .902 r
.51591 .16187 m
.51591 .17197 L
.51656 .17197 L
.51656 .16187 L
F
.2 .63 .79 r
.51591 .16187 m
.51591 .17197 L
.51656 .17197 L
.51656 .16187 L
s
.678 .847 .902 r
.51656 .16187 m
.51656 .17261 L
.5173 .17261 L
.5173 .16187 L
F
.2 .63 .79 r
.51656 .16187 m
.51656 .17261 L
.5173 .17261 L
.5173 .16187 L
s
.678 .847 .902 r
.5173 .16187 m
.5173 .17307 L
.51796 .17307 L
.51796 .16187 L
F
.2 .63 .79 r
.5173 .16187 m
.5173 .17307 L
.51796 .17307 L
.51796 .16187 L
s
.678 .847 .902 r
.51796 .16187 m
.51796 .17341 L
.51856 .17341 L
.51856 .16187 L
F
.2 .63 .79 r
.51796 .16187 m
.51796 .17341 L
.51856 .17341 L
.51856 .16187 L
s
.678 .847 .902 r
.51856 .16187 m
.51856 .1738 L
.51898 .1738 L
.51898 .16187 L
F
.2 .63 .79 r
.51856 .16187 m
.51856 .1738 L
.51898 .1738 L
.51898 .16187 L
s
.678 .847 .902 r
.51898 .16187 m
.51898 .17388 L
.51931 .17388 L
.51931 .16187 L
F
.2 .63 .79 r
.51898 .16187 m
.51898 .17388 L
.51931 .17388 L
.51931 .16187 L
s
.678 .847 .902 r
.51931 .16187 m
.51931 .17411 L
.51986 .17411 L
.51986 .16187 L
F
.2 .63 .79 r
.51931 .16187 m
.51931 .17411 L
.51986 .17411 L
.51986 .16187 L
s
.678 .847 .902 r
.51986 .16187 m
.51986 .17465 L
.52048 .17465 L
.52048 .16187 L
F
.2 .63 .79 r
.51986 .16187 m
.51986 .17465 L
.52048 .17465 L
.52048 .16187 L
s
.678 .847 .902 r
.52048 .16187 m
.52048 .17487 L
.52096 .17487 L
.52096 .16187 L
F
.2 .63 .79 r
.52048 .16187 m
.52048 .17487 L
.52096 .17487 L
.52096 .16187 L
s
.678 .847 .902 r
.52096 .16187 m
.52096 .17532 L
.52144 .17532 L
.52144 .16187 L
F
.2 .63 .79 r
.52096 .16187 m
.52096 .17532 L
.52144 .17532 L
.52144 .16187 L
s
.678 .847 .902 r
.52144 .16187 m
.52144 .17546 L
.5217 .17546 L
.5217 .16187 L
F
.2 .63 .79 r
.52144 .16187 m
.52144 .17546 L
.5217 .17546 L
.5217 .16187 L
s
.678 .847 .902 r
.5217 .16187 m
.5217 .17569 L
.52219 .17569 L
.52219 .16187 L
F
.2 .63 .79 r
.5217 .16187 m
.5217 .17569 L
.52219 .17569 L
.52219 .16187 L
s
.678 .847 .902 r
.52219 .16187 m
.52219 .1763 L
.52285 .1763 L
.52285 .16187 L
F
.2 .63 .79 r
.52219 .16187 m
.52219 .1763 L
.52285 .1763 L
.52285 .16187 L
s
.678 .847 .902 r
.52285 .16187 m
.52285 .17651 L
.52327 .17651 L
.52327 .16187 L
F
.2 .63 .79 r
.52285 .16187 m
.52285 .17651 L
.52327 .17651 L
.52327 .16187 L
s
.678 .847 .902 r
.52327 .16187 m
.52327 .17681 L
.52387 .17681 L
.52387 .16187 L
F
.2 .63 .79 r
.52327 .16187 m
.52327 .17681 L
.52387 .17681 L
.52387 .16187 L
s
.678 .847 .902 r
.52387 .16187 m
.52387 .1771 L
.52453 .1771 L
.52453 .16187 L
F
.2 .63 .79 r
.52387 .16187 m
.52387 .1771 L
.52453 .1771 L
.52453 .16187 L
s
.678 .847 .902 r
.52453 .16187 m
.52453 .17743 L
.52481 .17743 L
.52481 .16187 L
F
.2 .63 .79 r
.52453 .16187 m
.52453 .17743 L
.52481 .17743 L
.52481 .16187 L
s
.678 .847 .902 r
.52481 .16187 m
.52481 .17778 L
.5252 .17778 L
.5252 .16187 L
F
.2 .63 .79 r
.52481 .16187 m
.52481 .17778 L
.5252 .17778 L
.5252 .16187 L
s
.678 .847 .902 r
.5252 .16187 m
.5252 .17806 L
.52579 .17806 L
.52579 .16187 L
F
.2 .63 .79 r
.5252 .16187 m
.5252 .17806 L
.52579 .17806 L
.52579 .16187 L
s
.678 .847 .902 r
.52579 .16187 m
.52579 .17835 L
.52605 .17835 L
.52605 .16187 L
F
.2 .63 .79 r
.52579 .16187 m
.52579 .17835 L
.52605 .17835 L
.52605 .16187 L
s
.678 .847 .902 r
.52605 .16187 m
.52605 .17877 L
.52676 .17877 L
.52676 .16187 L
F
.2 .63 .79 r
.52605 .16187 m
.52605 .17877 L
.52676 .17877 L
.52676 .16187 L
s
.678 .847 .902 r
.52676 .16187 m
.52676 .17903 L
.52722 .17903 L
.52722 .16187 L
F
.2 .63 .79 r
.52676 .16187 m
.52676 .17903 L
.52722 .17903 L
.52722 .16187 L
s
.678 .847 .902 r
.52722 .16187 m
.52722 .17938 L
.52767 .17938 L
.52767 .16187 L
F
.2 .63 .79 r
.52722 .16187 m
.52722 .17938 L
.52767 .17938 L
.52767 .16187 L
s
.678 .847 .902 r
.52767 .16187 m
.52767 .17971 L
.52824 .17971 L
.52824 .16187 L
F
.2 .63 .79 r
.52767 .16187 m
.52767 .17971 L
.52824 .17971 L
.52824 .16187 L
s
.678 .847 .902 r
.52824 .16187 m
.52824 .17994 L
.52854 .17994 L
.52854 .16187 L
F
.2 .63 .79 r
.52824 .16187 m
.52824 .17994 L
.52854 .17994 L
.52854 .16187 L
s
.678 .847 .902 r
.52854 .16187 m
.52854 .18032 L
.52906 .18032 L
.52906 .16187 L
F
.2 .63 .79 r
.52854 .16187 m
.52854 .18032 L
.52906 .18032 L
.52906 .16187 L
s
.678 .847 .902 r
.52906 .16187 m
.52906 .18076 L
.52967 .18076 L
.52967 .16187 L
F
.2 .63 .79 r
.52906 .16187 m
.52906 .18076 L
.52967 .18076 L
.52967 .16187 L
s
.678 .847 .902 r
.52967 .16187 m
.52967 .18079 L
.53044 .18079 L
.53044 .16187 L
F
.2 .63 .79 r
.52967 .16187 m
.52967 .18079 L
.53044 .18079 L
.53044 .16187 L
s
.678 .847 .902 r
.53044 .16187 m
.53044 .18156 L
.53113 .18156 L
.53113 .16187 L
F
.2 .63 .79 r
.53044 .16187 m
.53044 .18156 L
.53113 .18156 L
.53113 .16187 L
s
.678 .847 .902 r
.53113 .16187 m
.53113 .1819 L
.53156 .1819 L
.53156 .16187 L
F
.2 .63 .79 r
.53113 .16187 m
.53113 .1819 L
.53156 .1819 L
.53156 .16187 L
s
.678 .847 .902 r
.53156 .16187 m
.53156 .18217 L
.53186 .18217 L
.53186 .16187 L
F
.2 .63 .79 r
.53156 .16187 m
.53156 .18217 L
.53186 .18217 L
.53186 .16187 L
s
.678 .847 .902 r
.53186 .16187 m
.53186 .18232 L
.53225 .18232 L
.53225 .16187 L
F
.2 .63 .79 r
.53186 .16187 m
.53186 .18232 L
.53225 .18232 L
.53225 .16187 L
s
.678 .847 .902 r
.53225 .16187 m
.53225 .18258 L
.5327 .18258 L
.5327 .16187 L
F
.2 .63 .79 r
.53225 .16187 m
.53225 .18258 L
.5327 .18258 L
.5327 .16187 L
s
.678 .847 .902 r
.5327 .16187 m
.5327 .18321 L
.53346 .18321 L
.53346 .16187 L
F
.2 .63 .79 r
.5327 .16187 m
.5327 .18321 L
.53346 .18321 L
.53346 .16187 L
s
.678 .847 .902 r
.53346 .16187 m
.53346 .18337 L
.53374 .18337 L
.53374 .16187 L
F
.2 .63 .79 r
.53346 .16187 m
.53346 .18337 L
.53374 .18337 L
.53374 .16187 L
s
.678 .847 .902 r
.53374 .16187 m
.53374 .1835 L
.53444 .1835 L
.53444 .16187 L
F
.2 .63 .79 r
.53374 .16187 m
.53374 .1835 L
.53444 .1835 L
.53444 .16187 L
s
.678 .847 .902 r
.53444 .16187 m
.53444 .1841 L
.53505 .1841 L
.53505 .16187 L
F
.2 .63 .79 r
.53444 .16187 m
.53444 .1841 L
.53505 .1841 L
.53505 .16187 L
s
.678 .847 .902 r
.53505 .16187 m
.53505 .1844 L
.53564 .1844 L
.53564 .16187 L
F
.2 .63 .79 r
.53505 .16187 m
.53505 .1844 L
.53564 .1844 L
.53564 .16187 L
s
.678 .847 .902 r
.53564 .16187 m
.53564 .18503 L
.53612 .18503 L
.53612 .16187 L
F
.2 .63 .79 r
.53564 .16187 m
.53564 .18503 L
.53612 .18503 L
.53612 .16187 L
s
.678 .847 .902 r
.53612 .16187 m
.53612 .18519 L
.53641 .18519 L
.53641 .16187 L
F
.2 .63 .79 r
.53612 .16187 m
.53612 .18519 L
.53641 .18519 L
.53641 .16187 L
s
.678 .847 .902 r
.53641 .16187 m
.53641 .18537 L
.53698 .18537 L
.53698 .16187 L
F
.2 .63 .79 r
.53641 .16187 m
.53641 .18537 L
.53698 .18537 L
.53698 .16187 L
s
.678 .847 .902 r
.53698 .16187 m
.53698 .18575 L
.53741 .18575 L
.53741 .16187 L
F
.2 .63 .79 r
.53698 .16187 m
.53698 .18575 L
.53741 .18575 L
.53741 .16187 L
s
.678 .847 .902 r
.53741 .16187 m
.53741 .1861 L
.53811 .1861 L
.53811 .16187 L
F
.2 .63 .79 r
.53741 .16187 m
.53741 .1861 L
.53811 .1861 L
.53811 .16187 L
s
.678 .847 .902 r
.53811 .16187 m
.53811 .18639 L
.53838 .18639 L
.53838 .16187 L
F
.2 .63 .79 r
.53811 .16187 m
.53811 .18639 L
.53838 .18639 L
.53838 .16187 L
s
.678 .847 .902 r
.53838 .16187 m
.53838 .1868 L
.53905 .1868 L
.53905 .16187 L
F
.2 .63 .79 r
.53838 .16187 m
.53838 .1868 L
.53905 .1868 L
.53905 .16187 L
s
.678 .847 .902 r
.53905 .16187 m
.53905 .18748 L
.53983 .18748 L
.53983 .16187 L
F
.2 .63 .79 r
.53905 .16187 m
.53905 .18748 L
.53983 .18748 L
.53983 .16187 L
s
.678 .847 .902 r
.53983 .16187 m
.53983 .18775 L
.54032 .18775 L
.54032 .16187 L
F
.2 .63 .79 r
.53983 .16187 m
.53983 .18775 L
.54032 .18775 L
.54032 .16187 L
s
.678 .847 .902 r
.54032 .16187 m
.54032 .18802 L
.54083 .18802 L
.54083 .16187 L
F
.2 .63 .79 r
.54032 .16187 m
.54032 .18802 L
.54083 .18802 L
.54083 .16187 L
s
.678 .847 .902 r
.54083 .16187 m
.54083 .1882 L
.54144 .1882 L
.54144 .16187 L
F
.2 .63 .79 r
.54083 .16187 m
.54083 .1882 L
.54144 .1882 L
.54144 .16187 L
s
.678 .847 .902 r
.54144 .16187 m
.54144 .18862 L
.54195 .18862 L
.54195 .16187 L
F
.2 .63 .79 r
.54144 .16187 m
.54144 .18862 L
.54195 .18862 L
.54195 .16187 L
s
.678 .847 .902 r
.54195 .16187 m
.54195 .18928 L
.54263 .18928 L
.54263 .16187 L
F
.2 .63 .79 r
.54195 .16187 m
.54195 .18928 L
.54263 .18928 L
.54263 .16187 L
s
.678 .847 .902 r
.54263 .16187 m
.54263 .18957 L
.54318 .18957 L
.54318 .16187 L
F
.2 .63 .79 r
.54263 .16187 m
.54263 .18957 L
.54318 .18957 L
.54318 .16187 L
s
.678 .847 .902 r
.54318 .16187 m
.54318 .18998 L
.54391 .18998 L
.54391 .16187 L
F
.2 .63 .79 r
.54318 .16187 m
.54318 .18998 L
.54391 .18998 L
.54391 .16187 L
s
.678 .847 .902 r
.54391 .16187 m
.54391 .19036 L
.54422 .19036 L
.54422 .16187 L
F
.2 .63 .79 r
.54391 .16187 m
.54391 .19036 L
.54422 .19036 L
.54422 .16187 L
s
.678 .847 .902 r
.54422 .16187 m
.54422 .19089 L
.54485 .19089 L
.54485 .16187 L
F
.2 .63 .79 r
.54422 .16187 m
.54422 .19089 L
.54485 .19089 L
.54485 .16187 L
s
.678 .847 .902 r
.54485 .16187 m
.54485 .19091 L
.54525 .19091 L
.54525 .16187 L
F
.2 .63 .79 r
.54485 .16187 m
.54485 .19091 L
.54525 .19091 L
.54525 .16187 L
s
.678 .847 .902 r
.54525 .16187 m
.54525 .19119 L
.54577 .19119 L
.54577 .16187 L
F
.2 .63 .79 r
.54525 .16187 m
.54525 .19119 L
.54577 .19119 L
.54577 .16187 L
s
.678 .847 .902 r
.54577 .16187 m
.54577 .19167 L
.54613 .19167 L
.54613 .16187 L
F
.2 .63 .79 r
.54577 .16187 m
.54577 .19167 L
.54613 .19167 L
.54613 .16187 L
s
.678 .847 .902 r
.54613 .16187 m
.54613 .19194 L
.54672 .19194 L
.54672 .16187 L
F
.2 .63 .79 r
.54613 .16187 m
.54613 .19194 L
.54672 .19194 L
.54672 .16187 L
s
.678 .847 .902 r
.54672 .16187 m
.54672 .1925 L
.54723 .1925 L
.54723 .16187 L
F
.2 .63 .79 r
.54672 .16187 m
.54672 .1925 L
.54723 .1925 L
.54723 .16187 L
s
.678 .847 .902 r
.54723 .16187 m
.54723 .19281 L
.54794 .19281 L
.54794 .16187 L
F
.2 .63 .79 r
.54723 .16187 m
.54723 .19281 L
.54794 .19281 L
.54794 .16187 L
s
.678 .847 .902 r
.54794 .16187 m
.54794 .19317 L
.54852 .19317 L
.54852 .16187 L
F
.2 .63 .79 r
.54794 .16187 m
.54794 .19317 L
.54852 .19317 L
.54852 .16187 L
s
.678 .847 .902 r
.54852 .16187 m
.54852 .1935 L
.54888 .1935 L
.54888 .16187 L
F
.2 .63 .79 r
.54852 .16187 m
.54852 .1935 L
.54888 .1935 L
.54888 .16187 L
s
.678 .847 .902 r
.54888 .16187 m
.54888 .19368 L
.54934 .19368 L
.54934 .16187 L
F
.2 .63 .79 r
.54888 .16187 m
.54888 .19368 L
.54934 .19368 L
.54934 .16187 L
s
.678 .847 .902 r
.54934 .16187 m
.54934 .19401 L
.54973 .19401 L
.54973 .16187 L
F
.2 .63 .79 r
.54934 .16187 m
.54934 .19401 L
.54973 .19401 L
.54973 .16187 L
s
.678 .847 .902 r
.54973 .16187 m
.54973 .19446 L
.55011 .19446 L
.55011 .16187 L
F
.2 .63 .79 r
.54973 .16187 m
.54973 .19446 L
.55011 .19446 L
.55011 .16187 L
s
.678 .847 .902 r
.55011 .16187 m
.55011 .19448 L
.55058 .19448 L
.55058 .16187 L
F
.2 .63 .79 r
.55011 .16187 m
.55011 .19448 L
.55058 .19448 L
.55058 .16187 L
s
.678 .847 .902 r
.55058 .16187 m
.55058 .19479 L
.55101 .19479 L
.55101 .16187 L
F
.2 .63 .79 r
.55058 .16187 m
.55058 .19479 L
.55101 .19479 L
.55101 .16187 L
s
.678 .847 .902 r
.55101 .16187 m
.55101 .19533 L
.55154 .19533 L
.55154 .16187 L
F
.2 .63 .79 r
.55101 .16187 m
.55101 .19533 L
.55154 .19533 L
.55154 .16187 L
s
.678 .847 .902 r
.55154 .16187 m
.55154 .19545 L
.55194 .19545 L
.55194 .16187 L
F
.2 .63 .79 r
.55154 .16187 m
.55154 .19545 L
.55194 .19545 L
.55194 .16187 L
s
.678 .847 .902 r
.55194 .16187 m
.55194 .19589 L
.55273 .19589 L
.55273 .16187 L
F
.2 .63 .79 r
.55194 .16187 m
.55194 .19589 L
.55273 .19589 L
.55273 .16187 L
s
.678 .847 .902 r
.55273 .16187 m
.55273 .19651 L
.55347 .19651 L
.55347 .16187 L
F
.2 .63 .79 r
.55273 .16187 m
.55273 .19651 L
.55347 .19651 L
.55347 .16187 L
s
.678 .847 .902 r
.55347 .16187 m
.55347 .19707 L
.55419 .19707 L
.55419 .16187 L
F
.2 .63 .79 r
.55347 .16187 m
.55347 .19707 L
.55419 .19707 L
.55419 .16187 L
s
.678 .847 .902 r
.55419 .16187 m
.55419 .19771 L
.55489 .19771 L
.55489 .16187 L
F
.2 .63 .79 r
.55419 .16187 m
.55419 .19771 L
.55489 .19771 L
.55489 .16187 L
s
.678 .847 .902 r
.55489 .16187 m
.55489 .19788 L
.55524 .19788 L
.55524 .16187 L
F
.2 .63 .79 r
.55489 .16187 m
.55489 .19788 L
.55524 .19788 L
.55524 .16187 L
s
.678 .847 .902 r
.55524 .16187 m
.55524 .19799 L
.55567 .19799 L
.55567 .16187 L
F
.2 .63 .79 r
.55524 .16187 m
.55524 .19799 L
.55567 .19799 L
.55567 .16187 L
s
.678 .847 .902 r
.55567 .16187 m
.55567 .19838 L
.55647 .19838 L
.55647 .16187 L
F
.2 .63 .79 r
.55567 .16187 m
.55567 .19838 L
.55647 .19838 L
.55647 .16187 L
s
.678 .847 .902 r
.55647 .16187 m
.55647 .19901 L
.5571 .19901 L
.5571 .16187 L
F
.2 .63 .79 r
.55647 .16187 m
.55647 .19901 L
.5571 .19901 L
.5571 .16187 L
s
.678 .847 .902 r
.5571 .16187 m
.5571 .19948 L
.55762 .19948 L
.55762 .16187 L
F
.2 .63 .79 r
.5571 .16187 m
.5571 .19948 L
.55762 .19948 L
.55762 .16187 L
s
.678 .847 .902 r
.55762 .16187 m
.55762 .19981 L
.5579 .19981 L
.5579 .16187 L
F
.2 .63 .79 r
.55762 .16187 m
.55762 .19981 L
.5579 .19981 L
.5579 .16187 L
s
.678 .847 .902 r
.5579 .16187 m
.5579 .19986 L
.55842 .19986 L
.55842 .16187 L
F
.2 .63 .79 r
.5579 .16187 m
.5579 .19986 L
.55842 .19986 L
.55842 .16187 L
s
.678 .847 .902 r
.55842 .16187 m
.55842 .20046 L
.55893 .20046 L
.55893 .16187 L
F
.2 .63 .79 r
.55842 .16187 m
.55842 .20046 L
.55893 .20046 L
.55893 .16187 L
s
.678 .847 .902 r
.55893 .16187 m
.55893 .20059 L
.55967 .20059 L
.55967 .16187 L
F
.2 .63 .79 r
.55893 .16187 m
.55893 .20059 L
.55967 .20059 L
.55967 .16187 L
s
.678 .847 .902 r
.55967 .16187 m
.55967 .20144 L
.56024 .20144 L
.56024 .16187 L
F
.2 .63 .79 r
.55967 .16187 m
.55967 .20144 L
.56024 .20144 L
.56024 .16187 L
s
.678 .847 .902 r
.56024 .16187 m
.56024 .20165 L
.56086 .20165 L
.56086 .16187 L
F
.2 .63 .79 r
.56024 .16187 m
.56024 .20165 L
.56086 .20165 L
.56086 .16187 L
s
.678 .847 .902 r
.56086 .16187 m
.56086 .20204 L
.5616 .20204 L
.5616 .16187 L
F
.2 .63 .79 r
.56086 .16187 m
.56086 .20204 L
.5616 .20204 L
.5616 .16187 L
s
.678 .847 .902 r
.5616 .16187 m
.5616 .20266 L
.56222 .20266 L
.56222 .16187 L
F
.2 .63 .79 r
.5616 .16187 m
.5616 .20266 L
.56222 .20266 L
.56222 .16187 L
s
.678 .847 .902 r
.56222 .16187 m
.56222 .20303 L
.56258 .20303 L
.56258 .16187 L
F
.2 .63 .79 r
.56222 .16187 m
.56222 .20303 L
.56258 .20303 L
.56258 .16187 L
s
.678 .847 .902 r
.56258 .16187 m
.56258 .20315 L
.56305 .20315 L
.56305 .16187 L
F
.2 .63 .79 r
.56258 .16187 m
.56258 .20315 L
.56305 .20315 L
.56305 .16187 L
s
.678 .847 .902 r
.56305 .16187 m
.56305 .20355 L
.56364 .20355 L
.56364 .16187 L
F
.2 .63 .79 r
.56305 .16187 m
.56305 .20355 L
.56364 .20355 L
.56364 .16187 L
s
.678 .847 .902 r
.56364 .16187 m
.56364 .20399 L
.56405 .20399 L
.56405 .16187 L
F
.2 .63 .79 r
.56364 .16187 m
.56364 .20399 L
.56405 .20399 L
.56405 .16187 L
s
.678 .847 .902 r
.56405 .16187 m
.56405 .2045 L
.56477 .2045 L
.56477 .16187 L
F
.2 .63 .79 r
.56405 .16187 m
.56405 .2045 L
.56477 .2045 L
.56477 .16187 L
s
.678 .847 .902 r
.56477 .16187 m
.56477 .2049 L
.56553 .2049 L
.56553 .16187 L
F
.2 .63 .79 r
.56477 .16187 m
.56477 .2049 L
.56553 .2049 L
.56553 .16187 L
s
.678 .847 .902 r
.56553 .16187 m
.56553 .20525 L
.56596 .20525 L
.56596 .16187 L
F
.2 .63 .79 r
.56553 .16187 m
.56553 .20525 L
.56596 .20525 L
.56596 .16187 L
s
.678 .847 .902 r
.56596 .16187 m
.56596 .20553 L
.56638 .20553 L
.56638 .16187 L
F
.2 .63 .79 r
.56596 .16187 m
.56596 .20553 L
.56638 .20553 L
.56638 .16187 L
s
.678 .847 .902 r
.56638 .16187 m
.56638 .2059 L
.56718 .2059 L
.56718 .16187 L
F
.2 .63 .79 r
.56638 .16187 m
.56638 .2059 L
.56718 .2059 L
.56718 .16187 L
s
.678 .847 .902 r
.56718 .16187 m
.56718 .20649 L
.56746 .20649 L
.56746 .16187 L
F
.2 .63 .79 r
.56718 .16187 m
.56718 .20649 L
.56746 .20649 L
.56746 .16187 L
s
.678 .847 .902 r
.56746 .16187 m
.56746 .20665 L
.56799 .20665 L
.56799 .16187 L
F
.2 .63 .79 r
.56746 .16187 m
.56746 .20665 L
.56799 .20665 L
.56799 .16187 L
s
.678 .847 .902 r
.56799 .16187 m
.56799 .20704 L
.56831 .20704 L
.56831 .16187 L
F
.2 .63 .79 r
.56799 .16187 m
.56799 .20704 L
.56831 .20704 L
.56831 .16187 L
s
.678 .847 .902 r
.56831 .16187 m
.56831 .20721 L
.56892 .20721 L
.56892 .16187 L
F
.2 .63 .79 r
.56831 .16187 m
.56831 .20721 L
.56892 .20721 L
.56892 .16187 L
s
.678 .847 .902 r
.56892 .16187 m
.56892 .20769 L
.56921 .20769 L
.56921 .16187 L
F
.2 .63 .79 r
.56892 .16187 m
.56892 .20769 L
.56921 .20769 L
.56921 .16187 L
s
.678 .847 .902 r
.56921 .16187 m
.56921 .20823 L
.56991 .20823 L
.56991 .16187 L
F
.2 .63 .79 r
.56921 .16187 m
.56921 .20823 L
.56991 .20823 L
.56991 .16187 L
s
.678 .847 .902 r
.56991 .16187 m
.56991 .20829 L
.57051 .20829 L
.57051 .16187 L
F
.2 .63 .79 r
.56991 .16187 m
.56991 .20829 L
.57051 .20829 L
.57051 .16187 L
s
.678 .847 .902 r
.57051 .16187 m
.57051 .20879 L
.57109 .20879 L
.57109 .16187 L
F
.2 .63 .79 r
.57051 .16187 m
.57051 .20879 L
.57109 .20879 L
.57109 .16187 L
s
.678 .847 .902 r
.57109 .16187 m
.57109 .20935 L
.57167 .20935 L
.57167 .16187 L
F
.2 .63 .79 r
.57109 .16187 m
.57109 .20935 L
.57167 .20935 L
.57167 .16187 L
s
.678 .847 .902 r
.57167 .16187 m
.57167 .20956 L
.5721 .20956 L
.5721 .16187 L
F
.2 .63 .79 r
.57167 .16187 m
.57167 .20956 L
.5721 .20956 L
.5721 .16187 L
s
.678 .847 .902 r
.5721 .16187 m
.5721 .2098 L
.57277 .2098 L
.57277 .16187 L
F
.2 .63 .79 r
.5721 .16187 m
.5721 .2098 L
.57277 .2098 L
.57277 .16187 L
s
.678 .847 .902 r
.57277 .16187 m
.57277 .21034 L
.57301 .21034 L
.57301 .16187 L
F
.2 .63 .79 r
.57277 .16187 m
.57277 .21034 L
.57301 .21034 L
.57301 .16187 L
s
.678 .847 .902 r
.57301 .16187 m
.57301 .21055 L
.57378 .21055 L
.57378 .16187 L
F
.2 .63 .79 r
.57301 .16187 m
.57301 .21055 L
.57378 .21055 L
.57378 .16187 L
s
.678 .847 .902 r
.57378 .16187 m
.57378 .21133 L
.57429 .21133 L
.57429 .16187 L
F
.2 .63 .79 r
.57378 .16187 m
.57378 .21133 L
.57429 .21133 L
.57429 .16187 L
s
.678 .847 .902 r
.57429 .16187 m
.57429 .21144 L
.57457 .21144 L
.57457 .16187 L
F
.2 .63 .79 r
.57429 .16187 m
.57429 .21144 L
.57457 .21144 L
.57457 .16187 L
s
.678 .847 .902 r
.57457 .16187 m
.57457 .21185 L
.57527 .21185 L
.57527 .16187 L
F
.2 .63 .79 r
.57457 .16187 m
.57457 .21185 L
.57527 .21185 L
.57527 .16187 L
s
.678 .847 .902 r
.57527 .16187 m
.57527 .21244 L
.57581 .21244 L
.57581 .16187 L
F
.2 .63 .79 r
.57527 .16187 m
.57527 .21244 L
.57581 .21244 L
.57581 .16187 L
s
.678 .847 .902 r
.57581 .16187 m
.57581 .21274 L
.57653 .21274 L
.57653 .16187 L
F
.2 .63 .79 r
.57581 .16187 m
.57581 .21274 L
.57653 .21274 L
.57653 .16187 L
s
.678 .847 .902 r
.57653 .16187 m
.57653 .21337 L
.57721 .21337 L
.57721 .16187 L
F
.2 .63 .79 r
.57653 .16187 m
.57653 .21337 L
.57721 .21337 L
.57721 .16187 L
s
.678 .847 .902 r
.57721 .16187 m
.57721 .21392 L
.57799 .21392 L
.57799 .16187 L
F
.2 .63 .79 r
.57721 .16187 m
.57721 .21392 L
.57799 .21392 L
.57799 .16187 L
s
.678 .847 .902 r
.57799 .16187 m
.57799 .21421 L
.57858 .21421 L
.57858 .16187 L
F
.2 .63 .79 r
.57799 .16187 m
.57799 .21421 L
.57858 .21421 L
.57858 .16187 L
s
.678 .847 .902 r
.57858 .16187 m
.57858 .21454 L
.57911 .21454 L
.57911 .16187 L
F
.2 .63 .79 r
.57858 .16187 m
.57858 .21454 L
.57911 .21454 L
.57911 .16187 L
s
.678 .847 .902 r
.57911 .16187 m
.57911 .21504 L
.57962 .21504 L
.57962 .16187 L
F
.2 .63 .79 r
.57911 .16187 m
.57911 .21504 L
.57962 .21504 L
.57962 .16187 L
s
.678 .847 .902 r
.57962 .16187 m
.57962 .21551 L
.58041 .21551 L
.58041 .16187 L
F
.2 .63 .79 r
.57962 .16187 m
.57962 .21551 L
.58041 .21551 L
.58041 .16187 L
s
.678 .847 .902 r
.58041 .16187 m
.58041 .21597 L
.58096 .21597 L
.58096 .16187 L
F
.2 .63 .79 r
.58041 .16187 m
.58041 .21597 L
.58096 .21597 L
.58096 .16187 L
s
.678 .847 .902 r
.58096 .16187 m
.58096 .21631 L
.58121 .21631 L
.58121 .16187 L
F
.2 .63 .79 r
.58096 .16187 m
.58096 .21631 L
.58121 .21631 L
.58121 .16187 L
s
.678 .847 .902 r
.58121 .16187 m
.58121 .21662 L
.58164 .21662 L
.58164 .16187 L
F
.2 .63 .79 r
.58121 .16187 m
.58121 .21662 L
.58164 .21662 L
.58164 .16187 L
s
.678 .847 .902 r
.58164 .16187 m
.58164 .21674 L
.58206 .21674 L
.58206 .16187 L
F
.2 .63 .79 r
.58164 .16187 m
.58164 .21674 L
.58206 .21674 L
.58206 .16187 L
s
.678 .847 .902 r
.58206 .16187 m
.58206 .21724 L
.58256 .21724 L
.58256 .16187 L
F
.2 .63 .79 r
.58206 .16187 m
.58206 .21724 L
.58256 .21724 L
.58256 .16187 L
s
.678 .847 .902 r
.58256 .16187 m
.58256 .21754 L
.58291 .21754 L
.58291 .16187 L
F
.2 .63 .79 r
.58256 .16187 m
.58256 .21754 L
.58291 .21754 L
.58291 .16187 L
s
.678 .847 .902 r
.58291 .16187 m
.58291 .21794 L
.58355 .21794 L
.58355 .16187 L
F
.2 .63 .79 r
.58291 .16187 m
.58291 .21794 L
.58355 .21794 L
.58355 .16187 L
s
.678 .847 .902 r
.58355 .16187 m
.58355 .21804 L
.5842 .21804 L
.5842 .16187 L
F
.2 .63 .79 r
.58355 .16187 m
.58355 .21804 L
.5842 .21804 L
.5842 .16187 L
s
.678 .847 .902 r
.5842 .16187 m
.5842 .21858 L
.58492 .21858 L
.58492 .16187 L
F
.2 .63 .79 r
.5842 .16187 m
.5842 .21858 L
.58492 .21858 L
.58492 .16187 L
s
.678 .847 .902 r
.58492 .16187 m
.58492 .2194 L
.58565 .2194 L
.58565 .16187 L
F
.2 .63 .79 r
.58492 .16187 m
.58492 .2194 L
.58565 .2194 L
.58565 .16187 L
s
.678 .847 .902 r
.58565 .16187 m
.58565 .22001 L
.58643 .22001 L
.58643 .16187 L
F
.2 .63 .79 r
.58565 .16187 m
.58565 .22001 L
.58643 .22001 L
.58643 .16187 L
s
.678 .847 .902 r
.58643 .16187 m
.58643 .22045 L
.58707 .22045 L
.58707 .16187 L
F
.2 .63 .79 r
.58643 .16187 m
.58643 .22045 L
.58707 .22045 L
.58707 .16187 L
s
.678 .847 .902 r
.58707 .16187 m
.58707 .22114 L
.58784 .22114 L
.58784 .16187 L
F
.2 .63 .79 r
.58707 .16187 m
.58707 .22114 L
.58784 .22114 L
.58784 .16187 L
s
.678 .847 .902 r
.58784 .16187 m
.58784 .22143 L
.5883 .22143 L
.5883 .16187 L
F
.2 .63 .79 r
.58784 .16187 m
.58784 .22143 L
.5883 .22143 L
.5883 .16187 L
s
.678 .847 .902 r
.5883 .16187 m
.5883 .22172 L
.58904 .22172 L
.58904 .16187 L
F
.2 .63 .79 r
.5883 .16187 m
.5883 .22172 L
.58904 .22172 L
.58904 .16187 L
s
.678 .847 .902 r
.58904 .16187 m
.58904 .2221 L
.5898 .2221 L
.5898 .16187 L
F
.2 .63 .79 r
.58904 .16187 m
.58904 .2221 L
.5898 .2221 L
.5898 .16187 L
s
.678 .847 .902 r
.5898 .16187 m
.5898 .22293 L
.59027 .22293 L
.59027 .16187 L
F
.2 .63 .79 r
.5898 .16187 m
.5898 .22293 L
.59027 .22293 L
.59027 .16187 L
s
.678 .847 .902 r
.59027 .16187 m
.59027 .22303 L
.59082 .22303 L
.59082 .16187 L
F
.2 .63 .79 r
.59027 .16187 m
.59027 .22303 L
.59082 .22303 L
.59082 .16187 L
s
.678 .847 .902 r
.59082 .16187 m
.59082 .22347 L
.59111 .22347 L
.59111 .16187 L
F
.2 .63 .79 r
.59082 .16187 m
.59082 .22347 L
.59111 .22347 L
.59111 .16187 L
s
.678 .847 .902 r
.59111 .16187 m
.59111 .22372 L
.59189 .22372 L
.59189 .16187 L
F
.2 .63 .79 r
.59111 .16187 m
.59111 .22372 L
.59189 .22372 L
.59189 .16187 L
s
.678 .847 .902 r
.59189 .16187 m
.59189 .22441 L
.59258 .22441 L
.59258 .16187 L
F
.2 .63 .79 r
.59189 .16187 m
.59189 .22441 L
.59258 .22441 L
.59258 .16187 L
s
.678 .847 .902 r
.59258 .16187 m
.59258 .22483 L
.59284 .22483 L
.59284 .16187 L
F
.2 .63 .79 r
.59258 .16187 m
.59258 .22483 L
.59284 .22483 L
.59284 .16187 L
s
.678 .847 .902 r
.59284 .16187 m
.59284 .22527 L
.59344 .22527 L
.59344 .16187 L
F
.2 .63 .79 r
.59284 .16187 m
.59284 .22527 L
.59344 .22527 L
.59344 .16187 L
s
.678 .847 .902 r
.59344 .16187 m
.59344 .2257 L
.59424 .2257 L
.59424 .16187 L
F
.2 .63 .79 r
.59344 .16187 m
.59344 .2257 L
.59424 .2257 L
.59424 .16187 L
s
.678 .847 .902 r
.59424 .16187 m
.59424 .22615 L
.59462 .22615 L
.59462 .16187 L
F
.2 .63 .79 r
.59424 .16187 m
.59424 .22615 L
.59462 .22615 L
.59462 .16187 L
s
.678 .847 .902 r
.59462 .16187 m
.59462 .22617 L
.59488 .22617 L
.59488 .16187 L
F
.2 .63 .79 r
.59462 .16187 m
.59462 .22617 L
.59488 .22617 L
.59488 .16187 L
s
.678 .847 .902 r
.59488 .16187 m
.59488 .22636 L
.59528 .22636 L
.59528 .16187 L
F
.2 .63 .79 r
.59488 .16187 m
.59488 .22636 L
.59528 .22636 L
.59528 .16187 L
s
.678 .847 .902 r
.59528 .16187 m
.59528 .22682 L
.5959 .22682 L
.5959 .16187 L
F
.2 .63 .79 r
.59528 .16187 m
.59528 .22682 L
.5959 .22682 L
.5959 .16187 L
s
.678 .847 .902 r
.5959 .16187 m
.5959 .22721 L
.5966 .22721 L
.5966 .16187 L
F
.2 .63 .79 r
.5959 .16187 m
.5959 .22721 L
.5966 .22721 L
.5966 .16187 L
s
.678 .847 .902 r
.5966 .16187 m
.5966 .22771 L
.5973 .22771 L
.5973 .16187 L
F
.2 .63 .79 r
.5966 .16187 m
.5966 .22771 L
.5973 .22771 L
.5973 .16187 L
s
.678 .847 .902 r
.5973 .16187 m
.5973 .22826 L
.59787 .22826 L
.59787 .16187 L
F
.2 .63 .79 r
.5973 .16187 m
.5973 .22826 L
.59787 .22826 L
.59787 .16187 L
s
.678 .847 .902 r
.59787 .16187 m
.59787 .22879 L
.59865 .22879 L
.59865 .16187 L
F
.2 .63 .79 r
.59787 .16187 m
.59787 .22879 L
.59865 .22879 L
.59865 .16187 L
s
.678 .847 .902 r
.59865 .16187 m
.59865 .22919 L
.59943 .22919 L
.59943 .16187 L
F
.2 .63 .79 r
.59865 .16187 m
.59865 .22919 L
.59943 .22919 L
.59943 .16187 L
s
.678 .847 .902 r
.59943 .16187 m
.59943 .23001 L
.60022 .23001 L
.60022 .16187 L
F
.2 .63 .79 r
.59943 .16187 m
.59943 .23001 L
.60022 .23001 L
.60022 .16187 L
s
.678 .847 .902 r
.60022 .16187 m
.60022 .23054 L
.60081 .23054 L
.60081 .16187 L
F
.2 .63 .79 r
.60022 .16187 m
.60022 .23054 L
.60081 .23054 L
.60081 .16187 L
s
.678 .847 .902 r
.60081 .16187 m
.60081 .23097 L
.60119 .23097 L
.60119 .16187 L
F
.2 .63 .79 r
.60081 .16187 m
.60081 .23097 L
.60119 .23097 L
.60119 .16187 L
s
.678 .847 .902 r
.60119 .16187 m
.60119 .23107 L
.60145 .23107 L
.60145 .16187 L
F
.2 .63 .79 r
.60119 .16187 m
.60119 .23107 L
.60145 .23107 L
.60145 .16187 L
s
.678 .847 .902 r
.60145 .16187 m
.60145 .23153 L
.60201 .23153 L
.60201 .16187 L
F
.2 .63 .79 r
.60145 .16187 m
.60145 .23153 L
.60201 .23153 L
.60201 .16187 L
s
.678 .847 .902 r
.60201 .16187 m
.60201 .23171 L
.60267 .23171 L
.60267 .16187 L
F
.2 .63 .79 r
.60201 .16187 m
.60201 .23171 L
.60267 .23171 L
.60267 .16187 L
s
.678 .847 .902 r
.60267 .16187 m
.60267 .23236 L
.60311 .23236 L
.60311 .16187 L
F
.2 .63 .79 r
.60267 .16187 m
.60267 .23236 L
.60311 .23236 L
.60311 .16187 L
s
.678 .847 .902 r
.60311 .16187 m
.60311 .23255 L
.6037 .23255 L
.6037 .16187 L
F
.2 .63 .79 r
.60311 .16187 m
.60311 .23255 L
.6037 .23255 L
.6037 .16187 L
s
.678 .847 .902 r
.6037 .16187 m
.6037 .23302 L
.60396 .23302 L
.60396 .16187 L
F
.2 .63 .79 r
.6037 .16187 m
.6037 .23302 L
.60396 .23302 L
.60396 .16187 L
s
.678 .847 .902 r
.60396 .16187 m
.60396 .23337 L
.60457 .23337 L
.60457 .16187 L
F
.2 .63 .79 r
.60396 .16187 m
.60396 .23337 L
.60457 .23337 L
.60457 .16187 L
s
.678 .847 .902 r
.60457 .16187 m
.60457 .2337 L
.60503 .2337 L
.60503 .16187 L
F
.2 .63 .79 r
.60457 .16187 m
.60457 .2337 L
.60503 .2337 L
.60503 .16187 L
s
.678 .847 .902 r
.60503 .16187 m
.60503 .23426 L
.60573 .23426 L
.60573 .16187 L
F
.2 .63 .79 r
.60503 .16187 m
.60503 .23426 L
.60573 .23426 L
.60573 .16187 L
s
.678 .847 .902 r
.60573 .16187 m
.60573 .23478 L
.60654 .23478 L
.60654 .16187 L
F
.2 .63 .79 r
.60573 .16187 m
.60573 .23478 L
.60654 .23478 L
.60654 .16187 L
s
.678 .847 .902 r
.60654 .16187 m
.60654 .23519 L
.6068 .23519 L
.6068 .16187 L
F
.2 .63 .79 r
.60654 .16187 m
.60654 .23519 L
.6068 .23519 L
.6068 .16187 L
s
.678 .847 .902 r
.6068 .16187 m
.6068 .23549 L
.60727 .23549 L
.60727 .16187 L
F
.2 .63 .79 r
.6068 .16187 m
.6068 .23549 L
.60727 .23549 L
.60727 .16187 L
s
.678 .847 .902 r
.60727 .16187 m
.60727 .23589 L
.60783 .23589 L
.60783 .16187 L
F
.2 .63 .79 r
.60727 .16187 m
.60727 .23589 L
.60783 .23589 L
.60783 .16187 L
s
.678 .847 .902 r
.60783 .16187 m
.60783 .23632 L
.60862 .23632 L
.60862 .16187 L
F
.2 .63 .79 r
.60783 .16187 m
.60783 .23632 L
.60862 .23632 L
.60862 .16187 L
s
.678 .847 .902 r
.60862 .16187 m
.60862 .2369 L
.60929 .2369 L
.60929 .16187 L
F
.2 .63 .79 r
.60862 .16187 m
.60862 .2369 L
.60929 .2369 L
.60929 .16187 L
s
.678 .847 .902 r
.60929 .16187 m
.60929 .23727 L
.60994 .23727 L
.60994 .16187 L
F
.2 .63 .79 r
.60929 .16187 m
.60929 .23727 L
.60994 .23727 L
.60994 .16187 L
s
.678 .847 .902 r
.60994 .16187 m
.60994 .23787 L
.61062 .23787 L
.61062 .16187 L
F
.2 .63 .79 r
.60994 .16187 m
.60994 .23787 L
.61062 .23787 L
.61062 .16187 L
s
.678 .847 .902 r
.61062 .16187 m
.61062 .23824 L
.61095 .23824 L
.61095 .16187 L
F
.2 .63 .79 r
.61062 .16187 m
.61062 .23824 L
.61095 .23824 L
.61095 .16187 L
s
.678 .847 .902 r
.61095 .16187 m
.61095 .23848 L
.61129 .23848 L
.61129 .16187 L
F
.2 .63 .79 r
.61095 .16187 m
.61095 .23848 L
.61129 .23848 L
.61129 .16187 L
s
.678 .847 .902 r
.61129 .16187 m
.61129 .23912 L
.61196 .23912 L
.61196 .16187 L
F
.2 .63 .79 r
.61129 .16187 m
.61129 .23912 L
.61196 .23912 L
.61196 .16187 L
s
.678 .847 .902 r
.61196 .16187 m
.61196 .23939 L
.61267 .23939 L
.61267 .16187 L
F
.2 .63 .79 r
.61196 .16187 m
.61196 .23939 L
.61267 .23939 L
.61267 .16187 L
s
.678 .847 .902 r
.61267 .16187 m
.61267 .23995 L
.61302 .23995 L
.61302 .16187 L
F
.2 .63 .79 r
.61267 .16187 m
.61267 .23995 L
.61302 .23995 L
.61302 .16187 L
s
.678 .847 .902 r
.61302 .16187 m
.61302 .24032 L
.61357 .24032 L
.61357 .16187 L
F
.2 .63 .79 r
.61302 .16187 m
.61302 .24032 L
.61357 .24032 L
.61357 .16187 L
s
.678 .847 .902 r
.61357 .16187 m
.61357 .24049 L
.61411 .24049 L
.61411 .16187 L
F
.2 .63 .79 r
.61357 .16187 m
.61357 .24049 L
.61411 .24049 L
.61411 .16187 L
s
.678 .847 .902 r
.61411 .16187 m
.61411 .24096 L
.6148 .24096 L
.6148 .16187 L
F
.2 .63 .79 r
.61411 .16187 m
.61411 .24096 L
.6148 .24096 L
.6148 .16187 L
s
.678 .847 .902 r
.6148 .16187 m
.6148 .24142 L
.61539 .24142 L
.61539 .16187 L
F
.2 .63 .79 r
.6148 .16187 m
.6148 .24142 L
.61539 .24142 L
.61539 .16187 L
s
.678 .847 .902 r
.61539 .16187 m
.61539 .24217 L
.61609 .24217 L
.61609 .16187 L
F
.2 .63 .79 r
.61539 .16187 m
.61539 .24217 L
.61609 .24217 L
.61609 .16187 L
s
.678 .847 .902 r
.61609 .16187 m
.61609 .2425 L
.61643 .2425 L
.61643 .16187 L
F
.2 .63 .79 r
.61609 .16187 m
.61609 .2425 L
.61643 .2425 L
.61643 .16187 L
s
.678 .847 .902 r
.61643 .16187 m
.61643 .24265 L
.61678 .24265 L
.61678 .16187 L
F
.2 .63 .79 r
.61643 .16187 m
.61643 .24265 L
.61678 .24265 L
.61678 .16187 L
s
.678 .847 .902 r
.61678 .16187 m
.61678 .24318 L
.61735 .24318 L
.61735 .16187 L
F
.2 .63 .79 r
.61678 .16187 m
.61678 .24318 L
.61735 .24318 L
.61735 .16187 L
s
.678 .847 .902 r
.61735 .16187 m
.61735 .24336 L
.61769 .24336 L
.61769 .16187 L
F
.2 .63 .79 r
.61735 .16187 m
.61735 .24336 L
.61769 .24336 L
.61769 .16187 L
s
.678 .847 .902 r
.61769 .16187 m
.61769 .2437 L
.61837 .2437 L
.61837 .16187 L
F
.2 .63 .79 r
.61769 .16187 m
.61769 .2437 L
.61837 .2437 L
.61837 .16187 L
s
.678 .847 .902 r
.61837 .16187 m
.61837 .24429 L
.61882 .24429 L
.61882 .16187 L
F
.2 .63 .79 r
.61837 .16187 m
.61837 .24429 L
.61882 .24429 L
.61882 .16187 L
s
.678 .847 .902 r
.61882 .16187 m
.61882 .24453 L
.6194 .24453 L
.6194 .16187 L
F
.2 .63 .79 r
.61882 .16187 m
.61882 .24453 L
.6194 .24453 L
.6194 .16187 L
s
.678 .847 .902 r
.6194 .16187 m
.6194 .24505 L
.61971 .24505 L
.61971 .16187 L
F
.2 .63 .79 r
.6194 .16187 m
.6194 .24505 L
.61971 .24505 L
.61971 .16187 L
s
.678 .847 .902 r
.61971 .16187 m
.61971 .24537 L
.62017 .24537 L
.62017 .16187 L
F
.2 .63 .79 r
.61971 .16187 m
.61971 .24537 L
.62017 .24537 L
.62017 .16187 L
s
.678 .847 .902 r
.62017 .16187 m
.62017 .24599 L
.62087 .24599 L
.62087 .16187 L
F
.2 .63 .79 r
.62017 .16187 m
.62017 .24599 L
.62087 .24599 L
.62087 .16187 L
s
.678 .847 .902 r
.62087 .16187 m
.62087 .24637 L
.62146 .24637 L
.62146 .16187 L
F
.2 .63 .79 r
.62087 .16187 m
.62087 .24637 L
.62146 .24637 L
.62146 .16187 L
s
.678 .847 .902 r
.62146 .16187 m
.62146 .24654 L
.62191 .24654 L
.62191 .16187 L
F
.2 .63 .79 r
.62146 .16187 m
.62146 .24654 L
.62191 .24654 L
.62191 .16187 L
s
.678 .847 .902 r
.62191 .16187 m
.62191 .24704 L
.62253 .24704 L
.62253 .16187 L
F
.2 .63 .79 r
.62191 .16187 m
.62191 .24704 L
.62253 .24704 L
.62253 .16187 L
s
.678 .847 .902 r
.62253 .16187 m
.62253 .24743 L
.62279 .24743 L
.62279 .16187 L
F
.2 .63 .79 r
.62253 .16187 m
.62253 .24743 L
.62279 .24743 L
.62279 .16187 L
s
.678 .847 .902 r
.62279 .16187 m
.62279 .24771 L
.6233 .24771 L
.6233 .16187 L
F
.2 .63 .79 r
.62279 .16187 m
.62279 .24771 L
.6233 .24771 L
.6233 .16187 L
s
.678 .847 .902 r
.6233 .16187 m
.6233 .24817 L
.62365 .24817 L
.62365 .16187 L
F
.2 .63 .79 r
.6233 .16187 m
.6233 .24817 L
.62365 .24817 L
.62365 .16187 L
s
.678 .847 .902 r
.62365 .16187 m
.62365 .24852 L
.6244 .24852 L
.6244 .16187 L
F
.2 .63 .79 r
.62365 .16187 m
.62365 .24852 L
.6244 .24852 L
.6244 .16187 L
s
.678 .847 .902 r
.6244 .16187 m
.6244 .24883 L
.62476 .24883 L
.62476 .16187 L
F
.2 .63 .79 r
.6244 .16187 m
.6244 .24883 L
.62476 .24883 L
.62476 .16187 L
s
.678 .847 .902 r
.62476 .16187 m
.62476 .24927 L
.62516 .24927 L
.62516 .16187 L
F
.2 .63 .79 r
.62476 .16187 m
.62476 .24927 L
.62516 .24927 L
.62516 .16187 L
s
.678 .847 .902 r
.62516 .16187 m
.62516 .24945 L
.62576 .24945 L
.62576 .16187 L
F
.2 .63 .79 r
.62516 .16187 m
.62516 .24945 L
.62576 .24945 L
.62576 .16187 L
s
.678 .847 .902 r
.62576 .16187 m
.62576 .24999 L
.62622 .24999 L
.62622 .16187 L
F
.2 .63 .79 r
.62576 .16187 m
.62576 .24999 L
.62622 .24999 L
.62622 .16187 L
s
.678 .847 .902 r
.62622 .16187 m
.62622 .25055 L
.6267 .25055 L
.6267 .16187 L
F
.2 .63 .79 r
.62622 .16187 m
.62622 .25055 L
.6267 .25055 L
.6267 .16187 L
s
.678 .847 .902 r
.6267 .16187 m
.6267 .25083 L
.62731 .25083 L
.62731 .16187 L
F
.2 .63 .79 r
.6267 .16187 m
.6267 .25083 L
.62731 .25083 L
.62731 .16187 L
s
.678 .847 .902 r
.62731 .16187 m
.62731 .25134 L
.62802 .25134 L
.62802 .16187 L
F
.2 .63 .79 r
.62731 .16187 m
.62731 .25134 L
.62802 .25134 L
.62802 .16187 L
s
.678 .847 .902 r
.62802 .16187 m
.62802 .25186 L
.62838 .25186 L
.62838 .16187 L
F
.2 .63 .79 r
.62802 .16187 m
.62802 .25186 L
.62838 .25186 L
.62838 .16187 L
s
.678 .847 .902 r
.62838 .16187 m
.62838 .25214 L
.62876 .25214 L
.62876 .16187 L
F
.2 .63 .79 r
.62838 .16187 m
.62838 .25214 L
.62876 .25214 L
.62876 .16187 L
s
.678 .847 .902 r
.62876 .16187 m
.62876 .25239 L
.62904 .25239 L
.62904 .16187 L
F
.2 .63 .79 r
.62876 .16187 m
.62876 .25239 L
.62904 .25239 L
.62904 .16187 L
s
.678 .847 .902 r
.62904 .16187 m
.62904 .2526 L
.62965 .2526 L
.62965 .16187 L
F
.2 .63 .79 r
.62904 .16187 m
.62904 .2526 L
.62965 .2526 L
.62965 .16187 L
s
.678 .847 .902 r
.62965 .16187 m
.62965 .25314 L
.63013 .25314 L
.63013 .16187 L
F
.2 .63 .79 r
.62965 .16187 m
.62965 .25314 L
.63013 .25314 L
.63013 .16187 L
s
.678 .847 .902 r
.63013 .16187 m
.63013 .25345 L
.63087 .25345 L
.63087 .16187 L
F
.2 .63 .79 r
.63013 .16187 m
.63013 .25345 L
.63087 .25345 L
.63087 .16187 L
s
.678 .847 .902 r
.63087 .16187 m
.63087 .25415 L
.63138 .25415 L
.63138 .16187 L
F
.2 .63 .79 r
.63087 .16187 m
.63087 .25415 L
.63138 .25415 L
.63138 .16187 L
s
.678 .847 .902 r
.63138 .16187 m
.63138 .25461 L
.63193 .25461 L
.63193 .16187 L
F
.2 .63 .79 r
.63138 .16187 m
.63138 .25461 L
.63193 .25461 L
.63193 .16187 L
s
.678 .847 .902 r
.63193 .16187 m
.63193 .2547 L
.63219 .2547 L
.63219 .16187 L
F
.2 .63 .79 r
.63193 .16187 m
.63193 .2547 L
.63219 .2547 L
.63219 .16187 L
s
.678 .847 .902 r
.63219 .16187 m
.63219 .25499 L
.63247 .25499 L
.63247 .16187 L
F
.2 .63 .79 r
.63219 .16187 m
.63219 .25499 L
.63247 .25499 L
.63247 .16187 L
s
.678 .847 .902 r
.63247 .16187 m
.63247 .25514 L
.6332 .25514 L
.6332 .16187 L
F
.2 .63 .79 r
.63247 .16187 m
.63247 .25514 L
.6332 .25514 L
.6332 .16187 L
s
.678 .847 .902 r
.6332 .16187 m
.6332 .25589 L
.63353 .25589 L
.63353 .16187 L
F
.2 .63 .79 r
.6332 .16187 m
.6332 .25589 L
.63353 .25589 L
.63353 .16187 L
s
.678 .847 .902 r
.63353 .16187 m
.63353 .25619 L
.63398 .25619 L
.63398 .16187 L
F
.2 .63 .79 r
.63353 .16187 m
.63353 .25619 L
.63398 .25619 L
.63398 .16187 L
s
.678 .847 .902 r
.63398 .16187 m
.63398 .25651 L
.63424 .25651 L
.63424 .16187 L
F
.2 .63 .79 r
.63398 .16187 m
.63398 .25651 L
.63424 .25651 L
.63424 .16187 L
s
.678 .847 .902 r
.63424 .16187 m
.63424 .25675 L
.63471 .25675 L
.63471 .16187 L
F
.2 .63 .79 r
.63424 .16187 m
.63424 .25675 L
.63471 .25675 L
.63471 .16187 L
s
.678 .847 .902 r
.63471 .16187 m
.63471 .25742 L
.63551 .25742 L
.63551 .16187 L
F
.2 .63 .79 r
.63471 .16187 m
.63471 .25742 L
.63551 .25742 L
.63551 .16187 L
s
.678 .847 .902 r
.63551 .16187 m
.63551 .25757 L
.63601 .25757 L
.63601 .16187 L
F
.2 .63 .79 r
.63551 .16187 m
.63551 .25757 L
.63601 .25757 L
.63601 .16187 L
s
.678 .847 .902 r
.63601 .16187 m
.63601 .25837 L
.63671 .25837 L
.63671 .16187 L
F
.2 .63 .79 r
.63601 .16187 m
.63601 .25837 L
.63671 .25837 L
.63671 .16187 L
s
.678 .847 .902 r
.63671 .16187 m
.63671 .25873 L
.63703 .25873 L
.63703 .16187 L
F
.2 .63 .79 r
.63671 .16187 m
.63671 .25873 L
.63703 .25873 L
.63703 .16187 L
s
.678 .847 .902 r
.63703 .16187 m
.63703 .25898 L
.63746 .25898 L
.63746 .16187 L
F
.2 .63 .79 r
.63703 .16187 m
.63703 .25898 L
.63746 .25898 L
.63746 .16187 L
s
.678 .847 .902 r
.63746 .16187 m
.63746 .25925 L
.63775 .25925 L
.63775 .16187 L
F
.2 .63 .79 r
.63746 .16187 m
.63746 .25925 L
.63775 .25925 L
.63775 .16187 L
s
.678 .847 .902 r
.63775 .16187 m
.63775 .25965 L
.63821 .25965 L
.63821 .16187 L
F
.2 .63 .79 r
.63775 .16187 m
.63775 .25965 L
.63821 .25965 L
.63821 .16187 L
s
.678 .847 .902 r
.63821 .16187 m
.63821 .25987 L
.63872 .25987 L
.63872 .16187 L
F
.2 .63 .79 r
.63821 .16187 m
.63821 .25987 L
.63872 .25987 L
.63872 .16187 L
s
.678 .847 .902 r
.63872 .16187 m
.63872 .26017 L
.63926 .26017 L
.63926 .16187 L
F
.2 .63 .79 r
.63872 .16187 m
.63872 .26017 L
.63926 .26017 L
.63926 .16187 L
s
.678 .847 .902 r
.63926 .16187 m
.63926 .26104 L
.63999 .26104 L
.63999 .16187 L
F
.2 .63 .79 r
.63926 .16187 m
.63926 .26104 L
.63999 .26104 L
.63999 .16187 L
s
.678 .847 .902 r
.63999 .16187 m
.63999 .26114 L
.64032 .26114 L
.64032 .16187 L
F
.2 .63 .79 r
.63999 .16187 m
.63999 .26114 L
.64032 .26114 L
.64032 .16187 L
s
.678 .847 .902 r
.64032 .16187 m
.64032 .26159 L
.64079 .26159 L
.64079 .16187 L
F
.2 .63 .79 r
.64032 .16187 m
.64032 .26159 L
.64079 .26159 L
.64079 .16187 L
s
.678 .847 .902 r
.64079 .16187 m
.64079 .26223 L
.64151 .26223 L
.64151 .16187 L
F
.2 .63 .79 r
.64079 .16187 m
.64079 .26223 L
.64151 .26223 L
.64151 .16187 L
s
.678 .847 .902 r
.64151 .16187 m
.64151 .26243 L
.64202 .26243 L
.64202 .16187 L
F
.2 .63 .79 r
.64151 .16187 m
.64151 .26243 L
.64202 .26243 L
.64202 .16187 L
s
.678 .847 .902 r
.64202 .16187 m
.64202 .26299 L
.64241 .26299 L
.64241 .16187 L
F
.2 .63 .79 r
.64202 .16187 m
.64202 .26299 L
.64241 .26299 L
.64241 .16187 L
s
.678 .847 .902 r
.64241 .16187 m
.64241 .26358 L
.64317 .26358 L
.64317 .16187 L
F
.2 .63 .79 r
.64241 .16187 m
.64241 .26358 L
.64317 .26358 L
.64317 .16187 L
s
.678 .847 .902 r
.64317 .16187 m
.64317 .26367 L
.6436 .26367 L
.6436 .16187 L
F
.2 .63 .79 r
.64317 .16187 m
.64317 .26367 L
.6436 .26367 L
.6436 .16187 L
s
.678 .847 .902 r
.6436 .16187 m
.6436 .26409 L
.64408 .26409 L
.64408 .16187 L
F
.2 .63 .79 r
.6436 .16187 m
.6436 .26409 L
.64408 .26409 L
.64408 .16187 L
s
.678 .847 .902 r
.64408 .16187 m
.64408 .26451 L
.64444 .26451 L
.64444 .16187 L
F
.2 .63 .79 r
.64408 .16187 m
.64408 .26451 L
.64444 .26451 L
.64444 .16187 L
s
.678 .847 .902 r
.64444 .16187 m
.64444 .26486 L
.64471 .26486 L
.64471 .16187 L
F
.2 .63 .79 r
.64444 .16187 m
.64444 .26486 L
.64471 .26486 L
.64471 .16187 L
s
.678 .847 .902 r
.64471 .16187 m
.64471 .26499 L
.64505 .26499 L
.64505 .16187 L
F
.2 .63 .79 r
.64471 .16187 m
.64471 .26499 L
.64505 .26499 L
.64505 .16187 L
s
.678 .847 .902 r
.64505 .16187 m
.64505 .2653 L
.64532 .2653 L
.64532 .16187 L
F
.2 .63 .79 r
.64505 .16187 m
.64505 .2653 L
.64532 .2653 L
.64532 .16187 L
s
.678 .847 .902 r
.64532 .16187 m
.64532 .26553 L
.64566 .26553 L
.64566 .16187 L
F
.2 .63 .79 r
.64532 .16187 m
.64532 .26553 L
.64566 .26553 L
.64566 .16187 L
s
.678 .847 .902 r
.64566 .16187 m
.64566 .26579 L
.64627 .26579 L
.64627 .16187 L
F
.2 .63 .79 r
.64566 .16187 m
.64566 .26579 L
.64627 .26579 L
.64627 .16187 L
s
.678 .847 .902 r
.64627 .16187 m
.64627 .2663 L
.64662 .2663 L
.64662 .16187 L
F
.2 .63 .79 r
.64627 .16187 m
.64627 .2663 L
.64662 .2663 L
.64662 .16187 L
s
.678 .847 .902 r
.64662 .16187 m
.64662 .26666 L
.6472 .26666 L
.6472 .16187 L
F
.2 .63 .79 r
.64662 .16187 m
.64662 .26666 L
.6472 .26666 L
.6472 .16187 L
s
.678 .847 .902 r
.6472 .16187 m
.6472 .26716 L
.64764 .26716 L
.64764 .16187 L
F
.2 .63 .79 r
.6472 .16187 m
.6472 .26716 L
.64764 .26716 L
.64764 .16187 L
s
.678 .847 .902 r
.64764 .16187 m
.64764 .26739 L
.64818 .26739 L
.64818 .16187 L
F
.2 .63 .79 r
.64764 .16187 m
.64764 .26739 L
.64818 .26739 L
.64818 .16187 L
s
.678 .847 .902 r
.64818 .16187 m
.64818 .26818 L
.6489 .26818 L
.6489 .16187 L
F
.2 .63 .79 r
.64818 .16187 m
.64818 .26818 L
.6489 .26818 L
.6489 .16187 L
s
.678 .847 .902 r
.6489 .16187 m
.6489 .26861 L
.64943 .26861 L
.64943 .16187 L
F
.2 .63 .79 r
.6489 .16187 m
.6489 .26861 L
.64943 .26861 L
.64943 .16187 L
s
.678 .847 .902 r
.64943 .16187 m
.64943 .26923 L
.65022 .26923 L
.65022 .16187 L
F
.2 .63 .79 r
.64943 .16187 m
.64943 .26923 L
.65022 .26923 L
.65022 .16187 L
s
.678 .847 .902 r
.65022 .16187 m
.65022 .26954 L
.6505 .26954 L
.6505 .16187 L
F
.2 .63 .79 r
.65022 .16187 m
.65022 .26954 L
.6505 .26954 L
.6505 .16187 L
s
.678 .847 .902 r
.6505 .16187 m
.6505 .26979 L
.65092 .26979 L
.65092 .16187 L
F
.2 .63 .79 r
.6505 .16187 m
.6505 .26979 L
.65092 .26979 L
.65092 .16187 L
s
.678 .847 .902 r
.65092 .16187 m
.65092 .27035 L
.65152 .27035 L
.65152 .16187 L
F
.2 .63 .79 r
.65092 .16187 m
.65092 .27035 L
.65152 .27035 L
.65152 .16187 L
s
.678 .847 .902 r
.65152 .16187 m
.65152 .27081 L
.65223 .27081 L
.65223 .16187 L
F
.2 .63 .79 r
.65152 .16187 m
.65152 .27081 L
.65223 .27081 L
.65223 .16187 L
s
.678 .847 .902 r
.65223 .16187 m
.65223 .2711 L
.65285 .2711 L
.65285 .16187 L
F
.2 .63 .79 r
.65223 .16187 m
.65223 .2711 L
.65285 .2711 L
.65285 .16187 L
s
.678 .847 .902 r
.65285 .16187 m
.65285 .27181 L
.65335 .27181 L
.65335 .16187 L
F
.2 .63 .79 r
.65285 .16187 m
.65285 .27181 L
.65335 .27181 L
.65335 .16187 L
s
.678 .847 .902 r
.65335 .16187 m
.65335 .27207 L
.65369 .27207 L
.65369 .16187 L
F
.2 .63 .79 r
.65335 .16187 m
.65335 .27207 L
.65369 .27207 L
.65369 .16187 L
s
.678 .847 .902 r
.65369 .16187 m
.65369 .27257 L
.65425 .27257 L
.65425 .16187 L
F
.2 .63 .79 r
.65369 .16187 m
.65369 .27257 L
.65425 .27257 L
.65425 .16187 L
s
.678 .847 .902 r
.65425 .16187 m
.65425 .27282 L
.65491 .27282 L
.65491 .16187 L
F
.2 .63 .79 r
.65425 .16187 m
.65425 .27282 L
.65491 .27282 L
.65491 .16187 L
s
.678 .847 .902 r
.65491 .16187 m
.65491 .27337 L
.65522 .27337 L
.65522 .16187 L
F
.2 .63 .79 r
.65491 .16187 m
.65491 .27337 L
.65522 .27337 L
.65522 .16187 L
s
.678 .847 .902 r
.65522 .16187 m
.65522 .27364 L
.65589 .27364 L
.65589 .16187 L
F
.2 .63 .79 r
.65522 .16187 m
.65522 .27364 L
.65589 .27364 L
.65589 .16187 L
s
.678 .847 .902 r
.65589 .16187 m
.65589 .27413 L
.65634 .27413 L
.65634 .16187 L
F
.2 .63 .79 r
.65589 .16187 m
.65589 .27413 L
.65634 .27413 L
.65634 .16187 L
s
.678 .847 .902 r
.65634 .16187 m
.65634 .27459 L
.65696 .27459 L
.65696 .16187 L
F
.2 .63 .79 r
.65634 .16187 m
.65634 .27459 L
.65696 .27459 L
.65696 .16187 L
s
.678 .847 .902 r
.65696 .16187 m
.65696 .27511 L
.65775 .27511 L
.65775 .16187 L
F
.2 .63 .79 r
.65696 .16187 m
.65696 .27511 L
.65775 .27511 L
.65775 .16187 L
s
.678 .847 .902 r
.65775 .16187 m
.65775 .27592 L
.65838 .27592 L
.65838 .16187 L
F
.2 .63 .79 r
.65775 .16187 m
.65775 .27592 L
.65838 .27592 L
.65838 .16187 L
s
.678 .847 .902 r
.65838 .16187 m
.65838 .27629 L
.65874 .27629 L
.65874 .16187 L
F
.2 .63 .79 r
.65838 .16187 m
.65838 .27629 L
.65874 .27629 L
.65874 .16187 L
s
.678 .847 .902 r
.65874 .16187 m
.65874 .27637 L
.65898 .27637 L
.65898 .16187 L
F
.2 .63 .79 r
.65874 .16187 m
.65874 .27637 L
.65898 .27637 L
.65898 .16187 L
s
.678 .847 .902 r
.65898 .16187 m
.65898 .27702 L
.65967 .27702 L
.65967 .16187 L
F
.2 .63 .79 r
.65898 .16187 m
.65898 .27702 L
.65967 .27702 L
.65967 .16187 L
s
.678 .847 .902 r
.65967 .16187 m
.65967 .27717 L
.65997 .27717 L
.65997 .16187 L
F
.2 .63 .79 r
.65967 .16187 m
.65967 .27717 L
.65997 .27717 L
.65997 .16187 L
s
.678 .847 .902 r
.65997 .16187 m
.65997 .27744 L
.66069 .27744 L
.66069 .16187 L
F
.2 .63 .79 r
.65997 .16187 m
.65997 .27744 L
.66069 .27744 L
.66069 .16187 L
s
.678 .847 .902 r
.66069 .16187 m
.66069 .27832 L
.6612 .27832 L
.6612 .16187 L
F
.2 .63 .79 r
.66069 .16187 m
.66069 .27832 L
.6612 .27832 L
.6612 .16187 L
s
.678 .847 .902 r
.6612 .16187 m
.6612 .27839 L
.66198 .27839 L
.66198 .16187 L
F
.2 .63 .79 r
.6612 .16187 m
.6612 .27839 L
.66198 .27839 L
.66198 .16187 L
s
.678 .847 .902 r
.66198 .16187 m
.66198 .27925 L
.66255 .27925 L
.66255 .16187 L
F
.2 .63 .79 r
.66198 .16187 m
.66198 .27925 L
.66255 .27925 L
.66255 .16187 L
s
.678 .847 .902 r
.66255 .16187 m
.66255 .27969 L
.66328 .27969 L
.66328 .16187 L
F
.2 .63 .79 r
.66255 .16187 m
.66255 .27969 L
.66328 .27969 L
.66328 .16187 L
s
.678 .847 .902 r
.66328 .16187 m
.66328 .28012 L
.66376 .28012 L
.66376 .16187 L
F
.2 .63 .79 r
.66328 .16187 m
.66328 .28012 L
.66376 .28012 L
.66376 .16187 L
s
.678 .847 .902 r
.66376 .16187 m
.66376 .28069 L
.66436 .28069 L
.66436 .16187 L
F
.2 .63 .79 r
.66376 .16187 m
.66376 .28069 L
.66436 .28069 L
.66436 .16187 L
s
.678 .847 .902 r
.66436 .16187 m
.66436 .28139 L
.66514 .28139 L
.66514 .16187 L
F
.2 .63 .79 r
.66436 .16187 m
.66436 .28139 L
.66514 .28139 L
.66514 .16187 L
s
.678 .847 .902 r
.66514 .16187 m
.66514 .28177 L
.6654 .28177 L
.6654 .16187 L
F
.2 .63 .79 r
.66514 .16187 m
.66514 .28177 L
.6654 .28177 L
.6654 .16187 L
s
.678 .847 .902 r
.6654 .16187 m
.6654 .28234 L
.66608 .28234 L
.66608 .16187 L
F
.2 .63 .79 r
.6654 .16187 m
.6654 .28234 L
.66608 .28234 L
.66608 .16187 L
s
.678 .847 .902 r
.66608 .16187 m
.66608 .28259 L
.66642 .28259 L
.66642 .16187 L
F
.2 .63 .79 r
.66608 .16187 m
.66608 .28259 L
.66642 .28259 L
.66642 .16187 L
s
.678 .847 .902 r
.66642 .16187 m
.66642 .2827 L
.66709 .2827 L
.66709 .16187 L
F
.2 .63 .79 r
.66642 .16187 m
.66642 .2827 L
.66709 .2827 L
.66709 .16187 L
s
.678 .847 .902 r
.66709 .16187 m
.66709 .28361 L
.66761 .28361 L
.66761 .16187 L
F
.2 .63 .79 r
.66709 .16187 m
.66709 .28361 L
.66761 .28361 L
.66761 .16187 L
s
.678 .847 .902 r
.66761 .16187 m
.66761 .2838 L
.66787 .2838 L
.66787 .16187 L
F
.2 .63 .79 r
.66761 .16187 m
.66761 .2838 L
.66787 .2838 L
.66787 .16187 L
s
.678 .847 .902 r
.66787 .16187 m
.66787 .2841 L
.66813 .2841 L
.66813 .16187 L
F
.2 .63 .79 r
.66787 .16187 m
.66787 .2841 L
.66813 .2841 L
.66813 .16187 L
s
.678 .847 .902 r
.66813 .16187 m
.66813 .28426 L
.66838 .28426 L
.66838 .16187 L
F
.2 .63 .79 r
.66813 .16187 m
.66813 .28426 L
.66838 .28426 L
.66838 .16187 L
s
.678 .847 .902 r
.66838 .16187 m
.66838 .28444 L
.66869 .28444 L
.66869 .16187 L
F
.2 .63 .79 r
.66838 .16187 m
.66838 .28444 L
.66869 .28444 L
.66869 .16187 L
s
.678 .847 .902 r
.66869 .16187 m
.66869 .28461 L
.66914 .28461 L
.66914 .16187 L
F
.2 .63 .79 r
.66869 .16187 m
.66869 .28461 L
.66914 .28461 L
.66914 .16187 L
s
.678 .847 .902 r
.66914 .16187 m
.66914 .28508 L
.66942 .28508 L
.66942 .16187 L
F
.2 .63 .79 r
.66914 .16187 m
.66914 .28508 L
.66942 .28508 L
.66942 .16187 L
s
.678 .847 .902 r
.66942 .16187 m
.66942 .2855 L
.66985 .2855 L
.66985 .16187 L
F
.2 .63 .79 r
.66942 .16187 m
.66942 .2855 L
.66985 .2855 L
.66985 .16187 L
s
.678 .847 .902 r
.66985 .16187 m
.66985 .2859 L
.67061 .2859 L
.67061 .16187 L
F
.2 .63 .79 r
.66985 .16187 m
.66985 .2859 L
.67061 .2859 L
.67061 .16187 L
s
.678 .847 .902 r
.67061 .16187 m
.67061 .28651 L
.67105 .28651 L
.67105 .16187 L
F
.2 .63 .79 r
.67061 .16187 m
.67061 .28651 L
.67105 .28651 L
.67105 .16187 L
s
.678 .847 .902 r
.67105 .16187 m
.67105 .28678 L
.67144 .28678 L
.67144 .16187 L
F
.2 .63 .79 r
.67105 .16187 m
.67105 .28678 L
.67144 .28678 L
.67144 .16187 L
s
.678 .847 .902 r
.67144 .16187 m
.67144 .28707 L
.67182 .28707 L
.67182 .16187 L
F
.2 .63 .79 r
.67144 .16187 m
.67144 .28707 L
.67182 .28707 L
.67182 .16187 L
s
.678 .847 .902 r
.67182 .16187 m
.67182 .2873 L
.6721 .2873 L
.6721 .16187 L
F
.2 .63 .79 r
.67182 .16187 m
.67182 .2873 L
.6721 .2873 L
.6721 .16187 L
s
.678 .847 .902 r
.6721 .16187 m
.6721 .28802 L
.67284 .28802 L
.67284 .16187 L
F
.2 .63 .79 r
.6721 .16187 m
.6721 .28802 L
.67284 .28802 L
.67284 .16187 L
s
.678 .847 .902 r
.67284 .16187 m
.67284 .28828 L
.67327 .28828 L
.67327 .16187 L
F
.2 .63 .79 r
.67284 .16187 m
.67284 .28828 L
.67327 .28828 L
.67327 .16187 L
s
.678 .847 .902 r
.67327 .16187 m
.67327 .28844 L
.67388 .28844 L
.67388 .16187 L
F
.2 .63 .79 r
.67327 .16187 m
.67327 .28844 L
.67388 .28844 L
.67388 .16187 L
s
.678 .847 .902 r
.67388 .16187 m
.67388 .28895 L
.67423 .28895 L
.67423 .16187 L
F
.2 .63 .79 r
.67388 .16187 m
.67388 .28895 L
.67423 .28895 L
.67423 .16187 L
s
.678 .847 .902 r
.67423 .16187 m
.67423 .28959 L
.67473 .28959 L
.67473 .16187 L
F
.2 .63 .79 r
.67423 .16187 m
.67423 .28959 L
.67473 .28959 L
.67473 .16187 L
s
.678 .847 .902 r
.67473 .16187 m
.67473 .28975 L
.67537 .28975 L
.67537 .16187 L
F
.2 .63 .79 r
.67473 .16187 m
.67473 .28975 L
.67537 .28975 L
.67537 .16187 L
s
.678 .847 .902 r
.67537 .16187 m
.67537 .29041 L
.67602 .29041 L
.67602 .16187 L
F
.2 .63 .79 r
.67537 .16187 m
.67537 .29041 L
.67602 .29041 L
.67602 .16187 L
s
.678 .847 .902 r
.67602 .16187 m
.67602 .29085 L
.67634 .29085 L
.67634 .16187 L
F
.2 .63 .79 r
.67602 .16187 m
.67602 .29085 L
.67634 .29085 L
.67634 .16187 L
s
.678 .847 .902 r
.67634 .16187 m
.67634 .29154 L
.67697 .29154 L
.67697 .16187 L
F
.2 .63 .79 r
.67634 .16187 m
.67634 .29154 L
.67697 .29154 L
.67697 .16187 L
s
.678 .847 .902 r
.67697 .16187 m
.67697 .2918 L
.67751 .2918 L
.67751 .16187 L
F
.2 .63 .79 r
.67697 .16187 m
.67697 .2918 L
.67751 .2918 L
.67751 .16187 L
s
.678 .847 .902 r
.67751 .16187 m
.67751 .29226 L
.67829 .29226 L
.67829 .16187 L
F
.2 .63 .79 r
.67751 .16187 m
.67751 .29226 L
.67829 .29226 L
.67829 .16187 L
s
.678 .847 .902 r
.67829 .16187 m
.67829 .29295 L
.67891 .29295 L
.67891 .16187 L
F
.2 .63 .79 r
.67829 .16187 m
.67829 .29295 L
.67891 .29295 L
.67891 .16187 L
s
.678 .847 .902 r
.67891 .16187 m
.67891 .29342 L
.67952 .29342 L
.67952 .16187 L
F
.2 .63 .79 r
.67891 .16187 m
.67891 .29342 L
.67952 .29342 L
.67952 .16187 L
s
.678 .847 .902 r
.67952 .16187 m
.67952 .294 L
.68004 .294 L
.68004 .16187 L
F
.2 .63 .79 r
.67952 .16187 m
.67952 .294 L
.68004 .294 L
.68004 .16187 L
s
.678 .847 .902 r
.68004 .16187 m
.68004 .29464 L
.68081 .29464 L
.68081 .16187 L
F
.2 .63 .79 r
.68004 .16187 m
.68004 .29464 L
.68081 .29464 L
.68081 .16187 L
s
.678 .847 .902 r
.68081 .16187 m
.68081 .29487 L
.68136 .29487 L
.68136 .16187 L
F
.2 .63 .79 r
.68081 .16187 m
.68081 .29487 L
.68136 .29487 L
.68136 .16187 L
s
.678 .847 .902 r
.68136 .16187 m
.68136 .29542 L
.68177 .29542 L
.68177 .16187 L
F
.2 .63 .79 r
.68136 .16187 m
.68136 .29542 L
.68177 .29542 L
.68177 .16187 L
s
.678 .847 .902 r
.68177 .16187 m
.68177 .29568 L
.68226 .29568 L
.68226 .16187 L
F
.2 .63 .79 r
.68177 .16187 m
.68177 .29568 L
.68226 .29568 L
.68226 .16187 L
s
.678 .847 .902 r
.68226 .16187 m
.68226 .29649 L
.68283 .29649 L
.68283 .16187 L
F
.2 .63 .79 r
.68226 .16187 m
.68226 .29649 L
.68283 .29649 L
.68283 .16187 L
s
.678 .847 .902 r
.68283 .16187 m
.68283 .29684 L
.68343 .29684 L
.68343 .16187 L
F
.2 .63 .79 r
.68283 .16187 m
.68283 .29684 L
.68343 .29684 L
.68343 .16187 L
s
.678 .847 .902 r
.68343 .16187 m
.68343 .2974 L
.68421 .2974 L
.68421 .16187 L
F
.2 .63 .79 r
.68343 .16187 m
.68343 .2974 L
.68421 .2974 L
.68421 .16187 L
s
.678 .847 .902 r
.68421 .16187 m
.68421 .29786 L
.68454 .29786 L
.68454 .16187 L
F
.2 .63 .79 r
.68421 .16187 m
.68421 .29786 L
.68454 .29786 L
.68454 .16187 L
s
.678 .847 .902 r
.68454 .16187 m
.68454 .29813 L
.68498 .29813 L
.68498 .16187 L
F
.2 .63 .79 r
.68454 .16187 m
.68454 .29813 L
.68498 .29813 L
.68498 .16187 L
s
.678 .847 .902 r
.68498 .16187 m
.68498 .29849 L
.68554 .29849 L
.68554 .16187 L
F
.2 .63 .79 r
.68498 .16187 m
.68498 .29849 L
.68554 .29849 L
.68554 .16187 L
s
.678 .847 .902 r
.68554 .16187 m
.68554 .29902 L
.68582 .29902 L
.68582 .16187 L
F
.2 .63 .79 r
.68554 .16187 m
.68554 .29902 L
.68582 .29902 L
.68582 .16187 L
s
.678 .847 .902 r
.68582 .16187 m
.68582 .29965 L
.68653 .29965 L
.68653 .16187 L
F
.2 .63 .79 r
.68582 .16187 m
.68582 .29965 L
.68653 .29965 L
.68653 .16187 L
s
.678 .847 .902 r
.68653 .16187 m
.68653 .29989 L
.68717 .29989 L
.68717 .16187 L
F
.2 .63 .79 r
.68653 .16187 m
.68653 .29989 L
.68717 .29989 L
.68717 .16187 L
s
.678 .847 .902 r
.68717 .16187 m
.68717 .30035 L
.68762 .30035 L
.68762 .16187 L
F
.2 .63 .79 r
.68717 .16187 m
.68717 .30035 L
.68762 .30035 L
.68762 .16187 L
s
.678 .847 .902 r
.68762 .16187 m
.68762 .30105 L
.68821 .30105 L
.68821 .16187 L
F
.2 .63 .79 r
.68762 .16187 m
.68762 .30105 L
.68821 .30105 L
.68821 .16187 L
s
.678 .847 .902 r
.68821 .16187 m
.68821 .30137 L
.68853 .30137 L
.68853 .16187 L
F
.2 .63 .79 r
.68821 .16187 m
.68821 .30137 L
.68853 .30137 L
.68853 .16187 L
s
.678 .847 .902 r
.68853 .16187 m
.68853 .30207 L
.68932 .30207 L
.68932 .16187 L
F
.2 .63 .79 r
.68853 .16187 m
.68853 .30207 L
.68932 .30207 L
.68932 .16187 L
s
.678 .847 .902 r
.68932 .16187 m
.68932 .3024 L
.68969 .3024 L
.68969 .16187 L
F
.2 .63 .79 r
.68932 .16187 m
.68932 .3024 L
.68969 .3024 L
.68969 .16187 L
s
.678 .847 .902 r
.68969 .16187 m
.68969 .30299 L
.69046 .30299 L
.69046 .16187 L
F
.2 .63 .79 r
.68969 .16187 m
.68969 .30299 L
.69046 .30299 L
.69046 .16187 L
s
.678 .847 .902 r
.69046 .16187 m
.69046 .30322 L
.69104 .30322 L
.69104 .16187 L
F
.2 .63 .79 r
.69046 .16187 m
.69046 .30322 L
.69104 .30322 L
.69104 .16187 L
s
.678 .847 .902 r
.69104 .16187 m
.69104 .30374 L
.69129 .30374 L
.69129 .16187 L
F
.2 .63 .79 r
.69104 .16187 m
.69104 .30374 L
.69129 .30374 L
.69129 .16187 L
s
.678 .847 .902 r
.69129 .16187 m
.69129 .30401 L
.69186 .30401 L
.69186 .16187 L
F
.2 .63 .79 r
.69129 .16187 m
.69129 .30401 L
.69186 .30401 L
.69186 .16187 L
s
.678 .847 .902 r
.69186 .16187 m
.69186 .30446 L
.69225 .30446 L
.69225 .16187 L
F
.2 .63 .79 r
.69186 .16187 m
.69186 .30446 L
.69225 .30446 L
.69225 .16187 L
s
.678 .847 .902 r
.69225 .16187 m
.69225 .30482 L
.69255 .30482 L
.69255 .16187 L
F
.2 .63 .79 r
.69225 .16187 m
.69225 .30482 L
.69255 .30482 L
.69255 .16187 L
s
.678 .847 .902 r
.69255 .16187 m
.69255 .30515 L
.69285 .30515 L
.69285 .16187 L
F
.2 .63 .79 r
.69255 .16187 m
.69255 .30515 L
.69285 .30515 L
.69285 .16187 L
s
.678 .847 .902 r
.69285 .16187 m
.69285 .30524 L
.69311 .30524 L
.69311 .16187 L
F
.2 .63 .79 r
.69285 .16187 m
.69285 .30524 L
.69311 .30524 L
.69311 .16187 L
s
.678 .847 .902 r
.69311 .16187 m
.69311 .30545 L
.6939 .30545 L
.6939 .16187 L
F
.2 .63 .79 r
.69311 .16187 m
.69311 .30545 L
.6939 .30545 L
.6939 .16187 L
s
.678 .847 .902 r
.6939 .16187 m
.6939 .30637 L
.69452 .30637 L
.69452 .16187 L
F
.2 .63 .79 r
.6939 .16187 m
.6939 .30637 L
.69452 .30637 L
.69452 .16187 L
s
.678 .847 .902 r
.69452 .16187 m
.69452 .30709 L
.69504 .30709 L
.69504 .16187 L
F
.2 .63 .79 r
.69452 .16187 m
.69452 .30709 L
.69504 .30709 L
.69504 .16187 L
s
.678 .847 .902 r
.69504 .16187 m
.69504 .30738 L
.69551 .30738 L
.69551 .16187 L
F
.2 .63 .79 r
.69504 .16187 m
.69504 .30738 L
.69551 .30738 L
.69551 .16187 L
s
.678 .847 .902 r
.69551 .16187 m
.69551 .30763 L
.69577 .30763 L
.69577 .16187 L
F
.2 .63 .79 r
.69551 .16187 m
.69551 .30763 L
.69577 .30763 L
.69577 .16187 L
s
.678 .847 .902 r
.69577 .16187 m
.69577 .30775 L
.6963 .30775 L
.6963 .16187 L
F
.2 .63 .79 r
.69577 .16187 m
.69577 .30775 L
.6963 .30775 L
.6963 .16187 L
s
.678 .847 .902 r
.6963 .16187 m
.6963 .30838 L
.69662 .30838 L
.69662 .16187 L
F
.2 .63 .79 r
.6963 .16187 m
.6963 .30838 L
.69662 .30838 L
.69662 .16187 L
s
.678 .847 .902 r
.69662 .16187 m
.69662 .30879 L
.69734 .30879 L
.69734 .16187 L
F
.2 .63 .79 r
.69662 .16187 m
.69662 .30879 L
.69734 .30879 L
.69734 .16187 L
s
.678 .847 .902 r
.69734 .16187 m
.69734 .30977 L
.69812 .30977 L
.69812 .16187 L
F
.2 .63 .79 r
.69734 .16187 m
.69734 .30977 L
.69812 .30977 L
.69812 .16187 L
s
.678 .847 .902 r
.69812 .16187 m
.69812 .30988 L
.69875 .30988 L
.69875 .16187 L
F
.2 .63 .79 r
.69812 .16187 m
.69812 .30988 L
.69875 .30988 L
.69875 .16187 L
s
.678 .847 .902 r
.69875 .16187 m
.69875 .3105 L
.69925 .3105 L
.69925 .16187 L
F
.2 .63 .79 r
.69875 .16187 m
.69875 .3105 L
.69925 .3105 L
.69925 .16187 L
s
.678 .847 .902 r
.69925 .16187 m
.69925 .31091 L
.69976 .31091 L
.69976 .16187 L
F
.2 .63 .79 r
.69925 .16187 m
.69925 .31091 L
.69976 .31091 L
.69976 .16187 L
s
.678 .847 .902 r
.69976 .16187 m
.69976 .3113 L
.70018 .3113 L
.70018 .16187 L
F
.2 .63 .79 r
.69976 .16187 m
.69976 .3113 L
.70018 .3113 L
.70018 .16187 L
s
.678 .847 .902 r
.70018 .16187 m
.70018 .31182 L
.70074 .31182 L
.70074 .16187 L
F
.2 .63 .79 r
.70018 .16187 m
.70018 .31182 L
.70074 .31182 L
.70074 .16187 L
s
.678 .847 .902 r
.70074 .16187 m
.70074 .3123 L
.70126 .3123 L
.70126 .16187 L
F
.2 .63 .79 r
.70074 .16187 m
.70074 .3123 L
.70126 .3123 L
.70126 .16187 L
s
.678 .847 .902 r
.70126 .16187 m
.70126 .31269 L
.70163 .31269 L
.70163 .16187 L
F
.2 .63 .79 r
.70126 .16187 m
.70126 .31269 L
.70163 .31269 L
.70163 .16187 L
s
.678 .847 .902 r
.70163 .16187 m
.70163 .31304 L
.7021 .31304 L
.7021 .16187 L
F
.2 .63 .79 r
.70163 .16187 m
.70163 .31304 L
.7021 .31304 L
.7021 .16187 L
s
.678 .847 .902 r
.7021 .16187 m
.7021 .31346 L
.70288 .31346 L
.70288 .16187 L
F
.2 .63 .79 r
.7021 .16187 m
.7021 .31346 L
.70288 .31346 L
.70288 .16187 L
s
.678 .847 .902 r
.70288 .16187 m
.70288 .31437 L
.70339 .31437 L
.70339 .16187 L
F
.2 .63 .79 r
.70288 .16187 m
.70288 .31437 L
.70339 .31437 L
.70339 .16187 L
s
.678 .847 .902 r
.70339 .16187 m
.70339 .31448 L
.70401 .31448 L
.70401 .16187 L
F
.2 .63 .79 r
.70339 .16187 m
.70339 .31448 L
.70401 .31448 L
.70401 .16187 L
s
.678 .847 .902 r
.70401 .16187 m
.70401 .31496 L
.70432 .31496 L
.70432 .16187 L
F
.2 .63 .79 r
.70401 .16187 m
.70401 .31496 L
.70432 .31496 L
.70432 .16187 L
s
.678 .847 .902 r
.70432 .16187 m
.70432 .31566 L
.70505 .31566 L
.70505 .16187 L
F
.2 .63 .79 r
.70432 .16187 m
.70432 .31566 L
.70505 .31566 L
.70505 .16187 L
s
.678 .847 .902 r
.70505 .16187 m
.70505 .3159 L
.7055 .3159 L
.7055 .16187 L
F
.2 .63 .79 r
.70505 .16187 m
.70505 .3159 L
.7055 .3159 L
.7055 .16187 L
s
.678 .847 .902 r
.7055 .16187 m
.7055 .31673 L
.7061 .31673 L
.7061 .16187 L
F
.2 .63 .79 r
.7055 .16187 m
.7055 .31673 L
.7061 .31673 L
.7061 .16187 L
s
.678 .847 .902 r
.7061 .16187 m
.7061 .31709 L
.70642 .31709 L
.70642 .16187 L
F
.2 .63 .79 r
.7061 .16187 m
.7061 .31709 L
.70642 .31709 L
.70642 .16187 L
s
.678 .847 .902 r
.70642 .16187 m
.70642 .31715 L
.70678 .31715 L
.70678 .16187 L
F
.2 .63 .79 r
.70642 .16187 m
.70642 .31715 L
.70678 .31715 L
.70678 .16187 L
s
.678 .847 .902 r
.70678 .16187 m
.70678 .31746 L
.70751 .31746 L
.70751 .16187 L
F
.2 .63 .79 r
.70678 .16187 m
.70678 .31746 L
.70751 .31746 L
.70751 .16187 L
s
.678 .847 .902 r
.70751 .16187 m
.70751 .31812 L
.70788 .31812 L
.70788 .16187 L
F
.2 .63 .79 r
.70751 .16187 m
.70751 .31812 L
.70788 .31812 L
.70788 .16187 L
s
.678 .847 .902 r
.70788 .16187 m
.70788 .31851 L
.7082 .31851 L
.7082 .16187 L
F
.2 .63 .79 r
.70788 .16187 m
.70788 .31851 L
.7082 .31851 L
.7082 .16187 L
s
.678 .847 .902 r
.7082 .16187 m
.7082 .31873 L
.70883 .31873 L
.70883 .16187 L
F
.2 .63 .79 r
.7082 .16187 m
.7082 .31873 L
.70883 .31873 L
.70883 .16187 L
s
.678 .847 .902 r
.70883 .16187 m
.70883 .31946 L
.70948 .31946 L
.70948 .16187 L
F
.2 .63 .79 r
.70883 .16187 m
.70883 .31946 L
.70948 .31946 L
.70948 .16187 L
s
.678 .847 .902 r
.70948 .16187 m
.70948 .32008 L
.70993 .32008 L
.70993 .16187 L
F
.2 .63 .79 r
.70948 .16187 m
.70948 .32008 L
.70993 .32008 L
.70993 .16187 L
s
.678 .847 .902 r
.70993 .16187 m
.70993 .32035 L
.71028 .32035 L
.71028 .16187 L
F
.2 .63 .79 r
.70993 .16187 m
.70993 .32035 L
.71028 .32035 L
.71028 .16187 L
s
.678 .847 .902 r
.71028 .16187 m
.71028 .32073 L
.71053 .32073 L
.71053 .16187 L
F
.2 .63 .79 r
.71028 .16187 m
.71028 .32073 L
.71053 .32073 L
.71053 .16187 L
s
.678 .847 .902 r
.71053 .16187 m
.71053 .32075 L
.71092 .32075 L
.71092 .16187 L
F
.2 .63 .79 r
.71053 .16187 m
.71053 .32075 L
.71092 .32075 L
.71092 .16187 L
s
.678 .847 .902 r
.71092 .16187 m
.71092 .32132 L
.71167 .32132 L
.71167 .16187 L
F
.2 .63 .79 r
.71092 .16187 m
.71092 .32132 L
.71167 .32132 L
.71167 .16187 L
s
.678 .847 .902 r
.71167 .16187 m
.71167 .3219 L
.7124 .3219 L
.7124 .16187 L
F
.2 .63 .79 r
.71167 .16187 m
.71167 .3219 L
.7124 .3219 L
.7124 .16187 L
s
.678 .847 .902 r
.7124 .16187 m
.7124 .32262 L
.71291 .32262 L
.71291 .16187 L
F
.2 .63 .79 r
.7124 .16187 m
.7124 .32262 L
.71291 .32262 L
.71291 .16187 L
s
.678 .847 .902 r
.71291 .16187 m
.71291 .32318 L
.71358 .32318 L
.71358 .16187 L
F
.2 .63 .79 r
.71291 .16187 m
.71291 .32318 L
.71358 .32318 L
.71358 .16187 L
s
.678 .847 .902 r
.71358 .16187 m
.71358 .32396 L
.7142 .32396 L
.7142 .16187 L
F
.2 .63 .79 r
.71358 .16187 m
.71358 .32396 L
.7142 .32396 L
.7142 .16187 L
s
.678 .847 .902 r
.7142 .16187 m
.7142 .32438 L
.71471 .32438 L
.71471 .16187 L
F
.2 .63 .79 r
.7142 .16187 m
.7142 .32438 L
.71471 .32438 L
.71471 .16187 L
s
.678 .847 .902 r
.71471 .16187 m
.71471 .32457 L
.71523 .32457 L
.71523 .16187 L
F
.2 .63 .79 r
.71471 .16187 m
.71471 .32457 L
.71523 .32457 L
.71523 .16187 L
s
.678 .847 .902 r
.71523 .16187 m
.71523 .32517 L
.71564 .32517 L
.71564 .16187 L
F
.2 .63 .79 r
.71523 .16187 m
.71523 .32517 L
.71564 .32517 L
.71564 .16187 L
s
.678 .847 .902 r
.71564 .16187 m
.71564 .32548 L
.71589 .32548 L
.71589 .16187 L
F
.2 .63 .79 r
.71564 .16187 m
.71564 .32548 L
.71589 .32548 L
.71589 .16187 L
s
.678 .847 .902 r
.71589 .16187 m
.71589 .32584 L
.71633 .32584 L
.71633 .16187 L
F
.2 .63 .79 r
.71589 .16187 m
.71589 .32584 L
.71633 .32584 L
.71633 .16187 L
s
.678 .847 .902 r
.71633 .16187 m
.71633 .32621 L
.71693 .32621 L
.71693 .16187 L
F
.2 .63 .79 r
.71633 .16187 m
.71633 .32621 L
.71693 .32621 L
.71693 .16187 L
s
.678 .847 .902 r
.71693 .16187 m
.71693 .32685 L
.71769 .32685 L
.71769 .16187 L
F
.2 .63 .79 r
.71693 .16187 m
.71693 .32685 L
.71769 .32685 L
.71769 .16187 L
s
.678 .847 .902 r
.71769 .16187 m
.71769 .32753 L
.71814 .32753 L
.71814 .16187 L
F
.2 .63 .79 r
.71769 .16187 m
.71769 .32753 L
.71814 .32753 L
.71814 .16187 L
s
.678 .847 .902 r
.71814 .16187 m
.71814 .32782 L
.7185 .32782 L
.7185 .16187 L
F
.2 .63 .79 r
.71814 .16187 m
.71814 .32782 L
.7185 .32782 L
.7185 .16187 L
s
.678 .847 .902 r
.7185 .16187 m
.7185 .32805 L
.71899 .32805 L
.71899 .16187 L
F
.2 .63 .79 r
.7185 .16187 m
.7185 .32805 L
.71899 .32805 L
.71899 .16187 L
s
.678 .847 .902 r
.71899 .16187 m
.71899 .32845 L
.71926 .32845 L
.71926 .16187 L
F
.2 .63 .79 r
.71899 .16187 m
.71899 .32845 L
.71926 .32845 L
.71926 .16187 L
s
.678 .847 .902 r
.71926 .16187 m
.71926 .32879 L
.71959 .32879 L
.71959 .16187 L
F
.2 .63 .79 r
.71926 .16187 m
.71926 .32879 L
.71959 .32879 L
.71959 .16187 L
s
.678 .847 .902 r
.71959 .16187 m
.71959 .32896 L
.71987 .32896 L
.71987 .16187 L
F
.2 .63 .79 r
.71959 .16187 m
.71959 .32896 L
.71987 .32896 L
.71987 .16187 L
s
.678 .847 .902 r
.71987 .16187 m
.71987 .32928 L
.72053 .32928 L
.72053 .16187 L
F
.2 .63 .79 r
.71987 .16187 m
.71987 .32928 L
.72053 .32928 L
.72053 .16187 L
s
.678 .847 .902 r
.72053 .16187 m
.72053 .32975 L
.72097 .32975 L
.72097 .16187 L
F
.2 .63 .79 r
.72053 .16187 m
.72053 .32975 L
.72097 .32975 L
.72097 .16187 L
s
.678 .847 .902 r
.72097 .16187 m
.72097 .33016 L
.72164 .33016 L
.72164 .16187 L
F
.2 .63 .79 r
.72097 .16187 m
.72097 .33016 L
.72164 .33016 L
.72164 .16187 L
s
.678 .847 .902 r
.72164 .16187 m
.72164 .33135 L
.72239 .33135 L
.72239 .16187 L
F
.2 .63 .79 r
.72164 .16187 m
.72164 .33135 L
.72239 .33135 L
.72239 .16187 L
s
.678 .847 .902 r
.72239 .16187 m
.72239 .3316 L
.72304 .3316 L
.72304 .16187 L
F
.2 .63 .79 r
.72239 .16187 m
.72239 .3316 L
.72304 .3316 L
.72304 .16187 L
s
.678 .847 .902 r
.72304 .16187 m
.72304 .33201 L
.72333 .33201 L
.72333 .16187 L
F
.2 .63 .79 r
.72304 .16187 m
.72304 .33201 L
.72333 .33201 L
.72333 .16187 L
s
.678 .847 .902 r
.72333 .16187 m
.72333 .33274 L
.72406 .33274 L
.72406 .16187 L
F
.2 .63 .79 r
.72333 .16187 m
.72333 .33274 L
.72406 .33274 L
.72406 .16187 L
s
.678 .847 .902 r
.72406 .16187 m
.72406 .33308 L
.72432 .33308 L
.72432 .16187 L
F
.2 .63 .79 r
.72406 .16187 m
.72406 .33308 L
.72432 .33308 L
.72432 .16187 L
s
.678 .847 .902 r
.72432 .16187 m
.72432 .33346 L
.7247 .33346 L
.7247 .16187 L
F
.2 .63 .79 r
.72432 .16187 m
.72432 .33346 L
.7247 .33346 L
.7247 .16187 L
s
.678 .847 .902 r
.7247 .16187 m
.7247 .33372 L
.72513 .33372 L
.72513 .16187 L
F
.2 .63 .79 r
.7247 .16187 m
.7247 .33372 L
.72513 .33372 L
.72513 .16187 L
s
.678 .847 .902 r
.72513 .16187 m
.72513 .33417 L
.72548 .33417 L
.72548 .16187 L
F
.2 .63 .79 r
.72513 .16187 m
.72513 .33417 L
.72548 .33417 L
.72548 .16187 L
s
.678 .847 .902 r
.72548 .16187 m
.72548 .33468 L
.72604 .33468 L
.72604 .16187 L
F
.2 .63 .79 r
.72548 .16187 m
.72548 .33468 L
.72604 .33468 L
.72604 .16187 L
s
.678 .847 .902 r
.72604 .16187 m
.72604 .33515 L
.72671 .33515 L
.72671 .16187 L
F
.2 .63 .79 r
.72604 .16187 m
.72604 .33515 L
.72671 .33515 L
.72671 .16187 L
s
.678 .847 .902 r
.72671 .16187 m
.72671 .33555 L
.72697 .33555 L
.72697 .16187 L
F
.2 .63 .79 r
.72671 .16187 m
.72671 .33555 L
.72697 .33555 L
.72697 .16187 L
s
.678 .847 .902 r
.72697 .16187 m
.72697 .3356 L
.72732 .3356 L
.72732 .16187 L
F
.2 .63 .79 r
.72697 .16187 m
.72697 .3356 L
.72732 .3356 L
.72732 .16187 L
s
.678 .847 .902 r
.72732 .16187 m
.72732 .33594 L
.72767 .33594 L
.72767 .16187 L
F
.2 .63 .79 r
.72732 .16187 m
.72732 .33594 L
.72767 .33594 L
.72767 .16187 L
s
.678 .847 .902 r
.72767 .16187 m
.72767 .33626 L
.72798 .33626 L
.72798 .16187 L
F
.2 .63 .79 r
.72767 .16187 m
.72767 .33626 L
.72798 .33626 L
.72798 .16187 L
s
.678 .847 .902 r
.72798 .16187 m
.72798 .33661 L
.72829 .33661 L
.72829 .16187 L
F
.2 .63 .79 r
.72798 .16187 m
.72798 .33661 L
.72829 .33661 L
.72829 .16187 L
s
.678 .847 .902 r
.72829 .16187 m
.72829 .3369 L
.72899 .3369 L
.72899 .16187 L
F
.2 .63 .79 r
.72829 .16187 m
.72829 .3369 L
.72899 .3369 L
.72899 .16187 L
s
.678 .847 .902 r
.72899 .16187 m
.72899 .33769 L
.7298 .33769 L
.7298 .16187 L
F
.2 .63 .79 r
.72899 .16187 m
.72899 .33769 L
.7298 .33769 L
.7298 .16187 L
s
.678 .847 .902 r
.7298 .16187 m
.7298 .33863 L
.73043 .33863 L
.73043 .16187 L
F
.2 .63 .79 r
.7298 .16187 m
.7298 .33863 L
.73043 .33863 L
.73043 .16187 L
s
.678 .847 .902 r
.73043 .16187 m
.73043 .33897 L
.7307 .33897 L
.7307 .16187 L
F
.2 .63 .79 r
.73043 .16187 m
.73043 .33897 L
.7307 .33897 L
.7307 .16187 L
s
.678 .847 .902 r
.7307 .16187 m
.7307 .33925 L
.73132 .33925 L
.73132 .16187 L
F
.2 .63 .79 r
.7307 .16187 m
.7307 .33925 L
.73132 .33925 L
.73132 .16187 L
s
.678 .847 .902 r
.73132 .16187 m
.73132 .33956 L
.73209 .33956 L
.73209 .16187 L
F
.2 .63 .79 r
.73132 .16187 m
.73132 .33956 L
.73209 .33956 L
.73209 .16187 L
s
.678 .847 .902 r
.73209 .16187 m
.73209 .34066 L
.73286 .34066 L
.73286 .16187 L
F
.2 .63 .79 r
.73209 .16187 m
.73209 .34066 L
.73286 .34066 L
.73286 .16187 L
s
.678 .847 .902 r
.73286 .16187 m
.73286 .34148 L
.73351 .34148 L
.73351 .16187 L
F
.2 .63 .79 r
.73286 .16187 m
.73286 .34148 L
.73351 .34148 L
.73351 .16187 L
s
.678 .847 .902 r
.73351 .16187 m
.73351 .34184 L
.73426 .34184 L
.73426 .16187 L
F
.2 .63 .79 r
.73351 .16187 m
.73351 .34184 L
.73426 .34184 L
.73426 .16187 L
s
.678 .847 .902 r
.73426 .16187 m
.73426 .34228 L
.73452 .34228 L
.73452 .16187 L
F
.2 .63 .79 r
.73426 .16187 m
.73426 .34228 L
.73452 .34228 L
.73452 .16187 L
s
.678 .847 .902 r
.73452 .16187 m
.73452 .34258 L
.73489 .34258 L
.73489 .16187 L
F
.2 .63 .79 r
.73452 .16187 m
.73452 .34258 L
.73489 .34258 L
.73489 .16187 L
s
.678 .847 .902 r
.73489 .16187 m
.73489 .34327 L
.73549 .34327 L
.73549 .16187 L
F
.2 .63 .79 r
.73489 .16187 m
.73489 .34327 L
.73549 .34327 L
.73549 .16187 L
s
.678 .847 .902 r
.73549 .16187 m
.73549 .34356 L
.73576 .34356 L
.73576 .16187 L
F
.2 .63 .79 r
.73549 .16187 m
.73549 .34356 L
.73576 .34356 L
.73576 .16187 L
s
.678 .847 .902 r
.73576 .16187 m
.73576 .34373 L
.736 .34373 L
.736 .16187 L
F
.2 .63 .79 r
.73576 .16187 m
.73576 .34373 L
.736 .34373 L
.736 .16187 L
s
.678 .847 .902 r
.736 .16187 m
.736 .34412 L
.73679 .34412 L
.73679 .16187 L
F
.2 .63 .79 r
.736 .16187 m
.736 .34412 L
.73679 .34412 L
.73679 .16187 L
s
.678 .847 .902 r
.73679 .16187 m
.73679 .34468 L
.7372 .34468 L
.7372 .16187 L
F
.2 .63 .79 r
.73679 .16187 m
.73679 .34468 L
.7372 .34468 L
.7372 .16187 L
s
.678 .847 .902 r
.7372 .16187 m
.7372 .34552 L
.73792 .34552 L
.73792 .16187 L
F
.2 .63 .79 r
.7372 .16187 m
.7372 .34552 L
.73792 .34552 L
.73792 .16187 L
s
.678 .847 .902 r
.73792 .16187 m
.73792 .34586 L
.73842 .34586 L
.73842 .16187 L
F
.2 .63 .79 r
.73792 .16187 m
.73792 .34586 L
.73842 .34586 L
.73842 .16187 L
s
.678 .847 .902 r
.73842 .16187 m
.73842 .34633 L
.73879 .34633 L
.73879 .16187 L
F
.2 .63 .79 r
.73842 .16187 m
.73842 .34633 L
.73879 .34633 L
.73879 .16187 L
s
.678 .847 .902 r
.73879 .16187 m
.73879 .34655 L
.73918 .34655 L
.73918 .16187 L
F
.2 .63 .79 r
.73879 .16187 m
.73879 .34655 L
.73918 .34655 L
.73918 .16187 L
s
.678 .847 .902 r
.73918 .16187 m
.73918 .34723 L
.73979 .34723 L
.73979 .16187 L
F
.2 .63 .79 r
.73918 .16187 m
.73918 .34723 L
.73979 .34723 L
.73979 .16187 L
s
.678 .847 .902 r
.73979 .16187 m
.73979 .34749 L
.74017 .34749 L
.74017 .16187 L
F
.2 .63 .79 r
.73979 .16187 m
.73979 .34749 L
.74017 .34749 L
.74017 .16187 L
s
.678 .847 .902 r
.74017 .16187 m
.74017 .34786 L
.74047 .34786 L
.74047 .16187 L
F
.2 .63 .79 r
.74017 .16187 m
.74017 .34786 L
.74047 .34786 L
.74047 .16187 L
s
.678 .847 .902 r
.74047 .16187 m
.74047 .34829 L
.7408 .34829 L
.7408 .16187 L
F
.2 .63 .79 r
.74047 .16187 m
.74047 .34829 L
.7408 .34829 L
.7408 .16187 L
s
.678 .847 .902 r
.7408 .16187 m
.7408 .34868 L
.74151 .34868 L
.74151 .16187 L
F
.2 .63 .79 r
.7408 .16187 m
.7408 .34868 L
.74151 .34868 L
.74151 .16187 L
s
.678 .847 .902 r
.74151 .16187 m
.74151 .34932 L
.74189 .34932 L
.74189 .16187 L
F
.2 .63 .79 r
.74151 .16187 m
.74151 .34932 L
.74189 .34932 L
.74189 .16187 L
s
.678 .847 .902 r
.74189 .16187 m
.74189 .34963 L
.74238 .34963 L
.74238 .16187 L
F
.2 .63 .79 r
.74189 .16187 m
.74189 .34963 L
.74238 .34963 L
.74238 .16187 L
s
.678 .847 .902 r
.74238 .16187 m
.74238 .35006 L
.74267 .35006 L
.74267 .16187 L
F
.2 .63 .79 r
.74238 .16187 m
.74238 .35006 L
.74267 .35006 L
.74267 .16187 L
s
.678 .847 .902 r
.74267 .16187 m
.74267 .35009 L
.743 .35009 L
.743 .16187 L
F
.2 .63 .79 r
.74267 .16187 m
.74267 .35009 L
.743 .35009 L
.743 .16187 L
s
.678 .847 .902 r
.743 .16187 m
.743 .35076 L
.74343 .35076 L
.74343 .16187 L
F
.2 .63 .79 r
.743 .16187 m
.743 .35076 L
.74343 .35076 L
.74343 .16187 L
s
.678 .847 .902 r
.74343 .16187 m
.74343 .35081 L
.74394 .35081 L
.74394 .16187 L
F
.2 .63 .79 r
.74343 .16187 m
.74343 .35081 L
.74394 .35081 L
.74394 .16187 L
s
.678 .847 .902 r
.74394 .16187 m
.74394 .3513 L
.7444 .3513 L
.7444 .16187 L
F
.2 .63 .79 r
.74394 .16187 m
.74394 .3513 L
.7444 .3513 L
.7444 .16187 L
s
.678 .847 .902 r
.7444 .16187 m
.7444 .35193 L
.74478 .35193 L
.74478 .16187 L
F
.2 .63 .79 r
.7444 .16187 m
.7444 .35193 L
.74478 .35193 L
.74478 .16187 L
s
.678 .847 .902 r
.74478 .16187 m
.74478 .35237 L
.74519 .35237 L
.74519 .16187 L
F
.2 .63 .79 r
.74478 .16187 m
.74478 .35237 L
.74519 .35237 L
.74519 .16187 L
s
.678 .847 .902 r
.74519 .16187 m
.74519 .35273 L
.74558 .35273 L
.74558 .16187 L
F
.2 .63 .79 r
.74519 .16187 m
.74519 .35273 L
.74558 .35273 L
.74558 .16187 L
s
.678 .847 .902 r
.74558 .16187 m
.74558 .353 L
.74625 .353 L
.74625 .16187 L
F
.2 .63 .79 r
.74558 .16187 m
.74558 .353 L
.74625 .353 L
.74625 .16187 L
s
.678 .847 .902 r
.74625 .16187 m
.74625 .35342 L
.74661 .35342 L
.74661 .16187 L
F
.2 .63 .79 r
.74625 .16187 m
.74625 .35342 L
.74661 .35342 L
.74661 .16187 L
s
.678 .847 .902 r
.74661 .16187 m
.74661 .35393 L
.74702 .35393 L
.74702 .16187 L
F
.2 .63 .79 r
.74661 .16187 m
.74661 .35393 L
.74702 .35393 L
.74702 .16187 L
s
.678 .847 .902 r
.74702 .16187 m
.74702 .35432 L
.74741 .35432 L
.74741 .16187 L
F
.2 .63 .79 r
.74702 .16187 m
.74702 .35432 L
.74741 .35432 L
.74741 .16187 L
s
.678 .847 .902 r
.74741 .16187 m
.74741 .35456 L
.74791 .35456 L
.74791 .16187 L
F
.2 .63 .79 r
.74741 .16187 m
.74741 .35456 L
.74791 .35456 L
.74791 .16187 L
s
.678 .847 .902 r
.74791 .16187 m
.74791 .35506 L
.74836 .35506 L
.74836 .16187 L
F
.2 .63 .79 r
.74791 .16187 m
.74791 .35506 L
.74836 .35506 L
.74836 .16187 L
s
.678 .847 .902 r
.74836 .16187 m
.74836 .3554 L
.74908 .3554 L
.74908 .16187 L
F
.2 .63 .79 r
.74836 .16187 m
.74836 .3554 L
.74908 .3554 L
.74908 .16187 L
s
.678 .847 .902 r
.74908 .16187 m
.74908 .35629 L
.74935 .35629 L
.74935 .16187 L
F
.2 .63 .79 r
.74908 .16187 m
.74908 .35629 L
.74935 .35629 L
.74935 .16187 L
s
.678 .847 .902 r
.74935 .16187 m
.74935 .3566 L
.7497 .3566 L
.7497 .16187 L
F
.2 .63 .79 r
.74935 .16187 m
.74935 .3566 L
.7497 .3566 L
.7497 .16187 L
s
.678 .847 .902 r
.7497 .16187 m
.7497 .35695 L
.75035 .35695 L
.75035 .16187 L
F
.2 .63 .79 r
.7497 .16187 m
.7497 .35695 L
.75035 .35695 L
.75035 .16187 L
s
.678 .847 .902 r
.75035 .16187 m
.75035 .35764 L
.75093 .35764 L
.75093 .16187 L
F
.2 .63 .79 r
.75035 .16187 m
.75035 .35764 L
.75093 .35764 L
.75093 .16187 L
s
.678 .847 .902 r
.75093 .16187 m
.75093 .35811 L
.75171 .35811 L
.75171 .16187 L
F
.2 .63 .79 r
.75093 .16187 m
.75093 .35811 L
.75171 .35811 L
.75171 .16187 L
s
.678 .847 .902 r
.75171 .16187 m
.75171 .35878 L
.75197 .35878 L
.75197 .16187 L
F
.2 .63 .79 r
.75171 .16187 m
.75171 .35878 L
.75197 .35878 L
.75197 .16187 L
s
.678 .847 .902 r
.75197 .16187 m
.75197 .35945 L
.75271 .35945 L
.75271 .16187 L
F
.2 .63 .79 r
.75197 .16187 m
.75197 .35945 L
.75271 .35945 L
.75271 .16187 L
s
.678 .847 .902 r
.75271 .16187 m
.75271 .35979 L
.75315 .35979 L
.75315 .16187 L
F
.2 .63 .79 r
.75271 .16187 m
.75271 .35979 L
.75315 .35979 L
.75315 .16187 L
s
.678 .847 .902 r
.75315 .16187 m
.75315 .36029 L
.75369 .36029 L
.75369 .16187 L
F
.2 .63 .79 r
.75315 .16187 m
.75315 .36029 L
.75369 .36029 L
.75369 .16187 L
s
.678 .847 .902 r
.75369 .16187 m
.75369 .36113 L
.75446 .36113 L
.75446 .16187 L
F
.2 .63 .79 r
.75369 .16187 m
.75369 .36113 L
.75446 .36113 L
.75446 .16187 L
s
.678 .847 .902 r
.75446 .16187 m
.75446 .36168 L
.75512 .36168 L
.75512 .16187 L
F
.2 .63 .79 r
.75446 .16187 m
.75446 .36168 L
.75512 .36168 L
.75512 .16187 L
s
.678 .847 .902 r
.75512 .16187 m
.75512 .36196 L
.75538 .36196 L
.75538 .16187 L
F
.2 .63 .79 r
.75512 .16187 m
.75512 .36196 L
.75538 .36196 L
.75538 .16187 L
s
.678 .847 .902 r
.75538 .16187 m
.75538 .36218 L
.75564 .36218 L
.75564 .16187 L
F
.2 .63 .79 r
.75538 .16187 m
.75538 .36218 L
.75564 .36218 L
.75564 .16187 L
s
.678 .847 .902 r
.75564 .16187 m
.75564 .36271 L
.7562 .36271 L
.7562 .16187 L
F
.2 .63 .79 r
.75564 .16187 m
.75564 .36271 L
.7562 .36271 L
.7562 .16187 L
s
.678 .847 .902 r
.7562 .16187 m
.7562 .36287 L
.75672 .36287 L
.75672 .16187 L
F
.2 .63 .79 r
.7562 .16187 m
.7562 .36287 L
.75672 .36287 L
.75672 .16187 L
s
.678 .847 .902 r
.75672 .16187 m
.75672 .36383 L
.75737 .36383 L
.75737 .16187 L
F
.2 .63 .79 r
.75672 .16187 m
.75672 .36383 L
.75737 .36383 L
.75737 .16187 L
s
.678 .847 .902 r
.75737 .16187 m
.75737 .36443 L
.75805 .36443 L
.75805 .16187 L
F
.2 .63 .79 r
.75737 .16187 m
.75737 .36443 L
.75805 .36443 L
.75805 .16187 L
s
.678 .847 .902 r
.75805 .16187 m
.75805 .36489 L
.75875 .36489 L
.75875 .16187 L
F
.2 .63 .79 r
.75805 .16187 m
.75805 .36489 L
.75875 .36489 L
.75875 .16187 L
s
.678 .847 .902 r
.75875 .16187 m
.75875 .36527 L
.75915 .36527 L
.75915 .16187 L
F
.2 .63 .79 r
.75875 .16187 m
.75875 .36527 L
.75915 .36527 L
.75915 .16187 L
s
.678 .847 .902 r
.75915 .16187 m
.75915 .36578 L
.75964 .36578 L
.75964 .16187 L
F
.2 .63 .79 r
.75915 .16187 m
.75915 .36578 L
.75964 .36578 L
.75964 .16187 L
s
.678 .847 .902 r
.75964 .16187 m
.75964 .36621 L
.76017 .36621 L
.76017 .16187 L
F
.2 .63 .79 r
.75964 .16187 m
.75964 .36621 L
.76017 .36621 L
.76017 .16187 L
s
.678 .847 .902 r
.76017 .16187 m
.76017 .36673 L
.7606 .36673 L
.7606 .16187 L
F
.2 .63 .79 r
.76017 .16187 m
.76017 .36673 L
.7606 .36673 L
.7606 .16187 L
s
.678 .847 .902 r
.7606 .16187 m
.7606 .36764 L
.76136 .36764 L
.76136 .16187 L
F
.2 .63 .79 r
.7606 .16187 m
.7606 .36764 L
.76136 .36764 L
.76136 .16187 L
s
.678 .847 .902 r
.76136 .16187 m
.76136 .36792 L
.76194 .36792 L
.76194 .16187 L
F
.2 .63 .79 r
.76136 .16187 m
.76136 .36792 L
.76194 .36792 L
.76194 .16187 L
s
.678 .847 .902 r
.76194 .16187 m
.76194 .36847 L
.76244 .36847 L
.76244 .16187 L
F
.2 .63 .79 r
.76194 .16187 m
.76194 .36847 L
.76244 .36847 L
.76244 .16187 L
s
.678 .847 .902 r
.76244 .16187 m
.76244 .36892 L
.76276 .36892 L
.76276 .16187 L
F
.2 .63 .79 r
.76244 .16187 m
.76244 .36892 L
.76276 .36892 L
.76276 .16187 L
s
.678 .847 .902 r
.76276 .16187 m
.76276 .3692 L
.76312 .3692 L
.76312 .16187 L
F
.2 .63 .79 r
.76276 .16187 m
.76276 .3692 L
.76312 .3692 L
.76312 .16187 L
s
.678 .847 .902 r
.76312 .16187 m
.76312 .36992 L
.76392 .36992 L
.76392 .16187 L
F
.2 .63 .79 r
.76312 .16187 m
.76312 .36992 L
.76392 .36992 L
.76392 .16187 L
s
.678 .847 .902 r
.76392 .16187 m
.76392 .37069 L
.76446 .37069 L
.76446 .16187 L
F
.2 .63 .79 r
.76392 .16187 m
.76392 .37069 L
.76446 .37069 L
.76446 .16187 L
s
.678 .847 .902 r
.76446 .16187 m
.76446 .37086 L
.76476 .37086 L
.76476 .16187 L
F
.2 .63 .79 r
.76446 .16187 m
.76446 .37086 L
.76476 .37086 L
.76476 .16187 L
s
.678 .847 .902 r
.76476 .16187 m
.76476 .37117 L
.76518 .37117 L
.76518 .16187 L
F
.2 .63 .79 r
.76476 .16187 m
.76476 .37117 L
.76518 .37117 L
.76518 .16187 L
s
.678 .847 .902 r
.76518 .16187 m
.76518 .37194 L
.76578 .37194 L
.76578 .16187 L
F
.2 .63 .79 r
.76518 .16187 m
.76518 .37194 L
.76578 .37194 L
.76578 .16187 L
s
.678 .847 .902 r
.76578 .16187 m
.76578 .37202 L
.76603 .37202 L
.76603 .16187 L
F
.2 .63 .79 r
.76578 .16187 m
.76578 .37202 L
.76603 .37202 L
.76603 .16187 L
s
.678 .847 .902 r
.76603 .16187 m
.76603 .3724 L
.76636 .3724 L
.76636 .16187 L
F
.2 .63 .79 r
.76603 .16187 m
.76603 .3724 L
.76636 .3724 L
.76636 .16187 L
s
.678 .847 .902 r
.76636 .16187 m
.76636 .37286 L
.76693 .37286 L
.76693 .16187 L
F
.2 .63 .79 r
.76636 .16187 m
.76636 .37286 L
.76693 .37286 L
.76693 .16187 L
s
.678 .847 .902 r
.76693 .16187 m
.76693 .37319 L
.76752 .37319 L
.76752 .16187 L
F
.2 .63 .79 r
.76693 .16187 m
.76693 .37319 L
.76752 .37319 L
.76752 .16187 L
s
.678 .847 .902 r
.76752 .16187 m
.76752 .37409 L
.76831 .37409 L
.76831 .16187 L
F
.2 .63 .79 r
.76752 .16187 m
.76752 .37409 L
.76831 .37409 L
.76831 .16187 L
s
.678 .847 .902 r
.76831 .16187 m
.76831 .37484 L
.76889 .37484 L
.76889 .16187 L
F
.2 .63 .79 r
.76831 .16187 m
.76831 .37484 L
.76889 .37484 L
.76889 .16187 L
s
.678 .847 .902 r
.76889 .16187 m
.76889 .3751 L
.76919 .3751 L
.76919 .16187 L
F
.2 .63 .79 r
.76889 .16187 m
.76889 .3751 L
.76919 .3751 L
.76919 .16187 L
s
.678 .847 .902 r
.76919 .16187 m
.76919 .37549 L
.76993 .37549 L
.76993 .16187 L
F
.2 .63 .79 r
.76919 .16187 m
.76919 .37549 L
.76993 .37549 L
.76993 .16187 L
s
.678 .847 .902 r
.76993 .16187 m
.76993 .37624 L
.77027 .37624 L
.77027 .16187 L
F
.2 .63 .79 r
.76993 .16187 m
.76993 .37624 L
.77027 .37624 L
.77027 .16187 L
s
.678 .847 .902 r
.77027 .16187 m
.77027 .37649 L
.77097 .37649 L
.77097 .16187 L
F
.2 .63 .79 r
.77027 .16187 m
.77027 .37649 L
.77097 .37649 L
.77097 .16187 L
s
.678 .847 .902 r
.77097 .16187 m
.77097 .37723 L
.77167 .37723 L
.77167 .16187 L
F
.2 .63 .79 r
.77097 .16187 m
.77097 .37723 L
.77167 .37723 L
.77167 .16187 L
s
.678 .847 .902 r
.77167 .16187 m
.77167 .37813 L
.77217 .37813 L
.77217 .16187 L
F
.2 .63 .79 r
.77167 .16187 m
.77167 .37813 L
.77217 .37813 L
.77217 .16187 L
s
.678 .847 .902 r
.77217 .16187 m
.77217 .37846 L
.77279 .37846 L
.77279 .16187 L
F
.2 .63 .79 r
.77217 .16187 m
.77217 .37846 L
.77279 .37846 L
.77279 .16187 L
s
.678 .847 .902 r
.77279 .16187 m
.77279 .3792 L
.7733 .3792 L
.7733 .16187 L
F
.2 .63 .79 r
.77279 .16187 m
.77279 .3792 L
.7733 .3792 L
.7733 .16187 L
s
.678 .847 .902 r
.7733 .16187 m
.7733 .37959 L
.77404 .37959 L
.77404 .16187 L
F
.2 .63 .79 r
.7733 .16187 m
.7733 .37959 L
.77404 .37959 L
.77404 .16187 L
s
.678 .847 .902 r
.77404 .16187 m
.77404 .38041 L
.77477 .38041 L
.77477 .16187 L
F
.2 .63 .79 r
.77404 .16187 m
.77404 .38041 L
.77477 .38041 L
.77477 .16187 L
s
.678 .847 .902 r
.77477 .16187 m
.77477 .38072 L
.77513 .38072 L
.77513 .16187 L
F
.2 .63 .79 r
.77477 .16187 m
.77477 .38072 L
.77513 .38072 L
.77513 .16187 L
s
.678 .847 .902 r
.77513 .16187 m
.77513 .38119 L
.77556 .38119 L
.77556 .16187 L
F
.2 .63 .79 r
.77513 .16187 m
.77513 .38119 L
.77556 .38119 L
.77556 .16187 L
s
.678 .847 .902 r
.77556 .16187 m
.77556 .3815 L
.77618 .3815 L
.77618 .16187 L
F
.2 .63 .79 r
.77556 .16187 m
.77556 .3815 L
.77618 .3815 L
.77618 .16187 L
s
.678 .847 .902 r
.77618 .16187 m
.77618 .38275 L
.77693 .38275 L
.77693 .16187 L
F
.2 .63 .79 r
.77618 .16187 m
.77618 .38275 L
.77693 .38275 L
.77693 .16187 L
s
.678 .847 .902 r
.77693 .16187 m
.77693 .38286 L
.77755 .38286 L
.77755 .16187 L
F
.2 .63 .79 r
.77693 .16187 m
.77693 .38286 L
.77755 .38286 L
.77755 .16187 L
s
.678 .847 .902 r
.77755 .16187 m
.77755 .38369 L
.77792 .38369 L
.77792 .16187 L
F
.2 .63 .79 r
.77755 .16187 m
.77755 .38369 L
.77792 .38369 L
.77792 .16187 L
s
.678 .847 .902 r
.77792 .16187 m
.77792 .38403 L
.77836 .38403 L
.77836 .16187 L
F
.2 .63 .79 r
.77792 .16187 m
.77792 .38403 L
.77836 .38403 L
.77836 .16187 L
s
.678 .847 .902 r
.77836 .16187 m
.77836 .38419 L
.77875 .38419 L
.77875 .16187 L
F
.2 .63 .79 r
.77836 .16187 m
.77836 .38419 L
.77875 .38419 L
.77875 .16187 L
s
.678 .847 .902 r
.77875 .16187 m
.77875 .38511 L
.77938 .38511 L
.77938 .16187 L
F
.2 .63 .79 r
.77875 .16187 m
.77875 .38511 L
.77938 .38511 L
.77938 .16187 L
s
.678 .847 .902 r
.77938 .16187 m
.77938 .38523 L
.77965 .38523 L
.77965 .16187 L
F
.2 .63 .79 r
.77938 .16187 m
.77938 .38523 L
.77965 .38523 L
.77965 .16187 L
s
.678 .847 .902 r
.77965 .16187 m
.77965 .38548 L
.78033 .38548 L
.78033 .16187 L
F
.2 .63 .79 r
.77965 .16187 m
.77965 .38548 L
.78033 .38548 L
.78033 .16187 L
s
.678 .847 .902 r
.78033 .16187 m
.78033 .38661 L
.78094 .38661 L
.78094 .16187 L
F
.2 .63 .79 r
.78033 .16187 m
.78033 .38661 L
.78094 .38661 L
.78094 .16187 L
s
.678 .847 .902 r
.78094 .16187 m
.78094 .3869 L
.78158 .3869 L
.78158 .16187 L
F
.2 .63 .79 r
.78094 .16187 m
.78094 .3869 L
.78158 .3869 L
.78158 .16187 L
s
.678 .847 .902 r
.78158 .16187 m
.78158 .38756 L
.78208 .38756 L
.78208 .16187 L
F
.2 .63 .79 r
.78158 .16187 m
.78158 .38756 L
.78208 .38756 L
.78208 .16187 L
s
.678 .847 .902 r
.78208 .16187 m
.78208 .3882 L
.78271 .3882 L
.78271 .16187 L
F
.2 .63 .79 r
.78208 .16187 m
.78208 .3882 L
.78271 .3882 L
.78271 .16187 L
s
.678 .847 .902 r
.78271 .16187 m
.78271 .38877 L
.78339 .38877 L
.78339 .16187 L
F
.2 .63 .79 r
.78271 .16187 m
.78271 .38877 L
.78339 .38877 L
.78339 .16187 L
s
.678 .847 .902 r
.78339 .16187 m
.78339 .38939 L
.78392 .38939 L
.78392 .16187 L
F
.2 .63 .79 r
.78339 .16187 m
.78339 .38939 L
.78392 .38939 L
.78392 .16187 L
s
.678 .847 .902 r
.78392 .16187 m
.78392 .38975 L
.78452 .38975 L
.78452 .16187 L
F
.2 .63 .79 r
.78392 .16187 m
.78392 .38975 L
.78452 .38975 L
.78452 .16187 L
s
.678 .847 .902 r
.78452 .16187 m
.78452 .39041 L
.78526 .39041 L
.78526 .16187 L
F
.2 .63 .79 r
.78452 .16187 m
.78452 .39041 L
.78526 .39041 L
.78526 .16187 L
s
.678 .847 .902 r
.78526 .16187 m
.78526 .39119 L
.78569 .39119 L
.78569 .16187 L
F
.2 .63 .79 r
.78526 .16187 m
.78526 .39119 L
.78569 .39119 L
.78569 .16187 L
s
.678 .847 .902 r
.78569 .16187 m
.78569 .39211 L
.78641 .39211 L
.78641 .16187 L
F
.2 .63 .79 r
.78569 .16187 m
.78569 .39211 L
.78641 .39211 L
.78641 .16187 L
s
.678 .847 .902 r
.78641 .16187 m
.78641 .3922 L
.78674 .3922 L
.78674 .16187 L
F
.2 .63 .79 r
.78641 .16187 m
.78641 .3922 L
.78674 .3922 L
.78674 .16187 L
s
.678 .847 .902 r
.78674 .16187 m
.78674 .39262 L
.78699 .39262 L
.78699 .16187 L
F
.2 .63 .79 r
.78674 .16187 m
.78674 .39262 L
.78699 .39262 L
.78699 .16187 L
s
.678 .847 .902 r
.78699 .16187 m
.78699 .39312 L
.78748 .39312 L
.78748 .16187 L
F
.2 .63 .79 r
.78699 .16187 m
.78699 .39312 L
.78748 .39312 L
.78748 .16187 L
s
.678 .847 .902 r
.78748 .16187 m
.78748 .3937 L
.7881 .3937 L
.7881 .16187 L
F
.2 .63 .79 r
.78748 .16187 m
.78748 .3937 L
.7881 .3937 L
.7881 .16187 L
s
.678 .847 .902 r
.7881 .16187 m
.7881 .39439 L
.7888 .39439 L
.7888 .16187 L
F
.2 .63 .79 r
.7881 .16187 m
.7881 .39439 L
.7888 .39439 L
.7888 .16187 L
s
.678 .847 .902 r
.7888 .16187 m
.7888 .39476 L
.78923 .39476 L
.78923 .16187 L
F
.2 .63 .79 r
.7888 .16187 m
.7888 .39476 L
.78923 .39476 L
.78923 .16187 L
s
.678 .847 .902 r
.78923 .16187 m
.78923 .39542 L
.78978 .39542 L
.78978 .16187 L
F
.2 .63 .79 r
.78923 .16187 m
.78923 .39542 L
.78978 .39542 L
.78978 .16187 L
s
.678 .847 .902 r
.78978 .16187 m
.78978 .39605 L
.79058 .39605 L
.79058 .16187 L
F
.2 .63 .79 r
.78978 .16187 m
.78978 .39605 L
.79058 .39605 L
.79058 .16187 L
s
.678 .847 .902 r
.79058 .16187 m
.79058 .39628 L
.79116 .39628 L
.79116 .16187 L
F
.2 .63 .79 r
.79058 .16187 m
.79058 .39628 L
.79116 .39628 L
.79116 .16187 L
s
.678 .847 .902 r
.79116 .16187 m
.79116 .39684 L
.79196 .39684 L
.79196 .16187 L
F
.2 .63 .79 r
.79116 .16187 m
.79116 .39684 L
.79196 .39684 L
.79196 .16187 L
s
.678 .847 .902 r
.79196 .16187 m
.79196 .39799 L
.79236 .39799 L
.79236 .16187 L
F
.2 .63 .79 r
.79196 .16187 m
.79196 .39799 L
.79236 .39799 L
.79236 .16187 L
s
.678 .847 .902 r
.79236 .16187 m
.79236 .39839 L
.79278 .39839 L
.79278 .16187 L
F
.2 .63 .79 r
.79236 .16187 m
.79236 .39839 L
.79278 .39839 L
.79278 .16187 L
s
.678 .847 .902 r
.79278 .16187 m
.79278 .3989 L
.79333 .3989 L
.79333 .16187 L
F
.2 .63 .79 r
.79278 .16187 m
.79278 .3989 L
.79333 .3989 L
.79333 .16187 L
s
.678 .847 .902 r
.79333 .16187 m
.79333 .39933 L
.79368 .39933 L
.79368 .16187 L
F
.2 .63 .79 r
.79333 .16187 m
.79333 .39933 L
.79368 .39933 L
.79368 .16187 L
s
.678 .847 .902 r
.79368 .16187 m
.79368 .39941 L
.79428 .39941 L
.79428 .16187 L
F
.2 .63 .79 r
.79368 .16187 m
.79368 .39941 L
.79428 .39941 L
.79428 .16187 L
s
.678 .847 .902 r
.79428 .16187 m
.79428 .40028 L
.79486 .40028 L
.79486 .16187 L
F
.2 .63 .79 r
.79428 .16187 m
.79428 .40028 L
.79486 .40028 L
.79486 .16187 L
s
.678 .847 .902 r
.79486 .16187 m
.79486 .40065 L
.79516 .40065 L
.79516 .16187 L
F
.2 .63 .79 r
.79486 .16187 m
.79486 .40065 L
.79516 .40065 L
.79516 .16187 L
s
.678 .847 .902 r
.79516 .16187 m
.79516 .40103 L
.7957 .40103 L
.7957 .16187 L
F
.2 .63 .79 r
.79516 .16187 m
.79516 .40103 L
.7957 .40103 L
.7957 .16187 L
s
.678 .847 .902 r
.7957 .16187 m
.7957 .40182 L
.79642 .40182 L
.79642 .16187 L
F
.2 .63 .79 r
.7957 .16187 m
.7957 .40182 L
.79642 .40182 L
.79642 .16187 L
s
.678 .847 .902 r
.79642 .16187 m
.79642 .40211 L
.79671 .40211 L
.79671 .16187 L
F
.2 .63 .79 r
.79642 .16187 m
.79642 .40211 L
.79671 .40211 L
.79671 .16187 L
s
.678 .847 .902 r
.79671 .16187 m
.79671 .4025 L
.79722 .4025 L
.79722 .16187 L
F
.2 .63 .79 r
.79671 .16187 m
.79671 .4025 L
.79722 .4025 L
.79722 .16187 L
s
.678 .847 .902 r
.79722 .16187 m
.79722 .40298 L
.79781 .40298 L
.79781 .16187 L
F
.2 .63 .79 r
.79722 .16187 m
.79722 .40298 L
.79781 .40298 L
.79781 .16187 L
s
.678 .847 .902 r
.79781 .16187 m
.79781 .40355 L
.79836 .40355 L
.79836 .16187 L
F
.2 .63 .79 r
.79781 .16187 m
.79781 .40355 L
.79836 .40355 L
.79836 .16187 L
s
.678 .847 .902 r
.79836 .16187 m
.79836 .40406 L
.79873 .40406 L
.79873 .16187 L
F
.2 .63 .79 r
.79836 .16187 m
.79836 .40406 L
.79873 .40406 L
.79873 .16187 L
s
.678 .847 .902 r
.79873 .16187 m
.79873 .40482 L
.79915 .40482 L
.79915 .16187 L
F
.2 .63 .79 r
.79873 .16187 m
.79873 .40482 L
.79915 .40482 L
.79915 .16187 L
s
.678 .847 .902 r
.79915 .16187 m
.79915 .40507 L
.79974 .40507 L
.79974 .16187 L
F
.2 .63 .79 r
.79915 .16187 m
.79915 .40507 L
.79974 .40507 L
.79974 .16187 L
s
.678 .847 .902 r
.79974 .16187 m
.79974 .40549 L
.80004 .40549 L
.80004 .16187 L
F
.2 .63 .79 r
.79974 .16187 m
.79974 .40549 L
.80004 .40549 L
.80004 .16187 L
s
.678 .847 .902 r
.80004 .16187 m
.80004 .40584 L
.8006 .40584 L
.8006 .16187 L
F
.2 .63 .79 r
.80004 .16187 m
.80004 .40584 L
.8006 .40584 L
.8006 .16187 L
s
.678 .847 .902 r
.8006 .16187 m
.8006 .40636 L
.80112 .40636 L
.80112 .16187 L
F
.2 .63 .79 r
.8006 .16187 m
.8006 .40636 L
.80112 .40636 L
.80112 .16187 L
s
.678 .847 .902 r
.80112 .16187 m
.80112 .40712 L
.80153 .40712 L
.80153 .16187 L
F
.2 .63 .79 r
.80112 .16187 m
.80112 .40712 L
.80153 .40712 L
.80153 .16187 L
s
.678 .847 .902 r
.80153 .16187 m
.80153 .40738 L
.80208 .40738 L
.80208 .16187 L
F
.2 .63 .79 r
.80153 .16187 m
.80153 .40738 L
.80208 .40738 L
.80208 .16187 L
s
.678 .847 .902 r
.80208 .16187 m
.80208 .40804 L
.80265 .40804 L
.80265 .16187 L
F
.2 .63 .79 r
.80208 .16187 m
.80208 .40804 L
.80265 .40804 L
.80265 .16187 L
s
.678 .847 .902 r
.80265 .16187 m
.80265 .40842 L
.8034 .40842 L
.8034 .16187 L
F
.2 .63 .79 r
.80265 .16187 m
.80265 .40842 L
.8034 .40842 L
.8034 .16187 L
s
.678 .847 .902 r
.8034 .16187 m
.8034 .40942 L
.80382 .40942 L
.80382 .16187 L
F
.2 .63 .79 r
.8034 .16187 m
.8034 .40942 L
.80382 .40942 L
.80382 .16187 L
s
.678 .847 .902 r
.80382 .16187 m
.80382 .40968 L
.80421 .40968 L
.80421 .16187 L
F
.2 .63 .79 r
.80382 .16187 m
.80382 .40968 L
.80421 .40968 L
.80421 .16187 L
s
.678 .847 .902 r
.80421 .16187 m
.80421 .41016 L
.8046 .41016 L
.8046 .16187 L
F
.2 .63 .79 r
.80421 .16187 m
.80421 .41016 L
.8046 .41016 L
.8046 .16187 L
s
.678 .847 .902 r
.8046 .16187 m
.8046 .41043 L
.80504 .41043 L
.80504 .16187 L
F
.2 .63 .79 r
.8046 .16187 m
.8046 .41043 L
.80504 .41043 L
.80504 .16187 L
s
.678 .847 .902 r
.80504 .16187 m
.80504 .41101 L
.80535 .41101 L
.80535 .16187 L
F
.2 .63 .79 r
.80504 .16187 m
.80504 .41101 L
.80535 .41101 L
.80535 .16187 L
s
.678 .847 .902 r
.80535 .16187 m
.80535 .41123 L
.80595 .41123 L
.80595 .16187 L
F
.2 .63 .79 r
.80535 .16187 m
.80535 .41123 L
.80595 .41123 L
.80595 .16187 L
s
.678 .847 .902 r
.80595 .16187 m
.80595 .41233 L
.80657 .41233 L
.80657 .16187 L
F
.2 .63 .79 r
.80595 .16187 m
.80595 .41233 L
.80657 .41233 L
.80657 .16187 L
s
.678 .847 .902 r
.80657 .16187 m
.80657 .41264 L
.80695 .41264 L
.80695 .16187 L
F
.2 .63 .79 r
.80657 .16187 m
.80657 .41264 L
.80695 .41264 L
.80695 .16187 L
s
.678 .847 .902 r
.80695 .16187 m
.80695 .41293 L
.80753 .41293 L
.80753 .16187 L
F
.2 .63 .79 r
.80695 .16187 m
.80695 .41293 L
.80753 .41293 L
.80753 .16187 L
s
.678 .847 .902 r
.80753 .16187 m
.80753 .41372 L
.80821 .41372 L
.80821 .16187 L
F
.2 .63 .79 r
.80753 .16187 m
.80753 .41372 L
.80821 .41372 L
.80821 .16187 L
s
.678 .847 .902 r
.80821 .16187 m
.80821 .41454 L
.80879 .41454 L
.80879 .16187 L
F
.2 .63 .79 r
.80821 .16187 m
.80821 .41454 L
.80879 .41454 L
.80879 .16187 L
s
.678 .847 .902 r
.80879 .16187 m
.80879 .41498 L
.80947 .41498 L
.80947 .16187 L
F
.2 .63 .79 r
.80879 .16187 m
.80879 .41498 L
.80947 .41498 L
.80947 .16187 L
s
.678 .847 .902 r
.80947 .16187 m
.80947 .41544 L
.81026 .41544 L
.81026 .16187 L
F
.2 .63 .79 r
.80947 .16187 m
.80947 .41544 L
.81026 .41544 L
.81026 .16187 L
s
.678 .847 .902 r
.81026 .16187 m
.81026 .41627 L
.81063 .41627 L
.81063 .16187 L
F
.2 .63 .79 r
.81026 .16187 m
.81026 .41627 L
.81063 .41627 L
.81063 .16187 L
s
.678 .847 .902 r
.81063 .16187 m
.81063 .41686 L
.81108 .41686 L
.81108 .16187 L
F
.2 .63 .79 r
.81063 .16187 m
.81063 .41686 L
.81108 .41686 L
.81108 .16187 L
s
.678 .847 .902 r
.81108 .16187 m
.81108 .41722 L
.81159 .41722 L
.81159 .16187 L
F
.2 .63 .79 r
.81108 .16187 m
.81108 .41722 L
.81159 .41722 L
.81159 .16187 L
s
.678 .847 .902 r
.81159 .16187 m
.81159 .41779 L
.81203 .41779 L
.81203 .16187 L
F
.2 .63 .79 r
.81159 .16187 m
.81159 .41779 L
.81203 .41779 L
.81203 .16187 L
s
.678 .847 .902 r
.81203 .16187 m
.81203 .41797 L
.81234 .41797 L
.81234 .16187 L
F
.2 .63 .79 r
.81203 .16187 m
.81203 .41797 L
.81234 .41797 L
.81234 .16187 L
s
.678 .847 .902 r
.81234 .16187 m
.81234 .41868 L
.81304 .41868 L
.81304 .16187 L
F
.2 .63 .79 r
.81234 .16187 m
.81234 .41868 L
.81304 .41868 L
.81304 .16187 L
s
.678 .847 .902 r
.81304 .16187 m
.81304 .41928 L
.81384 .41928 L
.81384 .16187 L
F
.2 .63 .79 r
.81304 .16187 m
.81304 .41928 L
.81384 .41928 L
.81384 .16187 L
s
.678 .847 .902 r
.81384 .16187 m
.81384 .41975 L
.81411 .41975 L
.81411 .16187 L
F
.2 .63 .79 r
.81384 .16187 m
.81384 .41975 L
.81411 .41975 L
.81411 .16187 L
s
.678 .847 .902 r
.81411 .16187 m
.81411 .42059 L
.81468 .42059 L
.81468 .16187 L
F
.2 .63 .79 r
.81411 .16187 m
.81411 .42059 L
.81468 .42059 L
.81468 .16187 L
s
.678 .847 .902 r
.81468 .16187 m
.81468 .42068 L
.81505 .42068 L
.81505 .16187 L
F
.2 .63 .79 r
.81468 .16187 m
.81468 .42068 L
.81505 .42068 L
.81505 .16187 L
s
.678 .847 .902 r
.81505 .16187 m
.81505 .42109 L
.81534 .42109 L
.81534 .16187 L
F
.2 .63 .79 r
.81505 .16187 m
.81505 .42109 L
.81534 .42109 L
.81534 .16187 L
s
.678 .847 .902 r
.81534 .16187 m
.81534 .42149 L
.816 .42149 L
.816 .16187 L
F
.2 .63 .79 r
.81534 .16187 m
.81534 .42149 L
.816 .42149 L
.816 .16187 L
s
.678 .847 .902 r
.816 .16187 m
.816 .42223 L
.81641 .42223 L
.81641 .16187 L
F
.2 .63 .79 r
.816 .16187 m
.816 .42223 L
.81641 .42223 L
.81641 .16187 L
s
.678 .847 .902 r
.81641 .16187 m
.81641 .42289 L
.8172 .42289 L
.8172 .16187 L
F
.2 .63 .79 r
.81641 .16187 m
.81641 .42289 L
.8172 .42289 L
.8172 .16187 L
s
.678 .847 .902 r
.8172 .16187 m
.8172 .42329 L
.81786 .42329 L
.81786 .16187 L
F
.2 .63 .79 r
.8172 .16187 m
.8172 .42329 L
.81786 .42329 L
.81786 .16187 L
s
.678 .847 .902 r
.81786 .16187 m
.81786 .42421 L
.81845 .42421 L
.81845 .16187 L
F
.2 .63 .79 r
.81786 .16187 m
.81786 .42421 L
.81845 .42421 L
.81845 .16187 L
s
.678 .847 .902 r
.81845 .16187 m
.81845 .42473 L
.81908 .42473 L
.81908 .16187 L
F
.2 .63 .79 r
.81845 .16187 m
.81845 .42473 L
.81908 .42473 L
.81908 .16187 L
s
.678 .847 .902 r
.81908 .16187 m
.81908 .4254 L
.81949 .4254 L
.81949 .16187 L
F
.2 .63 .79 r
.81908 .16187 m
.81908 .4254 L
.81949 .4254 L
.81949 .16187 L
s
.678 .847 .902 r
.81949 .16187 m
.81949 .42573 L
.82001 .42573 L
.82001 .16187 L
F
.2 .63 .79 r
.81949 .16187 m
.81949 .42573 L
.82001 .42573 L
.82001 .16187 L
s
.678 .847 .902 r
.82001 .16187 m
.82001 .42614 L
.82026 .42614 L
.82026 .16187 L
F
.2 .63 .79 r
.82001 .16187 m
.82001 .42614 L
.82026 .42614 L
.82026 .16187 L
s
.678 .847 .902 r
.82026 .16187 m
.82026 .42696 L
.82101 .42696 L
.82101 .16187 L
F
.2 .63 .79 r
.82026 .16187 m
.82026 .42696 L
.82101 .42696 L
.82101 .16187 L
s
.678 .847 .902 r
.82101 .16187 m
.82101 .42759 L
.82166 .42759 L
.82166 .16187 L
F
.2 .63 .79 r
.82101 .16187 m
.82101 .42759 L
.82166 .42759 L
.82166 .16187 L
s
.678 .847 .902 r
.82166 .16187 m
.82166 .4283 L
.8223 .4283 L
.8223 .16187 L
F
.2 .63 .79 r
.82166 .16187 m
.82166 .4283 L
.8223 .4283 L
.8223 .16187 L
s
.678 .847 .902 r
.8223 .16187 m
.8223 .42874 L
.82257 .42874 L
.82257 .16187 L
F
.2 .63 .79 r
.8223 .16187 m
.8223 .42874 L
.82257 .42874 L
.82257 .16187 L
s
.678 .847 .902 r
.82257 .16187 m
.82257 .42894 L
.82319 .42894 L
.82319 .16187 L
F
.2 .63 .79 r
.82257 .16187 m
.82257 .42894 L
.82319 .42894 L
.82319 .16187 L
s
.678 .847 .902 r
.82319 .16187 m
.82319 .42977 L
.82363 .42977 L
.82363 .16187 L
F
.2 .63 .79 r
.82319 .16187 m
.82319 .42977 L
.82363 .42977 L
.82363 .16187 L
s
.678 .847 .902 r
.82363 .16187 m
.82363 .42992 L
.824 .42992 L
.824 .16187 L
F
.2 .63 .79 r
.82363 .16187 m
.82363 .42992 L
.824 .42992 L
.824 .16187 L
s
.678 .847 .902 r
.824 .16187 m
.824 .43035 L
.82465 .43035 L
.82465 .16187 L
F
.2 .63 .79 r
.824 .16187 m
.824 .43035 L
.82465 .43035 L
.82465 .16187 L
s
.678 .847 .902 r
.82465 .16187 m
.82465 .43093 L
.82519 .43093 L
.82519 .16187 L
F
.2 .63 .79 r
.82465 .16187 m
.82465 .43093 L
.82519 .43093 L
.82519 .16187 L
s
.678 .847 .902 r
.82519 .16187 m
.82519 .43158 L
.82574 .43158 L
.82574 .16187 L
F
.2 .63 .79 r
.82519 .16187 m
.82519 .43158 L
.82574 .43158 L
.82574 .16187 L
s
.678 .847 .902 r
.82574 .16187 m
.82574 .43234 L
.82613 .43234 L
.82613 .16187 L
F
.2 .63 .79 r
.82574 .16187 m
.82574 .43234 L
.82613 .43234 L
.82613 .16187 L
s
.678 .847 .902 r
.82613 .16187 m
.82613 .43254 L
.82674 .43254 L
.82674 .16187 L
F
.2 .63 .79 r
.82613 .16187 m
.82613 .43254 L
.82674 .43254 L
.82674 .16187 L
s
.678 .847 .902 r
.82674 .16187 m
.82674 .43314 L
.82753 .43314 L
.82753 .16187 L
F
.2 .63 .79 r
.82674 .16187 m
.82674 .43314 L
.82753 .43314 L
.82753 .16187 L
s
.678 .847 .902 r
.82753 .16187 m
.82753 .43434 L
.82795 .43434 L
.82795 .16187 L
F
.2 .63 .79 r
.82753 .16187 m
.82753 .43434 L
.82795 .43434 L
.82795 .16187 L
s
.678 .847 .902 r
.82795 .16187 m
.82795 .43448 L
.82828 .43448 L
.82828 .16187 L
F
.2 .63 .79 r
.82795 .16187 m
.82795 .43448 L
.82828 .43448 L
.82828 .16187 L
s
.678 .847 .902 r
.82828 .16187 m
.82828 .43537 L
.82905 .43537 L
.82905 .16187 L
F
.2 .63 .79 r
.82828 .16187 m
.82828 .43537 L
.82905 .43537 L
.82905 .16187 L
s
.678 .847 .902 r
.82905 .16187 m
.82905 .43578 L
.82966 .43578 L
.82966 .16187 L
F
.2 .63 .79 r
.82905 .16187 m
.82905 .43578 L
.82966 .43578 L
.82966 .16187 L
s
.678 .847 .902 r
.82966 .16187 m
.82966 .4363 L
.8301 .4363 L
.8301 .16187 L
F
.2 .63 .79 r
.82966 .16187 m
.82966 .4363 L
.8301 .4363 L
.8301 .16187 L
s
.678 .847 .902 r
.8301 .16187 m
.8301 .43672 L
.83058 .43672 L
.83058 .16187 L
F
.2 .63 .79 r
.8301 .16187 m
.8301 .43672 L
.83058 .43672 L
.83058 .16187 L
s
.678 .847 .902 r
.83058 .16187 m
.83058 .43723 L
.831 .43723 L
.831 .16187 L
F
.2 .63 .79 r
.83058 .16187 m
.83058 .43723 L
.831 .43723 L
.831 .16187 L
s
.678 .847 .902 r
.831 .16187 m
.831 .43759 L
.83178 .43759 L
.83178 .16187 L
F
.2 .63 .79 r
.831 .16187 m
.831 .43759 L
.83178 .43759 L
.83178 .16187 L
s
.678 .847 .902 r
.83178 .16187 m
.83178 .43857 L
.83206 .43857 L
.83206 .16187 L
F
.2 .63 .79 r
.83178 .16187 m
.83178 .43857 L
.83206 .43857 L
.83206 .16187 L
s
.678 .847 .902 r
.83206 .16187 m
.83206 .43941 L
.83283 .43941 L
.83283 .16187 L
F
.2 .63 .79 r
.83206 .16187 m
.83206 .43941 L
.83283 .43941 L
.83283 .16187 L
s
.678 .847 .902 r
.83283 .16187 m
.83283 .43951 L
.83323 .43951 L
.83323 .16187 L
F
.2 .63 .79 r
.83283 .16187 m
.83283 .43951 L
.83323 .43951 L
.83323 .16187 L
s
.678 .847 .902 r
.83323 .16187 m
.83323 .43997 L
.83351 .43997 L
.83351 .16187 L
F
.2 .63 .79 r
.83323 .16187 m
.83323 .43997 L
.83351 .43997 L
.83351 .16187 L
s
.678 .847 .902 r
.83351 .16187 m
.83351 .4402 L
.83395 .4402 L
.83395 .16187 L
F
.2 .63 .79 r
.83351 .16187 m
.83351 .4402 L
.83395 .4402 L
.83395 .16187 L
s
.678 .847 .902 r
.83395 .16187 m
.83395 .4407 L
.83432 .4407 L
.83432 .16187 L
F
.2 .63 .79 r
.83395 .16187 m
.83395 .4407 L
.83432 .4407 L
.83432 .16187 L
s
.678 .847 .902 r
.83432 .16187 m
.83432 .44109 L
.83469 .44109 L
.83469 .16187 L
F
.2 .63 .79 r
.83432 .16187 m
.83432 .44109 L
.83469 .44109 L
.83469 .16187 L
s
.678 .847 .902 r
.83469 .16187 m
.83469 .44142 L
.83516 .44142 L
.83516 .16187 L
F
.2 .63 .79 r
.83469 .16187 m
.83469 .44142 L
.83516 .44142 L
.83516 .16187 L
s
.678 .847 .902 r
.83516 .16187 m
.83516 .4421 L
.83597 .4421 L
.83597 .16187 L
F
.2 .63 .79 r
.83516 .16187 m
.83516 .4421 L
.83597 .4421 L
.83597 .16187 L
s
.678 .847 .902 r
.83597 .16187 m
.83597 .44276 L
.83678 .44276 L
.83678 .16187 L
F
.2 .63 .79 r
.83597 .16187 m
.83597 .44276 L
.83678 .44276 L
.83678 .16187 L
s
.678 .847 .902 r
.83678 .16187 m
.83678 .44361 L
.83731 .44361 L
.83731 .16187 L
F
.2 .63 .79 r
.83678 .16187 m
.83678 .44361 L
.83731 .44361 L
.83731 .16187 L
s
.678 .847 .902 r
.83731 .16187 m
.83731 .44492 L
.83804 .44492 L
.83804 .16187 L
F
.2 .63 .79 r
.83731 .16187 m
.83731 .44492 L
.83804 .44492 L
.83804 .16187 L
s
.678 .847 .902 r
.83804 .16187 m
.83804 .44496 L
.83854 .44496 L
.83854 .16187 L
F
.2 .63 .79 r
.83804 .16187 m
.83804 .44496 L
.83854 .44496 L
.83854 .16187 L
s
.678 .847 .902 r
.83854 .16187 m
.83854 .44564 L
.8392 .44564 L
.8392 .16187 L
F
.2 .63 .79 r
.83854 .16187 m
.83854 .44564 L
.8392 .44564 L
.8392 .16187 L
s
.678 .847 .902 r
.8392 .16187 m
.8392 .44682 L
.83992 .44682 L
.83992 .16187 L
F
.2 .63 .79 r
.8392 .16187 m
.8392 .44682 L
.83992 .44682 L
.83992 .16187 L
s
.678 .847 .902 r
.83992 .16187 m
.83992 .44766 L
.84068 .44766 L
.84068 .16187 L
F
.2 .63 .79 r
.83992 .16187 m
.83992 .44766 L
.84068 .44766 L
.84068 .16187 L
s
.678 .847 .902 r
.84068 .16187 m
.84068 .44775 L
.841 .44775 L
.841 .16187 L
F
.2 .63 .79 r
.84068 .16187 m
.84068 .44775 L
.841 .44775 L
.841 .16187 L
s
.678 .847 .902 r
.841 .16187 m
.841 .4486 L
.84157 .4486 L
.84157 .16187 L
F
.2 .63 .79 r
.841 .16187 m
.841 .4486 L
.84157 .4486 L
.84157 .16187 L
s
.678 .847 .902 r
.84157 .16187 m
.84157 .44869 L
.84233 .44869 L
.84233 .16187 L
F
.2 .63 .79 r
.84157 .16187 m
.84157 .44869 L
.84233 .44869 L
.84233 .16187 L
s
.678 .847 .902 r
.84233 .16187 m
.84233 .44968 L
.84273 .44968 L
.84273 .16187 L
F
.2 .63 .79 r
.84233 .16187 m
.84233 .44968 L
.84273 .44968 L
.84273 .16187 L
s
.678 .847 .902 r
.84273 .16187 m
.84273 .45039 L
.84341 .45039 L
.84341 .16187 L
F
.2 .63 .79 r
.84273 .16187 m
.84273 .45039 L
.84341 .45039 L
.84341 .16187 L
s
.678 .847 .902 r
.84341 .16187 m
.84341 .45085 L
.84374 .45085 L
.84374 .16187 L
F
.2 .63 .79 r
.84341 .16187 m
.84341 .45085 L
.84374 .45085 L
.84374 .16187 L
s
.678 .847 .902 r
.84374 .16187 m
.84374 .45142 L
.84433 .45142 L
.84433 .16187 L
F
.2 .63 .79 r
.84374 .16187 m
.84374 .45142 L
.84433 .45142 L
.84433 .16187 L
s
.678 .847 .902 r
.84433 .16187 m
.84433 .45177 L
.84474 .45177 L
.84474 .16187 L
F
.2 .63 .79 r
.84433 .16187 m
.84433 .45177 L
.84474 .45177 L
.84474 .16187 L
s
.678 .847 .902 r
.84474 .16187 m
.84474 .45269 L
.8454 .45269 L
.8454 .16187 L
F
.2 .63 .79 r
.84474 .16187 m
.84474 .45269 L
.8454 .45269 L
.8454 .16187 L
s
.678 .847 .902 r
.8454 .16187 m
.8454 .45301 L
.84576 .45301 L
.84576 .16187 L
F
.2 .63 .79 r
.8454 .16187 m
.8454 .45301 L
.84576 .45301 L
.84576 .16187 L
s
.678 .847 .902 r
.84576 .16187 m
.84576 .45339 L
.84619 .45339 L
.84619 .16187 L
F
.2 .63 .79 r
.84576 .16187 m
.84576 .45339 L
.84619 .45339 L
.84619 .16187 L
s
.678 .847 .902 r
.84619 .16187 m
.84619 .45362 L
.84656 .45362 L
.84656 .16187 L
F
.2 .63 .79 r
.84619 .16187 m
.84619 .45362 L
.84656 .45362 L
.84656 .16187 L
s
.678 .847 .902 r
.84656 .16187 m
.84656 .45441 L
.84702 .45441 L
.84702 .16187 L
F
.2 .63 .79 r
.84656 .16187 m
.84656 .45441 L
.84702 .45441 L
.84702 .16187 L
s
.678 .847 .902 r
.84702 .16187 m
.84702 .45489 L
.84782 .45489 L
.84782 .16187 L
F
.2 .63 .79 r
.84702 .16187 m
.84702 .45489 L
.84782 .45489 L
.84782 .16187 L
s
.678 .847 .902 r
.84782 .16187 m
.84782 .45546 L
.84812 .45546 L
.84812 .16187 L
F
.2 .63 .79 r
.84782 .16187 m
.84782 .45546 L
.84812 .45546 L
.84812 .16187 L
s
.678 .847 .902 r
.84812 .16187 m
.84812 .4557 L
.84883 .4557 L
.84883 .16187 L
F
.2 .63 .79 r
.84812 .16187 m
.84812 .4557 L
.84883 .4557 L
.84883 .16187 L
s
.678 .847 .902 r
.84883 .16187 m
.84883 .45672 L
.84929 .45672 L
.84929 .16187 L
F
.2 .63 .79 r
.84883 .16187 m
.84883 .45672 L
.84929 .45672 L
.84929 .16187 L
s
.678 .847 .902 r
.84929 .16187 m
.84929 .45732 L
.85009 .45732 L
.85009 .16187 L
F
.2 .63 .79 r
.84929 .16187 m
.84929 .45732 L
.85009 .45732 L
.85009 .16187 L
s
.678 .847 .902 r
.85009 .16187 m
.85009 .458 L
.85067 .458 L
.85067 .16187 L
F
.2 .63 .79 r
.85009 .16187 m
.85009 .458 L
.85067 .458 L
.85067 .16187 L
s
.678 .847 .902 r
.85067 .16187 m
.85067 .45845 L
.85145 .45845 L
.85145 .16187 L
F
.2 .63 .79 r
.85067 .16187 m
.85067 .45845 L
.85145 .45845 L
.85145 .16187 L
s
.678 .847 .902 r
.85145 .16187 m
.85145 .45971 L
.85222 .45971 L
.85222 .16187 L
F
.2 .63 .79 r
.85145 .16187 m
.85145 .45971 L
.85222 .45971 L
.85222 .16187 L
s
.678 .847 .902 r
.85222 .16187 m
.85222 .46015 L
.8526 .46015 L
.8526 .16187 L
F
.2 .63 .79 r
.85222 .16187 m
.85222 .46015 L
.8526 .46015 L
.8526 .16187 L
s
.678 .847 .902 r
.8526 .16187 m
.8526 .46083 L
.85326 .46083 L
.85326 .16187 L
F
.2 .63 .79 r
.8526 .16187 m
.8526 .46083 L
.85326 .46083 L
.85326 .16187 L
s
.678 .847 .902 r
.85326 .16187 m
.85326 .46123 L
.85353 .46123 L
.85353 .16187 L
F
.2 .63 .79 r
.85326 .16187 m
.85326 .46123 L
.85353 .46123 L
.85353 .16187 L
s
.678 .847 .902 r
.85353 .16187 m
.85353 .46187 L
.85422 .46187 L
.85422 .16187 L
F
.2 .63 .79 r
.85353 .16187 m
.85353 .46187 L
.85422 .46187 L
.85422 .16187 L
s
.678 .847 .902 r
.85422 .16187 m
.85422 .46245 L
.85484 .46245 L
.85484 .16187 L
F
.2 .63 .79 r
.85422 .16187 m
.85422 .46245 L
.85484 .46245 L
.85484 .16187 L
s
.678 .847 .902 r
.85484 .16187 m
.85484 .46326 L
.85555 .46326 L
.85555 .16187 L
F
.2 .63 .79 r
.85484 .16187 m
.85484 .46326 L
.85555 .46326 L
.85555 .16187 L
s
.678 .847 .902 r
.85555 .16187 m
.85555 .46417 L
.85622 .46417 L
.85622 .16187 L
F
.2 .63 .79 r
.85555 .16187 m
.85555 .46417 L
.85622 .46417 L
.85622 .16187 L
s
.678 .847 .902 r
.85622 .16187 m
.85622 .4646 L
.85647 .4646 L
.85647 .16187 L
F
.2 .63 .79 r
.85622 .16187 m
.85622 .4646 L
.85647 .4646 L
.85647 .16187 L
s
.678 .847 .902 r
.85647 .16187 m
.85647 .46508 L
.857 .46508 L
.857 .16187 L
F
.2 .63 .79 r
.85647 .16187 m
.85647 .46508 L
.857 .46508 L
.857 .16187 L
s
.678 .847 .902 r
.857 .16187 m
.857 .46554 L
.85737 .46554 L
.85737 .16187 L
F
.2 .63 .79 r
.857 .16187 m
.857 .46554 L
.85737 .46554 L
.85737 .16187 L
s
.678 .847 .902 r
.85737 .16187 m
.85737 .4658 L
.85787 .4658 L
.85787 .16187 L
F
.2 .63 .79 r
.85737 .16187 m
.85737 .4658 L
.85787 .4658 L
.85787 .16187 L
s
.678 .847 .902 r
.85787 .16187 m
.85787 .46657 L
.85827 .46657 L
.85827 .16187 L
F
.2 .63 .79 r
.85787 .16187 m
.85787 .46657 L
.85827 .46657 L
.85827 .16187 L
s
.678 .847 .902 r
.85827 .16187 m
.85827 .46663 L
.85868 .46663 L
.85868 .16187 L
F
.2 .63 .79 r
.85827 .16187 m
.85827 .46663 L
.85868 .46663 L
.85868 .16187 L
s
.678 .847 .902 r
.85868 .16187 m
.85868 .46724 L
.85943 .46724 L
.85943 .16187 L
F
.2 .63 .79 r
.85868 .16187 m
.85868 .46724 L
.85943 .46724 L
.85943 .16187 L
s
.678 .847 .902 r
.85943 .16187 m
.85943 .46796 L
.8598 .46796 L
.8598 .16187 L
F
.2 .63 .79 r
.85943 .16187 m
.85943 .46796 L
.8598 .46796 L
.8598 .16187 L
s
.678 .847 .902 r
.8598 .16187 m
.8598 .46835 L
.86055 .46835 L
.86055 .16187 L
F
.2 .63 .79 r
.8598 .16187 m
.8598 .46835 L
.86055 .46835 L
.86055 .16187 L
s
.678 .847 .902 r
.86055 .16187 m
.86055 .46934 L
.86097 .46934 L
.86097 .16187 L
F
.2 .63 .79 r
.86055 .16187 m
.86055 .46934 L
.86097 .46934 L
.86097 .16187 L
s
.678 .847 .902 r
.86097 .16187 m
.86097 .47018 L
.86167 .47018 L
.86167 .16187 L
F
.2 .63 .79 r
.86097 .16187 m
.86097 .47018 L
.86167 .47018 L
.86167 .16187 L
s
.678 .847 .902 r
.86167 .16187 m
.86167 .47039 L
.86213 .47039 L
.86213 .16187 L
F
.2 .63 .79 r
.86167 .16187 m
.86167 .47039 L
.86213 .47039 L
.86213 .16187 L
s
.678 .847 .902 r
.86213 .16187 m
.86213 .47106 L
.86265 .47106 L
.86265 .16187 L
F
.2 .63 .79 r
.86213 .16187 m
.86213 .47106 L
.86265 .47106 L
.86265 .16187 L
s
.678 .847 .902 r
.86265 .16187 m
.86265 .47142 L
.86308 .47142 L
.86308 .16187 L
F
.2 .63 .79 r
.86265 .16187 m
.86265 .47142 L
.86308 .47142 L
.86308 .16187 L
s
.678 .847 .902 r
.86308 .16187 m
.86308 .47201 L
.86345 .47201 L
.86345 .16187 L
F
.2 .63 .79 r
.86308 .16187 m
.86308 .47201 L
.86345 .47201 L
.86345 .16187 L
s
.678 .847 .902 r
.86345 .16187 m
.86345 .47229 L
.86394 .47229 L
.86394 .16187 L
F
.2 .63 .79 r
.86345 .16187 m
.86345 .47229 L
.86394 .47229 L
.86394 .16187 L
s
.678 .847 .902 r
.86394 .16187 m
.86394 .4733 L
.86449 .4733 L
.86449 .16187 L
F
.2 .63 .79 r
.86394 .16187 m
.86394 .4733 L
.86449 .4733 L
.86449 .16187 L
s
.678 .847 .902 r
.86449 .16187 m
.86449 .47364 L
.86478 .47364 L
.86478 .16187 L
F
.2 .63 .79 r
.86449 .16187 m
.86449 .47364 L
.86478 .47364 L
.86478 .16187 L
s
.678 .847 .902 r
.86478 .16187 m
.86478 .47366 L
.86529 .47366 L
.86529 .16187 L
F
.2 .63 .79 r
.86478 .16187 m
.86478 .47366 L
.86529 .47366 L
.86529 .16187 L
s
.678 .847 .902 r
.86529 .16187 m
.86529 .47473 L
.86576 .47473 L
.86576 .16187 L
F
.2 .63 .79 r
.86529 .16187 m
.86529 .47473 L
.86576 .47473 L
.86576 .16187 L
s
.678 .847 .902 r
.86576 .16187 m
.86576 .47501 L
.86643 .47501 L
.86643 .16187 L
F
.2 .63 .79 r
.86576 .16187 m
.86576 .47501 L
.86643 .47501 L
.86643 .16187 L
s
.678 .847 .902 r
.86643 .16187 m
.86643 .47577 L
.86691 .47577 L
.86691 .16187 L
F
.2 .63 .79 r
.86643 .16187 m
.86643 .47577 L
.86691 .47577 L
.86691 .16187 L
s
.678 .847 .902 r
.86691 .16187 m
.86691 .47632 L
.86752 .47632 L
.86752 .16187 L
F
.2 .63 .79 r
.86691 .16187 m
.86691 .47632 L
.86752 .47632 L
.86752 .16187 L
s
.678 .847 .902 r
.86752 .16187 m
.86752 .47683 L
.86812 .47683 L
.86812 .16187 L
F
.2 .63 .79 r
.86752 .16187 m
.86752 .47683 L
.86812 .47683 L
.86812 .16187 L
s
.678 .847 .902 r
.86812 .16187 m
.86812 .47768 L
.86879 .47768 L
.86879 .16187 L
F
.2 .63 .79 r
.86812 .16187 m
.86812 .47768 L
.86879 .47768 L
.86879 .16187 L
s
.678 .847 .902 r
.86879 .16187 m
.86879 .47872 L
.86954 .47872 L
.86954 .16187 L
F
.2 .63 .79 r
.86879 .16187 m
.86879 .47872 L
.86954 .47872 L
.86954 .16187 L
s
.678 .847 .902 r
.86954 .16187 m
.86954 .47923 L
.87002 .47923 L
.87002 .16187 L
F
.2 .63 .79 r
.86954 .16187 m
.86954 .47923 L
.87002 .47923 L
.87002 .16187 L
s
.678 .847 .902 r
.87002 .16187 m
.87002 .47974 L
.87036 .47974 L
.87036 .16187 L
F
.2 .63 .79 r
.87002 .16187 m
.87002 .47974 L
.87036 .47974 L
.87036 .16187 L
s
.678 .847 .902 r
.87036 .16187 m
.87036 .48007 L
.87087 .48007 L
.87087 .16187 L
F
.2 .63 .79 r
.87036 .16187 m
.87036 .48007 L
.87087 .48007 L
.87087 .16187 L
s
.678 .847 .902 r
.87087 .16187 m
.87087 .4808 L
.87145 .4808 L
.87145 .16187 L
F
.2 .63 .79 r
.87087 .16187 m
.87087 .4808 L
.87145 .4808 L
.87145 .16187 L
s
.678 .847 .902 r
.87145 .16187 m
.87145 .48123 L
.87199 .48123 L
.87199 .16187 L
F
.2 .63 .79 r
.87145 .16187 m
.87145 .48123 L
.87199 .48123 L
.87199 .16187 L
s
.678 .847 .902 r
.87199 .16187 m
.87199 .4821 L
.87277 .4821 L
.87277 .16187 L
F
.2 .63 .79 r
.87199 .16187 m
.87199 .4821 L
.87277 .4821 L
.87277 .16187 L
s
.678 .847 .902 r
.87277 .16187 m
.87277 .48269 L
.87335 .48269 L
.87335 .16187 L
F
.2 .63 .79 r
.87277 .16187 m
.87277 .48269 L
.87335 .48269 L
.87335 .16187 L
s
.678 .847 .902 r
.87335 .16187 m
.87335 .4831 L
.87375 .4831 L
.87375 .16187 L
F
.2 .63 .79 r
.87335 .16187 m
.87335 .4831 L
.87375 .4831 L
.87375 .16187 L
s
.678 .847 .902 r
.87375 .16187 m
.87375 .48389 L
.8744 .48389 L
.8744 .16187 L
F
.2 .63 .79 r
.87375 .16187 m
.87375 .48389 L
.8744 .48389 L
.8744 .16187 L
s
.678 .847 .902 r
.8744 .16187 m
.8744 .48446 L
.87496 .48446 L
.87496 .16187 L
F
.2 .63 .79 r
.8744 .16187 m
.8744 .48446 L
.87496 .48446 L
.87496 .16187 L
s
.678 .847 .902 r
.87496 .16187 m
.87496 .48513 L
.87525 .48513 L
.87525 .16187 L
F
.2 .63 .79 r
.87496 .16187 m
.87496 .48513 L
.87525 .48513 L
.87525 .16187 L
s
.678 .847 .902 r
.87525 .16187 m
.87525 .48596 L
.87604 .48596 L
.87604 .16187 L
F
.2 .63 .79 r
.87525 .16187 m
.87525 .48596 L
.87604 .48596 L
.87604 .16187 L
s
.678 .847 .902 r
.87604 .16187 m
.87604 .48604 L
.87656 .48604 L
.87656 .16187 L
F
.2 .63 .79 r
.87604 .16187 m
.87604 .48604 L
.87656 .48604 L
.87656 .16187 L
s
.678 .847 .902 r
.87656 .16187 m
.87656 .48669 L
.87687 .48669 L
.87687 .16187 L
F
.2 .63 .79 r
.87656 .16187 m
.87656 .48669 L
.87687 .48669 L
.87687 .16187 L
s
.678 .847 .902 r
.87687 .16187 m
.87687 .48754 L
.87741 .48754 L
.87741 .16187 L
F
.2 .63 .79 r
.87687 .16187 m
.87687 .48754 L
.87741 .48754 L
.87741 .16187 L
s
.678 .847 .902 r
.87741 .16187 m
.87741 .48835 L
.87815 .48835 L
.87815 .16187 L
F
.2 .63 .79 r
.87741 .16187 m
.87741 .48835 L
.87815 .48835 L
.87815 .16187 L
s
.678 .847 .902 r
.87815 .16187 m
.87815 .48838 L
.8784 .48838 L
.8784 .16187 L
F
.2 .63 .79 r
.87815 .16187 m
.87815 .48838 L
.8784 .48838 L
.8784 .16187 L
s
.678 .847 .902 r
.8784 .16187 m
.8784 .48883 L
.87905 .48883 L
.87905 .16187 L
F
.2 .63 .79 r
.8784 .16187 m
.8784 .48883 L
.87905 .48883 L
.87905 .16187 L
s
.678 .847 .902 r
.87905 .16187 m
.87905 .48982 L
.87973 .48982 L
.87973 .16187 L
F
.2 .63 .79 r
.87905 .16187 m
.87905 .48982 L
.87973 .48982 L
.87973 .16187 L
s
.678 .847 .902 r
.87973 .16187 m
.87973 .49034 L
.88024 .49034 L
.88024 .16187 L
F
.2 .63 .79 r
.87973 .16187 m
.87973 .49034 L
.88024 .49034 L
.88024 .16187 L
s
.678 .847 .902 r
.88024 .16187 m
.88024 .49095 L
.88068 .49095 L
.88068 .16187 L
F
.2 .63 .79 r
.88024 .16187 m
.88024 .49095 L
.88068 .49095 L
.88068 .16187 L
s
.678 .847 .902 r
.88068 .16187 m
.88068 .4915 L
.88097 .4915 L
.88097 .16187 L
F
.2 .63 .79 r
.88068 .16187 m
.88068 .4915 L
.88097 .4915 L
.88097 .16187 L
s
.678 .847 .902 r
.88097 .16187 m
.88097 .49153 L
.88123 .49153 L
.88123 .16187 L
F
.2 .63 .79 r
.88097 .16187 m
.88097 .49153 L
.88123 .49153 L
.88123 .16187 L
s
.678 .847 .902 r
.88123 .16187 m
.88123 .49215 L
.8818 .49215 L
.8818 .16187 L
F
.2 .63 .79 r
.88123 .16187 m
.88123 .49215 L
.8818 .49215 L
.8818 .16187 L
s
.678 .847 .902 r
.8818 .16187 m
.8818 .49313 L
.88256 .49313 L
.88256 .16187 L
F
.2 .63 .79 r
.8818 .16187 m
.8818 .49313 L
.88256 .49313 L
.88256 .16187 L
s
.678 .847 .902 r
.88256 .16187 m
.88256 .49334 L
.88332 .49334 L
.88332 .16187 L
F
.2 .63 .79 r
.88256 .16187 m
.88256 .49334 L
.88332 .49334 L
.88332 .16187 L
s
.678 .847 .902 r
.88332 .16187 m
.88332 .49446 L
.88387 .49446 L
.88387 .16187 L
F
.2 .63 .79 r
.88332 .16187 m
.88332 .49446 L
.88387 .49446 L
.88387 .16187 L
s
.678 .847 .902 r
.88387 .16187 m
.88387 .49549 L
.88466 .49549 L
.88466 .16187 L
F
.2 .63 .79 r
.88387 .16187 m
.88387 .49549 L
.88466 .49549 L
.88466 .16187 L
s
.678 .847 .902 r
.88466 .16187 m
.88466 .49584 L
.88513 .49584 L
.88513 .16187 L
F
.2 .63 .79 r
.88466 .16187 m
.88466 .49584 L
.88513 .49584 L
.88513 .16187 L
s
.678 .847 .902 r
.88513 .16187 m
.88513 .49654 L
.88591 .49654 L
.88591 .16187 L
F
.2 .63 .79 r
.88513 .16187 m
.88513 .49654 L
.88591 .49654 L
.88591 .16187 L
s
.678 .847 .902 r
.88591 .16187 m
.88591 .49716 L
.8867 .49716 L
.8867 .16187 L
F
.2 .63 .79 r
.88591 .16187 m
.88591 .49716 L
.8867 .49716 L
.8867 .16187 L
s
.678 .847 .902 r
.8867 .16187 m
.8867 .49845 L
.88733 .49845 L
.88733 .16187 L
F
.2 .63 .79 r
.8867 .16187 m
.8867 .49845 L
.88733 .49845 L
.88733 .16187 L
s
.678 .847 .902 r
.88733 .16187 m
.88733 .49922 L
.88796 .49922 L
.88796 .16187 L
F
.2 .63 .79 r
.88733 .16187 m
.88733 .49922 L
.88796 .49922 L
.88796 .16187 L
s
.678 .847 .902 r
.88796 .16187 m
.88796 .49935 L
.88843 .49935 L
.88843 .16187 L
F
.2 .63 .79 r
.88796 .16187 m
.88796 .49935 L
.88843 .49935 L
.88843 .16187 L
s
.678 .847 .902 r
.88843 .16187 m
.88843 .50005 L
.88916 .50005 L
.88916 .16187 L
F
.2 .63 .79 r
.88843 .16187 m
.88843 .50005 L
.88916 .50005 L
.88916 .16187 L
s
.678 .847 .902 r
.88916 .16187 m
.88916 .50129 L
.88982 .50129 L
.88982 .16187 L
F
.2 .63 .79 r
.88916 .16187 m
.88916 .50129 L
.88982 .50129 L
.88982 .16187 L
s
.678 .847 .902 r
.88982 .16187 m
.88982 .50173 L
.89017 .50173 L
.89017 .16187 L
F
.2 .63 .79 r
.88982 .16187 m
.88982 .50173 L
.89017 .50173 L
.89017 .16187 L
s
.678 .847 .902 r
.89017 .16187 m
.89017 .50217 L
.89057 .50217 L
.89057 .16187 L
F
.2 .63 .79 r
.89017 .16187 m
.89017 .50217 L
.89057 .50217 L
.89057 .16187 L
s
.678 .847 .902 r
.89057 .16187 m
.89057 .50238 L
.891 .50238 L
.891 .16187 L
F
.2 .63 .79 r
.89057 .16187 m
.89057 .50238 L
.891 .50238 L
.891 .16187 L
s
.678 .847 .902 r
.891 .16187 m
.891 .50344 L
.89172 .50344 L
.89172 .16187 L
F
.2 .63 .79 r
.891 .16187 m
.891 .50344 L
.89172 .50344 L
.89172 .16187 L
s
.678 .847 .902 r
.89172 .16187 m
.89172 .50386 L
.89206 .50386 L
.89206 .16187 L
F
.2 .63 .79 r
.89172 .16187 m
.89172 .50386 L
.89206 .50386 L
.89206 .16187 L
s
.678 .847 .902 r
.89206 .16187 m
.89206 .5043 L
.89262 .5043 L
.89262 .16187 L
F
.2 .63 .79 r
.89206 .16187 m
.89206 .5043 L
.89262 .5043 L
.89262 .16187 L
s
.678 .847 .902 r
.89262 .16187 m
.89262 .50499 L
.89318 .50499 L
.89318 .16187 L
F
.2 .63 .79 r
.89262 .16187 m
.89262 .50499 L
.89318 .50499 L
.89318 .16187 L
s
.678 .847 .902 r
.89318 .16187 m
.89318 .50543 L
.89363 .50543 L
.89363 .16187 L
F
.2 .63 .79 r
.89318 .16187 m
.89318 .50543 L
.89363 .50543 L
.89363 .16187 L
s
.678 .847 .902 r
.89363 .16187 m
.89363 .50595 L
.89434 .50595 L
.89434 .16187 L
F
.2 .63 .79 r
.89363 .16187 m
.89363 .50595 L
.89434 .50595 L
.89434 .16187 L
s
.678 .847 .902 r
.89434 .16187 m
.89434 .50684 L
.89485 .50684 L
.89485 .16187 L
F
.2 .63 .79 r
.89434 .16187 m
.89434 .50684 L
.89485 .50684 L
.89485 .16187 L
s
.678 .847 .902 r
.89485 .16187 m
.89485 .50744 L
.89539 .50744 L
.89539 .16187 L
F
.2 .63 .79 r
.89485 .16187 m
.89485 .50744 L
.89539 .50744 L
.89539 .16187 L
s
.678 .847 .902 r
.89539 .16187 m
.89539 .50841 L
.89609 .50841 L
.89609 .16187 L
F
.2 .63 .79 r
.89539 .16187 m
.89539 .50841 L
.89609 .50841 L
.89609 .16187 L
s
.678 .847 .902 r
.89609 .16187 m
.89609 .50889 L
.89684 .50889 L
.89684 .16187 L
F
.2 .63 .79 r
.89609 .16187 m
.89609 .50889 L
.89684 .50889 L
.89684 .16187 L
s
.678 .847 .902 r
.89684 .16187 m
.89684 .50966 L
.8974 .50966 L
.8974 .16187 L
F
.2 .63 .79 r
.89684 .16187 m
.89684 .50966 L
.8974 .50966 L
.8974 .16187 L
s
.678 .847 .902 r
.8974 .16187 m
.8974 .50999 L
.8982 .50999 L
.8982 .16187 L
F
.2 .63 .79 r
.8974 .16187 m
.8974 .50999 L
.8982 .50999 L
.8982 .16187 L
s
.678 .847 .902 r
.8982 .16187 m
.8982 .51092 L
.8989 .51092 L
.8989 .16187 L
F
.2 .63 .79 r
.8982 .16187 m
.8982 .51092 L
.8989 .51092 L
.8989 .16187 L
s
.678 .847 .902 r
.8989 .16187 m
.8989 .51171 L
.89943 .51171 L
.89943 .16187 L
F
.2 .63 .79 r
.8989 .16187 m
.8989 .51171 L
.89943 .51171 L
.89943 .16187 L
s
.678 .847 .902 r
.89943 .16187 m
.89943 .51231 L
.90001 .51231 L
.90001 .16187 L
F
.2 .63 .79 r
.89943 .16187 m
.89943 .51231 L
.90001 .51231 L
.90001 .16187 L
s
.678 .847 .902 r
.90001 .16187 m
.90001 .51318 L
.90027 .51318 L
.90027 .16187 L
F
.2 .63 .79 r
.90001 .16187 m
.90001 .51318 L
.90027 .51318 L
.90027 .16187 L
s
.678 .847 .902 r
.90027 .16187 m
.90027 .51332 L
.90058 .51332 L
.90058 .16187 L
F
.2 .63 .79 r
.90027 .16187 m
.90027 .51332 L
.90058 .51332 L
.90058 .16187 L
s
.678 .847 .902 r
.90058 .16187 m
.90058 .51374 L
.90129 .51374 L
.90129 .16187 L
F
.2 .63 .79 r
.90058 .16187 m
.90058 .51374 L
.90129 .51374 L
.90129 .16187 L
s
.678 .847 .902 r
.90129 .16187 m
.90129 .51438 L
.90165 .51438 L
.90165 .16187 L
F
.2 .63 .79 r
.90129 .16187 m
.90129 .51438 L
.90165 .51438 L
.90165 .16187 L
s
.678 .847 .902 r
.90165 .16187 m
.90165 .51501 L
.90197 .51501 L
.90197 .16187 L
F
.2 .63 .79 r
.90165 .16187 m
.90165 .51501 L
.90197 .51501 L
.90197 .16187 L
s
.678 .847 .902 r
.90197 .16187 m
.90197 .5154 L
.90244 .5154 L
.90244 .16187 L
F
.2 .63 .79 r
.90197 .16187 m
.90197 .5154 L
.90244 .5154 L
.90244 .16187 L
s
.678 .847 .902 r
.90244 .16187 m
.90244 .51593 L
.90304 .51593 L
.90304 .16187 L
F
.2 .63 .79 r
.90244 .16187 m
.90244 .51593 L
.90304 .51593 L
.90304 .16187 L
s
.678 .847 .902 r
.90304 .16187 m
.90304 .51653 L
.90381 .51653 L
.90381 .16187 L
F
.2 .63 .79 r
.90304 .16187 m
.90304 .51653 L
.90381 .51653 L
.90381 .16187 L
s
.678 .847 .902 r
.90381 .16187 m
.90381 .51752 L
.90451 .51752 L
.90451 .16187 L
F
.2 .63 .79 r
.90381 .16187 m
.90381 .51752 L
.90451 .51752 L
.90451 .16187 L
s
.678 .847 .902 r
.90451 .16187 m
.90451 .51842 L
.90506 .51842 L
.90506 .16187 L
F
.2 .63 .79 r
.90451 .16187 m
.90451 .51842 L
.90506 .51842 L
.90506 .16187 L
s
.678 .847 .902 r
.90506 .16187 m
.90506 .51897 L
.90557 .51897 L
.90557 .16187 L
F
.2 .63 .79 r
.90506 .16187 m
.90506 .51897 L
.90557 .51897 L
.90557 .16187 L
s
.678 .847 .902 r
.90557 .16187 m
.90557 .51956 L
.90601 .51956 L
.90601 .16187 L
F
.2 .63 .79 r
.90557 .16187 m
.90557 .51956 L
.90601 .51956 L
.90601 .16187 L
s
.678 .847 .902 r
.90601 .16187 m
.90601 .52006 L
.9064 .52006 L
.9064 .16187 L
F
.2 .63 .79 r
.90601 .16187 m
.90601 .52006 L
.9064 .52006 L
.9064 .16187 L
s
.678 .847 .902 r
.9064 .16187 m
.9064 .52025 L
.90674 .52025 L
.90674 .16187 L
F
.2 .63 .79 r
.9064 .16187 m
.9064 .52025 L
.90674 .52025 L
.90674 .16187 L
s
.678 .847 .902 r
.90674 .16187 m
.90674 .52073 L
.90734 .52073 L
.90734 .16187 L
F
.2 .63 .79 r
.90674 .16187 m
.90674 .52073 L
.90734 .52073 L
.90734 .16187 L
s
.678 .847 .902 r
.90734 .16187 m
.90734 .52213 L
.90809 .52213 L
.90809 .16187 L
F
.2 .63 .79 r
.90734 .16187 m
.90734 .52213 L
.90809 .52213 L
.90809 .16187 L
s
.678 .847 .902 r
.90809 .16187 m
.90809 .52218 L
.90874 .52218 L
.90874 .16187 L
F
.2 .63 .79 r
.90809 .16187 m
.90809 .52218 L
.90874 .52218 L
.90874 .16187 L
s
.678 .847 .902 r
.90874 .16187 m
.90874 .52298 L
.90919 .52298 L
.90919 .16187 L
F
.2 .63 .79 r
.90874 .16187 m
.90874 .52298 L
.90919 .52298 L
.90919 .16187 L
s
.678 .847 .902 r
.90919 .16187 m
.90919 .52394 L
.90985 .52394 L
.90985 .16187 L
F
.2 .63 .79 r
.90919 .16187 m
.90919 .52394 L
.90985 .52394 L
.90985 .16187 L
s
.678 .847 .902 r
.90985 .16187 m
.90985 .52439 L
.91028 .52439 L
.91028 .16187 L
F
.2 .63 .79 r
.90985 .16187 m
.90985 .52439 L
.91028 .52439 L
.91028 .16187 L
s
.678 .847 .902 r
.91028 .16187 m
.91028 .52467 L
.91094 .52467 L
.91094 .16187 L
F
.2 .63 .79 r
.91028 .16187 m
.91028 .52467 L
.91094 .52467 L
.91094 .16187 L
s
.678 .847 .902 r
.91094 .16187 m
.91094 .52549 L
.91149 .52549 L
.91149 .16187 L
F
.2 .63 .79 r
.91094 .16187 m
.91094 .52549 L
.91149 .52549 L
.91149 .16187 L
s
.678 .847 .902 r
.91149 .16187 m
.91149 .52633 L
.91187 .52633 L
.91187 .16187 L
F
.2 .63 .79 r
.91149 .16187 m
.91149 .52633 L
.91187 .52633 L
.91187 .16187 L
s
.678 .847 .902 r
.91187 .16187 m
.91187 .52677 L
.91251 .52677 L
.91251 .16187 L
F
.2 .63 .79 r
.91187 .16187 m
.91187 .52677 L
.91251 .52677 L
.91251 .16187 L
s
.678 .847 .902 r
.91251 .16187 m
.91251 .52734 L
.91316 .52734 L
.91316 .16187 L
F
.2 .63 .79 r
.91251 .16187 m
.91251 .52734 L
.91316 .52734 L
.91316 .16187 L
s
.678 .847 .902 r
.91316 .16187 m
.91316 .52843 L
.91364 .52843 L
.91364 .16187 L
F
.2 .63 .79 r
.91316 .16187 m
.91316 .52843 L
.91364 .52843 L
.91364 .16187 L
s
.678 .847 .902 r
.91364 .16187 m
.91364 .52877 L
.91412 .52877 L
.91412 .16187 L
F
.2 .63 .79 r
.91364 .16187 m
.91364 .52877 L
.91412 .52877 L
.91412 .16187 L
s
.678 .847 .902 r
.91412 .16187 m
.91412 .52931 L
.91465 .52931 L
.91465 .16187 L
F
.2 .63 .79 r
.91412 .16187 m
.91412 .52931 L
.91465 .52931 L
.91465 .16187 L
s
.678 .847 .902 r
.91465 .16187 m
.91465 .53005 L
.91522 .53005 L
.91522 .16187 L
F
.2 .63 .79 r
.91465 .16187 m
.91465 .53005 L
.91522 .53005 L
.91522 .16187 L
s
.678 .847 .902 r
.91522 .16187 m
.91522 .53046 L
.91547 .53046 L
.91547 .16187 L
F
.2 .63 .79 r
.91522 .16187 m
.91522 .53046 L
.91547 .53046 L
.91547 .16187 L
s
.678 .847 .902 r
.91547 .16187 m
.91547 .53071 L
.91616 .53071 L
.91616 .16187 L
F
.2 .63 .79 r
.91547 .16187 m
.91547 .53071 L
.91616 .53071 L
.91616 .16187 L
s
.678 .847 .902 r
.91616 .16187 m
.91616 .53156 L
.91673 .53156 L
.91673 .16187 L
F
.2 .63 .79 r
.91616 .16187 m
.91616 .53156 L
.91673 .53156 L
.91673 .16187 L
s
.678 .847 .902 r
.91673 .16187 m
.91673 .53225 L
.9174 .53225 L
.9174 .16187 L
F
.2 .63 .79 r
.91673 .16187 m
.91673 .53225 L
.9174 .53225 L
.9174 .16187 L
s
.678 .847 .902 r
.9174 .16187 m
.9174 .53334 L
.91791 .53334 L
.91791 .16187 L
F
.2 .63 .79 r
.9174 .16187 m
.9174 .53334 L
.91791 .53334 L
.91791 .16187 L
s
.678 .847 .902 r
.91791 .16187 m
.91791 .53376 L
.91833 .53376 L
.91833 .16187 L
F
.2 .63 .79 r
.91791 .16187 m
.91791 .53376 L
.91833 .53376 L
.91833 .16187 L
s
.678 .847 .902 r
.91833 .16187 m
.91833 .53423 L
.91871 .53423 L
.91871 .16187 L
F
.2 .63 .79 r
.91833 .16187 m
.91833 .53423 L
.91871 .53423 L
.91871 .16187 L
s
.678 .847 .902 r
.91871 .16187 m
.91871 .53473 L
.91923 .53473 L
.91923 .16187 L
F
.2 .63 .79 r
.91871 .16187 m
.91871 .53473 L
.91923 .53473 L
.91923 .16187 L
s
.678 .847 .902 r
.91923 .16187 m
.91923 .53533 L
.91964 .53533 L
.91964 .16187 L
F
.2 .63 .79 r
.91923 .16187 m
.91923 .53533 L
.91964 .53533 L
.91964 .16187 L
s
.678 .847 .902 r
.91964 .16187 m
.91964 .53577 L
.92026 .53577 L
.92026 .16187 L
F
.2 .63 .79 r
.91964 .16187 m
.91964 .53577 L
.92026 .53577 L
.92026 .16187 L
s
.678 .847 .902 r
.92026 .16187 m
.92026 .53653 L
.9207 .53653 L
.9207 .16187 L
F
.2 .63 .79 r
.92026 .16187 m
.92026 .53653 L
.9207 .53653 L
.9207 .16187 L
s
.678 .847 .902 r
.9207 .16187 m
.9207 .5371 L
.92138 .5371 L
.92138 .16187 L
F
.2 .63 .79 r
.9207 .16187 m
.9207 .5371 L
.92138 .5371 L
.92138 .16187 L
s
.678 .847 .902 r
.92138 .16187 m
.92138 .53796 L
.92215 .53796 L
.92215 .16187 L
F
.2 .63 .79 r
.92138 .16187 m
.92138 .53796 L
.92215 .53796 L
.92215 .16187 L
s
.678 .847 .902 r
.92215 .16187 m
.92215 .53902 L
.92291 .53902 L
.92291 .16187 L
F
.2 .63 .79 r
.92215 .16187 m
.92215 .53902 L
.92291 .53902 L
.92291 .16187 L
s
.678 .847 .902 r
.92291 .16187 m
.92291 .53936 L
.92317 .53936 L
.92317 .16187 L
F
.2 .63 .79 r
.92291 .16187 m
.92291 .53936 L
.92317 .53936 L
.92317 .16187 L
s
.678 .847 .902 r
.92317 .16187 m
.92317 .53975 L
.92344 .53975 L
.92344 .16187 L
F
.2 .63 .79 r
.92317 .16187 m
.92317 .53975 L
.92344 .53975 L
.92344 .16187 L
s
.678 .847 .902 r
.92344 .16187 m
.92344 .54012 L
.92389 .54012 L
.92389 .16187 L
F
.2 .63 .79 r
.92344 .16187 m
.92344 .54012 L
.92389 .54012 L
.92389 .16187 L
s
.678 .847 .902 r
.92389 .16187 m
.92389 .5405 L
.92452 .5405 L
.92452 .16187 L
F
.2 .63 .79 r
.92389 .16187 m
.92389 .5405 L
.92452 .5405 L
.92452 .16187 L
s
.678 .847 .902 r
.92452 .16187 m
.92452 .54157 L
.92494 .54157 L
.92494 .16187 L
F
.2 .63 .79 r
.92452 .16187 m
.92452 .54157 L
.92494 .54157 L
.92494 .16187 L
s
.678 .847 .902 r
.92494 .16187 m
.92494 .54183 L
.92536 .54183 L
.92536 .16187 L
F
.2 .63 .79 r
.92494 .16187 m
.92494 .54183 L
.92536 .54183 L
.92536 .16187 L
s
.678 .847 .902 r
.92536 .16187 m
.92536 .54271 L
.92614 .54271 L
.92614 .16187 L
F
.2 .63 .79 r
.92536 .16187 m
.92536 .54271 L
.92614 .54271 L
.92614 .16187 L
s
.678 .847 .902 r
.92614 .16187 m
.92614 .54338 L
.92653 .54338 L
.92653 .16187 L
F
.2 .63 .79 r
.92614 .16187 m
.92614 .54338 L
.92653 .54338 L
.92653 .16187 L
s
.678 .847 .902 r
.92653 .16187 m
.92653 .5439 L
.92723 .5439 L
.92723 .16187 L
F
.2 .63 .79 r
.92653 .16187 m
.92653 .5439 L
.92723 .5439 L
.92723 .16187 L
s
.678 .847 .902 r
.92723 .16187 m
.92723 .54499 L
.92789 .54499 L
.92789 .16187 L
F
.2 .63 .79 r
.92723 .16187 m
.92723 .54499 L
.92789 .54499 L
.92789 .16187 L
s
.678 .847 .902 r
.92789 .16187 m
.92789 .54537 L
.92867 .54537 L
.92867 .16187 L
F
.2 .63 .79 r
.92789 .16187 m
.92789 .54537 L
.92867 .54537 L
.92867 .16187 L
s
.678 .847 .902 r
.92867 .16187 m
.92867 .5464 L
.92917 .5464 L
.92917 .16187 L
F
.2 .63 .79 r
.92867 .16187 m
.92867 .5464 L
.92917 .5464 L
.92917 .16187 L
s
.678 .847 .902 r
.92917 .16187 m
.92917 .54676 L
.92954 .54676 L
.92954 .16187 L
F
.2 .63 .79 r
.92917 .16187 m
.92917 .54676 L
.92954 .54676 L
.92954 .16187 L
s
.678 .847 .902 r
.92954 .16187 m
.92954 .54767 L
.93034 .54767 L
.93034 .16187 L
F
.2 .63 .79 r
.92954 .16187 m
.92954 .54767 L
.93034 .54767 L
.93034 .16187 L
s
.678 .847 .902 r
.93034 .16187 m
.93034 .54831 L
.93085 .54831 L
.93085 .16187 L
F
.2 .63 .79 r
.93034 .16187 m
.93034 .54831 L
.93085 .54831 L
.93085 .16187 L
s
.678 .847 .902 r
.93085 .16187 m
.93085 .54862 L
.93118 .54862 L
.93118 .16187 L
F
.2 .63 .79 r
.93085 .16187 m
.93085 .54862 L
.93118 .54862 L
.93118 .16187 L
s
.678 .847 .902 r
.93118 .16187 m
.93118 .54965 L
.93197 .54965 L
.93197 .16187 L
F
.2 .63 .79 r
.93118 .16187 m
.93118 .54965 L
.93197 .54965 L
.93197 .16187 L
s
.678 .847 .902 r
.93197 .16187 m
.93197 .55 L
.93249 .55 L
.93249 .16187 L
F
.2 .63 .79 r
.93197 .16187 m
.93197 .55 L
.93249 .55 L
.93249 .16187 L
s
.678 .847 .902 r
.93249 .16187 m
.93249 .55088 L
.93283 .55088 L
.93283 .16187 L
F
.2 .63 .79 r
.93249 .16187 m
.93249 .55088 L
.93283 .55088 L
.93283 .16187 L
s
.678 .847 .902 r
.93283 .16187 m
.93283 .55135 L
.93335 .55135 L
.93335 .16187 L
F
.2 .63 .79 r
.93283 .16187 m
.93283 .55135 L
.93335 .55135 L
.93335 .16187 L
s
.678 .847 .902 r
.93335 .16187 m
.93335 .55162 L
.93394 .55162 L
.93394 .16187 L
F
.2 .63 .79 r
.93335 .16187 m
.93335 .55162 L
.93394 .55162 L
.93394 .16187 L
s
.678 .847 .902 r
.93394 .16187 m
.93394 .55275 L
.93459 .55275 L
.93459 .16187 L
F
.2 .63 .79 r
.93394 .16187 m
.93394 .55275 L
.93459 .55275 L
.93459 .16187 L
s
.678 .847 .902 r
.93459 .16187 m
.93459 .55319 L
.93497 .55319 L
.93497 .16187 L
F
.2 .63 .79 r
.93459 .16187 m
.93459 .55319 L
.93497 .55319 L
.93497 .16187 L
s
.678 .847 .902 r
.93497 .16187 m
.93497 .55412 L
.93553 .55412 L
.93553 .16187 L
F
.2 .63 .79 r
.93497 .16187 m
.93497 .55412 L
.93553 .55412 L
.93553 .16187 L
s
.678 .847 .902 r
.93553 .16187 m
.93553 .55478 L
.93611 .55478 L
.93611 .16187 L
F
.2 .63 .79 r
.93553 .16187 m
.93553 .55478 L
.93611 .55478 L
.93611 .16187 L
s
.678 .847 .902 r
.93611 .16187 m
.93611 .55496 L
.93673 .55496 L
.93673 .16187 L
F
.2 .63 .79 r
.93611 .16187 m
.93611 .55496 L
.93673 .55496 L
.93673 .16187 L
s
.678 .847 .902 r
.93673 .16187 m
.93673 .55641 L
.93747 .55641 L
.93747 .16187 L
F
.2 .63 .79 r
.93673 .16187 m
.93673 .55641 L
.93747 .55641 L
.93747 .16187 L
s
.678 .847 .902 r
.93747 .16187 m
.93747 .55723 L
.93821 .55723 L
.93821 .16187 L
F
.2 .63 .79 r
.93747 .16187 m
.93747 .55723 L
.93821 .55723 L
.93821 .16187 L
s
.678 .847 .902 r
.93821 .16187 m
.93821 .55737 L
.93861 .55737 L
.93861 .16187 L
F
.2 .63 .79 r
.93821 .16187 m
.93821 .55737 L
.93861 .55737 L
.93861 .16187 L
s
.678 .847 .902 r
.93861 .16187 m
.93861 .55824 L
.93905 .55824 L
.93905 .16187 L
F
.2 .63 .79 r
.93861 .16187 m
.93861 .55824 L
.93905 .55824 L
.93905 .16187 L
s
.678 .847 .902 r
.93905 .16187 m
.93905 .55865 L
.93981 .55865 L
.93981 .16187 L
F
.2 .63 .79 r
.93905 .16187 m
.93905 .55865 L
.93981 .55865 L
.93981 .16187 L
s
.678 .847 .902 r
.93981 .16187 m
.93981 .55939 L
.94041 .55939 L
.94041 .16187 L
F
.2 .63 .79 r
.93981 .16187 m
.93981 .55939 L
.94041 .55939 L
.94041 .16187 L
s
.678 .847 .902 r
.94041 .16187 m
.94041 .56034 L
.94092 .56034 L
.94092 .16187 L
F
.2 .63 .79 r
.94041 .16187 m
.94041 .56034 L
.94092 .56034 L
.94092 .16187 L
s
.678 .847 .902 r
.94092 .16187 m
.94092 .56057 L
.94151 .56057 L
.94151 .16187 L
F
.2 .63 .79 r
.94092 .16187 m
.94092 .56057 L
.94151 .56057 L
.94151 .16187 L
s
.678 .847 .902 r
.94151 .16187 m
.94151 .56134 L
.94229 .56134 L
.94229 .16187 L
F
.2 .63 .79 r
.94151 .16187 m
.94151 .56134 L
.94229 .56134 L
.94229 .16187 L
s
.678 .847 .902 r
.94229 .16187 m
.94229 .56243 L
.94262 .56243 L
.94262 .16187 L
F
.2 .63 .79 r
.94229 .16187 m
.94229 .56243 L
.94262 .56243 L
.94262 .16187 L
s
.678 .847 .902 r
.94262 .16187 m
.94262 .56275 L
.94302 .56275 L
.94302 .16187 L
F
.2 .63 .79 r
.94262 .16187 m
.94262 .56275 L
.94302 .56275 L
.94302 .16187 L
s
.678 .847 .902 r
.94302 .16187 m
.94302 .56332 L
.94361 .56332 L
.94361 .16187 L
F
.2 .63 .79 r
.94302 .16187 m
.94302 .56332 L
.94361 .56332 L
.94361 .16187 L
s
.678 .847 .902 r
.94361 .16187 m
.94361 .56412 L
.94413 .56412 L
.94413 .16187 L
F
.2 .63 .79 r
.94361 .16187 m
.94361 .56412 L
.94413 .56412 L
.94413 .16187 L
s
.678 .847 .902 r
.94413 .16187 m
.94413 .56454 L
.94438 .56454 L
.94438 .16187 L
F
.2 .63 .79 r
.94413 .16187 m
.94413 .56454 L
.94438 .56454 L
.94438 .16187 L
s
.678 .847 .902 r
.94438 .16187 m
.94438 .56499 L
.94478 .56499 L
.94478 .16187 L
F
.2 .63 .79 r
.94438 .16187 m
.94438 .56499 L
.94478 .56499 L
.94478 .16187 L
s
.678 .847 .902 r
.94478 .16187 m
.94478 .56524 L
.94509 .56524 L
.94509 .16187 L
F
.2 .63 .79 r
.94478 .16187 m
.94478 .56524 L
.94509 .56524 L
.94509 .16187 L
s
.678 .847 .902 r
.94509 .16187 m
.94509 .5659 L
.94552 .5659 L
.94552 .16187 L
F
.2 .63 .79 r
.94509 .16187 m
.94509 .5659 L
.94552 .5659 L
.94552 .16187 L
s
.678 .847 .902 r
.94552 .16187 m
.94552 .56663 L
.94605 .56663 L
.94605 .16187 L
F
.2 .63 .79 r
.94552 .16187 m
.94552 .56663 L
.94605 .56663 L
.94605 .16187 L
s
.678 .847 .902 r
.94605 .16187 m
.94605 .5671 L
.94667 .5671 L
.94667 .16187 L
F
.2 .63 .79 r
.94605 .16187 m
.94605 .5671 L
.94667 .5671 L
.94667 .16187 L
s
.678 .847 .902 r
.94667 .16187 m
.94667 .56776 L
.94714 .56776 L
.94714 .16187 L
F
.2 .63 .79 r
.94667 .16187 m
.94667 .56776 L
.94714 .56776 L
.94714 .16187 L
s
.678 .847 .902 r
.94714 .16187 m
.94714 .5681 L
.94743 .5681 L
.94743 .16187 L
F
.2 .63 .79 r
.94714 .16187 m
.94714 .5681 L
.94743 .5681 L
.94743 .16187 L
s
.678 .847 .902 r
.94743 .16187 m
.94743 .56922 L
.94822 .56922 L
.94822 .16187 L
F
.2 .63 .79 r
.94743 .16187 m
.94743 .56922 L
.94822 .56922 L
.94822 .16187 L
s
.678 .847 .902 r
.94822 .16187 m
.94822 .56946 L
.94849 .56946 L
.94849 .16187 L
F
.2 .63 .79 r
.94822 .16187 m
.94822 .56946 L
.94849 .56946 L
.94849 .16187 L
s
.678 .847 .902 r
.94849 .16187 m
.94849 .56993 L
.94914 .56993 L
.94914 .16187 L
F
.2 .63 .79 r
.94849 .16187 m
.94849 .56993 L
.94914 .56993 L
.94914 .16187 L
s
.678 .847 .902 r
.94914 .16187 m
.94914 .57055 L
.9495 .57055 L
.9495 .16187 L
F
.2 .63 .79 r
.94914 .16187 m
.94914 .57055 L
.9495 .57055 L
.9495 .16187 L
s
.678 .847 .902 r
.9495 .16187 m
.9495 .57081 L
.9498 .57081 L
.9498 .16187 L
F
.2 .63 .79 r
.9495 .16187 m
.9495 .57081 L
.9498 .57081 L
.9498 .16187 L
s
.678 .847 .902 r
.9498 .16187 m
.9498 .57157 L
.95047 .57157 L
.95047 .16187 L
F
.2 .63 .79 r
.9498 .16187 m
.9498 .57157 L
.95047 .57157 L
.95047 .16187 L
s
.678 .847 .902 r
.95047 .16187 m
.95047 .57228 L
.95093 .57228 L
.95093 .16187 L
F
.2 .63 .79 r
.95047 .16187 m
.95047 .57228 L
.95093 .57228 L
.95093 .16187 L
s
.678 .847 .902 r
.95093 .16187 m
.95093 .57253 L
.95134 .57253 L
.95134 .16187 L
F
.2 .63 .79 r
.95093 .16187 m
.95093 .57253 L
.95134 .57253 L
.95134 .16187 L
s
.678 .847 .902 r
.95134 .16187 m
.95134 .57348 L
.95184 .57348 L
.95184 .16187 L
F
.2 .63 .79 r
.95134 .16187 m
.95134 .57348 L
.95184 .57348 L
.95184 .16187 L
s
.678 .847 .902 r
.95184 .16187 m
.95184 .57401 L
.95225 .57401 L
.95225 .16187 L
F
.2 .63 .79 r
.95184 .16187 m
.95184 .57401 L
.95225 .57401 L
.95225 .16187 L
s
.678 .847 .902 r
.95225 .16187 m
.95225 .57452 L
.95292 .57452 L
.95292 .16187 L
F
.2 .63 .79 r
.95225 .16187 m
.95225 .57452 L
.95292 .57452 L
.95292 .16187 L
s
.678 .847 .902 r
.95292 .16187 m
.95292 .57539 L
.95335 .57539 L
.95335 .16187 L
F
.2 .63 .79 r
.95292 .16187 m
.95292 .57539 L
.95335 .57539 L
.95335 .16187 L
s
.678 .847 .902 r
.95335 .16187 m
.95335 .57549 L
.95377 .57549 L
.95377 .16187 L
F
.2 .63 .79 r
.95335 .16187 m
.95335 .57549 L
.95377 .57549 L
.95377 .16187 L
s
.678 .847 .902 r
.95377 .16187 m
.95377 .57606 L
.95402 .57606 L
.95402 .16187 L
F
.2 .63 .79 r
.95377 .16187 m
.95377 .57606 L
.95402 .57606 L
.95402 .16187 L
s
.678 .847 .902 r
.95402 .16187 m
.95402 .57628 L
.95435 .57628 L
.95435 .16187 L
F
.2 .63 .79 r
.95402 .16187 m
.95402 .57628 L
.95435 .57628 L
.95435 .16187 L
s
.678 .847 .902 r
.95435 .16187 m
.95435 .5769 L
.95506 .5769 L
.95506 .16187 L
F
.2 .63 .79 r
.95435 .16187 m
.95435 .5769 L
.95506 .5769 L
.95506 .16187 L
s
.678 .847 .902 r
.95506 .16187 m
.95506 .57775 L
.95548 .57775 L
.95548 .16187 L
F
.2 .63 .79 r
.95506 .16187 m
.95506 .57775 L
.95548 .57775 L
.95548 .16187 L
s
.678 .847 .902 r
.95548 .16187 m
.95548 .57856 L
.95614 .57856 L
.95614 .16187 L
F
.2 .63 .79 r
.95548 .16187 m
.95548 .57856 L
.95614 .57856 L
.95614 .16187 L
s
.678 .847 .902 r
.95614 .16187 m
.95614 .57904 L
.95639 .57904 L
.95639 .16187 L
F
.2 .63 .79 r
.95614 .16187 m
.95614 .57904 L
.95639 .57904 L
.95639 .16187 L
s
.678 .847 .902 r
.95639 .16187 m
.95639 .57945 L
.95692 .57945 L
.95692 .16187 L
F
.2 .63 .79 r
.95639 .16187 m
.95639 .57945 L
.95692 .57945 L
.95692 .16187 L
s
.678 .847 .902 r
.95692 .16187 m
.95692 .5802 L
.9576 .5802 L
.9576 .16187 L
F
.2 .63 .79 r
.95692 .16187 m
.95692 .5802 L
.9576 .5802 L
.9576 .16187 L
s
.678 .847 .902 r
.9576 .16187 m
.9576 .58061 L
.9579 .58061 L
.9579 .16187 L
F
.2 .63 .79 r
.9576 .16187 m
.9576 .58061 L
.9579 .58061 L
.9579 .16187 L
s
.678 .847 .902 r
.9579 .16187 m
.9579 .58104 L
.95848 .58104 L
.95848 .16187 L
F
.2 .63 .79 r
.9579 .16187 m
.9579 .58104 L
.95848 .58104 L
.95848 .16187 L
s
.678 .847 .902 r
.95848 .16187 m
.95848 .58171 L
.95897 .58171 L
.95897 .16187 L
F
.2 .63 .79 r
.95848 .16187 m
.95848 .58171 L
.95897 .58171 L
.95897 .16187 L
s
.678 .847 .902 r
.95897 .16187 m
.95897 .58272 L
.95967 .58272 L
.95967 .16187 L
F
.2 .63 .79 r
.95897 .16187 m
.95897 .58272 L
.95967 .58272 L
.95967 .16187 L
s
.678 .847 .902 r
.95967 .16187 m
.95967 .58322 L
.95993 .58322 L
.95993 .16187 L
F
.2 .63 .79 r
.95967 .16187 m
.95967 .58322 L
.95993 .58322 L
.95993 .16187 L
s
.678 .847 .902 r
.95993 .16187 m
.95993 .58403 L
.96067 .58403 L
.96067 .16187 L
F
.2 .63 .79 r
.95993 .16187 m
.95993 .58403 L
.96067 .58403 L
.96067 .16187 L
s
.678 .847 .902 r
.96067 .16187 m
.96067 .58461 L
.96104 .58461 L
.96104 .16187 L
F
.2 .63 .79 r
.96067 .16187 m
.96067 .58461 L
.96104 .58461 L
.96104 .16187 L
s
.678 .847 .902 r
.96104 .16187 m
.96104 .58516 L
.96169 .58516 L
.96169 .16187 L
F
.2 .63 .79 r
.96104 .16187 m
.96104 .58516 L
.96169 .58516 L
.96169 .16187 L
s
.678 .847 .902 r
.96169 .16187 m
.96169 .58598 L
.96208 .58598 L
.96208 .16187 L
F
.2 .63 .79 r
.96169 .16187 m
.96169 .58598 L
.96208 .58598 L
.96208 .16187 L
s
.678 .847 .902 r
.96208 .16187 m
.96208 .58609 L
.96261 .58609 L
.96261 .16187 L
F
.2 .63 .79 r
.96208 .16187 m
.96208 .58609 L
.96261 .58609 L
.96261 .16187 L
s
.678 .847 .902 r
.96261 .16187 m
.96261 .58726 L
.96338 .58726 L
.96338 .16187 L
F
.2 .63 .79 r
.96261 .16187 m
.96261 .58726 L
.96338 .58726 L
.96338 .16187 L
s
.678 .847 .902 r
.96338 .16187 m
.96338 .58793 L
.96376 .58793 L
.96376 .16187 L
F
.2 .63 .79 r
.96338 .16187 m
.96338 .58793 L
.96376 .58793 L
.96376 .16187 L
s
.678 .847 .902 r
.96376 .16187 m
.96376 .58815 L
.96456 .58815 L
.96456 .16187 L
F
.2 .63 .79 r
.96376 .16187 m
.96376 .58815 L
.96456 .58815 L
.96456 .16187 L
s
.678 .847 .902 r
.96456 .16187 m
.96456 .58951 L
.96521 .58951 L
.96521 .16187 L
F
.2 .63 .79 r
.96456 .16187 m
.96456 .58951 L
.96521 .58951 L
.96521 .16187 L
s
.678 .847 .902 r
.96521 .16187 m
.96521 .59035 L
.96579 .59035 L
.96579 .16187 L
F
.2 .63 .79 r
.96521 .16187 m
.96521 .59035 L
.96579 .59035 L
.96579 .16187 L
s
.678 .847 .902 r
.96579 .16187 m
.96579 .5911 L
.96657 .5911 L
.96657 .16187 L
F
.2 .63 .79 r
.96579 .16187 m
.96579 .5911 L
.96657 .5911 L
.96657 .16187 L
s
.678 .847 .902 r
.96657 .16187 m
.96657 .59215 L
.96736 .59215 L
.96736 .16187 L
F
.2 .63 .79 r
.96657 .16187 m
.96657 .59215 L
.96736 .59215 L
.96736 .16187 L
s
.678 .847 .902 r
.96736 .16187 m
.96736 .59279 L
.96793 .59279 L
.96793 .16187 L
F
.2 .63 .79 r
.96736 .16187 m
.96736 .59279 L
.96793 .59279 L
.96793 .16187 L
s
.678 .847 .902 r
.96793 .16187 m
.96793 .59349 L
.9686 .59349 L
.9686 .16187 L
F
.2 .63 .79 r
.96793 .16187 m
.96793 .59349 L
.9686 .59349 L
.9686 .16187 L
s
.678 .847 .902 r
.9686 .16187 m
.9686 .59403 L
.96921 .59403 L
.96921 .16187 L
F
.2 .63 .79 r
.9686 .16187 m
.9686 .59403 L
.96921 .59403 L
.96921 .16187 L
s
.678 .847 .902 r
.96921 .16187 m
.96921 .59516 L
.96958 .59516 L
.96958 .16187 L
F
.2 .63 .79 r
.96921 .16187 m
.96921 .59516 L
.96958 .59516 L
.96958 .16187 L
s
.678 .847 .902 r
.96958 .16187 m
.96958 .59563 L
.97013 .59563 L
.97013 .16187 L
F
.2 .63 .79 r
.96958 .16187 m
.96958 .59563 L
.97013 .59563 L
.97013 .16187 L
s
.678 .847 .902 r
.97013 .16187 m
.97013 .59627 L
.97052 .59627 L
.97052 .16187 L
F
.2 .63 .79 r
.97013 .16187 m
.97013 .59627 L
.97052 .59627 L
.97052 .16187 L
s
.678 .847 .902 r
.97052 .16187 m
.97052 .5968 L
.97125 .5968 L
.97125 .16187 L
F
.2 .63 .79 r
.97052 .16187 m
.97052 .5968 L
.97125 .5968 L
.97125 .16187 L
s
.678 .847 .902 r
.97125 .16187 m
.97125 .59757 L
.97157 .59757 L
.97157 .16187 L
F
.2 .63 .79 r
.97125 .16187 m
.97125 .59757 L
.97157 .59757 L
.97157 .16187 L
s
.678 .847 .902 r
.97157 .16187 m
.97157 .59811 L
.97234 .59811 L
.97234 .16187 L
F
.2 .63 .79 r
.97157 .16187 m
.97157 .59811 L
.97234 .59811 L
.97234 .16187 L
s
.678 .847 .902 r
.97234 .16187 m
.97234 .59922 L
.97305 .59922 L
.97305 .16187 L
F
.2 .63 .79 r
.97234 .16187 m
.97234 .59922 L
.97305 .59922 L
.97305 .16187 L
s
.678 .847 .902 r
.97305 .16187 m
.97305 .59976 L
.97332 .59976 L
.97332 .16187 L
F
.2 .63 .79 r
.97305 .16187 m
.97305 .59976 L
.97332 .59976 L
.97332 .16187 L
s
.678 .847 .902 r
.97332 .16187 m
.97332 .59993 L
.97362 .59993 L
.97362 .16187 L
F
.2 .63 .79 r
.97332 .16187 m
.97332 .59993 L
.97362 .59993 L
.97362 .16187 L
s
.678 .847 .902 r
.97362 .16187 m
.97362 .60043 L
.9739 .60043 L
.9739 .16187 L
F
.2 .63 .79 r
.97362 .16187 m
.97362 .60043 L
.9739 .60043 L
.9739 .16187 L
s
.678 .847 .902 r
.9739 .16187 m
.9739 .60053 L
.97448 .60053 L
.97448 .16187 L
F
.2 .63 .79 r
.9739 .16187 m
.9739 .60053 L
.97448 .60053 L
.97448 .16187 L
s
.678 .847 .902 r
.97448 .16187 m
.97448 .60143 L
.97491 .60143 L
.97491 .16187 L
F
.2 .63 .79 r
.97448 .16187 m
.97448 .60143 L
.97491 .60143 L
.97491 .16187 L
s
.678 .847 .902 r
.97491 .16187 m
.97491 .60217 L
.97562 .60217 L
.97562 .16187 L
F
.2 .63 .79 r
.97491 .16187 m
.97491 .60217 L
.97562 .60217 L
.97562 .16187 L
s
.678 .847 .902 r
.97562 .16187 m
.97562 .60308 L
.97619 .60308 L
.97619 .16187 L
F
.2 .63 .79 r
.97562 .16187 m
.97562 .60308 L
.97619 .60308 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02416 .01472 Mdot
.02437 .01472 Mdot
.02529 .01472 Mdot
.02569 .01472 Mdot
.02577 .01472 Mdot
.02632 .01472 Mdot
.027 .01472 Mdot
.02723 .01472 Mdot
.02794 .01473 Mdot
.02863 .01473 Mdot
.02918 .01473 Mdot
.02956 .01474 Mdot
.02964 .01474 Mdot
.03059 .01474 Mdot
.03115 .01475 Mdot
.03165 .01475 Mdot
.03187 .01476 Mdot
.03285 .01477 Mdot
.03335 .01477 Mdot
.0341 .01478 Mdot
.03478 .01479 Mdot
.0351 .0148 Mdot
.03569 .01481 Mdot
.03601 .01481 Mdot
.03694 .01483 Mdot
.03706 .01483 Mdot
.03824 .01485 Mdot
.03855 .01486 Mdot
.03955 .01488 Mdot
.0396 .01488 Mdot
.04069 .0149 Mdot
.04078 .0149 Mdot
.04186 .01493 Mdot
.04242 .01494 Mdot
.04283 .01495 Mdot
.04363 .01497 Mdot
.04435 .01499 Mdot
.04512 .01501 Mdot
.04549 .01502 Mdot
.04593 .01503 Mdot
.04641 .01505 Mdot
.04699 .01506 Mdot
.04753 .01508 Mdot
.04825 .0151 Mdot
.04887 .01512 Mdot
.04911 .01513 Mdot
.05001 .01516 Mdot
.05075 .01519 Mdot
.05139 .01521 Mdot
.05216 .01524 Mdot
.05275 .01526 Mdot
.05305 .01527 Mdot
.05388 .0153 Mdot
.05427 .01532 Mdot
.05428 .01532 Mdot
.05491 .01534 Mdot
.05551 .01537 Mdot
.05627 .0154 Mdot
.05689 .01543 Mdot
.05699 .01543 Mdot
.05758 .01546 Mdot
.05815 .01548 Mdot
.0586 .0155 Mdot
.05958 .01555 Mdot
.05997 .01556 Mdot
.06056 .01559 Mdot
.06134 .01563 Mdot
.06165 .01564 Mdot
.06205 .01566 Mdot
.06255 .01569 Mdot
.06304 .01571 Mdot
.06328 .01573 Mdot
.06395 .01576 Mdot
.06422 .01577 Mdot
.06491 .01581 Mdot
.06561 .01585 Mdot
.06638 .01589 Mdot
.06662 .0159 Mdot
.06719 .01594 Mdot
.06761 .01596 Mdot
.06828 .016 Mdot
.06892 .01604 Mdot
.06964 .01608 Mdot
.07006 .0161 Mdot
.0707 .01614 Mdot
.07077 .01615 Mdot
.07164 .0162 Mdot
.07223 .01624 Mdot
.07277 .01627 Mdot
.07355 .01632 Mdot
.07388 .01634 Mdot
.07461 .01639 Mdot
.07485 .01641 Mdot
.07559 .01646 Mdot
.07576 .01647 Mdot
.07646 .01651 Mdot
.07706 .01656 Mdot
.07745 .01658 Mdot
.07771 .0166 Mdot
.07838 .01665 Mdot
.07903 .01669 Mdot
.07944 .01672 Mdot
.07983 .01675 Mdot
.08088 .01683 Mdot
.08137 .01686 Mdot
.08236 .01694 Mdot
.08284 .01698 Mdot
.08333 .01701 Mdot
.08383 .01705 Mdot
.08475 .01713 Mdot
.08495 .01714 Mdot
.086 .01722 Mdot
.08637 .01726 Mdot
.08648 .01726 Mdot
.08757 .01735 Mdot
.08797 .01739 Mdot
.08824 .01741 Mdot
.08881 .01746 Mdot
.08927 .0175 Mdot
.08951 .01752 Mdot
.09025 .01758 Mdot
.09055 .01761 Mdot
.09147 .01769 Mdot
.09158 .0177 Mdot
.09213 .01774 Mdot
.09276 .0178 Mdot
.09303 .01782 Mdot
.09336 .01785 Mdot
.09356 .01787 Mdot
.09427 .01794 Mdot
.09438 .01795 Mdot
.09484 .01799 Mdot
.09583 .01808 Mdot
.09604 .0181 Mdot
.09663 .01816 Mdot
.09722 .01821 Mdot
.09797 .01828 Mdot
.09857 .01834 Mdot
.09883 .01837 Mdot
.09954 .01844 Mdot
.10011 .01849 Mdot
.10067 .01855 Mdot
.10131 .01861 Mdot
.10171 .01865 Mdot
.10203 .01869 Mdot
.10265 .01875 Mdot
.10349 .01883 Mdot
.10372 .01886 Mdot
.1042 .01891 Mdot
.10462 .01895 Mdot
.10504 .019 Mdot
.10587 .01909 Mdot
.10606 .01911 Mdot
.10643 .01914 Mdot
.10715 .01922 Mdot
.10735 .01924 Mdot
.10782 .0193 Mdot
.10828 .01934 Mdot
.10899 .01942 Mdot
.10959 .01949 Mdot
.1102 .01956 Mdot
.11058 .0196 Mdot
.11094 .01964 Mdot
.11136 .01969 Mdot
.11209 .01977 Mdot
.11253 .01982 Mdot
.11316 .0199 Mdot
.11392 .01998 Mdot
.11469 .02007 Mdot
.11496 .02011 Mdot
.1159 .02022 Mdot
.1163 .02027 Mdot
.11685 .02033 Mdot
.11712 .02037 Mdot
.11803 .02048 Mdot
.11862 .02055 Mdot
.11876 .02057 Mdot
.11942 .02065 Mdot
.11968 .02068 Mdot
.12048 .02078 Mdot
.12112 .02086 Mdot
.12156 .02092 Mdot
.12244 .02103 Mdot
.12365 .02118 Mdot
.12403 .02123 Mdot
.12453 .0213 Mdot
.12513 .02138 Mdot
.12558 .02144 Mdot
.12595 .02148 Mdot
.12629 .02153 Mdot
.12644 .02155 Mdot
.12689 .02161 Mdot
.12734 .02167 Mdot
.12822 .02179 Mdot
.12874 .02186 Mdot
.12957 .02197 Mdot
.12996 .02203 Mdot
.1305 .0221 Mdot
.13116 .02219 Mdot
.13162 .02226 Mdot
.13202 .02231 Mdot
.1324 .02237 Mdot
.13301 .02245 Mdot
.13327 .02249 Mdot
.1344 .02265 Mdot
.13489 .02272 Mdot
.13506 .02275 Mdot
.13551 .02281 Mdot
.13591 .02287 Mdot
.13672 .02299 Mdot
.13749 .0231 Mdot
.13811 .02319 Mdot
.13831 .02322 Mdot
.13904 .02333 Mdot
.13945 .02339 Mdot
.14013 .02349 Mdot
.14054 .02356 Mdot
.14133 .02368 Mdot
.14166 .02373 Mdot
.14217 .02381 Mdot
.14278 .0239 Mdot
.14338 .02399 Mdot
.14397 .02408 Mdot
.14497 .02424 Mdot
.14539 .02431 Mdot
.14552 .02433 Mdot
.14615 .02443 Mdot
.14661 .0245 Mdot
.14708 .02458 Mdot
.14717 .02459 Mdot
.14738 .02462 Mdot
.14781 .02469 Mdot
.14872 .02484 Mdot
.14875 .02485 Mdot
.14952 .02497 Mdot
.14992 .02504 Mdot
.15064 .02515 Mdot
.15093 .0252 Mdot
.15131 .02526 Mdot
.15181 .02535 Mdot
.15278 .02551 Mdot
.15328 .02559 Mdot
.15382 .02568 Mdot
.15438 .02578 Mdot
.15495 .02588 Mdot
.15567 .026 Mdot
.15608 .02607 Mdot
.15643 .02613 Mdot
.15677 .02619 Mdot
.15719 .02626 Mdot
.15747 .02631 Mdot
.15827 .02645 Mdot
.159 .02658 Mdot
.1594 .02665 Mdot
.16013 .02677 Mdot
.16066 .02687 Mdot
.16117 .02696 Mdot
.16141 .027 Mdot
.16231 .02716 Mdot
.16288 .02727 Mdot
.16335 .02735 Mdot
.16374 .02742 Mdot
.16404 .02748 Mdot
.16466 .02759 Mdot
.16504 .02766 Mdot
.16523 .02769 Mdot
.16554 .02775 Mdot
.1659 .02782 Mdot
.16661 .02795 Mdot
.16736 .02809 Mdot
.16812 .02823 Mdot
.16851 .0283 Mdot
.16884 .02836 Mdot
.16978 .02854 Mdot
.17036 .02865 Mdot
.17055 .02869 Mdot
.17139 .02885 Mdot
.17172 .02891 Mdot
.17254 .02907 Mdot
.17325 .02921 Mdot
.17365 .02929 Mdot
.17369 .02929 Mdot
.17465 .02948 Mdot
.17509 .02957 Mdot
.17525 .0296 Mdot
.17601 .02975 Mdot
.1768 .0299 Mdot
.17701 .02995 Mdot
.17788 .03012 Mdot
.17876 .0303 Mdot
.1789 .03032 Mdot
.17965 .03048 Mdot
.18028 .0306 Mdot
.18058 .03066 Mdot
.18149 .03085 Mdot
.18204 .03096 Mdot
.18304 .03117 Mdot
.18364 .03129 Mdot
.1841 .03139 Mdot
.18435 .03144 Mdot
.1851 .0316 Mdot
.18595 .03178 Mdot
.18641 .03187 Mdot
.18706 .03201 Mdot
.18751 .0321 Mdot
.18822 .03226 Mdot
.18875 .03237 Mdot
.18935 .0325 Mdot
.1895 .03253 Mdot
.19005 .03265 Mdot
.19045 .03274 Mdot
.19094 .03284 Mdot
.19164 .03299 Mdot
.19226 .03313 Mdot
.19241 .03316 Mdot
.19327 .03335 Mdot
.19349 .0334 Mdot
.19457 .03364 Mdot
.1952 .03378 Mdot
.19544 .03383 Mdot
.19593 .03394 Mdot
.19634 .03403 Mdot
.19677 .03413 Mdot
.19718 .03422 Mdot
.19752 .0343 Mdot
.19804 .03441 Mdot
.1983 .03447 Mdot
.19883 .03459 Mdot
.19954 .03475 Mdot
.20022 .03491 Mdot
.20139 .03518 Mdot
.20183 .03528 Mdot
.20274 .03549 Mdot
.20289 .03553 Mdot
.20339 .03564 Mdot
.20415 .03582 Mdot
.20502 .03602 Mdot
.20518 .03606 Mdot
.20596 .03625 Mdot
.20662 .0364 Mdot
.2069 .03647 Mdot
.20709 .03651 Mdot
.2078 .03668 Mdot
.20802 .03674 Mdot
.2085 .03685 Mdot
.20902 .03698 Mdot
.20984 .03717 Mdot
.21031 .03729 Mdot
.21038 .0373 Mdot
.21105 .03747 Mdot
.21156 .03759 Mdot
.21225 .03776 Mdot
.21235 .03778 Mdot
.21329 .03801 Mdot
.21371 .03812 Mdot
.21396 .03818 Mdot
.21439 .03829 Mdot
.2152 .03849 Mdot
.21575 .03862 Mdot
.21652 .03882 Mdot
.21699 .03893 Mdot
.21772 .03912 Mdot
.21852 .03932 Mdot
.21904 .03945 Mdot
.21937 .03953 Mdot
.22023 .03975 Mdot
.22053 .03983 Mdot
.2208 .0399 Mdot
.2217 .04013 Mdot
.22201 .04021 Mdot
.22294 .04045 Mdot
.22314 .0405 Mdot
.22386 .04069 Mdot
.2241 .04075 Mdot
.22449 .04085 Mdot
.22507 .041 Mdot
.22595 .04123 Mdot
.22605 .04126 Mdot
.22688 .04148 Mdot
.22717 .04155 Mdot
.228 .04177 Mdot
.22843 .04188 Mdot
.229 .04204 Mdot
.23003 .04231 Mdot
.23056 .04245 Mdot
.23099 .04257 Mdot
.23182 .04279 Mdot
.23202 .04285 Mdot
.23278 .04305 Mdot
.23354 .04326 Mdot
.23407 .0434 Mdot
.23455 .04353 Mdot
.23508 .04368 Mdot
.23613 .04397 Mdot
.23631 .04402 Mdot
.23697 .0442 Mdot
.2373 .04429 Mdot
.23767 .04439 Mdot
.23857 .04465 Mdot
.23871 .04468 Mdot
.23937 .04487 Mdot
.23965 .04495 Mdot
.24026 .04512 Mdot
.24137 .04543 Mdot
.24158 .04549 Mdot
.24179 .04555 Mdot
.2423 .04569 Mdot
.24262 .04578 Mdot
.24324 .04596 Mdot
.24377 .04611 Mdot
.24438 .04629 Mdot
.24473 .04639 Mdot
.24518 .04652 Mdot
.2458 .04669 Mdot
.24616 .0468 Mdot
.24711 .04707 Mdot
.24758 .04721 Mdot
.24791 .04731 Mdot
.24866 .04752 Mdot
.24937 .04773 Mdot
.25014 .04796 Mdot
.25082 .04816 Mdot
.25094 .04819 Mdot
.25183 .04846 Mdot
.25211 .04854 Mdot
.25257 .04868 Mdot
.25269 .04871 Mdot
.25353 .04896 Mdot
.25354 .04896 Mdot
.25397 .04909 Mdot
.2545 .04925 Mdot
.25537 .04951 Mdot
.25609 .04973 Mdot
.25657 .04987 Mdot
.25673 .04992 Mdot
.25736 .05011 Mdot
.25753 .05016 Mdot
.25787 .05027 Mdot
.2585 .05046 Mdot
.25959 .05079 Mdot
.25991 .05089 Mdot
.26014 .05096 Mdot
.26144 .05136 Mdot
.26202 .05154 Mdot
.26248 .05168 Mdot
.26305 .05186 Mdot
.26392 .05213 Mdot
.2644 .05228 Mdot
.26488 .05243 Mdot
.2653 .05256 Mdot
.26582 .05272 Mdot
.26647 .05293 Mdot
.26696 .05308 Mdot
.2672 .05316 Mdot
.26766 .0533 Mdot
.26835 .05352 Mdot
.26879 .05366 Mdot
.26915 .05378 Mdot
.27015 .05409 Mdot
.27029 .05414 Mdot
.27106 .05439 Mdot
.27142 .0545 Mdot
.27238 .05481 Mdot
.27261 .05488 Mdot
.27301 .05502 Mdot
.27341 .05514 Mdot
.27418 .05539 Mdot
.27457 .05552 Mdot
.2752 .05573 Mdot
.27564 .05587 Mdot
.27574 .0559 Mdot
.27688 .05628 Mdot
.27696 .0563 Mdot
.27756 .0565 Mdot
.27801 .05665 Mdot
.27843 .05679 Mdot
.27944 .05712 Mdot
.27992 .05728 Mdot
.28031 .05741 Mdot
.28111 .05768 Mdot
.2816 .05784 Mdot
.28241 .05811 Mdot
.28265 .05819 Mdot
.28298 .05831 Mdot
.28351 .05848 Mdot
.28379 .05858 Mdot
.28422 .05872 Mdot
.28531 .05909 Mdot
.28556 .05917 Mdot
.28601 .05933 Mdot
.28614 .05937 Mdot
.28654 .05951 Mdot
.28708 .05969 Mdot
.28802 .06002 Mdot
.28836 .06013 Mdot
.28839 .06014 Mdot
.2888 .06028 Mdot
.28929 .06045 Mdot
.28985 .06065 Mdot
.29044 .06085 Mdot
.29091 .06101 Mdot
.29164 .06127 Mdot
.29184 .06134 Mdot
.29222 .06147 Mdot
.29285 .06169 Mdot
.29349 .06191 Mdot
.29391 .06206 Mdot
.29455 .06228 Mdot
.2948 .06237 Mdot
.29553 .06263 Mdot
.2958 .06272 Mdot
.29681 .06308 Mdot
.29738 .06328 Mdot
.29774 .06341 Mdot
.29835 .06363 Mdot
.29867 .06374 Mdot
.2991 .06389 Mdot
.29997 .0642 Mdot
.30054 .06441 Mdot
.30078 .0645 Mdot
.30101 .06458 Mdot
.30161 .0648 Mdot
.30209 .06497 Mdot
.30269 .06519 Mdot
.30306 .06532 Mdot
.30378 .06558 Mdot
.30401 .06567 Mdot
.30474 .06593 Mdot
.30588 .06635 Mdot
.30594 .06637 Mdot
.30685 .0667 Mdot
.30753 .06695 Mdot
.30791 .06709 Mdot
.30836 .06726 Mdot
.30921 .06757 Mdot
.30954 .06769 Mdot
.3099 .06783 Mdot
.31099 .06824 Mdot
.31143 .0684 Mdot
.31194 .06859 Mdot
.31276 .06889 Mdot
.31299 .06898 Mdot
.31396 .06935 Mdot
.3147 .06963 Mdot
.31499 .06974 Mdot
.3156 .06997 Mdot
.3161 .07016 Mdot
.3165 .07031 Mdot
.31688 .07045 Mdot
.31788 .07083 Mdot
.31811 .07092 Mdot
.31857 .0711 Mdot
.31908 .07129 Mdot
.32005 .07166 Mdot
.3206 .07188 Mdot
.32116 .07209 Mdot
.3217 .0723 Mdot
.3222 .0725 Mdot
.32344 .07298 Mdot
.32364 .07305 Mdot
.3242 .07327 Mdot
.32483 .07352 Mdot
.32517 .07365 Mdot
.32603 .07399 Mdot
.32628 .07409 Mdot
.32668 .07424 Mdot
.32741 .07453 Mdot
.3279 .07472 Mdot
.32796 .07475 Mdot
.32922 .07524 Mdot
.32939 .07531 Mdot
.33005 .07557 Mdot
.33093 .07592 Mdot
.33097 .07594 Mdot
.33218 .07642 Mdot
.33239 .07651 Mdot
.33293 .07672 Mdot
.3332 .07683 Mdot
.33398 .07715 Mdot
.33499 .07756 Mdot
.33538 .07771 Mdot
.33575 .07786 Mdot
.33611 .07801 Mdot
.33679 .07828 Mdot
.33713 .07842 Mdot
.33778 .07869 Mdot
.3381 .07882 Mdot
.33903 .0792 Mdot
.33927 .07929 Mdot
.33952 .0794 Mdot
.34034 .07973 Mdot
.34083 .07994 Mdot
.34112 .08005 Mdot
.34159 .08025 Mdot
.34221 .0805 Mdot
.34256 .08065 Mdot
.34326 .08094 Mdot
.34365 .0811 Mdot
.34409 .08128 Mdot
.34472 .08154 Mdot
.34511 .08171 Mdot
.34525 .08176 Mdot
.3457 .08195 Mdot
.34682 .08242 Mdot
.347 .0825 Mdot
.34742 .08267 Mdot
.34814 .08298 Mdot
.34847 .08312 Mdot
.34903 .08335 Mdot
.34971 .08364 Mdot
.35043 .08394 Mdot
.35091 .08415 Mdot
.35143 .08437 Mdot
.35181 .08453 Mdot
.35232 .08475 Mdot
.35299 .08503 Mdot
.35342 .08522 Mdot
.35393 .08544 Mdot
.35397 .08545 Mdot
.35445 .08566 Mdot
.35481 .08581 Mdot
.35535 .08604 Mdot
.35592 .08629 Mdot
.35655 .08656 Mdot
.35743 .08694 Mdot
.35785 .08712 Mdot
.35816 .08726 Mdot
.35852 .08742 Mdot
.35883 .08755 Mdot
.3595 .08784 Mdot
.36033 .08821 Mdot
.36065 .08834 Mdot
.36116 .08857 Mdot
.36172 .08881 Mdot
.36252 .08916 Mdot
.36288 .08932 Mdot
.3635 .0896 Mdot
.3642 .0899 Mdot
.36448 .09003 Mdot
.36529 .09039 Mdot
.36578 .09061 Mdot
.36623 .0908 Mdot
.36669 .09101 Mdot
.36738 .09132 Mdot
.36781 .09151 Mdot
.36804 .09161 Mdot
.36851 .09182 Mdot
.36859 .09186 Mdot
.36954 .09228 Mdot
.36975 .09238 Mdot
.37015 .09256 Mdot
.37088 .09288 Mdot
.3715 .09317 Mdot
.37192 .09335 Mdot
.3728 .09375 Mdot
.37315 .09391 Mdot
.37364 .09413 Mdot
.37501 .09476 Mdot
.37547 .09496 Mdot
.37577 .0951 Mdot
.37601 .09521 Mdot
.37637 .09538 Mdot
.37673 .09554 Mdot
.37734 .09582 Mdot
.37774 .096 Mdot
.37834 .09628 Mdot
.3792 .09668 Mdot
.37937 .09675 Mdot
.38051 .09728 Mdot
.3812 .0976 Mdot
.38158 .09778 Mdot
.3824 .09816 Mdot
.38292 .0984 Mdot
.38313 .0985 Mdot
.38371 .09877 Mdot
.38427 .09903 Mdot
.38476 .09926 Mdot
.38517 .09945 Mdot
.38588 .09979 Mdot
.38626 .09997 Mdot
.38703 .10033 Mdot
.38758 .10059 Mdot
.38824 .1009 Mdot
.3886 .10107 Mdot
.38891 .10122 Mdot
.38938 .10144 Mdot
.38986 .10167 Mdot
.39067 .10205 Mdot
.39126 .10233 Mdot
.3914 .1024 Mdot
.39244 .1029 Mdot
.39288 .10311 Mdot
.393 .10317 Mdot
.3937 .1035 Mdot
.39438 .10383 Mdot
.39469 .10398 Mdot
.39479 .10403 Mdot
.39563 .10443 Mdot
.39616 .10469 Mdot
.39679 .10499 Mdot
.39764 .1054 Mdot
.39805 .1056 Mdot
.3983 .10572 Mdot
.39914 .10613 Mdot
.39948 .1063 Mdot
.39991 .10651 Mdot
.40058 .10683 Mdot
.40081 .10695 Mdot
.40118 .10713 Mdot
.40185 .10746 Mdot
.40225 .10765 Mdot
.40266 .10786 Mdot
.40306 .10805 Mdot
.40388 .10846 Mdot
.40416 .10859 Mdot
.40459 .10881 Mdot
.40484 .10893 Mdot
.40567 .10934 Mdot
.40595 .10948 Mdot
.40653 .10977 Mdot
.40722 .11011 Mdot
.40743 .11021 Mdot
.40778 .11039 Mdot
.40813 .11057 Mdot
.40826 .11063 Mdot
.40865 .11082 Mdot
.40958 .11129 Mdot
.41007 .11154 Mdot
.41038 .11169 Mdot
.41105 .11203 Mdot
.41188 .11245 Mdot
.41212 .11257 Mdot
.41274 .11288 Mdot
.41307 .11304 Mdot
.41366 .11334 Mdot
.41385 .11344 Mdot
.41462 .11383 Mdot
.41544 .11425 Mdot
.41563 .11434 Mdot
.41607 .11457 Mdot
.41636 .11471 Mdot
.41661 .11484 Mdot
.41725 .11517 Mdot
.41734 .11521 Mdot
.41773 .11541 Mdot
.41803 .11556 Mdot
.4184 .11576 Mdot
.41905 .11609 Mdot
.41947 .11631 Mdot
.42009 .11662 Mdot
.42073 .11695 Mdot
.42127 .11723 Mdot
.42159 .11739 Mdot
.42241 .11782 Mdot
.4232 .11823 Mdot
.42342 .11835 Mdot
.42379 .11854 Mdot
.42455 .11893 Mdot
.4254 .11937 Mdot
.42557 .11946 Mdot
.42661 .12 Mdot
.42738 .12041 Mdot
.4279 .12068 Mdot
.42844 .12096 Mdot
.42888 .12119 Mdot
.42965 .1216 Mdot
.43023 .12191 Mdot
.43053 .12206 Mdot
.43129 .12246 Mdot
.43156 .12261 Mdot
.43218 .12294 Mdot
.43311 .12343 Mdot
.43321 .12348 Mdot
.43388 .12384 Mdot
.43453 .12419 Mdot
.43483 .12435 Mdot
.43576 .12484 Mdot
.43594 .12494 Mdot
.43667 .12533 Mdot
.43701 .12551 Mdot
.43726 .12565 Mdot
.43776 .12591 Mdot
.438 .12604 Mdot
.43892 .12654 Mdot
.43952 .12686 Mdot
.44007 .12716 Mdot
.44031 .12729 Mdot
.44063 .12746 Mdot
.44126 .1278 Mdot
.44162 .128 Mdot
.44268 .12857 Mdot
.44282 .12865 Mdot
.44366 .1291 Mdot
.44429 .12945 Mdot
.44485 .12975 Mdot
.44513 .12991 Mdot
.44543 .13007 Mdot
.44602 .1304 Mdot
.44654 .13068 Mdot
.44728 .13109 Mdot
.44748 .1312 Mdot
.44793 .13145 Mdot
.44877 .13191 Mdot
.44955 .13234 Mdot
.45014 .13266 Mdot
.45049 .13286 Mdot
.45079 .13302 Mdot
.45103 .13316 Mdot
.45166 .1335 Mdot
.45219 .1338 Mdot
.45224 .13383 Mdot
.45253 .13399 Mdot
.45315 .13433 Mdot
.4538 .1347 Mdot
.45416 .1349 Mdot
.45444 .13505 Mdot
.45566 .13574 Mdot
.45574 .13578 Mdot
.45662 .13628 Mdot
.45728 .13665 Mdot
.45779 .13694 Mdot
.4582 .13716 Mdot
.45852 .13735 Mdot
.45899 .13761 Mdot
.45992 .13814 Mdot
.46016 .13828 Mdot
.46067 .13856 Mdot
.46098 .13874 Mdot
.46177 .13919 Mdot
.46199 .13931 Mdot
.4625 .1396 Mdot
.46283 .13979 Mdot
.46319 .14 Mdot
.46346 .14015 Mdot
.46404 .14048 Mdot
.46458 .14079 Mdot
.46516 .14112 Mdot
.46609 .14165 Mdot
.46657 .14193 Mdot
.46757 .1425 Mdot
.46803 .14277 Mdot
.46857 .14308 Mdot
.46932 .14352 Mdot
.47003 .14393 Mdot
.4706 .14426 Mdot
.47118 .1446 Mdot
.47138 .14471 Mdot
.47207 .14511 Mdot
.47227 .14523 Mdot
.47296 .14563 Mdot
.47368 .14605 Mdot
.47402 .14625 Mdot
.47439 .14647 Mdot
.47502 .14683 Mdot
.47583 .14731 Mdot
.47646 .14768 Mdot
.47697 .14798 Mdot
.47728 .14816 Mdot
.47796 .14856 Mdot
.47845 .14885 Mdot
.47881 .14906 Mdot
.47964 .14955 Mdot
.48064 .15015 Mdot
.48088 .15029 Mdot
.48136 .15057 Mdot
.4822 .15107 Mdot
.48257 .15129 Mdot
.48315 .15164 Mdot
.48372 .15198 Mdot
.48381 .15203 Mdot
.4844 .15239 Mdot
.48533 .15294 Mdot
.48561 .15311 Mdot
.48582 .15323 Mdot
.48627 .1535 Mdot
.48675 .15379 Mdot
.48726 .1541 Mdot
.4878 .15442 Mdot
.48808 .15459 Mdot
.48876 .155 Mdot
.48949 .15544 Mdot
.49009 .1558 Mdot
.49034 .15596 Mdot
.49119 .15647 Mdot
.49201 .15697 Mdot
.49258 .15731 Mdot
.49305 .1576 Mdot
.49329 .15775 Mdot
.49378 .15805 Mdot
.49432 .15838 Mdot
.49442 .15844 Mdot
.49505 .15882 Mdot
.49554 .15912 Mdot
.49634 .15961 Mdot
.49721 .16015 Mdot
.49768 .16044 Mdot
.49837 .16086 Mdot
.49873 .16108 Mdot
.49926 .16141 Mdot
.49963 .16164 Mdot
.49999 .16186 Mdot
.50051 .16218 Mdot
.50066 .16228 Mdot
.50124 .16263 Mdot
.50148 .16278 Mdot
.5019 .16304 Mdot
.50238 .16334 Mdot
.50257 .16346 Mdot
.50337 .16396 Mdot
.50352 .16405 Mdot
.50414 .16444 Mdot
.50432 .16455 Mdot
.50507 .16502 Mdot
.50568 .1654 Mdot
.50628 .16577 Mdot
.50683 .16612 Mdot
.50776 .1667 Mdot
.50828 .16703 Mdot
.50889 .16741 Mdot
.50969 .16791 Mdot
.50983 .168 Mdot
.51028 .16829 Mdot
.51073 .16857 Mdot
.51135 .16896 Mdot
.51152 .16907 Mdot
.51266 .16979 Mdot
.513 .17001 Mdot
.51301 .17002 Mdot
.51367 .17044 Mdot
.51402 .17066 Mdot
.51439 .1709 Mdot
.51534 .1715 Mdot
.5159 .17186 Mdot
.51608 .17197 Mdot
.51708 .17261 Mdot
.51779 .17307 Mdot
.51833 .17341 Mdot
.51894 .1738 Mdot
.51907 .17388 Mdot
.51942 .17411 Mdot
.52026 .17465 Mdot
.5206 .17487 Mdot
.5213 .17532 Mdot
.5215 .17546 Mdot
.52186 .17569 Mdot
.5228 .1763 Mdot
.52313 .17651 Mdot
.5236 .17681 Mdot
.52405 .1771 Mdot
.52455 .17743 Mdot
.52508 .17778 Mdot
.52551 .17806 Mdot
.52596 .17835 Mdot
.52661 .17877 Mdot
.52701 .17903 Mdot
.52754 .17938 Mdot
.52804 .17971 Mdot
.52839 .17994 Mdot
.52898 .18032 Mdot
.52965 .18076 Mdot
.5297 .18079 Mdot
.53086 .18156 Mdot
.53138 .1819 Mdot
.53179 .18217 Mdot
.53201 .18232 Mdot
.53242 .18258 Mdot
.53336 .18321 Mdot
.53361 .18337 Mdot
.5338 .1835 Mdot
.53471 .1841 Mdot
.53516 .1844 Mdot
.53611 .18503 Mdot
.53635 .18519 Mdot
.53662 .18537 Mdot
.53719 .18575 Mdot
.53772 .1861 Mdot
.53816 .18639 Mdot
.53877 .1868 Mdot
.53979 .18748 Mdot
.54019 .18775 Mdot
.54058 .18802 Mdot
.54086 .1882 Mdot
.54149 .18862 Mdot
.54247 .18928 Mdot
.54289 .18957 Mdot
.5435 .18998 Mdot
.54407 .19036 Mdot
.54484 .19089 Mdot
.54488 .19091 Mdot
.54529 .19119 Mdot
.546 .19167 Mdot
.54641 .19194 Mdot
.54722 .1925 Mdot
.54768 .19281 Mdot
.54821 .19317 Mdot
.5487 .1935 Mdot
.54896 .19368 Mdot
.54944 .19401 Mdot
.5501 .19446 Mdot
.55014 .19448 Mdot
.55058 .19479 Mdot
.55137 .19533 Mdot
.55155 .19545 Mdot
.5522 .19589 Mdot
.5531 .19651 Mdot
.55391 .19707 Mdot
.55484 .19771 Mdot
.55509 .19788 Mdot
.55525 .19799 Mdot
.5558 .19838 Mdot
.55673 .19901 Mdot
.5574 .19948 Mdot
.55788 .19981 Mdot
.55795 .19986 Mdot
.55881 .20046 Mdot
.55901 .20059 Mdot
.56022 .20144 Mdot
.56053 .20165 Mdot
.56108 .20204 Mdot
.56198 .20266 Mdot
.5625 .20303 Mdot
.56268 .20315 Mdot
.56325 .20355 Mdot
.56387 .20399 Mdot
.5646 .2045 Mdot
.56517 .2049 Mdot
.56566 .20525 Mdot
.56606 .20553 Mdot
.56659 .2059 Mdot
.56744 .20649 Mdot
.56766 .20665 Mdot
.5682 .20704 Mdot
.56845 .20721 Mdot
.56913 .20769 Mdot
.56989 .20823 Mdot
.56998 .20829 Mdot
.57068 .20879 Mdot
.57147 .20935 Mdot
.57176 .20956 Mdot
.57211 .2098 Mdot
.57285 .21034 Mdot
.57316 .21055 Mdot
.57424 .21133 Mdot
.5744 .21144 Mdot
.57497 .21185 Mdot
.57579 .21244 Mdot
.57622 .21274 Mdot
.5771 .21337 Mdot
.57785 .21392 Mdot
.57826 .21421 Mdot
.57872 .21454 Mdot
.57941 .21504 Mdot
.58007 .21551 Mdot
.5807 .21597 Mdot
.58118 .21631 Mdot
.5816 .21662 Mdot
.58177 .21674 Mdot
.58245 .21724 Mdot
.58288 .21754 Mdot
.58342 .21794 Mdot
.58356 .21804 Mdot
.5843 .21858 Mdot
.58543 .2194 Mdot
.58627 .22001 Mdot
.58686 .22045 Mdot
.58781 .22114 Mdot
.58821 .22143 Mdot
.5886 .22172 Mdot
.58912 .2221 Mdot
.59026 .22293 Mdot
.59039 .22303 Mdot
.59098 .22347 Mdot
.59133 .22372 Mdot
.59226 .22441 Mdot
.59283 .22483 Mdot
.59342 .22527 Mdot
.59401 .2257 Mdot
.59462 .22615 Mdot
.59464 .22617 Mdot
.5949 .22636 Mdot
.59552 .22682 Mdot
.59604 .22721 Mdot
.59671 .22771 Mdot
.59746 .22826 Mdot
.59816 .22879 Mdot
.5987 .22919 Mdot
.5998 .23001 Mdot
.6005 .23054 Mdot
.60108 .23097 Mdot
.60122 .23107 Mdot
.60183 .23153 Mdot
.60207 .23171 Mdot
.60294 .23236 Mdot
.60319 .23255 Mdot
.60382 .23302 Mdot
.60428 .23337 Mdot
.60472 .2337 Mdot
.60546 .23426 Mdot
.60615 .23478 Mdot
.60668 .23519 Mdot
.60709 .23549 Mdot
.60761 .23589 Mdot
.60818 .23632 Mdot
.60895 .2369 Mdot
.60944 .23727 Mdot
.61022 .23787 Mdot
.61071 .23824 Mdot
.61102 .23848 Mdot
.61186 .23912 Mdot
.61221 .23939 Mdot
.61295 .23995 Mdot
.61342 .24032 Mdot
.61365 .24049 Mdot
.61427 .24096 Mdot
.61487 .24142 Mdot
.61585 .24217 Mdot
.61628 .2425 Mdot
.61647 .24265 Mdot
.61715 .24318 Mdot
.6174 .24336 Mdot
.61784 .2437 Mdot
.6186 .24429 Mdot
.6189 .24453 Mdot
.61958 .24505 Mdot
.61999 .24537 Mdot
.62079 .24599 Mdot
.62128 .24637 Mdot
.6215 .24654 Mdot
.62215 .24704 Mdot
.62265 .24743 Mdot
.62301 .24771 Mdot
.6236 .24817 Mdot
.62405 .24852 Mdot
.62444 .24883 Mdot
.62501 .24927 Mdot
.62524 .24945 Mdot
.62594 .24999 Mdot
.62665 .25055 Mdot
.62701 .25083 Mdot
.62766 .25134 Mdot
.62832 .25186 Mdot
.62868 .25214 Mdot
.629 .25239 Mdot
.62926 .2526 Mdot
.62995 .25314 Mdot
.63034 .25345 Mdot
.63124 .25415 Mdot
.63181 .25461 Mdot
.63193 .2547 Mdot
.6323 .25499 Mdot
.63249 .25514 Mdot
.63343 .25589 Mdot
.63382 .25619 Mdot
.63422 .25651 Mdot
.63452 .25675 Mdot
.63537 .25742 Mdot
.63556 .25757 Mdot
.63657 .25837 Mdot
.63702 .25873 Mdot
.63733 .25898 Mdot
.63767 .25925 Mdot
.63817 .25965 Mdot
.63845 .25987 Mdot
.63883 .26017 Mdot
.63991 .26104 Mdot
.64003 .26114 Mdot
.6406 .26159 Mdot
.6414 .26223 Mdot
.64165 .26243 Mdot
.64235 .26299 Mdot
.64309 .26358 Mdot
.64319 .26367 Mdot
.64372 .26409 Mdot
.64424 .26451 Mdot
.64468 .26486 Mdot
.64483 .26499 Mdot
.64521 .2653 Mdot
.6455 .26553 Mdot
.64582 .26579 Mdot
.64645 .2663 Mdot
.6469 .26666 Mdot
.64752 .26716 Mdot
.6478 .26739 Mdot
.64877 .26818 Mdot
.64931 .26861 Mdot
.65007 .26923 Mdot
.65045 .26954 Mdot
.65076 .26979 Mdot
.65145 .27035 Mdot
.65201 .27081 Mdot
.65237 .2711 Mdot
.65324 .27181 Mdot
.65356 .27207 Mdot
.65416 .27257 Mdot
.65447 .27282 Mdot
.65514 .27337 Mdot
.65548 .27364 Mdot
.65607 .27413 Mdot
.65663 .27459 Mdot
.65727 .27511 Mdot
.65825 .27592 Mdot
.6587 .27629 Mdot
.65879 .27637 Mdot
.65959 .27702 Mdot
.65976 .27717 Mdot
.66009 .27744 Mdot
.66116 .27832 Mdot
.66124 .27839 Mdot
.66228 .27925 Mdot
.66281 .27969 Mdot
.66333 .28012 Mdot
.66402 .28069 Mdot
.66486 .28139 Mdot
.66532 .28177 Mdot
.66599 .28234 Mdot
.6663 .28259 Mdot
.66643 .2827 Mdot
.66752 .28361 Mdot
.66775 .2838 Mdot
.66811 .2841 Mdot
.66829 .28426 Mdot
.66851 .28444 Mdot
.66872 .28461 Mdot
.66928 .28508 Mdot
.66978 .2855 Mdot
.67025 .2859 Mdot
.67098 .28651 Mdot
.6713 .28678 Mdot
.67165 .28707 Mdot
.67192 .2873 Mdot
.67278 .28802 Mdot
.67309 .28828 Mdot
.67328 .28844 Mdot
.67388 .28895 Mdot
.67464 .28959 Mdot
.67483 .28975 Mdot
.67561 .29041 Mdot
.67612 .29085 Mdot
.67694 .29154 Mdot
.67725 .2918 Mdot
.67779 .29226 Mdot
.6786 .29295 Mdot
.67916 .29342 Mdot
.67984 .294 Mdot
.68059 .29464 Mdot
.68086 .29487 Mdot
.6815 .29542 Mdot
.68181 .29568 Mdot
.68275 .29649 Mdot
.68317 .29684 Mdot
.68382 .2974 Mdot
.68436 .29786 Mdot
.68468 .29813 Mdot
.68509 .29849 Mdot
.6857 .29902 Mdot
.68644 .29965 Mdot
.68672 .29989 Mdot
.68725 .30035 Mdot
.68807 .30105 Mdot
.68844 .30137 Mdot
.68925 .30207 Mdot
.68964 .3024 Mdot
.69031 .30299 Mdot
.69058 .30322 Mdot
.69118 .30374 Mdot
.69149 .30401 Mdot
.69202 .30446 Mdot
.69243 .30482 Mdot
.6928 .30515 Mdot
.69291 .30524 Mdot
.69315 .30545 Mdot
.69421 .30637 Mdot
.69504 .30709 Mdot
.69537 .30738 Mdot
.69565 .30763 Mdot
.6958 .30775 Mdot
.69652 .30838 Mdot
.69699 .30879 Mdot
.6981 .30977 Mdot
.69823 .30988 Mdot
.69894 .3105 Mdot
.69941 .31091 Mdot
.69985 .3113 Mdot
.70044 .31182 Mdot
.70099 .3123 Mdot
.70143 .31269 Mdot
.70183 .31304 Mdot
.70231 .31346 Mdot
.70335 .31437 Mdot
.70346 .31448 Mdot
.70402 .31496 Mdot
.7048 .31566 Mdot
.70508 .3159 Mdot
.70602 .31673 Mdot
.70642 .31709 Mdot
.70648 .31715 Mdot
.70684 .31746 Mdot
.70757 .31812 Mdot
.70802 .31851 Mdot
.70826 .31873 Mdot
.70909 .31946 Mdot
.70978 .32008 Mdot
.71009 .32035 Mdot
.71051 .32073 Mdot
.71053 .32075 Mdot
.71118 .32132 Mdot
.71183 .3219 Mdot
.71263 .32262 Mdot
.71326 .32318 Mdot
.71412 .32396 Mdot
.7146 .32438 Mdot
.71481 .32457 Mdot
.71548 .32517 Mdot
.71583 .32548 Mdot
.71622 .32584 Mdot
.71664 .32621 Mdot
.71735 .32685 Mdot
.7181 .32753 Mdot
.71842 .32782 Mdot
.71868 .32805 Mdot
.71912 .32845 Mdot
.7195 .32879 Mdot
.71969 .32896 Mdot
.72004 .32928 Mdot
.72056 .32975 Mdot
.72101 .33016 Mdot
.72233 .33135 Mdot
.72261 .3316 Mdot
.72306 .33201 Mdot
.72386 .33274 Mdot
.72424 .33308 Mdot
.72466 .33346 Mdot
.72494 .33372 Mdot
.72543 .33417 Mdot
.72599 .33468 Mdot
.7265 .33515 Mdot
.72695 .33555 Mdot
.727 .3356 Mdot
.72737 .33594 Mdot
.72773 .33626 Mdot
.7281 .33661 Mdot
.72842 .3369 Mdot
.72929 .33769 Mdot
.73031 .33863 Mdot
.73068 .33897 Mdot
.73099 .33925 Mdot
.73133 .33956 Mdot
.73252 .34066 Mdot
.73341 .34148 Mdot
.7338 .34184 Mdot
.73429 .34228 Mdot
.73461 .34258 Mdot
.73536 .34327 Mdot
.73567 .34356 Mdot
.73585 .34373 Mdot
.73627 .34412 Mdot
.73689 .34468 Mdot
.73779 .34552 Mdot
.73816 .34586 Mdot
.73866 .34633 Mdot
.7389 .34655 Mdot
.73963 .34723 Mdot
.73991 .34749 Mdot
.74031 .34786 Mdot
.74077 .34829 Mdot
.74119 .34868 Mdot
.74188 .34932 Mdot
.74221 .34963 Mdot
.74267 .35006 Mdot
.7427 .35009 Mdot
.74342 .35076 Mdot
.74348 .35081 Mdot
.744 .3513 Mdot
.74467 .35193 Mdot
.74515 .35237 Mdot
.74553 .35273 Mdot
.74581 .353 Mdot
.74626 .35342 Mdot
.74681 .35393 Mdot
.74722 .35432 Mdot
.74748 .35456 Mdot
.74801 .35506 Mdot
.74837 .3554 Mdot
.74932 .35629 Mdot
.74965 .3566 Mdot
.75002 .35695 Mdot
.75075 .35764 Mdot
.75124 .35811 Mdot
.75196 .35878 Mdot
.75267 .35945 Mdot
.75303 .35979 Mdot
.75356 .36029 Mdot
.75444 .36113 Mdot
.75502 .36168 Mdot
.75531 .36196 Mdot
.75555 .36218 Mdot
.75611 .36271 Mdot
.75627 .36287 Mdot
.75728 .36383 Mdot
.75791 .36443 Mdot
.75839 .36489 Mdot
.75879 .36527 Mdot
.75933 .36578 Mdot
.75978 .36621 Mdot
.76033 .36673 Mdot
.76127 .36764 Mdot
.76156 .36792 Mdot
.76214 .36847 Mdot
.76261 .36892 Mdot
.7629 .3692 Mdot
.76365 .36992 Mdot
.76445 .37069 Mdot
.76463 .37086 Mdot
.76495 .37117 Mdot
.76575 .37194 Mdot
.76584 .37202 Mdot
.76623 .3724 Mdot
.7667 .37286 Mdot
.76705 .37319 Mdot
.76798 .37409 Mdot
.76876 .37484 Mdot
.76903 .3751 Mdot
.76943 .37549 Mdot
.7702 .37624 Mdot
.77046 .37649 Mdot
.77122 .37723 Mdot
.77215 .37813 Mdot
.77249 .37846 Mdot
.77325 .3792 Mdot
.77365 .37959 Mdot
.77449 .38041 Mdot
.77481 .38072 Mdot
.7753 .38119 Mdot
.77561 .3815 Mdot
.77689 .38275 Mdot
.777 .38286 Mdot
.77785 .38369 Mdot
.7782 .38403 Mdot
.77837 .38419 Mdot
.7793 .38511 Mdot
.77943 .38523 Mdot
.77968 .38548 Mdot
.78083 .38661 Mdot
.78113 .3869 Mdot
.7818 .38756 Mdot
.78245 .3882 Mdot
.78303 .38877 Mdot
.78366 .38939 Mdot
.78402 .38975 Mdot
.78469 .39041 Mdot
.78548 .39119 Mdot
.78641 .39211 Mdot
.7865 .3922 Mdot
.78693 .39262 Mdot
.78743 .39312 Mdot
.78802 .3937 Mdot
.78871 .39439 Mdot
.78909 .39476 Mdot
.78975 .39542 Mdot
.79038 .39605 Mdot
.79061 .39628 Mdot
.79118 .39684 Mdot
.79233 .39799 Mdot
.79272 .39839 Mdot
.79324 .3989 Mdot
.79367 .39933 Mdot
.79375 .39941 Mdot
.79462 .40028 Mdot
.79499 .40065 Mdot
.79537 .40103 Mdot
.79616 .40182 Mdot
.79644 .40211 Mdot
.79684 .4025 Mdot
.79732 .40298 Mdot
.79788 .40355 Mdot
.79839 .40406 Mdot
.79915 .40482 Mdot
.7994 .40507 Mdot
.79981 .40549 Mdot
.80016 .40584 Mdot
.80067 .40636 Mdot
.80143 .40712 Mdot
.80169 .40738 Mdot
.80234 .40804 Mdot
.80271 .40842 Mdot
.80371 .40942 Mdot
.80396 .40968 Mdot
.80444 .41016 Mdot
.8047 .41043 Mdot
.80528 .41101 Mdot
.80549 .41123 Mdot
.80657 .41233 Mdot
.80688 .41264 Mdot
.80717 .41293 Mdot
.80794 .41372 Mdot
.80875 .41454 Mdot
.80917 .41498 Mdot
.80963 .41544 Mdot
.81044 .41627 Mdot
.81102 .41686 Mdot
.81137 .41722 Mdot
.81193 .41779 Mdot
.81211 .41797 Mdot
.81279 .41868 Mdot
.81339 .41928 Mdot
.81384 .41975 Mdot
.81466 .42059 Mdot
.81475 .42068 Mdot
.81515 .42109 Mdot
.81553 .42149 Mdot
.81625 .42223 Mdot
.8169 .42289 Mdot
.81729 .42329 Mdot
.81818 .42421 Mdot
.81869 .42473 Mdot
.81933 .4254 Mdot
.81965 .42573 Mdot
.82005 .42614 Mdot
.82084 .42696 Mdot
.82146 .42759 Mdot
.82214 .4283 Mdot
.82256 .42874 Mdot
.82275 .42894 Mdot
.82356 .42977 Mdot
.8237 .42992 Mdot
.82412 .43035 Mdot
.82467 .43093 Mdot
.8253 .43158 Mdot
.82603 .43234 Mdot
.82622 .43254 Mdot
.8268 .43314 Mdot
.82794 .43434 Mdot
.82808 .43448 Mdot
.82893 .43537 Mdot
.82932 .43578 Mdot
.82982 .4363 Mdot
.83022 .43672 Mdot
.83071 .43723 Mdot
.83106 .43759 Mdot
.83199 .43857 Mdot
.83278 .43941 Mdot
.83289 .43951 Mdot
.83332 .43997 Mdot
.83354 .4402 Mdot
.83402 .4407 Mdot
.83439 .44109 Mdot
.8347 .44142 Mdot
.83535 .4421 Mdot
.83597 .44276 Mdot
.83678 .44361 Mdot
.83802 .44492 Mdot
.83806 .44496 Mdot
.83871 .44564 Mdot
.83982 .44682 Mdot
.84061 .44766 Mdot
.84069 .44775 Mdot
.84149 .4486 Mdot
.84158 .44869 Mdot
.84251 .44968 Mdot
.84318 .45039 Mdot
.84361 .45085 Mdot
.84415 .45142 Mdot
.84448 .45177 Mdot
.84534 .45269 Mdot
.84564 .45301 Mdot
.846 .45339 Mdot
.84621 .45362 Mdot
.84695 .45441 Mdot
.8474 .45489 Mdot
.84793 .45546 Mdot
.84815 .4557 Mdot
.84911 .45672 Mdot
.84967 .45732 Mdot
.85031 .458 Mdot
.85073 .45845 Mdot
.8519 .45971 Mdot
.8523 .46015 Mdot
.85294 .46083 Mdot
.85331 .46123 Mdot
.8539 .46187 Mdot
.85444 .46245 Mdot
.8552 .46326 Mdot
.85604 .46417 Mdot
.85644 .4646 Mdot
.85688 .46508 Mdot
.8573 .46554 Mdot
.85755 .4658 Mdot
.85826 .46657 Mdot
.85831 .46663 Mdot
.85888 .46724 Mdot
.85954 .46796 Mdot
.8599 .46835 Mdot
.86081 .46934 Mdot
.86159 .47018 Mdot
.86177 .47039 Mdot
.8624 .47106 Mdot
.86272 .47142 Mdot
.86327 .47201 Mdot
.86352 .47229 Mdot
.86445 .4733 Mdot
.86476 .47364 Mdot
.86478 .47366 Mdot
.86575 .47473 Mdot
.86602 .47501 Mdot
.86671 .47577 Mdot
.86721 .47632 Mdot
.86768 .47683 Mdot
.86845 .47768 Mdot
.8694 .47872 Mdot
.86987 .47923 Mdot
.87033 .47974 Mdot
.87063 .48007 Mdot
.87129 .4808 Mdot
.87168 .48123 Mdot
.87248 .4821 Mdot
.87301 .48269 Mdot
.87338 .4831 Mdot
.8741 .48389 Mdot
.87461 .48446 Mdot
.87522 .48513 Mdot
.87597 .48596 Mdot
.87604 .48604 Mdot
.87663 .48669 Mdot
.8774 .48754 Mdot
.87813 .48835 Mdot
.87816 .48838 Mdot
.87856 .48883 Mdot
.87945 .48982 Mdot
.87993 .49034 Mdot
.88047 .49095 Mdot
.88097 .4915 Mdot
.881 .49153 Mdot
.88155 .49215 Mdot
.88243 .49313 Mdot
.88262 .49334 Mdot
.88363 .49446 Mdot
.88454 .49549 Mdot
.88486 .49584 Mdot
.88549 .49654 Mdot
.88604 .49716 Mdot
.88719 .49845 Mdot
.88788 .49922 Mdot
.88799 .49935 Mdot
.88862 .50005 Mdot
.88972 .50129 Mdot
.89012 .50173 Mdot
.8905 .50217 Mdot
.89069 .50238 Mdot
.89163 .50344 Mdot
.89201 .50386 Mdot
.89239 .5043 Mdot
.89301 .50499 Mdot
.8934 .50543 Mdot
.89386 .50595 Mdot
.89465 .50684 Mdot
.89517 .50744 Mdot
.89603 .50841 Mdot
.89645 .50889 Mdot
.89714 .50966 Mdot
.89743 .50999 Mdot
.89825 .51092 Mdot
.89894 .51171 Mdot
.89948 .51231 Mdot
.90024 .51318 Mdot
.90036 .51332 Mdot
.90073 .51374 Mdot
.9013 .51438 Mdot
.90185 .51501 Mdot
.90219 .5154 Mdot
.90265 .51593 Mdot
.90318 .51653 Mdot
.90404 .51752 Mdot
.90483 .51842 Mdot
.90532 .51897 Mdot
.90583 .51956 Mdot
.90626 .52006 Mdot
.90643 .52025 Mdot
.90685 .52073 Mdot
.90807 .52213 Mdot
.90812 .52218 Mdot
.90881 .52298 Mdot
.90965 .52394 Mdot
.91004 .52439 Mdot
.91028 .52467 Mdot
.91099 .52549 Mdot
.91172 .52633 Mdot
.9121 .52677 Mdot
.9126 .52734 Mdot
.91354 .52843 Mdot
.91384 .52877 Mdot
.91431 .52931 Mdot
.91494 .53005 Mdot
.9153 .53046 Mdot
.91551 .53071 Mdot
.91625 .53156 Mdot
.91685 .53225 Mdot
.91778 .53334 Mdot
.91814 .53376 Mdot
.91855 .53423 Mdot
.91898 .53473 Mdot
.9195 .53533 Mdot
.91987 .53577 Mdot
.92053 .53653 Mdot
.92102 .5371 Mdot
.92176 .53796 Mdot
.92267 .53902 Mdot
.92295 .53936 Mdot
.92329 .53975 Mdot
.92361 .54012 Mdot
.92393 .5405 Mdot
.92485 .54157 Mdot
.92507 .54183 Mdot
.92583 .54271 Mdot
.9264 .54338 Mdot
.92684 .5439 Mdot
.92777 .54499 Mdot
.92809 .54537 Mdot
.92897 .5464 Mdot
.92928 .54676 Mdot
.93005 .54767 Mdot
.9306 .54831 Mdot
.93086 .54862 Mdot
.93174 .54965 Mdot
.93203 .55 Mdot
.93278 .55088 Mdot
.93317 .55135 Mdot
.93341 .55162 Mdot
.93436 .55275 Mdot
.93473 .55319 Mdot
.93552 .55412 Mdot
.93608 .55478 Mdot
.93623 .55496 Mdot
.93745 .55641 Mdot
.93815 .55723 Mdot
.93827 .55737 Mdot
.939 .55824 Mdot
.93934 .55865 Mdot
.93996 .55939 Mdot
.94076 .56034 Mdot
.94095 .56057 Mdot
.9416 .56134 Mdot
.94251 .56243 Mdot
.94278 .56275 Mdot
.94326 .56332 Mdot
.94393 .56412 Mdot
.94428 .56454 Mdot
.94466 .56499 Mdot
.94487 .56524 Mdot
.94542 .5659 Mdot
.94603 .56663 Mdot
.94642 .5671 Mdot
.94697 .56776 Mdot
.94726 .5681 Mdot
.94819 .56922 Mdot
.94839 .56946 Mdot
.94879 .56993 Mdot
.9493 .57055 Mdot
.94952 .57081 Mdot
.95015 .57157 Mdot
.95074 .57228 Mdot
.95095 .57253 Mdot
.95174 .57348 Mdot
.95218 .57401 Mdot
.9526 .57452 Mdot
.95332 .57539 Mdot
.95341 .57549 Mdot
.95387 .57606 Mdot
.95406 .57628 Mdot
.95457 .5769 Mdot
.95527 .57775 Mdot
.95595 .57856 Mdot
.95634 .57904 Mdot
.95668 .57945 Mdot
.9573 .5802 Mdot
.95764 .58061 Mdot
.95799 .58104 Mdot
.95855 .58171 Mdot
.95938 .58272 Mdot
.95979 .58322 Mdot
.96046 .58403 Mdot
.96093 .58461 Mdot
.96138 .58516 Mdot
.96206 .58598 Mdot
.96215 .58609 Mdot
.96311 .58726 Mdot
.96366 .58793 Mdot
.96384 .58815 Mdot
.96495 .58951 Mdot
.96564 .59035 Mdot
.96625 .5911 Mdot
.96711 .59215 Mdot
.96764 .59279 Mdot
.96821 .59349 Mdot
.96865 .59403 Mdot
.96957 .59516 Mdot
.96995 .59563 Mdot
.97047 .59627 Mdot
.9709 .5968 Mdot
.97152 .59757 Mdot
.97196 .59811 Mdot
.97287 .59922 Mdot
.97331 .59976 Mdot
.97345 .59993 Mdot
.97385 .60043 Mdot
.97393 .60053 Mdot
.97466 .60143 Mdot
.97526 .60217 Mdot
.976 .60308 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1808) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00169411) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666678) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP80
0000103jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0
n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2
000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00
00030?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40
oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`
iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4
000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V0P0000030?[`iP<00000o`3jl>JM
0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H40000
00030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H20000
00D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`
iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000203jl>H200000080n_3V0P0000000`3j
l>H000000000003o0?[`iY`0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0
n_3V00<000000?[`iP3jl>H09@3jl>H2000000030?[`iP000000000000X0n_3V0P0000050?[`iP80
00001@3jl>H2000000D0n_3V0P0000040?[`iP030000003jl>H0n_3V008000000P3jl>H200000003
0?[`iP00000000000?l0n_3VW03jl>H10?ooo`007`3jl>H6000000@0n_3V0P00000_0?[`iPD00000
:03jl>H3000000`0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000020?[`iPD00000
0`3jl>H300000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V
0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00000000000000003jl>H0
0`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H000000000003jl>H5000000<0
n_3V3000000_0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0
n_3V0`0000040?[`iP<000001@3jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V
0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V0000000000030?[`iP05
0000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`
iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`
iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080
n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP800000103jl>H200000080
n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0
n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000
103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP8000001@3jl>H5000000<0n_3V
0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3V
WP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103j
l>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V0`0000000`3jl>H00000
0?[`iP040?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP@00000
0`3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000H0n_3V0P00003o0?[`iYd0n_3V
0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V100000030?[`iP80000000<0
n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103jl>H200000300n_3V0P00
00000`3jl>H00000000000090?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3j
l>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P00000;0?[`iP8000008P3jl>H2
00000300n_3V0P0000000`3jl>H000000000000:0?[`iP8000001@3jl>H2000000D0n_3V0P000005
0?[`iP8000001@3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P00003o0?[`iYd0n_3V0@3oool0
0200n_3V1P0000090?[`iP800000803jl>H400000340n_3V0`00000<0?[`iP<00000103jl>H30000
00@0n_3V0`0000040?[`iP<00000103jl>H300000080n_3V1@00003o0?[`iYd0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`
iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`iP030000003jl>H0n_3V
00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H000000000000200000005
0?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H0000001P0n_3V1@00003K0?[`
iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`
iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V100000000`3jl>H0000000000002
0?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H000000?[`iP03000001P0n_3V
0`0000040?[`iP8000001@3jl>H3000000@0n_3V0`0000030?[`iPH000000P3jl>H3000000<0n_3V
0`0000050?[`iP@000000P3jl>H6000000030?[`iP000000000000@00000J@3jl>H10?ooo`008@3j
l>H2000000030?[`iP000000000000D0000000@0n_3V00000000000000000P3jl>H2000000030?[`
iP000000000000T0n_3V1@0000090?[`iP800000g`3jl>H2000000@0n_3V0P0000020?[`iP800000
0P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080
n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3j
l>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3j
l>H00000000000030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP8000000`3jl>H2000000030?[`iP000000000000@0n_3V0P0000050?[`
iP8000001@3jl>H2000000D0n_3V0P00001[0?[`iP40oooo000R0?[`iP<00000:@3jl>H200000=h0
n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0
n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V00000000
00002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H20000
00@0n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H00000000000090?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`
iP80000000<0n_3V0000000000001@3jl>H2000000030?[`iP000000000000@00000103jl>H20000
00D0n_3V0P00001[0?[`iP40oooo000R0?[`iP<000006P3jl>H5000000/0n_3V0P00003M0?[`iP@0
00000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H200000005
0?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3j
l>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H20000
00030?[`iP000000000000<0n_3V10000000103jl>H000000?[`iP3jl>H2000000D0n_3V0P000005
0?[`iP800000J`3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002X0n_3V0P00003L0?[`
iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2
000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2
000000030?[`iP000000000000X0n_3V0`000000103jl>H000000000003jl>H200000080n_3V0P00
00020?[`iP<0000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02000001P0n_3V0P00
00000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000@0n_3V0P0000030?[`iP@000000`3jl>H2000000030?[`iP00000000000080n_3V00@0
00000?[`iP00000000001@3jl>H2000000D0n_3V0P00001[0?[`iP40oooo000P0?[`iP<0000000@0
n_3V00000000000000009P3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000
000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0
n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0n_3V00000000
00000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H0
0000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0
n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V00@000000?[`iP00
000000001@3jl>H2000000D0n_3V0P00001[0?[`iP40oooo001=0?[`iP80000000<0n_3V00000000
0000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP8000008P3jl>H200000080
n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000020?[`iP@00000103jl>H2000000@0n_3V0P0000000`3jl>H0
0000000000030?[`iP<000000`3jl>H4000000<0n_3V1000001[0?[`iP40oooo001>0?[`iP<00000
g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000I0?[`iP<00000
00<0n_3V0000000000000P00000^0?[`iP<000002`3jl>H3000000@0n_3V0`0000050?[`iP800000
1@3jl>H3000000<0n_3V0`0000050?[`iP8000001@3jl>H2000000D0n_3V0P00001[0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0
n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40
oooo000W0?[`iP050000003jl>H000000?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`
iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V00000000
00000P000000103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V00000080n_3V00<00000
0?[`iP3jl>H05`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P000003
0?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V0000000000001P00000J
0?[`iPH000000P3jl>H3000000@0n_3V0`0000040?[`iP<00000/`3jl>H10?ooo`008@3jl>H20000
00030?[`iP000000000000D0000000D0n_3V00000000000000000?[`iP04000000/0n_3V1@000009
0?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2
000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@0
00000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H00000
0000003jl>H200000080n_3V0P00000;0?[`iPD000002`3jl>H2000000<0n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000;80
n_3V0@3oool00280n_3V0`00000X0?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V
0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V
0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP@00000
6`3jl>H2000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP00000000000;80n_3V0@3oool00280n_3V0`0000090?[`iP030000003j
l>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H4000000<0n_3V1@00
00020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P00
00020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP@000003@3jl>H5000000/0n_3V
0P0000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H000000000002b0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000009`3j
l>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3j
l>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000
0`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP80
00006`3jl>H2000000@0n_3V0`0000030?[`iP80000000<0n_3V0000000000000`3jl>H300000;<0
n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V00000000
0000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V00000000
0000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H50000
00<0n_3V1@00000K0?[`iP8000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V000000000000/P3jl>H10?ooo`00C@3jl>H200000003
0?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2000003P0
n_3V100000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H000000000002b0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V
0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000b0?[`iP800000103jl>H3000000@0n_3V
0`0000040?[`iP<00000/`3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool001d0n_3V9P3oon02000006`0oooP0P0000040?ooh0800000103oon02000006/0
oooP1@00001Y0?ooh0D000000P3oon02000000@0oooP0P00001[0?ooh0@000008`3oon0N0?[`iP40
oooo000M0?[`iRD0oooP00@000000?ooh03oon000000JP3oon0010000000oooP0?ooh00000080?oo
h0040000003oon00oooP000006`0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh007
0?ooh0040000003oon00oooP000006X0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M
0?[`iRD0oooP00@000000?ooh03oon000000JP3oon0010000000oooP0?ooh000000;0?ooh0030000
003oon00oooP06X0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh00:0?ooh0030000
003oon00oooP06T0oooP00<000000?ooh03oon008`3oon0N0?[`iP40oooo000M0?[`iRD0oooP00@0
00000?ooh03oon000000JP3oon0010000000oooP0?ooh00000090?ooh0800000K@3oon000`000000
oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP0P00001]0?ooh0030000003oon00oooP0280
oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03o
on0000002@3oon000`000000oooP0?ooh01/0?ooh0030000003oon00oooP06/0oooP00<000000?oo
h03oon00203oon000`000000oooP0?ooh01Z0?ooh0040000003oon00oooP000002<0oooP7P3jl>H1
0?ooo`007@3jl>HV0?ooh0800000K03oon02000000X0oooP0`00001[0?ooh0800000K03oon020000
00X0oooP0`00001[0?ooh0800000903oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh?l00000jP00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0
oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00
L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?oo
h03oon00203oon0D00000?l0oooPbP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP00L0oooP9000003o0?ooh;/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon00
1P3oon04000000H0oooP0P00000J0000oa800000o`3oon2^0?ooh0@00000603oon0N0?[`iP40oooo
000M0?[`iPX0oooP100000040?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon00203o
on0K000000P0003o4P00003o0?ooh:T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh140cHDo4@00000:
0000o`l00000o`3oon2R0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?oo
h0800000203oon000`000000oooP0?ooh0090?ooh200cHDo300000090000o``00000o`3oon2L0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP:P3=QCl;000000P0003o2P00003o0?ooh9H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon0b0<f5?`/000001@000?l:00000?l0oooP
T@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh3T0cHDo2@0000050000o`X00000o`3oon2<0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP?`3=QCl8000000D0003o2@00003o
0?ooh8P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon150<f5?`L000001@000?l900000?l0oooPP`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh4X0cHDo1`0000050000o`P0
0000o`3oon1o0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooPC`3=QCl7000000@0003o2000003o0?ooh7/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1D0<f5?`H000001@00
0?l600000?l0oooPN03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh5P0cHDo1`0000040000o`H00000o`3oon1d0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPG03=QCl70000
00@0003o1P00003o0?ooh700oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP0`0000090?ooh600cHDo1`0000030000o`H00000o`3oon1[0?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1T0<f5?`H0000010000?l600000?l0oooP
J@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh6P0cHDo1P0000030000o`H00000o`3oon1V0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPJ`3=QCl6000000@0003o1@00003o
0?ooh6<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon1^0<f5?`L000000`000?l500000?l0oooPH03oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh780cHDo1P0000030000o`D0
0000o`3oon1M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooPM@3=QCl600000080003o1P00003o0?ooh5X0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1h0<f5?`D000000`00
0?l600000?l0oooPE`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh7/0cHDo1@0000030000o`H00000o`3oon1D0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPOP3=QCl50000
0080003o1P00003o0?ooh580oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon210<f5?`@000000`000?l600000?l0oooPC`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh8@0cHDo
100000030000o`H00000o`3oon1<0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooPQ`3=QCl4000000<0003o1@00003o0?ooh4X0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2:
0<f5?`@000000P000?l600000?l0oooPA`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon03000000T0oooPS03=QCl4000000<0003o1@00003o0?ooh4<0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh8l0cHDo100000030000o`@0
0000o`3oon130?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooPT@3=QCl500000080003o1@00003o0?ooh400oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2D0<f5?`@000000`00
0?l500000?l0oooP?@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh0090?ooh9H0cHDo1@0000030000o`@00000o`3oon0k0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPV@3=QCl50000
0080003o1000003o0?ooh3T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon2K0<f5?`D000000P000?l500000?l0oooP=P3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh9h0cHDo
100000020000o`D00000o`3oon0d0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooPX03=QCl400000080003o1@00003o0?ooh380oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2R
0<f5?`@000000`000?l400000?l0oooP<03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh:D0cHDo100000020000o`@00000o`3oon0^0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooPY`3=QCl400000080003o1000003o0?ooh2`0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2Y0<f5?`@000000P000?l500000?l0oooP
:@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh:`0cHDo0`0000030000o`@00000o`3oon0W0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP[P3=QCl400000080003o1000003o
0?ooh2D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?oo
h;00cHDo100000020000o`@00000o`3oon0Q0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon2b0<f5?`@000000P000?l400000?l0oooP8@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh;@0cHDo
100000020000o`@00000o`3oon0O0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooP]P3=QCl400000080003o1000003o0?ooh1d0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2h
0<f5?`@000000P000?l400000?l0oooP6`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh;X0cHDo100000020000o`@00000o`3oon0I0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP_03=QCl400000080003o1000003o0?ooh1L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2n0<f5?`@000000P000?l400000?l0oooP
5@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh<00cHDo100000020000o`<00000o`3oon0D0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP`P3=QCl400000080003o0`00003o
0?ooh180oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon002@3oon340<f5?`@000000P000?l300000?l0oooP403oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh<H0cHDo100000000`000?l0
00000000000200000?l0oooP3P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh<P0cHDo0`0000020000o`@00000o`3oon0<0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPbP3=
QCl300000080003o1000003o0?ooh0X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`0000090?ooh</0cHDo100000000`000?l000000000000200000?l0oooP1`3oon03
000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPc@3=QCl30000
0080003o1000003o0?ooh0L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon3?0<f5?`<000000P000?l400000?l0oooP1@3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=40cHDo
0`0000020000o`@00000o`3oon030?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP00T0oooPd`3=QCl3000000030000o`000000000000800000o`3o
on020?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPe03=QCl300000080003o1000003o0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPeP3=QCl300000080003o1000003m0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooPf03=QCl300000080003o0`00003l0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPfP3=QCl3000000030000o`000000000000800000
nP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh=`0cHDo0P0000020000o`@00000n03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=d0cHDo0`0000020000o`<00000m`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h=l0cHDo0`0000000`000?l000000000000200000?D0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP00T0oooPh03=QCl300000080
003o1000003c0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000
003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon3R0<f5?`<000000P000?l300000?80
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon00
00001`3oon04000000P0oooPi`0000020000onP00000203oon04000001P0oooP7P3jl>H10?ooo`00
7@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00k`3oon0300000003
0000o`000000000000800000h`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00l03oon0300000080
003o0`00003R03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP
0P0000080?ooh0030000003oon00oooP0?80oooP0`0000000`000?l000000000000200000>00<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03c0?ooh0<000000P000?l300000=l0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03e0?ooh0<0000000<0003o0000000000000P00003M
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00m`3oon0200000080003o0`00003L03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n03oon03000000030000o`00000000000080
0000fP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?X0oooP0P0000000`000?l000000000000200000=T0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03k0?ooh08000000P00
0?l400000=L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03m0?ooh080000000<0003o0000000000000P00003F03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00oP3oon020000
0080003o1000003D03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon010?ooh080000000<0003o0000000000000`00003B03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon020?ooh08000000P000?l400000=40<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0@0oooP0P0000000`000?l000000000
000200000=00<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03
00000?l0oooP1@3oon0200000080003o1000003>03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0L0oooP0P0000000`000?l00000000000020000
0<d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh0P0oooP0P0000020000o`@00000b`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP2P3oon02000000030000
o`000000000000800000bP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP2`3oon0200000080003o0`00003903>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0=
0?ooh080000000<0003o0000000000000P00003703>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0>0?ooh08000000P000?l30000
0<H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh100oooP0P0000000`000?l000000000000200000<@0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh140oooP
0P0000020000o`<00000``0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP4P3oon03000000030000o`000000000000800000`@0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP503oon0200000080003o0`00003003>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0E0?ooh0<0000000@0003o0000
000000000000_`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP5`3oon0200000080003o0`00002m03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0H0?ooh0<0
000000@0003o0000000000000000_00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0<00000o`3oon0I0?ooh0<000000P000?l300000;X0<j7:2@3oon03000001P0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP6`3oon03000000040000
o`000000000000000;T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh1`0oooP0`00000010000?l0000000000000002h03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0M0?ooh0<000000P000?l300000;H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1l0oooP0`00000010000?l000000000
0000002e03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0P0?ooh0<0000000@0003o0000000000000000]00cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP8@3o
on0300000080003o0P00002c03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0S0?ooh0<0000000@0003o0000000000000000/@0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP903oon03000000040000o`000000000000000;00<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2D0oooP0`000002
0000o`800000[`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP9`3oon03000000040000o`000000000000000:d0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h2P0oooP0`00000010000?l0000000000000002/03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0Y0?ooh0<000000P000?l20000
0:/0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh2/0oooP0`00000010000?l0000000000000002Y03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh2`0oooP0`00000010000?l0
000000000000002X03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh2d0oooP0`0000020000o`800000Y`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP;`3oon03000000030000
o`00000000000:H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh300oooP0`00000010000?l0000000000000002T03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on0a0?ooh0<0000000@0003o0000000000000000X`0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<P3oon0300000080003o0P00
002R03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0d0?ooh0<0000000<0003o000000000000X@0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP=@3oon030000
00030000o`00000000000:00<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh3H0oooP0`0000020000o`800000WP0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
=`3oon04000000030000o`000000000009d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3T0oooP0`0000000`000?l000000000
002L03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0j0?ooh0<0000000<0003o000000000000V`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>`3oon030000
0080003o00<0000003>QbP0cXLX0V00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP?03oon04000000030000o`000000000009P0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh3d0oooP100000000`000?l000000000002G03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh3l0oooP0`0000000`000?l000000000
002F03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh400oooP0`0000000`000?l000000000002E03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon110?ooh0<0000000@0003o0000
000000000000T`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP@P3oon0300000080003o0P00002B03>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon130?ooh0@0
000000<0003o000000000000T@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPA@3oon03000000030000o`00000000000900<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh4H0oooP0`0000000`000?l000000000002?03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon170?ooh0<0000000@0003o
0000000000000000S@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPB03oon03000000040000o`0000000000000008`0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh4T0oooP0`00000010000?l0000000000000002;03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1;0?ooh080000000@0003o
0000000000000000RP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPC03oon02000000040000o`0000000000000008T0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<00000
0?ooh03oon00o`3oon1=0?ooh08000000P000?l2000008P0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP
0?l0oooPCP3oon03000000040000o`0000000000000008H0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon1>0?oo
h0<0000000@0003o0000000000000000Q@0cXLX80?ooh0@00000603oon0N0?[`iP40oooo000M0?[`
iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh500oooP0`0000001000
0?l0000000000000002403>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh580oooP0P0000001000
0?l0000000000000002303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPD`3oon02000000040000o`0000000000
00000880<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh5@0oooP0P00000010000?l0000000000000002103>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1E0?oo
h080000000@0003o0000000000000000P00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPEP3oon02000000040000o`0000000000
000007l0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh5L0oooP0P0000020000o`800000OP0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF03oon0300000004
0000o`0000000000000007`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh5X0oooP0P00000010000?l0000000000000001k03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1K0?ooh080000000@0003o0000000000000000NP0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPG03oon0200000004
0000o`0000000000000007T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh5d0oooP0P00000010000?l0000000000000001h03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1N0?ooh080000000@0003o0000000000000000M`0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon1O0?ooh080000000@0003o00000000
00000000MP0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1P0?ooh080000000@0003o0000000000000000M@0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPHP3oon000`000000
003o0000o`02000007@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh680oooP0`0000000`000?l000000000001c03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on1S0?ooh0<0000000<0003o000000000000LP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI@3oon02000000040000o`000000
000000000700<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh6H0oooP0P00000010000?l0000000000000001_03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1W
0?ooh080000000@0003o0000000000000000KP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ03oon02000000040000o`000000
0000000006d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh6T0oooP0P00000010000?l0000000000000001/03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Z
0?ooh080000000@0003o0000000000000000J`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJ`3oon02000000040000o`000000
0000000006X0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh6`0oooP0P00000010000?l0000000000000001Y03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1]
0?ooh080000000@0003o0000000000000000J00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPKP3oon02000000040000o`000000
0000000006L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon03
00000?l0oooPK`3oon0200000080003o0P00001V03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh700oooP0`0000000`000?l000000000001U03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1a0?ooh0<0000000<0003o000000000000I00cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPLP3oon03000000030000
o`000000000006<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh7<0oooP0`0000000`000?l000000000001R03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1d
0?ooh0<0000000<0003o000000000000H@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPMP3oon02000000030000o`0000000000
0600<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh7L0oooP0P0000000`000?l000000000001O03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1g0?ooh0<00000
00<0003o000000000000GP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPN03oon03000000030000o`000000000005d0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7T0oooP0`0000000`000?l000000000001L03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1k0?ooh080000000<0003o0000
00000000F`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPN`3oon03000000030000o`000000000005X0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7`0oooP
0`0000000`000?l000000000001I03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP0`00003o0?ooh7d0oooP0`0000000`000?l000000000001H03>QbPT0oooP0`00
000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7l0oooP0P000000
0`000?l000000000001G03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1o0?ooh0<0000000<0003o000000000000EP0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPP03oon03000000030000o`000000000005D0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh880oooP0P0000000`000?l00000
0000001D03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon220?ooh0<0000000<0003o000000000000D`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPP`3oon03
000000030000o`00000000000580<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8D0oooP0P0000000`000?l000000000001A03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon260?ooh080000000<0003o000000000000D00cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQP3oon03000000030000
o`000000000004l0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8L0oooP0`0000000`000?l000000000001>03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon28
0?ooh0<0000000<0003o000000000000C@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPR@3oon03000000030000o`0000000000
04`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh8X0oooP0`0000000`000?l000000000001;03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh8/0oooP0`0000000`000?l00000
0000001:03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh8`0oooP0`0000000`000?l000000000001903>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2=0?ooh0<0000000<0003o
000000000000B00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPSP3oon03000000030000o`000000000004L0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8l0
oooP0`0000000`000?l000000000001603>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2@0?ooh080000000@0003o000000000000
0000A@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPT@3oon02000000040000o`0000000000000004@0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh980oooP
0P00000010000?l0000000000000001303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2C0?ooh080000000@0003o000000000000
0000@P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPU03oon02000000030000o`00000000000480<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9D0oooP0P00
000010000?l0000000000000001003>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2F0?ooh080000000@0003o0000000000000000
?`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPU`3oon02000000030000o`000000000003l0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V403oon04000000L0oooP00<000000?ooh03oon00o`3oon2H
0?ooh080000000<0003o000000000000?P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>H@0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00o`3oon2I0?oo
h080000000<0003o000000000000?@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HA0?ooh0030000003oon00oooP00L0oooP1000003o0?ooh9T0oooP00<000000000o`00
00000P00000l03>QbPP0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP
0?ooh0060?ooh0030000003oon00oooP0?l0oooPV`3oon000`000000003o00000002000003/0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?oo
h00000070?ooh0030000003oon00oooP0?l0oooPW03oon000`000000003o00000002000003X0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<0
00000?ooh03oon00o`3oon2L0?ooh080000000@0003o0000000000000000>@0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW@3o
on02000000040000o`0000000000000003P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9h0oooP0P00000010000?l000000000
0000000g03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2O0?ooh080000000@0003o0000000000000000=P0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX03o
on02000000040000o`0000000000000003D0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:40oooP0P00000010000?l000000000
0000000d03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2R0?ooh080000000@0003o0000000000000000<`0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPX`3o
on02000000040000o`000000000000000380<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:@0oooP0P00000010000?l000000000
0000000a03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2U0?ooh080000000<0003o000000000000<@0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPYP3oon02
000000030000o`00000000000300<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon0300000?l0oooPY`3oon02000000030000o`000000000002l0<j7:2@3oon030000
01P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ03oon0200000003
0000o`000000000002h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh:P0oooP0P00000010000?l0000000000000000]03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2Y0?ooh080000000@0003o0000000000000000;00cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZP3oon02000000040000
o`0000000000000002/0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh:/0oooP0P00000010000?l0000000000000000Z03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2/0?ooh080000000<0003o000000000000:P0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[@3oon02000000030000o`00
0000000002T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:h0oooP0P0000000`000?l000000000000X03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2_0?oo
h080000000<0003o0000000000009`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/03oon02000000030000o`000000000002H0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh;40oooP0P0000000`000?l000000000000U03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh0<0000000<0
003o000000000000900cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP/P3oon03000000030000o`000000000002<0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP/`3oon030000
00030000o`00000000000280<j7:2@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP]03oon03000000030000o`000000<j7:0240<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;D0oooP
0P0000000`000?l000000000000Q03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2f0?ooh080000000<0003o000000000000800c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP]`3oon02000000030000o`000000000001l0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;P0oooP0P0000000`00
0?l000000000000N03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2h0?ooh0<0000000<0003o0000000000007@0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
^@3oon03000000030000o`000000000001`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;X0oooP0P00000010000?l000000000
0000000K03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2k0?ooh080000000<0003o0000000000006`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_03oon02
000000030000o`000000000001X0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;d0oooP0P0000000`000?l000000000000I03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2n0?ooh080000000<0003o000000000000600cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_P3oon03000000030000
o`000000000001L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;l0oooP0P00000010000?l0000000000000000F03>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh<00oooP0P00
000010000?l0000000000000000E03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<40oooP0P0000000`000?l000000000000E03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon32
0?ooh080000000<0003o000000000000500cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP``3oon02000000030000o`0000000000
01<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh<<0oooP0`0000000`000?l000000000000B03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon340?ooh0800000
00@0003o00000000000000004@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa@3oon02000000040000o`000000000000000100
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<H0oooP0P00000010000?l0000000000000000?03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon370?ooh0800000
00<0003o0000000000003`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPb03oon02000000030000o`000000000000h0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<T0oooP0P0000000`000?l000000000000=03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?ooh080000000@0003o0000
000000000000300cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPbP3oon02000000040000o`0000000000000000/0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h</0oooP0P00000010000?l0000000000000000:03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh<`0oooP0P0000000`000?l000000000000:03>Q
bPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<d0
oooP0P0000000`000?l000000000000903>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3>0?ooh080000000<0003o000000000000
200cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPc`3oon02000000030000o`000000000000L0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<l0oooP0P000000
0`000?l000000000000703>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon3@0?ooh080000000<0003o0000000000001P0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPd@3oon02000000030000o`000000000000D0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=80oooP0P0000000`000?l00000
0000000403>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon3B0?ooh0<0000000<0003o0000000000000`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd`3oon03
000000030000o`00000000000080<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=@0oooP0`00000010000?l0000003>QbP0cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPe@3oon02000000040000o`000000000003>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPeP3oon020000
00030000o`000000000000/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00
oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh=L0oooP0P0000000`00
0?l000000000000:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh003
0000003oon00oooP00H0oooP1000003o0?ooh=H0oooP0`0000000`000?l000000?ooh0060?ooh0@0
0000603oon0N0?[`iP40oooo000M0?[`iQ<0oooP00<000000?ooh03oon001@3oon000`000000oooP
0?ooh03o0?ooh=P0oooP1000000:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>H@0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3I0?ooh0800000
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<0
00000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000
oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000
003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooPo`00
003Z000001P0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003L0?[`iP@000000P3jl>H800000080n_3V100000001`3jl>H00000000000000000n_3V0000003j
l>H0300000000`3jl>H0000000000004000000040?[`iP0000000000000000P0n_3V1@0000040?[`
iPL0000000<0n_3V0000003jl>H00`0000090?[`iPD000000P3jl>H400000080n_3V1@00000B0?[`
iPH000001P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V0000000000000000i03jl>H1
0?ooo`00g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H2000000<0n_3V00L000000?[`
iP00000000000?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000002@3jl>H010000000n_3V0?[`iP3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00D0
n_3V0P0000000`3jl>H000000000003U0?[`iP40oooo003M0?[`iP80000000<0n_3V000000000000
103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP800000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP800000303jl>H5000000D0n_3V0P0000060?[`iPD0
00001P3jl>H300000>H0n_3V0@3oool00=d0n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`
iP00000000000?[`iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V0P000000103j
l>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P000002
0?[`iP8000000P3jl>H2000001H0n_3V0P0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00003V
0?[`iP40oooo003M0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H20000
00060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00
000000000?[`iP80000000<0n_3V0000003jl>H00P00000;0?[`iP8000000`3jl>H200000080n_3V
0P0000020?[`iP<0000000<0n_3V0000003jl>H04P3jl>H2000000P0n_3V00<000000?[`iP3jl>H0
1@3jl>H2000000030?[`iP00000000000>D0n_3V0@3oool00=d0n_3V0P0000020?[`iP80000000<0
n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3j
l>H500000080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000002`3j
l>H500000080n_3V100000020?[`iP<0000000<0n_3V0000000000004`3jl>H2000000l0n_3V0`00
00001@3jl>H00000000000000000n_3V00@00000g`3jl>H10?ooo`00g@3jl>H200000080n_3V0P00
000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0H0?[`iP8000008@3jl>H4000001P0n_3V00<0
00000?[`iP3jl>H0g`3jl>H10?ooo`00g03jl>H6000000@0n_3V0P00000_0?[`iPD000006`3jl>H3
00000240n_3V0P00000I0?[`iP030000003jl>H0n_3V0=h0n_3V0@3oool00?l0n_3VN03jl>H00`00
0000n_3V0?[`iP3M0?[`iP40oooo003o0?[`iWD0n_3V00@000000?[`iP3jl>H00000g`3jl>H10?oo
o`00o`3jl>If0?[`iP800000h03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02418 .01472 L
.02418 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02418 .01472 L
.02418 .16187 L
s
1 .894 .882 r
.02418 .16187 m
.02418 .01472 L
.02468 .01472 L
.02468 .16187 L
F
.804 .522 .247 r
.02418 .16187 m
.02418 .01472 L
.02468 .01472 L
.02468 .16187 L
s
1 .894 .882 r
.02468 .16187 m
.02468 .01472 L
.02505 .01472 L
.02505 .16187 L
F
.804 .522 .247 r
.02468 .16187 m
.02468 .01472 L
.02505 .01472 L
.02505 .16187 L
s
1 .894 .882 r
.02505 .16187 m
.02505 .01472 L
.02527 .01472 L
.02527 .16187 L
F
.804 .522 .247 r
.02505 .16187 m
.02505 .01472 L
.02527 .01472 L
.02527 .16187 L
s
1 .894 .882 r
.02527 .16187 m
.02527 .01472 L
.02575 .01472 L
.02575 .16187 L
F
.804 .522 .247 r
.02527 .16187 m
.02527 .01472 L
.02575 .01472 L
.02575 .16187 L
s
1 .894 .882 r
.02575 .16187 m
.02575 .01472 L
.026 .01472 L
.026 .16187 L
F
.804 .522 .247 r
.02575 .16187 m
.02575 .01472 L
.026 .01472 L
.026 .16187 L
s
1 .894 .882 r
.026 .16187 m
.026 .01472 L
.0265 .01472 L
.0265 .16187 L
F
.804 .522 .247 r
.026 .16187 m
.026 .01472 L
.0265 .01472 L
.0265 .16187 L
s
1 .894 .882 r
.0265 .16187 m
.0265 .01472 L
.02695 .01472 L
.02695 .16187 L
F
.804 .522 .247 r
.0265 .16187 m
.0265 .01472 L
.02695 .01472 L
.02695 .16187 L
s
1 .894 .882 r
.02695 .16187 m
.02695 .01472 L
.02725 .01472 L
.02725 .16187 L
F
.804 .522 .247 r
.02695 .16187 m
.02695 .01472 L
.02725 .01472 L
.02725 .16187 L
s
1 .894 .882 r
.02725 .16187 m
.02725 .01472 L
.02746 .01472 L
.02746 .16187 L
F
.804 .522 .247 r
.02725 .16187 m
.02725 .01472 L
.02746 .01472 L
.02746 .16187 L
s
1 .894 .882 r
.02746 .16187 m
.02746 .01473 L
.02798 .01473 L
.02798 .16187 L
F
.804 .522 .247 r
.02746 .16187 m
.02746 .01473 L
.02798 .01473 L
.02798 .16187 L
s
1 .894 .882 r
.02798 .16187 m
.02798 .01473 L
.02857 .01473 L
.02857 .16187 L
F
.804 .522 .247 r
.02798 .16187 m
.02798 .01473 L
.02857 .01473 L
.02857 .16187 L
s
1 .894 .882 r
.02857 .16187 m
.02857 .01473 L
.02892 .01473 L
.02892 .16187 L
F
.804 .522 .247 r
.02857 .16187 m
.02857 .01473 L
.02892 .01473 L
.02892 .16187 L
s
1 .894 .882 r
.02892 .16187 m
.02892 .01473 L
.02934 .01473 L
.02934 .16187 L
F
.804 .522 .247 r
.02892 .16187 m
.02892 .01473 L
.02934 .01473 L
.02934 .16187 L
s
1 .894 .882 r
.02934 .16187 m
.02934 .01474 L
.02992 .01474 L
.02992 .16187 L
F
.804 .522 .247 r
.02934 .16187 m
.02934 .01474 L
.02992 .01474 L
.02992 .16187 L
s
1 .894 .882 r
.02992 .16187 m
.02992 .01474 L
.03028 .01474 L
.03028 .16187 L
F
.804 .522 .247 r
.02992 .16187 m
.02992 .01474 L
.03028 .01474 L
.03028 .16187 L
s
1 .894 .882 r
.03028 .16187 m
.03028 .01474 L
.03075 .01474 L
.03075 .16187 L
F
.804 .522 .247 r
.03028 .16187 m
.03028 .01474 L
.03075 .01474 L
.03075 .16187 L
s
1 .894 .882 r
.03075 .16187 m
.03075 .01475 L
.03119 .01475 L
.03119 .16187 L
F
.804 .522 .247 r
.03075 .16187 m
.03075 .01475 L
.03119 .01475 L
.03119 .16187 L
s
1 .894 .882 r
.03119 .16187 m
.03119 .01475 L
.03158 .01475 L
.03158 .16187 L
F
.804 .522 .247 r
.03119 .16187 m
.03119 .01475 L
.03158 .01475 L
.03158 .16187 L
s
1 .894 .882 r
.03158 .16187 m
.03158 .01475 L
.03203 .01475 L
.03203 .16187 L
F
.804 .522 .247 r
.03158 .16187 m
.03158 .01475 L
.03203 .01475 L
.03203 .16187 L
s
1 .894 .882 r
.03203 .16187 m
.03203 .01476 L
.03248 .01476 L
.03248 .16187 L
F
.804 .522 .247 r
.03203 .16187 m
.03203 .01476 L
.03248 .01476 L
.03248 .16187 L
s
1 .894 .882 r
.03248 .16187 m
.03248 .01477 L
.03273 .01477 L
.03273 .16187 L
F
.804 .522 .247 r
.03248 .16187 m
.03248 .01477 L
.03273 .01477 L
.03273 .16187 L
s
1 .894 .882 r
.03273 .16187 m
.03273 .01477 L
.03335 .01477 L
.03335 .16187 L
F
.804 .522 .247 r
.03273 .16187 m
.03273 .01477 L
.03335 .01477 L
.03335 .16187 L
s
1 .894 .882 r
.03335 .16187 m
.03335 .01478 L
.03395 .01478 L
.03395 .16187 L
F
.804 .522 .247 r
.03335 .16187 m
.03335 .01478 L
.03395 .01478 L
.03395 .16187 L
s
1 .894 .882 r
.03395 .16187 m
.03395 .01478 L
.03422 .01478 L
.03422 .16187 L
F
.804 .522 .247 r
.03395 .16187 m
.03395 .01478 L
.03422 .01478 L
.03422 .16187 L
s
1 .894 .882 r
.03422 .16187 m
.03422 .01479 L
.0346 .01479 L
.0346 .16187 L
F
.804 .522 .247 r
.03422 .16187 m
.03422 .01479 L
.0346 .01479 L
.0346 .16187 L
s
1 .894 .882 r
.0346 .16187 m
.0346 .01479 L
.03505 .01479 L
.03505 .16187 L
F
.804 .522 .247 r
.0346 .16187 m
.0346 .01479 L
.03505 .01479 L
.03505 .16187 L
s
1 .894 .882 r
.03505 .16187 m
.03505 .0148 L
.03562 .0148 L
.03562 .16187 L
F
.804 .522 .247 r
.03505 .16187 m
.03505 .0148 L
.03562 .0148 L
.03562 .16187 L
s
1 .894 .882 r
.03562 .16187 m
.03562 .01481 L
.03605 .01481 L
.03605 .16187 L
F
.804 .522 .247 r
.03562 .16187 m
.03562 .01481 L
.03605 .01481 L
.03605 .16187 L
s
1 .894 .882 r
.03605 .16187 m
.03605 .01481 L
.03638 .01481 L
.03638 .16187 L
F
.804 .522 .247 r
.03605 .16187 m
.03605 .01481 L
.03638 .01481 L
.03638 .16187 L
s
1 .894 .882 r
.03638 .16187 m
.03638 .01482 L
.03695 .01482 L
.03695 .16187 L
F
.804 .522 .247 r
.03638 .16187 m
.03638 .01482 L
.03695 .01482 L
.03695 .16187 L
s
1 .894 .882 r
.03695 .16187 m
.03695 .01483 L
.03727 .01483 L
.03727 .16187 L
F
.804 .522 .247 r
.03695 .16187 m
.03695 .01483 L
.03727 .01483 L
.03727 .16187 L
s
1 .894 .882 r
.03727 .16187 m
.03727 .01484 L
.03758 .01484 L
.03758 .16187 L
F
.804 .522 .247 r
.03727 .16187 m
.03727 .01484 L
.03758 .01484 L
.03758 .16187 L
s
1 .894 .882 r
.03758 .16187 m
.03758 .01484 L
.0379 .01484 L
.0379 .16187 L
F
.804 .522 .247 r
.03758 .16187 m
.03758 .01484 L
.0379 .01484 L
.0379 .16187 L
s
1 .894 .882 r
.0379 .16187 m
.0379 .01485 L
.03814 .01485 L
.03814 .16187 L
F
.804 .522 .247 r
.0379 .16187 m
.0379 .01485 L
.03814 .01485 L
.03814 .16187 L
s
1 .894 .882 r
.03814 .16187 m
.03814 .01486 L
.03851 .01486 L
.03851 .16187 L
F
.804 .522 .247 r
.03814 .16187 m
.03814 .01486 L
.03851 .01486 L
.03851 .16187 L
s
1 .894 .882 r
.03851 .16187 m
.03851 .01486 L
.03911 .01486 L
.03911 .16187 L
F
.804 .522 .247 r
.03851 .16187 m
.03851 .01486 L
.03911 .01486 L
.03911 .16187 L
s
1 .894 .882 r
.03911 .16187 m
.03911 .01488 L
.03965 .01488 L
.03965 .16187 L
F
.804 .522 .247 r
.03911 .16187 m
.03911 .01488 L
.03965 .01488 L
.03965 .16187 L
s
1 .894 .882 r
.03965 .16187 m
.03965 .01488 L
.03995 .01488 L
.03995 .16187 L
F
.804 .522 .247 r
.03965 .16187 m
.03965 .01488 L
.03995 .01488 L
.03995 .16187 L
s
1 .894 .882 r
.03995 .16187 m
.03995 .01489 L
.04014 .01489 L
.04014 .16187 L
F
.804 .522 .247 r
.03995 .16187 m
.03995 .01489 L
.04014 .01489 L
.04014 .16187 L
s
1 .894 .882 r
.04014 .16187 m
.04014 .01489 L
.04047 .01489 L
.04047 .16187 L
F
.804 .522 .247 r
.04014 .16187 m
.04014 .01489 L
.04047 .01489 L
.04047 .16187 L
s
1 .894 .882 r
.04047 .16187 m
.04047 .0149 L
.04076 .0149 L
.04076 .16187 L
F
.804 .522 .247 r
.04047 .16187 m
.04047 .0149 L
.04076 .0149 L
.04076 .16187 L
s
1 .894 .882 r
.04076 .16187 m
.04076 .01491 L
.0413 .01491 L
.0413 .16187 L
F
.804 .522 .247 r
.04076 .16187 m
.04076 .01491 L
.0413 .01491 L
.0413 .16187 L
s
1 .894 .882 r
.0413 .16187 m
.0413 .01492 L
.04168 .01492 L
.04168 .16187 L
F
.804 .522 .247 r
.0413 .16187 m
.0413 .01492 L
.04168 .01492 L
.04168 .16187 L
s
1 .894 .882 r
.04168 .16187 m
.04168 .01493 L
.0422 .01493 L
.0422 .16187 L
F
.804 .522 .247 r
.04168 .16187 m
.04168 .01493 L
.0422 .01493 L
.0422 .16187 L
s
1 .894 .882 r
.0422 .16187 m
.0422 .01494 L
.04243 .01494 L
.04243 .16187 L
F
.804 .522 .247 r
.0422 .16187 m
.0422 .01494 L
.04243 .01494 L
.04243 .16187 L
s
1 .894 .882 r
.04243 .16187 m
.04243 .01495 L
.04299 .01495 L
.04299 .16187 L
F
.804 .522 .247 r
.04243 .16187 m
.04243 .01495 L
.04299 .01495 L
.04299 .16187 L
s
1 .894 .882 r
.04299 .16187 m
.04299 .01496 L
.04341 .01496 L
.04341 .16187 L
F
.804 .522 .247 r
.04299 .16187 m
.04299 .01496 L
.04341 .01496 L
.04341 .16187 L
s
1 .894 .882 r
.04341 .16187 m
.04341 .01497 L
.04384 .01497 L
.04384 .16187 L
F
.804 .522 .247 r
.04341 .16187 m
.04341 .01497 L
.04384 .01497 L
.04384 .16187 L
s
1 .894 .882 r
.04384 .16187 m
.04384 .01499 L
.04434 .01499 L
.04434 .16187 L
F
.804 .522 .247 r
.04384 .16187 m
.04384 .01499 L
.04434 .01499 L
.04434 .16187 L
s
1 .894 .882 r
.04434 .16187 m
.04434 .01499 L
.04465 .01499 L
.04465 .16187 L
F
.804 .522 .247 r
.04434 .16187 m
.04434 .01499 L
.04465 .01499 L
.04465 .16187 L
s
1 .894 .882 r
.04465 .16187 m
.04465 .015 L
.04512 .015 L
.04512 .16187 L
F
.804 .522 .247 r
.04465 .16187 m
.04465 .015 L
.04512 .015 L
.04512 .16187 L
s
1 .894 .882 r
.04512 .16187 m
.04512 .01501 L
.04533 .01501 L
.04533 .16187 L
F
.804 .522 .247 r
.04512 .16187 m
.04512 .01501 L
.04533 .01501 L
.04533 .16187 L
s
1 .894 .882 r
.04533 .16187 m
.04533 .01502 L
.04568 .01502 L
.04568 .16187 L
F
.804 .522 .247 r
.04533 .16187 m
.04533 .01502 L
.04568 .01502 L
.04568 .16187 L
s
1 .894 .882 r
.04568 .16187 m
.04568 .01503 L
.04606 .01503 L
.04606 .16187 L
F
.804 .522 .247 r
.04568 .16187 m
.04568 .01503 L
.04606 .01503 L
.04606 .16187 L
s
1 .894 .882 r
.04606 .16187 m
.04606 .01504 L
.0464 .01504 L
.0464 .16187 L
F
.804 .522 .247 r
.04606 .16187 m
.04606 .01504 L
.0464 .01504 L
.0464 .16187 L
s
1 .894 .882 r
.0464 .16187 m
.0464 .01506 L
.04693 .01506 L
.04693 .16187 L
F
.804 .522 .247 r
.0464 .16187 m
.0464 .01506 L
.04693 .01506 L
.04693 .16187 L
s
1 .894 .882 r
.04693 .16187 m
.04693 .01507 L
.04716 .01507 L
.04716 .16187 L
F
.804 .522 .247 r
.04693 .16187 m
.04693 .01507 L
.04716 .01507 L
.04716 .16187 L
s
1 .894 .882 r
.04716 .16187 m
.04716 .01507 L
.04748 .01507 L
.04748 .16187 L
F
.804 .522 .247 r
.04716 .16187 m
.04716 .01507 L
.04748 .01507 L
.04748 .16187 L
s
1 .894 .882 r
.04748 .16187 m
.04748 .01508 L
.0481 .01508 L
.0481 .16187 L
F
.804 .522 .247 r
.04748 .16187 m
.04748 .01508 L
.0481 .01508 L
.0481 .16187 L
s
1 .894 .882 r
.0481 .16187 m
.0481 .01511 L
.04867 .01511 L
.04867 .16187 L
F
.804 .522 .247 r
.0481 .16187 m
.0481 .01511 L
.04867 .01511 L
.04867 .16187 L
s
1 .894 .882 r
.04867 .16187 m
.04867 .01512 L
.049 .01512 L
.049 .16187 L
F
.804 .522 .247 r
.04867 .16187 m
.04867 .01512 L
.049 .01512 L
.049 .16187 L
s
1 .894 .882 r
.049 .16187 m
.049 .01513 L
.04921 .01513 L
.04921 .16187 L
F
.804 .522 .247 r
.049 .16187 m
.049 .01513 L
.04921 .01513 L
.04921 .16187 L
s
1 .894 .882 r
.04921 .16187 m
.04921 .01514 L
.04983 .01514 L
.04983 .16187 L
F
.804 .522 .247 r
.04921 .16187 m
.04921 .01514 L
.04983 .01514 L
.04983 .16187 L
s
1 .894 .882 r
.04983 .16187 m
.04983 .01515 L
.05026 .01515 L
.05026 .16187 L
F
.804 .522 .247 r
.04983 .16187 m
.04983 .01515 L
.05026 .01515 L
.05026 .16187 L
s
1 .894 .882 r
.05026 .16187 m
.05026 .01518 L
.05049 .01518 L
.05049 .16187 L
F
.804 .522 .247 r
.05026 .16187 m
.05026 .01518 L
.05049 .01518 L
.05049 .16187 L
s
1 .894 .882 r
.05049 .16187 m
.05049 .01519 L
.0508 .01519 L
.0508 .16187 L
F
.804 .522 .247 r
.05049 .16187 m
.05049 .01519 L
.0508 .01519 L
.0508 .16187 L
s
1 .894 .882 r
.0508 .16187 m
.0508 .0152 L
.05123 .0152 L
.05123 .16187 L
F
.804 .522 .247 r
.0508 .16187 m
.0508 .0152 L
.05123 .0152 L
.05123 .16187 L
s
1 .894 .882 r
.05123 .16187 m
.05123 .01521 L
.05178 .01521 L
.05178 .16187 L
F
.804 .522 .247 r
.05123 .16187 m
.05123 .01521 L
.05178 .01521 L
.05178 .16187 L
s
1 .894 .882 r
.05178 .16187 m
.05178 .01523 L
.05241 .01523 L
.05241 .16187 L
F
.804 .522 .247 r
.05178 .16187 m
.05178 .01523 L
.05241 .01523 L
.05241 .16187 L
s
1 .894 .882 r
.05241 .16187 m
.05241 .01525 L
.0528 .01525 L
.0528 .16187 L
F
.804 .522 .247 r
.05241 .16187 m
.05241 .01525 L
.0528 .01525 L
.0528 .16187 L
s
1 .894 .882 r
.0528 .16187 m
.0528 .01527 L
.05301 .01527 L
.05301 .16187 L
F
.804 .522 .247 r
.0528 .16187 m
.0528 .01527 L
.05301 .01527 L
.05301 .16187 L
s
1 .894 .882 r
.05301 .16187 m
.05301 .01527 L
.05332 .01527 L
.05332 .16187 L
F
.804 .522 .247 r
.05301 .16187 m
.05301 .01527 L
.05332 .01527 L
.05332 .16187 L
s
1 .894 .882 r
.05332 .16187 m
.05332 .01529 L
.05364 .01529 L
.05364 .16187 L
F
.804 .522 .247 r
.05332 .16187 m
.05332 .01529 L
.05364 .01529 L
.05364 .16187 L
s
1 .894 .882 r
.05364 .16187 m
.05364 .0153 L
.05391 .0153 L
.05391 .16187 L
F
.804 .522 .247 r
.05364 .16187 m
.05364 .0153 L
.05391 .0153 L
.05391 .16187 L
s
1 .894 .882 r
.05391 .16187 m
.05391 .01531 L
.05428 .01531 L
.05428 .16187 L
F
.804 .522 .247 r
.05391 .16187 m
.05391 .01531 L
.05428 .01531 L
.05428 .16187 L
s
1 .894 .882 r
.05428 .16187 m
.05428 .01532 L
.05458 .01532 L
.05458 .16187 L
F
.804 .522 .247 r
.05428 .16187 m
.05428 .01532 L
.05458 .01532 L
.05458 .16187 L
s
1 .894 .882 r
.05458 .16187 m
.05458 .01533 L
.05518 .01533 L
.05518 .16187 L
F
.804 .522 .247 r
.05458 .16187 m
.05458 .01533 L
.05518 .01533 L
.05518 .16187 L
s
1 .894 .882 r
.05518 .16187 m
.05518 .01536 L
.05572 .01536 L
.05572 .16187 L
F
.804 .522 .247 r
.05518 .16187 m
.05518 .01536 L
.05572 .01536 L
.05572 .16187 L
s
1 .894 .882 r
.05572 .16187 m
.05572 .01538 L
.05593 .01538 L
.05593 .16187 L
F
.804 .522 .247 r
.05572 .16187 m
.05572 .01538 L
.05593 .01538 L
.05593 .16187 L
s
1 .894 .882 r
.05593 .16187 m
.05593 .01539 L
.05634 .01539 L
.05634 .16187 L
F
.804 .522 .247 r
.05593 .16187 m
.05593 .01539 L
.05634 .01539 L
.05634 .16187 L
s
1 .894 .882 r
.05634 .16187 m
.05634 .01541 L
.0569 .01541 L
.0569 .16187 L
F
.804 .522 .247 r
.05634 .16187 m
.05634 .01541 L
.0569 .01541 L
.0569 .16187 L
s
1 .894 .882 r
.0569 .16187 m
.0569 .01544 L
.05731 .01544 L
.05731 .16187 L
F
.804 .522 .247 r
.0569 .16187 m
.0569 .01544 L
.05731 .01544 L
.05731 .16187 L
s
1 .894 .882 r
.05731 .16187 m
.05731 .01545 L
.05754 .01545 L
.05754 .16187 L
F
.804 .522 .247 r
.05731 .16187 m
.05731 .01545 L
.05754 .01545 L
.05754 .16187 L
s
1 .894 .882 r
.05754 .16187 m
.05754 .01546 L
.05803 .01546 L
.05803 .16187 L
F
.804 .522 .247 r
.05754 .16187 m
.05754 .01546 L
.05803 .01546 L
.05803 .16187 L
s
1 .894 .882 r
.05803 .16187 m
.05803 .01549 L
.05844 .01549 L
.05844 .16187 L
F
.804 .522 .247 r
.05803 .16187 m
.05803 .01549 L
.05844 .01549 L
.05844 .16187 L
s
1 .894 .882 r
.05844 .16187 m
.05844 .01551 L
.05884 .01551 L
.05884 .16187 L
F
.804 .522 .247 r
.05844 .16187 m
.05844 .01551 L
.05884 .01551 L
.05884 .16187 L
s
1 .894 .882 r
.05884 .16187 m
.05884 .01551 L
.05908 .01551 L
.05908 .16187 L
F
.804 .522 .247 r
.05884 .16187 m
.05884 .01551 L
.05908 .01551 L
.05908 .16187 L
s
1 .894 .882 r
.05908 .16187 m
.05908 .01553 L
.05933 .01553 L
.05933 .16187 L
F
.804 .522 .247 r
.05908 .16187 m
.05908 .01553 L
.05933 .01553 L
.05933 .16187 L
s
1 .894 .882 r
.05933 .16187 m
.05933 .01553 L
.05971 .01553 L
.05971 .16187 L
F
.804 .522 .247 r
.05933 .16187 m
.05933 .01553 L
.05971 .01553 L
.05971 .16187 L
s
1 .894 .882 r
.05971 .16187 m
.05971 .01556 L
.05998 .01556 L
.05998 .16187 L
F
.804 .522 .247 r
.05971 .16187 m
.05971 .01556 L
.05998 .01556 L
.05998 .16187 L
s
1 .894 .882 r
.05998 .16187 m
.05998 .01558 L
.06044 .01558 L
.06044 .16187 L
F
.804 .522 .247 r
.05998 .16187 m
.05998 .01558 L
.06044 .01558 L
.06044 .16187 L
s
1 .894 .882 r
.06044 .16187 m
.06044 .01559 L
.06077 .01559 L
.06077 .16187 L
F
.804 .522 .247 r
.06044 .16187 m
.06044 .01559 L
.06077 .01559 L
.06077 .16187 L
s
1 .894 .882 r
.06077 .16187 m
.06077 .01562 L
.06116 .01562 L
.06116 .16187 L
F
.804 .522 .247 r
.06077 .16187 m
.06077 .01562 L
.06116 .01562 L
.06116 .16187 L
s
1 .894 .882 r
.06116 .16187 m
.06116 .01563 L
.06168 .01563 L
.06168 .16187 L
F
.804 .522 .247 r
.06116 .16187 m
.06116 .01563 L
.06168 .01563 L
.06168 .16187 L
s
1 .894 .882 r
.06168 .16187 m
.06168 .01566 L
.06212 .01566 L
.06212 .16187 L
F
.804 .522 .247 r
.06168 .16187 m
.06168 .01566 L
.06212 .01566 L
.06212 .16187 L
s
1 .894 .882 r
.06212 .16187 m
.06212 .01567 L
.06234 .01567 L
.06234 .16187 L
F
.804 .522 .247 r
.06212 .16187 m
.06212 .01567 L
.06234 .01567 L
.06234 .16187 L
s
1 .894 .882 r
.06234 .16187 m
.06234 .01568 L
.06259 .01568 L
.06259 .16187 L
F
.804 .522 .247 r
.06234 .16187 m
.06234 .01568 L
.06259 .01568 L
.06259 .16187 L
s
1 .894 .882 r
.06259 .16187 m
.06259 .0157 L
.06304 .0157 L
.06304 .16187 L
F
.804 .522 .247 r
.06259 .16187 m
.06259 .0157 L
.06304 .0157 L
.06304 .16187 L
s
1 .894 .882 r
.06304 .16187 m
.06304 .01571 L
.0633 .01571 L
.0633 .16187 L
F
.804 .522 .247 r
.06304 .16187 m
.06304 .01571 L
.0633 .01571 L
.0633 .16187 L
s
1 .894 .882 r
.0633 .16187 m
.0633 .01574 L
.06385 .01574 L
.06385 .16187 L
F
.804 .522 .247 r
.0633 .16187 m
.0633 .01574 L
.06385 .01574 L
.06385 .16187 L
s
1 .894 .882 r
.06385 .16187 m
.06385 .01576 L
.06414 .01576 L
.06414 .16187 L
F
.804 .522 .247 r
.06385 .16187 m
.06385 .01576 L
.06414 .01576 L
.06414 .16187 L
s
1 .894 .882 r
.06414 .16187 m
.06414 .0158 L
.06468 .0158 L
.06468 .16187 L
F
.804 .522 .247 r
.06414 .16187 m
.06414 .0158 L
.06468 .0158 L
.06468 .16187 L
s
1 .894 .882 r
.06468 .16187 m
.06468 .0158 L
.06493 .0158 L
.06493 .16187 L
F
.804 .522 .247 r
.06468 .16187 m
.06468 .0158 L
.06493 .0158 L
.06493 .16187 L
s
1 .894 .882 r
.06493 .16187 m
.06493 .01582 L
.06526 .01582 L
.06526 .16187 L
F
.804 .522 .247 r
.06493 .16187 m
.06493 .01582 L
.06526 .01582 L
.06526 .16187 L
s
1 .894 .882 r
.06526 .16187 m
.06526 .01584 L
.06563 .01584 L
.06563 .16187 L
F
.804 .522 .247 r
.06526 .16187 m
.06526 .01584 L
.06563 .01584 L
.06563 .16187 L
s
1 .894 .882 r
.06563 .16187 m
.06563 .01587 L
.06595 .01587 L
.06595 .16187 L
F
.804 .522 .247 r
.06563 .16187 m
.06563 .01587 L
.06595 .01587 L
.06595 .16187 L
s
1 .894 .882 r
.06595 .16187 m
.06595 .01588 L
.06616 .01588 L
.06616 .16187 L
F
.804 .522 .247 r
.06595 .16187 m
.06595 .01588 L
.06616 .01588 L
.06616 .16187 L
s
1 .894 .882 r
.06616 .16187 m
.06616 .0159 L
.06665 .0159 L
.06665 .16187 L
F
.804 .522 .247 r
.06616 .16187 m
.06616 .0159 L
.06665 .0159 L
.06665 .16187 L
s
1 .894 .882 r
.06665 .16187 m
.06665 .01593 L
.06724 .01593 L
.06724 .16187 L
F
.804 .522 .247 r
.06665 .16187 m
.06665 .01593 L
.06724 .01593 L
.06724 .16187 L
s
1 .894 .882 r
.06724 .16187 m
.06724 .01595 L
.0678 .01595 L
.0678 .16187 L
F
.804 .522 .247 r
.06724 .16187 m
.06724 .01595 L
.0678 .01595 L
.0678 .16187 L
s
1 .894 .882 r
.0678 .16187 m
.0678 .01598 L
.0684 .01598 L
.0684 .16187 L
F
.804 .522 .247 r
.0678 .16187 m
.0678 .01598 L
.0684 .01598 L
.0684 .16187 L
s
1 .894 .882 r
.0684 .16187 m
.0684 .01601 L
.06884 .01601 L
.06884 .16187 L
F
.804 .522 .247 r
.0684 .16187 m
.0684 .01601 L
.06884 .01601 L
.06884 .16187 L
s
1 .894 .882 r
.06884 .16187 m
.06884 .01604 L
.06924 .01604 L
.06924 .16187 L
F
.804 .522 .247 r
.06884 .16187 m
.06884 .01604 L
.06924 .01604 L
.06924 .16187 L
s
1 .894 .882 r
.06924 .16187 m
.06924 .01607 L
.06972 .01607 L
.06972 .16187 L
F
.804 .522 .247 r
.06924 .16187 m
.06924 .01607 L
.06972 .01607 L
.06972 .16187 L
s
1 .894 .882 r
.06972 .16187 m
.06972 .01609 L
.07005 .01609 L
.07005 .16187 L
F
.804 .522 .247 r
.06972 .16187 m
.06972 .01609 L
.07005 .01609 L
.07005 .16187 L
s
1 .894 .882 r
.07005 .16187 m
.07005 .01611 L
.07035 .01611 L
.07035 .16187 L
F
.804 .522 .247 r
.07005 .16187 m
.07005 .01611 L
.07035 .01611 L
.07035 .16187 L
s
1 .894 .882 r
.07035 .16187 m
.07035 .01613 L
.07055 .01613 L
.07055 .16187 L
F
.804 .522 .247 r
.07035 .16187 m
.07035 .01613 L
.07055 .01613 L
.07055 .16187 L
s
1 .894 .882 r
.07055 .16187 m
.07055 .01614 L
.07115 .01614 L
.07115 .16187 L
F
.804 .522 .247 r
.07055 .16187 m
.07055 .01614 L
.07115 .01614 L
.07115 .16187 L
s
1 .894 .882 r
.07115 .16187 m
.07115 .01619 L
.07168 .01619 L
.07168 .16187 L
F
.804 .522 .247 r
.07115 .16187 m
.07115 .01619 L
.07168 .01619 L
.07168 .16187 L
s
1 .894 .882 r
.07168 .16187 m
.07168 .01622 L
.07195 .01622 L
.07195 .16187 L
F
.804 .522 .247 r
.07168 .16187 m
.07168 .01622 L
.07195 .01622 L
.07195 .16187 L
s
1 .894 .882 r
.07195 .16187 m
.07195 .01624 L
.07254 .01624 L
.07254 .16187 L
F
.804 .522 .247 r
.07195 .16187 m
.07195 .01624 L
.07254 .01624 L
.07254 .16187 L
s
1 .894 .882 r
.07254 .16187 m
.07254 .01627 L
.07288 .01627 L
.07288 .16187 L
F
.804 .522 .247 r
.07254 .16187 m
.07254 .01627 L
.07288 .01627 L
.07288 .16187 L
s
1 .894 .882 r
.07288 .16187 m
.07288 .0163 L
.07334 .0163 L
.07334 .16187 L
F
.804 .522 .247 r
.07288 .16187 m
.07288 .0163 L
.07334 .0163 L
.07334 .16187 L
s
1 .894 .882 r
.07334 .16187 m
.07334 .01632 L
.07369 .01632 L
.07369 .16187 L
F
.804 .522 .247 r
.07334 .16187 m
.07334 .01632 L
.07369 .01632 L
.07369 .16187 L
s
1 .894 .882 r
.07369 .16187 m
.07369 .01635 L
.07419 .01635 L
.07419 .16187 L
F
.804 .522 .247 r
.07369 .16187 m
.07369 .01635 L
.07419 .01635 L
.07419 .16187 L
s
1 .894 .882 r
.07419 .16187 m
.07419 .01639 L
.07463 .01639 L
.07463 .16187 L
F
.804 .522 .247 r
.07419 .16187 m
.07419 .01639 L
.07463 .01639 L
.07463 .16187 L
s
1 .894 .882 r
.07463 .16187 m
.07463 .0164 L
.07504 .0164 L
.07504 .16187 L
F
.804 .522 .247 r
.07463 .16187 m
.07463 .0164 L
.07504 .0164 L
.07504 .16187 L
s
1 .894 .882 r
.07504 .16187 m
.07504 .01642 L
.07524 .01642 L
.07524 .16187 L
F
.804 .522 .247 r
.07504 .16187 m
.07504 .01642 L
.07524 .01642 L
.07524 .16187 L
s
1 .894 .882 r
.07524 .16187 m
.07524 .01643 L
.07556 .01643 L
.07556 .16187 L
F
.804 .522 .247 r
.07524 .16187 m
.07524 .01643 L
.07556 .01643 L
.07556 .16187 L
s
1 .894 .882 r
.07556 .16187 m
.07556 .01645 L
.07587 .01645 L
.07587 .16187 L
F
.804 .522 .247 r
.07556 .16187 m
.07556 .01645 L
.07587 .01645 L
.07587 .16187 L
s
1 .894 .882 r
.07587 .16187 m
.07587 .01649 L
.07626 .01649 L
.07626 .16187 L
F
.804 .522 .247 r
.07587 .16187 m
.07587 .01649 L
.07626 .01649 L
.07626 .16187 L
s
1 .894 .882 r
.07626 .16187 m
.07626 .01651 L
.07662 .01651 L
.07662 .16187 L
F
.804 .522 .247 r
.07626 .16187 m
.07626 .01651 L
.07662 .01651 L
.07662 .16187 L
s
1 .894 .882 r
.07662 .16187 m
.07662 .01654 L
.07698 .01654 L
.07698 .16187 L
F
.804 .522 .247 r
.07662 .16187 m
.07662 .01654 L
.07698 .01654 L
.07698 .16187 L
s
1 .894 .882 r
.07698 .16187 m
.07698 .01657 L
.07737 .01657 L
.07737 .16187 L
F
.804 .522 .247 r
.07698 .16187 m
.07698 .01657 L
.07737 .01657 L
.07737 .16187 L
s
1 .894 .882 r
.07737 .16187 m
.07737 .01659 L
.0778 .01659 L
.0778 .16187 L
F
.804 .522 .247 r
.07737 .16187 m
.07737 .01659 L
.0778 .01659 L
.0778 .16187 L
s
1 .894 .882 r
.0778 .16187 m
.0778 .01661 L
.07836 .01661 L
.07836 .16187 L
F
.804 .522 .247 r
.0778 .16187 m
.0778 .01661 L
.07836 .01661 L
.07836 .16187 L
s
1 .894 .882 r
.07836 .16187 m
.07836 .01668 L
.07896 .01668 L
.07896 .16187 L
F
.804 .522 .247 r
.07836 .16187 m
.07836 .01668 L
.07896 .01668 L
.07896 .16187 L
s
1 .894 .882 r
.07896 .16187 m
.07896 .01671 L
.0795 .01671 L
.0795 .16187 L
F
.804 .522 .247 r
.07896 .16187 m
.07896 .01671 L
.0795 .01671 L
.0795 .16187 L
s
1 .894 .882 r
.0795 .16187 m
.0795 .01675 L
.0798 .01675 L
.0798 .16187 L
F
.804 .522 .247 r
.0795 .16187 m
.0795 .01675 L
.0798 .01675 L
.0798 .16187 L
s
1 .894 .882 r
.0798 .16187 m
.0798 .01678 L
.08025 .01678 L
.08025 .16187 L
F
.804 .522 .247 r
.0798 .16187 m
.0798 .01678 L
.08025 .01678 L
.08025 .16187 L
s
1 .894 .882 r
.08025 .16187 m
.08025 .01678 L
.08083 .01678 L
.08083 .16187 L
F
.804 .522 .247 r
.08025 .16187 m
.08025 .01678 L
.08083 .01678 L
.08083 .16187 L
s
1 .894 .882 r
.08083 .16187 m
.08083 .01683 L
.08141 .01683 L
.08141 .16187 L
F
.804 .522 .247 r
.08083 .16187 m
.08083 .01683 L
.08141 .01683 L
.08141 .16187 L
s
1 .894 .882 r
.08141 .16187 m
.08141 .01687 L
.08182 .01687 L
.08182 .16187 L
F
.804 .522 .247 r
.08141 .16187 m
.08141 .01687 L
.08182 .01687 L
.08182 .16187 L
s
1 .894 .882 r
.08182 .16187 m
.08182 .0169 L
.08219 .0169 L
.08219 .16187 L
F
.804 .522 .247 r
.08182 .16187 m
.08182 .0169 L
.08219 .0169 L
.08219 .16187 L
s
1 .894 .882 r
.08219 .16187 m
.08219 .01694 L
.08283 .01694 L
.08283 .16187 L
F
.804 .522 .247 r
.08219 .16187 m
.08219 .01694 L
.08283 .01694 L
.08283 .16187 L
s
1 .894 .882 r
.08283 .16187 m
.08283 .01699 L
.08325 .01699 L
.08325 .16187 L
F
.804 .522 .247 r
.08283 .16187 m
.08283 .01699 L
.08325 .01699 L
.08325 .16187 L
s
1 .894 .882 r
.08325 .16187 m
.08325 .01702 L
.08384 .01702 L
.08384 .16187 L
F
.804 .522 .247 r
.08325 .16187 m
.08325 .01702 L
.08384 .01702 L
.08384 .16187 L
s
1 .894 .882 r
.08384 .16187 m
.08384 .01707 L
.08405 .01707 L
.08405 .16187 L
F
.804 .522 .247 r
.08384 .16187 m
.08384 .01707 L
.08405 .01707 L
.08405 .16187 L
s
1 .894 .882 r
.08405 .16187 m
.08405 .01709 L
.08439 .01709 L
.08439 .16187 L
F
.804 .522 .247 r
.08405 .16187 m
.08405 .01709 L
.08439 .01709 L
.08439 .16187 L
s
1 .894 .882 r
.08439 .16187 m
.08439 .01712 L
.08501 .01712 L
.08501 .16187 L
F
.804 .522 .247 r
.08439 .16187 m
.08439 .01712 L
.08501 .01712 L
.08501 .16187 L
s
1 .894 .882 r
.08501 .16187 m
.08501 .01717 L
.08538 .01717 L
.08538 .16187 L
F
.804 .522 .247 r
.08501 .16187 m
.08501 .01717 L
.08538 .01717 L
.08538 .16187 L
s
1 .894 .882 r
.08538 .16187 m
.08538 .01721 L
.08602 .01721 L
.08602 .16187 L
F
.804 .522 .247 r
.08538 .16187 m
.08538 .01721 L
.08602 .01721 L
.08602 .16187 L
s
1 .894 .882 r
.08602 .16187 m
.08602 .01724 L
.08623 .01724 L
.08623 .16187 L
F
.804 .522 .247 r
.08602 .16187 m
.08602 .01724 L
.08623 .01724 L
.08623 .16187 L
s
1 .894 .882 r
.08623 .16187 m
.08623 .01726 L
.08673 .01726 L
.08673 .16187 L
F
.804 .522 .247 r
.08623 .16187 m
.08623 .01726 L
.08673 .01726 L
.08673 .16187 L
s
1 .894 .882 r
.08673 .16187 m
.08673 .01728 L
.08735 .01728 L
.08735 .16187 L
F
.804 .522 .247 r
.08673 .16187 m
.08673 .01728 L
.08735 .01728 L
.08735 .16187 L
s
1 .894 .882 r
.08735 .16187 m
.08735 .01734 L
.08783 .01734 L
.08783 .16187 L
F
.804 .522 .247 r
.08735 .16187 m
.08735 .01734 L
.08783 .01734 L
.08783 .16187 L
s
1 .894 .882 r
.08783 .16187 m
.08783 .01738 L
.08831 .01738 L
.08831 .16187 L
F
.804 .522 .247 r
.08783 .16187 m
.08783 .01738 L
.08831 .01738 L
.08831 .16187 L
s
1 .894 .882 r
.08831 .16187 m
.08831 .01743 L
.08862 .01743 L
.08862 .16187 L
F
.804 .522 .247 r
.08831 .16187 m
.08831 .01743 L
.08862 .01743 L
.08862 .16187 L
s
1 .894 .882 r
.08862 .16187 m
.08862 .01746 L
.08899 .01746 L
.08899 .16187 L
F
.804 .522 .247 r
.08862 .16187 m
.08862 .01746 L
.08899 .01746 L
.08899 .16187 L
s
1 .894 .882 r
.08899 .16187 m
.08899 .01747 L
.08955 .01747 L
.08955 .16187 L
F
.804 .522 .247 r
.08899 .16187 m
.08899 .01747 L
.08955 .01747 L
.08955 .16187 L
s
1 .894 .882 r
.08955 .16187 m
.08955 .01753 L
.09008 .01753 L
.09008 .16187 L
F
.804 .522 .247 r
.08955 .16187 m
.08955 .01753 L
.09008 .01753 L
.09008 .16187 L
s
1 .894 .882 r
.09008 .16187 m
.09008 .01757 L
.09048 .01757 L
.09048 .16187 L
F
.804 .522 .247 r
.09008 .16187 m
.09008 .01757 L
.09048 .01757 L
.09048 .16187 L
s
1 .894 .882 r
.09048 .16187 m
.09048 .01762 L
.09074 .01762 L
.09074 .16187 L
F
.804 .522 .247 r
.09048 .16187 m
.09048 .01762 L
.09074 .01762 L
.09074 .16187 L
s
1 .894 .882 r
.09074 .16187 m
.09074 .01762 L
.09104 .01762 L
.09104 .16187 L
F
.804 .522 .247 r
.09074 .16187 m
.09074 .01762 L
.09104 .01762 L
.09104 .16187 L
s
1 .894 .882 r
.09104 .16187 m
.09104 .01766 L
.09162 .01766 L
.09162 .16187 L
F
.804 .522 .247 r
.09104 .16187 m
.09104 .01766 L
.09162 .01766 L
.09162 .16187 L
s
1 .894 .882 r
.09162 .16187 m
.09162 .01774 L
.09208 .01774 L
.09208 .16187 L
F
.804 .522 .247 r
.09162 .16187 m
.09162 .01774 L
.09208 .01774 L
.09208 .16187 L
s
1 .894 .882 r
.09208 .16187 m
.09208 .01777 L
.09257 .01777 L
.09257 .16187 L
F
.804 .522 .247 r
.09208 .16187 m
.09208 .01777 L
.09257 .01777 L
.09257 .16187 L
s
1 .894 .882 r
.09257 .16187 m
.09257 .01783 L
.09314 .01783 L
.09314 .16187 L
F
.804 .522 .247 r
.09257 .16187 m
.09257 .01783 L
.09314 .01783 L
.09314 .16187 L
s
1 .894 .882 r
.09314 .16187 m
.09314 .01788 L
.09373 .01788 L
.09373 .16187 L
F
.804 .522 .247 r
.09314 .16187 m
.09314 .01788 L
.09373 .01788 L
.09373 .16187 L
s
1 .894 .882 r
.09373 .16187 m
.09373 .0179 L
.09395 .0179 L
.09395 .16187 L
F
.804 .522 .247 r
.09373 .16187 m
.09373 .0179 L
.09395 .0179 L
.09395 .16187 L
s
1 .894 .882 r
.09395 .16187 m
.09395 .01793 L
.09449 .01793 L
.09449 .16187 L
F
.804 .522 .247 r
.09395 .16187 m
.09395 .01793 L
.09449 .01793 L
.09449 .16187 L
s
1 .894 .882 r
.09449 .16187 m
.09449 .01796 L
.09505 .01796 L
.09505 .16187 L
F
.804 .522 .247 r
.09449 .16187 m
.09449 .01796 L
.09505 .01796 L
.09505 .16187 L
s
1 .894 .882 r
.09505 .16187 m
.09505 .01801 L
.09548 .01801 L
.09548 .16187 L
F
.804 .522 .247 r
.09505 .16187 m
.09505 .01801 L
.09548 .01801 L
.09548 .16187 L
s
1 .894 .882 r
.09548 .16187 m
.09548 .01805 L
.09572 .01805 L
.09572 .16187 L
F
.804 .522 .247 r
.09548 .16187 m
.09548 .01805 L
.09572 .01805 L
.09572 .16187 L
s
1 .894 .882 r
.09572 .16187 m
.09572 .01809 L
.09608 .01809 L
.09608 .16187 L
F
.804 .522 .247 r
.09572 .16187 m
.09572 .01809 L
.09608 .01809 L
.09608 .16187 L
s
1 .894 .882 r
.09608 .16187 m
.09608 .01813 L
.09664 .01813 L
.09664 .16187 L
F
.804 .522 .247 r
.09608 .16187 m
.09608 .01813 L
.09664 .01813 L
.09664 .16187 L
s
1 .894 .882 r
.09664 .16187 m
.09664 .01818 L
.09705 .01818 L
.09705 .16187 L
F
.804 .522 .247 r
.09664 .16187 m
.09664 .01818 L
.09705 .01818 L
.09705 .16187 L
s
1 .894 .882 r
.09705 .16187 m
.09705 .01822 L
.09743 .01822 L
.09743 .16187 L
F
.804 .522 .247 r
.09705 .16187 m
.09705 .01822 L
.09743 .01822 L
.09743 .16187 L
s
1 .894 .882 r
.09743 .16187 m
.09743 .01826 L
.09781 .01826 L
.09781 .16187 L
F
.804 .522 .247 r
.09743 .16187 m
.09743 .01826 L
.09781 .01826 L
.09781 .16187 L
s
1 .894 .882 r
.09781 .16187 m
.09781 .01828 L
.09808 .01828 L
.09808 .16187 L
F
.804 .522 .247 r
.09781 .16187 m
.09781 .01828 L
.09808 .01828 L
.09808 .16187 L
s
1 .894 .882 r
.09808 .16187 m
.09808 .01832 L
.09864 .01832 L
.09864 .16187 L
F
.804 .522 .247 r
.09808 .16187 m
.09808 .01832 L
.09864 .01832 L
.09864 .16187 L
s
1 .894 .882 r
.09864 .16187 m
.09864 .01835 L
.09891 .01835 L
.09891 .16187 L
F
.804 .522 .247 r
.09864 .16187 m
.09864 .01835 L
.09891 .01835 L
.09891 .16187 L
s
1 .894 .882 r
.09891 .16187 m
.09891 .01838 L
.09911 .01838 L
.09911 .16187 L
F
.804 .522 .247 r
.09891 .16187 m
.09891 .01838 L
.09911 .01838 L
.09911 .16187 L
s
1 .894 .882 r
.09911 .16187 m
.09911 .0184 L
.09946 .0184 L
.09946 .16187 L
F
.804 .522 .247 r
.09911 .16187 m
.09911 .0184 L
.09946 .0184 L
.09946 .16187 L
s
1 .894 .882 r
.09946 .16187 m
.09946 .01843 L
.09969 .01843 L
.09969 .16187 L
F
.804 .522 .247 r
.09946 .16187 m
.09946 .01843 L
.09969 .01843 L
.09969 .16187 L
s
1 .894 .882 r
.09969 .16187 m
.09969 .0185 L
.10019 .0185 L
.10019 .16187 L
F
.804 .522 .247 r
.09969 .16187 m
.09969 .0185 L
.10019 .0185 L
.10019 .16187 L
s
1 .894 .882 r
.10019 .16187 m
.10019 .01852 L
.10076 .01852 L
.10076 .16187 L
F
.804 .522 .247 r
.10019 .16187 m
.10019 .01852 L
.10076 .01852 L
.10076 .16187 L
s
1 .894 .882 r
.10076 .16187 m
.10076 .01856 L
.101 .01856 L
.101 .16187 L
F
.804 .522 .247 r
.10076 .16187 m
.10076 .01856 L
.101 .01856 L
.101 .16187 L
s
1 .894 .882 r
.101 .16187 m
.101 .01858 L
.10129 .01858 L
.10129 .16187 L
F
.804 .522 .247 r
.101 .16187 m
.101 .01858 L
.10129 .01858 L
.10129 .16187 L
s
1 .894 .882 r
.10129 .16187 m
.10129 .01861 L
.10152 .01861 L
.10152 .16187 L
F
.804 .522 .247 r
.10129 .16187 m
.10129 .01861 L
.10152 .01861 L
.10152 .16187 L
s
1 .894 .882 r
.10152 .16187 m
.10152 .01865 L
.1018 .01865 L
.1018 .16187 L
F
.804 .522 .247 r
.10152 .16187 m
.10152 .01865 L
.1018 .01865 L
.1018 .16187 L
s
1 .894 .882 r
.1018 .16187 m
.1018 .01867 L
.1021 .01867 L
.1021 .16187 L
F
.804 .522 .247 r
.1018 .16187 m
.1018 .01867 L
.1021 .01867 L
.1021 .16187 L
s
1 .894 .882 r
.1021 .16187 m
.1021 .0187 L
.10245 .0187 L
.10245 .16187 L
F
.804 .522 .247 r
.1021 .16187 m
.1021 .0187 L
.10245 .0187 L
.10245 .16187 L
s
1 .894 .882 r
.10245 .16187 m
.10245 .01874 L
.10265 .01874 L
.10265 .16187 L
F
.804 .522 .247 r
.10245 .16187 m
.10245 .01874 L
.10265 .01874 L
.10265 .16187 L
s
1 .894 .882 r
.10265 .16187 m
.10265 .01875 L
.10302 .01875 L
.10302 .16187 L
F
.804 .522 .247 r
.10265 .16187 m
.10265 .01875 L
.10302 .01875 L
.10302 .16187 L
s
1 .894 .882 r
.10302 .16187 m
.10302 .01879 L
.10341 .01879 L
.10341 .16187 L
F
.804 .522 .247 r
.10302 .16187 m
.10302 .01879 L
.10341 .01879 L
.10341 .16187 L
s
1 .894 .882 r
.10341 .16187 m
.10341 .01883 L
.10395 .01883 L
.10395 .16187 L
F
.804 .522 .247 r
.10341 .16187 m
.10341 .01883 L
.10395 .01883 L
.10395 .16187 L
s
1 .894 .882 r
.10395 .16187 m
.10395 .01891 L
.10455 .01891 L
.10455 .16187 L
F
.804 .522 .247 r
.10395 .16187 m
.10395 .01891 L
.10455 .01891 L
.10455 .16187 L
s
1 .894 .882 r
.10455 .16187 m
.10455 .01896 L
.10476 .01896 L
.10476 .16187 L
F
.804 .522 .247 r
.10455 .16187 m
.10455 .01896 L
.10476 .01896 L
.10476 .16187 L
s
1 .894 .882 r
.10476 .16187 m
.10476 .019 L
.10523 .019 L
.10523 .16187 L
F
.804 .522 .247 r
.10476 .16187 m
.10476 .019 L
.10523 .019 L
.10523 .16187 L
s
1 .894 .882 r
.10523 .16187 m
.10523 .01903 L
.10555 .01903 L
.10555 .16187 L
F
.804 .522 .247 r
.10523 .16187 m
.10523 .01903 L
.10555 .01903 L
.10555 .16187 L
s
1 .894 .882 r
.10555 .16187 m
.10555 .01908 L
.10596 .01908 L
.10596 .16187 L
F
.804 .522 .247 r
.10555 .16187 m
.10555 .01908 L
.10596 .01908 L
.10596 .16187 L
s
1 .894 .882 r
.10596 .16187 m
.10596 .01913 L
.10643 .01913 L
.10643 .16187 L
F
.804 .522 .247 r
.10596 .16187 m
.10596 .01913 L
.10643 .01913 L
.10643 .16187 L
s
1 .894 .882 r
.10643 .16187 m
.10643 .01916 L
.10682 .01916 L
.10682 .16187 L
F
.804 .522 .247 r
.10643 .16187 m
.10643 .01916 L
.10682 .01916 L
.10682 .16187 L
s
1 .894 .882 r
.10682 .16187 m
.10682 .01923 L
.10721 .01923 L
.10721 .16187 L
F
.804 .522 .247 r
.10682 .16187 m
.10682 .01923 L
.10721 .01923 L
.10721 .16187 L
s
1 .894 .882 r
.10721 .16187 m
.10721 .01925 L
.10754 .01925 L
.10754 .16187 L
F
.804 .522 .247 r
.10721 .16187 m
.10721 .01925 L
.10754 .01925 L
.10754 .16187 L
s
1 .894 .882 r
.10754 .16187 m
.10754 .0193 L
.10801 .0193 L
.10801 .16187 L
F
.804 .522 .247 r
.10754 .16187 m
.10754 .0193 L
.10801 .0193 L
.10801 .16187 L
s
1 .894 .882 r
.10801 .16187 m
.10801 .01932 L
.10824 .01932 L
.10824 .16187 L
F
.804 .522 .247 r
.10801 .16187 m
.10801 .01932 L
.10824 .01932 L
.10824 .16187 L
s
1 .894 .882 r
.10824 .16187 m
.10824 .01937 L
.1086 .01937 L
.1086 .16187 L
F
.804 .522 .247 r
.10824 .16187 m
.10824 .01937 L
.1086 .01937 L
.1086 .16187 L
s
1 .894 .882 r
.1086 .16187 m
.1086 .01941 L
.10906 .01941 L
.10906 .16187 L
F
.804 .522 .247 r
.1086 .16187 m
.1086 .01941 L
.10906 .01941 L
.10906 .16187 L
s
1 .894 .882 r
.10906 .16187 m
.10906 .01945 L
.1096 .01945 L
.1096 .16187 L
F
.804 .522 .247 r
.10906 .16187 m
.10906 .01945 L
.1096 .01945 L
.1096 .16187 L
s
1 .894 .882 r
.1096 .16187 m
.1096 .01949 L
.11023 .01949 L
.11023 .16187 L
F
.804 .522 .247 r
.1096 .16187 m
.1096 .01949 L
.11023 .01949 L
.11023 .16187 L
s
1 .894 .882 r
.11023 .16187 m
.11023 .01958 L
.11049 .01958 L
.11049 .16187 L
F
.804 .522 .247 r
.11023 .16187 m
.11023 .01958 L
.11049 .01958 L
.11049 .16187 L
s
1 .894 .882 r
.11049 .16187 m
.11049 .01962 L
.11091 .01962 L
.11091 .16187 L
F
.804 .522 .247 r
.11049 .16187 m
.11049 .01962 L
.11091 .01962 L
.11091 .16187 L
s
1 .894 .882 r
.11091 .16187 m
.11091 .01968 L
.11137 .01968 L
.11137 .16187 L
F
.804 .522 .247 r
.11091 .16187 m
.11091 .01968 L
.11137 .01968 L
.11137 .16187 L
s
1 .894 .882 r
.11137 .16187 m
.11137 .01973 L
.11188 .01973 L
.11188 .16187 L
F
.804 .522 .247 r
.11137 .16187 m
.11137 .01973 L
.11188 .01973 L
.11188 .16187 L
s
1 .894 .882 r
.11188 .16187 m
.11188 .01978 L
.11243 .01978 L
.11243 .16187 L
F
.804 .522 .247 r
.11188 .16187 m
.11188 .01978 L
.11243 .01978 L
.11243 .16187 L
s
1 .894 .882 r
.11243 .16187 m
.11243 .01982 L
.11284 .01982 L
.11284 .16187 L
F
.804 .522 .247 r
.11243 .16187 m
.11243 .01982 L
.11284 .01982 L
.11284 .16187 L
s
1 .894 .882 r
.11284 .16187 m
.11284 .01988 L
.11312 .01988 L
.11312 .16187 L
F
.804 .522 .247 r
.11284 .16187 m
.11284 .01988 L
.11312 .01988 L
.11312 .16187 L
s
1 .894 .882 r
.11312 .16187 m
.11312 .01991 L
.11343 .01991 L
.11343 .16187 L
F
.804 .522 .247 r
.11312 .16187 m
.11312 .01991 L
.11343 .01991 L
.11343 .16187 L
s
1 .894 .882 r
.11343 .16187 m
.11343 .01994 L
.11363 .01994 L
.11363 .16187 L
F
.804 .522 .247 r
.11343 .16187 m
.11343 .01994 L
.11363 .01994 L
.11363 .16187 L
s
1 .894 .882 r
.11363 .16187 m
.11363 .01999 L
.11408 .01999 L
.11408 .16187 L
F
.804 .522 .247 r
.11363 .16187 m
.11363 .01999 L
.11408 .01999 L
.11408 .16187 L
s
1 .894 .882 r
.11408 .16187 m
.11408 .02001 L
.11434 .02001 L
.11434 .16187 L
F
.804 .522 .247 r
.11408 .16187 m
.11408 .02001 L
.11434 .02001 L
.11434 .16187 L
s
1 .894 .882 r
.11434 .16187 m
.11434 .02009 L
.11483 .02009 L
.11483 .16187 L
F
.804 .522 .247 r
.11434 .16187 m
.11434 .02009 L
.11483 .02009 L
.11483 .16187 L
s
1 .894 .882 r
.11483 .16187 m
.11483 .02015 L
.11534 .02015 L
.11534 .16187 L
F
.804 .522 .247 r
.11483 .16187 m
.11483 .02015 L
.11534 .02015 L
.11534 .16187 L
s
1 .894 .882 r
.11534 .16187 m
.11534 .02015 L
.11558 .02015 L
.11558 .16187 L
F
.804 .522 .247 r
.11534 .16187 m
.11534 .02015 L
.11558 .02015 L
.11558 .16187 L
s
1 .894 .882 r
.11558 .16187 m
.11558 .0202 L
.116 .0202 L
.116 .16187 L
F
.804 .522 .247 r
.11558 .16187 m
.11558 .0202 L
.116 .0202 L
.116 .16187 L
s
1 .894 .882 r
.116 .16187 m
.116 .02025 L
.11629 .02025 L
.11629 .16187 L
F
.804 .522 .247 r
.116 .16187 m
.116 .02025 L
.11629 .02025 L
.11629 .16187 L
s
1 .894 .882 r
.11629 .16187 m
.11629 .0203 L
.1166 .0203 L
.1166 .16187 L
F
.804 .522 .247 r
.11629 .16187 m
.11629 .0203 L
.1166 .0203 L
.1166 .16187 L
s
1 .894 .882 r
.1166 .16187 m
.1166 .02033 L
.11714 .02033 L
.11714 .16187 L
F
.804 .522 .247 r
.1166 .16187 m
.1166 .02033 L
.11714 .02033 L
.11714 .16187 L
s
1 .894 .882 r
.11714 .16187 m
.11714 .02043 L
.11774 .02043 L
.11774 .16187 L
F
.804 .522 .247 r
.11714 .16187 m
.11714 .02043 L
.11774 .02043 L
.11774 .16187 L
s
1 .894 .882 r
.11774 .16187 m
.11774 .02045 L
.11799 .02045 L
.11799 .16187 L
F
.804 .522 .247 r
.11774 .16187 m
.11774 .02045 L
.11799 .02045 L
.11799 .16187 L
s
1 .894 .882 r
.11799 .16187 m
.11799 .02049 L
.11857 .02049 L
.11857 .16187 L
F
.804 .522 .247 r
.11799 .16187 m
.11799 .02049 L
.11857 .02049 L
.11857 .16187 L
s
1 .894 .882 r
.11857 .16187 m
.11857 .02057 L
.11885 .02057 L
.11885 .16187 L
F
.804 .522 .247 r
.11857 .16187 m
.11857 .02057 L
.11885 .02057 L
.11885 .16187 L
s
1 .894 .882 r
.11885 .16187 m
.11885 .02059 L
.1191 .02059 L
.1191 .16187 L
F
.804 .522 .247 r
.11885 .16187 m
.11885 .02059 L
.1191 .02059 L
.1191 .16187 L
s
1 .894 .882 r
.1191 .16187 m
.1191 .02061 L
.11936 .02061 L
.11936 .16187 L
F
.804 .522 .247 r
.1191 .16187 m
.1191 .02061 L
.11936 .02061 L
.11936 .16187 L
s
1 .894 .882 r
.11936 .16187 m
.11936 .02067 L
.11988 .02067 L
.11988 .16187 L
F
.804 .522 .247 r
.11936 .16187 m
.11936 .02067 L
.11988 .02067 L
.11988 .16187 L
s
1 .894 .882 r
.11988 .16187 m
.11988 .02071 L
.12037 .02071 L
.12037 .16187 L
F
.804 .522 .247 r
.11988 .16187 m
.11988 .02071 L
.12037 .02071 L
.12037 .16187 L
s
1 .894 .882 r
.12037 .16187 m
.12037 .0208 L
.1208 .0208 L
.1208 .16187 L
F
.804 .522 .247 r
.12037 .16187 m
.12037 .0208 L
.1208 .0208 L
.1208 .16187 L
s
1 .894 .882 r
.1208 .16187 m
.1208 .02084 L
.12119 .02084 L
.12119 .16187 L
F
.804 .522 .247 r
.1208 .16187 m
.1208 .02084 L
.12119 .02084 L
.12119 .16187 L
s
1 .894 .882 r
.12119 .16187 m
.12119 .02087 L
.12179 .02087 L
.12179 .16187 L
F
.804 .522 .247 r
.12119 .16187 m
.12119 .02087 L
.12179 .02087 L
.12179 .16187 L
s
1 .894 .882 r
.12179 .16187 m
.12179 .02095 L
.12206 .02095 L
.12206 .16187 L
F
.804 .522 .247 r
.12179 .16187 m
.12179 .02095 L
.12206 .02095 L
.12206 .16187 L
s
1 .894 .882 r
.12206 .16187 m
.12206 .02102 L
.1224 .02102 L
.1224 .16187 L
F
.804 .522 .247 r
.12206 .16187 m
.12206 .02102 L
.1224 .02102 L
.1224 .16187 L
s
1 .894 .882 r
.1224 .16187 m
.1224 .02105 L
.12267 .02105 L
.12267 .16187 L
F
.804 .522 .247 r
.1224 .16187 m
.1224 .02105 L
.12267 .02105 L
.12267 .16187 L
s
1 .894 .882 r
.12267 .16187 m
.12267 .0211 L
.12327 .0211 L
.12327 .16187 L
F
.804 .522 .247 r
.12267 .16187 m
.12267 .0211 L
.12327 .0211 L
.12327 .16187 L
s
1 .894 .882 r
.12327 .16187 m
.12327 .02115 L
.12372 .02115 L
.12372 .16187 L
F
.804 .522 .247 r
.12327 .16187 m
.12327 .02115 L
.12372 .02115 L
.12372 .16187 L
s
1 .894 .882 r
.12372 .16187 m
.12372 .02122 L
.124 .02122 L
.124 .16187 L
F
.804 .522 .247 r
.12372 .16187 m
.12372 .02122 L
.124 .02122 L
.124 .16187 L
s
1 .894 .882 r
.124 .16187 m
.124 .02128 L
.12442 .02128 L
.12442 .16187 L
F
.804 .522 .247 r
.124 .16187 m
.124 .02128 L
.12442 .02128 L
.12442 .16187 L
s
1 .894 .882 r
.12442 .16187 m
.12442 .02131 L
.1247 .02131 L
.1247 .16187 L
F
.804 .522 .247 r
.12442 .16187 m
.12442 .02131 L
.1247 .02131 L
.1247 .16187 L
s
1 .894 .882 r
.1247 .16187 m
.1247 .02134 L
.12511 .02134 L
.12511 .16187 L
F
.804 .522 .247 r
.1247 .16187 m
.1247 .02134 L
.12511 .02134 L
.12511 .16187 L
s
1 .894 .882 r
.12511 .16187 m
.12511 .02139 L
.12559 .02139 L
.12559 .16187 L
F
.804 .522 .247 r
.12511 .16187 m
.12511 .02139 L
.12559 .02139 L
.12559 .16187 L
s
1 .894 .882 r
.12559 .16187 m
.12559 .02146 L
.12591 .02146 L
.12591 .16187 L
F
.804 .522 .247 r
.12559 .16187 m
.12559 .02146 L
.12591 .02146 L
.12591 .16187 L
s
1 .894 .882 r
.12591 .16187 m
.12591 .02153 L
.12653 .02153 L
.12653 .16187 L
F
.804 .522 .247 r
.12591 .16187 m
.12591 .02153 L
.12653 .02153 L
.12653 .16187 L
s
1 .894 .882 r
.12653 .16187 m
.12653 .02162 L
.12703 .02162 L
.12703 .16187 L
F
.804 .522 .247 r
.12653 .16187 m
.12653 .02162 L
.12703 .02162 L
.12703 .16187 L
s
1 .894 .882 r
.12703 .16187 m
.12703 .02166 L
.12755 .02166 L
.12755 .16187 L
F
.804 .522 .247 r
.12703 .16187 m
.12703 .02166 L
.12755 .02166 L
.12755 .16187 L
s
1 .894 .882 r
.12755 .16187 m
.12755 .02171 L
.12781 .02171 L
.12781 .16187 L
F
.804 .522 .247 r
.12755 .16187 m
.12755 .02171 L
.12781 .02171 L
.12781 .16187 L
s
1 .894 .882 r
.12781 .16187 m
.12781 .02175 L
.12804 .02175 L
.12804 .16187 L
F
.804 .522 .247 r
.12781 .16187 m
.12781 .02175 L
.12804 .02175 L
.12804 .16187 L
s
1 .894 .882 r
.12804 .16187 m
.12804 .02177 L
.12846 .02177 L
.12846 .16187 L
F
.804 .522 .247 r
.12804 .16187 m
.12804 .02177 L
.12846 .02177 L
.12846 .16187 L
s
1 .894 .882 r
.12846 .16187 m
.12846 .02182 L
.12892 .02182 L
.12892 .16187 L
F
.804 .522 .247 r
.12846 .16187 m
.12846 .02182 L
.12892 .02182 L
.12892 .16187 L
s
1 .894 .882 r
.12892 .16187 m
.12892 .02189 L
.12955 .02189 L
.12955 .16187 L
F
.804 .522 .247 r
.12892 .16187 m
.12892 .02189 L
.12955 .02189 L
.12955 .16187 L
s
1 .894 .882 r
.12955 .16187 m
.12955 .02201 L
.12991 .02201 L
.12991 .16187 L
F
.804 .522 .247 r
.12955 .16187 m
.12955 .02201 L
.12991 .02201 L
.12991 .16187 L
s
1 .894 .882 r
.12991 .16187 m
.12991 .02202 L
.13047 .02202 L
.13047 .16187 L
F
.804 .522 .247 r
.12991 .16187 m
.12991 .02202 L
.13047 .02202 L
.13047 .16187 L
s
1 .894 .882 r
.13047 .16187 m
.13047 .02211 L
.1307 .02211 L
.1307 .16187 L
F
.804 .522 .247 r
.13047 .16187 m
.13047 .02211 L
.1307 .02211 L
.1307 .16187 L
s
1 .894 .882 r
.1307 .16187 m
.1307 .02216 L
.13112 .02216 L
.13112 .16187 L
F
.804 .522 .247 r
.1307 .16187 m
.1307 .02216 L
.13112 .02216 L
.13112 .16187 L
s
1 .894 .882 r
.13112 .16187 m
.13112 .02223 L
.13151 .02223 L
.13151 .16187 L
F
.804 .522 .247 r
.13112 .16187 m
.13112 .02223 L
.13151 .02223 L
.13151 .16187 L
s
1 .894 .882 r
.13151 .16187 m
.13151 .02224 L
.132 .02224 L
.132 .16187 L
F
.804 .522 .247 r
.13151 .16187 m
.13151 .02224 L
.132 .02224 L
.132 .16187 L
s
1 .894 .882 r
.132 .16187 m
.132 .02234 L
.13253 .02234 L
.13253 .16187 L
F
.804 .522 .247 r
.132 .16187 m
.132 .02234 L
.13253 .02234 L
.13253 .16187 L
s
1 .894 .882 r
.13253 .16187 m
.13253 .02242 L
.13287 .02242 L
.13287 .16187 L
F
.804 .522 .247 r
.13253 .16187 m
.13253 .02242 L
.13287 .02242 L
.13287 .16187 L
s
1 .894 .882 r
.13287 .16187 m
.13287 .02245 L
.1333 .02245 L
.1333 .16187 L
F
.804 .522 .247 r
.13287 .16187 m
.13287 .02245 L
.1333 .02245 L
.1333 .16187 L
s
1 .894 .882 r
.1333 .16187 m
.1333 .02252 L
.13353 .02252 L
.13353 .16187 L
F
.804 .522 .247 r
.1333 .16187 m
.1333 .02252 L
.13353 .02252 L
.13353 .16187 L
s
1 .894 .882 r
.13353 .16187 m
.13353 .02257 L
.13397 .02257 L
.13397 .16187 L
F
.804 .522 .247 r
.13353 .16187 m
.13353 .02257 L
.13397 .02257 L
.13397 .16187 L
s
1 .894 .882 r
.13397 .16187 m
.13397 .02265 L
.13454 .02265 L
.13454 .16187 L
F
.804 .522 .247 r
.13397 .16187 m
.13397 .02265 L
.13454 .02265 L
.13454 .16187 L
s
1 .894 .882 r
.13454 .16187 m
.13454 .0227 L
.13487 .0227 L
.13487 .16187 L
F
.804 .522 .247 r
.13454 .16187 m
.13454 .0227 L
.13487 .0227 L
.13487 .16187 L
s
1 .894 .882 r
.13487 .16187 m
.13487 .02275 L
.13533 .02275 L
.13533 .16187 L
F
.804 .522 .247 r
.13487 .16187 m
.13487 .02275 L
.13533 .02275 L
.13533 .16187 L
s
1 .894 .882 r
.13533 .16187 m
.13533 .02282 L
.13593 .02282 L
.13593 .16187 L
F
.804 .522 .247 r
.13533 .16187 m
.13533 .02282 L
.13593 .02282 L
.13593 .16187 L
s
1 .894 .882 r
.13593 .16187 m
.13593 .02289 L
.13636 .02289 L
.13636 .16187 L
F
.804 .522 .247 r
.13593 .16187 m
.13593 .02289 L
.13636 .02289 L
.13636 .16187 L
s
1 .894 .882 r
.13636 .16187 m
.13636 .02294 L
.13672 .02294 L
.13672 .16187 L
F
.804 .522 .247 r
.13636 .16187 m
.13636 .02294 L
.13672 .02294 L
.13672 .16187 L
s
1 .894 .882 r
.13672 .16187 m
.13672 .02304 L
.13732 .02304 L
.13732 .16187 L
F
.804 .522 .247 r
.13672 .16187 m
.13672 .02304 L
.13732 .02304 L
.13732 .16187 L
s
1 .894 .882 r
.13732 .16187 m
.13732 .02311 L
.13758 .02311 L
.13758 .16187 L
F
.804 .522 .247 r
.13732 .16187 m
.13732 .02311 L
.13758 .02311 L
.13758 .16187 L
s
1 .894 .882 r
.13758 .16187 m
.13758 .02312 L
.13795 .02312 L
.13795 .16187 L
F
.804 .522 .247 r
.13758 .16187 m
.13758 .02312 L
.13795 .02312 L
.13795 .16187 L
s
1 .894 .882 r
.13795 .16187 m
.13795 .0232 L
.13827 .0232 L
.13827 .16187 L
F
.804 .522 .247 r
.13795 .16187 m
.13795 .0232 L
.13827 .0232 L
.13827 .16187 L
s
1 .894 .882 r
.13827 .16187 m
.13827 .02324 L
.13864 .02324 L
.13864 .16187 L
F
.804 .522 .247 r
.13827 .16187 m
.13827 .02324 L
.13864 .02324 L
.13864 .16187 L
s
1 .894 .882 r
.13864 .16187 m
.13864 .02333 L
.13907 .02333 L
.13907 .16187 L
F
.804 .522 .247 r
.13864 .16187 m
.13864 .02333 L
.13907 .02333 L
.13907 .16187 L
s
1 .894 .882 r
.13907 .16187 m
.13907 .02334 L
.13946 .02334 L
.13946 .16187 L
F
.804 .522 .247 r
.13907 .16187 m
.13907 .02334 L
.13946 .02334 L
.13946 .16187 L
s
1 .894 .882 r
.13946 .16187 m
.13946 .02346 L
.14005 .02346 L
.14005 .16187 L
F
.804 .522 .247 r
.13946 .16187 m
.13946 .02346 L
.14005 .02346 L
.14005 .16187 L
s
1 .894 .882 r
.14005 .16187 m
.14005 .02351 L
.14051 .02351 L
.14051 .16187 L
F
.804 .522 .247 r
.14005 .16187 m
.14005 .02351 L
.14051 .02351 L
.14051 .16187 L
s
1 .894 .882 r
.14051 .16187 m
.14051 .02359 L
.1409 .02359 L
.1409 .16187 L
F
.804 .522 .247 r
.14051 .16187 m
.14051 .02359 L
.1409 .02359 L
.1409 .16187 L
s
1 .894 .882 r
.1409 .16187 m
.1409 .02366 L
.14149 .02366 L
.14149 .16187 L
F
.804 .522 .247 r
.1409 .16187 m
.1409 .02366 L
.14149 .02366 L
.14149 .16187 L
s
1 .894 .882 r
.14149 .16187 m
.14149 .02376 L
.14189 .02376 L
.14189 .16187 L
F
.804 .522 .247 r
.14149 .16187 m
.14149 .02376 L
.14189 .02376 L
.14189 .16187 L
s
1 .894 .882 r
.14189 .16187 m
.14189 .0238 L
.1425 .0238 L
.1425 .16187 L
F
.804 .522 .247 r
.14189 .16187 m
.14189 .0238 L
.1425 .0238 L
.1425 .16187 L
s
1 .894 .882 r
.1425 .16187 m
.1425 .02387 L
.143 .02387 L
.143 .16187 L
F
.804 .522 .247 r
.1425 .16187 m
.1425 .02387 L
.143 .02387 L
.143 .16187 L
s
1 .894 .882 r
.143 .16187 m
.143 .02399 L
.14344 .02399 L
.14344 .16187 L
F
.804 .522 .247 r
.143 .16187 m
.143 .02399 L
.14344 .02399 L
.14344 .16187 L
s
1 .894 .882 r
.14344 .16187 m
.14344 .02407 L
.14405 .02407 L
.14405 .16187 L
F
.804 .522 .247 r
.14344 .16187 m
.14344 .02407 L
.14405 .02407 L
.14405 .16187 L
s
1 .894 .882 r
.14405 .16187 m
.14405 .02416 L
.14462 .02416 L
.14462 .16187 L
F
.804 .522 .247 r
.14405 .16187 m
.14405 .02416 L
.14462 .02416 L
.14462 .16187 L
s
1 .894 .882 r
.14462 .16187 m
.14462 .02421 L
.14488 .02421 L
.14488 .16187 L
F
.804 .522 .247 r
.14462 .16187 m
.14462 .02421 L
.14488 .02421 L
.14488 .16187 L
s
1 .894 .882 r
.14488 .16187 m
.14488 .0243 L
.14538 .0243 L
.14538 .16187 L
F
.804 .522 .247 r
.14488 .16187 m
.14488 .0243 L
.14538 .0243 L
.14538 .16187 L
s
1 .894 .882 r
.14538 .16187 m
.14538 .02432 L
.14585 .02432 L
.14585 .16187 L
F
.804 .522 .247 r
.14538 .16187 m
.14538 .02432 L
.14585 .02432 L
.14585 .16187 L
s
1 .894 .882 r
.14585 .16187 m
.14585 .02439 L
.14616 .02439 L
.14616 .16187 L
F
.804 .522 .247 r
.14585 .16187 m
.14585 .02439 L
.14616 .02439 L
.14616 .16187 L
s
1 .894 .882 r
.14616 .16187 m
.14616 .02443 L
.14645 .02443 L
.14645 .16187 L
F
.804 .522 .247 r
.14616 .16187 m
.14616 .02443 L
.14645 .02443 L
.14645 .16187 L
s
1 .894 .882 r
.14645 .16187 m
.14645 .0245 L
.14671 .0245 L
.14671 .16187 L
F
.804 .522 .247 r
.14645 .16187 m
.14645 .0245 L
.14671 .0245 L
.14671 .16187 L
s
1 .894 .882 r
.14671 .16187 m
.14671 .02452 L
.14702 .02452 L
.14702 .16187 L
F
.804 .522 .247 r
.14671 .16187 m
.14671 .02452 L
.14702 .02452 L
.14702 .16187 L
s
1 .894 .882 r
.14702 .16187 m
.14702 .0246 L
.14736 .0246 L
.14736 .16187 L
F
.804 .522 .247 r
.14702 .16187 m
.14702 .0246 L
.14736 .0246 L
.14736 .16187 L
s
1 .894 .882 r
.14736 .16187 m
.14736 .02463 L
.14758 .02463 L
.14758 .16187 L
F
.804 .522 .247 r
.14736 .16187 m
.14736 .02463 L
.14758 .02463 L
.14758 .16187 L
s
1 .894 .882 r
.14758 .16187 m
.14758 .0247 L
.14811 .0247 L
.14811 .16187 L
F
.804 .522 .247 r
.14758 .16187 m
.14758 .0247 L
.14811 .0247 L
.14811 .16187 L
s
1 .894 .882 r
.14811 .16187 m
.14811 .02479 L
.14874 .02479 L
.14874 .16187 L
F
.804 .522 .247 r
.14811 .16187 m
.14811 .02479 L
.14874 .02479 L
.14874 .16187 L
s
1 .894 .882 r
.14874 .16187 m
.14874 .02486 L
.14934 .02486 L
.14934 .16187 L
F
.804 .522 .247 r
.14874 .16187 m
.14874 .02486 L
.14934 .02486 L
.14934 .16187 L
s
1 .894 .882 r
.14934 .16187 m
.14934 .02496 L
.14977 .02496 L
.14977 .16187 L
F
.804 .522 .247 r
.14934 .16187 m
.14934 .02496 L
.14977 .02496 L
.14977 .16187 L
s
1 .894 .882 r
.14977 .16187 m
.14977 .02504 L
.15011 .02504 L
.15011 .16187 L
F
.804 .522 .247 r
.14977 .16187 m
.14977 .02504 L
.15011 .02504 L
.15011 .16187 L
s
1 .894 .882 r
.15011 .16187 m
.15011 .02509 L
.15033 .02509 L
.15033 .16187 L
F
.804 .522 .247 r
.15011 .16187 m
.15011 .02509 L
.15033 .02509 L
.15033 .16187 L
s
1 .894 .882 r
.15033 .16187 m
.15033 .02515 L
.15067 .02515 L
.15067 .16187 L
F
.804 .522 .247 r
.15033 .16187 m
.15033 .02515 L
.15067 .02515 L
.15067 .16187 L
s
1 .894 .882 r
.15067 .16187 m
.15067 .02518 L
.15091 .02518 L
.15091 .16187 L
F
.804 .522 .247 r
.15067 .16187 m
.15067 .02518 L
.15091 .02518 L
.15091 .16187 L
s
1 .894 .882 r
.15091 .16187 m
.15091 .0252 L
.15129 .0252 L
.15129 .16187 L
F
.804 .522 .247 r
.15091 .16187 m
.15091 .0252 L
.15129 .0252 L
.15129 .16187 L
s
1 .894 .882 r
.15129 .16187 m
.15129 .02532 L
.15175 .02532 L
.15175 .16187 L
F
.804 .522 .247 r
.15129 .16187 m
.15129 .02532 L
.15175 .02532 L
.15175 .16187 L
s
1 .894 .882 r
.15175 .16187 m
.15175 .02536 L
.15211 .02536 L
.15211 .16187 L
F
.804 .522 .247 r
.15175 .16187 m
.15175 .02536 L
.15211 .02536 L
.15211 .16187 L
s
1 .894 .882 r
.15211 .16187 m
.15211 .02543 L
.15248 .02543 L
.15248 .16187 L
F
.804 .522 .247 r
.15211 .16187 m
.15211 .02543 L
.15248 .02543 L
.15248 .16187 L
s
1 .894 .882 r
.15248 .16187 m
.15248 .02549 L
.15306 .02549 L
.15306 .16187 L
F
.804 .522 .247 r
.15248 .16187 m
.15248 .02549 L
.15306 .02549 L
.15306 .16187 L
s
1 .894 .882 r
.15306 .16187 m
.15306 .02564 L
.15355 .02564 L
.15355 .16187 L
F
.804 .522 .247 r
.15306 .16187 m
.15306 .02564 L
.15355 .02564 L
.15355 .16187 L
s
1 .894 .882 r
.15355 .16187 m
.15355 .02569 L
.15399 .02569 L
.15399 .16187 L
F
.804 .522 .247 r
.15355 .16187 m
.15355 .02569 L
.15399 .02569 L
.15399 .16187 L
s
1 .894 .882 r
.15399 .16187 m
.15399 .02576 L
.1543 .02576 L
.1543 .16187 L
F
.804 .522 .247 r
.15399 .16187 m
.15399 .02576 L
.1543 .02576 L
.1543 .16187 L
s
1 .894 .882 r
.1543 .16187 m
.1543 .02578 L
.15456 .02578 L
.15456 .16187 L
F
.804 .522 .247 r
.1543 .16187 m
.1543 .02578 L
.15456 .02578 L
.15456 .16187 L
s
1 .894 .882 r
.15456 .16187 m
.15456 .02584 L
.15477 .02584 L
.15477 .16187 L
F
.804 .522 .247 r
.15456 .16187 m
.15456 .02584 L
.15477 .02584 L
.15477 .16187 L
s
1 .894 .882 r
.15477 .16187 m
.15477 .02587 L
.15509 .02587 L
.15509 .16187 L
F
.804 .522 .247 r
.15477 .16187 m
.15477 .02587 L
.15509 .02587 L
.15509 .16187 L
s
1 .894 .882 r
.15509 .16187 m
.15509 .02593 L
.1553 .02593 L
.1553 .16187 L
F
.804 .522 .247 r
.15509 .16187 m
.15509 .02593 L
.1553 .02593 L
.1553 .16187 L
s
1 .894 .882 r
.1553 .16187 m
.1553 .02596 L
.15549 .02596 L
.15549 .16187 L
F
.804 .522 .247 r
.1553 .16187 m
.1553 .02596 L
.15549 .02596 L
.15549 .16187 L
s
1 .894 .882 r
.15549 .16187 m
.15549 .02604 L
.15604 .02604 L
.15604 .16187 L
F
.804 .522 .247 r
.15549 .16187 m
.15549 .02604 L
.15604 .02604 L
.15604 .16187 L
s
1 .894 .882 r
.15604 .16187 m
.15604 .02615 L
.15665 .02615 L
.15665 .16187 L
F
.804 .522 .247 r
.15604 .16187 m
.15604 .02615 L
.15665 .02615 L
.15665 .16187 L
s
1 .894 .882 r
.15665 .16187 m
.15665 .02624 L
.15728 .02624 L
.15728 .16187 L
F
.804 .522 .247 r
.15665 .16187 m
.15665 .02624 L
.15728 .02624 L
.15728 .16187 L
s
1 .894 .882 r
.15728 .16187 m
.15728 .02628 L
.15758 .02628 L
.15758 .16187 L
F
.804 .522 .247 r
.15728 .16187 m
.15728 .02628 L
.15758 .02628 L
.15758 .16187 L
s
1 .894 .882 r
.15758 .16187 m
.15758 .02635 L
.15813 .02635 L
.15813 .16187 L
F
.804 .522 .247 r
.15758 .16187 m
.15758 .02635 L
.15813 .02635 L
.15813 .16187 L
s
1 .894 .882 r
.15813 .16187 m
.15813 .02644 L
.15834 .02644 L
.15834 .16187 L
F
.804 .522 .247 r
.15813 .16187 m
.15813 .02644 L
.15834 .02644 L
.15834 .16187 L
s
1 .894 .882 r
.15834 .16187 m
.15834 .02649 L
.15872 .02649 L
.15872 .16187 L
F
.804 .522 .247 r
.15834 .16187 m
.15834 .02649 L
.15872 .02649 L
.15872 .16187 L
s
1 .894 .882 r
.15872 .16187 m
.15872 .02659 L
.15932 .02659 L
.15932 .16187 L
F
.804 .522 .247 r
.15872 .16187 m
.15872 .02659 L
.15932 .02659 L
.15932 .16187 L
s
1 .894 .882 r
.15932 .16187 m
.15932 .02668 L
.15985 .02668 L
.15985 .16187 L
F
.804 .522 .247 r
.15932 .16187 m
.15932 .02668 L
.15985 .02668 L
.15985 .16187 L
s
1 .894 .882 r
.15985 .16187 m
.15985 .0268 L
.16035 .0268 L
.16035 .16187 L
F
.804 .522 .247 r
.15985 .16187 m
.15985 .0268 L
.16035 .0268 L
.16035 .16187 L
s
1 .894 .882 r
.16035 .16187 m
.16035 .02686 L
.16069 .02686 L
.16069 .16187 L
F
.804 .522 .247 r
.16035 .16187 m
.16035 .02686 L
.16069 .02686 L
.16069 .16187 L
s
1 .894 .882 r
.16069 .16187 m
.16069 .02692 L
.1611 .02692 L
.1611 .16187 L
F
.804 .522 .247 r
.16069 .16187 m
.16069 .02692 L
.1611 .02692 L
.1611 .16187 L
s
1 .894 .882 r
.1611 .16187 m
.1611 .02698 L
.16136 .02698 L
.16136 .16187 L
F
.804 .522 .247 r
.1611 .16187 m
.1611 .02698 L
.16136 .02698 L
.16136 .16187 L
s
1 .894 .882 r
.16136 .16187 m
.16136 .02702 L
.16169 .02702 L
.16169 .16187 L
F
.804 .522 .247 r
.16136 .16187 m
.16136 .02702 L
.16169 .02702 L
.16169 .16187 L
s
1 .894 .882 r
.16169 .16187 m
.16169 .02709 L
.16229 .02709 L
.16229 .16187 L
F
.804 .522 .247 r
.16169 .16187 m
.16169 .02709 L
.16229 .02709 L
.16229 .16187 L
s
1 .894 .882 r
.16229 .16187 m
.16229 .02719 L
.16277 .02719 L
.16277 .16187 L
F
.804 .522 .247 r
.16229 .16187 m
.16229 .02719 L
.16277 .02719 L
.16277 .16187 L
s
1 .894 .882 r
.16277 .16187 m
.16277 .0273 L
.16317 .0273 L
.16317 .16187 L
F
.804 .522 .247 r
.16277 .16187 m
.16277 .0273 L
.16317 .0273 L
.16317 .16187 L
s
1 .894 .882 r
.16317 .16187 m
.16317 .02739 L
.16371 .02739 L
.16371 .16187 L
F
.804 .522 .247 r
.16317 .16187 m
.16317 .02739 L
.16371 .02739 L
.16371 .16187 L
s
1 .894 .882 r
.16371 .16187 m
.16371 .02745 L
.16419 .02745 L
.16419 .16187 L
F
.804 .522 .247 r
.16371 .16187 m
.16371 .02745 L
.16419 .02745 L
.16419 .16187 L
s
1 .894 .882 r
.16419 .16187 m
.16419 .02758 L
.16459 .02758 L
.16459 .16187 L
F
.804 .522 .247 r
.16419 .16187 m
.16419 .02758 L
.16459 .02758 L
.16459 .16187 L
s
1 .894 .882 r
.16459 .16187 m
.16459 .02764 L
.16497 .02764 L
.16497 .16187 L
F
.804 .522 .247 r
.16459 .16187 m
.16459 .02764 L
.16497 .02764 L
.16497 .16187 L
s
1 .894 .882 r
.16497 .16187 m
.16497 .02767 L
.16538 .02767 L
.16538 .16187 L
F
.804 .522 .247 r
.16497 .16187 m
.16497 .02767 L
.16538 .02767 L
.16538 .16187 L
s
1 .894 .882 r
.16538 .16187 m
.16538 .02776 L
.16585 .02776 L
.16585 .16187 L
F
.804 .522 .247 r
.16538 .16187 m
.16538 .02776 L
.16585 .02776 L
.16585 .16187 L
s
1 .894 .882 r
.16585 .16187 m
.16585 .02783 L
.16625 .02783 L
.16625 .16187 L
F
.804 .522 .247 r
.16585 .16187 m
.16585 .02783 L
.16625 .02783 L
.16625 .16187 L
s
1 .894 .882 r
.16625 .16187 m
.16625 .0279 L
.16672 .0279 L
.16672 .16187 L
F
.804 .522 .247 r
.16625 .16187 m
.16625 .0279 L
.16672 .0279 L
.16672 .16187 L
s
1 .894 .882 r
.16672 .16187 m
.16672 .02801 L
.16716 .02801 L
.16716 .16187 L
F
.804 .522 .247 r
.16672 .16187 m
.16672 .02801 L
.16716 .02801 L
.16716 .16187 L
s
1 .894 .882 r
.16716 .16187 m
.16716 .02812 L
.16764 .02812 L
.16764 .16187 L
F
.804 .522 .247 r
.16716 .16187 m
.16716 .02812 L
.16764 .02812 L
.16764 .16187 L
s
1 .894 .882 r
.16764 .16187 m
.16764 .02815 L
.16793 .02815 L
.16793 .16187 L
F
.804 .522 .247 r
.16764 .16187 m
.16764 .02815 L
.16793 .02815 L
.16793 .16187 L
s
1 .894 .882 r
.16793 .16187 m
.16793 .02829 L
.16848 .02829 L
.16848 .16187 L
F
.804 .522 .247 r
.16793 .16187 m
.16793 .02829 L
.16848 .02829 L
.16848 .16187 L
s
1 .894 .882 r
.16848 .16187 m
.16848 .02837 L
.1689 .02837 L
.1689 .16187 L
F
.804 .522 .247 r
.16848 .16187 m
.16848 .02837 L
.1689 .02837 L
.1689 .16187 L
s
1 .894 .882 r
.1689 .16187 m
.1689 .02839 L
.1692 .02839 L
.1692 .16187 L
F
.804 .522 .247 r
.1689 .16187 m
.1689 .02839 L
.1692 .02839 L
.1692 .16187 L
s
1 .894 .882 r
.1692 .16187 m
.1692 .02847 L
.16952 .02847 L
.16952 .16187 L
F
.804 .522 .247 r
.1692 .16187 m
.1692 .02847 L
.16952 .02847 L
.16952 .16187 L
s
1 .894 .882 r
.16952 .16187 m
.16952 .02851 L
.16974 .02851 L
.16974 .16187 L
F
.804 .522 .247 r
.16952 .16187 m
.16952 .02851 L
.16974 .02851 L
.16974 .16187 L
s
1 .894 .882 r
.16974 .16187 m
.16974 .02855 L
.17029 .02855 L
.17029 .16187 L
F
.804 .522 .247 r
.16974 .16187 m
.16974 .02855 L
.17029 .02855 L
.17029 .16187 L
s
1 .894 .882 r
.17029 .16187 m
.17029 .02869 L
.17089 .02869 L
.17089 .16187 L
F
.804 .522 .247 r
.17029 .16187 m
.17029 .02869 L
.17089 .02869 L
.17089 .16187 L
s
1 .894 .882 r
.17089 .16187 m
.17089 .02885 L
.17144 .02885 L
.17144 .16187 L
F
.804 .522 .247 r
.17089 .16187 m
.17089 .02885 L
.17144 .02885 L
.17144 .16187 L
s
1 .894 .882 r
.17144 .16187 m
.17144 .02894 L
.17204 .02894 L
.17204 .16187 L
F
.804 .522 .247 r
.17144 .16187 m
.17144 .02894 L
.17204 .02894 L
.17204 .16187 L
s
1 .894 .882 r
.17204 .16187 m
.17204 .02903 L
.17245 .02903 L
.17245 .16187 L
F
.804 .522 .247 r
.17204 .16187 m
.17204 .02903 L
.17245 .02903 L
.17245 .16187 L
s
1 .894 .882 r
.17245 .16187 m
.17245 .02907 L
.17308 .02907 L
.17308 .16187 L
F
.804 .522 .247 r
.17245 .16187 m
.17245 .02907 L
.17308 .02907 L
.17308 .16187 L
s
1 .894 .882 r
.17308 .16187 m
.17308 .02921 L
.17335 .02921 L
.17335 .16187 L
F
.804 .522 .247 r
.17308 .16187 m
.17308 .02921 L
.17335 .02921 L
.17335 .16187 L
s
1 .894 .882 r
.17335 .16187 m
.17335 .0293 L
.17374 .0293 L
.17374 .16187 L
F
.804 .522 .247 r
.17335 .16187 m
.17335 .0293 L
.17374 .0293 L
.17374 .16187 L
s
1 .894 .882 r
.17374 .16187 m
.17374 .0294 L
.17425 .0294 L
.17425 .16187 L
F
.804 .522 .247 r
.17374 .16187 m
.17374 .0294 L
.17425 .0294 L
.17425 .16187 L
s
1 .894 .882 r
.17425 .16187 m
.17425 .02946 L
.17459 .02946 L
.17459 .16187 L
F
.804 .522 .247 r
.17425 .16187 m
.17425 .02946 L
.17459 .02946 L
.17459 .16187 L
s
1 .894 .882 r
.17459 .16187 m
.17459 .02953 L
.1751 .02953 L
.1751 .16187 L
F
.804 .522 .247 r
.17459 .16187 m
.17459 .02953 L
.1751 .02953 L
.1751 .16187 L
s
1 .894 .882 r
.1751 .16187 m
.1751 .02957 L
.1753 .02957 L
.1753 .16187 L
F
.804 .522 .247 r
.1751 .16187 m
.1751 .02957 L
.1753 .02957 L
.1753 .16187 L
s
1 .894 .882 r
.1753 .16187 m
.1753 .02964 L
.17559 .02964 L
.17559 .16187 L
F
.804 .522 .247 r
.1753 .16187 m
.1753 .02964 L
.17559 .02964 L
.17559 .16187 L
s
1 .894 .882 r
.17559 .16187 m
.17559 .0297 L
.1761 .0297 L
.1761 .16187 L
F
.804 .522 .247 r
.17559 .16187 m
.17559 .0297 L
.1761 .0297 L
.1761 .16187 L
s
1 .894 .882 r
.1761 .16187 m
.1761 .02978 L
.1764 .02978 L
.1764 .16187 L
F
.804 .522 .247 r
.1761 .16187 m
.1761 .02978 L
.1764 .02978 L
.1764 .16187 L
s
1 .894 .882 r
.1764 .16187 m
.1764 .02989 L
.17676 .02989 L
.17676 .16187 L
F
.804 .522 .247 r
.1764 .16187 m
.1764 .02989 L
.17676 .02989 L
.17676 .16187 L
s
1 .894 .882 r
.17676 .16187 m
.17676 .02991 L
.17726 .02991 L
.17726 .16187 L
F
.804 .522 .247 r
.17676 .16187 m
.17676 .02991 L
.17726 .02991 L
.17726 .16187 L
s
1 .894 .882 r
.17726 .16187 m
.17726 .03002 L
.17748 .03002 L
.17748 .16187 L
F
.804 .522 .247 r
.17726 .16187 m
.17726 .03002 L
.17748 .03002 L
.17748 .16187 L
s
1 .894 .882 r
.17748 .16187 m
.17748 .03004 L
.17768 .03004 L
.17768 .16187 L
F
.804 .522 .247 r
.17748 .16187 m
.17748 .03004 L
.17768 .03004 L
.17768 .16187 L
s
1 .894 .882 r
.17768 .16187 m
.17768 .03017 L
.17813 .03017 L
.17813 .16187 L
F
.804 .522 .247 r
.17768 .16187 m
.17768 .03017 L
.17813 .03017 L
.17813 .16187 L
s
1 .894 .882 r
.17813 .16187 m
.17813 .03018 L
.1784 .03018 L
.1784 .16187 L
F
.804 .522 .247 r
.17813 .16187 m
.17813 .03018 L
.1784 .03018 L
.1784 .16187 L
s
1 .894 .882 r
.1784 .16187 m
.1784 .03025 L
.17895 .03025 L
.17895 .16187 L
F
.804 .522 .247 r
.1784 .16187 m
.1784 .03025 L
.17895 .03025 L
.17895 .16187 L
s
1 .894 .882 r
.17895 .16187 m
.17895 .0304 L
.17947 .0304 L
.17947 .16187 L
F
.804 .522 .247 r
.17895 .16187 m
.17895 .0304 L
.17947 .0304 L
.17947 .16187 L
s
1 .894 .882 r
.17947 .16187 m
.17947 .03048 L
.17989 .03048 L
.17989 .16187 L
F
.804 .522 .247 r
.17947 .16187 m
.17947 .03048 L
.17989 .03048 L
.17989 .16187 L
s
1 .894 .882 r
.17989 .16187 m
.17989 .03053 L
.18025 .03053 L
.18025 .16187 L
F
.804 .522 .247 r
.17989 .16187 m
.17989 .03053 L
.18025 .03053 L
.18025 .16187 L
s
1 .894 .882 r
.18025 .16187 m
.18025 .0307 L
.18085 .0307 L
.18085 .16187 L
F
.804 .522 .247 r
.18025 .16187 m
.18025 .0307 L
.18085 .0307 L
.18085 .16187 L
s
1 .894 .882 r
.18085 .16187 m
.18085 .0308 L
.18145 .0308 L
.18145 .16187 L
F
.804 .522 .247 r
.18085 .16187 m
.18085 .0308 L
.18145 .0308 L
.18145 .16187 L
s
1 .894 .882 r
.18145 .16187 m
.18145 .03091 L
.18191 .03091 L
.18191 .16187 L
F
.804 .522 .247 r
.18145 .16187 m
.18145 .03091 L
.18191 .03091 L
.18191 .16187 L
s
1 .894 .882 r
.18191 .16187 m
.18191 .03099 L
.18249 .03099 L
.18249 .16187 L
F
.804 .522 .247 r
.18191 .16187 m
.18191 .03099 L
.18249 .03099 L
.18249 .16187 L
s
1 .894 .882 r
.18249 .16187 m
.18249 .03114 L
.1831 .03114 L
.1831 .16187 L
F
.804 .522 .247 r
.18249 .16187 m
.18249 .03114 L
.1831 .03114 L
.1831 .16187 L
s
1 .894 .882 r
.1831 .16187 m
.1831 .03118 L
.18362 .03118 L
.18362 .16187 L
F
.804 .522 .247 r
.1831 .16187 m
.1831 .03118 L
.18362 .03118 L
.18362 .16187 L
s
1 .894 .882 r
.18362 .16187 m
.18362 .03133 L
.18388 .03133 L
.18388 .16187 L
F
.804 .522 .247 r
.18362 .16187 m
.18362 .03133 L
.18388 .03133 L
.18388 .16187 L
s
1 .894 .882 r
.18388 .16187 m
.18388 .03137 L
.18415 .03137 L
.18415 .16187 L
F
.804 .522 .247 r
.18388 .16187 m
.18388 .03137 L
.18415 .03137 L
.18415 .16187 L
s
1 .894 .882 r
.18415 .16187 m
.18415 .03148 L
.1846 .03148 L
.1846 .16187 L
F
.804 .522 .247 r
.18415 .16187 m
.18415 .03148 L
.1846 .03148 L
.1846 .16187 L
s
1 .894 .882 r
.1846 .16187 m
.1846 .03151 L
.18481 .03151 L
.18481 .16187 L
F
.804 .522 .247 r
.1846 .16187 m
.1846 .03151 L
.18481 .03151 L
.18481 .16187 L
s
1 .894 .882 r
.18481 .16187 m
.18481 .03157 L
.18507 .03157 L
.18507 .16187 L
F
.804 .522 .247 r
.18481 .16187 m
.18481 .03157 L
.18507 .03157 L
.18507 .16187 L
s
1 .894 .882 r
.18507 .16187 m
.18507 .0317 L
.18568 .0317 L
.18568 .16187 L
F
.804 .522 .247 r
.18507 .16187 m
.18507 .0317 L
.18568 .0317 L
.18568 .16187 L
s
1 .894 .882 r
.18568 .16187 m
.18568 .03178 L
.18626 .03178 L
.18626 .16187 L
F
.804 .522 .247 r
.18568 .16187 m
.18568 .03178 L
.18626 .03178 L
.18626 .16187 L
s
1 .894 .882 r
.18626 .16187 m
.18626 .03185 L
.18681 .03185 L
.18681 .16187 L
F
.804 .522 .247 r
.18626 .16187 m
.18626 .03185 L
.18681 .03185 L
.18681 .16187 L
s
1 .894 .882 r
.18681 .16187 m
.18681 .03204 L
.18734 .03204 L
.18734 .16187 L
F
.804 .522 .247 r
.18681 .16187 m
.18681 .03204 L
.18734 .03204 L
.18734 .16187 L
s
1 .894 .882 r
.18734 .16187 m
.18734 .03212 L
.18765 .03212 L
.18765 .16187 L
F
.804 .522 .247 r
.18734 .16187 m
.18734 .03212 L
.18765 .03212 L
.18765 .16187 L
s
1 .894 .882 r
.18765 .16187 m
.18765 .03225 L
.1882 .03225 L
.1882 .16187 L
F
.804 .522 .247 r
.18765 .16187 m
.18765 .03225 L
.1882 .03225 L
.1882 .16187 L
s
1 .894 .882 r
.1882 .16187 m
.1882 .03236 L
.18875 .03236 L
.18875 .16187 L
F
.804 .522 .247 r
.1882 .16187 m
.1882 .03236 L
.18875 .03236 L
.18875 .16187 L
s
1 .894 .882 r
.18875 .16187 m
.18875 .03241 L
.18901 .03241 L
.18901 .16187 L
F
.804 .522 .247 r
.18875 .16187 m
.18875 .03241 L
.18901 .03241 L
.18901 .16187 L
s
1 .894 .882 r
.18901 .16187 m
.18901 .03245 L
.18925 .03245 L
.18925 .16187 L
F
.804 .522 .247 r
.18901 .16187 m
.18901 .03245 L
.18925 .03245 L
.18925 .16187 L
s
1 .894 .882 r
.18925 .16187 m
.18925 .03257 L
.18988 .03257 L
.18988 .16187 L
F
.804 .522 .247 r
.18925 .16187 m
.18925 .03257 L
.18988 .03257 L
.18988 .16187 L
s
1 .894 .882 r
.18988 .16187 m
.18988 .03263 L
.1901 .03263 L
.1901 .16187 L
F
.804 .522 .247 r
.18988 .16187 m
.18988 .03263 L
.1901 .03263 L
.1901 .16187 L
s
1 .894 .882 r
.1901 .16187 m
.1901 .03268 L
.19058 .03268 L
.19058 .16187 L
F
.804 .522 .247 r
.1901 .16187 m
.1901 .03268 L
.19058 .03268 L
.19058 .16187 L
s
1 .894 .882 r
.19058 .16187 m
.19058 .0328 L
.19109 .0328 L
.19109 .16187 L
F
.804 .522 .247 r
.19058 .16187 m
.19058 .0328 L
.19109 .0328 L
.19109 .16187 L
s
1 .894 .882 r
.19109 .16187 m
.19109 .03292 L
.19132 .03292 L
.19132 .16187 L
F
.804 .522 .247 r
.19109 .16187 m
.19109 .03292 L
.19132 .03292 L
.19132 .16187 L
s
1 .894 .882 r
.19132 .16187 m
.19132 .03296 L
.19157 .03296 L
.19157 .16187 L
F
.804 .522 .247 r
.19132 .16187 m
.19132 .03296 L
.19157 .03296 L
.19157 .16187 L
s
1 .894 .882 r
.19157 .16187 m
.19157 .033 L
.19179 .033 L
.19179 .16187 L
F
.804 .522 .247 r
.19157 .16187 m
.19157 .033 L
.19179 .033 L
.19179 .16187 L
s
1 .894 .882 r
.19179 .16187 m
.19179 .03314 L
.19235 .03314 L
.19235 .16187 L
F
.804 .522 .247 r
.19179 .16187 m
.19179 .03314 L
.19235 .03314 L
.19235 .16187 L
s
1 .894 .882 r
.19235 .16187 m
.19235 .03316 L
.19261 .03316 L
.19261 .16187 L
F
.804 .522 .247 r
.19235 .16187 m
.19235 .03316 L
.19261 .03316 L
.19261 .16187 L
s
1 .894 .882 r
.19261 .16187 m
.19261 .03326 L
.19298 .03326 L
.19298 .16187 L
F
.804 .522 .247 r
.19261 .16187 m
.19261 .03326 L
.19298 .03326 L
.19298 .16187 L
s
1 .894 .882 r
.19298 .16187 m
.19298 .03338 L
.19358 .03338 L
.19358 .16187 L
F
.804 .522 .247 r
.19298 .16187 m
.19298 .03338 L
.19358 .03338 L
.19358 .16187 L
s
1 .894 .882 r
.19358 .16187 m
.19358 .03346 L
.19406 .03346 L
.19406 .16187 L
F
.804 .522 .247 r
.19358 .16187 m
.19358 .03346 L
.19406 .03346 L
.19406 .16187 L
s
1 .894 .882 r
.19406 .16187 m
.19406 .03356 L
.19451 .03356 L
.19451 .16187 L
F
.804 .522 .247 r
.19406 .16187 m
.19406 .03356 L
.19451 .03356 L
.19451 .16187 L
s
1 .894 .882 r
.19451 .16187 m
.19451 .03364 L
.19486 .03364 L
.19486 .16187 L
F
.804 .522 .247 r
.19451 .16187 m
.19451 .03364 L
.19486 .03364 L
.19486 .16187 L
s
1 .894 .882 r
.19486 .16187 m
.19486 .0337 L
.19539 .0337 L
.19539 .16187 L
F
.804 .522 .247 r
.19486 .16187 m
.19486 .0337 L
.19539 .0337 L
.19539 .16187 L
s
1 .894 .882 r
.19539 .16187 m
.19539 .03388 L
.1959 .03388 L
.1959 .16187 L
F
.804 .522 .247 r
.19539 .16187 m
.19539 .03388 L
.1959 .03388 L
.1959 .16187 L
s
1 .894 .882 r
.1959 .16187 m
.1959 .03402 L
.1964 .03402 L
.1964 .16187 L
F
.804 .522 .247 r
.1959 .16187 m
.1959 .03402 L
.1964 .03402 L
.1964 .16187 L
s
1 .894 .882 r
.1964 .16187 m
.1964 .03407 L
.19684 .03407 L
.19684 .16187 L
F
.804 .522 .247 r
.1964 .16187 m
.1964 .03407 L
.19684 .03407 L
.19684 .16187 L
s
1 .894 .882 r
.19684 .16187 m
.19684 .03416 L
.19704 .03416 L
.19704 .16187 L
F
.804 .522 .247 r
.19684 .16187 m
.19684 .03416 L
.19704 .03416 L
.19704 .16187 L
s
1 .894 .882 r
.19704 .16187 m
.19704 .03426 L
.19742 .03426 L
.19742 .16187 L
F
.804 .522 .247 r
.19704 .16187 m
.19704 .03426 L
.19742 .03426 L
.19742 .16187 L
s
1 .894 .882 r
.19742 .16187 m
.19742 .03439 L
.19801 .03439 L
.19801 .16187 L
F
.804 .522 .247 r
.19742 .16187 m
.19742 .03439 L
.19801 .03439 L
.19801 .16187 L
s
1 .894 .882 r
.19801 .16187 m
.19801 .03445 L
.19855 .03445 L
.19855 .16187 L
F
.804 .522 .247 r
.19801 .16187 m
.19801 .03445 L
.19855 .03445 L
.19855 .16187 L
s
1 .894 .882 r
.19855 .16187 m
.19855 .0346 L
.19912 .0346 L
.19912 .16187 L
F
.804 .522 .247 r
.19855 .16187 m
.19855 .0346 L
.19912 .0346 L
.19912 .16187 L
s
1 .894 .882 r
.19912 .16187 m
.19912 .03469 L
.19946 .03469 L
.19946 .16187 L
F
.804 .522 .247 r
.19912 .16187 m
.19912 .03469 L
.19946 .03469 L
.19946 .16187 L
s
1 .894 .882 r
.19946 .16187 m
.19946 .03476 L
.20006 .03476 L
.20006 .16187 L
F
.804 .522 .247 r
.19946 .16187 m
.19946 .03476 L
.20006 .03476 L
.20006 .16187 L
s
1 .894 .882 r
.20006 .16187 m
.20006 .03488 L
.20056 .03488 L
.20056 .16187 L
F
.804 .522 .247 r
.20006 .16187 m
.20006 .03488 L
.20056 .03488 L
.20056 .16187 L
s
1 .894 .882 r
.20056 .16187 m
.20056 .03501 L
.20085 .03501 L
.20085 .16187 L
F
.804 .522 .247 r
.20056 .16187 m
.20056 .03501 L
.20085 .03501 L
.20085 .16187 L
s
1 .894 .882 r
.20085 .16187 m
.20085 .03516 L
.20131 .03516 L
.20131 .16187 L
F
.804 .522 .247 r
.20085 .16187 m
.20085 .03516 L
.20131 .03516 L
.20131 .16187 L
s
1 .894 .882 r
.20131 .16187 m
.20131 .0352 L
.20187 .0352 L
.20187 .16187 L
F
.804 .522 .247 r
.20131 .16187 m
.20131 .0352 L
.20187 .0352 L
.20187 .16187 L
s
1 .894 .882 r
.20187 .16187 m
.20187 .03533 L
.20231 .03533 L
.20231 .16187 L
F
.804 .522 .247 r
.20187 .16187 m
.20187 .03533 L
.20231 .03533 L
.20231 .16187 L
s
1 .894 .882 r
.20231 .16187 m
.20231 .03544 L
.20258 .03544 L
.20258 .16187 L
F
.804 .522 .247 r
.20231 .16187 m
.20231 .03544 L
.20258 .03544 L
.20258 .16187 L
s
1 .894 .882 r
.20258 .16187 m
.20258 .03547 L
.20311 .03547 L
.20311 .16187 L
F
.804 .522 .247 r
.20258 .16187 m
.20258 .03547 L
.20311 .03547 L
.20311 .16187 L
s
1 .894 .882 r
.20311 .16187 m
.20311 .03559 L
.2036 .03559 L
.2036 .16187 L
F
.804 .522 .247 r
.20311 .16187 m
.20311 .03559 L
.2036 .03559 L
.2036 .16187 L
s
1 .894 .882 r
.2036 .16187 m
.2036 .03574 L
.20386 .03574 L
.20386 .16187 L
F
.804 .522 .247 r
.2036 .16187 m
.2036 .03574 L
.20386 .03574 L
.20386 .16187 L
s
1 .894 .882 r
.20386 .16187 m
.20386 .03576 L
.20417 .03576 L
.20417 .16187 L
F
.804 .522 .247 r
.20386 .16187 m
.20386 .03576 L
.20417 .03576 L
.20417 .16187 L
s
1 .894 .882 r
.20417 .16187 m
.20417 .03587 L
.20442 .03587 L
.20442 .16187 L
F
.804 .522 .247 r
.20417 .16187 m
.20417 .03587 L
.20442 .03587 L
.20442 .16187 L
s
1 .894 .882 r
.20442 .16187 m
.20442 .03593 L
.20465 .03593 L
.20465 .16187 L
F
.804 .522 .247 r
.20442 .16187 m
.20442 .03593 L
.20465 .03593 L
.20465 .16187 L
s
1 .894 .882 r
.20465 .16187 m
.20465 .036 L
.2052 .036 L
.2052 .16187 L
F
.804 .522 .247 r
.20465 .16187 m
.20465 .036 L
.2052 .036 L
.2052 .16187 L
s
1 .894 .882 r
.2052 .16187 m
.2052 .03608 L
.20562 .03608 L
.20562 .16187 L
F
.804 .522 .247 r
.2052 .16187 m
.2052 .03608 L
.20562 .03608 L
.20562 .16187 L
s
1 .894 .882 r
.20562 .16187 m
.20562 .03618 L
.20599 .03618 L
.20599 .16187 L
F
.804 .522 .247 r
.20562 .16187 m
.20562 .03618 L
.20599 .03618 L
.20599 .16187 L
s
1 .894 .882 r
.20599 .16187 m
.20599 .03626 L
.20636 .03626 L
.20636 .16187 L
F
.804 .522 .247 r
.20599 .16187 m
.20599 .03626 L
.20636 .03626 L
.20636 .16187 L
s
1 .894 .882 r
.20636 .16187 m
.20636 .03636 L
.20666 .03636 L
.20666 .16187 L
F
.804 .522 .247 r
.20636 .16187 m
.20636 .03636 L
.20666 .03636 L
.20666 .16187 L
s
1 .894 .882 r
.20666 .16187 m
.20666 .0365 L
.20707 .0365 L
.20707 .16187 L
F
.804 .522 .247 r
.20666 .16187 m
.20666 .0365 L
.20707 .0365 L
.20707 .16187 L
s
1 .894 .882 r
.20707 .16187 m
.20707 .03657 L
.2077 .03657 L
.2077 .16187 L
F
.804 .522 .247 r
.20707 .16187 m
.20707 .03657 L
.2077 .03657 L
.2077 .16187 L
s
1 .894 .882 r
.2077 .16187 m
.2077 .03668 L
.20812 .03668 L
.20812 .16187 L
F
.804 .522 .247 r
.2077 .16187 m
.2077 .03668 L
.20812 .03668 L
.20812 .16187 L
s
1 .894 .882 r
.20812 .16187 m
.20812 .03685 L
.20852 .03685 L
.20852 .16187 L
F
.804 .522 .247 r
.20812 .16187 m
.20812 .03685 L
.20852 .03685 L
.20852 .16187 L
s
1 .894 .882 r
.20852 .16187 m
.20852 .03689 L
.20899 .03689 L
.20899 .16187 L
F
.804 .522 .247 r
.20852 .16187 m
.20852 .03689 L
.20899 .03689 L
.20899 .16187 L
s
1 .894 .882 r
.20899 .16187 m
.20899 .03697 L
.20947 .03697 L
.20947 .16187 L
F
.804 .522 .247 r
.20899 .16187 m
.20899 .03697 L
.20947 .03697 L
.20947 .16187 L
s
1 .894 .882 r
.20947 .16187 m
.20947 .03719 L
.20993 .03719 L
.20993 .16187 L
F
.804 .522 .247 r
.20947 .16187 m
.20947 .03719 L
.20993 .03719 L
.20993 .16187 L
s
1 .894 .882 r
.20993 .16187 m
.20993 .03731 L
.21047 .03731 L
.21047 .16187 L
F
.804 .522 .247 r
.20993 .16187 m
.20993 .03731 L
.21047 .03731 L
.21047 .16187 L
s
1 .894 .882 r
.21047 .16187 m
.21047 .03733 L
.21084 .03733 L
.21084 .16187 L
F
.804 .522 .247 r
.21047 .16187 m
.21047 .03733 L
.21084 .03733 L
.21084 .16187 L
s
1 .894 .882 r
.21084 .16187 m
.21084 .03742 L
.21106 .03742 L
.21106 .16187 L
F
.804 .522 .247 r
.21084 .16187 m
.21084 .03742 L
.21106 .03742 L
.21106 .16187 L
s
1 .894 .882 r
.21106 .16187 m
.21106 .03755 L
.21159 .03755 L
.21159 .16187 L
F
.804 .522 .247 r
.21106 .16187 m
.21106 .03755 L
.21159 .03755 L
.21159 .16187 L
s
1 .894 .882 r
.21159 .16187 m
.21159 .03763 L
.21189 .03763 L
.21189 .16187 L
F
.804 .522 .247 r
.21159 .16187 m
.21159 .03763 L
.21189 .03763 L
.21189 .16187 L
s
1 .894 .882 r
.21189 .16187 m
.21189 .03769 L
.21218 .03769 L
.21218 .16187 L
F
.804 .522 .247 r
.21189 .16187 m
.21189 .03769 L
.21218 .03769 L
.21218 .16187 L
s
1 .894 .882 r
.21218 .16187 m
.21218 .03782 L
.2125 .03782 L
.2125 .16187 L
F
.804 .522 .247 r
.21218 .16187 m
.21218 .03782 L
.2125 .03782 L
.2125 .16187 L
s
1 .894 .882 r
.2125 .16187 m
.2125 .03785 L
.21273 .03785 L
.21273 .16187 L
F
.804 .522 .247 r
.2125 .16187 m
.2125 .03785 L
.21273 .03785 L
.21273 .16187 L
s
1 .894 .882 r
.21273 .16187 m
.21273 .03792 L
.21296 .03792 L
.21296 .16187 L
F
.804 .522 .247 r
.21273 .16187 m
.21273 .03792 L
.21296 .03792 L
.21296 .16187 L
s
1 .894 .882 r
.21296 .16187 m
.21296 .03795 L
.21358 .03795 L
.21358 .16187 L
F
.804 .522 .247 r
.21296 .16187 m
.21296 .03795 L
.21358 .03795 L
.21358 .16187 L
s
1 .894 .882 r
.21358 .16187 m
.21358 .0381 L
.21385 .0381 L
.21385 .16187 L
F
.804 .522 .247 r
.21358 .16187 m
.21358 .0381 L
.21385 .0381 L
.21385 .16187 L
s
1 .894 .882 r
.21385 .16187 m
.21385 .03826 L
.21449 .03826 L
.21449 .16187 L
F
.804 .522 .247 r
.21385 .16187 m
.21385 .03826 L
.21449 .03826 L
.21449 .16187 L
s
1 .894 .882 r
.21449 .16187 m
.21449 .03833 L
.2148 .03833 L
.2148 .16187 L
F
.804 .522 .247 r
.21449 .16187 m
.21449 .03833 L
.2148 .03833 L
.2148 .16187 L
s
1 .894 .882 r
.2148 .16187 m
.2148 .03848 L
.2152 .03848 L
.2152 .16187 L
F
.804 .522 .247 r
.2148 .16187 m
.2148 .03848 L
.2152 .03848 L
.2152 .16187 L
s
1 .894 .882 r
.2152 .16187 m
.2152 .03849 L
.21573 .03849 L
.21573 .16187 L
F
.804 .522 .247 r
.2152 .16187 m
.2152 .03849 L
.21573 .03849 L
.21573 .16187 L
s
1 .894 .882 r
.21573 .16187 m
.21573 .03869 L
.21619 .03869 L
.21619 .16187 L
F
.804 .522 .247 r
.21573 .16187 m
.21573 .03869 L
.21619 .03869 L
.21619 .16187 L
s
1 .894 .882 r
.21619 .16187 m
.21619 .03873 L
.21639 .03873 L
.21639 .16187 L
F
.804 .522 .247 r
.21619 .16187 m
.21619 .03873 L
.21639 .03873 L
.21639 .16187 L
s
1 .894 .882 r
.21639 .16187 m
.21639 .03879 L
.21702 .03879 L
.21702 .16187 L
F
.804 .522 .247 r
.21639 .16187 m
.21639 .03879 L
.21702 .03879 L
.21702 .16187 L
s
1 .894 .882 r
.21702 .16187 m
.21702 .03903 L
.21756 .03903 L
.21756 .16187 L
F
.804 .522 .247 r
.21702 .16187 m
.21702 .03903 L
.21756 .03903 L
.21756 .16187 L
s
1 .894 .882 r
.21756 .16187 m
.21756 .0391 L
.21779 .0391 L
.21779 .16187 L
F
.804 .522 .247 r
.21756 .16187 m
.21756 .0391 L
.21779 .0391 L
.21779 .16187 L
s
1 .894 .882 r
.21779 .16187 m
.21779 .03915 L
.21822 .03915 L
.21822 .16187 L
F
.804 .522 .247 r
.21779 .16187 m
.21779 .03915 L
.21822 .03915 L
.21822 .16187 L
s
1 .894 .882 r
.21822 .16187 m
.21822 .03931 L
.21858 .03931 L
.21858 .16187 L
F
.804 .522 .247 r
.21822 .16187 m
.21822 .03931 L
.21858 .03931 L
.21858 .16187 L
s
1 .894 .882 r
.21858 .16187 m
.21858 .03937 L
.21883 .03937 L
.21883 .16187 L
F
.804 .522 .247 r
.21858 .16187 m
.21858 .03937 L
.21883 .03937 L
.21883 .16187 L
s
1 .894 .882 r
.21883 .16187 m
.21883 .03945 L
.21924 .03945 L
.21924 .16187 L
F
.804 .522 .247 r
.21883 .16187 m
.21883 .03945 L
.21924 .03945 L
.21924 .16187 L
s
1 .894 .882 r
.21924 .16187 m
.21924 .03954 L
.21977 .03954 L
.21977 .16187 L
F
.804 .522 .247 r
.21924 .16187 m
.21924 .03954 L
.21977 .03954 L
.21977 .16187 L
s
1 .894 .882 r
.21977 .16187 m
.21977 .03974 L
.22039 .03974 L
.22039 .16187 L
F
.804 .522 .247 r
.21977 .16187 m
.21977 .03974 L
.22039 .03974 L
.22039 .16187 L
s
1 .894 .882 r
.22039 .16187 m
.22039 .03982 L
.22062 .03982 L
.22062 .16187 L
F
.804 .522 .247 r
.22039 .16187 m
.22039 .03982 L
.22062 .03982 L
.22062 .16187 L
s
1 .894 .882 r
.22062 .16187 m
.22062 .03996 L
.22113 .03996 L
.22113 .16187 L
F
.804 .522 .247 r
.22062 .16187 m
.22062 .03996 L
.22113 .03996 L
.22113 .16187 L
s
1 .894 .882 r
.22113 .16187 m
.22113 .04007 L
.22155 .04007 L
.22155 .16187 L
F
.804 .522 .247 r
.22113 .16187 m
.22113 .04007 L
.22155 .04007 L
.22155 .16187 L
s
1 .894 .882 r
.22155 .16187 m
.22155 .04015 L
.22208 .04015 L
.22208 .16187 L
F
.804 .522 .247 r
.22155 .16187 m
.22155 .04015 L
.22208 .04015 L
.22208 .16187 L
s
1 .894 .882 r
.22208 .16187 m
.22208 .04031 L
.22262 .04031 L
.22262 .16187 L
F
.804 .522 .247 r
.22208 .16187 m
.22208 .04031 L
.22262 .04031 L
.22262 .16187 L
s
1 .894 .882 r
.22262 .16187 m
.22262 .04041 L
.22309 .04041 L
.22309 .16187 L
F
.804 .522 .247 r
.22262 .16187 m
.22262 .04041 L
.22309 .04041 L
.22309 .16187 L
s
1 .894 .882 r
.22309 .16187 m
.22309 .04049 L
.22348 .04049 L
.22348 .16187 L
F
.804 .522 .247 r
.22309 .16187 m
.22309 .04049 L
.22348 .04049 L
.22348 .16187 L
s
1 .894 .882 r
.22348 .16187 m
.22348 .04064 L
.22402 .04064 L
.22402 .16187 L
F
.804 .522 .247 r
.22348 .16187 m
.22348 .04064 L
.22402 .04064 L
.22402 .16187 L
s
1 .894 .882 r
.22402 .16187 m
.22402 .04077 L
.22449 .04077 L
.22449 .16187 L
F
.804 .522 .247 r
.22402 .16187 m
.22402 .04077 L
.22449 .04077 L
.22449 .16187 L
s
1 .894 .882 r
.22449 .16187 m
.22449 .04093 L
.22496 .04093 L
.22496 .16187 L
F
.804 .522 .247 r
.22449 .16187 m
.22449 .04093 L
.22496 .04093 L
.22496 .16187 L
s
1 .894 .882 r
.22496 .16187 m
.22496 .04103 L
.22523 .04103 L
.22523 .16187 L
F
.804 .522 .247 r
.22496 .16187 m
.22496 .04103 L
.22523 .04103 L
.22523 .16187 L
s
1 .894 .882 r
.22523 .16187 m
.22523 .04108 L
.22556 .04108 L
.22556 .16187 L
F
.804 .522 .247 r
.22523 .16187 m
.22523 .04108 L
.22556 .04108 L
.22556 .16187 L
s
1 .894 .882 r
.22556 .16187 m
.22556 .04117 L
.22614 .04117 L
.22614 .16187 L
F
.804 .522 .247 r
.22556 .16187 m
.22556 .04117 L
.22614 .04117 L
.22614 .16187 L
s
1 .894 .882 r
.22614 .16187 m
.22614 .04133 L
.22635 .04133 L
.22635 .16187 L
F
.804 .522 .247 r
.22614 .16187 m
.22614 .04133 L
.22635 .04133 L
.22635 .16187 L
s
1 .894 .882 r
.22635 .16187 m
.22635 .04138 L
.2266 .04138 L
.2266 .16187 L
F
.804 .522 .247 r
.22635 .16187 m
.22635 .04138 L
.2266 .04138 L
.2266 .16187 L
s
1 .894 .882 r
.2266 .16187 m
.2266 .04143 L
.22693 .04143 L
.22693 .16187 L
F
.804 .522 .247 r
.2266 .16187 m
.2266 .04143 L
.22693 .04143 L
.22693 .16187 L
s
1 .894 .882 r
.22693 .16187 m
.22693 .04153 L
.22717 .04153 L
.22717 .16187 L
F
.804 .522 .247 r
.22693 .16187 m
.22693 .04153 L
.22717 .04153 L
.22717 .16187 L
s
1 .894 .882 r
.22717 .16187 m
.22717 .04163 L
.22778 .04163 L
.22778 .16187 L
F
.804 .522 .247 r
.22717 .16187 m
.22717 .04163 L
.22778 .04163 L
.22778 .16187 L
s
1 .894 .882 r
.22778 .16187 m
.22778 .04178 L
.22824 .04178 L
.22824 .16187 L
F
.804 .522 .247 r
.22778 .16187 m
.22778 .04178 L
.22824 .04178 L
.22824 .16187 L
s
1 .894 .882 r
.22824 .16187 m
.22824 .04193 L
.22885 .04193 L
.22885 .16187 L
F
.804 .522 .247 r
.22824 .16187 m
.22824 .04193 L
.22885 .04193 L
.22885 .16187 L
s
1 .894 .882 r
.22885 .16187 m
.22885 .042 L
.22948 .042 L
.22948 .16187 L
F
.804 .522 .247 r
.22885 .16187 m
.22885 .042 L
.22948 .042 L
.22948 .16187 L
s
1 .894 .882 r
.22948 .16187 m
.22948 .04217 L
.22987 .04217 L
.22987 .16187 L
F
.804 .522 .247 r
.22948 .16187 m
.22948 .04217 L
.22987 .04217 L
.22987 .16187 L
s
1 .894 .882 r
.22987 .16187 m
.22987 .04231 L
.23045 .04231 L
.23045 .16187 L
F
.804 .522 .247 r
.22987 .16187 m
.22987 .04231 L
.23045 .04231 L
.23045 .16187 L
s
1 .894 .882 r
.23045 .16187 m
.23045 .04258 L
.23107 .04258 L
.23107 .16187 L
F
.804 .522 .247 r
.23045 .16187 m
.23045 .04258 L
.23107 .04258 L
.23107 .16187 L
s
1 .894 .882 r
.23107 .16187 m
.23107 .04267 L
.23166 .04267 L
.23166 .16187 L
F
.804 .522 .247 r
.23107 .16187 m
.23107 .04267 L
.23166 .04267 L
.23166 .16187 L
s
1 .894 .882 r
.23166 .16187 m
.23166 .04277 L
.23218 .04277 L
.23218 .16187 L
F
.804 .522 .247 r
.23166 .16187 m
.23166 .04277 L
.23218 .04277 L
.23218 .16187 L
s
1 .894 .882 r
.23218 .16187 m
.23218 .04293 L
.23252 .04293 L
.23252 .16187 L
F
.804 .522 .247 r
.23218 .16187 m
.23218 .04293 L
.23252 .04293 L
.23252 .16187 L
s
1 .894 .882 r
.23252 .16187 m
.23252 .04302 L
.23281 .04302 L
.23281 .16187 L
F
.804 .522 .247 r
.23252 .16187 m
.23252 .04302 L
.23281 .04302 L
.23281 .16187 L
s
1 .894 .882 r
.23281 .16187 m
.23281 .04312 L
.23304 .04312 L
.23304 .16187 L
F
.804 .522 .247 r
.23281 .16187 m
.23281 .04312 L
.23304 .04312 L
.23304 .16187 L
s
1 .894 .882 r
.23304 .16187 m
.23304 .04318 L
.23329 .04318 L
.23329 .16187 L
F
.804 .522 .247 r
.23304 .16187 m
.23304 .04318 L
.23329 .04318 L
.23329 .16187 L
s
1 .894 .882 r
.23329 .16187 m
.23329 .04326 L
.23388 .04326 L
.23388 .16187 L
F
.804 .522 .247 r
.23329 .16187 m
.23329 .04326 L
.23388 .04326 L
.23388 .16187 L
s
1 .894 .882 r
.23388 .16187 m
.23388 .04336 L
.23427 .04336 L
.23427 .16187 L
F
.804 .522 .247 r
.23388 .16187 m
.23388 .04336 L
.23427 .04336 L
.23427 .16187 L
s
1 .894 .882 r
.23427 .16187 m
.23427 .04352 L
.23467 .04352 L
.23467 .16187 L
F
.804 .522 .247 r
.23427 .16187 m
.23427 .04352 L
.23467 .04352 L
.23467 .16187 L
s
1 .894 .882 r
.23467 .16187 m
.23467 .04359 L
.23508 .04359 L
.23508 .16187 L
F
.804 .522 .247 r
.23467 .16187 m
.23467 .04359 L
.23508 .04359 L
.23508 .16187 L
s
1 .894 .882 r
.23508 .16187 m
.23508 .04377 L
.23559 .04377 L
.23559 .16187 L
F
.804 .522 .247 r
.23508 .16187 m
.23508 .04377 L
.23559 .04377 L
.23559 .16187 L
s
1 .894 .882 r
.23559 .16187 m
.23559 .04387 L
.23585 .04387 L
.23585 .16187 L
F
.804 .522 .247 r
.23559 .16187 m
.23559 .04387 L
.23585 .04387 L
.23585 .16187 L
s
1 .894 .882 r
.23585 .16187 m
.23585 .04392 L
.2363 .04392 L
.2363 .16187 L
F
.804 .522 .247 r
.23585 .16187 m
.23585 .04392 L
.2363 .04392 L
.2363 .16187 L
s
1 .894 .882 r
.2363 .16187 m
.2363 .04404 L
.2367 .04404 L
.2367 .16187 L
F
.804 .522 .247 r
.2363 .16187 m
.2363 .04404 L
.2367 .04404 L
.2367 .16187 L
s
1 .894 .882 r
.2367 .16187 m
.2367 .04425 L
.23715 .04425 L
.23715 .16187 L
F
.804 .522 .247 r
.2367 .16187 m
.2367 .04425 L
.23715 .04425 L
.23715 .16187 L
s
1 .894 .882 r
.23715 .16187 m
.23715 .04431 L
.23772 .04431 L
.23772 .16187 L
F
.804 .522 .247 r
.23715 .16187 m
.23715 .04431 L
.23772 .04431 L
.23772 .16187 L
s
1 .894 .882 r
.23772 .16187 m
.23772 .04448 L
.23813 .04448 L
.23813 .16187 L
F
.804 .522 .247 r
.23772 .16187 m
.23772 .04448 L
.23813 .04448 L
.23813 .16187 L
s
1 .894 .882 r
.23813 .16187 m
.23813 .0446 L
.23854 .0446 L
.23854 .16187 L
F
.804 .522 .247 r
.23813 .16187 m
.23813 .0446 L
.23854 .0446 L
.23854 .16187 L
s
1 .894 .882 r
.23854 .16187 m
.23854 .04471 L
.23917 .04471 L
.23917 .16187 L
F
.804 .522 .247 r
.23854 .16187 m
.23854 .04471 L
.23917 .04471 L
.23917 .16187 L
s
1 .894 .882 r
.23917 .16187 m
.23917 .04494 L
.23977 .04494 L
.23977 .16187 L
F
.804 .522 .247 r
.23917 .16187 m
.23917 .04494 L
.23977 .04494 L
.23977 .16187 L
s
1 .894 .882 r
.23977 .16187 m
.23977 .04505 L
.24019 .04505 L
.24019 .16187 L
F
.804 .522 .247 r
.23977 .16187 m
.23977 .04505 L
.24019 .04505 L
.24019 .16187 L
s
1 .894 .882 r
.24019 .16187 m
.24019 .04514 L
.2404 .04514 L
.2404 .16187 L
F
.804 .522 .247 r
.24019 .16187 m
.24019 .04514 L
.2404 .04514 L
.2404 .16187 L
s
1 .894 .882 r
.2404 .16187 m
.2404 .04517 L
.24064 .04517 L
.24064 .16187 L
F
.804 .522 .247 r
.2404 .16187 m
.2404 .04517 L
.24064 .04517 L
.24064 .16187 L
s
1 .894 .882 r
.24064 .16187 m
.24064 .04538 L
.24126 .04538 L
.24126 .16187 L
F
.804 .522 .247 r
.24064 .16187 m
.24064 .04538 L
.24126 .04538 L
.24126 .16187 L
s
1 .894 .882 r
.24126 .16187 m
.24126 .04541 L
.24173 .04541 L
.24173 .16187 L
F
.804 .522 .247 r
.24126 .16187 m
.24126 .04541 L
.24173 .04541 L
.24173 .16187 L
s
1 .894 .882 r
.24173 .16187 m
.24173 .04558 L
.24206 .04558 L
.24206 .16187 L
F
.804 .522 .247 r
.24173 .16187 m
.24173 .04558 L
.24206 .04558 L
.24206 .16187 L
s
1 .894 .882 r
.24206 .16187 m
.24206 .04573 L
.24259 .04573 L
.24259 .16187 L
F
.804 .522 .247 r
.24206 .16187 m
.24206 .04573 L
.24259 .04573 L
.24259 .16187 L
s
1 .894 .882 r
.24259 .16187 m
.24259 .04584 L
.24312 .04584 L
.24312 .16187 L
F
.804 .522 .247 r
.24259 .16187 m
.24259 .04584 L
.24312 .04584 L
.24312 .16187 L
s
1 .894 .882 r
.24312 .16187 m
.24312 .04595 L
.24354 .04595 L
.24354 .16187 L
F
.804 .522 .247 r
.24312 .16187 m
.24312 .04595 L
.24354 .04595 L
.24354 .16187 L
s
1 .894 .882 r
.24354 .16187 m
.24354 .0461 L
.24382 .0461 L
.24382 .16187 L
F
.804 .522 .247 r
.24354 .16187 m
.24354 .0461 L
.24382 .0461 L
.24382 .16187 L
s
1 .894 .882 r
.24382 .16187 m
.24382 .04617 L
.2444 .04617 L
.2444 .16187 L
F
.804 .522 .247 r
.24382 .16187 m
.24382 .04617 L
.2444 .04617 L
.2444 .16187 L
s
1 .894 .882 r
.2444 .16187 m
.2444 .04632 L
.24472 .04632 L
.24472 .16187 L
F
.804 .522 .247 r
.2444 .16187 m
.2444 .04632 L
.24472 .04632 L
.24472 .16187 L
s
1 .894 .882 r
.24472 .16187 m
.24472 .04643 L
.24494 .04643 L
.24494 .16187 L
F
.804 .522 .247 r
.24472 .16187 m
.24472 .04643 L
.24494 .04643 L
.24494 .16187 L
s
1 .894 .882 r
.24494 .16187 m
.24494 .04652 L
.24545 .04652 L
.24545 .16187 L
F
.804 .522 .247 r
.24494 .16187 m
.24494 .04652 L
.24545 .04652 L
.24545 .16187 L
s
1 .894 .882 r
.24545 .16187 m
.24545 .04664 L
.24571 .04664 L
.24571 .16187 L
F
.804 .522 .247 r
.24545 .16187 m
.24545 .04664 L
.24571 .04664 L
.24571 .16187 L
s
1 .894 .882 r
.24571 .16187 m
.24571 .04671 L
.24596 .04671 L
.24596 .16187 L
F
.804 .522 .247 r
.24571 .16187 m
.24571 .04671 L
.24596 .04671 L
.24596 .16187 L
s
1 .894 .882 r
.24596 .16187 m
.24596 .04679 L
.24636 .04679 L
.24636 .16187 L
F
.804 .522 .247 r
.24596 .16187 m
.24596 .04679 L
.24636 .04679 L
.24636 .16187 L
s
1 .894 .882 r
.24636 .16187 m
.24636 .04688 L
.24667 .04688 L
.24667 .16187 L
F
.804 .522 .247 r
.24636 .16187 m
.24636 .04688 L
.24667 .04688 L
.24667 .16187 L
s
1 .894 .882 r
.24667 .16187 m
.24667 .04703 L
.24712 .04703 L
.24712 .16187 L
F
.804 .522 .247 r
.24667 .16187 m
.24667 .04703 L
.24712 .04703 L
.24712 .16187 L
s
1 .894 .882 r
.24712 .16187 m
.24712 .0471 L
.24744 .0471 L
.24744 .16187 L
F
.804 .522 .247 r
.24712 .16187 m
.24712 .0471 L
.24744 .0471 L
.24744 .16187 L
s
1 .894 .882 r
.24744 .16187 m
.24744 .04732 L
.24807 .04732 L
.24807 .16187 L
F
.804 .522 .247 r
.24744 .16187 m
.24744 .04732 L
.24807 .04732 L
.24807 .16187 L
s
1 .894 .882 r
.24807 .16187 m
.24807 .04743 L
.2486 .04743 L
.2486 .16187 L
F
.804 .522 .247 r
.24807 .16187 m
.24807 .04743 L
.2486 .04743 L
.2486 .16187 L
s
1 .894 .882 r
.2486 .16187 m
.2486 .04753 L
.24906 .04753 L
.24906 .16187 L
F
.804 .522 .247 r
.2486 .16187 m
.2486 .04753 L
.24906 .04753 L
.24906 .16187 L
s
1 .894 .882 r
.24906 .16187 m
.24906 .04769 L
.24942 .04769 L
.24942 .16187 L
F
.804 .522 .247 r
.24906 .16187 m
.24906 .04769 L
.24942 .04769 L
.24942 .16187 L
s
1 .894 .882 r
.24942 .16187 m
.24942 .04778 L
.24982 .04778 L
.24982 .16187 L
F
.804 .522 .247 r
.24942 .16187 m
.24942 .04778 L
.24982 .04778 L
.24982 .16187 L
s
1 .894 .882 r
.24982 .16187 m
.24982 .04799 L
.25033 .04799 L
.25033 .16187 L
F
.804 .522 .247 r
.24982 .16187 m
.24982 .04799 L
.25033 .04799 L
.25033 .16187 L
s
1 .894 .882 r
.25033 .16187 m
.25033 .04802 L
.25074 .04802 L
.25074 .16187 L
F
.804 .522 .247 r
.25033 .16187 m
.25033 .04802 L
.25074 .04802 L
.25074 .16187 L
s
1 .894 .882 r
.25074 .16187 m
.25074 .0482 L
.25112 .0482 L
.25112 .16187 L
F
.804 .522 .247 r
.25074 .16187 m
.25074 .0482 L
.25112 .0482 L
.25112 .16187 L
s
1 .894 .882 r
.25112 .16187 m
.25112 .04827 L
.25169 .04827 L
.25169 .16187 L
F
.804 .522 .247 r
.25112 .16187 m
.25112 .04827 L
.25169 .04827 L
.25169 .16187 L
s
1 .894 .882 r
.25169 .16187 m
.25169 .04845 L
.25206 .04845 L
.25206 .16187 L
F
.804 .522 .247 r
.25169 .16187 m
.25169 .04845 L
.25206 .04845 L
.25206 .16187 L
s
1 .894 .882 r
.25206 .16187 m
.25206 .04858 L
.25258 .04858 L
.25258 .16187 L
F
.804 .522 .247 r
.25206 .16187 m
.25206 .04858 L
.25258 .04858 L
.25258 .16187 L
s
1 .894 .882 r
.25258 .16187 m
.25258 .0487 L
.25306 .0487 L
.25306 .16187 L
F
.804 .522 .247 r
.25258 .16187 m
.25258 .0487 L
.25306 .0487 L
.25306 .16187 L
s
1 .894 .882 r
.25306 .16187 m
.25306 .04892 L
.25341 .04892 L
.25341 .16187 L
F
.804 .522 .247 r
.25306 .16187 m
.25306 .04892 L
.25341 .04892 L
.25341 .16187 L
s
1 .894 .882 r
.25341 .16187 m
.25341 .04898 L
.25369 .04898 L
.25369 .16187 L
F
.804 .522 .247 r
.25341 .16187 m
.25341 .04898 L
.25369 .04898 L
.25369 .16187 L
s
1 .894 .882 r
.25369 .16187 m
.25369 .04902 L
.25426 .04902 L
.25426 .16187 L
F
.804 .522 .247 r
.25369 .16187 m
.25369 .04902 L
.25426 .04902 L
.25426 .16187 L
s
1 .894 .882 r
.25426 .16187 m
.25426 .04927 L
.25461 .04927 L
.25461 .16187 L
F
.804 .522 .247 r
.25426 .16187 m
.25426 .04927 L
.25461 .04927 L
.25461 .16187 L
s
1 .894 .882 r
.25461 .16187 m
.25461 .04932 L
.25493 .04932 L
.25493 .16187 L
F
.804 .522 .247 r
.25461 .16187 m
.25461 .04932 L
.25493 .04932 L
.25493 .16187 L
s
1 .894 .882 r
.25493 .16187 m
.25493 .0494 L
.25534 .0494 L
.25534 .16187 L
F
.804 .522 .247 r
.25493 .16187 m
.25493 .0494 L
.25534 .0494 L
.25534 .16187 L
s
1 .894 .882 r
.25534 .16187 m
.25534 .04958 L
.25585 .04958 L
.25585 .16187 L
F
.804 .522 .247 r
.25534 .16187 m
.25534 .04958 L
.25585 .04958 L
.25585 .16187 L
s
1 .894 .882 r
.25585 .16187 m
.25585 .04968 L
.25614 .04968 L
.25614 .16187 L
F
.804 .522 .247 r
.25585 .16187 m
.25585 .04968 L
.25614 .04968 L
.25614 .16187 L
s
1 .894 .882 r
.25614 .16187 m
.25614 .0499 L
.2567 .0499 L
.2567 .16187 L
F
.804 .522 .247 r
.25614 .16187 m
.25614 .0499 L
.2567 .0499 L
.2567 .16187 L
s
1 .894 .882 r
.2567 .16187 m
.2567 .04999 L
.25699 .04999 L
.25699 .16187 L
F
.804 .522 .247 r
.2567 .16187 m
.2567 .04999 L
.25699 .04999 L
.25699 .16187 L
s
1 .894 .882 r
.25699 .16187 m
.25699 .05006 L
.25724 .05006 L
.25724 .16187 L
F
.804 .522 .247 r
.25699 .16187 m
.25699 .05006 L
.25724 .05006 L
.25724 .16187 L
s
1 .894 .882 r
.25724 .16187 m
.25724 .05008 L
.25785 .05008 L
.25785 .16187 L
F
.804 .522 .247 r
.25724 .16187 m
.25724 .05008 L
.25785 .05008 L
.25785 .16187 L
s
1 .894 .882 r
.25785 .16187 m
.25785 .05028 L
.25841 .05028 L
.25841 .16187 L
F
.804 .522 .247 r
.25785 .16187 m
.25785 .05028 L
.25841 .05028 L
.25841 .16187 L
s
1 .894 .882 r
.25841 .16187 m
.25841 .05048 L
.25881 .05048 L
.25881 .16187 L
F
.804 .522 .247 r
.25841 .16187 m
.25841 .05048 L
.25881 .05048 L
.25881 .16187 L
s
1 .894 .882 r
.25881 .16187 m
.25881 .05064 L
.25923 .05064 L
.25923 .16187 L
F
.804 .522 .247 r
.25881 .16187 m
.25881 .05064 L
.25923 .05064 L
.25923 .16187 L
s
1 .894 .882 r
.25923 .16187 m
.25923 .05077 L
.25968 .05077 L
.25968 .16187 L
F
.804 .522 .247 r
.25923 .16187 m
.25923 .05077 L
.25968 .05077 L
.25968 .16187 L
s
1 .894 .882 r
.25968 .16187 m
.25968 .05091 L
.26003 .05091 L
.26003 .16187 L
F
.804 .522 .247 r
.25968 .16187 m
.25968 .05091 L
.26003 .05091 L
.26003 .16187 L
s
1 .894 .882 r
.26003 .16187 m
.26003 .05102 L
.26056 .05102 L
.26056 .16187 L
F
.804 .522 .247 r
.26003 .16187 m
.26003 .05102 L
.26056 .05102 L
.26056 .16187 L
s
1 .894 .882 r
.26056 .16187 m
.26056 .05113 L
.26077 .05113 L
.26077 .16187 L
F
.804 .522 .247 r
.26056 .16187 m
.26056 .05113 L
.26077 .05113 L
.26077 .16187 L
s
1 .894 .882 r
.26077 .16187 m
.26077 .05116 L
.26103 .05116 L
.26103 .16187 L
F
.804 .522 .247 r
.26077 .16187 m
.26077 .05116 L
.26103 .05116 L
.26103 .16187 L
s
1 .894 .882 r
.26103 .16187 m
.26103 .05132 L
.26144 .05132 L
.26144 .16187 L
F
.804 .522 .247 r
.26103 .16187 m
.26103 .05132 L
.26144 .05132 L
.26144 .16187 L
s
1 .894 .882 r
.26144 .16187 m
.26144 .05139 L
.26179 .05139 L
.26179 .16187 L
F
.804 .522 .247 r
.26144 .16187 m
.26144 .05139 L
.26179 .05139 L
.26179 .16187 L
s
1 .894 .882 r
.26179 .16187 m
.26179 .0515 L
.26212 .0515 L
.26212 .16187 L
F
.804 .522 .247 r
.26179 .16187 m
.26179 .0515 L
.26212 .0515 L
.26212 .16187 L
s
1 .894 .882 r
.26212 .16187 m
.26212 .05169 L
.26254 .05169 L
.26254 .16187 L
F
.804 .522 .247 r
.26212 .16187 m
.26212 .05169 L
.26254 .05169 L
.26254 .16187 L
s
1 .894 .882 r
.26254 .16187 m
.26254 .05175 L
.2628 .05175 L
.2628 .16187 L
F
.804 .522 .247 r
.26254 .16187 m
.26254 .05175 L
.2628 .05175 L
.2628 .16187 L
s
1 .894 .882 r
.2628 .16187 m
.2628 .05183 L
.26306 .05183 L
.26306 .16187 L
F
.804 .522 .247 r
.2628 .16187 m
.2628 .05183 L
.26306 .05183 L
.26306 .16187 L
s
1 .894 .882 r
.26306 .16187 m
.26306 .05189 L
.26346 .05189 L
.26346 .16187 L
F
.804 .522 .247 r
.26306 .16187 m
.26306 .05189 L
.26346 .05189 L
.26346 .16187 L
s
1 .894 .882 r
.26346 .16187 m
.26346 .05199 L
.26371 .05199 L
.26371 .16187 L
F
.804 .522 .247 r
.26346 .16187 m
.26346 .05199 L
.26371 .05199 L
.26371 .16187 L
s
1 .894 .882 r
.26371 .16187 m
.26371 .05213 L
.26429 .05213 L
.26429 .16187 L
F
.804 .522 .247 r
.26371 .16187 m
.26371 .05213 L
.26429 .05213 L
.26429 .16187 L
s
1 .894 .882 r
.26429 .16187 m
.26429 .05232 L
.26478 .05232 L
.26478 .16187 L
F
.804 .522 .247 r
.26429 .16187 m
.26429 .05232 L
.26478 .05232 L
.26478 .16187 L
s
1 .894 .882 r
.26478 .16187 m
.26478 .05252 L
.26531 .05252 L
.26531 .16187 L
F
.804 .522 .247 r
.26478 .16187 m
.26478 .05252 L
.26531 .05252 L
.26531 .16187 L
s
1 .894 .882 r
.26531 .16187 m
.26531 .0527 L
.2659 .0527 L
.2659 .16187 L
F
.804 .522 .247 r
.26531 .16187 m
.26531 .0527 L
.2659 .0527 L
.2659 .16187 L
s
1 .894 .882 r
.2659 .16187 m
.2659 .05278 L
.26611 .05278 L
.26611 .16187 L
F
.804 .522 .247 r
.2659 .16187 m
.2659 .05278 L
.26611 .05278 L
.26611 .16187 L
s
1 .894 .882 r
.26611 .16187 m
.26611 .05289 L
.26651 .05289 L
.26651 .16187 L
F
.804 .522 .247 r
.26611 .16187 m
.26611 .05289 L
.26651 .05289 L
.26651 .16187 L
s
1 .894 .882 r
.26651 .16187 m
.26651 .05307 L
.26698 .05307 L
.26698 .16187 L
F
.804 .522 .247 r
.26651 .16187 m
.26651 .05307 L
.26698 .05307 L
.26698 .16187 L
s
1 .894 .882 r
.26698 .16187 m
.26698 .05323 L
.2676 .05323 L
.2676 .16187 L
F
.804 .522 .247 r
.26698 .16187 m
.26698 .05323 L
.2676 .05323 L
.2676 .16187 L
s
1 .894 .882 r
.2676 .16187 m
.2676 .05332 L
.26789 .05332 L
.26789 .16187 L
F
.804 .522 .247 r
.2676 .16187 m
.2676 .05332 L
.26789 .05332 L
.26789 .16187 L
s
1 .894 .882 r
.26789 .16187 m
.26789 .05341 L
.26852 .05341 L
.26852 .16187 L
F
.804 .522 .247 r
.26789 .16187 m
.26789 .05341 L
.26852 .05341 L
.26852 .16187 L
s
1 .894 .882 r
.26852 .16187 m
.26852 .05359 L
.26876 .05359 L
.26876 .16187 L
F
.804 .522 .247 r
.26852 .16187 m
.26852 .05359 L
.26876 .05359 L
.26876 .16187 L
s
1 .894 .882 r
.26876 .16187 m
.26876 .05366 L
.26912 .05366 L
.26912 .16187 L
F
.804 .522 .247 r
.26876 .16187 m
.26876 .05366 L
.26912 .05366 L
.26912 .16187 L
s
1 .894 .882 r
.26912 .16187 m
.26912 .05386 L
.2697 .05386 L
.2697 .16187 L
F
.804 .522 .247 r
.26912 .16187 m
.26912 .05386 L
.2697 .05386 L
.2697 .16187 L
s
1 .894 .882 r
.2697 .16187 m
.2697 .05401 L
.27 .05401 L
.27 .16187 L
F
.804 .522 .247 r
.2697 .16187 m
.2697 .05401 L
.27 .05401 L
.27 .16187 L
s
1 .894 .882 r
.27 .16187 m
.27 .05409 L
.27022 .05409 L
.27022 .16187 L
F
.804 .522 .247 r
.27 .16187 m
.27 .05409 L
.27022 .05409 L
.27022 .16187 L
s
1 .894 .882 r
.27022 .16187 m
.27022 .05412 L
.27051 .05412 L
.27051 .16187 L
F
.804 .522 .247 r
.27022 .16187 m
.27022 .05412 L
.27051 .05412 L
.27051 .16187 L
s
1 .894 .882 r
.27051 .16187 m
.27051 .05431 L
.27086 .05431 L
.27086 .16187 L
F
.804 .522 .247 r
.27051 .16187 m
.27051 .05431 L
.27086 .05431 L
.27086 .16187 L
s
1 .894 .882 r
.27086 .16187 m
.27086 .05439 L
.27145 .05439 L
.27145 .16187 L
F
.804 .522 .247 r
.27086 .16187 m
.27086 .05439 L
.27145 .05439 L
.27145 .16187 L
s
1 .894 .882 r
.27145 .16187 m
.27145 .05456 L
.27198 .05456 L
.27198 .16187 L
F
.804 .522 .247 r
.27145 .16187 m
.27145 .05456 L
.27198 .05456 L
.27198 .16187 L
s
1 .894 .882 r
.27198 .16187 m
.27198 .05471 L
.27249 .05471 L
.27249 .16187 L
F
.804 .522 .247 r
.27198 .16187 m
.27198 .05471 L
.27249 .05471 L
.27249 .16187 L
s
1 .894 .882 r
.27249 .16187 m
.27249 .05486 L
.27278 .05486 L
.27278 .16187 L
F
.804 .522 .247 r
.27249 .16187 m
.27249 .05486 L
.27278 .05486 L
.27278 .16187 L
s
1 .894 .882 r
.27278 .16187 m
.27278 .05506 L
.2733 .05506 L
.2733 .16187 L
F
.804 .522 .247 r
.27278 .16187 m
.27278 .05506 L
.2733 .05506 L
.2733 .16187 L
s
1 .894 .882 r
.2733 .16187 m
.2733 .05512 L
.27362 .05512 L
.27362 .16187 L
F
.804 .522 .247 r
.2733 .16187 m
.2733 .05512 L
.27362 .05512 L
.27362 .16187 L
s
1 .894 .882 r
.27362 .16187 m
.27362 .05523 L
.27408 .05523 L
.27408 .16187 L
F
.804 .522 .247 r
.27362 .16187 m
.27362 .05523 L
.27408 .05523 L
.27408 .16187 L
s
1 .894 .882 r
.27408 .16187 m
.27408 .05545 L
.27442 .05545 L
.27442 .16187 L
F
.804 .522 .247 r
.27408 .16187 m
.27408 .05545 L
.27442 .05545 L
.27442 .16187 L
s
1 .894 .882 r
.27442 .16187 m
.27442 .05549 L
.27464 .05549 L
.27464 .16187 L
F
.804 .522 .247 r
.27442 .16187 m
.27442 .05549 L
.27464 .05549 L
.27464 .16187 L
s
1 .894 .882 r
.27464 .16187 m
.27464 .05559 L
.27507 .05559 L
.27507 .16187 L
F
.804 .522 .247 r
.27464 .16187 m
.27464 .05559 L
.27507 .05559 L
.27507 .16187 L
s
1 .894 .882 r
.27507 .16187 m
.27507 .05574 L
.27557 .05574 L
.27557 .16187 L
F
.804 .522 .247 r
.27507 .16187 m
.27507 .05574 L
.27557 .05574 L
.27557 .16187 L
s
1 .894 .882 r
.27557 .16187 m
.27557 .05588 L
.27589 .05588 L
.27589 .16187 L
F
.804 .522 .247 r
.27557 .16187 m
.27557 .05588 L
.27589 .05588 L
.27589 .16187 L
s
1 .894 .882 r
.27589 .16187 m
.27589 .05604 L
.27636 .05604 L
.27636 .16187 L
F
.804 .522 .247 r
.27589 .16187 m
.27589 .05604 L
.27636 .05604 L
.27636 .16187 L
s
1 .894 .882 r
.27636 .16187 m
.27636 .05619 L
.27695 .05619 L
.27695 .16187 L
F
.804 .522 .247 r
.27636 .16187 m
.27636 .05619 L
.27695 .05619 L
.27695 .16187 L
s
1 .894 .882 r
.27695 .16187 m
.27695 .05641 L
.27747 .05641 L
.27747 .16187 L
F
.804 .522 .247 r
.27695 .16187 m
.27695 .05641 L
.27747 .05641 L
.27747 .16187 L
s
1 .894 .882 r
.27747 .16187 m
.27747 .05654 L
.2777 .05654 L
.2777 .16187 L
F
.804 .522 .247 r
.27747 .16187 m
.27747 .05654 L
.2777 .05654 L
.2777 .16187 L
s
1 .894 .882 r
.2777 .16187 m
.2777 .05661 L
.27816 .05661 L
.27816 .16187 L
F
.804 .522 .247 r
.2777 .16187 m
.2777 .05661 L
.27816 .05661 L
.27816 .16187 L
s
1 .894 .882 r
.27816 .16187 m
.27816 .05674 L
.27871 .05674 L
.27871 .16187 L
F
.804 .522 .247 r
.27816 .16187 m
.27816 .05674 L
.27871 .05674 L
.27871 .16187 L
s
1 .894 .882 r
.27871 .16187 m
.27871 .05694 L
.27905 .05694 L
.27905 .16187 L
F
.804 .522 .247 r
.27871 .16187 m
.27871 .05694 L
.27905 .05694 L
.27905 .16187 L
s
1 .894 .882 r
.27905 .16187 m
.27905 .05704 L
.27935 .05704 L
.27935 .16187 L
F
.804 .522 .247 r
.27905 .16187 m
.27905 .05704 L
.27935 .05704 L
.27935 .16187 L
s
1 .894 .882 r
.27935 .16187 m
.27935 .05718 L
.2797 .05718 L
.2797 .16187 L
F
.804 .522 .247 r
.27935 .16187 m
.27935 .05718 L
.2797 .05718 L
.2797 .16187 L
s
1 .894 .882 r
.2797 .16187 m
.2797 .05732 L
.28022 .05732 L
.28022 .16187 L
F
.804 .522 .247 r
.2797 .16187 m
.2797 .05732 L
.28022 .05732 L
.28022 .16187 L
s
1 .894 .882 r
.28022 .16187 m
.28022 .05742 L
.28047 .05742 L
.28047 .16187 L
F
.804 .522 .247 r
.28022 .16187 m
.28022 .05742 L
.28047 .05742 L
.28047 .16187 L
s
1 .894 .882 r
.28047 .16187 m
.28047 .05758 L
.28105 .05758 L
.28105 .16187 L
F
.804 .522 .247 r
.28047 .16187 m
.28047 .05758 L
.28105 .05758 L
.28105 .16187 L
s
1 .894 .882 r
.28105 .16187 m
.28105 .05771 L
.28145 .05771 L
.28145 .16187 L
F
.804 .522 .247 r
.28105 .16187 m
.28105 .05771 L
.28145 .05771 L
.28145 .16187 L
s
1 .894 .882 r
.28145 .16187 m
.28145 .05787 L
.28208 .05787 L
.28208 .16187 L
F
.804 .522 .247 r
.28145 .16187 m
.28145 .05787 L
.28208 .05787 L
.28208 .16187 L
s
1 .894 .882 r
.28208 .16187 m
.28208 .05805 L
.28245 .05805 L
.28245 .16187 L
F
.804 .522 .247 r
.28208 .16187 m
.28208 .05805 L
.28245 .05805 L
.28245 .16187 L
s
1 .894 .882 r
.28245 .16187 m
.28245 .05819 L
.28293 .05819 L
.28293 .16187 L
F
.804 .522 .247 r
.28245 .16187 m
.28245 .05819 L
.28293 .05819 L
.28293 .16187 L
s
1 .894 .882 r
.28293 .16187 m
.28293 .05842 L
.28346 .05842 L
.28346 .16187 L
F
.804 .522 .247 r
.28293 .16187 m
.28293 .05842 L
.28346 .05842 L
.28346 .16187 L
s
1 .894 .882 r
.28346 .16187 m
.28346 .05852 L
.28395 .05852 L
.28395 .16187 L
F
.804 .522 .247 r
.28346 .16187 m
.28346 .05852 L
.28395 .05852 L
.28395 .16187 L
s
1 .894 .882 r
.28395 .16187 m
.28395 .05868 L
.28451 .05868 L
.28451 .16187 L
F
.804 .522 .247 r
.28395 .16187 m
.28395 .05868 L
.28451 .05868 L
.28451 .16187 L
s
1 .894 .882 r
.28451 .16187 m
.28451 .05889 L
.28484 .05889 L
.28484 .16187 L
F
.804 .522 .247 r
.28451 .16187 m
.28451 .05889 L
.28484 .05889 L
.28484 .16187 L
s
1 .894 .882 r
.28484 .16187 m
.28484 .05902 L
.28533 .05902 L
.28533 .16187 L
F
.804 .522 .247 r
.28484 .16187 m
.28484 .05902 L
.28533 .05902 L
.28533 .16187 L
s
1 .894 .882 r
.28533 .16187 m
.28533 .05918 L
.28559 .05918 L
.28559 .16187 L
F
.804 .522 .247 r
.28533 .16187 m
.28533 .05918 L
.28559 .05918 L
.28559 .16187 L
s
1 .894 .882 r
.28559 .16187 m
.28559 .05926 L
.28584 .05926 L
.28584 .16187 L
F
.804 .522 .247 r
.28559 .16187 m
.28559 .05926 L
.28584 .05926 L
.28584 .16187 L
s
1 .894 .882 r
.28584 .16187 m
.28584 .05929 L
.28604 .05929 L
.28604 .16187 L
F
.804 .522 .247 r
.28584 .16187 m
.28584 .05929 L
.28604 .05929 L
.28604 .16187 L
s
1 .894 .882 r
.28604 .16187 m
.28604 .05941 L
.28626 .05941 L
.28626 .16187 L
F
.804 .522 .247 r
.28604 .16187 m
.28604 .05941 L
.28626 .05941 L
.28626 .16187 L
s
1 .894 .882 r
.28626 .16187 m
.28626 .05947 L
.28656 .05947 L
.28656 .16187 L
F
.804 .522 .247 r
.28626 .16187 m
.28626 .05947 L
.28656 .05947 L
.28656 .16187 L
s
1 .894 .882 r
.28656 .16187 m
.28656 .05954 L
.28693 .05954 L
.28693 .16187 L
F
.804 .522 .247 r
.28656 .16187 m
.28656 .05954 L
.28693 .05954 L
.28693 .16187 L
s
1 .894 .882 r
.28693 .16187 m
.28693 .05971 L
.28754 .05971 L
.28754 .16187 L
F
.804 .522 .247 r
.28693 .16187 m
.28693 .05971 L
.28754 .05971 L
.28754 .16187 L
s
1 .894 .882 r
.28754 .16187 m
.28754 .05993 L
.28793 .05993 L
.28793 .16187 L
F
.804 .522 .247 r
.28754 .16187 m
.28754 .05993 L
.28793 .05993 L
.28793 .16187 L
s
1 .894 .882 r
.28793 .16187 m
.28793 .06002 L
.28832 .06002 L
.28832 .16187 L
F
.804 .522 .247 r
.28793 .16187 m
.28793 .06002 L
.28832 .06002 L
.28832 .16187 L
s
1 .894 .882 r
.28832 .16187 m
.28832 .06017 L
.28854 .06017 L
.28854 .16187 L
F
.804 .522 .247 r
.28832 .16187 m
.28832 .06017 L
.28854 .06017 L
.28854 .16187 L
s
1 .894 .882 r
.28854 .16187 m
.28854 .06035 L
.28905 .06035 L
.28905 .16187 L
F
.804 .522 .247 r
.28854 .16187 m
.28854 .06035 L
.28905 .06035 L
.28905 .16187 L
s
1 .894 .882 r
.28905 .16187 m
.28905 .06043 L
.28928 .06043 L
.28928 .16187 L
F
.804 .522 .247 r
.28905 .16187 m
.28905 .06043 L
.28928 .06043 L
.28928 .16187 L
s
1 .894 .882 r
.28928 .16187 m
.28928 .06056 L
.28978 .06056 L
.28978 .16187 L
F
.804 .522 .247 r
.28928 .16187 m
.28928 .06056 L
.28978 .06056 L
.28978 .16187 L
s
1 .894 .882 r
.28978 .16187 m
.28978 .06065 L
.2904 .06065 L
.2904 .16187 L
F
.804 .522 .247 r
.28978 .16187 m
.28978 .06065 L
.2904 .06065 L
.2904 .16187 L
s
1 .894 .882 r
.2904 .16187 m
.2904 .06089 L
.29096 .06089 L
.29096 .16187 L
F
.804 .522 .247 r
.2904 .16187 m
.2904 .06089 L
.29096 .06089 L
.29096 .16187 L
s
1 .894 .882 r
.29096 .16187 m
.29096 .06109 L
.29143 .06109 L
.29143 .16187 L
F
.804 .522 .247 r
.29096 .16187 m
.29096 .06109 L
.29143 .06109 L
.29143 .16187 L
s
1 .894 .882 r
.29143 .16187 m
.29143 .06124 L
.29193 .06124 L
.29193 .16187 L
F
.804 .522 .247 r
.29143 .16187 m
.29143 .06124 L
.29193 .06124 L
.29193 .16187 L
s
1 .894 .882 r
.29193 .16187 m
.29193 .06148 L
.29238 .06148 L
.29238 .16187 L
F
.804 .522 .247 r
.29193 .16187 m
.29193 .06148 L
.29238 .06148 L
.29238 .16187 L
s
1 .894 .882 r
.29238 .16187 m
.29238 .0616 L
.29265 .0616 L
.29265 .16187 L
F
.804 .522 .247 r
.29238 .16187 m
.29238 .0616 L
.29265 .0616 L
.29265 .16187 L
s
1 .894 .882 r
.29265 .16187 m
.29265 .06174 L
.29323 .06174 L
.29323 .16187 L
F
.804 .522 .247 r
.29265 .16187 m
.29265 .06174 L
.29323 .06174 L
.29323 .16187 L
s
1 .894 .882 r
.29323 .16187 m
.29323 .06189 L
.29343 .06189 L
.29343 .16187 L
F
.804 .522 .247 r
.29323 .16187 m
.29323 .06189 L
.29343 .06189 L
.29343 .16187 L
s
1 .894 .882 r
.29343 .16187 m
.29343 .06198 L
.29395 .06198 L
.29395 .16187 L
F
.804 .522 .247 r
.29343 .16187 m
.29343 .06198 L
.29395 .06198 L
.29395 .16187 L
s
1 .894 .882 r
.29395 .16187 m
.29395 .06212 L
.29453 .06212 L
.29453 .16187 L
F
.804 .522 .247 r
.29395 .16187 m
.29395 .06212 L
.29453 .06212 L
.29453 .16187 L
s
1 .894 .882 r
.29453 .16187 m
.29453 .06228 L
.29481 .06228 L
.29481 .16187 L
F
.804 .522 .247 r
.29453 .16187 m
.29453 .06228 L
.29481 .06228 L
.29481 .16187 L
s
1 .894 .882 r
.29481 .16187 m
.29481 .06257 L
.2954 .06257 L
.2954 .16187 L
F
.804 .522 .247 r
.29481 .16187 m
.29481 .06257 L
.2954 .06257 L
.2954 .16187 L
s
1 .894 .882 r
.2954 .16187 m
.2954 .06268 L
.29586 .06268 L
.29586 .16187 L
F
.804 .522 .247 r
.2954 .16187 m
.2954 .06268 L
.29586 .06268 L
.29586 .16187 L
s
1 .894 .882 r
.29586 .16187 m
.29586 .06294 L
.29643 .06294 L
.29643 .16187 L
F
.804 .522 .247 r
.29586 .16187 m
.29586 .06294 L
.29643 .06294 L
.29643 .16187 L
s
1 .894 .882 r
.29643 .16187 m
.29643 .06296 L
.29668 .06296 L
.29668 .16187 L
F
.804 .522 .247 r
.29643 .16187 m
.29643 .06296 L
.29668 .06296 L
.29668 .16187 L
s
1 .894 .882 r
.29668 .16187 m
.29668 .06311 L
.29716 .06311 L
.29716 .16187 L
F
.804 .522 .247 r
.29668 .16187 m
.29668 .06311 L
.29716 .06311 L
.29716 .16187 L
s
1 .894 .882 r
.29716 .16187 m
.29716 .06324 L
.29744 .06324 L
.29744 .16187 L
F
.804 .522 .247 r
.29716 .16187 m
.29716 .06324 L
.29744 .06324 L
.29744 .16187 L
s
1 .894 .882 r
.29744 .16187 m
.29744 .06344 L
.29804 .06344 L
.29804 .16187 L
F
.804 .522 .247 r
.29744 .16187 m
.29744 .06344 L
.29804 .06344 L
.29804 .16187 L
s
1 .894 .882 r
.29804 .16187 m
.29804 .06362 L
.29853 .06362 L
.29853 .16187 L
F
.804 .522 .247 r
.29804 .16187 m
.29804 .06362 L
.29853 .06362 L
.29853 .16187 L
s
1 .894 .882 r
.29853 .16187 m
.29853 .06371 L
.29882 .06371 L
.29882 .16187 L
F
.804 .522 .247 r
.29853 .16187 m
.29853 .06371 L
.29882 .06371 L
.29882 .16187 L
s
1 .894 .882 r
.29882 .16187 m
.29882 .06386 L
.29907 .06386 L
.29907 .16187 L
F
.804 .522 .247 r
.29882 .16187 m
.29882 .06386 L
.29907 .06386 L
.29907 .16187 L
s
1 .894 .882 r
.29907 .16187 m
.29907 .06396 L
.29936 .06396 L
.29936 .16187 L
F
.804 .522 .247 r
.29907 .16187 m
.29907 .06396 L
.29936 .06396 L
.29936 .16187 L
s
1 .894 .882 r
.29936 .16187 m
.29936 .06411 L
.2998 .06411 L
.2998 .16187 L
F
.804 .522 .247 r
.29936 .16187 m
.29936 .06411 L
.2998 .06411 L
.2998 .16187 L
s
1 .894 .882 r
.2998 .16187 m
.2998 .06423 L
.30024 .06423 L
.30024 .16187 L
F
.804 .522 .247 r
.2998 .16187 m
.2998 .06423 L
.30024 .06423 L
.30024 .16187 L
s
1 .894 .882 r
.30024 .16187 m
.30024 .06436 L
.3005 .06436 L
.3005 .16187 L
F
.804 .522 .247 r
.30024 .16187 m
.30024 .06436 L
.3005 .06436 L
.3005 .16187 L
s
1 .894 .882 r
.3005 .16187 m
.3005 .06446 L
.30086 .06446 L
.30086 .16187 L
F
.804 .522 .247 r
.3005 .16187 m
.3005 .06446 L
.30086 .06446 L
.30086 .16187 L
s
1 .894 .882 r
.30086 .16187 m
.30086 .06462 L
.30148 .06462 L
.30148 .16187 L
F
.804 .522 .247 r
.30086 .16187 m
.30086 .06462 L
.30148 .06462 L
.30148 .16187 L
s
1 .894 .882 r
.30148 .16187 m
.30148 .0648 L
.30204 .0648 L
.30204 .16187 L
F
.804 .522 .247 r
.30148 .16187 m
.30148 .0648 L
.30204 .0648 L
.30204 .16187 L
s
1 .894 .882 r
.30204 .16187 m
.30204 .0651 L
.30251 .0651 L
.30251 .16187 L
F
.804 .522 .247 r
.30204 .16187 m
.30204 .0651 L
.30251 .0651 L
.30251 .16187 L
s
1 .894 .882 r
.30251 .16187 m
.30251 .06518 L
.30279 .06518 L
.30279 .16187 L
F
.804 .522 .247 r
.30251 .16187 m
.30251 .06518 L
.30279 .06518 L
.30279 .16187 L
s
1 .894 .882 r
.30279 .16187 m
.30279 .06529 L
.30302 .06529 L
.30302 .16187 L
F
.804 .522 .247 r
.30279 .16187 m
.30279 .06529 L
.30302 .06529 L
.30302 .16187 L
s
1 .894 .882 r
.30302 .16187 m
.30302 .06537 L
.30357 .06537 L
.30357 .16187 L
F
.804 .522 .247 r
.30302 .16187 m
.30302 .06537 L
.30357 .06537 L
.30357 .16187 L
s
1 .894 .882 r
.30357 .16187 m
.30357 .06559 L
.30414 .06559 L
.30414 .16187 L
F
.804 .522 .247 r
.30357 .16187 m
.30357 .06559 L
.30414 .06559 L
.30414 .16187 L
s
1 .894 .882 r
.30414 .16187 m
.30414 .06576 L
.30448 .06576 L
.30448 .16187 L
F
.804 .522 .247 r
.30414 .16187 m
.30414 .06576 L
.30448 .06576 L
.30448 .16187 L
s
1 .894 .882 r
.30448 .16187 m
.30448 .066 L
.30508 .066 L
.30508 .16187 L
F
.804 .522 .247 r
.30448 .16187 m
.30448 .066 L
.30508 .066 L
.30508 .16187 L
s
1 .894 .882 r
.30508 .16187 m
.30508 .06613 L
.30568 .06613 L
.30568 .16187 L
F
.804 .522 .247 r
.30508 .16187 m
.30508 .06613 L
.30568 .06613 L
.30568 .16187 L
s
1 .894 .882 r
.30568 .16187 m
.30568 .06636 L
.30598 .06636 L
.30598 .16187 L
F
.804 .522 .247 r
.30568 .16187 m
.30568 .06636 L
.30598 .06636 L
.30598 .16187 L
s
1 .894 .882 r
.30598 .16187 m
.30598 .06645 L
.30639 .06645 L
.30639 .16187 L
F
.804 .522 .247 r
.30598 .16187 m
.30598 .06645 L
.30639 .06645 L
.30639 .16187 L
s
1 .894 .882 r
.30639 .16187 m
.30639 .06666 L
.30693 .06666 L
.30693 .16187 L
F
.804 .522 .247 r
.30639 .16187 m
.30639 .06666 L
.30693 .06666 L
.30693 .16187 L
s
1 .894 .882 r
.30693 .16187 m
.30693 .06683 L
.30724 .06683 L
.30724 .16187 L
F
.804 .522 .247 r
.30693 .16187 m
.30693 .06683 L
.30724 .06683 L
.30724 .16187 L
s
1 .894 .882 r
.30724 .16187 m
.30724 .06688 L
.30745 .06688 L
.30745 .16187 L
F
.804 .522 .247 r
.30724 .16187 m
.30724 .06688 L
.30745 .06688 L
.30745 .16187 L
s
1 .894 .882 r
.30745 .16187 m
.30745 .06706 L
.30789 .06706 L
.30789 .16187 L
F
.804 .522 .247 r
.30745 .16187 m
.30745 .06706 L
.30789 .06706 L
.30789 .16187 L
s
1 .894 .882 r
.30789 .16187 m
.30789 .06709 L
.30814 .06709 L
.30814 .16187 L
F
.804 .522 .247 r
.30789 .16187 m
.30789 .06709 L
.30814 .06709 L
.30814 .16187 L
s
1 .894 .882 r
.30814 .16187 m
.30814 .06724 L
.30835 .06724 L
.30835 .16187 L
F
.804 .522 .247 r
.30814 .16187 m
.30814 .06724 L
.30835 .06724 L
.30835 .16187 L
s
1 .894 .882 r
.30835 .16187 m
.30835 .0674 L
.30895 .0674 L
.30895 .16187 L
F
.804 .522 .247 r
.30835 .16187 m
.30835 .0674 L
.30895 .0674 L
.30895 .16187 L
s
1 .894 .882 r
.30895 .16187 m
.30895 .06748 L
.3093 .06748 L
.3093 .16187 L
F
.804 .522 .247 r
.30895 .16187 m
.30895 .06748 L
.3093 .06748 L
.3093 .16187 L
s
1 .894 .882 r
.3093 .16187 m
.3093 .06765 L
.30974 .06765 L
.30974 .16187 L
F
.804 .522 .247 r
.3093 .16187 m
.3093 .06765 L
.30974 .06765 L
.30974 .16187 L
s
1 .894 .882 r
.30974 .16187 m
.30974 .06781 L
.31015 .06781 L
.31015 .16187 L
F
.804 .522 .247 r
.30974 .16187 m
.30974 .06781 L
.31015 .06781 L
.31015 .16187 L
s
1 .894 .882 r
.31015 .16187 m
.31015 .06792 L
.31068 .06792 L
.31068 .16187 L
F
.804 .522 .247 r
.31015 .16187 m
.31015 .06792 L
.31068 .06792 L
.31068 .16187 L
s
1 .894 .882 r
.31068 .16187 m
.31068 .06825 L
.3113 .06825 L
.3113 .16187 L
F
.804 .522 .247 r
.31068 .16187 m
.31068 .06825 L
.3113 .06825 L
.3113 .16187 L
s
1 .894 .882 r
.3113 .16187 m
.3113 .06849 L
.31176 .06849 L
.31176 .16187 L
F
.804 .522 .247 r
.3113 .16187 m
.3113 .06849 L
.31176 .06849 L
.31176 .16187 L
s
1 .894 .882 r
.31176 .16187 m
.31176 .0687 L
.31224 .0687 L
.31224 .16187 L
F
.804 .522 .247 r
.31176 .16187 m
.31176 .0687 L
.31224 .0687 L
.31224 .16187 L
s
1 .894 .882 r
.31224 .16187 m
.31224 .06872 L
.31251 .06872 L
.31251 .16187 L
F
.804 .522 .247 r
.31224 .16187 m
.31224 .06872 L
.31251 .06872 L
.31251 .16187 L
s
1 .894 .882 r
.31251 .16187 m
.31251 .06899 L
.31304 .06899 L
.31304 .16187 L
F
.804 .522 .247 r
.31251 .16187 m
.31251 .06899 L
.31304 .06899 L
.31304 .16187 L
s
1 .894 .882 r
.31304 .16187 m
.31304 .069 L
.31345 .069 L
.31345 .16187 L
F
.804 .522 .247 r
.31304 .16187 m
.31304 .069 L
.31345 .069 L
.31345 .16187 L
s
1 .894 .882 r
.31345 .16187 m
.31345 .0693 L
.31403 .0693 L
.31403 .16187 L
F
.804 .522 .247 r
.31345 .16187 m
.31345 .0693 L
.31403 .0693 L
.31403 .16187 L
s
1 .894 .882 r
.31403 .16187 m
.31403 .06946 L
.31436 .06946 L
.31436 .16187 L
F
.804 .522 .247 r
.31403 .16187 m
.31403 .06946 L
.31436 .06946 L
.31436 .16187 L
s
1 .894 .882 r
.31436 .16187 m
.31436 .06957 L
.31474 .06957 L
.31474 .16187 L
F
.804 .522 .247 r
.31436 .16187 m
.31436 .06957 L
.31474 .06957 L
.31474 .16187 L
s
1 .894 .882 r
.31474 .16187 m
.31474 .06969 L
.3152 .06969 L
.3152 .16187 L
F
.804 .522 .247 r
.31474 .16187 m
.31474 .06969 L
.3152 .06969 L
.3152 .16187 L
s
1 .894 .882 r
.3152 .16187 m
.3152 .06989 L
.31581 .06989 L
.31581 .16187 L
F
.804 .522 .247 r
.3152 .16187 m
.3152 .06989 L
.31581 .06989 L
.31581 .16187 L
s
1 .894 .882 r
.31581 .16187 m
.31581 .07012 L
.31603 .07012 L
.31603 .16187 L
F
.804 .522 .247 r
.31581 .16187 m
.31581 .07012 L
.31603 .07012 L
.31603 .16187 L
s
1 .894 .882 r
.31603 .16187 m
.31603 .07014 L
.31664 .07014 L
.31664 .16187 L
F
.804 .522 .247 r
.31603 .16187 m
.31603 .07014 L
.31664 .07014 L
.31664 .16187 L
s
1 .894 .882 r
.31664 .16187 m
.31664 .07049 L
.31719 .07049 L
.31719 .16187 L
F
.804 .522 .247 r
.31664 .16187 m
.31664 .07049 L
.31719 .07049 L
.31719 .16187 L
s
1 .894 .882 r
.31719 .16187 m
.31719 .07066 L
.31769 .07066 L
.31769 .16187 L
F
.804 .522 .247 r
.31719 .16187 m
.31719 .07066 L
.31769 .07066 L
.31769 .16187 L
s
1 .894 .882 r
.31769 .16187 m
.31769 .0708 L
.31789 .0708 L
.31789 .16187 L
F
.804 .522 .247 r
.31769 .16187 m
.31769 .0708 L
.31789 .0708 L
.31789 .16187 L
s
1 .894 .882 r
.31789 .16187 m
.31789 .07087 L
.31825 .07087 L
.31825 .16187 L
F
.804 .522 .247 r
.31789 .16187 m
.31789 .07087 L
.31825 .07087 L
.31825 .16187 L
s
1 .894 .882 r
.31825 .16187 m
.31825 .07108 L
.31874 .07108 L
.31874 .16187 L
F
.804 .522 .247 r
.31825 .16187 m
.31825 .07108 L
.31874 .07108 L
.31874 .16187 L
s
1 .894 .882 r
.31874 .16187 m
.31874 .07129 L
.31923 .07129 L
.31923 .16187 L
F
.804 .522 .247 r
.31874 .16187 m
.31874 .07129 L
.31923 .07129 L
.31923 .16187 L
s
1 .894 .882 r
.31923 .16187 m
.31923 .07143 L
.31945 .07143 L
.31945 .16187 L
F
.804 .522 .247 r
.31923 .16187 m
.31923 .07143 L
.31945 .07143 L
.31945 .16187 L
s
1 .894 .882 r
.31945 .16187 m
.31945 .07145 L
.31967 .07145 L
.31967 .16187 L
F
.804 .522 .247 r
.31945 .16187 m
.31945 .07145 L
.31967 .07145 L
.31967 .16187 L
s
1 .894 .882 r
.31967 .16187 m
.31967 .07154 L
.3199 .07154 L
.3199 .16187 L
F
.804 .522 .247 r
.31967 .16187 m
.31967 .07154 L
.3199 .07154 L
.3199 .16187 L
s
1 .894 .882 r
.3199 .16187 m
.3199 .07166 L
.32018 .07166 L
.32018 .16187 L
F
.804 .522 .247 r
.3199 .16187 m
.3199 .07166 L
.32018 .07166 L
.32018 .16187 L
s
1 .894 .882 r
.32018 .16187 m
.32018 .07183 L
.3205 .07183 L
.3205 .16187 L
F
.804 .522 .247 r
.32018 .16187 m
.32018 .07183 L
.3205 .07183 L
.3205 .16187 L
s
1 .894 .882 r
.3205 .16187 m
.3205 .0719 L
.32074 .0719 L
.32074 .16187 L
F
.804 .522 .247 r
.3205 .16187 m
.3205 .0719 L
.32074 .0719 L
.32074 .16187 L
s
1 .894 .882 r
.32074 .16187 m
.32074 .072 L
.32115 .072 L
.32115 .16187 L
F
.804 .522 .247 r
.32074 .16187 m
.32074 .072 L
.32115 .072 L
.32115 .16187 L
s
1 .894 .882 r
.32115 .16187 m
.32115 .07217 L
.32158 .07217 L
.32158 .16187 L
F
.804 .522 .247 r
.32115 .16187 m
.32115 .07217 L
.32158 .07217 L
.32158 .16187 L
s
1 .894 .882 r
.32158 .16187 m
.32158 .07233 L
.32183 .07233 L
.32183 .16187 L
F
.804 .522 .247 r
.32158 .16187 m
.32158 .07233 L
.32183 .07233 L
.32183 .16187 L
s
1 .894 .882 r
.32183 .16187 m
.32183 .07245 L
.32218 .07245 L
.32218 .16187 L
F
.804 .522 .247 r
.32183 .16187 m
.32183 .07245 L
.32218 .07245 L
.32218 .16187 L
s
1 .894 .882 r
.32218 .16187 m
.32218 .07259 L
.32281 .07259 L
.32281 .16187 L
F
.804 .522 .247 r
.32218 .16187 m
.32218 .07259 L
.32281 .07259 L
.32281 .16187 L
s
1 .894 .882 r
.32281 .16187 m
.32281 .07288 L
.3233 .07288 L
.3233 .16187 L
F
.804 .522 .247 r
.32281 .16187 m
.32281 .07288 L
.3233 .07288 L
.3233 .16187 L
s
1 .894 .882 r
.3233 .16187 m
.3233 .07293 L
.32387 .07293 L
.32387 .16187 L
F
.804 .522 .247 r
.3233 .16187 m
.3233 .07293 L
.32387 .07293 L
.32387 .16187 L
s
1 .894 .882 r
.32387 .16187 m
.32387 .07319 L
.32447 .07319 L
.32447 .16187 L
F
.804 .522 .247 r
.32387 .16187 m
.32387 .07319 L
.32447 .07319 L
.32447 .16187 L
s
1 .894 .882 r
.32447 .16187 m
.32447 .0734 L
.32484 .0734 L
.32484 .16187 L
F
.804 .522 .247 r
.32447 .16187 m
.32447 .0734 L
.32484 .0734 L
.32484 .16187 L
s
1 .894 .882 r
.32484 .16187 m
.32484 .07361 L
.32535 .07361 L
.32535 .16187 L
F
.804 .522 .247 r
.32484 .16187 m
.32484 .07361 L
.32535 .07361 L
.32535 .16187 L
s
1 .894 .882 r
.32535 .16187 m
.32535 .07374 L
.32589 .07374 L
.32589 .16187 L
F
.804 .522 .247 r
.32535 .16187 m
.32535 .07374 L
.32589 .07374 L
.32589 .16187 L
s
1 .894 .882 r
.32589 .16187 m
.32589 .07397 L
.32651 .07397 L
.32651 .16187 L
F
.804 .522 .247 r
.32589 .16187 m
.32589 .07397 L
.32651 .07397 L
.32651 .16187 L
s
1 .894 .882 r
.32651 .16187 m
.32651 .07427 L
.32698 .07427 L
.32698 .16187 L
F
.804 .522 .247 r
.32651 .16187 m
.32651 .07427 L
.32698 .07427 L
.32698 .16187 L
s
1 .894 .882 r
.32698 .16187 m
.32698 .07444 L
.32718 .07444 L
.32718 .16187 L
F
.804 .522 .247 r
.32698 .16187 m
.32698 .07444 L
.32718 .07444 L
.32718 .16187 L
s
1 .894 .882 r
.32718 .16187 m
.32718 .07455 L
.32771 .07455 L
.32771 .16187 L
F
.804 .522 .247 r
.32718 .16187 m
.32718 .07455 L
.32771 .07455 L
.32771 .16187 L
s
1 .894 .882 r
.32771 .16187 m
.32771 .07481 L
.32816 .07481 L
.32816 .16187 L
F
.804 .522 .247 r
.32771 .16187 m
.32771 .07481 L
.32816 .07481 L
.32816 .16187 L
s
1 .894 .882 r
.32816 .16187 m
.32816 .07506 L
.32878 .07506 L
.32878 .16187 L
F
.804 .522 .247 r
.32816 .16187 m
.32816 .07506 L
.32878 .07506 L
.32878 .16187 L
s
1 .894 .882 r
.32878 .16187 m
.32878 .07511 L
.32913 .07511 L
.32913 .16187 L
F
.804 .522 .247 r
.32878 .16187 m
.32878 .07511 L
.32913 .07511 L
.32913 .16187 L
s
1 .894 .882 r
.32913 .16187 m
.32913 .07533 L
.32963 .07533 L
.32963 .16187 L
F
.804 .522 .247 r
.32913 .16187 m
.32913 .07533 L
.32963 .07533 L
.32963 .16187 L
s
1 .894 .882 r
.32963 .16187 m
.32963 .07552 L
.33005 .07552 L
.33005 .16187 L
F
.804 .522 .247 r
.32963 .16187 m
.32963 .07552 L
.33005 .07552 L
.33005 .16187 L
s
1 .894 .882 r
.33005 .16187 m
.33005 .07573 L
.33062 .07573 L
.33062 .16187 L
F
.804 .522 .247 r
.33005 .16187 m
.33005 .07573 L
.33062 .07573 L
.33062 .16187 L
s
1 .894 .882 r
.33062 .16187 m
.33062 .07589 L
.33089 .07589 L
.33089 .16187 L
F
.804 .522 .247 r
.33062 .16187 m
.33062 .07589 L
.33089 .07589 L
.33089 .16187 L
s
1 .894 .882 r
.33089 .16187 m
.33089 .07602 L
.33125 .07602 L
.33125 .16187 L
F
.804 .522 .247 r
.33089 .16187 m
.33089 .07602 L
.33125 .07602 L
.33125 .16187 L
s
1 .894 .882 r
.33125 .16187 m
.33125 .07606 L
.33163 .07606 L
.33163 .16187 L
F
.804 .522 .247 r
.33125 .16187 m
.33125 .07606 L
.33163 .07606 L
.33163 .16187 L
s
1 .894 .882 r
.33163 .16187 m
.33163 .07624 L
.33198 .07624 L
.33198 .16187 L
F
.804 .522 .247 r
.33163 .16187 m
.33163 .07624 L
.33198 .07624 L
.33198 .16187 L
s
1 .894 .882 r
.33198 .16187 m
.33198 .07642 L
.33247 .07642 L
.33247 .16187 L
F
.804 .522 .247 r
.33198 .16187 m
.33198 .07642 L
.33247 .07642 L
.33247 .16187 L
s
1 .894 .882 r
.33247 .16187 m
.33247 .07666 L
.33277 .07666 L
.33277 .16187 L
F
.804 .522 .247 r
.33247 .16187 m
.33247 .07666 L
.33277 .07666 L
.33277 .16187 L
s
1 .894 .882 r
.33277 .16187 m
.33277 .07669 L
.33299 .07669 L
.33299 .16187 L
F
.804 .522 .247 r
.33277 .16187 m
.33277 .07669 L
.33299 .07669 L
.33299 .16187 L
s
1 .894 .882 r
.33299 .16187 m
.33299 .07687 L
.33334 .07687 L
.33334 .16187 L
F
.804 .522 .247 r
.33299 .16187 m
.33299 .07687 L
.33334 .07687 L
.33334 .16187 L
s
1 .894 .882 r
.33334 .16187 m
.33334 .07704 L
.33398 .07704 L
.33398 .16187 L
F
.804 .522 .247 r
.33334 .16187 m
.33334 .07704 L
.33398 .07704 L
.33398 .16187 L
s
1 .894 .882 r
.33398 .16187 m
.33398 .07729 L
.33435 .07729 L
.33435 .16187 L
F
.804 .522 .247 r
.33398 .16187 m
.33398 .07729 L
.33435 .07729 L
.33435 .16187 L
s
1 .894 .882 r
.33435 .16187 m
.33435 .07731 L
.33462 .07731 L
.33462 .16187 L
F
.804 .522 .247 r
.33435 .16187 m
.33435 .07731 L
.33462 .07731 L
.33462 .16187 L
s
1 .894 .882 r
.33462 .16187 m
.33462 .07757 L
.33523 .07757 L
.33523 .16187 L
F
.804 .522 .247 r
.33462 .16187 m
.33462 .07757 L
.33523 .07757 L
.33523 .16187 L
s
1 .894 .882 r
.33523 .16187 m
.33523 .07767 L
.33554 .07767 L
.33554 .16187 L
F
.804 .522 .247 r
.33523 .16187 m
.33523 .07767 L
.33554 .07767 L
.33554 .16187 L
s
1 .894 .882 r
.33554 .16187 m
.33554 .07794 L
.33602 .07794 L
.33602 .16187 L
F
.804 .522 .247 r
.33554 .16187 m
.33554 .07794 L
.33602 .07794 L
.33602 .16187 L
s
1 .894 .882 r
.33602 .16187 m
.33602 .07808 L
.3363 .07808 L
.3363 .16187 L
F
.804 .522 .247 r
.33602 .16187 m
.33602 .07808 L
.3363 .07808 L
.3363 .16187 L
s
1 .894 .882 r
.3363 .16187 m
.3363 .0781 L
.33664 .0781 L
.33664 .16187 L
F
.804 .522 .247 r
.3363 .16187 m
.3363 .0781 L
.33664 .0781 L
.33664 .16187 L
s
1 .894 .882 r
.33664 .16187 m
.33664 .07824 L
.33694 .07824 L
.33694 .16187 L
F
.804 .522 .247 r
.33664 .16187 m
.33664 .07824 L
.33694 .07824 L
.33694 .16187 L
s
1 .894 .882 r
.33694 .16187 m
.33694 .07842 L
.33752 .07842 L
.33752 .16187 L
F
.804 .522 .247 r
.33694 .16187 m
.33694 .07842 L
.33752 .07842 L
.33752 .16187 L
s
1 .894 .882 r
.33752 .16187 m
.33752 .0786 L
.33799 .0786 L
.33799 .16187 L
F
.804 .522 .247 r
.33752 .16187 m
.33752 .0786 L
.33799 .0786 L
.33799 .16187 L
s
1 .894 .882 r
.33799 .16187 m
.33799 .0788 L
.33836 .0788 L
.33836 .16187 L
F
.804 .522 .247 r
.33799 .16187 m
.33799 .0788 L
.33836 .0788 L
.33836 .16187 L
s
1 .894 .882 r
.33836 .16187 m
.33836 .07912 L
.33894 .07912 L
.33894 .16187 L
F
.804 .522 .247 r
.33836 .16187 m
.33836 .07912 L
.33894 .07912 L
.33894 .16187 L
s
1 .894 .882 r
.33894 .16187 m
.33894 .07923 L
.33921 .07923 L
.33921 .16187 L
F
.804 .522 .247 r
.33894 .16187 m
.33894 .07923 L
.33921 .07923 L
.33921 .16187 L
s
1 .894 .882 r
.33921 .16187 m
.33921 .07931 L
.33945 .07931 L
.33945 .16187 L
F
.804 .522 .247 r
.33921 .16187 m
.33921 .07931 L
.33945 .07931 L
.33945 .16187 L
s
1 .894 .882 r
.33945 .16187 m
.33945 .07945 L
.33988 .07945 L
.33988 .16187 L
F
.804 .522 .247 r
.33945 .16187 m
.33945 .07945 L
.33988 .07945 L
.33988 .16187 L
s
1 .894 .882 r
.33988 .16187 m
.33988 .07955 L
.34038 .07955 L
.34038 .16187 L
F
.804 .522 .247 r
.33988 .16187 m
.33988 .07955 L
.34038 .07955 L
.34038 .16187 L
s
1 .894 .882 r
.34038 .16187 m
.34038 .07996 L
.34094 .07996 L
.34094 .16187 L
F
.804 .522 .247 r
.34038 .16187 m
.34038 .07996 L
.34094 .07996 L
.34094 .16187 L
s
1 .894 .882 r
.34094 .16187 m
.34094 .08005 L
.34143 .08005 L
.34143 .16187 L
F
.804 .522 .247 r
.34094 .16187 m
.34094 .08005 L
.34143 .08005 L
.34143 .16187 L
s
1 .894 .882 r
.34143 .16187 m
.34143 .0802 L
.34171 .0802 L
.34171 .16187 L
F
.804 .522 .247 r
.34143 .16187 m
.34143 .0802 L
.34171 .0802 L
.34171 .16187 L
s
1 .894 .882 r
.34171 .16187 m
.34171 .08035 L
.34191 .08035 L
.34191 .16187 L
F
.804 .522 .247 r
.34171 .16187 m
.34171 .08035 L
.34191 .08035 L
.34191 .16187 L
s
1 .894 .882 r
.34191 .16187 m
.34191 .08056 L
.34236 .08056 L
.34236 .16187 L
F
.804 .522 .247 r
.34191 .16187 m
.34191 .08056 L
.34236 .08056 L
.34236 .16187 L
s
1 .894 .882 r
.34236 .16187 m
.34236 .08057 L
.34282 .08057 L
.34282 .16187 L
F
.804 .522 .247 r
.34236 .16187 m
.34236 .08057 L
.34282 .08057 L
.34282 .16187 L
s
1 .894 .882 r
.34282 .16187 m
.34282 .08084 L
.34338 .08084 L
.34338 .16187 L
F
.804 .522 .247 r
.34282 .16187 m
.34282 .08084 L
.34338 .08084 L
.34338 .16187 L
s
1 .894 .882 r
.34338 .16187 m
.34338 .08099 L
.34359 .08099 L
.34359 .16187 L
F
.804 .522 .247 r
.34338 .16187 m
.34338 .08099 L
.34359 .08099 L
.34359 .16187 L
s
1 .894 .882 r
.34359 .16187 m
.34359 .08108 L
.34386 .08108 L
.34386 .16187 L
F
.804 .522 .247 r
.34359 .16187 m
.34359 .08108 L
.34386 .08108 L
.34386 .16187 L
s
1 .894 .882 r
.34386 .16187 m
.34386 .08133 L
.34425 .08133 L
.34425 .16187 L
F
.804 .522 .247 r
.34386 .16187 m
.34386 .08133 L
.34425 .08133 L
.34425 .16187 L
s
1 .894 .882 r
.34425 .16187 m
.34425 .08151 L
.34483 .08151 L
.34483 .16187 L
F
.804 .522 .247 r
.34425 .16187 m
.34425 .08151 L
.34483 .08151 L
.34483 .16187 L
s
1 .894 .882 r
.34483 .16187 m
.34483 .0818 L
.34537 .0818 L
.34537 .16187 L
F
.804 .522 .247 r
.34483 .16187 m
.34483 .0818 L
.34537 .0818 L
.34537 .16187 L
s
1 .894 .882 r
.34537 .16187 m
.34537 .08184 L
.3458 .08184 L
.3458 .16187 L
F
.804 .522 .247 r
.34537 .16187 m
.34537 .08184 L
.3458 .08184 L
.3458 .16187 L
s
1 .894 .882 r
.3458 .16187 m
.3458 .08211 L
.3461 .08211 L
.3461 .16187 L
F
.804 .522 .247 r
.3458 .16187 m
.3458 .08211 L
.3461 .08211 L
.3461 .16187 L
s
1 .894 .882 r
.3461 .16187 m
.3461 .08221 L
.34652 .08221 L
.34652 .16187 L
F
.804 .522 .247 r
.3461 .16187 m
.3461 .08221 L
.34652 .08221 L
.34652 .16187 L
s
1 .894 .882 r
.34652 .16187 m
.34652 .08244 L
.34696 .08244 L
.34696 .16187 L
F
.804 .522 .247 r
.34652 .16187 m
.34652 .08244 L
.34696 .08244 L
.34696 .16187 L
s
1 .894 .882 r
.34696 .16187 m
.34696 .08265 L
.34745 .08265 L
.34745 .16187 L
F
.804 .522 .247 r
.34696 .16187 m
.34696 .08265 L
.34745 .08265 L
.34745 .16187 L
s
1 .894 .882 r
.34745 .16187 m
.34745 .08285 L
.34791 .08285 L
.34791 .16187 L
F
.804 .522 .247 r
.34745 .16187 m
.34745 .08285 L
.34791 .08285 L
.34791 .16187 L
s
1 .894 .882 r
.34791 .16187 m
.34791 .08292 L
.34817 .08292 L
.34817 .16187 L
F
.804 .522 .247 r
.34791 .16187 m
.34791 .08292 L
.34817 .08292 L
.34817 .16187 L
s
1 .894 .882 r
.34817 .16187 m
.34817 .08318 L
.34866 .08318 L
.34866 .16187 L
F
.804 .522 .247 r
.34817 .16187 m
.34817 .08318 L
.34866 .08318 L
.34866 .16187 L
s
1 .894 .882 r
.34866 .16187 m
.34866 .08323 L
.34906 .08323 L
.34906 .16187 L
F
.804 .522 .247 r
.34866 .16187 m
.34866 .08323 L
.34906 .08323 L
.34906 .16187 L
s
1 .894 .882 r
.34906 .16187 m
.34906 .08344 L
.34948 .08344 L
.34948 .16187 L
F
.804 .522 .247 r
.34906 .16187 m
.34906 .08344 L
.34948 .08344 L
.34948 .16187 L
s
1 .894 .882 r
.34948 .16187 m
.34948 .08372 L
.34994 .08372 L
.34994 .16187 L
F
.804 .522 .247 r
.34948 .16187 m
.34948 .08372 L
.34994 .08372 L
.34994 .16187 L
s
1 .894 .882 r
.34994 .16187 m
.34994 .08398 L
.35057 .08398 L
.35057 .16187 L
F
.804 .522 .247 r
.34994 .16187 m
.34994 .08398 L
.35057 .08398 L
.35057 .16187 L
s
1 .894 .882 r
.35057 .16187 m
.35057 .08406 L
.35105 .08406 L
.35105 .16187 L
F
.804 .522 .247 r
.35057 .16187 m
.35057 .08406 L
.35105 .08406 L
.35105 .16187 L
s
1 .894 .882 r
.35105 .16187 m
.35105 .08424 L
.35162 .08424 L
.35162 .16187 L
F
.804 .522 .247 r
.35105 .16187 m
.35105 .08424 L
.35162 .08424 L
.35162 .16187 L
s
1 .894 .882 r
.35162 .16187 m
.35162 .08456 L
.35199 .08456 L
.35199 .16187 L
F
.804 .522 .247 r
.35162 .16187 m
.35162 .08456 L
.35199 .08456 L
.35199 .16187 L
s
1 .894 .882 r
.35199 .16187 m
.35199 .08468 L
.35261 .08468 L
.35261 .16187 L
F
.804 .522 .247 r
.35199 .16187 m
.35199 .08468 L
.35261 .08468 L
.35261 .16187 L
s
1 .894 .882 r
.35261 .16187 m
.35261 .0849 L
.35283 .0849 L
.35283 .16187 L
F
.804 .522 .247 r
.35261 .16187 m
.35261 .0849 L
.35283 .0849 L
.35283 .16187 L
s
1 .894 .882 r
.35283 .16187 m
.35283 .08498 L
.35313 .08498 L
.35313 .16187 L
F
.804 .522 .247 r
.35283 .16187 m
.35283 .08498 L
.35313 .08498 L
.35313 .16187 L
s
1 .894 .882 r
.35313 .16187 m
.35313 .08516 L
.35359 .08516 L
.35359 .16187 L
F
.804 .522 .247 r
.35313 .16187 m
.35313 .08516 L
.35359 .08516 L
.35359 .16187 L
s
1 .894 .882 r
.35359 .16187 m
.35359 .08535 L
.35418 .08535 L
.35418 .16187 L
F
.804 .522 .247 r
.35359 .16187 m
.35359 .08535 L
.35418 .08535 L
.35418 .16187 L
s
1 .894 .882 r
.35418 .16187 m
.35418 .08562 L
.35477 .08562 L
.35477 .16187 L
F
.804 .522 .247 r
.35418 .16187 m
.35418 .08562 L
.35477 .08562 L
.35477 .16187 L
s
1 .894 .882 r
.35477 .16187 m
.35477 .08585 L
.35532 .08585 L
.35532 .16187 L
F
.804 .522 .247 r
.35477 .16187 m
.35477 .08585 L
.35532 .08585 L
.35532 .16187 L
s
1 .894 .882 r
.35532 .16187 m
.35532 .08618 L
.35584 .08618 L
.35584 .16187 L
F
.804 .522 .247 r
.35532 .16187 m
.35532 .08618 L
.35584 .08618 L
.35584 .16187 L
s
1 .894 .882 r
.35584 .16187 m
.35584 .08629 L
.35608 .08629 L
.35608 .16187 L
F
.804 .522 .247 r
.35584 .16187 m
.35584 .08629 L
.35608 .08629 L
.35608 .16187 L
s
1 .894 .882 r
.35608 .16187 m
.35608 .08638 L
.35643 .08638 L
.35643 .16187 L
F
.804 .522 .247 r
.35608 .16187 m
.35608 .08638 L
.35643 .08638 L
.35643 .16187 L
s
1 .894 .882 r
.35643 .16187 m
.35643 .08657 L
.35688 .08657 L
.35688 .16187 L
F
.804 .522 .247 r
.35643 .16187 m
.35643 .08657 L
.35688 .08657 L
.35688 .16187 L
s
1 .894 .882 r
.35688 .16187 m
.35688 .08672 L
.35716 .08672 L
.35716 .16187 L
F
.804 .522 .247 r
.35688 .16187 m
.35688 .08672 L
.35716 .08672 L
.35716 .16187 L
s
1 .894 .882 r
.35716 .16187 m
.35716 .08692 L
.3576 .08692 L
.3576 .16187 L
F
.804 .522 .247 r
.35716 .16187 m
.35716 .08692 L
.3576 .08692 L
.3576 .16187 L
s
1 .894 .882 r
.3576 .16187 m
.3576 .08708 L
.35811 .08708 L
.35811 .16187 L
F
.804 .522 .247 r
.3576 .16187 m
.3576 .08708 L
.35811 .08708 L
.35811 .16187 L
s
1 .894 .882 r
.35811 .16187 m
.35811 .08736 L
.35873 .08736 L
.35873 .16187 L
F
.804 .522 .247 r
.35811 .16187 m
.35811 .08736 L
.35873 .08736 L
.35873 .16187 L
s
1 .894 .882 r
.35873 .16187 m
.35873 .08758 L
.35894 .08758 L
.35894 .16187 L
F
.804 .522 .247 r
.35873 .16187 m
.35873 .08758 L
.35894 .08758 L
.35894 .16187 L
s
1 .894 .882 r
.35894 .16187 m
.35894 .08775 L
.35952 .08775 L
.35952 .16187 L
F
.804 .522 .247 r
.35894 .16187 m
.35894 .08775 L
.35952 .08775 L
.35952 .16187 L
s
1 .894 .882 r
.35952 .16187 m
.35952 .08787 L
.35983 .08787 L
.35983 .16187 L
F
.804 .522 .247 r
.35952 .16187 m
.35952 .08787 L
.35983 .08787 L
.35983 .16187 L
s
1 .894 .882 r
.35983 .16187 m
.35983 .08815 L
.36022 .08815 L
.36022 .16187 L
F
.804 .522 .247 r
.35983 .16187 m
.35983 .08815 L
.36022 .08815 L
.36022 .16187 L
s
1 .894 .882 r
.36022 .16187 m
.36022 .0883 L
.36061 .0883 L
.36061 .16187 L
F
.804 .522 .247 r
.36022 .16187 m
.36022 .0883 L
.36061 .0883 L
.36061 .16187 L
s
1 .894 .882 r
.36061 .16187 m
.36061 .0885 L
.3612 .0885 L
.3612 .16187 L
F
.804 .522 .247 r
.36061 .16187 m
.36061 .0885 L
.3612 .0885 L
.3612 .16187 L
s
1 .894 .882 r
.3612 .16187 m
.3612 .08876 L
.36166 .08876 L
.36166 .16187 L
F
.804 .522 .247 r
.3612 .16187 m
.3612 .08876 L
.36166 .08876 L
.36166 .16187 L
s
1 .894 .882 r
.36166 .16187 m
.36166 .08896 L
.36212 .08896 L
.36212 .16187 L
F
.804 .522 .247 r
.36166 .16187 m
.36166 .08896 L
.36212 .08896 L
.36212 .16187 L
s
1 .894 .882 r
.36212 .16187 m
.36212 .089 L
.36233 .089 L
.36233 .16187 L
F
.804 .522 .247 r
.36212 .16187 m
.36212 .089 L
.36233 .089 L
.36233 .16187 L
s
1 .894 .882 r
.36233 .16187 m
.36233 .08918 L
.36294 .08918 L
.36294 .16187 L
F
.804 .522 .247 r
.36233 .16187 m
.36233 .08918 L
.36294 .08918 L
.36294 .16187 L
s
1 .894 .882 r
.36294 .16187 m
.36294 .08946 L
.36337 .08946 L
.36337 .16187 L
F
.804 .522 .247 r
.36294 .16187 m
.36294 .08946 L
.36337 .08946 L
.36337 .16187 L
s
1 .894 .882 r
.36337 .16187 m
.36337 .08966 L
.36373 .08966 L
.36373 .16187 L
F
.804 .522 .247 r
.36337 .16187 m
.36337 .08966 L
.36373 .08966 L
.36373 .16187 L
s
1 .894 .882 r
.36373 .16187 m
.36373 .08983 L
.36411 .08983 L
.36411 .16187 L
F
.804 .522 .247 r
.36373 .16187 m
.36373 .08983 L
.36411 .08983 L
.36411 .16187 L
s
1 .894 .882 r
.36411 .16187 m
.36411 .08988 L
.36433 .08988 L
.36433 .16187 L
F
.804 .522 .247 r
.36411 .16187 m
.36411 .08988 L
.36433 .08988 L
.36433 .16187 L
s
1 .894 .882 r
.36433 .16187 m
.36433 .09002 L
.36479 .09002 L
.36479 .16187 L
F
.804 .522 .247 r
.36433 .16187 m
.36433 .09002 L
.36479 .09002 L
.36479 .16187 L
s
1 .894 .882 r
.36479 .16187 m
.36479 .09028 L
.36524 .09028 L
.36524 .16187 L
F
.804 .522 .247 r
.36479 .16187 m
.36479 .09028 L
.36524 .09028 L
.36524 .16187 L
s
1 .894 .882 r
.36524 .16187 m
.36524 .09039 L
.36575 .09039 L
.36575 .16187 L
F
.804 .522 .247 r
.36524 .16187 m
.36524 .09039 L
.36575 .09039 L
.36575 .16187 L
s
1 .894 .882 r
.36575 .16187 m
.36575 .09083 L
.36636 .09083 L
.36636 .16187 L
F
.804 .522 .247 r
.36575 .16187 m
.36575 .09083 L
.36636 .09083 L
.36636 .16187 L
s
1 .894 .882 r
.36636 .16187 m
.36636 .09088 L
.36667 .09088 L
.36667 .16187 L
F
.804 .522 .247 r
.36636 .16187 m
.36636 .09088 L
.36667 .09088 L
.36667 .16187 L
s
1 .894 .882 r
.36667 .16187 m
.36667 .09102 L
.36686 .09102 L
.36686 .16187 L
F
.804 .522 .247 r
.36667 .16187 m
.36667 .09102 L
.36686 .09102 L
.36686 .16187 L
s
1 .894 .882 r
.36686 .16187 m
.36686 .09127 L
.36728 .09127 L
.36728 .16187 L
F
.804 .522 .247 r
.36686 .16187 m
.36686 .09127 L
.36728 .09127 L
.36728 .16187 L
s
1 .894 .882 r
.36728 .16187 m
.36728 .09133 L
.36765 .09133 L
.36765 .16187 L
F
.804 .522 .247 r
.36728 .16187 m
.36728 .09133 L
.36765 .09133 L
.36765 .16187 L
s
1 .894 .882 r
.36765 .16187 m
.36765 .09159 L
.36808 .09159 L
.36808 .16187 L
F
.804 .522 .247 r
.36765 .16187 m
.36765 .09159 L
.36808 .09159 L
.36808 .16187 L
s
1 .894 .882 r
.36808 .16187 m
.36808 .09171 L
.36829 .09171 L
.36829 .16187 L
F
.804 .522 .247 r
.36808 .16187 m
.36808 .09171 L
.36829 .09171 L
.36829 .16187 L
s
1 .894 .882 r
.36829 .16187 m
.36829 .09176 L
.36869 .09176 L
.36869 .16187 L
F
.804 .522 .247 r
.36829 .16187 m
.36829 .09176 L
.36869 .09176 L
.36869 .16187 L
s
1 .894 .882 r
.36869 .16187 m
.36869 .09204 L
.36911 .09204 L
.36911 .16187 L
F
.804 .522 .247 r
.36869 .16187 m
.36869 .09204 L
.36911 .09204 L
.36911 .16187 L
s
1 .894 .882 r
.36911 .16187 m
.36911 .09218 L
.36943 .09218 L
.36943 .16187 L
F
.804 .522 .247 r
.36911 .16187 m
.36911 .09218 L
.36943 .09218 L
.36943 .16187 L
s
1 .894 .882 r
.36943 .16187 m
.36943 .09241 L
.36989 .09241 L
.36989 .16187 L
F
.804 .522 .247 r
.36943 .16187 m
.36943 .09241 L
.36989 .09241 L
.36989 .16187 L
s
1 .894 .882 r
.36989 .16187 m
.36989 .09247 L
.37009 .09247 L
.37009 .16187 L
F
.804 .522 .247 r
.36989 .16187 m
.36989 .09247 L
.37009 .09247 L
.37009 .16187 L
s
1 .894 .882 r
.37009 .16187 m
.37009 .09255 L
.37055 .09255 L
.37055 .16187 L
F
.804 .522 .247 r
.37009 .16187 m
.37009 .09255 L
.37055 .09255 L
.37055 .16187 L
s
1 .894 .882 r
.37055 .16187 m
.37055 .09291 L
.37106 .09291 L
.37106 .16187 L
F
.804 .522 .247 r
.37055 .16187 m
.37055 .09291 L
.37106 .09291 L
.37106 .16187 L
s
1 .894 .882 r
.37106 .16187 m
.37106 .09325 L
.37169 .09325 L
.37169 .16187 L
F
.804 .522 .247 r
.37106 .16187 m
.37106 .09325 L
.37169 .09325 L
.37169 .16187 L
s
1 .894 .882 r
.37169 .16187 m
.37169 .09327 L
.37188 .09327 L
.37188 .16187 L
F
.804 .522 .247 r
.37169 .16187 m
.37169 .09327 L
.37188 .09327 L
.37188 .16187 L
s
1 .894 .882 r
.37188 .16187 m
.37188 .09349 L
.37236 .09349 L
.37236 .16187 L
F
.804 .522 .247 r
.37188 .16187 m
.37188 .09349 L
.37236 .09349 L
.37236 .16187 L
s
1 .894 .882 r
.37236 .16187 m
.37236 .09358 L
.37263 .09358 L
.37263 .16187 L
F
.804 .522 .247 r
.37236 .16187 m
.37236 .09358 L
.37263 .09358 L
.37263 .16187 L
s
1 .894 .882 r
.37263 .16187 m
.37263 .09372 L
.37309 .09372 L
.37309 .16187 L
F
.804 .522 .247 r
.37263 .16187 m
.37263 .09372 L
.37309 .09372 L
.37309 .16187 L
s
1 .894 .882 r
.37309 .16187 m
.37309 .09396 L
.37354 .09396 L
.37354 .16187 L
F
.804 .522 .247 r
.37309 .16187 m
.37309 .09396 L
.37354 .09396 L
.37354 .16187 L
s
1 .894 .882 r
.37354 .16187 m
.37354 .0942 L
.374 .0942 L
.374 .16187 L
F
.804 .522 .247 r
.37354 .16187 m
.37354 .0942 L
.374 .0942 L
.374 .16187 L
s
1 .894 .882 r
.374 .16187 m
.374 .09448 L
.37444 .09448 L
.37444 .16187 L
F
.804 .522 .247 r
.374 .16187 m
.374 .09448 L
.37444 .09448 L
.37444 .16187 L
s
1 .894 .882 r
.37444 .16187 m
.37444 .09456 L
.37464 .09456 L
.37464 .16187 L
F
.804 .522 .247 r
.37444 .16187 m
.37444 .09456 L
.37464 .09456 L
.37464 .16187 L
s
1 .894 .882 r
.37464 .16187 m
.37464 .09466 L
.37522 .09466 L
.37522 .16187 L
F
.804 .522 .247 r
.37464 .16187 m
.37464 .09466 L
.37522 .09466 L
.37522 .16187 L
s
1 .894 .882 r
.37522 .16187 m
.37522 .095 L
.3757 .095 L
.3757 .16187 L
F
.804 .522 .247 r
.37522 .16187 m
.37522 .095 L
.3757 .095 L
.3757 .16187 L
s
1 .894 .882 r
.3757 .16187 m
.3757 .09519 L
.37603 .09519 L
.37603 .16187 L
F
.804 .522 .247 r
.3757 .16187 m
.3757 .09519 L
.37603 .09519 L
.37603 .16187 L
s
1 .894 .882 r
.37603 .16187 m
.37603 .09526 L
.37623 .09526 L
.37623 .16187 L
F
.804 .522 .247 r
.37603 .16187 m
.37603 .09526 L
.37623 .09526 L
.37623 .16187 L
s
1 .894 .882 r
.37623 .16187 m
.37623 .09536 L
.37658 .09536 L
.37658 .16187 L
F
.804 .522 .247 r
.37623 .16187 m
.37623 .09536 L
.37658 .09536 L
.37658 .16187 L
s
1 .894 .882 r
.37658 .16187 m
.37658 .09552 L
.37689 .09552 L
.37689 .16187 L
F
.804 .522 .247 r
.37658 .16187 m
.37658 .09552 L
.37689 .09552 L
.37689 .16187 L
s
1 .894 .882 r
.37689 .16187 m
.37689 .09562 L
.37743 .09562 L
.37743 .16187 L
F
.804 .522 .247 r
.37689 .16187 m
.37689 .09562 L
.37743 .09562 L
.37743 .16187 L
s
1 .894 .882 r
.37743 .16187 m
.37743 .09601 L
.37805 .09601 L
.37805 .16187 L
F
.804 .522 .247 r
.37743 .16187 m
.37743 .09601 L
.37805 .09601 L
.37805 .16187 L
s
1 .894 .882 r
.37805 .16187 m
.37805 .09617 L
.37863 .09617 L
.37863 .16187 L
F
.804 .522 .247 r
.37805 .16187 m
.37805 .09617 L
.37863 .09617 L
.37863 .16187 L
s
1 .894 .882 r
.37863 .16187 m
.37863 .09656 L
.37916 .09656 L
.37916 .16187 L
F
.804 .522 .247 r
.37863 .16187 m
.37863 .09656 L
.37916 .09656 L
.37916 .16187 L
s
1 .894 .882 r
.37916 .16187 m
.37916 .09673 L
.37957 .09673 L
.37957 .16187 L
F
.804 .522 .247 r
.37916 .16187 m
.37916 .09673 L
.37957 .09673 L
.37957 .16187 L
s
1 .894 .882 r
.37957 .16187 m
.37957 .09695 L
.37993 .09695 L
.37993 .16187 L
F
.804 .522 .247 r
.37957 .16187 m
.37957 .09695 L
.37993 .09695 L
.37993 .16187 L
s
1 .894 .882 r
.37993 .16187 m
.37993 .09721 L
.3805 .09721 L
.3805 .16187 L
F
.804 .522 .247 r
.37993 .16187 m
.37993 .09721 L
.3805 .09721 L
.3805 .16187 L
s
1 .894 .882 r
.3805 .16187 m
.3805 .09734 L
.38076 .09734 L
.38076 .16187 L
F
.804 .522 .247 r
.3805 .16187 m
.3805 .09734 L
.38076 .09734 L
.38076 .16187 L
s
1 .894 .882 r
.38076 .16187 m
.38076 .09754 L
.38131 .09754 L
.38131 .16187 L
F
.804 .522 .247 r
.38076 .16187 m
.38076 .09754 L
.38131 .09754 L
.38131 .16187 L
s
1 .894 .882 r
.38131 .16187 m
.38131 .09776 L
.38167 .09776 L
.38167 .16187 L
F
.804 .522 .247 r
.38131 .16187 m
.38131 .09776 L
.38167 .09776 L
.38167 .16187 L
s
1 .894 .882 r
.38167 .16187 m
.38167 .09796 L
.38223 .09796 L
.38223 .16187 L
F
.804 .522 .247 r
.38167 .16187 m
.38167 .09796 L
.38223 .09796 L
.38223 .16187 L
s
1 .894 .882 r
.38223 .16187 m
.38223 .09824 L
.38265 .09824 L
.38265 .16187 L
F
.804 .522 .247 r
.38223 .16187 m
.38223 .09824 L
.38265 .09824 L
.38265 .16187 L
s
1 .894 .882 r
.38265 .16187 m
.38265 .09836 L
.38312 .09836 L
.38312 .16187 L
F
.804 .522 .247 r
.38265 .16187 m
.38265 .09836 L
.38312 .09836 L
.38312 .16187 L
s
1 .894 .882 r
.38312 .16187 m
.38312 .09861 L
.38366 .09861 L
.38366 .16187 L
F
.804 .522 .247 r
.38312 .16187 m
.38312 .09861 L
.38366 .09861 L
.38366 .16187 L
s
1 .894 .882 r
.38366 .16187 m
.38366 .09877 L
.38397 .09877 L
.38397 .16187 L
F
.804 .522 .247 r
.38366 .16187 m
.38366 .09877 L
.38397 .09877 L
.38397 .16187 L
s
1 .894 .882 r
.38397 .16187 m
.38397 .09896 L
.38457 .09896 L
.38457 .16187 L
F
.804 .522 .247 r
.38397 .16187 m
.38397 .09896 L
.38457 .09896 L
.38457 .16187 L
s
1 .894 .882 r
.38457 .16187 m
.38457 .09922 L
.38479 .09922 L
.38479 .16187 L
F
.804 .522 .247 r
.38457 .16187 m
.38457 .09922 L
.38479 .09922 L
.38479 .16187 L
s
1 .894 .882 r
.38479 .16187 m
.38479 .09947 L
.38532 .09947 L
.38532 .16187 L
F
.804 .522 .247 r
.38479 .16187 m
.38479 .09947 L
.38532 .09947 L
.38532 .16187 L
s
1 .894 .882 r
.38532 .16187 m
.38532 .09968 L
.38569 .09968 L
.38569 .16187 L
F
.804 .522 .247 r
.38532 .16187 m
.38532 .09968 L
.38569 .09968 L
.38569 .16187 L
s
1 .894 .882 r
.38569 .16187 m
.38569 .09978 L
.38599 .09978 L
.38599 .16187 L
F
.804 .522 .247 r
.38569 .16187 m
.38569 .09978 L
.38599 .09978 L
.38599 .16187 L
s
1 .894 .882 r
.38599 .16187 m
.38599 .1 L
.38652 .1 L
.38652 .16187 L
F
.804 .522 .247 r
.38599 .16187 m
.38599 .1 L
.38652 .1 L
.38652 .16187 L
s
1 .894 .882 r
.38652 .16187 m
.38652 .1002 L
.38704 .1002 L
.38704 .16187 L
F
.804 .522 .247 r
.38652 .16187 m
.38652 .1002 L
.38704 .1002 L
.38704 .16187 L
s
1 .894 .882 r
.38704 .16187 m
.38704 .10039 L
.38726 .10039 L
.38726 .16187 L
F
.804 .522 .247 r
.38704 .16187 m
.38704 .10039 L
.38726 .10039 L
.38726 .16187 L
s
1 .894 .882 r
.38726 .16187 m
.38726 .10049 L
.38789 .10049 L
.38789 .16187 L
F
.804 .522 .247 r
.38726 .16187 m
.38726 .10049 L
.38789 .10049 L
.38789 .16187 L
s
1 .894 .882 r
.38789 .16187 m
.38789 .10092 L
.38851 .10092 L
.38851 .16187 L
F
.804 .522 .247 r
.38789 .16187 m
.38789 .10092 L
.38851 .10092 L
.38851 .16187 L
s
1 .894 .882 r
.38851 .16187 m
.38851 .10127 L
.38906 .10127 L
.38906 .16187 L
F
.804 .522 .247 r
.38851 .16187 m
.38851 .10127 L
.38906 .10127 L
.38906 .16187 L
s
1 .894 .882 r
.38906 .16187 m
.38906 .10135 L
.38933 .10135 L
.38933 .16187 L
F
.804 .522 .247 r
.38906 .16187 m
.38906 .10135 L
.38933 .10135 L
.38933 .16187 L
s
1 .894 .882 r
.38933 .16187 m
.38933 .1015 L
.38962 .1015 L
.38962 .16187 L
F
.804 .522 .247 r
.38933 .16187 m
.38933 .1015 L
.38962 .1015 L
.38962 .16187 L
s
1 .894 .882 r
.38962 .16187 m
.38962 .10161 L
.39002 .10161 L
.39002 .16187 L
F
.804 .522 .247 r
.38962 .16187 m
.38962 .10161 L
.39002 .10161 L
.39002 .16187 L
s
1 .894 .882 r
.39002 .16187 m
.39002 .1018 L
.3904 .1018 L
.3904 .16187 L
F
.804 .522 .247 r
.39002 .16187 m
.39002 .1018 L
.3904 .1018 L
.3904 .16187 L
s
1 .894 .882 r
.3904 .16187 m
.3904 .10205 L
.39075 .10205 L
.39075 .16187 L
F
.804 .522 .247 r
.3904 .16187 m
.3904 .10205 L
.39075 .10205 L
.39075 .16187 L
s
1 .894 .882 r
.39075 .16187 m
.39075 .1021 L
.39097 .1021 L
.39097 .16187 L
F
.804 .522 .247 r
.39075 .16187 m
.39075 .1021 L
.39097 .1021 L
.39097 .16187 L
s
1 .894 .882 r
.39097 .16187 m
.39097 .10236 L
.39146 .10236 L
.39146 .16187 L
F
.804 .522 .247 r
.39097 .16187 m
.39097 .10236 L
.39146 .10236 L
.39146 .16187 L
s
1 .894 .882 r
.39146 .16187 m
.39146 .10249 L
.39167 .10249 L
.39167 .16187 L
F
.804 .522 .247 r
.39146 .16187 m
.39146 .10249 L
.39167 .10249 L
.39167 .16187 L
s
1 .894 .882 r
.39167 .16187 m
.39167 .10257 L
.39208 .10257 L
.39208 .16187 L
F
.804 .522 .247 r
.39167 .16187 m
.39167 .10257 L
.39208 .10257 L
.39208 .16187 L
s
1 .894 .882 r
.39208 .16187 m
.39208 .10278 L
.39252 .10278 L
.39252 .16187 L
F
.804 .522 .247 r
.39208 .16187 m
.39208 .10278 L
.39252 .10278 L
.39252 .16187 L
s
1 .894 .882 r
.39252 .16187 m
.39252 .10297 L
.39274 .10297 L
.39274 .16187 L
F
.804 .522 .247 r
.39252 .16187 m
.39252 .10297 L
.39274 .10297 L
.39274 .16187 L
s
1 .894 .882 r
.39274 .16187 m
.39274 .10307 L
.39305 .10307 L
.39305 .16187 L
F
.804 .522 .247 r
.39274 .16187 m
.39274 .10307 L
.39305 .10307 L
.39305 .16187 L
s
1 .894 .882 r
.39305 .16187 m
.39305 .1032 L
.39334 .1032 L
.39334 .16187 L
F
.804 .522 .247 r
.39305 .16187 m
.39305 .1032 L
.39334 .1032 L
.39334 .16187 L
s
1 .894 .882 r
.39334 .16187 m
.39334 .10334 L
.39382 .10334 L
.39382 .16187 L
F
.804 .522 .247 r
.39334 .16187 m
.39334 .10334 L
.39382 .10334 L
.39382 .16187 L
s
1 .894 .882 r
.39382 .16187 m
.39382 .10383 L
.39446 .10383 L
.39446 .16187 L
F
.804 .522 .247 r
.39382 .16187 m
.39382 .10383 L
.39446 .10383 L
.39446 .16187 L
s
1 .894 .882 r
.39446 .16187 m
.39446 .10394 L
.39488 .10394 L
.39488 .16187 L
F
.804 .522 .247 r
.39446 .16187 m
.39446 .10394 L
.39488 .10394 L
.39488 .16187 L
s
1 .894 .882 r
.39488 .16187 m
.39488 .10411 L
.39544 .10411 L
.39544 .16187 L
F
.804 .522 .247 r
.39488 .16187 m
.39488 .10411 L
.39544 .10411 L
.39544 .16187 L
s
1 .894 .882 r
.39544 .16187 m
.39544 .10442 L
.3958 .10442 L
.3958 .16187 L
F
.804 .522 .247 r
.39544 .16187 m
.39544 .10442 L
.3958 .10442 L
.3958 .16187 L
s
1 .894 .882 r
.3958 .16187 m
.3958 .10455 L
.39611 .10455 L
.39611 .16187 L
F
.804 .522 .247 r
.3958 .16187 m
.3958 .10455 L
.39611 .10455 L
.39611 .16187 L
s
1 .894 .882 r
.39611 .16187 m
.39611 .1049 L
.39664 .1049 L
.39664 .16187 L
F
.804 .522 .247 r
.39611 .16187 m
.39611 .1049 L
.39664 .1049 L
.39664 .16187 L
s
1 .894 .882 r
.39664 .16187 m
.39664 .10507 L
.39717 .10507 L
.39717 .16187 L
F
.804 .522 .247 r
.39664 .16187 m
.39664 .10507 L
.39717 .10507 L
.39717 .16187 L
s
1 .894 .882 r
.39717 .16187 m
.39717 .10523 L
.39754 .10523 L
.39754 .16187 L
F
.804 .522 .247 r
.39717 .16187 m
.39717 .10523 L
.39754 .10523 L
.39754 .16187 L
s
1 .894 .882 r
.39754 .16187 m
.39754 .10545 L
.39786 .10545 L
.39786 .16187 L
F
.804 .522 .247 r
.39754 .16187 m
.39754 .10545 L
.39786 .10545 L
.39786 .16187 L
s
1 .894 .882 r
.39786 .16187 m
.39786 .10551 L
.39849 .10551 L
.39849 .16187 L
F
.804 .522 .247 r
.39786 .16187 m
.39786 .10551 L
.39849 .10551 L
.39849 .16187 L
s
1 .894 .882 r
.39849 .16187 m
.39849 .10583 L
.39894 .10583 L
.39894 .16187 L
F
.804 .522 .247 r
.39849 .16187 m
.39849 .10583 L
.39894 .10583 L
.39894 .16187 L
s
1 .894 .882 r
.39894 .16187 m
.39894 .10613 L
.39921 .10613 L
.39921 .16187 L
F
.804 .522 .247 r
.39894 .16187 m
.39894 .10613 L
.39921 .10613 L
.39921 .16187 L
s
1 .894 .882 r
.39921 .16187 m
.39921 .10626 L
.39977 .10626 L
.39977 .16187 L
F
.804 .522 .247 r
.39921 .16187 m
.39921 .10626 L
.39977 .10626 L
.39977 .16187 L
s
1 .894 .882 r
.39977 .16187 m
.39977 .10659 L
.40021 .10659 L
.40021 .16187 L
F
.804 .522 .247 r
.39977 .16187 m
.39977 .10659 L
.40021 .10659 L
.40021 .16187 L
s
1 .894 .882 r
.40021 .16187 m
.40021 .1067 L
.40051 .1067 L
.40051 .16187 L
F
.804 .522 .247 r
.40021 .16187 m
.40021 .1067 L
.40051 .1067 L
.40051 .16187 L
s
1 .894 .882 r
.40051 .16187 m
.40051 .10687 L
.40074 .10687 L
.40074 .16187 L
F
.804 .522 .247 r
.40051 .16187 m
.40051 .10687 L
.40074 .10687 L
.40074 .16187 L
s
1 .894 .882 r
.40074 .16187 m
.40074 .107 L
.401 .107 L
.401 .16187 L
F
.804 .522 .247 r
.40074 .16187 m
.40074 .107 L
.401 .107 L
.401 .16187 L
s
1 .894 .882 r
.401 .16187 m
.401 .10706 L
.40142 .10706 L
.40142 .16187 L
F
.804 .522 .247 r
.401 .16187 m
.401 .10706 L
.40142 .10706 L
.40142 .16187 L
s
1 .894 .882 r
.40142 .16187 m
.40142 .10727 L
.40194 .10727 L
.40194 .16187 L
F
.804 .522 .247 r
.40142 .16187 m
.40142 .10727 L
.40194 .10727 L
.40194 .16187 L
s
1 .894 .882 r
.40194 .16187 m
.40194 .10758 L
.40238 .10758 L
.40238 .16187 L
F
.804 .522 .247 r
.40194 .16187 m
.40194 .10758 L
.40238 .10758 L
.40238 .16187 L
s
1 .894 .882 r
.40238 .16187 m
.40238 .10775 L
.40262 .10775 L
.40262 .16187 L
F
.804 .522 .247 r
.40238 .16187 m
.40238 .10775 L
.40262 .10775 L
.40262 .16187 L
s
1 .894 .882 r
.40262 .16187 m
.40262 .10797 L
.40291 .10797 L
.40291 .16187 L
F
.804 .522 .247 r
.40262 .16187 m
.40262 .10797 L
.40291 .10797 L
.40291 .16187 L
s
1 .894 .882 r
.40291 .16187 m
.40291 .10799 L
.40334 .10799 L
.40334 .16187 L
F
.804 .522 .247 r
.40291 .16187 m
.40291 .10799 L
.40334 .10799 L
.40334 .16187 L
s
1 .894 .882 r
.40334 .16187 m
.40334 .10829 L
.40393 .10829 L
.40393 .16187 L
F
.804 .522 .247 r
.40334 .16187 m
.40334 .10829 L
.40393 .10829 L
.40393 .16187 L
s
1 .894 .882 r
.40393 .16187 m
.40393 .10853 L
.40417 .10853 L
.40417 .16187 L
F
.804 .522 .247 r
.40393 .16187 m
.40393 .10853 L
.40417 .10853 L
.40417 .16187 L
s
1 .894 .882 r
.40417 .16187 m
.40417 .10873 L
.40468 .10873 L
.40468 .16187 L
F
.804 .522 .247 r
.40417 .16187 m
.40417 .10873 L
.40468 .10873 L
.40468 .16187 L
s
1 .894 .882 r
.40468 .16187 m
.40468 .10907 L
.40519 .10907 L
.40519 .16187 L
F
.804 .522 .247 r
.40468 .16187 m
.40468 .10907 L
.40519 .10907 L
.40519 .16187 L
s
1 .894 .882 r
.40519 .16187 m
.40519 .10928 L
.40561 .10928 L
.40561 .16187 L
F
.804 .522 .247 r
.40519 .16187 m
.40519 .10928 L
.40561 .10928 L
.40561 .16187 L
s
1 .894 .882 r
.40561 .16187 m
.40561 .10937 L
.40618 .10937 L
.40618 .16187 L
F
.804 .522 .247 r
.40561 .16187 m
.40561 .10937 L
.40618 .10937 L
.40618 .16187 L
s
1 .894 .882 r
.40618 .16187 m
.40618 .10977 L
.40679 .10977 L
.40679 .16187 L
F
.804 .522 .247 r
.40618 .16187 m
.40618 .10977 L
.40679 .10977 L
.40679 .16187 L
s
1 .894 .882 r
.40679 .16187 m
.40679 .10999 L
.40741 .10999 L
.40741 .16187 L
F
.804 .522 .247 r
.40679 .16187 m
.40679 .10999 L
.40741 .10999 L
.40741 .16187 L
s
1 .894 .882 r
.40741 .16187 m
.40741 .11027 L
.40766 .11027 L
.40766 .16187 L
F
.804 .522 .247 r
.40741 .16187 m
.40741 .11027 L
.40766 .11027 L
.40766 .16187 L
s
1 .894 .882 r
.40766 .16187 m
.40766 .11045 L
.4081 .11045 L
.4081 .16187 L
F
.804 .522 .247 r
.40766 .16187 m
.40766 .11045 L
.4081 .11045 L
.4081 .16187 L
s
1 .894 .882 r
.4081 .16187 m
.4081 .11073 L
.40871 .11073 L
.40871 .16187 L
F
.804 .522 .247 r
.4081 .16187 m
.4081 .11073 L
.40871 .11073 L
.40871 .16187 L
s
1 .894 .882 r
.40871 .16187 m
.40871 .1109 L
.40907 .1109 L
.40907 .16187 L
F
.804 .522 .247 r
.40871 .16187 m
.40871 .1109 L
.40907 .1109 L
.40907 .16187 L
s
1 .894 .882 r
.40907 .16187 m
.40907 .1113 L
.40969 .1113 L
.40969 .16187 L
F
.804 .522 .247 r
.40907 .16187 m
.40907 .1113 L
.40969 .1113 L
.40969 .16187 L
s
1 .894 .882 r
.40969 .16187 m
.40969 .1114 L
.41021 .1114 L
.41021 .16187 L
F
.804 .522 .247 r
.40969 .16187 m
.40969 .1114 L
.41021 .1114 L
.41021 .16187 L
s
1 .894 .882 r
.41021 .16187 m
.41021 .11176 L
.41058 .11176 L
.41058 .16187 L
F
.804 .522 .247 r
.41021 .16187 m
.41021 .11176 L
.41058 .11176 L
.41058 .16187 L
s
1 .894 .882 r
.41058 .16187 m
.41058 .11191 L
.41083 .11191 L
.41083 .16187 L
F
.804 .522 .247 r
.41058 .16187 m
.41058 .11191 L
.41083 .11191 L
.41083 .16187 L
s
1 .894 .882 r
.41083 .16187 m
.41083 .11198 L
.4114 .11198 L
.4114 .16187 L
F
.804 .522 .247 r
.41083 .16187 m
.41083 .11198 L
.4114 .11198 L
.4114 .16187 L
s
1 .894 .882 r
.4114 .16187 m
.4114 .11233 L
.41185 .11233 L
.41185 .16187 L
F
.804 .522 .247 r
.4114 .16187 m
.4114 .11233 L
.41185 .11233 L
.41185 .16187 L
s
1 .894 .882 r
.41185 .16187 m
.41185 .11266 L
.41244 .11266 L
.41244 .16187 L
F
.804 .522 .247 r
.41185 .16187 m
.41185 .11266 L
.41244 .11266 L
.41244 .16187 L
s
1 .894 .882 r
.41244 .16187 m
.41244 .11288 L
.41281 .11288 L
.41281 .16187 L
F
.804 .522 .247 r
.41244 .16187 m
.41244 .11288 L
.41281 .11288 L
.41281 .16187 L
s
1 .894 .882 r
.41281 .16187 m
.41281 .11306 L
.41314 .11306 L
.41314 .16187 L
F
.804 .522 .247 r
.41281 .16187 m
.41281 .11306 L
.41314 .11306 L
.41314 .16187 L
s
1 .894 .882 r
.41314 .16187 m
.41314 .11313 L
.41354 .11313 L
.41354 .16187 L
F
.804 .522 .247 r
.41314 .16187 m
.41314 .11313 L
.41354 .11313 L
.41354 .16187 L
s
1 .894 .882 r
.41354 .16187 m
.41354 .11349 L
.41403 .11349 L
.41403 .16187 L
F
.804 .522 .247 r
.41354 .16187 m
.41354 .11349 L
.41403 .11349 L
.41403 .16187 L
s
1 .894 .882 r
.41403 .16187 m
.41403 .11376 L
.4146 .11376 L
.4146 .16187 L
F
.804 .522 .247 r
.41403 .16187 m
.41403 .11376 L
.4146 .11376 L
.4146 .16187 L
s
1 .894 .882 r
.4146 .16187 m
.4146 .11392 L
.41498 .11392 L
.41498 .16187 L
F
.804 .522 .247 r
.4146 .16187 m
.4146 .11392 L
.41498 .11392 L
.41498 .16187 L
s
1 .894 .882 r
.41498 .16187 m
.41498 .11416 L
.41533 .11416 L
.41533 .16187 L
F
.804 .522 .247 r
.41498 .16187 m
.41498 .11416 L
.41533 .11416 L
.41533 .16187 L
s
1 .894 .882 r
.41533 .16187 m
.41533 .1143 L
.41595 .1143 L
.41595 .16187 L
F
.804 .522 .247 r
.41533 .16187 m
.41533 .1143 L
.41595 .1143 L
.41595 .16187 L
s
1 .894 .882 r
.41595 .16187 m
.41595 .11463 L
.41621 .11463 L
.41621 .16187 L
F
.804 .522 .247 r
.41595 .16187 m
.41595 .11463 L
.41621 .11463 L
.41621 .16187 L
s
1 .894 .882 r
.41621 .16187 m
.41621 .11484 L
.4168 .11484 L
.4168 .16187 L
F
.804 .522 .247 r
.41621 .16187 m
.41621 .11484 L
.4168 .11484 L
.4168 .16187 L
s
1 .894 .882 r
.4168 .16187 m
.4168 .11507 L
.41722 .11507 L
.41722 .16187 L
F
.804 .522 .247 r
.4168 .16187 m
.4168 .11507 L
.41722 .11507 L
.41722 .16187 L
s
1 .894 .882 r
.41722 .16187 m
.41722 .11523 L
.41742 .11523 L
.41742 .16187 L
F
.804 .522 .247 r
.41722 .16187 m
.41722 .11523 L
.41742 .11523 L
.41742 .16187 L
s
1 .894 .882 r
.41742 .16187 m
.41742 .11534 L
.4177 .11534 L
.4177 .16187 L
F
.804 .522 .247 r
.41742 .16187 m
.41742 .11534 L
.4177 .11534 L
.4177 .16187 L
s
1 .894 .882 r
.4177 .16187 m
.4177 .11543 L
.41823 .11543 L
.41823 .16187 L
F
.804 .522 .247 r
.4177 .16187 m
.4177 .11543 L
.41823 .11543 L
.41823 .16187 L
s
1 .894 .882 r
.41823 .16187 m
.41823 .11569 L
.41885 .11569 L
.41885 .16187 L
F
.804 .522 .247 r
.41823 .16187 m
.41823 .11569 L
.41885 .11569 L
.41885 .16187 L
s
1 .894 .882 r
.41885 .16187 m
.41885 .116 L
.41907 .116 L
.41907 .16187 L
F
.804 .522 .247 r
.41885 .16187 m
.41885 .116 L
.41907 .116 L
.41907 .16187 L
s
1 .894 .882 r
.41907 .16187 m
.41907 .11621 L
.41964 .11621 L
.41964 .16187 L
F
.804 .522 .247 r
.41907 .16187 m
.41907 .11621 L
.41964 .11621 L
.41964 .16187 L
s
1 .894 .882 r
.41964 .16187 m
.41964 .11646 L
.42018 .11646 L
.42018 .16187 L
F
.804 .522 .247 r
.41964 .16187 m
.41964 .11646 L
.42018 .11646 L
.42018 .16187 L
s
1 .894 .882 r
.42018 .16187 m
.42018 .1168 L
.42048 .1168 L
.42048 .16187 L
F
.804 .522 .247 r
.42018 .16187 m
.42018 .1168 L
.42048 .1168 L
.42048 .16187 L
s
1 .894 .882 r
.42048 .16187 m
.42048 .1169 L
.42096 .1169 L
.42096 .16187 L
F
.804 .522 .247 r
.42048 .16187 m
.42048 .1169 L
.42096 .1169 L
.42096 .16187 L
s
1 .894 .882 r
.42096 .16187 m
.42096 .11719 L
.42147 .11719 L
.42147 .16187 L
F
.804 .522 .247 r
.42096 .16187 m
.42096 .11719 L
.42147 .11719 L
.42147 .16187 L
s
1 .894 .882 r
.42147 .16187 m
.42147 .11765 L
.42208 .11765 L
.42208 .16187 L
F
.804 .522 .247 r
.42147 .16187 m
.42147 .11765 L
.42208 .11765 L
.42208 .16187 L
s
1 .894 .882 r
.42208 .16187 m
.42208 .11772 L
.42256 .11772 L
.42256 .16187 L
F
.804 .522 .247 r
.42208 .16187 m
.42208 .11772 L
.42256 .11772 L
.42256 .16187 L
s
1 .894 .882 r
.42256 .16187 m
.42256 .11804 L
.42309 .11804 L
.42309 .16187 L
F
.804 .522 .247 r
.42256 .16187 m
.42256 .11804 L
.42309 .11804 L
.42309 .16187 L
s
1 .894 .882 r
.42309 .16187 m
.42309 .11828 L
.42343 .11828 L
.42343 .16187 L
F
.804 .522 .247 r
.42309 .16187 m
.42309 .11828 L
.42343 .11828 L
.42343 .16187 L
s
1 .894 .882 r
.42343 .16187 m
.42343 .11838 L
.4239 .11838 L
.4239 .16187 L
F
.804 .522 .247 r
.42343 .16187 m
.42343 .11838 L
.4239 .11838 L
.4239 .16187 L
s
1 .894 .882 r
.4239 .16187 m
.4239 .1186 L
.42418 .1186 L
.42418 .16187 L
F
.804 .522 .247 r
.4239 .16187 m
.4239 .1186 L
.42418 .1186 L
.42418 .16187 L
s
1 .894 .882 r
.42418 .16187 m
.42418 .11882 L
.42441 .11882 L
.42441 .16187 L
F
.804 .522 .247 r
.42418 .16187 m
.42418 .11882 L
.42441 .11882 L
.42441 .16187 L
s
1 .894 .882 r
.42441 .16187 m
.42441 .11903 L
.42481 .11903 L
.42481 .16187 L
F
.804 .522 .247 r
.42441 .16187 m
.42441 .11903 L
.42481 .11903 L
.42481 .16187 L
s
1 .894 .882 r
.42481 .16187 m
.42481 .11915 L
.4251 .11915 L
.4251 .16187 L
F
.804 .522 .247 r
.42481 .16187 m
.42481 .11915 L
.4251 .11915 L
.4251 .16187 L
s
1 .894 .882 r
.4251 .16187 m
.4251 .11927 L
.42565 .11927 L
.42565 .16187 L
F
.804 .522 .247 r
.4251 .16187 m
.4251 .11927 L
.42565 .11927 L
.42565 .16187 L
s
1 .894 .882 r
.42565 .16187 m
.42565 .11955 L
.42591 .11955 L
.42591 .16187 L
F
.804 .522 .247 r
.42565 .16187 m
.42565 .11955 L
.42591 .11955 L
.42591 .16187 L
s
1 .894 .882 r
.42591 .16187 m
.42591 .11979 L
.42624 .11979 L
.42624 .16187 L
F
.804 .522 .247 r
.42591 .16187 m
.42591 .11979 L
.42624 .11979 L
.42624 .16187 L
s
1 .894 .882 r
.42624 .16187 m
.42624 .11997 L
.42658 .11997 L
.42658 .16187 L
F
.804 .522 .247 r
.42624 .16187 m
.42624 .11997 L
.42658 .11997 L
.42658 .16187 L
s
1 .894 .882 r
.42658 .16187 m
.42658 .12008 L
.4269 .12008 L
.4269 .16187 L
F
.804 .522 .247 r
.42658 .16187 m
.42658 .12008 L
.4269 .12008 L
.4269 .16187 L
s
1 .894 .882 r
.4269 .16187 m
.4269 .12023 L
.42715 .12023 L
.42715 .16187 L
F
.804 .522 .247 r
.4269 .16187 m
.4269 .12023 L
.42715 .12023 L
.42715 .16187 L
s
1 .894 .882 r
.42715 .16187 m
.42715 .12032 L
.42738 .12032 L
.42738 .16187 L
F
.804 .522 .247 r
.42715 .16187 m
.42715 .12032 L
.42738 .12032 L
.42738 .16187 L
s
1 .894 .882 r
.42738 .16187 m
.42738 .12059 L
.42783 .12059 L
.42783 .16187 L
F
.804 .522 .247 r
.42738 .16187 m
.42738 .12059 L
.42783 .12059 L
.42783 .16187 L
s
1 .894 .882 r
.42783 .16187 m
.42783 .12073 L
.42818 .12073 L
.42818 .16187 L
F
.804 .522 .247 r
.42783 .16187 m
.42783 .12073 L
.42818 .12073 L
.42818 .16187 L
s
1 .894 .882 r
.42818 .16187 m
.42818 .12088 L
.4284 .12088 L
.4284 .16187 L
F
.804 .522 .247 r
.42818 .16187 m
.42818 .12088 L
.4284 .12088 L
.4284 .16187 L
s
1 .894 .882 r
.4284 .16187 m
.4284 .12109 L
.4287 .12109 L
.4287 .16187 L
F
.804 .522 .247 r
.4284 .16187 m
.4284 .12109 L
.4287 .12109 L
.4287 .16187 L
s
1 .894 .882 r
.4287 .16187 m
.4287 .12126 L
.42924 .12126 L
.42924 .16187 L
F
.804 .522 .247 r
.4287 .16187 m
.4287 .12126 L
.42924 .12126 L
.42924 .16187 L
s
1 .894 .882 r
.42924 .16187 m
.42924 .12147 L
.42949 .12147 L
.42949 .16187 L
F
.804 .522 .247 r
.42924 .16187 m
.42924 .12147 L
.42949 .12147 L
.42949 .16187 L
s
1 .894 .882 r
.42949 .16187 m
.42949 .12154 L
.42987 .12154 L
.42987 .16187 L
F
.804 .522 .247 r
.42949 .16187 m
.42949 .12154 L
.42987 .12154 L
.42987 .16187 L
s
1 .894 .882 r
.42987 .16187 m
.42987 .12181 L
.43029 .12181 L
.43029 .16187 L
F
.804 .522 .247 r
.42987 .16187 m
.42987 .12181 L
.43029 .12181 L
.43029 .16187 L
s
1 .894 .882 r
.43029 .16187 m
.43029 .1221 L
.43086 .1221 L
.43086 .16187 L
F
.804 .522 .247 r
.43029 .16187 m
.43029 .1221 L
.43086 .1221 L
.43086 .16187 L
s
1 .894 .882 r
.43086 .16187 m
.43086 .12231 L
.43126 .12231 L
.43126 .16187 L
F
.804 .522 .247 r
.43086 .16187 m
.43086 .12231 L
.43126 .12231 L
.43126 .16187 L
s
1 .894 .882 r
.43126 .16187 m
.43126 .1226 L
.43175 .1226 L
.43175 .16187 L
F
.804 .522 .247 r
.43126 .16187 m
.43126 .1226 L
.43175 .1226 L
.43175 .16187 L
s
1 .894 .882 r
.43175 .16187 m
.43175 .12283 L
.43203 .12283 L
.43203 .16187 L
F
.804 .522 .247 r
.43175 .16187 m
.43175 .12283 L
.43203 .12283 L
.43203 .16187 L
s
1 .894 .882 r
.43203 .16187 m
.43203 .12292 L
.43232 .12292 L
.43232 .16187 L
F
.804 .522 .247 r
.43203 .16187 m
.43203 .12292 L
.43232 .12292 L
.43232 .16187 L
s
1 .894 .882 r
.43232 .16187 m
.43232 .12307 L
.43264 .12307 L
.43264 .16187 L
F
.804 .522 .247 r
.43232 .16187 m
.43232 .12307 L
.43264 .12307 L
.43264 .16187 L
s
1 .894 .882 r
.43264 .16187 m
.43264 .1234 L
.43308 .1234 L
.43308 .16187 L
F
.804 .522 .247 r
.43264 .16187 m
.43264 .1234 L
.43308 .1234 L
.43308 .16187 L
s
1 .894 .882 r
.43308 .16187 m
.43308 .12369 L
.4336 .12369 L
.4336 .16187 L
F
.804 .522 .247 r
.43308 .16187 m
.43308 .12369 L
.4336 .12369 L
.4336 .16187 L
s
1 .894 .882 r
.4336 .16187 m
.4336 .12398 L
.43424 .12398 L
.43424 .16187 L
F
.804 .522 .247 r
.4336 .16187 m
.4336 .12398 L
.43424 .12398 L
.43424 .16187 L
s
1 .894 .882 r
.43424 .16187 m
.43424 .12406 L
.43464 .12406 L
.43464 .16187 L
F
.804 .522 .247 r
.43424 .16187 m
.43424 .12406 L
.43464 .12406 L
.43464 .16187 L
s
1 .894 .882 r
.43464 .16187 m
.43464 .12436 L
.43502 .12436 L
.43502 .16187 L
F
.804 .522 .247 r
.43464 .16187 m
.43464 .12436 L
.43502 .12436 L
.43502 .16187 L
s
1 .894 .882 r
.43502 .16187 m
.43502 .12446 L
.4354 .12446 L
.4354 .16187 L
F
.804 .522 .247 r
.43502 .16187 m
.43502 .12446 L
.4354 .12446 L
.4354 .16187 L
s
1 .894 .882 r
.4354 .16187 m
.4354 .1249 L
.43589 .1249 L
.43589 .16187 L
F
.804 .522 .247 r
.4354 .16187 m
.4354 .1249 L
.43589 .1249 L
.43589 .16187 L
s
1 .894 .882 r
.43589 .16187 m
.43589 .125 L
.43616 .125 L
.43616 .16187 L
F
.804 .522 .247 r
.43589 .16187 m
.43589 .125 L
.43616 .125 L
.43616 .16187 L
s
1 .894 .882 r
.43616 .16187 m
.43616 .12505 L
.43648 .12505 L
.43648 .16187 L
F
.804 .522 .247 r
.43616 .16187 m
.43616 .12505 L
.43648 .12505 L
.43648 .16187 L
s
1 .894 .882 r
.43648 .16187 m
.43648 .12537 L
.43682 .12537 L
.43682 .16187 L
F
.804 .522 .247 r
.43648 .16187 m
.43648 .12537 L
.43682 .12537 L
.43682 .16187 L
s
1 .894 .882 r
.43682 .16187 m
.43682 .12543 L
.43705 .12543 L
.43705 .16187 L
F
.804 .522 .247 r
.43682 .16187 m
.43682 .12543 L
.43705 .12543 L
.43705 .16187 L
s
1 .894 .882 r
.43705 .16187 m
.43705 .12557 L
.43761 .12557 L
.43761 .16187 L
F
.804 .522 .247 r
.43705 .16187 m
.43705 .12557 L
.43761 .12557 L
.43761 .16187 L
s
1 .894 .882 r
.43761 .16187 m
.43761 .12593 L
.43791 .12593 L
.43791 .16187 L
F
.804 .522 .247 r
.43761 .16187 m
.43761 .12593 L
.43791 .12593 L
.43791 .16187 L
s
1 .894 .882 r
.43791 .16187 m
.43791 .1261 L
.43814 .1261 L
.43814 .16187 L
F
.804 .522 .247 r
.43791 .16187 m
.43791 .1261 L
.43814 .1261 L
.43814 .16187 L
s
1 .894 .882 r
.43814 .16187 m
.43814 .12623 L
.43846 .12623 L
.43846 .16187 L
F
.804 .522 .247 r
.43814 .16187 m
.43814 .12623 L
.43846 .12623 L
.43846 .16187 L
s
1 .894 .882 r
.43846 .16187 m
.43846 .12643 L
.43896 .12643 L
.43896 .16187 L
F
.804 .522 .247 r
.43846 .16187 m
.43846 .12643 L
.43896 .12643 L
.43896 .16187 L
s
1 .894 .882 r
.43896 .16187 m
.43896 .1267 L
.43952 .1267 L
.43952 .16187 L
F
.804 .522 .247 r
.43896 .16187 m
.43896 .1267 L
.43952 .1267 L
.43952 .16187 L
s
1 .894 .882 r
.43952 .16187 m
.43952 .12696 L
.43996 .12696 L
.43996 .16187 L
F
.804 .522 .247 r
.43952 .16187 m
.43952 .12696 L
.43996 .12696 L
.43996 .16187 L
s
1 .894 .882 r
.43996 .16187 m
.43996 .12712 L
.44035 .12712 L
.44035 .16187 L
F
.804 .522 .247 r
.43996 .16187 m
.43996 .12712 L
.44035 .12712 L
.44035 .16187 L
s
1 .894 .882 r
.44035 .16187 m
.44035 .12734 L
.44065 .12734 L
.44065 .16187 L
F
.804 .522 .247 r
.44035 .16187 m
.44035 .12734 L
.44065 .12734 L
.44065 .16187 L
s
1 .894 .882 r
.44065 .16187 m
.44065 .1276 L
.44091 .1276 L
.44091 .16187 L
F
.804 .522 .247 r
.44065 .16187 m
.44065 .1276 L
.44091 .1276 L
.44091 .16187 L
s
1 .894 .882 r
.44091 .16187 m
.44091 .12773 L
.44127 .12773 L
.44127 .16187 L
F
.804 .522 .247 r
.44091 .16187 m
.44091 .12773 L
.44127 .12773 L
.44127 .16187 L
s
1 .894 .882 r
.44127 .16187 m
.44127 .12791 L
.44156 .12791 L
.44156 .16187 L
F
.804 .522 .247 r
.44127 .16187 m
.44127 .12791 L
.44156 .12791 L
.44156 .16187 L
s
1 .894 .882 r
.44156 .16187 m
.44156 .12824 L
.44217 .12824 L
.44217 .16187 L
F
.804 .522 .247 r
.44156 .16187 m
.44156 .12824 L
.44217 .12824 L
.44217 .16187 L
s
1 .894 .882 r
.44217 .16187 m
.44217 .12854 L
.44263 .12854 L
.44263 .16187 L
F
.804 .522 .247 r
.44217 .16187 m
.44217 .12854 L
.44263 .12854 L
.44263 .16187 L
s
1 .894 .882 r
.44263 .16187 m
.44263 .1287 L
.44311 .1287 L
.44311 .16187 L
F
.804 .522 .247 r
.44263 .16187 m
.44263 .1287 L
.44311 .1287 L
.44311 .16187 L
s
1 .894 .882 r
.44311 .16187 m
.44311 .12894 L
.4434 .12894 L
.4434 .16187 L
F
.804 .522 .247 r
.44311 .16187 m
.44311 .12894 L
.4434 .12894 L
.4434 .16187 L
s
1 .894 .882 r
.4434 .16187 m
.4434 .12911 L
.4438 .12911 L
.4438 .16187 L
F
.804 .522 .247 r
.4434 .16187 m
.4434 .12911 L
.4438 .12911 L
.4438 .16187 L
s
1 .894 .882 r
.4438 .16187 m
.4438 .12924 L
.44406 .12924 L
.44406 .16187 L
F
.804 .522 .247 r
.4438 .16187 m
.4438 .12924 L
.44406 .12924 L
.44406 .16187 L
s
1 .894 .882 r
.44406 .16187 m
.44406 .12941 L
.44435 .12941 L
.44435 .16187 L
F
.804 .522 .247 r
.44406 .16187 m
.44406 .12941 L
.44435 .12941 L
.44435 .16187 L
s
1 .894 .882 r
.44435 .16187 m
.44435 .1297 L
.4448 .1297 L
.4448 .16187 L
F
.804 .522 .247 r
.44435 .16187 m
.44435 .1297 L
.4448 .1297 L
.4448 .16187 L
s
1 .894 .882 r
.4448 .16187 m
.4448 .12974 L
.44513 .12974 L
.44513 .16187 L
F
.804 .522 .247 r
.4448 .16187 m
.4448 .12974 L
.44513 .12974 L
.44513 .16187 L
s
1 .894 .882 r
.44513 .16187 m
.44513 .13002 L
.4457 .13002 L
.4457 .16187 L
F
.804 .522 .247 r
.44513 .16187 m
.44513 .13002 L
.4457 .13002 L
.4457 .16187 L
s
1 .894 .882 r
.4457 .16187 m
.4457 .13047 L
.44629 .13047 L
.44629 .16187 L
F
.804 .522 .247 r
.4457 .16187 m
.4457 .13047 L
.44629 .13047 L
.44629 .16187 L
s
1 .894 .882 r
.44629 .16187 m
.44629 .1307 L
.4467 .1307 L
.4467 .16187 L
F
.804 .522 .247 r
.44629 .16187 m
.44629 .1307 L
.4467 .1307 L
.4467 .16187 L
s
1 .894 .882 r
.4467 .16187 m
.4467 .13098 L
.4471 .13098 L
.4471 .16187 L
F
.804 .522 .247 r
.4467 .16187 m
.4467 .13098 L
.4471 .13098 L
.4471 .16187 L
s
1 .894 .882 r
.4471 .16187 m
.4471 .13119 L
.44757 .13119 L
.44757 .16187 L
F
.804 .522 .247 r
.4471 .16187 m
.4471 .13119 L
.44757 .13119 L
.44757 .16187 L
s
1 .894 .882 r
.44757 .16187 m
.44757 .13152 L
.44812 .13152 L
.44812 .16187 L
F
.804 .522 .247 r
.44757 .16187 m
.44757 .13152 L
.44812 .13152 L
.44812 .16187 L
s
1 .894 .882 r
.44812 .16187 m
.44812 .13156 L
.4484 .13156 L
.4484 .16187 L
F
.804 .522 .247 r
.44812 .16187 m
.44812 .13156 L
.4484 .13156 L
.4484 .16187 L
s
1 .894 .882 r
.4484 .16187 m
.4484 .13184 L
.44894 .13184 L
.44894 .16187 L
F
.804 .522 .247 r
.4484 .16187 m
.4484 .13184 L
.44894 .13184 L
.44894 .16187 L
s
1 .894 .882 r
.44894 .16187 m
.44894 .13209 L
.44948 .13209 L
.44948 .16187 L
F
.804 .522 .247 r
.44894 .16187 m
.44894 .13209 L
.44948 .13209 L
.44948 .16187 L
s
1 .894 .882 r
.44948 .16187 m
.44948 .13239 L
.44978 .13239 L
.44978 .16187 L
F
.804 .522 .247 r
.44948 .16187 m
.44948 .13239 L
.44978 .13239 L
.44978 .16187 L
s
1 .894 .882 r
.44978 .16187 m
.44978 .13275 L
.45032 .13275 L
.45032 .16187 L
F
.804 .522 .247 r
.44978 .16187 m
.44978 .13275 L
.45032 .13275 L
.45032 .16187 L
s
1 .894 .882 r
.45032 .16187 m
.45032 .13283 L
.45075 .13283 L
.45075 .16187 L
F
.804 .522 .247 r
.45032 .16187 m
.45032 .13283 L
.45075 .13283 L
.45075 .16187 L
s
1 .894 .882 r
.45075 .16187 m
.45075 .13311 L
.45122 .13311 L
.45122 .16187 L
F
.804 .522 .247 r
.45075 .16187 m
.45075 .13311 L
.45122 .13311 L
.45122 .16187 L
s
1 .894 .882 r
.45122 .16187 m
.45122 .13356 L
.4518 .13356 L
.4518 .16187 L
F
.804 .522 .247 r
.45122 .16187 m
.45122 .13356 L
.4518 .13356 L
.4518 .16187 L
s
1 .894 .882 r
.4518 .16187 m
.4518 .13366 L
.45223 .13366 L
.45223 .16187 L
F
.804 .522 .247 r
.4518 .16187 m
.4518 .13366 L
.45223 .13366 L
.45223 .16187 L
s
1 .894 .882 r
.45223 .16187 m
.45223 .13394 L
.45269 .13394 L
.45269 .16187 L
F
.804 .522 .247 r
.45223 .16187 m
.45223 .13394 L
.45269 .13394 L
.45269 .16187 L
s
1 .894 .882 r
.45269 .16187 m
.45269 .13413 L
.4529 .13413 L
.4529 .16187 L
F
.804 .522 .247 r
.45269 .16187 m
.45269 .13413 L
.4529 .13413 L
.4529 .16187 L
s
1 .894 .882 r
.4529 .16187 m
.4529 .13425 L
.45319 .13425 L
.45319 .16187 L
F
.804 .522 .247 r
.4529 .16187 m
.4529 .13425 L
.45319 .13425 L
.45319 .16187 L
s
1 .894 .882 r
.45319 .16187 m
.45319 .13445 L
.45352 .13445 L
.45352 .16187 L
F
.804 .522 .247 r
.45319 .16187 m
.45319 .13445 L
.45352 .13445 L
.45352 .16187 L
s
1 .894 .882 r
.45352 .16187 m
.45352 .13465 L
.45377 .13465 L
.45377 .16187 L
F
.804 .522 .247 r
.45352 .16187 m
.45352 .13465 L
.45377 .13465 L
.45377 .16187 L
s
1 .894 .882 r
.45377 .16187 m
.45377 .1347 L
.45435 .1347 L
.45435 .16187 L
F
.804 .522 .247 r
.45377 .16187 m
.45377 .1347 L
.45435 .1347 L
.45435 .16187 L
s
1 .894 .882 r
.45435 .16187 m
.45435 .13509 L
.45455 .13509 L
.45455 .16187 L
F
.804 .522 .247 r
.45435 .16187 m
.45435 .13509 L
.45455 .13509 L
.45455 .16187 L
s
1 .894 .882 r
.45455 .16187 m
.45455 .13529 L
.45506 .13529 L
.45506 .16187 L
F
.804 .522 .247 r
.45455 .16187 m
.45455 .13529 L
.45506 .13529 L
.45506 .16187 L
s
1 .894 .882 r
.45506 .16187 m
.45506 .13563 L
.45563 .13563 L
.45563 .16187 L
F
.804 .522 .247 r
.45506 .16187 m
.45506 .13563 L
.45563 .13563 L
.45563 .16187 L
s
1 .894 .882 r
.45563 .16187 m
.45563 .1358 L
.45583 .1358 L
.45583 .16187 L
F
.804 .522 .247 r
.45563 .16187 m
.45563 .1358 L
.45583 .1358 L
.45583 .16187 L
s
1 .894 .882 r
.45583 .16187 m
.45583 .13597 L
.45608 .13597 L
.45608 .16187 L
F
.804 .522 .247 r
.45583 .16187 m
.45583 .13597 L
.45608 .13597 L
.45608 .16187 L
s
1 .894 .882 r
.45608 .16187 m
.45608 .13612 L
.45637 .13612 L
.45637 .16187 L
F
.804 .522 .247 r
.45608 .16187 m
.45608 .13612 L
.45637 .13612 L
.45637 .16187 L
s
1 .894 .882 r
.45637 .16187 m
.45637 .13629 L
.45672 .13629 L
.45672 .16187 L
F
.804 .522 .247 r
.45637 .16187 m
.45637 .13629 L
.45672 .13629 L
.45672 .16187 L
s
1 .894 .882 r
.45672 .16187 m
.45672 .13653 L
.4571 .13653 L
.4571 .16187 L
F
.804 .522 .247 r
.45672 .16187 m
.45672 .13653 L
.4571 .13653 L
.4571 .16187 L
s
1 .894 .882 r
.4571 .16187 m
.4571 .13656 L
.45743 .13656 L
.45743 .16187 L
F
.804 .522 .247 r
.4571 .16187 m
.4571 .13656 L
.45743 .13656 L
.45743 .16187 L
s
1 .894 .882 r
.45743 .16187 m
.45743 .13683 L
.45763 .13683 L
.45763 .16187 L
F
.804 .522 .247 r
.45743 .16187 m
.45743 .13683 L
.45763 .13683 L
.45763 .16187 L
s
1 .894 .882 r
.45763 .16187 m
.45763 .13693 L
.45808 .13693 L
.45808 .16187 L
F
.804 .522 .247 r
.45763 .16187 m
.45763 .13693 L
.45808 .13693 L
.45808 .16187 L
s
1 .894 .882 r
.45808 .16187 m
.45808 .13726 L
.45855 .13726 L
.45855 .16187 L
F
.804 .522 .247 r
.45808 .16187 m
.45808 .13726 L
.45855 .13726 L
.45855 .16187 L
s
1 .894 .882 r
.45855 .16187 m
.45855 .13744 L
.45878 .13744 L
.45878 .16187 L
F
.804 .522 .247 r
.45855 .16187 m
.45855 .13744 L
.45878 .13744 L
.45878 .16187 L
s
1 .894 .882 r
.45878 .16187 m
.45878 .13765 L
.45908 .13765 L
.45908 .16187 L
F
.804 .522 .247 r
.45878 .16187 m
.45878 .13765 L
.45908 .13765 L
.45908 .16187 L
s
1 .894 .882 r
.45908 .16187 m
.45908 .13767 L
.4593 .13767 L
.4593 .16187 L
F
.804 .522 .247 r
.45908 .16187 m
.45908 .13767 L
.4593 .13767 L
.4593 .16187 L
s
1 .894 .882 r
.4593 .16187 m
.4593 .13785 L
.45993 .13785 L
.45993 .16187 L
F
.804 .522 .247 r
.4593 .16187 m
.4593 .13785 L
.45993 .13785 L
.45993 .16187 L
s
1 .894 .882 r
.45993 .16187 m
.45993 .13825 L
.46022 .13825 L
.46022 .16187 L
F
.804 .522 .247 r
.45993 .16187 m
.45993 .13825 L
.46022 .13825 L
.46022 .16187 L
s
1 .894 .882 r
.46022 .16187 m
.46022 .13849 L
.46073 .13849 L
.46073 .16187 L
F
.804 .522 .247 r
.46022 .16187 m
.46022 .13849 L
.46073 .13849 L
.46073 .16187 L
s
1 .894 .882 r
.46073 .16187 m
.46073 .13873 L
.46112 .13873 L
.46112 .16187 L
F
.804 .522 .247 r
.46073 .16187 m
.46073 .13873 L
.46112 .13873 L
.46112 .16187 L
s
1 .894 .882 r
.46112 .16187 m
.46112 .13908 L
.46174 .13908 L
.46174 .16187 L
F
.804 .522 .247 r
.46112 .16187 m
.46112 .13908 L
.46174 .13908 L
.46174 .16187 L
s
1 .894 .882 r
.46174 .16187 m
.46174 .13929 L
.46237 .13929 L
.46237 .16187 L
F
.804 .522 .247 r
.46174 .16187 m
.46174 .13929 L
.46237 .13929 L
.46237 .16187 L
s
1 .894 .882 r
.46237 .16187 m
.46237 .13956 L
.46275 .13956 L
.46275 .16187 L
F
.804 .522 .247 r
.46237 .16187 m
.46237 .13956 L
.46275 .13956 L
.46275 .16187 L
s
1 .894 .882 r
.46275 .16187 m
.46275 .1399 L
.46308 .1399 L
.46308 .16187 L
F
.804 .522 .247 r
.46275 .16187 m
.46275 .1399 L
.46308 .1399 L
.46308 .16187 L
s
1 .894 .882 r
.46308 .16187 m
.46308 .14002 L
.46331 .14002 L
.46331 .16187 L
F
.804 .522 .247 r
.46308 .16187 m
.46308 .14002 L
.46331 .14002 L
.46331 .16187 L
s
1 .894 .882 r
.46331 .16187 m
.46331 .14027 L
.46393 .14027 L
.46393 .16187 L
F
.804 .522 .247 r
.46331 .16187 m
.46331 .14027 L
.46393 .14027 L
.46393 .16187 L
s
1 .894 .882 r
.46393 .16187 m
.46393 .14057 L
.46443 .14057 L
.46443 .16187 L
F
.804 .522 .247 r
.46393 .16187 m
.46393 .14057 L
.46443 .14057 L
.46443 .16187 L
s
1 .894 .882 r
.46443 .16187 m
.46443 .14073 L
.46484 .14073 L
.46484 .16187 L
F
.804 .522 .247 r
.46443 .16187 m
.46443 .14073 L
.46484 .14073 L
.46484 .16187 L
s
1 .894 .882 r
.46484 .16187 m
.46484 .14106 L
.46505 .14106 L
.46505 .16187 L
F
.804 .522 .247 r
.46484 .16187 m
.46484 .14106 L
.46505 .14106 L
.46505 .16187 L
s
1 .894 .882 r
.46505 .16187 m
.46505 .14125 L
.46562 .14125 L
.46562 .16187 L
F
.804 .522 .247 r
.46505 .16187 m
.46505 .14125 L
.46562 .14125 L
.46562 .16187 L
s
1 .894 .882 r
.46562 .16187 m
.46562 .14152 L
.46602 .14152 L
.46602 .16187 L
F
.804 .522 .247 r
.46562 .16187 m
.46562 .14152 L
.46602 .14152 L
.46602 .16187 L
s
1 .894 .882 r
.46602 .16187 m
.46602 .14166 L
.46627 .14166 L
.46627 .16187 L
F
.804 .522 .247 r
.46602 .16187 m
.46602 .14166 L
.46627 .14166 L
.46627 .16187 L
s
1 .894 .882 r
.46627 .16187 m
.46627 .14178 L
.46675 .14178 L
.46675 .16187 L
F
.804 .522 .247 r
.46627 .16187 m
.46627 .14178 L
.46675 .14178 L
.46675 .16187 L
s
1 .894 .882 r
.46675 .16187 m
.46675 .14216 L
.46717 .14216 L
.46717 .16187 L
F
.804 .522 .247 r
.46675 .16187 m
.46675 .14216 L
.46717 .14216 L
.46717 .16187 L
s
1 .894 .882 r
.46717 .16187 m
.46717 .14244 L
.46757 .14244 L
.46757 .16187 L
F
.804 .522 .247 r
.46717 .16187 m
.46717 .14244 L
.46757 .14244 L
.46757 .16187 L
s
1 .894 .882 r
.46757 .16187 m
.46757 .14251 L
.468 .14251 L
.468 .16187 L
F
.804 .522 .247 r
.46757 .16187 m
.46757 .14251 L
.468 .14251 L
.468 .16187 L
s
1 .894 .882 r
.468 .16187 m
.468 .1428 L
.46819 .1428 L
.46819 .16187 L
F
.804 .522 .247 r
.468 .16187 m
.468 .1428 L
.46819 .1428 L
.46819 .16187 L
s
1 .894 .882 r
.46819 .16187 m
.46819 .14308 L
.46858 .14308 L
.46858 .16187 L
F
.804 .522 .247 r
.46819 .16187 m
.46819 .14308 L
.46858 .14308 L
.46858 .16187 L
s
1 .894 .882 r
.46858 .16187 m
.46858 .14322 L
.46887 .14322 L
.46887 .16187 L
F
.804 .522 .247 r
.46858 .16187 m
.46858 .14322 L
.46887 .14322 L
.46887 .16187 L
s
1 .894 .882 r
.46887 .16187 m
.46887 .14348 L
.46927 .14348 L
.46927 .16187 L
F
.804 .522 .247 r
.46887 .16187 m
.46887 .14348 L
.46927 .14348 L
.46927 .16187 L
s
1 .894 .882 r
.46927 .16187 m
.46927 .14352 L
.46947 .14352 L
.46947 .16187 L
F
.804 .522 .247 r
.46927 .16187 m
.46927 .14352 L
.46947 .14352 L
.46947 .16187 L
s
1 .894 .882 r
.46947 .16187 m
.46947 .14366 L
.46977 .14366 L
.46977 .16187 L
F
.804 .522 .247 r
.46947 .16187 m
.46947 .14366 L
.46977 .14366 L
.46977 .16187 L
s
1 .894 .882 r
.46977 .16187 m
.46977 .14381 L
.47018 .14381 L
.47018 .16187 L
F
.804 .522 .247 r
.46977 .16187 m
.46977 .14381 L
.47018 .14381 L
.47018 .16187 L
s
1 .894 .882 r
.47018 .16187 m
.47018 .14406 L
.47038 .14406 L
.47038 .16187 L
F
.804 .522 .247 r
.47018 .16187 m
.47018 .14406 L
.47038 .14406 L
.47038 .16187 L
s
1 .894 .882 r
.47038 .16187 m
.47038 .1442 L
.4706 .1442 L
.4706 .16187 L
F
.804 .522 .247 r
.47038 .16187 m
.47038 .1442 L
.4706 .1442 L
.4706 .16187 L
s
1 .894 .882 r
.4706 .16187 m
.4706 .14443 L
.47091 .14443 L
.47091 .16187 L
F
.804 .522 .247 r
.4706 .16187 m
.4706 .14443 L
.47091 .14443 L
.47091 .16187 L
s
1 .894 .882 r
.47091 .16187 m
.47091 .14444 L
.47114 .14444 L
.47114 .16187 L
F
.804 .522 .247 r
.47091 .16187 m
.47091 .14444 L
.47114 .14444 L
.47114 .16187 L
s
1 .894 .882 r
.47114 .16187 m
.47114 .14473 L
.47164 .14473 L
.47164 .16187 L
F
.804 .522 .247 r
.47114 .16187 m
.47114 .14473 L
.47164 .14473 L
.47164 .16187 L
s
1 .894 .882 r
.47164 .16187 m
.47164 .14518 L
.47227 .14518 L
.47227 .16187 L
F
.804 .522 .247 r
.47164 .16187 m
.47164 .14518 L
.47227 .14518 L
.47227 .16187 L
s
1 .894 .882 r
.47227 .16187 m
.47227 .1453 L
.4726 .1453 L
.4726 .16187 L
F
.804 .522 .247 r
.47227 .16187 m
.47227 .1453 L
.4726 .1453 L
.4726 .16187 L
s
1 .894 .882 r
.4726 .16187 m
.4726 .14552 L
.47296 .14552 L
.47296 .16187 L
F
.804 .522 .247 r
.4726 .16187 m
.4726 .14552 L
.47296 .14552 L
.47296 .16187 L
s
1 .894 .882 r
.47296 .16187 m
.47296 .14571 L
.47324 .14571 L
.47324 .16187 L
F
.804 .522 .247 r
.47296 .16187 m
.47296 .14571 L
.47324 .14571 L
.47324 .16187 L
s
1 .894 .882 r
.47324 .16187 m
.47324 .14611 L
.47385 .14611 L
.47385 .16187 L
F
.804 .522 .247 r
.47324 .16187 m
.47324 .14611 L
.47385 .14611 L
.47385 .16187 L
s
1 .894 .882 r
.47385 .16187 m
.47385 .14634 L
.47425 .14634 L
.47425 .16187 L
F
.804 .522 .247 r
.47385 .16187 m
.47385 .14634 L
.47425 .14634 L
.47425 .16187 L
s
1 .894 .882 r
.47425 .16187 m
.47425 .1467 L
.47485 .1467 L
.47485 .16187 L
F
.804 .522 .247 r
.47425 .16187 m
.47425 .1467 L
.47485 .1467 L
.47485 .16187 L
s
1 .894 .882 r
.47485 .16187 m
.47485 .14675 L
.47507 .14675 L
.47507 .16187 L
F
.804 .522 .247 r
.47485 .16187 m
.47485 .14675 L
.47507 .14675 L
.47507 .16187 L
s
1 .894 .882 r
.47507 .16187 m
.47507 .14702 L
.4754 .14702 L
.4754 .16187 L
F
.804 .522 .247 r
.47507 .16187 m
.47507 .14702 L
.4754 .14702 L
.4754 .16187 L
s
1 .894 .882 r
.4754 .16187 m
.4754 .14717 L
.47602 .14717 L
.47602 .16187 L
F
.804 .522 .247 r
.4754 .16187 m
.4754 .14717 L
.47602 .14717 L
.47602 .16187 L
s
1 .894 .882 r
.47602 .16187 m
.47602 .14746 L
.47641 .14746 L
.47641 .16187 L
F
.804 .522 .247 r
.47602 .16187 m
.47602 .14746 L
.47641 .14746 L
.47641 .16187 L
s
1 .894 .882 r
.47641 .16187 m
.47641 .14768 L
.47684 .14768 L
.47684 .16187 L
F
.804 .522 .247 r
.47641 .16187 m
.47641 .14768 L
.47684 .14768 L
.47684 .16187 L
s
1 .894 .882 r
.47684 .16187 m
.47684 .14797 L
.47716 .14797 L
.47716 .16187 L
F
.804 .522 .247 r
.47684 .16187 m
.47684 .14797 L
.47716 .14797 L
.47716 .16187 L
s
1 .894 .882 r
.47716 .16187 m
.47716 .14818 L
.47758 .14818 L
.47758 .16187 L
F
.804 .522 .247 r
.47716 .16187 m
.47716 .14818 L
.47758 .14818 L
.47758 .16187 L
s
1 .894 .882 r
.47758 .16187 m
.47758 .14841 L
.47787 .14841 L
.47787 .16187 L
F
.804 .522 .247 r
.47758 .16187 m
.47758 .14841 L
.47787 .14841 L
.47787 .16187 L
s
1 .894 .882 r
.47787 .16187 m
.47787 .14853 L
.47809 .14853 L
.47809 .16187 L
F
.804 .522 .247 r
.47787 .16187 m
.47787 .14853 L
.47809 .14853 L
.47809 .16187 L
s
1 .894 .882 r
.47809 .16187 m
.47809 .14865 L
.47841 .14865 L
.47841 .16187 L
F
.804 .522 .247 r
.47809 .16187 m
.47809 .14865 L
.47841 .14865 L
.47841 .16187 L
s
1 .894 .882 r
.47841 .16187 m
.47841 .14883 L
.47873 .14883 L
.47873 .16187 L
F
.804 .522 .247 r
.47841 .16187 m
.47841 .14883 L
.47873 .14883 L
.47873 .16187 L
s
1 .894 .882 r
.47873 .16187 m
.47873 .14909 L
.47924 .14909 L
.47924 .16187 L
F
.804 .522 .247 r
.47873 .16187 m
.47873 .14909 L
.47924 .14909 L
.47924 .16187 L
s
1 .894 .882 r
.47924 .16187 m
.47924 .14942 L
.47945 .14942 L
.47945 .16187 L
F
.804 .522 .247 r
.47924 .16187 m
.47924 .14942 L
.47945 .14942 L
.47945 .16187 L
s
1 .894 .882 r
.47945 .16187 m
.47945 .14953 L
.47974 .14953 L
.47974 .16187 L
F
.804 .522 .247 r
.47945 .16187 m
.47945 .14953 L
.47974 .14953 L
.47974 .16187 L
s
1 .894 .882 r
.47974 .16187 m
.47974 .14962 L
.47994 .14962 L
.47994 .16187 L
F
.804 .522 .247 r
.47974 .16187 m
.47974 .14962 L
.47994 .14962 L
.47994 .16187 L
s
1 .894 .882 r
.47994 .16187 m
.47994 .14979 L
.48041 .14979 L
.48041 .16187 L
F
.804 .522 .247 r
.47994 .16187 m
.47994 .14979 L
.48041 .14979 L
.48041 .16187 L
s
1 .894 .882 r
.48041 .16187 m
.48041 .15006 L
.48077 .15006 L
.48077 .16187 L
F
.804 .522 .247 r
.48041 .16187 m
.48041 .15006 L
.48077 .15006 L
.48077 .16187 L
s
1 .894 .882 r
.48077 .16187 m
.48077 .15033 L
.48106 .15033 L
.48106 .16187 L
F
.804 .522 .247 r
.48077 .16187 m
.48077 .15033 L
.48106 .15033 L
.48106 .16187 L
s
1 .894 .882 r
.48106 .16187 m
.48106 .15059 L
.48157 .15059 L
.48157 .16187 L
F
.804 .522 .247 r
.48106 .16187 m
.48106 .15059 L
.48157 .15059 L
.48157 .16187 L
s
1 .894 .882 r
.48157 .16187 m
.48157 .15083 L
.48187 .15083 L
.48187 .16187 L
F
.804 .522 .247 r
.48157 .16187 m
.48157 .15083 L
.48187 .15083 L
.48187 .16187 L
s
1 .894 .882 r
.48187 .16187 m
.48187 .151 L
.48214 .151 L
.48214 .16187 L
F
.804 .522 .247 r
.48187 .16187 m
.48187 .151 L
.48214 .151 L
.48214 .16187 L
s
1 .894 .882 r
.48214 .16187 m
.48214 .15118 L
.48246 .15118 L
.48246 .16187 L
F
.804 .522 .247 r
.48214 .16187 m
.48214 .15118 L
.48246 .15118 L
.48246 .16187 L
s
1 .894 .882 r
.48246 .16187 m
.48246 .15137 L
.48276 .15137 L
.48276 .16187 L
F
.804 .522 .247 r
.48246 .16187 m
.48246 .15137 L
.48276 .15137 L
.48276 .16187 L
s
1 .894 .882 r
.48276 .16187 m
.48276 .15157 L
.4831 .15157 L
.4831 .16187 L
F
.804 .522 .247 r
.48276 .16187 m
.48276 .15157 L
.4831 .15157 L
.4831 .16187 L
s
1 .894 .882 r
.4831 .16187 m
.4831 .15169 L
.48334 .15169 L
.48334 .16187 L
F
.804 .522 .247 r
.4831 .16187 m
.4831 .15169 L
.48334 .15169 L
.48334 .16187 L
s
1 .894 .882 r
.48334 .16187 m
.48334 .1521 L
.48396 .1521 L
.48396 .16187 L
F
.804 .522 .247 r
.48334 .16187 m
.48334 .1521 L
.48396 .1521 L
.48396 .16187 L
s
1 .894 .882 r
.48396 .16187 m
.48396 .15222 L
.48428 .15222 L
.48428 .16187 L
F
.804 .522 .247 r
.48396 .16187 m
.48396 .15222 L
.48428 .15222 L
.48428 .16187 L
s
1 .894 .882 r
.48428 .16187 m
.48428 .15253 L
.48487 .15253 L
.48487 .16187 L
F
.804 .522 .247 r
.48428 .16187 m
.48428 .15253 L
.48487 .15253 L
.48487 .16187 L
s
1 .894 .882 r
.48487 .16187 m
.48487 .15279 L
.48532 .15279 L
.48532 .16187 L
F
.804 .522 .247 r
.48487 .16187 m
.48487 .15279 L
.48532 .15279 L
.48532 .16187 L
s
1 .894 .882 r
.48532 .16187 m
.48532 .15311 L
.48581 .15311 L
.48581 .16187 L
F
.804 .522 .247 r
.48532 .16187 m
.48532 .15311 L
.48581 .15311 L
.48581 .16187 L
s
1 .894 .882 r
.48581 .16187 m
.48581 .15329 L
.48635 .15329 L
.48635 .16187 L
F
.804 .522 .247 r
.48581 .16187 m
.48581 .15329 L
.48635 .15329 L
.48635 .16187 L
s
1 .894 .882 r
.48635 .16187 m
.48635 .15362 L
.48684 .15362 L
.48684 .16187 L
F
.804 .522 .247 r
.48635 .16187 m
.48635 .15362 L
.48684 .15362 L
.48684 .16187 L
s
1 .894 .882 r
.48684 .16187 m
.48684 .15392 L
.48726 .15392 L
.48726 .16187 L
F
.804 .522 .247 r
.48684 .16187 m
.48684 .15392 L
.48726 .15392 L
.48726 .16187 L
s
1 .894 .882 r
.48726 .16187 m
.48726 .15421 L
.48762 .15421 L
.48762 .16187 L
F
.804 .522 .247 r
.48726 .16187 m
.48726 .15421 L
.48762 .15421 L
.48762 .16187 L
s
1 .894 .882 r
.48762 .16187 m
.48762 .15436 L
.48804 .15436 L
.48804 .16187 L
F
.804 .522 .247 r
.48762 .16187 m
.48762 .15436 L
.48804 .15436 L
.48804 .16187 L
s
1 .894 .882 r
.48804 .16187 m
.48804 .15493 L
.48866 .15493 L
.48866 .16187 L
F
.804 .522 .247 r
.48804 .16187 m
.48804 .15493 L
.48866 .15493 L
.48866 .16187 L
s
1 .894 .882 r
.48866 .16187 m
.48866 .15506 L
.48905 .15506 L
.48905 .16187 L
F
.804 .522 .247 r
.48866 .16187 m
.48866 .15506 L
.48905 .15506 L
.48905 .16187 L
s
1 .894 .882 r
.48905 .16187 m
.48905 .15518 L
.48932 .15518 L
.48932 .16187 L
F
.804 .522 .247 r
.48905 .16187 m
.48905 .15518 L
.48932 .15518 L
.48932 .16187 L
s
1 .894 .882 r
.48932 .16187 m
.48932 .15536 L
.48973 .15536 L
.48973 .16187 L
F
.804 .522 .247 r
.48932 .16187 m
.48932 .15536 L
.48973 .15536 L
.48973 .16187 L
s
1 .894 .882 r
.48973 .16187 m
.48973 .15574 L
.49006 .15574 L
.49006 .16187 L
F
.804 .522 .247 r
.48973 .16187 m
.48973 .15574 L
.49006 .15574 L
.49006 .16187 L
s
1 .894 .882 r
.49006 .16187 m
.49006 .15583 L
.49029 .15583 L
.49029 .16187 L
F
.804 .522 .247 r
.49006 .16187 m
.49006 .15583 L
.49029 .15583 L
.49029 .16187 L
s
1 .894 .882 r
.49029 .16187 m
.49029 .15607 L
.4909 .15607 L
.4909 .16187 L
F
.804 .522 .247 r
.49029 .16187 m
.49029 .15607 L
.4909 .15607 L
.4909 .16187 L
s
1 .894 .882 r
.4909 .16187 m
.4909 .15644 L
.49144 .15644 L
.49144 .16187 L
F
.804 .522 .247 r
.4909 .16187 m
.4909 .15644 L
.49144 .15644 L
.49144 .16187 L
s
1 .894 .882 r
.49144 .16187 m
.49144 .15663 L
.49167 .15663 L
.49167 .16187 L
F
.804 .522 .247 r
.49144 .16187 m
.49144 .15663 L
.49167 .15663 L
.49167 .16187 L
s
1 .894 .882 r
.49167 .16187 m
.49167 .15695 L
.49227 .15695 L
.49227 .16187 L
F
.804 .522 .247 r
.49167 .16187 m
.49167 .15695 L
.49227 .15695 L
.49227 .16187 L
s
1 .894 .882 r
.49227 .16187 m
.49227 .15731 L
.49275 .15731 L
.49275 .16187 L
F
.804 .522 .247 r
.49227 .16187 m
.49227 .15731 L
.49275 .15731 L
.49275 .16187 L
s
1 .894 .882 r
.49275 .16187 m
.49275 .15758 L
.49319 .15758 L
.49319 .16187 L
F
.804 .522 .247 r
.49275 .16187 m
.49275 .15758 L
.49319 .15758 L
.49319 .16187 L
s
1 .894 .882 r
.49319 .16187 m
.49319 .15775 L
.49371 .15775 L
.49371 .16187 L
F
.804 .522 .247 r
.49319 .16187 m
.49319 .15775 L
.49371 .15775 L
.49371 .16187 L
s
1 .894 .882 r
.49371 .16187 m
.49371 .15831 L
.49426 .15831 L
.49426 .16187 L
F
.804 .522 .247 r
.49371 .16187 m
.49371 .15831 L
.49426 .15831 L
.49426 .16187 L
s
1 .894 .882 r
.49426 .16187 m
.49426 .15855 L
.49476 .15855 L
.49476 .16187 L
F
.804 .522 .247 r
.49426 .16187 m
.49426 .15855 L
.49476 .15855 L
.49476 .16187 L
s
1 .894 .882 r
.49476 .16187 m
.49476 .15866 L
.49506 .15866 L
.49506 .16187 L
F
.804 .522 .247 r
.49476 .16187 m
.49476 .15866 L
.49506 .15866 L
.49506 .16187 L
s
1 .894 .882 r
.49506 .16187 m
.49506 .15904 L
.49564 .15904 L
.49564 .16187 L
F
.804 .522 .247 r
.49506 .16187 m
.49506 .15904 L
.49564 .15904 L
.49564 .16187 L
s
1 .894 .882 r
.49564 .16187 m
.49564 .15926 L
.49593 .15926 L
.49593 .16187 L
F
.804 .522 .247 r
.49564 .16187 m
.49564 .15926 L
.49593 .15926 L
.49593 .16187 L
s
1 .894 .882 r
.49593 .16187 m
.49593 .15937 L
.49612 .15937 L
.49612 .16187 L
F
.804 .522 .247 r
.49593 .16187 m
.49593 .15937 L
.49612 .15937 L
.49612 .16187 L
s
1 .894 .882 r
.49612 .16187 m
.49612 .1597 L
.49653 .1597 L
.49653 .16187 L
F
.804 .522 .247 r
.49612 .16187 m
.49612 .1597 L
.49653 .1597 L
.49653 .16187 L
s
1 .894 .882 r
.49653 .16187 m
.49653 .15979 L
.49681 .15979 L
.49681 .16187 L
F
.804 .522 .247 r
.49653 .16187 m
.49653 .15979 L
.49681 .15979 L
.49681 .16187 L
s
1 .894 .882 r
.49681 .16187 m
.49681 .15994 L
.49732 .15994 L
.49732 .16187 L
F
.804 .522 .247 r
.49681 .16187 m
.49681 .15994 L
.49732 .15994 L
.49732 .16187 L
s
1 .894 .882 r
.49732 .16187 m
.49732 .16038 L
.49778 .16038 L
.49778 .16187 L
F
.804 .522 .247 r
.49732 .16187 m
.49732 .16038 L
.49778 .16038 L
.49778 .16187 L
s
1 .894 .882 r
.49778 .16187 m
.49778 .16078 L
.49841 .16078 L
.49841 .16187 L
F
.804 .522 .247 r
.49778 .16187 m
.49778 .16078 L
.49841 .16078 L
.49841 .16187 L
s
1 .894 .882 r
.49841 .16187 m
.49841 .16096 L
.49871 .16096 L
.49871 .16187 L
F
.804 .522 .247 r
.49841 .16187 m
.49841 .16096 L
.49871 .16096 L
.49871 .16187 L
s
1 .894 .882 r
.49871 .16187 m
.49871 .16119 L
.49902 .16119 L
.49902 .16187 L
F
.804 .522 .247 r
.49871 .16187 m
.49871 .16119 L
.49902 .16119 L
.49902 .16187 L
s
1 .894 .882 r
.49902 .16187 m
.49902 .16139 L
.49941 .16139 L
.49941 .16187 L
F
.804 .522 .247 r
.49902 .16187 m
.49902 .16139 L
.49941 .16139 L
.49941 .16187 L
s
1 .894 .882 r
.49941 .16187 m
.49941 .16166 L
.49982 .16166 L
.49982 .16187 L
F
.804 .522 .247 r
.49941 .16187 m
.49941 .16166 L
.49982 .16166 L
.49982 .16187 L
s
.678 .847 .902 r
.49982 .16187 m
.49982 .16198 L
.50042 .16198 L
.50042 .16187 L
F
.2 .63 .79 r
.49982 .16187 m
.49982 .16198 L
.50042 .16198 L
.50042 .16187 L
s
.678 .847 .902 r
.50042 .16187 m
.50042 .16218 L
.50069 .16218 L
.50069 .16187 L
F
.2 .63 .79 r
.50042 .16187 m
.50042 .16218 L
.50069 .16218 L
.50069 .16187 L
s
.678 .847 .902 r
.50069 .16187 m
.50069 .16234 L
.5011 .16234 L
.5011 .16187 L
F
.2 .63 .79 r
.50069 .16187 m
.50069 .16234 L
.5011 .16234 L
.5011 .16187 L
s
.678 .847 .902 r
.5011 .16187 m
.5011 .16261 L
.50162 .16261 L
.50162 .16187 L
F
.2 .63 .79 r
.5011 .16187 m
.5011 .16261 L
.50162 .16261 L
.50162 .16187 L
s
.678 .847 .902 r
.50162 .16187 m
.50162 .16307 L
.50218 .16307 L
.50218 .16187 L
F
.2 .63 .79 r
.50162 .16187 m
.50162 .16307 L
.50218 .16307 L
.50218 .16187 L
s
.678 .847 .902 r
.50218 .16187 m
.50218 .16338 L
.50249 .16338 L
.50249 .16187 L
F
.2 .63 .79 r
.50218 .16187 m
.50218 .16338 L
.50249 .16338 L
.50249 .16187 L
s
.678 .847 .902 r
.50249 .16187 m
.50249 .1636 L
.50306 .1636 L
.50306 .16187 L
F
.2 .63 .79 r
.50249 .16187 m
.50249 .1636 L
.50306 .1636 L
.50306 .16187 L
s
.678 .847 .902 r
.50306 .16187 m
.50306 .16386 L
.50333 .16386 L
.50333 .16187 L
F
.2 .63 .79 r
.50306 .16187 m
.50306 .16386 L
.50333 .16386 L
.50333 .16187 L
s
.678 .847 .902 r
.50333 .16187 m
.50333 .16398 L
.50355 .16398 L
.50355 .16187 L
F
.2 .63 .79 r
.50333 .16187 m
.50333 .16398 L
.50355 .16398 L
.50355 .16187 L
s
.678 .847 .902 r
.50355 .16187 m
.50355 .1643 L
.50395 .1643 L
.50395 .16187 L
F
.2 .63 .79 r
.50355 .16187 m
.50355 .1643 L
.50395 .1643 L
.50395 .16187 L
s
.678 .847 .902 r
.50395 .16187 m
.50395 .16446 L
.50422 .16446 L
.50422 .16187 L
F
.2 .63 .79 r
.50395 .16187 m
.50395 .16446 L
.50422 .16446 L
.50422 .16187 L
s
.678 .847 .902 r
.50422 .16187 m
.50422 .16469 L
.50483 .16469 L
.50483 .16187 L
F
.2 .63 .79 r
.50422 .16187 m
.50422 .16469 L
.50483 .16469 L
.50483 .16187 L
s
.678 .847 .902 r
.50483 .16187 m
.50483 .165 L
.50511 .165 L
.50511 .16187 L
F
.2 .63 .79 r
.50483 .16187 m
.50483 .165 L
.50511 .165 L
.50511 .16187 L
s
.678 .847 .902 r
.50511 .16187 m
.50511 .16513 L
.50541 .16513 L
.50541 .16187 L
F
.2 .63 .79 r
.50511 .16187 m
.50511 .16513 L
.50541 .16513 L
.50541 .16187 L
s
.678 .847 .902 r
.50541 .16187 m
.50541 .16535 L
.50568 .16535 L
.50568 .16187 L
F
.2 .63 .79 r
.50541 .16187 m
.50541 .16535 L
.50568 .16535 L
.50568 .16187 L
s
.678 .847 .902 r
.50568 .16187 m
.50568 .16555 L
.50606 .16555 L
.50606 .16187 L
F
.2 .63 .79 r
.50568 .16187 m
.50568 .16555 L
.50606 .16555 L
.50606 .16187 L
s
.678 .847 .902 r
.50606 .16187 m
.50606 .16569 L
.50627 .16569 L
.50627 .16187 L
F
.2 .63 .79 r
.50606 .16187 m
.50606 .16569 L
.50627 .16569 L
.50627 .16187 L
s
.678 .847 .902 r
.50627 .16187 m
.50627 .16586 L
.50669 .16586 L
.50669 .16187 L
F
.2 .63 .79 r
.50627 .16187 m
.50627 .16586 L
.50669 .16586 L
.50669 .16187 L
s
.678 .847 .902 r
.50669 .16187 m
.50669 .16608 L
.50713 .16608 L
.50713 .16187 L
F
.2 .63 .79 r
.50669 .16187 m
.50669 .16608 L
.50713 .16608 L
.50713 .16187 L
s
.678 .847 .902 r
.50713 .16187 m
.50713 .16654 L
.50753 .16654 L
.50753 .16187 L
F
.2 .63 .79 r
.50713 .16187 m
.50713 .16654 L
.50753 .16654 L
.50753 .16187 L
s
.678 .847 .902 r
.50753 .16187 m
.50753 .16657 L
.50807 .16657 L
.50807 .16187 L
F
.2 .63 .79 r
.50753 .16187 m
.50753 .16657 L
.50807 .16657 L
.50807 .16187 L
s
.678 .847 .902 r
.50807 .16187 m
.50807 .16703 L
.50838 .16703 L
.50838 .16187 L
F
.2 .63 .79 r
.50807 .16187 m
.50807 .16703 L
.50838 .16703 L
.50838 .16187 L
s
.678 .847 .902 r
.50838 .16187 m
.50838 .16718 L
.50862 .16718 L
.50862 .16187 L
F
.2 .63 .79 r
.50838 .16187 m
.50838 .16718 L
.50862 .16718 L
.50862 .16187 L
s
.678 .847 .902 r
.50862 .16187 m
.50862 .16736 L
.50924 .16736 L
.50924 .16187 L
F
.2 .63 .79 r
.50862 .16187 m
.50862 .16736 L
.50924 .16736 L
.50924 .16187 L
s
.678 .847 .902 r
.50924 .16187 m
.50924 .16779 L
.50982 .16779 L
.50982 .16187 L
F
.2 .63 .79 r
.50924 .16187 m
.50924 .16779 L
.50982 .16779 L
.50982 .16187 L
s
.678 .847 .902 r
.50982 .16187 m
.50982 .16805 L
.51005 .16805 L
.51005 .16187 L
F
.2 .63 .79 r
.50982 .16187 m
.50982 .16805 L
.51005 .16805 L
.51005 .16187 L
s
.678 .847 .902 r
.51005 .16187 m
.51005 .16827 L
.51052 .16827 L
.51052 .16187 L
F
.2 .63 .79 r
.51005 .16187 m
.51005 .16827 L
.51052 .16827 L
.51052 .16187 L
s
.678 .847 .902 r
.51052 .16187 m
.51052 .16846 L
.51081 .16846 L
.51081 .16187 L
F
.2 .63 .79 r
.51052 .16187 m
.51052 .16846 L
.51081 .16846 L
.51081 .16187 L
s
.678 .847 .902 r
.51081 .16187 m
.51081 .16874 L
.51103 .16874 L
.51103 .16187 L
F
.2 .63 .79 r
.51081 .16187 m
.51081 .16874 L
.51103 .16874 L
.51103 .16187 L
s
.678 .847 .902 r
.51103 .16187 m
.51103 .16895 L
.51158 .16895 L
.51158 .16187 L
F
.2 .63 .79 r
.51103 .16187 m
.51103 .16895 L
.51158 .16895 L
.51158 .16187 L
s
.678 .847 .902 r
.51158 .16187 m
.51158 .16941 L
.51212 .16941 L
.51212 .16187 L
F
.2 .63 .79 r
.51158 .16187 m
.51158 .16941 L
.51212 .16941 L
.51212 .16187 L
s
.678 .847 .902 r
.51212 .16187 m
.51212 .16952 L
.51233 .16952 L
.51233 .16187 L
F
.2 .63 .79 r
.51212 .16187 m
.51212 .16952 L
.51233 .16952 L
.51233 .16187 L
s
.678 .847 .902 r
.51233 .16187 m
.51233 .16978 L
.51296 .16978 L
.51296 .16187 L
F
.2 .63 .79 r
.51233 .16187 m
.51233 .16978 L
.51296 .16978 L
.51296 .16187 L
s
.678 .847 .902 r
.51296 .16187 m
.51296 .17012 L
.51331 .17012 L
.51331 .16187 L
F
.2 .63 .79 r
.51296 .16187 m
.51296 .17012 L
.51331 .17012 L
.51331 .16187 L
s
.678 .847 .902 r
.51331 .16187 m
.51331 .17021 L
.51377 .17021 L
.51377 .16187 L
F
.2 .63 .79 r
.51331 .16187 m
.51331 .17021 L
.51377 .17021 L
.51377 .16187 L
s
.678 .847 .902 r
.51377 .16187 m
.51377 .17065 L
.51402 .17065 L
.51402 .16187 L
F
.2 .63 .79 r
.51377 .16187 m
.51377 .17065 L
.51402 .17065 L
.51402 .16187 L
s
.678 .847 .902 r
.51402 .16187 m
.51402 .1709 L
.51455 .1709 L
.51455 .16187 L
F
.2 .63 .79 r
.51402 .16187 m
.51402 .1709 L
.51455 .1709 L
.51455 .16187 L
s
.678 .847 .902 r
.51455 .16187 m
.51455 .17102 L
.51479 .17102 L
.51479 .16187 L
F
.2 .63 .79 r
.51455 .16187 m
.51455 .17102 L
.51479 .17102 L
.51479 .16187 L
s
.678 .847 .902 r
.51479 .16187 m
.51479 .17122 L
.51517 .17122 L
.51517 .16187 L
F
.2 .63 .79 r
.51479 .16187 m
.51479 .17122 L
.51517 .17122 L
.51517 .16187 L
s
.678 .847 .902 r
.51517 .16187 m
.51517 .1715 L
.51567 .1715 L
.51567 .16187 L
F
.2 .63 .79 r
.51517 .16187 m
.51517 .1715 L
.51567 .1715 L
.51567 .16187 L
s
.678 .847 .902 r
.51567 .16187 m
.51567 .17181 L
.5162 .17181 L
.5162 .16187 L
F
.2 .63 .79 r
.51567 .16187 m
.51567 .17181 L
.5162 .17181 L
.5162 .16187 L
s
.678 .847 .902 r
.5162 .16187 m
.5162 .17228 L
.51665 .17228 L
.51665 .16187 L
F
.2 .63 .79 r
.5162 .16187 m
.5162 .17228 L
.51665 .17228 L
.51665 .16187 L
s
.678 .847 .902 r
.51665 .16187 m
.51665 .17238 L
.51723 .17238 L
.51723 .16187 L
F
.2 .63 .79 r
.51665 .16187 m
.51665 .17238 L
.51723 .17238 L
.51723 .16187 L
s
.678 .847 .902 r
.51723 .16187 m
.51723 .17279 L
.51753 .17279 L
.51753 .16187 L
F
.2 .63 .79 r
.51723 .16187 m
.51723 .17279 L
.51753 .17279 L
.51753 .16187 L
s
.678 .847 .902 r
.51753 .16187 m
.51753 .173 L
.51815 .173 L
.51815 .16187 L
F
.2 .63 .79 r
.51753 .16187 m
.51753 .173 L
.51815 .173 L
.51815 .16187 L
s
.678 .847 .902 r
.51815 .16187 m
.51815 .17331 L
.51849 .17331 L
.51849 .16187 L
F
.2 .63 .79 r
.51815 .16187 m
.51815 .17331 L
.51849 .17331 L
.51849 .16187 L
s
.678 .847 .902 r
.51849 .16187 m
.51849 .17368 L
.51902 .17368 L
.51902 .16187 L
F
.2 .63 .79 r
.51849 .16187 m
.51849 .17368 L
.51902 .17368 L
.51902 .16187 L
s
.678 .847 .902 r
.51902 .16187 m
.51902 .17387 L
.51933 .17387 L
.51933 .16187 L
F
.2 .63 .79 r
.51902 .16187 m
.51902 .17387 L
.51933 .17387 L
.51933 .16187 L
s
.678 .847 .902 r
.51933 .16187 m
.51933 .17418 L
.51956 .17418 L
.51956 .16187 L
F
.2 .63 .79 r
.51933 .16187 m
.51933 .17418 L
.51956 .17418 L
.51956 .16187 L
s
.678 .847 .902 r
.51956 .16187 m
.51956 .17434 L
.51986 .17434 L
.51986 .16187 L
F
.2 .63 .79 r
.51956 .16187 m
.51956 .17434 L
.51986 .17434 L
.51986 .16187 L
s
.678 .847 .902 r
.51986 .16187 m
.51986 .17441 L
.52011 .17441 L
.52011 .16187 L
F
.2 .63 .79 r
.51986 .16187 m
.51986 .17441 L
.52011 .17441 L
.52011 .16187 L
s
.678 .847 .902 r
.52011 .16187 m
.52011 .1747 L
.52033 .1747 L
.52033 .16187 L
F
.2 .63 .79 r
.52011 .16187 m
.52011 .1747 L
.52033 .1747 L
.52033 .16187 L
s
.678 .847 .902 r
.52033 .16187 m
.52033 .17482 L
.52052 .17482 L
.52052 .16187 L
F
.2 .63 .79 r
.52033 .16187 m
.52033 .17482 L
.52052 .17482 L
.52052 .16187 L
s
.678 .847 .902 r
.52052 .16187 m
.52052 .17487 L
.52091 .17487 L
.52091 .16187 L
F
.2 .63 .79 r
.52052 .16187 m
.52052 .17487 L
.52091 .17487 L
.52091 .16187 L
s
.678 .847 .902 r
.52091 .16187 m
.52091 .17512 L
.52127 .17512 L
.52127 .16187 L
F
.2 .63 .79 r
.52091 .16187 m
.52091 .17512 L
.52127 .17512 L
.52127 .16187 L
s
.678 .847 .902 r
.52127 .16187 m
.52127 .1755 L
.52191 .1755 L
.52191 .16187 L
F
.2 .63 .79 r
.52127 .16187 m
.52127 .1755 L
.52191 .1755 L
.52191 .16187 L
s
.678 .847 .902 r
.52191 .16187 m
.52191 .17578 L
.52211 .17578 L
.52211 .16187 L
F
.2 .63 .79 r
.52191 .16187 m
.52191 .17578 L
.52211 .17578 L
.52211 .16187 L
s
.678 .847 .902 r
.52211 .16187 m
.52211 .17593 L
.52234 .17593 L
.52234 .16187 L
F
.2 .63 .79 r
.52211 .16187 m
.52211 .17593 L
.52234 .17593 L
.52234 .16187 L
s
.678 .847 .902 r
.52234 .16187 m
.52234 .17606 L
.52288 .17606 L
.52288 .16187 L
F
.2 .63 .79 r
.52234 .16187 m
.52234 .17606 L
.52288 .17606 L
.52288 .16187 L
s
.678 .847 .902 r
.52288 .16187 m
.52288 .17653 L
.52346 .17653 L
.52346 .16187 L
F
.2 .63 .79 r
.52288 .16187 m
.52288 .17653 L
.52346 .17653 L
.52346 .16187 L
s
.678 .847 .902 r
.52346 .16187 m
.52346 .17687 L
.52376 .17687 L
.52376 .16187 L
F
.2 .63 .79 r
.52346 .16187 m
.52346 .17687 L
.52376 .17687 L
.52376 .16187 L
s
.678 .847 .902 r
.52376 .16187 m
.52376 .1771 L
.52439 .1771 L
.52439 .16187 L
F
.2 .63 .79 r
.52376 .16187 m
.52376 .1771 L
.52439 .1771 L
.52439 .16187 L
s
.678 .847 .902 r
.52439 .16187 m
.52439 .17753 L
.52474 .17753 L
.52474 .16187 L
F
.2 .63 .79 r
.52439 .16187 m
.52439 .17753 L
.52474 .17753 L
.52474 .16187 L
s
.678 .847 .902 r
.52474 .16187 m
.52474 .17758 L
.52501 .17758 L
.52501 .16187 L
F
.2 .63 .79 r
.52474 .16187 m
.52474 .17758 L
.52501 .17758 L
.52501 .16187 L
s
.678 .847 .902 r
.52501 .16187 m
.52501 .17786 L
.52543 .17786 L
.52543 .16187 L
F
.2 .63 .79 r
.52501 .16187 m
.52501 .17786 L
.52543 .17786 L
.52543 .16187 L
s
.678 .847 .902 r
.52543 .16187 m
.52543 .17816 L
.5258 .17816 L
.5258 .16187 L
F
.2 .63 .79 r
.52543 .16187 m
.52543 .17816 L
.5258 .17816 L
.5258 .16187 L
s
.678 .847 .902 r
.5258 .16187 m
.5258 .17845 L
.5262 .17845 L
.5262 .16187 L
F
.2 .63 .79 r
.5258 .16187 m
.5258 .17845 L
.5262 .17845 L
.5262 .16187 L
s
.678 .847 .902 r
.5262 .16187 m
.5262 .17881 L
.52682 .17881 L
.52682 .16187 L
F
.2 .63 .79 r
.5262 .16187 m
.5262 .17881 L
.52682 .17881 L
.52682 .16187 L
s
.678 .847 .902 r
.52682 .16187 m
.52682 .17897 L
.52725 .17897 L
.52725 .16187 L
F
.2 .63 .79 r
.52682 .16187 m
.52682 .17897 L
.52725 .17897 L
.52725 .16187 L
s
.678 .847 .902 r
.52725 .16187 m
.52725 .17927 L
.52748 .17927 L
.52748 .16187 L
F
.2 .63 .79 r
.52725 .16187 m
.52725 .17927 L
.52748 .17927 L
.52748 .16187 L
s
.678 .847 .902 r
.52748 .16187 m
.52748 .17944 L
.52799 .17944 L
.52799 .16187 L
F
.2 .63 .79 r
.52748 .16187 m
.52748 .17944 L
.52799 .17944 L
.52799 .16187 L
s
.678 .847 .902 r
.52799 .16187 m
.52799 .17988 L
.52848 .17988 L
.52848 .16187 L
F
.2 .63 .79 r
.52799 .16187 m
.52799 .17988 L
.52848 .17988 L
.52848 .16187 L
s
.678 .847 .902 r
.52848 .16187 m
.52848 .1801 L
.52888 .1801 L
.52888 .16187 L
F
.2 .63 .79 r
.52848 .16187 m
.52848 .1801 L
.52888 .1801 L
.52888 .16187 L
s
.678 .847 .902 r
.52888 .16187 m
.52888 .18056 L
.52944 .18056 L
.52944 .16187 L
F
.2 .63 .79 r
.52888 .16187 m
.52888 .18056 L
.52944 .18056 L
.52944 .16187 L
s
.678 .847 .902 r
.52944 .16187 m
.52944 .18069 L
.52989 .18069 L
.52989 .16187 L
F
.2 .63 .79 r
.52944 .16187 m
.52944 .18069 L
.52989 .18069 L
.52989 .16187 L
s
.678 .847 .902 r
.52989 .16187 m
.52989 .18112 L
.53035 .18112 L
.53035 .16187 L
F
.2 .63 .79 r
.52989 .16187 m
.52989 .18112 L
.53035 .18112 L
.53035 .16187 L
s
.678 .847 .902 r
.53035 .16187 m
.53035 .18133 L
.53075 .18133 L
.53075 .16187 L
F
.2 .63 .79 r
.53035 .16187 m
.53035 .18133 L
.53075 .18133 L
.53075 .16187 L
s
.678 .847 .902 r
.53075 .16187 m
.53075 .18164 L
.53111 .18164 L
.53111 .16187 L
F
.2 .63 .79 r
.53075 .16187 m
.53075 .18164 L
.53111 .18164 L
.53111 .16187 L
s
.678 .847 .902 r
.53111 .16187 m
.53111 .18173 L
.5314 .18173 L
.5314 .16187 L
F
.2 .63 .79 r
.53111 .16187 m
.53111 .18173 L
.5314 .18173 L
.5314 .16187 L
s
.678 .847 .902 r
.5314 .16187 m
.5314 .18197 L
.53187 .18197 L
.53187 .16187 L
F
.2 .63 .79 r
.5314 .16187 m
.5314 .18197 L
.53187 .18197 L
.53187 .16187 L
s
.678 .847 .902 r
.53187 .16187 m
.53187 .18246 L
.53225 .18246 L
.53225 .16187 L
F
.2 .63 .79 r
.53187 .16187 m
.53187 .18246 L
.53225 .18246 L
.53225 .16187 L
s
.678 .847 .902 r
.53225 .16187 m
.53225 .18249 L
.53257 .18249 L
.53257 .16187 L
F
.2 .63 .79 r
.53225 .16187 m
.53225 .18249 L
.53257 .18249 L
.53257 .16187 L
s
.678 .847 .902 r
.53257 .16187 m
.53257 .1829 L
.53296 .1829 L
.53296 .16187 L
F
.2 .63 .79 r
.53257 .16187 m
.53257 .1829 L
.53296 .1829 L
.53296 .16187 L
s
.678 .847 .902 r
.53296 .16187 m
.53296 .18317 L
.53348 .18317 L
.53348 .16187 L
F
.2 .63 .79 r
.53296 .16187 m
.53296 .18317 L
.53348 .18317 L
.53348 .16187 L
s
.678 .847 .902 r
.53348 .16187 m
.53348 .18332 L
.53375 .18332 L
.53375 .16187 L
F
.2 .63 .79 r
.53348 .16187 m
.53348 .18332 L
.53375 .18332 L
.53375 .16187 L
s
.678 .847 .902 r
.53375 .16187 m
.53375 .18361 L
.53408 .18361 L
.53408 .16187 L
F
.2 .63 .79 r
.53375 .16187 m
.53375 .18361 L
.53408 .18361 L
.53408 .16187 L
s
.678 .847 .902 r
.53408 .16187 m
.53408 .18383 L
.53431 .18383 L
.53431 .16187 L
F
.2 .63 .79 r
.53408 .16187 m
.53408 .18383 L
.53431 .18383 L
.53431 .16187 L
s
.678 .847 .902 r
.53431 .16187 m
.53431 .18399 L
.53476 .18399 L
.53476 .16187 L
F
.2 .63 .79 r
.53431 .16187 m
.53431 .18399 L
.53476 .18399 L
.53476 .16187 L
s
.678 .847 .902 r
.53476 .16187 m
.53476 .18435 L
.53525 .18435 L
.53525 .16187 L
F
.2 .63 .79 r
.53476 .16187 m
.53476 .18435 L
.53525 .18435 L
.53525 .16187 L
s
.678 .847 .902 r
.53525 .16187 m
.53525 .18446 L
.53584 .18446 L
.53584 .16187 L
F
.2 .63 .79 r
.53525 .16187 m
.53525 .18446 L
.53584 .18446 L
.53584 .16187 L
s
.678 .847 .902 r
.53584 .16187 m
.53584 .1849 L
.53631 .1849 L
.53631 .16187 L
F
.2 .63 .79 r
.53584 .16187 m
.53584 .1849 L
.53631 .1849 L
.53631 .16187 L
s
.678 .847 .902 r
.53631 .16187 m
.53631 .1854 L
.53678 .1854 L
.53678 .16187 L
F
.2 .63 .79 r
.53631 .16187 m
.53631 .1854 L
.53678 .1854 L
.53678 .16187 L
s
.678 .847 .902 r
.53678 .16187 m
.53678 .18555 L
.53703 .18555 L
.53703 .16187 L
F
.2 .63 .79 r
.53678 .16187 m
.53678 .18555 L
.53703 .18555 L
.53703 .16187 L
s
.678 .847 .902 r
.53703 .16187 m
.53703 .18581 L
.53759 .18581 L
.53759 .16187 L
F
.2 .63 .79 r
.53703 .16187 m
.53703 .18581 L
.53759 .18581 L
.53759 .16187 L
s
.678 .847 .902 r
.53759 .16187 m
.53759 .18635 L
.53818 .18635 L
.53818 .16187 L
F
.2 .63 .79 r
.53759 .16187 m
.53759 .18635 L
.53818 .18635 L
.53818 .16187 L
s
.678 .847 .902 r
.53818 .16187 m
.53818 .18645 L
.5388 .18645 L
.5388 .16187 L
F
.2 .63 .79 r
.53818 .16187 m
.53818 .18645 L
.5388 .18645 L
.5388 .16187 L
s
.678 .847 .902 r
.5388 .16187 m
.5388 .18684 L
.53928 .18684 L
.53928 .16187 L
F
.2 .63 .79 r
.5388 .16187 m
.5388 .18684 L
.53928 .18684 L
.53928 .16187 L
s
.678 .847 .902 r
.53928 .16187 m
.53928 .18723 L
.53948 .18723 L
.53948 .16187 L
F
.2 .63 .79 r
.53928 .16187 m
.53928 .18723 L
.53948 .18723 L
.53948 .16187 L
s
.678 .847 .902 r
.53948 .16187 m
.53948 .18742 L
.53981 .18742 L
.53981 .16187 L
F
.2 .63 .79 r
.53948 .16187 m
.53948 .18742 L
.53981 .18742 L
.53981 .16187 L
s
.678 .847 .902 r
.53981 .16187 m
.53981 .1876 L
.54015 .1876 L
.54015 .16187 L
F
.2 .63 .79 r
.53981 .16187 m
.53981 .1876 L
.54015 .1876 L
.54015 .16187 L
s
.678 .847 .902 r
.54015 .16187 m
.54015 .18785 L
.54043 .18785 L
.54043 .16187 L
F
.2 .63 .79 r
.54015 .16187 m
.54015 .18785 L
.54043 .18785 L
.54043 .16187 L
s
.678 .847 .902 r
.54043 .16187 m
.54043 .18822 L
.54091 .18822 L
.54091 .16187 L
F
.2 .63 .79 r
.54043 .16187 m
.54043 .18822 L
.54091 .18822 L
.54091 .16187 L
s
.678 .847 .902 r
.54091 .16187 m
.54091 .18833 L
.54114 .18833 L
.54114 .16187 L
F
.2 .63 .79 r
.54091 .16187 m
.54091 .18833 L
.54114 .18833 L
.54114 .16187 L
s
.678 .847 .902 r
.54114 .16187 m
.54114 .18848 L
.54166 .18848 L
.54166 .16187 L
F
.2 .63 .79 r
.54114 .16187 m
.54114 .18848 L
.54166 .18848 L
.54166 .16187 L
s
.678 .847 .902 r
.54166 .16187 m
.54166 .18899 L
.54218 .18899 L
.54218 .16187 L
F
.2 .63 .79 r
.54166 .16187 m
.54166 .18899 L
.54218 .18899 L
.54218 .16187 L
s
.678 .847 .902 r
.54218 .16187 m
.54218 .1893 L
.54254 .1893 L
.54254 .16187 L
F
.2 .63 .79 r
.54218 .16187 m
.54218 .1893 L
.54254 .1893 L
.54254 .16187 L
s
.678 .847 .902 r
.54254 .16187 m
.54254 .18958 L
.54302 .18958 L
.54302 .16187 L
F
.2 .63 .79 r
.54254 .16187 m
.54254 .18958 L
.54302 .18958 L
.54302 .16187 L
s
.678 .847 .902 r
.54302 .16187 m
.54302 .1899 L
.54365 .1899 L
.54365 .16187 L
F
.2 .63 .79 r
.54302 .16187 m
.54302 .1899 L
.54365 .1899 L
.54365 .16187 L
s
.678 .847 .902 r
.54365 .16187 m
.54365 .19025 L
.54409 .19025 L
.54409 .16187 L
F
.2 .63 .79 r
.54365 .16187 m
.54365 .19025 L
.54409 .19025 L
.54409 .16187 L
s
.678 .847 .902 r
.54409 .16187 m
.54409 .19041 L
.54431 .19041 L
.54431 .16187 L
F
.2 .63 .79 r
.54409 .16187 m
.54409 .19041 L
.54431 .19041 L
.54431 .16187 L
s
.678 .847 .902 r
.54431 .16187 m
.54431 .19077 L
.54476 .19077 L
.54476 .16187 L
F
.2 .63 .79 r
.54431 .16187 m
.54431 .19077 L
.54476 .19077 L
.54476 .16187 L
s
.678 .847 .902 r
.54476 .16187 m
.54476 .19085 L
.54513 .19085 L
.54513 .16187 L
F
.2 .63 .79 r
.54476 .16187 m
.54476 .19085 L
.54513 .19085 L
.54513 .16187 L
s
.678 .847 .902 r
.54513 .16187 m
.54513 .19143 L
.54572 .19143 L
.54572 .16187 L
F
.2 .63 .79 r
.54513 .16187 m
.54513 .19143 L
.54572 .19143 L
.54572 .16187 L
s
.678 .847 .902 r
.54572 .16187 m
.54572 .19152 L
.54599 .19152 L
.54599 .16187 L
F
.2 .63 .79 r
.54572 .16187 m
.54572 .19152 L
.54599 .19152 L
.54599 .16187 L
s
.678 .847 .902 r
.54599 .16187 m
.54599 .19194 L
.5466 .19194 L
.5466 .16187 L
F
.2 .63 .79 r
.54599 .16187 m
.54599 .19194 L
.5466 .19194 L
.5466 .16187 L
s
.678 .847 .902 r
.5466 .16187 m
.5466 .19219 L
.54715 .19219 L
.54715 .16187 L
F
.2 .63 .79 r
.5466 .16187 m
.5466 .19219 L
.54715 .19219 L
.54715 .16187 L
s
.678 .847 .902 r
.54715 .16187 m
.54715 .19259 L
.54768 .19259 L
.54768 .16187 L
F
.2 .63 .79 r
.54715 .16187 m
.54715 .19259 L
.54768 .19259 L
.54768 .16187 L
s
.678 .847 .902 r
.54768 .16187 m
.54768 .19298 L
.54801 .19298 L
.54801 .16187 L
F
.2 .63 .79 r
.54768 .16187 m
.54768 .19298 L
.54801 .19298 L
.54801 .16187 L
s
.678 .847 .902 r
.54801 .16187 m
.54801 .19316 L
.54823 .19316 L
.54823 .16187 L
F
.2 .63 .79 r
.54801 .16187 m
.54801 .19316 L
.54823 .19316 L
.54823 .16187 L
s
.678 .847 .902 r
.54823 .16187 m
.54823 .19327 L
.5488 .19327 L
.5488 .16187 L
F
.2 .63 .79 r
.54823 .16187 m
.54823 .19327 L
.5488 .19327 L
.5488 .16187 L
s
.678 .847 .902 r
.5488 .16187 m
.5488 .19363 L
.54904 .19363 L
.54904 .16187 L
F
.2 .63 .79 r
.5488 .16187 m
.5488 .19363 L
.54904 .19363 L
.54904 .16187 L
s
.678 .847 .902 r
.54904 .16187 m
.54904 .19377 L
.54937 .19377 L
.54937 .16187 L
F
.2 .63 .79 r
.54904 .16187 m
.54904 .19377 L
.54937 .19377 L
.54937 .16187 L
s
.678 .847 .902 r
.54937 .16187 m
.54937 .19402 L
.54989 .19402 L
.54989 .16187 L
F
.2 .63 .79 r
.54937 .16187 m
.54937 .19402 L
.54989 .19402 L
.54989 .16187 L
s
.678 .847 .902 r
.54989 .16187 m
.54989 .19454 L
.55031 .19454 L
.55031 .16187 L
F
.2 .63 .79 r
.54989 .16187 m
.54989 .19454 L
.55031 .19454 L
.55031 .16187 L
s
.678 .847 .902 r
.55031 .16187 m
.55031 .19489 L
.55092 .19489 L
.55092 .16187 L
F
.2 .63 .79 r
.55031 .16187 m
.55031 .19489 L
.55092 .19489 L
.55092 .16187 L
s
.678 .847 .902 r
.55092 .16187 m
.55092 .19508 L
.5514 .19508 L
.5514 .16187 L
F
.2 .63 .79 r
.55092 .16187 m
.55092 .19508 L
.5514 .19508 L
.5514 .16187 L
s
.678 .847 .902 r
.5514 .16187 m
.5514 .19554 L
.55188 .19554 L
.55188 .16187 L
F
.2 .63 .79 r
.5514 .16187 m
.5514 .19554 L
.55188 .19554 L
.55188 .16187 L
s
.678 .847 .902 r
.55188 .16187 m
.55188 .19587 L
.55242 .19587 L
.55242 .16187 L
F
.2 .63 .79 r
.55188 .16187 m
.55188 .19587 L
.55242 .19587 L
.55242 .16187 L
s
.678 .847 .902 r
.55242 .16187 m
.55242 .19623 L
.5527 .19623 L
.5527 .16187 L
F
.2 .63 .79 r
.55242 .16187 m
.55242 .19623 L
.5527 .19623 L
.5527 .16187 L
s
.678 .847 .902 r
.5527 .16187 m
.5527 .19631 L
.55301 .19631 L
.55301 .16187 L
F
.2 .63 .79 r
.5527 .16187 m
.5527 .19631 L
.55301 .19631 L
.55301 .16187 L
s
.678 .847 .902 r
.55301 .16187 m
.55301 .19681 L
.55364 .19681 L
.55364 .16187 L
F
.2 .63 .79 r
.55301 .16187 m
.55301 .19681 L
.55364 .19681 L
.55364 .16187 L
s
.678 .847 .902 r
.55364 .16187 m
.55364 .19725 L
.5542 .19725 L
.5542 .16187 L
F
.2 .63 .79 r
.55364 .16187 m
.55364 .19725 L
.5542 .19725 L
.5542 .16187 L
s
.678 .847 .902 r
.5542 .16187 m
.5542 .1974 L
.55467 .1974 L
.55467 .16187 L
F
.2 .63 .79 r
.5542 .16187 m
.5542 .1974 L
.55467 .1974 L
.55467 .16187 L
s
.678 .847 .902 r
.55467 .16187 m
.55467 .19761 L
.55495 .19761 L
.55495 .16187 L
F
.2 .63 .79 r
.55467 .16187 m
.55467 .19761 L
.55495 .19761 L
.55495 .16187 L
s
.678 .847 .902 r
.55495 .16187 m
.55495 .19779 L
.55533 .19779 L
.55533 .16187 L
F
.2 .63 .79 r
.55495 .16187 m
.55495 .19779 L
.55533 .19779 L
.55533 .16187 L
s
.678 .847 .902 r
.55533 .16187 m
.55533 .19827 L
.5557 .19827 L
.5557 .16187 L
F
.2 .63 .79 r
.55533 .16187 m
.55533 .19827 L
.5557 .19827 L
.5557 .16187 L
s
.678 .847 .902 r
.5557 .16187 m
.5557 .1985 L
.55622 .1985 L
.55622 .16187 L
F
.2 .63 .79 r
.5557 .16187 m
.5557 .1985 L
.55622 .1985 L
.55622 .16187 L
s
.678 .847 .902 r
.55622 .16187 m
.55622 .1988 L
.55644 .1988 L
.55644 .16187 L
F
.2 .63 .79 r
.55622 .16187 m
.55622 .1988 L
.55644 .1988 L
.55644 .16187 L
s
.678 .847 .902 r
.55644 .16187 m
.55644 .19891 L
.55684 .19891 L
.55684 .16187 L
F
.2 .63 .79 r
.55644 .16187 m
.55644 .19891 L
.55684 .19891 L
.55684 .16187 L
s
.678 .847 .902 r
.55684 .16187 m
.55684 .19927 L
.5573 .19927 L
.5573 .16187 L
F
.2 .63 .79 r
.55684 .16187 m
.55684 .19927 L
.5573 .19927 L
.5573 .16187 L
s
.678 .847 .902 r
.5573 .16187 m
.5573 .19947 L
.55792 .19947 L
.55792 .16187 L
F
.2 .63 .79 r
.5573 .16187 m
.5573 .19947 L
.55792 .19947 L
.55792 .16187 L
s
.678 .847 .902 r
.55792 .16187 m
.55792 .19989 L
.55844 .19989 L
.55844 .16187 L
F
.2 .63 .79 r
.55792 .16187 m
.55792 .19989 L
.55844 .19989 L
.55844 .16187 L
s
.678 .847 .902 r
.55844 .16187 m
.55844 .20035 L
.55882 .20035 L
.55882 .16187 L
F
.2 .63 .79 r
.55844 .16187 m
.55844 .20035 L
.55882 .20035 L
.55882 .16187 L
s
.678 .847 .902 r
.55882 .16187 m
.55882 .20059 L
.55935 .20059 L
.55935 .16187 L
F
.2 .63 .79 r
.55882 .16187 m
.55882 .20059 L
.55935 .20059 L
.55935 .16187 L
s
.678 .847 .902 r
.55935 .16187 m
.55935 .20115 L
.55992 .20115 L
.55992 .16187 L
F
.2 .63 .79 r
.55935 .16187 m
.55935 .20115 L
.55992 .20115 L
.55992 .16187 L
s
.678 .847 .902 r
.55992 .16187 m
.55992 .2015 L
.56031 .2015 L
.56031 .16187 L
F
.2 .63 .79 r
.55992 .16187 m
.55992 .2015 L
.56031 .2015 L
.56031 .16187 L
s
.678 .847 .902 r
.56031 .16187 m
.56031 .20162 L
.5608 .20162 L
.5608 .16187 L
F
.2 .63 .79 r
.56031 .16187 m
.56031 .20162 L
.5608 .20162 L
.5608 .16187 L
s
.678 .847 .902 r
.5608 .16187 m
.5608 .20196 L
.5611 .20196 L
.5611 .16187 L
F
.2 .63 .79 r
.5608 .16187 m
.5608 .20196 L
.5611 .20196 L
.5611 .16187 L
s
.678 .847 .902 r
.5611 .16187 m
.5611 .2021 L
.5617 .2021 L
.5617 .16187 L
F
.2 .63 .79 r
.5611 .16187 m
.5611 .2021 L
.5617 .2021 L
.5617 .16187 L
s
.678 .847 .902 r
.5617 .16187 m
.5617 .20277 L
.56225 .20277 L
.56225 .16187 L
F
.2 .63 .79 r
.5617 .16187 m
.5617 .20277 L
.56225 .20277 L
.56225 .16187 L
s
.678 .847 .902 r
.56225 .16187 m
.56225 .20296 L
.56246 .20296 L
.56246 .16187 L
F
.2 .63 .79 r
.56225 .16187 m
.56225 .20296 L
.56246 .20296 L
.56246 .16187 L
s
.678 .847 .902 r
.56246 .16187 m
.56246 .203 L
.56285 .203 L
.56285 .16187 L
F
.2 .63 .79 r
.56246 .16187 m
.56246 .203 L
.56285 .203 L
.56285 .16187 L
s
.678 .847 .902 r
.56285 .16187 m
.56285 .20333 L
.56336 .20333 L
.56336 .16187 L
F
.2 .63 .79 r
.56285 .16187 m
.56285 .20333 L
.56336 .20333 L
.56336 .16187 L
s
.678 .847 .902 r
.56336 .16187 m
.56336 .20377 L
.56379 .20377 L
.56379 .16187 L
F
.2 .63 .79 r
.56336 .16187 m
.56336 .20377 L
.56379 .20377 L
.56379 .16187 L
s
.678 .847 .902 r
.56379 .16187 m
.56379 .20407 L
.564 .20407 L
.564 .16187 L
F
.2 .63 .79 r
.56379 .16187 m
.56379 .20407 L
.564 .20407 L
.564 .16187 L
s
.678 .847 .902 r
.564 .16187 m
.564 .2041 L
.56448 .2041 L
.56448 .16187 L
F
.2 .63 .79 r
.564 .16187 m
.564 .2041 L
.56448 .2041 L
.56448 .16187 L
s
.678 .847 .902 r
.56448 .16187 m
.56448 .20454 L
.56472 .20454 L
.56472 .16187 L
F
.2 .63 .79 r
.56448 .16187 m
.56448 .20454 L
.56472 .20454 L
.56472 .16187 L
s
.678 .847 .902 r
.56472 .16187 m
.56472 .20466 L
.56505 .20466 L
.56505 .16187 L
F
.2 .63 .79 r
.56472 .16187 m
.56472 .20466 L
.56505 .20466 L
.56505 .16187 L
s
.678 .847 .902 r
.56505 .16187 m
.56505 .20511 L
.56552 .20511 L
.56552 .16187 L
F
.2 .63 .79 r
.56505 .16187 m
.56505 .20511 L
.56552 .20511 L
.56552 .16187 L
s
.678 .847 .902 r
.56552 .16187 m
.56552 .20518 L
.56581 .20518 L
.56581 .16187 L
F
.2 .63 .79 r
.56552 .16187 m
.56552 .20518 L
.56581 .20518 L
.56581 .16187 L
s
.678 .847 .902 r
.56581 .16187 m
.56581 .2054 L
.56617 .2054 L
.56617 .16187 L
F
.2 .63 .79 r
.56581 .16187 m
.56581 .2054 L
.56617 .2054 L
.56617 .16187 L
s
.678 .847 .902 r
.56617 .16187 m
.56617 .2057 L
.56648 .2057 L
.56648 .16187 L
F
.2 .63 .79 r
.56617 .16187 m
.56617 .2057 L
.56648 .2057 L
.56648 .16187 L
s
.678 .847 .902 r
.56648 .16187 m
.56648 .20592 L
.56674 .20592 L
.56674 .16187 L
F
.2 .63 .79 r
.56648 .16187 m
.56648 .20592 L
.56674 .20592 L
.56674 .16187 L
s
.678 .847 .902 r
.56674 .16187 m
.56674 .20621 L
.56721 .20621 L
.56721 .16187 L
F
.2 .63 .79 r
.56674 .16187 m
.56674 .20621 L
.56721 .20621 L
.56721 .16187 L
s
.678 .847 .902 r
.56721 .16187 m
.56721 .20635 L
.56759 .20635 L
.56759 .16187 L
F
.2 .63 .79 r
.56721 .16187 m
.56721 .20635 L
.56759 .20635 L
.56759 .16187 L
s
.678 .847 .902 r
.56759 .16187 m
.56759 .20669 L
.56801 .20669 L
.56801 .16187 L
F
.2 .63 .79 r
.56759 .16187 m
.56759 .20669 L
.56801 .20669 L
.56801 .16187 L
s
.678 .847 .902 r
.56801 .16187 m
.56801 .20727 L
.56853 .20727 L
.56853 .16187 L
F
.2 .63 .79 r
.56801 .16187 m
.56801 .20727 L
.56853 .20727 L
.56853 .16187 L
s
.678 .847 .902 r
.56853 .16187 m
.56853 .20739 L
.56912 .20739 L
.56912 .16187 L
F
.2 .63 .79 r
.56853 .16187 m
.56853 .20739 L
.56912 .20739 L
.56912 .16187 L
s
.678 .847 .902 r
.56912 .16187 m
.56912 .20775 L
.56955 .20775 L
.56955 .16187 L
F
.2 .63 .79 r
.56912 .16187 m
.56912 .20775 L
.56955 .20775 L
.56955 .16187 L
s
.678 .847 .902 r
.56955 .16187 m
.56955 .20804 L
.56978 .20804 L
.56978 .16187 L
F
.2 .63 .79 r
.56955 .16187 m
.56955 .20804 L
.56978 .20804 L
.56978 .16187 L
s
.678 .847 .902 r
.56978 .16187 m
.56978 .20825 L
.57 .20825 L
.57 .16187 L
F
.2 .63 .79 r
.56978 .16187 m
.56978 .20825 L
.57 .20825 L
.57 .16187 L
s
.678 .847 .902 r
.57 .16187 m
.57 .20856 L
.57048 .20856 L
.57048 .16187 L
F
.2 .63 .79 r
.57 .16187 m
.57 .20856 L
.57048 .20856 L
.57048 .16187 L
s
.678 .847 .902 r
.57048 .16187 m
.57048 .20868 L
.57095 .20868 L
.57095 .16187 L
F
.2 .63 .79 r
.57048 .16187 m
.57048 .20868 L
.57095 .20868 L
.57095 .16187 L
s
.678 .847 .902 r
.57095 .16187 m
.57095 .2091 L
.57127 .2091 L
.57127 .16187 L
F
.2 .63 .79 r
.57095 .16187 m
.57095 .2091 L
.57127 .2091 L
.57127 .16187 L
s
.678 .847 .902 r
.57127 .16187 m
.57127 .20933 L
.57147 .20933 L
.57147 .16187 L
F
.2 .63 .79 r
.57127 .16187 m
.57127 .20933 L
.57147 .20933 L
.57147 .16187 L
s
.678 .847 .902 r
.57147 .16187 m
.57147 .2095 L
.57175 .2095 L
.57175 .16187 L
F
.2 .63 .79 r
.57147 .16187 m
.57147 .2095 L
.57175 .2095 L
.57175 .16187 L
s
.678 .847 .902 r
.57175 .16187 m
.57175 .20995 L
.57235 .20995 L
.57235 .16187 L
F
.2 .63 .79 r
.57175 .16187 m
.57175 .20995 L
.57235 .20995 L
.57235 .16187 L
s
.678 .847 .902 r
.57235 .16187 m
.57235 .21 L
.57288 .21 L
.57288 .16187 L
F
.2 .63 .79 r
.57235 .16187 m
.57235 .21 L
.57288 .21 L
.57288 .16187 L
s
.678 .847 .902 r
.57288 .16187 m
.57288 .21077 L
.5735 .21077 L
.5735 .16187 L
F
.2 .63 .79 r
.57288 .16187 m
.57288 .21077 L
.5735 .21077 L
.5735 .16187 L
s
.678 .847 .902 r
.5735 .16187 m
.5735 .21101 L
.57395 .21101 L
.57395 .16187 L
F
.2 .63 .79 r
.5735 .16187 m
.5735 .21101 L
.57395 .21101 L
.57395 .16187 L
s
.678 .847 .902 r
.57395 .16187 m
.57395 .21119 L
.57449 .21119 L
.57449 .16187 L
F
.2 .63 .79 r
.57395 .16187 m
.57395 .21119 L
.57449 .21119 L
.57449 .16187 L
s
.678 .847 .902 r
.57449 .16187 m
.57449 .21171 L
.57488 .21171 L
.57488 .16187 L
F
.2 .63 .79 r
.57449 .16187 m
.57449 .21171 L
.57488 .21171 L
.57488 .16187 L
s
.678 .847 .902 r
.57488 .16187 m
.57488 .21179 L
.57523 .21179 L
.57523 .16187 L
F
.2 .63 .79 r
.57488 .16187 m
.57488 .21179 L
.57523 .21179 L
.57523 .16187 L
s
.678 .847 .902 r
.57523 .16187 m
.57523 .21215 L
.57557 .21215 L
.57557 .16187 L
F
.2 .63 .79 r
.57523 .16187 m
.57523 .21215 L
.57557 .21215 L
.57557 .16187 L
s
.678 .847 .902 r
.57557 .16187 m
.57557 .21228 L
.57595 .21228 L
.57595 .16187 L
F
.2 .63 .79 r
.57557 .16187 m
.57557 .21228 L
.57595 .21228 L
.57595 .16187 L
s
.678 .847 .902 r
.57595 .16187 m
.57595 .21261 L
.57622 .21261 L
.57622 .16187 L
F
.2 .63 .79 r
.57595 .16187 m
.57595 .21261 L
.57622 .21261 L
.57622 .16187 L
s
.678 .847 .902 r
.57622 .16187 m
.57622 .21284 L
.5765 .21284 L
.5765 .16187 L
F
.2 .63 .79 r
.57622 .16187 m
.57622 .21284 L
.5765 .21284 L
.5765 .16187 L
s
.678 .847 .902 r
.5765 .16187 m
.5765 .21325 L
.57701 .21325 L
.57701 .16187 L
F
.2 .63 .79 r
.5765 .16187 m
.5765 .21325 L
.57701 .21325 L
.57701 .16187 L
s
.678 .847 .902 r
.57701 .16187 m
.57701 .21344 L
.57721 .21344 L
.57721 .16187 L
F
.2 .63 .79 r
.57701 .16187 m
.57701 .21344 L
.57721 .21344 L
.57721 .16187 L
s
.678 .847 .902 r
.57721 .16187 m
.57721 .2138 L
.57769 .2138 L
.57769 .16187 L
F
.2 .63 .79 r
.57721 .16187 m
.57721 .2138 L
.57769 .2138 L
.57769 .16187 L
s
.678 .847 .902 r
.57769 .16187 m
.57769 .21393 L
.57809 .21393 L
.57809 .16187 L
F
.2 .63 .79 r
.57769 .16187 m
.57769 .21393 L
.57809 .21393 L
.57809 .16187 L
s
.678 .847 .902 r
.57809 .16187 m
.57809 .21431 L
.57865 .21431 L
.57865 .16187 L
F
.2 .63 .79 r
.57809 .16187 m
.57809 .21431 L
.57865 .21431 L
.57865 .16187 L
s
.678 .847 .902 r
.57865 .16187 m
.57865 .21469 L
.57905 .21469 L
.57905 .16187 L
F
.2 .63 .79 r
.57865 .16187 m
.57865 .21469 L
.57905 .21469 L
.57905 .16187 L
s
.678 .847 .902 r
.57905 .16187 m
.57905 .21499 L
.57949 .21499 L
.57949 .16187 L
F
.2 .63 .79 r
.57905 .16187 m
.57905 .21499 L
.57949 .21499 L
.57949 .16187 L
s
.678 .847 .902 r
.57949 .16187 m
.57949 .21532 L
.57986 .21532 L
.57986 .16187 L
F
.2 .63 .79 r
.57949 .16187 m
.57949 .21532 L
.57986 .21532 L
.57986 .16187 L
s
.678 .847 .902 r
.57986 .16187 m
.57986 .21552 L
.58014 .21552 L
.58014 .16187 L
F
.2 .63 .79 r
.57986 .16187 m
.57986 .21552 L
.58014 .21552 L
.58014 .16187 L
s
.678 .847 .902 r
.58014 .16187 m
.58014 .21581 L
.5807 .21581 L
.5807 .16187 L
F
.2 .63 .79 r
.58014 .16187 m
.58014 .21581 L
.5807 .21581 L
.5807 .16187 L
s
.678 .847 .902 r
.5807 .16187 m
.5807 .21601 L
.58102 .21601 L
.58102 .16187 L
F
.2 .63 .79 r
.5807 .16187 m
.5807 .21601 L
.58102 .21601 L
.58102 .16187 L
s
.678 .847 .902 r
.58102 .16187 m
.58102 .21645 L
.58138 .21645 L
.58138 .16187 L
F
.2 .63 .79 r
.58102 .16187 m
.58102 .21645 L
.58138 .21645 L
.58138 .16187 L
s
.678 .847 .902 r
.58138 .16187 m
.58138 .21649 L
.58201 .21649 L
.58201 .16187 L
F
.2 .63 .79 r
.58138 .16187 m
.58138 .21649 L
.58201 .21649 L
.58201 .16187 L
s
.678 .847 .902 r
.58201 .16187 m
.58201 .21721 L
.58262 .21721 L
.58262 .16187 L
F
.2 .63 .79 r
.58201 .16187 m
.58201 .21721 L
.58262 .21721 L
.58262 .16187 L
s
.678 .847 .902 r
.58262 .16187 m
.58262 .21739 L
.58304 .21739 L
.58304 .16187 L
F
.2 .63 .79 r
.58262 .16187 m
.58262 .21739 L
.58304 .21739 L
.58304 .16187 L
s
.678 .847 .902 r
.58304 .16187 m
.58304 .21767 L
.58343 .21767 L
.58343 .16187 L
F
.2 .63 .79 r
.58304 .16187 m
.58304 .21767 L
.58343 .21767 L
.58343 .16187 L
s
.678 .847 .902 r
.58343 .16187 m
.58343 .21805 L
.5838 .21805 L
.5838 .16187 L
F
.2 .63 .79 r
.58343 .16187 m
.58343 .21805 L
.5838 .21805 L
.5838 .16187 L
s
.678 .847 .902 r
.5838 .16187 m
.5838 .2183 L
.58405 .2183 L
.58405 .16187 L
F
.2 .63 .79 r
.5838 .16187 m
.5838 .2183 L
.58405 .2183 L
.58405 .16187 L
s
.678 .847 .902 r
.58405 .16187 m
.58405 .21846 L
.58428 .21846 L
.58428 .16187 L
F
.2 .63 .79 r
.58405 .16187 m
.58405 .21846 L
.58428 .21846 L
.58428 .16187 L
s
.678 .847 .902 r
.58428 .16187 m
.58428 .21856 L
.5845 .21856 L
.5845 .16187 L
F
.2 .63 .79 r
.58428 .16187 m
.58428 .21856 L
.5845 .21856 L
.5845 .16187 L
s
.678 .847 .902 r
.5845 .16187 m
.5845 .21887 L
.58472 .21887 L
.58472 .16187 L
F
.2 .63 .79 r
.5845 .16187 m
.5845 .21887 L
.58472 .21887 L
.58472 .16187 L
s
.678 .847 .902 r
.58472 .16187 m
.58472 .21906 L
.58523 .21906 L
.58523 .16187 L
F
.2 .63 .79 r
.58472 .16187 m
.58472 .21906 L
.58523 .21906 L
.58523 .16187 L
s
.678 .847 .902 r
.58523 .16187 m
.58523 .21929 L
.58583 .21929 L
.58583 .16187 L
F
.2 .63 .79 r
.58523 .16187 m
.58523 .21929 L
.58583 .21929 L
.58583 .16187 L
s
.678 .847 .902 r
.58583 .16187 m
.58583 .21992 L
.58642 .21992 L
.58642 .16187 L
F
.2 .63 .79 r
.58583 .16187 m
.58583 .21992 L
.58642 .21992 L
.58642 .16187 L
s
.678 .847 .902 r
.58642 .16187 m
.58642 .22013 L
.58677 .22013 L
.58677 .16187 L
F
.2 .63 .79 r
.58642 .16187 m
.58642 .22013 L
.58677 .22013 L
.58677 .16187 L
s
.678 .847 .902 r
.58677 .16187 m
.58677 .22056 L
.58726 .22056 L
.58726 .16187 L
F
.2 .63 .79 r
.58677 .16187 m
.58677 .22056 L
.58726 .22056 L
.58726 .16187 L
s
.678 .847 .902 r
.58726 .16187 m
.58726 .22076 L
.58757 .22076 L
.58757 .16187 L
F
.2 .63 .79 r
.58726 .16187 m
.58726 .22076 L
.58757 .22076 L
.58757 .16187 L
s
.678 .847 .902 r
.58757 .16187 m
.58757 .22098 L
.58795 .22098 L
.58795 .16187 L
F
.2 .63 .79 r
.58757 .16187 m
.58757 .22098 L
.58795 .22098 L
.58795 .16187 L
s
.678 .847 .902 r
.58795 .16187 m
.58795 .2214 L
.58838 .2214 L
.58838 .16187 L
F
.2 .63 .79 r
.58795 .16187 m
.58795 .2214 L
.58838 .2214 L
.58838 .16187 L
s
.678 .847 .902 r
.58838 .16187 m
.58838 .22173 L
.58867 .22173 L
.58867 .16187 L
F
.2 .63 .79 r
.58838 .16187 m
.58838 .22173 L
.58867 .22173 L
.58867 .16187 L
s
.678 .847 .902 r
.58867 .16187 m
.58867 .22192 L
.58917 .22192 L
.58917 .16187 L
F
.2 .63 .79 r
.58867 .16187 m
.58867 .22192 L
.58917 .22192 L
.58917 .16187 L
s
.678 .847 .902 r
.58917 .16187 m
.58917 .22217 L
.58937 .22217 L
.58937 .16187 L
F
.2 .63 .79 r
.58917 .16187 m
.58917 .22217 L
.58937 .22217 L
.58937 .16187 L
s
.678 .847 .902 r
.58937 .16187 m
.58937 .22246 L
.58972 .22246 L
.58972 .16187 L
F
.2 .63 .79 r
.58937 .16187 m
.58937 .22246 L
.58972 .22246 L
.58972 .16187 L
s
.678 .847 .902 r
.58972 .16187 m
.58972 .22259 L
.59008 .22259 L
.59008 .16187 L
F
.2 .63 .79 r
.58972 .16187 m
.58972 .22259 L
.59008 .22259 L
.59008 .16187 L
s
.678 .847 .902 r
.59008 .16187 m
.59008 .22287 L
.59046 .22287 L
.59046 .16187 L
F
.2 .63 .79 r
.59008 .16187 m
.59008 .22287 L
.59046 .22287 L
.59046 .16187 L
s
.678 .847 .902 r
.59046 .16187 m
.59046 .22317 L
.59093 .22317 L
.59093 .16187 L
F
.2 .63 .79 r
.59046 .16187 m
.59046 .22317 L
.59093 .22317 L
.59093 .16187 L
s
.678 .847 .902 r
.59093 .16187 m
.59093 .22359 L
.59129 .22359 L
.59129 .16187 L
F
.2 .63 .79 r
.59093 .16187 m
.59093 .22359 L
.59129 .22359 L
.59129 .16187 L
s
.678 .847 .902 r
.59129 .16187 m
.59129 .22384 L
.59168 .22384 L
.59168 .16187 L
F
.2 .63 .79 r
.59129 .16187 m
.59129 .22384 L
.59168 .22384 L
.59168 .16187 L
s
.678 .847 .902 r
.59168 .16187 m
.59168 .22404 L
.59227 .22404 L
.59227 .16187 L
F
.2 .63 .79 r
.59168 .16187 m
.59168 .22404 L
.59227 .22404 L
.59227 .16187 L
s
.678 .847 .902 r
.59227 .16187 m
.59227 .22446 L
.59255 .22446 L
.59255 .16187 L
F
.2 .63 .79 r
.59227 .16187 m
.59227 .22446 L
.59255 .22446 L
.59255 .16187 L
s
.678 .847 .902 r
.59255 .16187 m
.59255 .22473 L
.59318 .22473 L
.59318 .16187 L
F
.2 .63 .79 r
.59255 .16187 m
.59255 .22473 L
.59318 .22473 L
.59318 .16187 L
s
.678 .847 .902 r
.59318 .16187 m
.59318 .22509 L
.59351 .22509 L
.59351 .16187 L
F
.2 .63 .79 r
.59318 .16187 m
.59318 .22509 L
.59351 .22509 L
.59351 .16187 L
s
.678 .847 .902 r
.59351 .16187 m
.59351 .22564 L
.59406 .22564 L
.59406 .16187 L
F
.2 .63 .79 r
.59351 .16187 m
.59351 .22564 L
.59406 .22564 L
.59406 .16187 L
s
.678 .847 .902 r
.59406 .16187 m
.59406 .22577 L
.5943 .22577 L
.5943 .16187 L
F
.2 .63 .79 r
.59406 .16187 m
.59406 .22577 L
.5943 .22577 L
.5943 .16187 L
s
.678 .847 .902 r
.5943 .16187 m
.5943 .22606 L
.5949 .22606 L
.5949 .16187 L
F
.2 .63 .79 r
.5943 .16187 m
.5943 .22606 L
.5949 .22606 L
.5949 .16187 L
s
.678 .847 .902 r
.5949 .16187 m
.5949 .22655 L
.59537 .22655 L
.59537 .16187 L
F
.2 .63 .79 r
.5949 .16187 m
.5949 .22655 L
.59537 .22655 L
.59537 .16187 L
s
.678 .847 .902 r
.59537 .16187 m
.59537 .227 L
.59596 .227 L
.59596 .16187 L
F
.2 .63 .79 r
.59537 .16187 m
.59537 .227 L
.59596 .227 L
.59596 .16187 L
s
.678 .847 .902 r
.59596 .16187 m
.59596 .22729 L
.59625 .22729 L
.59625 .16187 L
F
.2 .63 .79 r
.59596 .16187 m
.59596 .22729 L
.59625 .22729 L
.59625 .16187 L
s
.678 .847 .902 r
.59625 .16187 m
.59625 .22745 L
.59669 .22745 L
.59669 .16187 L
F
.2 .63 .79 r
.59625 .16187 m
.59625 .22745 L
.59669 .22745 L
.59669 .16187 L
s
.678 .847 .902 r
.59669 .16187 m
.59669 .22771 L
.5973 .22771 L
.5973 .16187 L
F
.2 .63 .79 r
.59669 .16187 m
.59669 .22771 L
.5973 .22771 L
.5973 .16187 L
s
.678 .847 .902 r
.5973 .16187 m
.5973 .22835 L
.59777 .22835 L
.59777 .16187 L
F
.2 .63 .79 r
.5973 .16187 m
.5973 .22835 L
.59777 .22835 L
.59777 .16187 L
s
.678 .847 .902 r
.59777 .16187 m
.59777 .22874 L
.59832 .22874 L
.59832 .16187 L
F
.2 .63 .79 r
.59777 .16187 m
.59777 .22874 L
.59832 .22874 L
.59832 .16187 L
s
.678 .847 .902 r
.59832 .16187 m
.59832 .22902 L
.59852 .22902 L
.59852 .16187 L
F
.2 .63 .79 r
.59832 .16187 m
.59832 .22902 L
.59852 .22902 L
.59852 .16187 L
s
.678 .847 .902 r
.59852 .16187 m
.59852 .22914 L
.59903 .22914 L
.59903 .16187 L
F
.2 .63 .79 r
.59852 .16187 m
.59852 .22914 L
.59903 .22914 L
.59903 .16187 L
s
.678 .847 .902 r
.59903 .16187 m
.59903 .22952 L
.59965 .22952 L
.59965 .16187 L
F
.2 .63 .79 r
.59903 .16187 m
.59903 .22952 L
.59965 .22952 L
.59965 .16187 L
s
.678 .847 .902 r
.59965 .16187 m
.59965 .23005 L
.60018 .23005 L
.60018 .16187 L
F
.2 .63 .79 r
.59965 .16187 m
.59965 .23005 L
.60018 .23005 L
.60018 .16187 L
s
.678 .847 .902 r
.60018 .16187 m
.60018 .23032 L
.60067 .23032 L
.60067 .16187 L
F
.2 .63 .79 r
.60018 .16187 m
.60018 .23032 L
.60067 .23032 L
.60067 .16187 L
s
.678 .847 .902 r
.60067 .16187 m
.60067 .23068 L
.60101 .23068 L
.60101 .16187 L
F
.2 .63 .79 r
.60067 .16187 m
.60067 .23068 L
.60101 .23068 L
.60101 .16187 L
s
.678 .847 .902 r
.60101 .16187 m
.60101 .23122 L
.60144 .23122 L
.60144 .16187 L
F
.2 .63 .79 r
.60101 .16187 m
.60101 .23122 L
.60144 .23122 L
.60144 .16187 L
s
.678 .847 .902 r
.60144 .16187 m
.60144 .23127 L
.6017 .23127 L
.6017 .16187 L
F
.2 .63 .79 r
.60144 .16187 m
.60144 .23127 L
.6017 .23127 L
.6017 .16187 L
s
.678 .847 .902 r
.6017 .16187 m
.6017 .23154 L
.60202 .23154 L
.60202 .16187 L
F
.2 .63 .79 r
.6017 .16187 m
.6017 .23154 L
.60202 .23154 L
.60202 .16187 L
s
.678 .847 .902 r
.60202 .16187 m
.60202 .23192 L
.60261 .23192 L
.60261 .16187 L
F
.2 .63 .79 r
.60202 .16187 m
.60202 .23192 L
.60261 .23192 L
.60261 .16187 L
s
.678 .847 .902 r
.60261 .16187 m
.60261 .23241 L
.60309 .23241 L
.60309 .16187 L
F
.2 .63 .79 r
.60261 .16187 m
.60261 .23241 L
.60309 .23241 L
.60309 .16187 L
s
.678 .847 .902 r
.60309 .16187 m
.60309 .23291 L
.60371 .23291 L
.60371 .16187 L
F
.2 .63 .79 r
.60309 .16187 m
.60309 .23291 L
.60371 .23291 L
.60371 .16187 L
s
.678 .847 .902 r
.60371 .16187 m
.60371 .23299 L
.60404 .23299 L
.60404 .16187 L
F
.2 .63 .79 r
.60371 .16187 m
.60371 .23299 L
.60404 .23299 L
.60404 .16187 L
s
.678 .847 .902 r
.60404 .16187 m
.60404 .23336 L
.60448 .23336 L
.60448 .16187 L
F
.2 .63 .79 r
.60404 .16187 m
.60404 .23336 L
.60448 .23336 L
.60448 .16187 L
s
.678 .847 .902 r
.60448 .16187 m
.60448 .23355 L
.60505 .23355 L
.60505 .16187 L
F
.2 .63 .79 r
.60448 .16187 m
.60448 .23355 L
.60505 .23355 L
.60505 .16187 L
s
.678 .847 .902 r
.60505 .16187 m
.60505 .23427 L
.60562 .23427 L
.60562 .16187 L
F
.2 .63 .79 r
.60505 .16187 m
.60505 .23427 L
.60562 .23427 L
.60562 .16187 L
s
.678 .847 .902 r
.60562 .16187 m
.60562 .23463 L
.60598 .23463 L
.60598 .16187 L
F
.2 .63 .79 r
.60562 .16187 m
.60562 .23463 L
.60598 .23463 L
.60598 .16187 L
s
.678 .847 .902 r
.60598 .16187 m
.60598 .23511 L
.6066 .23511 L
.6066 .16187 L
F
.2 .63 .79 r
.60598 .16187 m
.60598 .23511 L
.6066 .23511 L
.6066 .16187 L
s
.678 .847 .902 r
.6066 .16187 m
.6066 .2353 L
.60722 .2353 L
.60722 .16187 L
F
.2 .63 .79 r
.6066 .16187 m
.6066 .2353 L
.60722 .2353 L
.60722 .16187 L
s
.678 .847 .902 r
.60722 .16187 m
.60722 .23562 L
.60768 .23562 L
.60768 .16187 L
F
.2 .63 .79 r
.60722 .16187 m
.60722 .23562 L
.60768 .23562 L
.60768 .16187 L
s
.678 .847 .902 r
.60768 .16187 m
.60768 .23621 L
.60825 .23621 L
.60825 .16187 L
F
.2 .63 .79 r
.60768 .16187 m
.60768 .23621 L
.60825 .23621 L
.60825 .16187 L
s
.678 .847 .902 r
.60825 .16187 m
.60825 .23651 L
.60845 .23651 L
.60845 .16187 L
F
.2 .63 .79 r
.60825 .16187 m
.60825 .23651 L
.60845 .23651 L
.60845 .16187 L
s
.678 .847 .902 r
.60845 .16187 m
.60845 .23672 L
.60878 .23672 L
.60878 .16187 L
F
.2 .63 .79 r
.60845 .16187 m
.60845 .23672 L
.60878 .23672 L
.60878 .16187 L
s
.678 .847 .902 r
.60878 .16187 m
.60878 .23697 L
.60934 .23697 L
.60934 .16187 L
F
.2 .63 .79 r
.60878 .16187 m
.60878 .23697 L
.60934 .23697 L
.60934 .16187 L
s
.678 .847 .902 r
.60934 .16187 m
.60934 .23756 L
.60989 .23756 L
.60989 .16187 L
F
.2 .63 .79 r
.60934 .16187 m
.60934 .23756 L
.60989 .23756 L
.60989 .16187 L
s
.678 .847 .902 r
.60989 .16187 m
.60989 .2378 L
.61022 .2378 L
.61022 .16187 L
F
.2 .63 .79 r
.60989 .16187 m
.60989 .2378 L
.61022 .2378 L
.61022 .16187 L
s
.678 .847 .902 r
.61022 .16187 m
.61022 .23804 L
.61058 .23804 L
.61058 .16187 L
F
.2 .63 .79 r
.61022 .16187 m
.61022 .23804 L
.61058 .23804 L
.61058 .16187 L
s
.678 .847 .902 r
.61058 .16187 m
.61058 .23815 L
.61079 .23815 L
.61079 .16187 L
F
.2 .63 .79 r
.61058 .16187 m
.61058 .23815 L
.61079 .23815 L
.61079 .16187 L
s
.678 .847 .902 r
.61079 .16187 m
.61079 .23846 L
.61105 .23846 L
.61105 .16187 L
F
.2 .63 .79 r
.61079 .16187 m
.61079 .23846 L
.61105 .23846 L
.61105 .16187 L
s
.678 .847 .902 r
.61105 .16187 m
.61105 .23881 L
.61167 .23881 L
.61167 .16187 L
F
.2 .63 .79 r
.61105 .16187 m
.61105 .23881 L
.61167 .23881 L
.61167 .16187 L
s
.678 .847 .902 r
.61167 .16187 m
.61167 .23926 L
.61223 .23926 L
.61223 .16187 L
F
.2 .63 .79 r
.61167 .16187 m
.61167 .23926 L
.61223 .23926 L
.61223 .16187 L
s
.678 .847 .902 r
.61223 .16187 m
.61223 .23982 L
.61283 .23982 L
.61283 .16187 L
F
.2 .63 .79 r
.61223 .16187 m
.61223 .23982 L
.61283 .23982 L
.61283 .16187 L
s
.678 .847 .902 r
.61283 .16187 m
.61283 .24001 L
.6134 .24001 L
.6134 .16187 L
F
.2 .63 .79 r
.61283 .16187 m
.61283 .24001 L
.6134 .24001 L
.6134 .16187 L
s
.678 .847 .902 r
.6134 .16187 m
.6134 .24031 L
.61363 .24031 L
.61363 .16187 L
F
.2 .63 .79 r
.6134 .16187 m
.6134 .24031 L
.61363 .24031 L
.61363 .16187 L
s
.678 .847 .902 r
.61363 .16187 m
.61363 .24065 L
.6139 .24065 L
.6139 .16187 L
F
.2 .63 .79 r
.61363 .16187 m
.61363 .24065 L
.6139 .24065 L
.6139 .16187 L
s
.678 .847 .902 r
.6139 .16187 m
.6139 .24115 L
.61452 .24115 L
.61452 .16187 L
F
.2 .63 .79 r
.6139 .16187 m
.6139 .24115 L
.61452 .24115 L
.61452 .16187 L
s
.678 .847 .902 r
.61452 .16187 m
.61452 .24119 L
.61495 .24119 L
.61495 .16187 L
F
.2 .63 .79 r
.61452 .16187 m
.61452 .24119 L
.61495 .24119 L
.61495 .16187 L
s
.678 .847 .902 r
.61495 .16187 m
.61495 .24167 L
.61538 .24167 L
.61538 .16187 L
F
.2 .63 .79 r
.61495 .16187 m
.61495 .24167 L
.61538 .24167 L
.61538 .16187 L
s
.678 .847 .902 r
.61538 .16187 m
.61538 .24202 L
.61571 .24202 L
.61571 .16187 L
F
.2 .63 .79 r
.61538 .16187 m
.61538 .24202 L
.61571 .24202 L
.61571 .16187 L
s
.678 .847 .902 r
.61571 .16187 m
.61571 .24212 L
.61596 .24212 L
.61596 .16187 L
F
.2 .63 .79 r
.61571 .16187 m
.61571 .24212 L
.61596 .24212 L
.61596 .16187 L
s
.678 .847 .902 r
.61596 .16187 m
.61596 .2423 L
.61622 .2423 L
.61622 .16187 L
F
.2 .63 .79 r
.61596 .16187 m
.61596 .2423 L
.61622 .2423 L
.61622 .16187 L
s
.678 .847 .902 r
.61622 .16187 m
.61622 .24266 L
.61666 .24266 L
.61666 .16187 L
F
.2 .63 .79 r
.61622 .16187 m
.61622 .24266 L
.61666 .24266 L
.61666 .16187 L
s
.678 .847 .902 r
.61666 .16187 m
.61666 .24291 L
.61702 .24291 L
.61702 .16187 L
F
.2 .63 .79 r
.61666 .16187 m
.61666 .24291 L
.61702 .24291 L
.61702 .16187 L
s
.678 .847 .902 r
.61702 .16187 m
.61702 .24313 L
.61744 .24313 L
.61744 .16187 L
F
.2 .63 .79 r
.61702 .16187 m
.61702 .24313 L
.61744 .24313 L
.61744 .16187 L
s
.678 .847 .902 r
.61744 .16187 m
.61744 .24355 L
.61777 .24355 L
.61777 .16187 L
F
.2 .63 .79 r
.61744 .16187 m
.61744 .24355 L
.61777 .24355 L
.61777 .16187 L
s
.678 .847 .902 r
.61777 .16187 m
.61777 .24387 L
.6182 .24387 L
.6182 .16187 L
F
.2 .63 .79 r
.61777 .16187 m
.61777 .24387 L
.6182 .24387 L
.6182 .16187 L
s
.678 .847 .902 r
.6182 .16187 m
.6182 .24409 L
.61842 .24409 L
.61842 .16187 L
F
.2 .63 .79 r
.6182 .16187 m
.6182 .24409 L
.61842 .24409 L
.61842 .16187 L
s
.678 .847 .902 r
.61842 .16187 m
.61842 .24443 L
.61892 .24443 L
.61892 .16187 L
F
.2 .63 .79 r
.61842 .16187 m
.61842 .24443 L
.61892 .24443 L
.61892 .16187 L
s
.678 .847 .902 r
.61892 .16187 m
.61892 .24478 L
.61934 .24478 L
.61934 .16187 L
F
.2 .63 .79 r
.61892 .16187 m
.61892 .24478 L
.61934 .24478 L
.61934 .16187 L
s
.678 .847 .902 r
.61934 .16187 m
.61934 .24508 L
.61963 .24508 L
.61963 .16187 L
F
.2 .63 .79 r
.61934 .16187 m
.61934 .24508 L
.61963 .24508 L
.61963 .16187 L
s
.678 .847 .902 r
.61963 .16187 m
.61963 .24547 L
.62014 .24547 L
.62014 .16187 L
F
.2 .63 .79 r
.61963 .16187 m
.61963 .24547 L
.62014 .24547 L
.62014 .16187 L
s
.678 .847 .902 r
.62014 .16187 m
.62014 .24571 L
.62061 .24571 L
.62061 .16187 L
F
.2 .63 .79 r
.62014 .16187 m
.62014 .24571 L
.62061 .24571 L
.62061 .16187 L
s
.678 .847 .902 r
.62061 .16187 m
.62061 .24611 L
.62096 .24611 L
.62096 .16187 L
F
.2 .63 .79 r
.62061 .16187 m
.62061 .24611 L
.62096 .24611 L
.62096 .16187 L
s
.678 .847 .902 r
.62096 .16187 m
.62096 .24619 L
.62127 .24619 L
.62127 .16187 L
F
.2 .63 .79 r
.62096 .16187 m
.62096 .24619 L
.62127 .24619 L
.62127 .16187 L
s
.678 .847 .902 r
.62127 .16187 m
.62127 .2465 L
.62185 .2465 L
.62185 .16187 L
F
.2 .63 .79 r
.62127 .16187 m
.62127 .2465 L
.62185 .2465 L
.62185 .16187 L
s
.678 .847 .902 r
.62185 .16187 m
.62185 .24709 L
.62236 .24709 L
.62236 .16187 L
F
.2 .63 .79 r
.62185 .16187 m
.62185 .24709 L
.62236 .24709 L
.62236 .16187 L
s
.678 .847 .902 r
.62236 .16187 m
.62236 .24741 L
.62278 .24741 L
.62278 .16187 L
F
.2 .63 .79 r
.62236 .16187 m
.62236 .24741 L
.62278 .24741 L
.62278 .16187 L
s
.678 .847 .902 r
.62278 .16187 m
.62278 .24758 L
.62305 .24758 L
.62305 .16187 L
F
.2 .63 .79 r
.62278 .16187 m
.62278 .24758 L
.62305 .24758 L
.62305 .16187 L
s
.678 .847 .902 r
.62305 .16187 m
.62305 .24793 L
.62356 .24793 L
.62356 .16187 L
F
.2 .63 .79 r
.62305 .16187 m
.62305 .24793 L
.62356 .24793 L
.62356 .16187 L
s
.678 .847 .902 r
.62356 .16187 m
.62356 .24844 L
.62408 .24844 L
.62408 .16187 L
F
.2 .63 .79 r
.62356 .16187 m
.62356 .24844 L
.62408 .24844 L
.62408 .16187 L
s
.678 .847 .902 r
.62408 .16187 m
.62408 .24879 L
.62471 .24879 L
.62471 .16187 L
F
.2 .63 .79 r
.62408 .16187 m
.62408 .24879 L
.62471 .24879 L
.62471 .16187 L
s
.678 .847 .902 r
.62471 .16187 m
.62471 .24928 L
.62519 .24928 L
.62519 .16187 L
F
.2 .63 .79 r
.62471 .16187 m
.62471 .24928 L
.62519 .24928 L
.62519 .16187 L
s
.678 .847 .902 r
.62519 .16187 m
.62519 .2496 L
.62555 .2496 L
.62555 .16187 L
F
.2 .63 .79 r
.62519 .16187 m
.62519 .2496 L
.62555 .2496 L
.62555 .16187 L
s
.678 .847 .902 r
.62555 .16187 m
.62555 .24987 L
.62602 .24987 L
.62602 .16187 L
F
.2 .63 .79 r
.62555 .16187 m
.62555 .24987 L
.62602 .24987 L
.62602 .16187 L
s
.678 .847 .902 r
.62602 .16187 m
.62602 .25018 L
.62658 .25018 L
.62658 .16187 L
F
.2 .63 .79 r
.62602 .16187 m
.62602 .25018 L
.62658 .25018 L
.62658 .16187 L
s
.678 .847 .902 r
.62658 .16187 m
.62658 .25051 L
.62681 .25051 L
.62681 .16187 L
F
.2 .63 .79 r
.62658 .16187 m
.62658 .25051 L
.62681 .25051 L
.62681 .16187 L
s
.678 .847 .902 r
.62681 .16187 m
.62681 .25072 L
.62701 .25072 L
.62701 .16187 L
F
.2 .63 .79 r
.62681 .16187 m
.62681 .25072 L
.62701 .25072 L
.62701 .16187 L
s
.678 .847 .902 r
.62701 .16187 m
.62701 .25089 L
.62725 .25089 L
.62725 .16187 L
F
.2 .63 .79 r
.62701 .16187 m
.62701 .25089 L
.62725 .25089 L
.62725 .16187 L
s
.678 .847 .902 r
.62725 .16187 m
.62725 .25125 L
.62767 .25125 L
.62767 .16187 L
F
.2 .63 .79 r
.62725 .16187 m
.62725 .25125 L
.62767 .25125 L
.62767 .16187 L
s
.678 .847 .902 r
.62767 .16187 m
.62767 .25149 L
.62811 .25149 L
.62811 .16187 L
F
.2 .63 .79 r
.62767 .16187 m
.62767 .25149 L
.62811 .25149 L
.62811 .16187 L
s
.678 .847 .902 r
.62811 .16187 m
.62811 .25202 L
.62872 .25202 L
.62872 .16187 L
F
.2 .63 .79 r
.62811 .16187 m
.62811 .25202 L
.62872 .25202 L
.62872 .16187 L
s
.678 .847 .902 r
.62872 .16187 m
.62872 .25236 L
.6291 .25236 L
.6291 .16187 L
F
.2 .63 .79 r
.62872 .16187 m
.62872 .25236 L
.6291 .25236 L
.6291 .16187 L
s
.678 .847 .902 r
.6291 .16187 m
.6291 .25262 L
.6293 .25262 L
.6293 .16187 L
F
.2 .63 .79 r
.6291 .16187 m
.6291 .25262 L
.6293 .25262 L
.6293 .16187 L
s
.678 .847 .902 r
.6293 .16187 m
.6293 .25275 L
.62963 .25275 L
.62963 .16187 L
F
.2 .63 .79 r
.6293 .16187 m
.6293 .25275 L
.62963 .25275 L
.62963 .16187 L
s
.678 .847 .902 r
.62963 .16187 m
.62963 .25305 L
.62993 .25305 L
.62993 .16187 L
F
.2 .63 .79 r
.62963 .16187 m
.62963 .25305 L
.62993 .25305 L
.62993 .16187 L
s
.678 .847 .902 r
.62993 .16187 m
.62993 .25312 L
.63048 .25312 L
.63048 .16187 L
F
.2 .63 .79 r
.62993 .16187 m
.62993 .25312 L
.63048 .25312 L
.63048 .16187 L
s
.678 .847 .902 r
.63048 .16187 m
.63048 .25356 L
.63096 .25356 L
.63096 .16187 L
F
.2 .63 .79 r
.63048 .16187 m
.63048 .25356 L
.63096 .25356 L
.63096 .16187 L
s
.678 .847 .902 r
.63096 .16187 m
.63096 .25396 L
.63118 .25396 L
.63118 .16187 L
F
.2 .63 .79 r
.63096 .16187 m
.63096 .25396 L
.63118 .25396 L
.63118 .16187 L
s
.678 .847 .902 r
.63118 .16187 m
.63118 .25421 L
.63153 .25421 L
.63153 .16187 L
F
.2 .63 .79 r
.63118 .16187 m
.63118 .25421 L
.63153 .25421 L
.63153 .16187 L
s
.678 .847 .902 r
.63153 .16187 m
.63153 .25443 L
.63176 .25443 L
.63176 .16187 L
F
.2 .63 .79 r
.63153 .16187 m
.63153 .25443 L
.63176 .25443 L
.63176 .16187 L
s
.678 .847 .902 r
.63176 .16187 m
.63176 .25464 L
.63201 .25464 L
.63201 .16187 L
F
.2 .63 .79 r
.63176 .16187 m
.63176 .25464 L
.63201 .25464 L
.63201 .16187 L
s
.678 .847 .902 r
.63201 .16187 m
.63201 .25521 L
.6326 .25521 L
.6326 .16187 L
F
.2 .63 .79 r
.63201 .16187 m
.63201 .25521 L
.6326 .25521 L
.6326 .16187 L
s
.678 .847 .902 r
.6326 .16187 m
.6326 .25558 L
.63308 .25558 L
.63308 .16187 L
F
.2 .63 .79 r
.6326 .16187 m
.6326 .25558 L
.63308 .25558 L
.63308 .16187 L
s
.678 .847 .902 r
.63308 .16187 m
.63308 .25576 L
.63343 .25576 L
.63343 .16187 L
F
.2 .63 .79 r
.63308 .16187 m
.63308 .25576 L
.63343 .25576 L
.63343 .16187 L
s
.678 .847 .902 r
.63343 .16187 m
.63343 .25606 L
.63369 .25606 L
.63369 .16187 L
F
.2 .63 .79 r
.63343 .16187 m
.63343 .25606 L
.63369 .25606 L
.63369 .16187 L
s
.678 .847 .902 r
.63369 .16187 m
.63369 .25616 L
.63399 .25616 L
.63399 .16187 L
F
.2 .63 .79 r
.63369 .16187 m
.63369 .25616 L
.63399 .25616 L
.63399 .16187 L
s
.678 .847 .902 r
.63399 .16187 m
.63399 .25638 L
.6343 .25638 L
.6343 .16187 L
F
.2 .63 .79 r
.63399 .16187 m
.63399 .25638 L
.6343 .25638 L
.6343 .16187 L
s
.678 .847 .902 r
.6343 .16187 m
.6343 .2566 L
.63482 .2566 L
.63482 .16187 L
F
.2 .63 .79 r
.6343 .16187 m
.6343 .2566 L
.63482 .2566 L
.63482 .16187 L
s
.678 .847 .902 r
.63482 .16187 m
.63482 .25714 L
.63515 .25714 L
.63515 .16187 L
F
.2 .63 .79 r
.63482 .16187 m
.63482 .25714 L
.63515 .25714 L
.63515 .16187 L
s
.678 .847 .902 r
.63515 .16187 m
.63515 .2573 L
.63541 .2573 L
.63541 .16187 L
F
.2 .63 .79 r
.63515 .16187 m
.63515 .2573 L
.63541 .2573 L
.63541 .16187 L
s
.678 .847 .902 r
.63541 .16187 m
.63541 .25769 L
.63572 .25769 L
.63572 .16187 L
F
.2 .63 .79 r
.63541 .16187 m
.63541 .25769 L
.63572 .25769 L
.63572 .16187 L
s
.678 .847 .902 r
.63572 .16187 m
.63572 .25797 L
.63619 .25797 L
.63619 .16187 L
F
.2 .63 .79 r
.63572 .16187 m
.63572 .25797 L
.63619 .25797 L
.63619 .16187 L
s
.678 .847 .902 r
.63619 .16187 m
.63619 .25847 L
.63674 .25847 L
.63674 .16187 L
F
.2 .63 .79 r
.63619 .16187 m
.63619 .25847 L
.63674 .25847 L
.63674 .16187 L
s
.678 .847 .902 r
.63674 .16187 m
.63674 .25881 L
.6372 .25881 L
.6372 .16187 L
F
.2 .63 .79 r
.63674 .16187 m
.63674 .25881 L
.6372 .25881 L
.6372 .16187 L
s
.678 .847 .902 r
.6372 .16187 m
.6372 .25895 L
.63754 .25895 L
.63754 .16187 L
F
.2 .63 .79 r
.6372 .16187 m
.6372 .25895 L
.63754 .25895 L
.63754 .16187 L
s
.678 .847 .902 r
.63754 .16187 m
.63754 .25917 L
.63782 .25917 L
.63782 .16187 L
F
.2 .63 .79 r
.63754 .16187 m
.63754 .25917 L
.63782 .25917 L
.63782 .16187 L
s
.678 .847 .902 r
.63782 .16187 m
.63782 .25977 L
.63836 .25977 L
.63836 .16187 L
F
.2 .63 .79 r
.63782 .16187 m
.63782 .25977 L
.63836 .25977 L
.63836 .16187 L
s
.678 .847 .902 r
.63836 .16187 m
.63836 .25989 L
.63867 .25989 L
.63867 .16187 L
F
.2 .63 .79 r
.63836 .16187 m
.63836 .25989 L
.63867 .25989 L
.63867 .16187 L
s
.678 .847 .902 r
.63867 .16187 m
.63867 .26016 L
.63891 .26016 L
.63891 .16187 L
F
.2 .63 .79 r
.63867 .16187 m
.63867 .26016 L
.63891 .26016 L
.63891 .16187 L
s
.678 .847 .902 r
.63891 .16187 m
.63891 .26026 L
.63928 .26026 L
.63928 .16187 L
F
.2 .63 .79 r
.63891 .16187 m
.63891 .26026 L
.63928 .26026 L
.63928 .16187 L
s
.678 .847 .902 r
.63928 .16187 m
.63928 .26072 L
.63953 .26072 L
.63953 .16187 L
F
.2 .63 .79 r
.63928 .16187 m
.63928 .26072 L
.63953 .26072 L
.63953 .16187 L
s
.678 .847 .902 r
.63953 .16187 m
.63953 .26077 L
.63982 .26077 L
.63982 .16187 L
F
.2 .63 .79 r
.63953 .16187 m
.63953 .26077 L
.63982 .26077 L
.63982 .16187 L
s
.678 .847 .902 r
.63982 .16187 m
.63982 .26104 L
.64034 .26104 L
.64034 .16187 L
F
.2 .63 .79 r
.63982 .16187 m
.63982 .26104 L
.64034 .26104 L
.64034 .16187 L
s
.678 .847 .902 r
.64034 .16187 m
.64034 .26159 L
.64067 .26159 L
.64067 .16187 L
F
.2 .63 .79 r
.64034 .16187 m
.64034 .26159 L
.64067 .26159 L
.64067 .16187 L
s
.678 .847 .902 r
.64067 .16187 m
.64067 .26173 L
.64086 .26173 L
.64086 .16187 L
F
.2 .63 .79 r
.64067 .16187 m
.64067 .26173 L
.64086 .26173 L
.64086 .16187 L
s
.678 .847 .902 r
.64086 .16187 m
.64086 .26186 L
.6412 .26186 L
.6412 .16187 L
F
.2 .63 .79 r
.64086 .16187 m
.64086 .26186 L
.6412 .26186 L
.6412 .16187 L
s
.678 .847 .902 r
.6412 .16187 m
.6412 .26211 L
.64143 .26211 L
.64143 .16187 L
F
.2 .63 .79 r
.6412 .16187 m
.6412 .26211 L
.64143 .26211 L
.64143 .16187 L
s
.678 .847 .902 r
.64143 .16187 m
.64143 .26237 L
.64205 .26237 L
.64205 .16187 L
F
.2 .63 .79 r
.64143 .16187 m
.64143 .26237 L
.64205 .26237 L
.64205 .16187 L
s
.678 .847 .902 r
.64205 .16187 m
.64205 .26305 L
.64262 .26305 L
.64262 .16187 L
F
.2 .63 .79 r
.64205 .16187 m
.64205 .26305 L
.64262 .26305 L
.64262 .16187 L
s
.678 .847 .902 r
.64262 .16187 m
.64262 .26337 L
.64285 .26337 L
.64285 .16187 L
F
.2 .63 .79 r
.64262 .16187 m
.64262 .26337 L
.64285 .26337 L
.64285 .16187 L
s
.678 .847 .902 r
.64285 .16187 m
.64285 .2634 L
.6434 .2634 L
.6434 .16187 L
F
.2 .63 .79 r
.64285 .16187 m
.64285 .2634 L
.6434 .2634 L
.6434 .16187 L
s
.678 .847 .902 r
.6434 .16187 m
.6434 .26388 L
.6437 .26388 L
.6437 .16187 L
F
.2 .63 .79 r
.6434 .16187 m
.6434 .26388 L
.6437 .26388 L
.6437 .16187 L
s
.678 .847 .902 r
.6437 .16187 m
.6437 .2641 L
.64413 .2641 L
.64413 .16187 L
F
.2 .63 .79 r
.6437 .16187 m
.6437 .2641 L
.64413 .2641 L
.64413 .16187 L
s
.678 .847 .902 r
.64413 .16187 m
.64413 .26474 L
.64473 .26474 L
.64473 .16187 L
F
.2 .63 .79 r
.64413 .16187 m
.64413 .26474 L
.64473 .26474 L
.64473 .16187 L
s
.678 .847 .902 r
.64473 .16187 m
.64473 .26493 L
.64516 .26493 L
.64516 .16187 L
F
.2 .63 .79 r
.64473 .16187 m
.64473 .26493 L
.64516 .26493 L
.64516 .16187 L
s
.678 .847 .902 r
.64516 .16187 m
.64516 .26544 L
.64563 .26544 L
.64563 .16187 L
F
.2 .63 .79 r
.64516 .16187 m
.64516 .26544 L
.64563 .26544 L
.64563 .16187 L
s
.678 .847 .902 r
.64563 .16187 m
.64563 .2657 L
.64615 .2657 L
.64615 .16187 L
F
.2 .63 .79 r
.64563 .16187 m
.64563 .2657 L
.64615 .2657 L
.64615 .16187 L
s
.678 .847 .902 r
.64615 .16187 m
.64615 .26628 L
.64649 .26628 L
.64649 .16187 L
F
.2 .63 .79 r
.64615 .16187 m
.64615 .26628 L
.64649 .26628 L
.64649 .16187 L
s
.678 .847 .902 r
.64649 .16187 m
.64649 .26651 L
.64677 .26651 L
.64677 .16187 L
F
.2 .63 .79 r
.64649 .16187 m
.64649 .26651 L
.64677 .26651 L
.64677 .16187 L
s
.678 .847 .902 r
.64677 .16187 m
.64677 .26668 L
.64715 .26668 L
.64715 .16187 L
F
.2 .63 .79 r
.64677 .16187 m
.64677 .26668 L
.64715 .26668 L
.64715 .16187 L
s
.678 .847 .902 r
.64715 .16187 m
.64715 .26697 L
.64777 .26697 L
.64777 .16187 L
F
.2 .63 .79 r
.64715 .16187 m
.64715 .26697 L
.64777 .26697 L
.64777 .16187 L
s
.678 .847 .902 r
.64777 .16187 m
.64777 .26744 L
.64799 .26744 L
.64799 .16187 L
F
.2 .63 .79 r
.64777 .16187 m
.64777 .26744 L
.64799 .26744 L
.64799 .16187 L
s
.678 .847 .902 r
.64799 .16187 m
.64799 .26758 L
.64822 .26758 L
.64822 .16187 L
F
.2 .63 .79 r
.64799 .16187 m
.64799 .26758 L
.64822 .26758 L
.64822 .16187 L
s
.678 .847 .902 r
.64822 .16187 m
.64822 .26778 L
.64842 .26778 L
.64842 .16187 L
F
.2 .63 .79 r
.64822 .16187 m
.64822 .26778 L
.64842 .26778 L
.64842 .16187 L
s
.678 .847 .902 r
.64842 .16187 m
.64842 .26802 L
.64898 .26802 L
.64898 .16187 L
F
.2 .63 .79 r
.64842 .16187 m
.64842 .26802 L
.64898 .26802 L
.64898 .16187 L
s
.678 .847 .902 r
.64898 .16187 m
.64898 .26848 L
.64955 .26848 L
.64955 .16187 L
F
.2 .63 .79 r
.64898 .16187 m
.64898 .26848 L
.64955 .26848 L
.64955 .16187 L
s
.678 .847 .902 r
.64955 .16187 m
.64955 .26882 L
.6499 .26882 L
.6499 .16187 L
F
.2 .63 .79 r
.64955 .16187 m
.64955 .26882 L
.6499 .26882 L
.6499 .16187 L
s
.678 .847 .902 r
.6499 .16187 m
.6499 .26931 L
.65041 .26931 L
.65041 .16187 L
F
.2 .63 .79 r
.6499 .16187 m
.6499 .26931 L
.65041 .26931 L
.65041 .16187 L
s
.678 .847 .902 r
.65041 .16187 m
.65041 .26984 L
.65097 .26984 L
.65097 .16187 L
F
.2 .63 .79 r
.65041 .16187 m
.65041 .26984 L
.65097 .26984 L
.65097 .16187 L
s
.678 .847 .902 r
.65097 .16187 m
.65097 .26998 L
.65139 .26998 L
.65139 .16187 L
F
.2 .63 .79 r
.65097 .16187 m
.65097 .26998 L
.65139 .26998 L
.65139 .16187 L
s
.678 .847 .902 r
.65139 .16187 m
.65139 .2705 L
.6517 .2705 L
.6517 .16187 L
F
.2 .63 .79 r
.65139 .16187 m
.65139 .2705 L
.6517 .2705 L
.6517 .16187 L
s
.678 .847 .902 r
.6517 .16187 m
.6517 .27067 L
.65223 .27067 L
.65223 .16187 L
F
.2 .63 .79 r
.6517 .16187 m
.6517 .27067 L
.65223 .27067 L
.65223 .16187 L
s
.678 .847 .902 r
.65223 .16187 m
.65223 .27103 L
.65286 .27103 L
.65286 .16187 L
F
.2 .63 .79 r
.65223 .16187 m
.65223 .27103 L
.65286 .27103 L
.65286 .16187 L
s
.678 .847 .902 r
.65286 .16187 m
.65286 .27155 L
.65324 .27155 L
.65324 .16187 L
F
.2 .63 .79 r
.65286 .16187 m
.65286 .27155 L
.65324 .27155 L
.65324 .16187 L
s
.678 .847 .902 r
.65324 .16187 m
.65324 .27207 L
.65363 .27207 L
.65363 .16187 L
F
.2 .63 .79 r
.65324 .16187 m
.65324 .27207 L
.65363 .27207 L
.65363 .16187 L
s
.678 .847 .902 r
.65363 .16187 m
.65363 .27216 L
.65406 .27216 L
.65406 .16187 L
F
.2 .63 .79 r
.65363 .16187 m
.65363 .27216 L
.65406 .27216 L
.65406 .16187 L
s
.678 .847 .902 r
.65406 .16187 m
.65406 .27249 L
.65445 .27249 L
.65445 .16187 L
F
.2 .63 .79 r
.65406 .16187 m
.65406 .27249 L
.65445 .27249 L
.65445 .16187 L
s
.678 .847 .902 r
.65445 .16187 m
.65445 .27298 L
.65487 .27298 L
.65487 .16187 L
F
.2 .63 .79 r
.65445 .16187 m
.65445 .27298 L
.65487 .27298 L
.65487 .16187 L
s
.678 .847 .902 r
.65487 .16187 m
.65487 .2735 L
.65546 .2735 L
.65546 .16187 L
F
.2 .63 .79 r
.65487 .16187 m
.65487 .2735 L
.65546 .2735 L
.65546 .16187 L
s
.678 .847 .902 r
.65546 .16187 m
.65546 .27393 L
.65606 .27393 L
.65606 .16187 L
F
.2 .63 .79 r
.65546 .16187 m
.65546 .27393 L
.65606 .27393 L
.65606 .16187 L
s
.678 .847 .902 r
.65606 .16187 m
.65606 .27448 L
.65656 .27448 L
.65656 .16187 L
F
.2 .63 .79 r
.65606 .16187 m
.65606 .27448 L
.65656 .27448 L
.65656 .16187 L
s
.678 .847 .902 r
.65656 .16187 m
.65656 .27469 L
.65683 .27469 L
.65683 .16187 L
F
.2 .63 .79 r
.65656 .16187 m
.65656 .27469 L
.65683 .27469 L
.65683 .16187 L
s
.678 .847 .902 r
.65683 .16187 m
.65683 .27516 L
.65735 .27516 L
.65735 .16187 L
F
.2 .63 .79 r
.65683 .16187 m
.65683 .27516 L
.65735 .27516 L
.65735 .16187 L
s
.678 .847 .902 r
.65735 .16187 m
.65735 .27525 L
.65775 .27525 L
.65775 .16187 L
F
.2 .63 .79 r
.65735 .16187 m
.65735 .27525 L
.65775 .27525 L
.65775 .16187 L
s
.678 .847 .902 r
.65775 .16187 m
.65775 .2758 L
.65827 .2758 L
.65827 .16187 L
F
.2 .63 .79 r
.65775 .16187 m
.65775 .2758 L
.65827 .2758 L
.65827 .16187 L
s
.678 .847 .902 r
.65827 .16187 m
.65827 .27599 L
.65852 .27599 L
.65852 .16187 L
F
.2 .63 .79 r
.65827 .16187 m
.65827 .27599 L
.65852 .27599 L
.65852 .16187 L
s
.678 .847 .902 r
.65852 .16187 m
.65852 .27643 L
.65899 .27643 L
.65899 .16187 L
F
.2 .63 .79 r
.65852 .16187 m
.65852 .27643 L
.65899 .27643 L
.65899 .16187 L
s
.678 .847 .902 r
.65899 .16187 m
.65899 .27682 L
.65938 .27682 L
.65938 .16187 L
F
.2 .63 .79 r
.65899 .16187 m
.65899 .27682 L
.65938 .27682 L
.65938 .16187 L
s
.678 .847 .902 r
.65938 .16187 m
.65938 .27705 L
.65999 .27705 L
.65999 .16187 L
F
.2 .63 .79 r
.65938 .16187 m
.65938 .27705 L
.65999 .27705 L
.65999 .16187 L
s
.678 .847 .902 r
.65999 .16187 m
.65999 .2776 L
.6603 .2776 L
.6603 .16187 L
F
.2 .63 .79 r
.65999 .16187 m
.65999 .2776 L
.6603 .2776 L
.6603 .16187 L
s
.678 .847 .902 r
.6603 .16187 m
.6603 .2778 L
.66062 .2778 L
.66062 .16187 L
F
.2 .63 .79 r
.6603 .16187 m
.6603 .2778 L
.66062 .2778 L
.66062 .16187 L
s
.678 .847 .902 r
.66062 .16187 m
.66062 .27804 L
.66113 .27804 L
.66113 .16187 L
F
.2 .63 .79 r
.66062 .16187 m
.66062 .27804 L
.66113 .27804 L
.66113 .16187 L
s
.678 .847 .902 r
.66113 .16187 m
.66113 .27843 L
.66137 .27843 L
.66137 .16187 L
F
.2 .63 .79 r
.66113 .16187 m
.66113 .27843 L
.66137 .27843 L
.66137 .16187 L
s
.678 .847 .902 r
.66137 .16187 m
.66137 .27889 L
.6619 .27889 L
.6619 .16187 L
F
.2 .63 .79 r
.66137 .16187 m
.66137 .27889 L
.6619 .27889 L
.6619 .16187 L
s
.678 .847 .902 r
.6619 .16187 m
.6619 .27909 L
.6621 .27909 L
.6621 .16187 L
F
.2 .63 .79 r
.6619 .16187 m
.6619 .27909 L
.6621 .27909 L
.6621 .16187 L
s
.678 .847 .902 r
.6621 .16187 m
.6621 .27916 L
.66272 .27916 L
.66272 .16187 L
F
.2 .63 .79 r
.6621 .16187 m
.6621 .27916 L
.66272 .27916 L
.66272 .16187 L
s
.678 .847 .902 r
.66272 .16187 m
.66272 .27974 L
.66297 .27974 L
.66297 .16187 L
F
.2 .63 .79 r
.66272 .16187 m
.66272 .27974 L
.66297 .27974 L
.66297 .16187 L
s
.678 .847 .902 r
.66297 .16187 m
.66297 .28002 L
.66331 .28002 L
.66331 .16187 L
F
.2 .63 .79 r
.66297 .16187 m
.66297 .28002 L
.66331 .28002 L
.66331 .16187 L
s
.678 .847 .902 r
.66331 .16187 m
.66331 .28014 L
.66376 .28014 L
.66376 .16187 L
F
.2 .63 .79 r
.66331 .16187 m
.66331 .28014 L
.66376 .28014 L
.66376 .16187 L
s
.678 .847 .902 r
.66376 .16187 m
.66376 .28048 L
.66414 .28048 L
.66414 .16187 L
F
.2 .63 .79 r
.66376 .16187 m
.66376 .28048 L
.66414 .28048 L
.66414 .16187 L
s
.678 .847 .902 r
.66414 .16187 m
.66414 .28103 L
.66464 .28103 L
.66464 .16187 L
F
.2 .63 .79 r
.66414 .16187 m
.66414 .28103 L
.66464 .28103 L
.66464 .16187 L
s
.678 .847 .902 r
.66464 .16187 m
.66464 .2813 L
.6652 .2813 L
.6652 .16187 L
F
.2 .63 .79 r
.66464 .16187 m
.66464 .2813 L
.6652 .2813 L
.6652 .16187 L
s
.678 .847 .902 r
.6652 .16187 m
.6652 .28182 L
.66569 .28182 L
.66569 .16187 L
F
.2 .63 .79 r
.6652 .16187 m
.6652 .28182 L
.66569 .28182 L
.66569 .16187 L
s
.678 .847 .902 r
.66569 .16187 m
.66569 .28223 L
.66612 .28223 L
.66612 .16187 L
F
.2 .63 .79 r
.66569 .16187 m
.66569 .28223 L
.66612 .28223 L
.66612 .16187 L
s
.678 .847 .902 r
.66612 .16187 m
.66612 .28281 L
.66675 .28281 L
.66675 .16187 L
F
.2 .63 .79 r
.66612 .16187 m
.66612 .28281 L
.66675 .28281 L
.66675 .16187 L
s
.678 .847 .902 r
.66675 .16187 m
.66675 .28316 L
.66722 .28316 L
.66722 .16187 L
F
.2 .63 .79 r
.66675 .16187 m
.66675 .28316 L
.66722 .28316 L
.66722 .16187 L
s
.678 .847 .902 r
.66722 .16187 m
.66722 .28358 L
.66784 .28358 L
.66784 .16187 L
F
.2 .63 .79 r
.66722 .16187 m
.66722 .28358 L
.66784 .28358 L
.66784 .16187 L
s
.678 .847 .902 r
.66784 .16187 m
.66784 .28391 L
.66805 .28391 L
.66805 .16187 L
F
.2 .63 .79 r
.66784 .16187 m
.66784 .28391 L
.66805 .28391 L
.66805 .16187 L
s
.678 .847 .902 r
.66805 .16187 m
.66805 .28407 L
.66836 .28407 L
.66836 .16187 L
F
.2 .63 .79 r
.66805 .16187 m
.66805 .28407 L
.66836 .28407 L
.66836 .16187 L
s
.678 .847 .902 r
.66836 .16187 m
.66836 .2844 L
.66877 .2844 L
.66877 .16187 L
F
.2 .63 .79 r
.66836 .16187 m
.66836 .2844 L
.66877 .2844 L
.66877 .16187 L
s
.678 .847 .902 r
.66877 .16187 m
.66877 .28485 L
.66911 .28485 L
.66911 .16187 L
F
.2 .63 .79 r
.66877 .16187 m
.66877 .28485 L
.66911 .28485 L
.66911 .16187 L
s
.678 .847 .902 r
.66911 .16187 m
.66911 .28506 L
.66957 .28506 L
.66957 .16187 L
F
.2 .63 .79 r
.66911 .16187 m
.66911 .28506 L
.66957 .28506 L
.66957 .16187 L
s
.678 .847 .902 r
.66957 .16187 m
.66957 .28551 L
.66991 .28551 L
.66991 .16187 L
F
.2 .63 .79 r
.66957 .16187 m
.66957 .28551 L
.66991 .28551 L
.66991 .16187 L
s
.678 .847 .902 r
.66991 .16187 m
.66991 .28568 L
.6702 .28568 L
.6702 .16187 L
F
.2 .63 .79 r
.66991 .16187 m
.66991 .28568 L
.6702 .28568 L
.6702 .16187 L
s
.678 .847 .902 r
.6702 .16187 m
.6702 .28603 L
.67042 .28603 L
.67042 .16187 L
F
.2 .63 .79 r
.6702 .16187 m
.6702 .28603 L
.67042 .28603 L
.67042 .16187 L
s
.678 .847 .902 r
.67042 .16187 m
.67042 .28648 L
.671 .28648 L
.671 .16187 L
F
.2 .63 .79 r
.67042 .16187 m
.67042 .28648 L
.671 .28648 L
.671 .16187 L
s
.678 .847 .902 r
.671 .16187 m
.671 .28677 L
.67129 .28677 L
.67129 .16187 L
F
.2 .63 .79 r
.671 .16187 m
.671 .28677 L
.67129 .28677 L
.67129 .16187 L
s
.678 .847 .902 r
.67129 .16187 m
.67129 .2869 L
.6717 .2869 L
.6717 .16187 L
F
.2 .63 .79 r
.67129 .16187 m
.67129 .2869 L
.6717 .2869 L
.6717 .16187 L
s
.678 .847 .902 r
.6717 .16187 m
.6717 .28713 L
.67189 .28713 L
.67189 .16187 L
F
.2 .63 .79 r
.6717 .16187 m
.6717 .28713 L
.67189 .28713 L
.67189 .16187 L
s
.678 .847 .902 r
.67189 .16187 m
.67189 .28769 L
.67249 .28769 L
.67249 .16187 L
F
.2 .63 .79 r
.67189 .16187 m
.67189 .28769 L
.67249 .28769 L
.67249 .16187 L
s
.678 .847 .902 r
.67249 .16187 m
.67249 .28786 L
.67273 .28786 L
.67273 .16187 L
F
.2 .63 .79 r
.67249 .16187 m
.67249 .28786 L
.67273 .28786 L
.67273 .16187 L
s
.678 .847 .902 r
.67273 .16187 m
.67273 .28813 L
.67299 .28813 L
.67299 .16187 L
F
.2 .63 .79 r
.67273 .16187 m
.67273 .28813 L
.67299 .28813 L
.67299 .16187 L
s
.678 .847 .902 r
.67299 .16187 m
.67299 .28852 L
.67337 .28852 L
.67337 .16187 L
F
.2 .63 .79 r
.67299 .16187 m
.67299 .28852 L
.67337 .28852 L
.67337 .16187 L
s
.678 .847 .902 r
.67337 .16187 m
.67337 .2888 L
.67378 .2888 L
.67378 .16187 L
F
.2 .63 .79 r
.67337 .16187 m
.67337 .2888 L
.67378 .2888 L
.67378 .16187 L
s
.678 .847 .902 r
.67378 .16187 m
.67378 .28912 L
.67415 .28912 L
.67415 .16187 L
F
.2 .63 .79 r
.67378 .16187 m
.67378 .28912 L
.67415 .28912 L
.67415 .16187 L
s
.678 .847 .902 r
.67415 .16187 m
.67415 .28932 L
.67451 .28932 L
.67451 .16187 L
F
.2 .63 .79 r
.67415 .16187 m
.67415 .28932 L
.67451 .28932 L
.67451 .16187 L
s
.678 .847 .902 r
.67451 .16187 m
.67451 .28976 L
.67503 .28976 L
.67503 .16187 L
F
.2 .63 .79 r
.67451 .16187 m
.67451 .28976 L
.67503 .28976 L
.67503 .16187 L
s
.678 .847 .902 r
.67503 .16187 m
.67503 .29012 L
.67565 .29012 L
.67565 .16187 L
F
.2 .63 .79 r
.67503 .16187 m
.67503 .29012 L
.67565 .29012 L
.67565 .16187 L
s
.678 .847 .902 r
.67565 .16187 m
.67565 .29048 L
.67602 .29048 L
.67602 .16187 L
F
.2 .63 .79 r
.67565 .16187 m
.67565 .29048 L
.67602 .29048 L
.67602 .16187 L
s
.678 .847 .902 r
.67602 .16187 m
.67602 .29119 L
.67654 .29119 L
.67654 .16187 L
F
.2 .63 .79 r
.67602 .16187 m
.67602 .29119 L
.67654 .29119 L
.67654 .16187 L
s
.678 .847 .902 r
.67654 .16187 m
.67654 .2913 L
.67709 .2913 L
.67709 .16187 L
F
.2 .63 .79 r
.67654 .16187 m
.67654 .2913 L
.67709 .2913 L
.67709 .16187 L
s
.678 .847 .902 r
.67709 .16187 m
.67709 .29176 L
.67769 .29176 L
.67769 .16187 L
F
.2 .63 .79 r
.67709 .16187 m
.67709 .29176 L
.67769 .29176 L
.67769 .16187 L
s
.678 .847 .902 r
.67769 .16187 m
.67769 .29219 L
.67795 .29219 L
.67795 .16187 L
F
.2 .63 .79 r
.67769 .16187 m
.67769 .29219 L
.67795 .29219 L
.67795 .16187 L
s
.678 .847 .902 r
.67795 .16187 m
.67795 .29257 L
.67824 .29257 L
.67824 .16187 L
F
.2 .63 .79 r
.67795 .16187 m
.67795 .29257 L
.67824 .29257 L
.67824 .16187 L
s
.678 .847 .902 r
.67824 .16187 m
.67824 .29282 L
.67863 .29282 L
.67863 .16187 L
F
.2 .63 .79 r
.67824 .16187 m
.67824 .29282 L
.67863 .29282 L
.67863 .16187 L
s
.678 .847 .902 r
.67863 .16187 m
.67863 .29323 L
.67897 .29323 L
.67897 .16187 L
F
.2 .63 .79 r
.67863 .16187 m
.67863 .29323 L
.67897 .29323 L
.67897 .16187 L
s
.678 .847 .902 r
.67897 .16187 m
.67897 .29347 L
.67953 .29347 L
.67953 .16187 L
F
.2 .63 .79 r
.67897 .16187 m
.67897 .29347 L
.67953 .29347 L
.67953 .16187 L
s
.678 .847 .902 r
.67953 .16187 m
.67953 .29398 L
.68017 .29398 L
.68017 .16187 L
F
.2 .63 .79 r
.67953 .16187 m
.67953 .29398 L
.68017 .29398 L
.68017 .16187 L
s
.678 .847 .902 r
.68017 .16187 m
.68017 .29445 L
.68054 .29445 L
.68054 .16187 L
F
.2 .63 .79 r
.68017 .16187 m
.68017 .29445 L
.68054 .29445 L
.68054 .16187 L
s
.678 .847 .902 r
.68054 .16187 m
.68054 .29492 L
.68093 .29492 L
.68093 .16187 L
F
.2 .63 .79 r
.68054 .16187 m
.68054 .29492 L
.68093 .29492 L
.68093 .16187 L
s
.678 .847 .902 r
.68093 .16187 m
.68093 .29511 L
.68139 .29511 L
.68139 .16187 L
F
.2 .63 .79 r
.68093 .16187 m
.68093 .29511 L
.68139 .29511 L
.68139 .16187 L
s
.678 .847 .902 r
.68139 .16187 m
.68139 .29534 L
.68181 .29534 L
.68181 .16187 L
F
.2 .63 .79 r
.68139 .16187 m
.68139 .29534 L
.68181 .29534 L
.68181 .16187 L
s
.678 .847 .902 r
.68181 .16187 m
.68181 .29582 L
.68218 .29582 L
.68218 .16187 L
F
.2 .63 .79 r
.68181 .16187 m
.68181 .29582 L
.68218 .29582 L
.68218 .16187 L
s
.678 .847 .902 r
.68218 .16187 m
.68218 .29605 L
.68261 .29605 L
.68261 .16187 L
F
.2 .63 .79 r
.68218 .16187 m
.68218 .29605 L
.68261 .29605 L
.68261 .16187 L
s
.678 .847 .902 r
.68261 .16187 m
.68261 .29639 L
.68302 .29639 L
.68302 .16187 L
F
.2 .63 .79 r
.68261 .16187 m
.68261 .29639 L
.68302 .29639 L
.68302 .16187 L
s
.678 .847 .902 r
.68302 .16187 m
.68302 .29684 L
.68338 .29684 L
.68338 .16187 L
F
.2 .63 .79 r
.68302 .16187 m
.68302 .29684 L
.68338 .29684 L
.68338 .16187 L
s
.678 .847 .902 r
.68338 .16187 m
.68338 .29726 L
.684 .29726 L
.684 .16187 L
F
.2 .63 .79 r
.68338 .16187 m
.68338 .29726 L
.684 .29726 L
.684 .16187 L
s
.678 .847 .902 r
.684 .16187 m
.684 .29762 L
.68421 .29762 L
.68421 .16187 L
F
.2 .63 .79 r
.684 .16187 m
.684 .29762 L
.68421 .29762 L
.68421 .16187 L
s
.678 .847 .902 r
.68421 .16187 m
.68421 .29779 L
.68444 .29779 L
.68444 .16187 L
F
.2 .63 .79 r
.68421 .16187 m
.68421 .29779 L
.68444 .29779 L
.68444 .16187 L
s
.678 .847 .902 r
.68444 .16187 m
.68444 .29809 L
.68464 .29809 L
.68464 .16187 L
F
.2 .63 .79 r
.68444 .16187 m
.68444 .29809 L
.68464 .29809 L
.68464 .16187 L
s
.678 .847 .902 r
.68464 .16187 m
.68464 .2983 L
.68493 .2983 L
.68493 .16187 L
F
.2 .63 .79 r
.68464 .16187 m
.68464 .2983 L
.68493 .2983 L
.68493 .16187 L
s
.678 .847 .902 r
.68493 .16187 m
.68493 .29854 L
.68515 .29854 L
.68515 .16187 L
F
.2 .63 .79 r
.68493 .16187 m
.68493 .29854 L
.68515 .29854 L
.68515 .16187 L
s
.678 .847 .902 r
.68515 .16187 m
.68515 .2986 L
.68565 .2986 L
.68565 .16187 L
F
.2 .63 .79 r
.68515 .16187 m
.68515 .2986 L
.68565 .2986 L
.68565 .16187 L
s
.678 .847 .902 r
.68565 .16187 m
.68565 .29923 L
.68597 .29923 L
.68597 .16187 L
F
.2 .63 .79 r
.68565 .16187 m
.68565 .29923 L
.68597 .29923 L
.68597 .16187 L
s
.678 .847 .902 r
.68597 .16187 m
.68597 .29944 L
.68635 .29944 L
.68635 .16187 L
F
.2 .63 .79 r
.68597 .16187 m
.68597 .29944 L
.68635 .29944 L
.68635 .16187 L
s
.678 .847 .902 r
.68635 .16187 m
.68635 .29975 L
.68661 .29975 L
.68661 .16187 L
F
.2 .63 .79 r
.68635 .16187 m
.68635 .29975 L
.68661 .29975 L
.68661 .16187 L
s
.678 .847 .902 r
.68661 .16187 m
.68661 .29982 L
.68705 .29982 L
.68705 .16187 L
F
.2 .63 .79 r
.68661 .16187 m
.68661 .29982 L
.68705 .29982 L
.68705 .16187 L
s
.678 .847 .902 r
.68705 .16187 m
.68705 .30022 L
.68726 .30022 L
.68726 .16187 L
F
.2 .63 .79 r
.68705 .16187 m
.68705 .30022 L
.68726 .30022 L
.68726 .16187 L
s
.678 .847 .902 r
.68726 .16187 m
.68726 .30039 L
.68789 .30039 L
.68789 .16187 L
F
.2 .63 .79 r
.68726 .16187 m
.68726 .30039 L
.68789 .30039 L
.68789 .16187 L
s
.678 .847 .902 r
.68789 .16187 m
.68789 .30133 L
.68845 .30133 L
.68845 .16187 L
F
.2 .63 .79 r
.68789 .16187 m
.68789 .30133 L
.68845 .30133 L
.68845 .16187 L
s
.678 .847 .902 r
.68845 .16187 m
.68845 .30165 L
.68896 .30165 L
.68896 .16187 L
F
.2 .63 .79 r
.68845 .16187 m
.68845 .30165 L
.68896 .30165 L
.68896 .16187 L
s
.678 .847 .902 r
.68896 .16187 m
.68896 .30197 L
.68918 .30197 L
.68918 .16187 L
F
.2 .63 .79 r
.68896 .16187 m
.68896 .30197 L
.68918 .30197 L
.68918 .16187 L
s
.678 .847 .902 r
.68918 .16187 m
.68918 .30221 L
.68962 .30221 L
.68962 .16187 L
F
.2 .63 .79 r
.68918 .16187 m
.68918 .30221 L
.68962 .30221 L
.68962 .16187 L
s
.678 .847 .902 r
.68962 .16187 m
.68962 .30269 L
.68999 .30269 L
.68999 .16187 L
F
.2 .63 .79 r
.68962 .16187 m
.68962 .30269 L
.68999 .30269 L
.68999 .16187 L
s
.678 .847 .902 r
.68999 .16187 m
.68999 .30274 L
.69023 .30274 L
.69023 .16187 L
F
.2 .63 .79 r
.68999 .16187 m
.68999 .30274 L
.69023 .30274 L
.69023 .16187 L
s
.678 .847 .902 r
.69023 .16187 m
.69023 .30319 L
.69066 .30319 L
.69066 .16187 L
F
.2 .63 .79 r
.69023 .16187 m
.69023 .30319 L
.69066 .30319 L
.69066 .16187 L
s
.678 .847 .902 r
.69066 .16187 m
.69066 .30331 L
.69093 .30331 L
.69093 .16187 L
F
.2 .63 .79 r
.69066 .16187 m
.69066 .30331 L
.69093 .30331 L
.69093 .16187 L
s
.678 .847 .902 r
.69093 .16187 m
.69093 .30391 L
.69151 .30391 L
.69151 .16187 L
F
.2 .63 .79 r
.69093 .16187 m
.69093 .30391 L
.69151 .30391 L
.69151 .16187 L
s
.678 .847 .902 r
.69151 .16187 m
.69151 .30405 L
.69197 .30405 L
.69197 .16187 L
F
.2 .63 .79 r
.69151 .16187 m
.69151 .30405 L
.69197 .30405 L
.69197 .16187 L
s
.678 .847 .902 r
.69197 .16187 m
.69197 .3045 L
.69224 .3045 L
.69224 .16187 L
F
.2 .63 .79 r
.69197 .16187 m
.69197 .3045 L
.69224 .3045 L
.69224 .16187 L
s
.678 .847 .902 r
.69224 .16187 m
.69224 .30482 L
.69252 .30482 L
.69252 .16187 L
F
.2 .63 .79 r
.69224 .16187 m
.69224 .30482 L
.69252 .30482 L
.69252 .16187 L
s
.678 .847 .902 r
.69252 .16187 m
.69252 .3051 L
.69308 .3051 L
.69308 .16187 L
F
.2 .63 .79 r
.69252 .16187 m
.69252 .3051 L
.69308 .3051 L
.69308 .16187 L
s
.678 .847 .902 r
.69308 .16187 m
.69308 .30568 L
.6935 .30568 L
.6935 .16187 L
F
.2 .63 .79 r
.69308 .16187 m
.69308 .30568 L
.6935 .30568 L
.6935 .16187 L
s
.678 .847 .902 r
.6935 .16187 m
.6935 .30585 L
.69377 .30585 L
.69377 .16187 L
F
.2 .63 .79 r
.6935 .16187 m
.6935 .30585 L
.69377 .30585 L
.69377 .16187 L
s
.678 .847 .902 r
.69377 .16187 m
.69377 .30645 L
.6944 .30645 L
.6944 .16187 L
F
.2 .63 .79 r
.69377 .16187 m
.69377 .30645 L
.6944 .30645 L
.6944 .16187 L
s
.678 .847 .902 r
.6944 .16187 m
.6944 .30674 L
.69493 .30674 L
.69493 .16187 L
F
.2 .63 .79 r
.6944 .16187 m
.6944 .30674 L
.69493 .30674 L
.69493 .16187 L
s
.678 .847 .902 r
.69493 .16187 m
.69493 .30731 L
.69548 .30731 L
.69548 .16187 L
F
.2 .63 .79 r
.69493 .16187 m
.69493 .30731 L
.69548 .30731 L
.69548 .16187 L
s
.678 .847 .902 r
.69548 .16187 m
.69548 .3077 L
.69607 .3077 L
.69607 .16187 L
F
.2 .63 .79 r
.69548 .16187 m
.69548 .3077 L
.69607 .3077 L
.69607 .16187 L
s
.678 .847 .902 r
.69607 .16187 m
.69607 .30808 L
.69651 .30808 L
.69651 .16187 L
F
.2 .63 .79 r
.69607 .16187 m
.69607 .30808 L
.69651 .30808 L
.69651 .16187 L
s
.678 .847 .902 r
.69651 .16187 m
.69651 .30864 L
.69697 .30864 L
.69697 .16187 L
F
.2 .63 .79 r
.69651 .16187 m
.69651 .30864 L
.69697 .30864 L
.69697 .16187 L
s
.678 .847 .902 r
.69697 .16187 m
.69697 .30894 L
.69728 .30894 L
.69728 .16187 L
F
.2 .63 .79 r
.69697 .16187 m
.69697 .30894 L
.69728 .30894 L
.69728 .16187 L
s
.678 .847 .902 r
.69728 .16187 m
.69728 .30914 L
.69785 .30914 L
.69785 .16187 L
F
.2 .63 .79 r
.69728 .16187 m
.69728 .30914 L
.69785 .30914 L
.69785 .16187 L
s
.678 .847 .902 r
.69785 .16187 m
.69785 .30961 L
.6983 .30961 L
.6983 .16187 L
F
.2 .63 .79 r
.69785 .16187 m
.69785 .30961 L
.6983 .30961 L
.6983 .16187 L
s
.678 .847 .902 r
.6983 .16187 m
.6983 .31029 L
.69883 .31029 L
.69883 .16187 L
F
.2 .63 .79 r
.6983 .16187 m
.6983 .31029 L
.69883 .31029 L
.69883 .16187 L
s
.678 .847 .902 r
.69883 .16187 m
.69883 .31079 L
.69927 .31079 L
.69927 .16187 L
F
.2 .63 .79 r
.69883 .16187 m
.69883 .31079 L
.69927 .31079 L
.69927 .16187 L
s
.678 .847 .902 r
.69927 .16187 m
.69927 .31097 L
.69982 .31097 L
.69982 .16187 L
F
.2 .63 .79 r
.69927 .16187 m
.69927 .31097 L
.69982 .31097 L
.69982 .16187 L
s
.678 .847 .902 r
.69982 .16187 m
.69982 .31138 L
.70001 .31138 L
.70001 .16187 L
F
.2 .63 .79 r
.69982 .16187 m
.69982 .31138 L
.70001 .31138 L
.70001 .16187 L
s
.678 .847 .902 r
.70001 .16187 m
.70001 .3117 L
.70036 .3117 L
.70036 .16187 L
F
.2 .63 .79 r
.70001 .16187 m
.70001 .3117 L
.70036 .3117 L
.70036 .16187 L
s
.678 .847 .902 r
.70036 .16187 m
.70036 .31204 L
.70075 .31204 L
.70075 .16187 L
F
.2 .63 .79 r
.70036 .16187 m
.70036 .31204 L
.70075 .31204 L
.70075 .16187 L
s
.678 .847 .902 r
.70075 .16187 m
.70075 .31227 L
.70106 .31227 L
.70106 .16187 L
F
.2 .63 .79 r
.70075 .16187 m
.70075 .31227 L
.70106 .31227 L
.70106 .16187 L
s
.678 .847 .902 r
.70106 .16187 m
.70106 .31263 L
.70163 .31263 L
.70163 .16187 L
F
.2 .63 .79 r
.70106 .16187 m
.70106 .31263 L
.70163 .31263 L
.70163 .16187 L
s
.678 .847 .902 r
.70163 .16187 m
.70163 .31288 L
.70204 .31288 L
.70204 .16187 L
F
.2 .63 .79 r
.70163 .16187 m
.70163 .31288 L
.70204 .31288 L
.70204 .16187 L
s
.678 .847 .902 r
.70204 .16187 m
.70204 .31362 L
.70261 .31362 L
.70261 .16187 L
F
.2 .63 .79 r
.70204 .16187 m
.70204 .31362 L
.70261 .31362 L
.70261 .16187 L
s
.678 .847 .902 r
.70261 .16187 m
.70261 .31379 L
.70284 .31379 L
.70284 .16187 L
F
.2 .63 .79 r
.70261 .16187 m
.70261 .31379 L
.70284 .31379 L
.70284 .16187 L
s
.678 .847 .902 r
.70284 .16187 m
.70284 .31429 L
.70331 .31429 L
.70331 .16187 L
F
.2 .63 .79 r
.70284 .16187 m
.70284 .31429 L
.70331 .31429 L
.70331 .16187 L
s
.678 .847 .902 r
.70331 .16187 m
.70331 .31462 L
.7038 .31462 L
.7038 .16187 L
F
.2 .63 .79 r
.70331 .16187 m
.70331 .31462 L
.7038 .31462 L
.7038 .16187 L
s
.678 .847 .902 r
.7038 .16187 m
.7038 .31507 L
.70414 .31507 L
.70414 .16187 L
F
.2 .63 .79 r
.7038 .16187 m
.7038 .31507 L
.70414 .31507 L
.70414 .16187 L
s
.678 .847 .902 r
.70414 .16187 m
.70414 .31556 L
.70475 .31556 L
.70475 .16187 L
F
.2 .63 .79 r
.70414 .16187 m
.70414 .31556 L
.70475 .31556 L
.70475 .16187 L
s
.678 .847 .902 r
.70475 .16187 m
.70475 .31563 L
.70522 .31563 L
.70522 .16187 L
F
.2 .63 .79 r
.70475 .16187 m
.70475 .31563 L
.70522 .31563 L
.70522 .16187 L
s
.678 .847 .902 r
.70522 .16187 m
.70522 .31614 L
.70582 .31614 L
.70582 .16187 L
F
.2 .63 .79 r
.70522 .16187 m
.70522 .31614 L
.70582 .31614 L
.70582 .16187 L
s
.678 .847 .902 r
.70582 .16187 m
.70582 .31669 L
.70625 .31669 L
.70625 .16187 L
F
.2 .63 .79 r
.70582 .16187 m
.70582 .31669 L
.70625 .31669 L
.70625 .16187 L
s
.678 .847 .902 r
.70625 .16187 m
.70625 .31703 L
.70645 .31703 L
.70645 .16187 L
F
.2 .63 .79 r
.70625 .16187 m
.70625 .31703 L
.70645 .31703 L
.70645 .16187 L
s
.678 .847 .902 r
.70645 .16187 m
.70645 .31728 L
.70668 .31728 L
.70668 .16187 L
F
.2 .63 .79 r
.70645 .16187 m
.70645 .31728 L
.70668 .31728 L
.70668 .16187 L
s
.678 .847 .902 r
.70668 .16187 m
.70668 .31748 L
.70701 .31748 L
.70701 .16187 L
F
.2 .63 .79 r
.70668 .16187 m
.70668 .31748 L
.70701 .31748 L
.70701 .16187 L
s
.678 .847 .902 r
.70701 .16187 m
.70701 .31782 L
.70732 .31782 L
.70732 .16187 L
F
.2 .63 .79 r
.70701 .16187 m
.70701 .31782 L
.70732 .31782 L
.70732 .16187 L
s
.678 .847 .902 r
.70732 .16187 m
.70732 .31796 L
.70759 .31796 L
.70759 .16187 L
F
.2 .63 .79 r
.70732 .16187 m
.70732 .31796 L
.70759 .31796 L
.70759 .16187 L
s
.678 .847 .902 r
.70759 .16187 m
.70759 .31836 L
.708 .31836 L
.708 .16187 L
F
.2 .63 .79 r
.70759 .16187 m
.70759 .31836 L
.708 .31836 L
.708 .16187 L
s
.678 .847 .902 r
.708 .16187 m
.708 .31882 L
.70845 .31882 L
.70845 .16187 L
F
.2 .63 .79 r
.708 .16187 m
.708 .31882 L
.70845 .31882 L
.70845 .16187 L
s
.678 .847 .902 r
.70845 .16187 m
.70845 .31922 L
.70896 .31922 L
.70896 .16187 L
F
.2 .63 .79 r
.70845 .16187 m
.70845 .31922 L
.70896 .31922 L
.70896 .16187 L
s
.678 .847 .902 r
.70896 .16187 m
.70896 .31964 L
.70932 .31964 L
.70932 .16187 L
F
.2 .63 .79 r
.70896 .16187 m
.70896 .31964 L
.70932 .31964 L
.70932 .16187 L
s
.678 .847 .902 r
.70932 .16187 m
.70932 .31967 L
.70972 .31967 L
.70972 .16187 L
F
.2 .63 .79 r
.70932 .16187 m
.70932 .31967 L
.70972 .31967 L
.70972 .16187 L
s
.678 .847 .902 r
.70972 .16187 m
.70972 .32028 L
.71001 .32028 L
.71001 .16187 L
F
.2 .63 .79 r
.70972 .16187 m
.70972 .32028 L
.71001 .32028 L
.71001 .16187 L
s
.678 .847 .902 r
.71001 .16187 m
.71001 .32052 L
.71032 .32052 L
.71032 .16187 L
F
.2 .63 .79 r
.71001 .16187 m
.71001 .32052 L
.71032 .32052 L
.71032 .16187 L
s
.678 .847 .902 r
.71032 .16187 m
.71032 .32061 L
.71056 .32061 L
.71056 .16187 L
F
.2 .63 .79 r
.71032 .16187 m
.71032 .32061 L
.71056 .32061 L
.71056 .16187 L
s
.678 .847 .902 r
.71056 .16187 m
.71056 .32098 L
.71104 .32098 L
.71104 .16187 L
F
.2 .63 .79 r
.71056 .16187 m
.71056 .32098 L
.71104 .32098 L
.71104 .16187 L
s
.678 .847 .902 r
.71104 .16187 m
.71104 .32162 L
.71155 .32162 L
.71155 .16187 L
F
.2 .63 .79 r
.71104 .16187 m
.71104 .32162 L
.71155 .32162 L
.71155 .16187 L
s
.678 .847 .902 r
.71155 .16187 m
.71155 .32169 L
.71193 .32169 L
.71193 .16187 L
F
.2 .63 .79 r
.71155 .16187 m
.71155 .32169 L
.71193 .32169 L
.71193 .16187 L
s
.678 .847 .902 r
.71193 .16187 m
.71193 .32216 L
.71213 .32216 L
.71213 .16187 L
F
.2 .63 .79 r
.71193 .16187 m
.71193 .32216 L
.71213 .32216 L
.71213 .16187 L
s
.678 .847 .902 r
.71213 .16187 m
.71213 .32228 L
.71233 .32228 L
.71233 .16187 L
F
.2 .63 .79 r
.71213 .16187 m
.71213 .32228 L
.71233 .32228 L
.71233 .16187 L
s
.678 .847 .902 r
.71233 .16187 m
.71233 .32241 L
.71255 .32241 L
.71255 .16187 L
F
.2 .63 .79 r
.71233 .16187 m
.71233 .32241 L
.71255 .32241 L
.71255 .16187 L
s
.678 .847 .902 r
.71255 .16187 m
.71255 .32257 L
.71278 .32257 L
.71278 .16187 L
F
.2 .63 .79 r
.71255 .16187 m
.71255 .32257 L
.71278 .32257 L
.71278 .16187 L
s
.678 .847 .902 r
.71278 .16187 m
.71278 .32276 L
.71301 .32276 L
.71301 .16187 L
F
.2 .63 .79 r
.71278 .16187 m
.71278 .32276 L
.71301 .32276 L
.71301 .16187 L
s
.678 .847 .902 r
.71301 .16187 m
.71301 .32314 L
.71338 .32314 L
.71338 .16187 L
F
.2 .63 .79 r
.71301 .16187 m
.71301 .32314 L
.71338 .32314 L
.71338 .16187 L
s
.678 .847 .902 r
.71338 .16187 m
.71338 .3233 L
.71363 .3233 L
.71363 .16187 L
F
.2 .63 .79 r
.71338 .16187 m
.71338 .3233 L
.71363 .3233 L
.71363 .16187 L
s
.678 .847 .902 r
.71363 .16187 m
.71363 .32381 L
.71407 .32381 L
.71407 .16187 L
F
.2 .63 .79 r
.71363 .16187 m
.71363 .32381 L
.71407 .32381 L
.71407 .16187 L
s
.678 .847 .902 r
.71407 .16187 m
.71407 .32401 L
.71429 .32401 L
.71429 .16187 L
F
.2 .63 .79 r
.71407 .16187 m
.71407 .32401 L
.71429 .32401 L
.71429 .16187 L
s
.678 .847 .902 r
.71429 .16187 m
.71429 .32433 L
.71462 .32433 L
.71462 .16187 L
F
.2 .63 .79 r
.71429 .16187 m
.71429 .32433 L
.71462 .32433 L
.71462 .16187 L
s
.678 .847 .902 r
.71462 .16187 m
.71462 .32466 L
.71518 .32466 L
.71518 .16187 L
F
.2 .63 .79 r
.71462 .16187 m
.71462 .32466 L
.71518 .32466 L
.71518 .16187 L
s
.678 .847 .902 r
.71518 .16187 m
.71518 .32491 L
.7155 .32491 L
.7155 .16187 L
F
.2 .63 .79 r
.71518 .16187 m
.71518 .32491 L
.7155 .32491 L
.7155 .16187 L
s
.678 .847 .902 r
.7155 .16187 m
.7155 .32532 L
.71608 .32532 L
.71608 .16187 L
F
.2 .63 .79 r
.7155 .16187 m
.7155 .32532 L
.71608 .32532 L
.71608 .16187 L
s
.678 .847 .902 r
.71608 .16187 m
.71608 .32577 L
.71665 .32577 L
.71665 .16187 L
F
.2 .63 .79 r
.71608 .16187 m
.71608 .32577 L
.71665 .32577 L
.71665 .16187 L
s
.678 .847 .902 r
.71665 .16187 m
.71665 .32641 L
.71695 .32641 L
.71695 .16187 L
F
.2 .63 .79 r
.71665 .16187 m
.71665 .32641 L
.71695 .32641 L
.71695 .16187 L
s
.678 .847 .902 r
.71695 .16187 m
.71695 .32661 L
.7174 .32661 L
.7174 .16187 L
F
.2 .63 .79 r
.71695 .16187 m
.71695 .32661 L
.7174 .32661 L
.7174 .16187 L
s
.678 .847 .902 r
.7174 .16187 m
.7174 .32702 L
.71781 .32702 L
.71781 .16187 L
F
.2 .63 .79 r
.7174 .16187 m
.7174 .32702 L
.71781 .32702 L
.71781 .16187 L
s
.678 .847 .902 r
.71781 .16187 m
.71781 .3273 L
.71816 .3273 L
.71816 .16187 L
F
.2 .63 .79 r
.71781 .16187 m
.71781 .3273 L
.71816 .3273 L
.71816 .16187 L
s
.678 .847 .902 r
.71816 .16187 m
.71816 .32772 L
.71837 .32772 L
.71837 .16187 L
F
.2 .63 .79 r
.71816 .16187 m
.71816 .32772 L
.71837 .32772 L
.71837 .16187 L
s
.678 .847 .902 r
.71837 .16187 m
.71837 .32789 L
.7187 .32789 L
.7187 .16187 L
F
.2 .63 .79 r
.71837 .16187 m
.71837 .32789 L
.7187 .32789 L
.7187 .16187 L
s
.678 .847 .902 r
.7187 .16187 m
.7187 .3281 L
.71906 .3281 L
.71906 .16187 L
F
.2 .63 .79 r
.7187 .16187 m
.7187 .3281 L
.71906 .3281 L
.71906 .16187 L
s
.678 .847 .902 r
.71906 .16187 m
.71906 .32868 L
.71957 .32868 L
.71957 .16187 L
F
.2 .63 .79 r
.71906 .16187 m
.71906 .32868 L
.71957 .32868 L
.71957 .16187 L
s
.678 .847 .902 r
.71957 .16187 m
.71957 .3291 L
.71991 .3291 L
.71991 .16187 L
F
.2 .63 .79 r
.71957 .16187 m
.71957 .3291 L
.71991 .3291 L
.71991 .16187 L
s
.678 .847 .902 r
.71991 .16187 m
.71991 .32933 L
.7205 .32933 L
.7205 .16187 L
F
.2 .63 .79 r
.71991 .16187 m
.71991 .32933 L
.7205 .32933 L
.7205 .16187 L
s
.678 .847 .902 r
.7205 .16187 m
.7205 .32973 L
.72085 .32973 L
.72085 .16187 L
F
.2 .63 .79 r
.7205 .16187 m
.7205 .32973 L
.72085 .32973 L
.72085 .16187 L
s
.678 .847 .902 r
.72085 .16187 m
.72085 .33002 L
.72135 .33002 L
.72135 .16187 L
F
.2 .63 .79 r
.72085 .16187 m
.72085 .33002 L
.72135 .33002 L
.72135 .16187 L
s
.678 .847 .902 r
.72135 .16187 m
.72135 .33061 L
.72166 .33061 L
.72166 .16187 L
F
.2 .63 .79 r
.72135 .16187 m
.72135 .33061 L
.72166 .33061 L
.72166 .16187 L
s
.678 .847 .902 r
.72166 .16187 m
.72166 .33086 L
.72221 .33086 L
.72221 .16187 L
F
.2 .63 .79 r
.72166 .16187 m
.72166 .33086 L
.72221 .33086 L
.72221 .16187 L
s
.678 .847 .902 r
.72221 .16187 m
.72221 .33127 L
.72252 .33127 L
.72252 .16187 L
F
.2 .63 .79 r
.72221 .16187 m
.72221 .33127 L
.72252 .33127 L
.72252 .16187 L
s
.678 .847 .902 r
.72252 .16187 m
.72252 .33166 L
.72285 .33166 L
.72285 .16187 L
F
.2 .63 .79 r
.72252 .16187 m
.72252 .33166 L
.72285 .33166 L
.72285 .16187 L
s
.678 .847 .902 r
.72285 .16187 m
.72285 .33192 L
.72309 .33192 L
.72309 .16187 L
F
.2 .63 .79 r
.72285 .16187 m
.72285 .33192 L
.72309 .33192 L
.72309 .16187 L
s
.678 .847 .902 r
.72309 .16187 m
.72309 .33218 L
.7234 .33218 L
.7234 .16187 L
F
.2 .63 .79 r
.72309 .16187 m
.72309 .33218 L
.7234 .33218 L
.7234 .16187 L
s
.678 .847 .902 r
.7234 .16187 m
.7234 .33247 L
.72368 .33247 L
.72368 .16187 L
F
.2 .63 .79 r
.7234 .16187 m
.7234 .33247 L
.72368 .33247 L
.72368 .16187 L
s
.678 .847 .902 r
.72368 .16187 m
.72368 .33299 L
.72432 .33299 L
.72432 .16187 L
F
.2 .63 .79 r
.72368 .16187 m
.72368 .33299 L
.72432 .33299 L
.72432 .16187 L
s
.678 .847 .902 r
.72432 .16187 m
.72432 .33343 L
.72464 .33343 L
.72464 .16187 L
F
.2 .63 .79 r
.72432 .16187 m
.72432 .33343 L
.72464 .33343 L
.72464 .16187 L
s
.678 .847 .902 r
.72464 .16187 m
.72464 .3337 L
.72527 .3337 L
.72527 .16187 L
F
.2 .63 .79 r
.72464 .16187 m
.72464 .3337 L
.72527 .3337 L
.72527 .16187 L
s
.678 .847 .902 r
.72527 .16187 m
.72527 .33412 L
.7256 .33412 L
.7256 .16187 L
F
.2 .63 .79 r
.72527 .16187 m
.72527 .33412 L
.7256 .33412 L
.7256 .16187 L
s
.678 .847 .902 r
.7256 .16187 m
.7256 .33447 L
.72587 .33447 L
.72587 .16187 L
F
.2 .63 .79 r
.7256 .16187 m
.7256 .33447 L
.72587 .33447 L
.72587 .16187 L
s
.678 .847 .902 r
.72587 .16187 m
.72587 .33461 L
.72607 .33461 L
.72607 .16187 L
F
.2 .63 .79 r
.72587 .16187 m
.72587 .33461 L
.72607 .33461 L
.72607 .16187 L
s
.678 .847 .902 r
.72607 .16187 m
.72607 .3348 L
.72645 .3348 L
.72645 .16187 L
F
.2 .63 .79 r
.72607 .16187 m
.72607 .3348 L
.72645 .3348 L
.72645 .16187 L
s
.678 .847 .902 r
.72645 .16187 m
.72645 .33559 L
.727 .33559 L
.727 .16187 L
F
.2 .63 .79 r
.72645 .16187 m
.72645 .33559 L
.727 .33559 L
.727 .16187 L
s
.678 .847 .902 r
.727 .16187 m
.727 .33586 L
.72756 .33586 L
.72756 .16187 L
F
.2 .63 .79 r
.727 .16187 m
.727 .33586 L
.72756 .33586 L
.72756 .16187 L
s
.678 .847 .902 r
.72756 .16187 m
.72756 .3364 L
.72819 .3364 L
.72819 .16187 L
F
.2 .63 .79 r
.72756 .16187 m
.72756 .3364 L
.72819 .3364 L
.72819 .16187 L
s
.678 .847 .902 r
.72819 .16187 m
.72819 .33685 L
.72843 .33685 L
.72843 .16187 L
F
.2 .63 .79 r
.72819 .16187 m
.72819 .33685 L
.72843 .33685 L
.72843 .16187 L
s
.678 .847 .902 r
.72843 .16187 m
.72843 .33722 L
.72881 .33722 L
.72881 .16187 L
F
.2 .63 .79 r
.72843 .16187 m
.72843 .33722 L
.72881 .33722 L
.72881 .16187 L
s
.678 .847 .902 r
.72881 .16187 m
.72881 .33745 L
.72905 .33745 L
.72905 .16187 L
F
.2 .63 .79 r
.72881 .16187 m
.72881 .33745 L
.72905 .33745 L
.72905 .16187 L
s
.678 .847 .902 r
.72905 .16187 m
.72905 .33779 L
.72954 .33779 L
.72954 .16187 L
F
.2 .63 .79 r
.72905 .16187 m
.72905 .33779 L
.72954 .33779 L
.72954 .16187 L
s
.678 .847 .902 r
.72954 .16187 m
.72954 .33803 L
.72982 .33803 L
.72982 .16187 L
F
.2 .63 .79 r
.72954 .16187 m
.72954 .33803 L
.72982 .33803 L
.72982 .16187 L
s
.678 .847 .902 r
.72982 .16187 m
.72982 .33833 L
.73004 .33833 L
.73004 .16187 L
F
.2 .63 .79 r
.72982 .16187 m
.72982 .33833 L
.73004 .33833 L
.73004 .16187 L
s
.678 .847 .902 r
.73004 .16187 m
.73004 .33868 L
.73042 .33868 L
.73042 .16187 L
F
.2 .63 .79 r
.73004 .16187 m
.73004 .33868 L
.73042 .33868 L
.73042 .16187 L
s
.678 .847 .902 r
.73042 .16187 m
.73042 .33879 L
.73079 .33879 L
.73079 .16187 L
F
.2 .63 .79 r
.73042 .16187 m
.73042 .33879 L
.73079 .33879 L
.73079 .16187 L
s
.678 .847 .902 r
.73079 .16187 m
.73079 .33914 L
.73116 .33914 L
.73116 .16187 L
F
.2 .63 .79 r
.73079 .16187 m
.73079 .33914 L
.73116 .33914 L
.73116 .16187 L
s
.678 .847 .902 r
.73116 .16187 m
.73116 .33974 L
.73171 .33974 L
.73171 .16187 L
F
.2 .63 .79 r
.73116 .16187 m
.73116 .33974 L
.73171 .33974 L
.73171 .16187 L
s
.678 .847 .902 r
.73171 .16187 m
.73171 .34 L
.73195 .34 L
.73195 .16187 L
F
.2 .63 .79 r
.73171 .16187 m
.73171 .34 L
.73195 .34 L
.73195 .16187 L
s
.678 .847 .902 r
.73195 .16187 m
.73195 .34036 L
.73227 .34036 L
.73227 .16187 L
F
.2 .63 .79 r
.73195 .16187 m
.73195 .34036 L
.73227 .34036 L
.73227 .16187 L
s
.678 .847 .902 r
.73227 .16187 m
.73227 .3406 L
.73252 .3406 L
.73252 .16187 L
F
.2 .63 .79 r
.73227 .16187 m
.73227 .3406 L
.73252 .3406 L
.73252 .16187 L
s
.678 .847 .902 r
.73252 .16187 m
.73252 .3407 L
.73299 .3407 L
.73299 .16187 L
F
.2 .63 .79 r
.73252 .16187 m
.73252 .3407 L
.73299 .3407 L
.73299 .16187 L
s
.678 .847 .902 r
.73299 .16187 m
.73299 .34124 L
.73322 .34124 L
.73322 .16187 L
F
.2 .63 .79 r
.73299 .16187 m
.73299 .34124 L
.73322 .34124 L
.73322 .16187 L
s
.678 .847 .902 r
.73322 .16187 m
.73322 .34145 L
.73342 .34145 L
.73342 .16187 L
F
.2 .63 .79 r
.73322 .16187 m
.73322 .34145 L
.73342 .34145 L
.73342 .16187 L
s
.678 .847 .902 r
.73342 .16187 m
.73342 .34155 L
.73367 .34155 L
.73367 .16187 L
F
.2 .63 .79 r
.73342 .16187 m
.73342 .34155 L
.73367 .34155 L
.73367 .16187 L
s
.678 .847 .902 r
.73367 .16187 m
.73367 .34195 L
.734 .34195 L
.734 .16187 L
F
.2 .63 .79 r
.73367 .16187 m
.73367 .34195 L
.734 .34195 L
.734 .16187 L
s
.678 .847 .902 r
.734 .16187 m
.734 .34207 L
.73461 .34207 L
.73461 .16187 L
F
.2 .63 .79 r
.734 .16187 m
.734 .34207 L
.73461 .34207 L
.73461 .16187 L
s
.678 .847 .902 r
.73461 .16187 m
.73461 .34293 L
.73523 .34293 L
.73523 .16187 L
F
.2 .63 .79 r
.73461 .16187 m
.73461 .34293 L
.73523 .34293 L
.73523 .16187 L
s
.678 .847 .902 r
.73523 .16187 m
.73523 .34323 L
.73575 .34323 L
.73575 .16187 L
F
.2 .63 .79 r
.73523 .16187 m
.73523 .34323 L
.73575 .34323 L
.73575 .16187 L
s
.678 .847 .902 r
.73575 .16187 m
.73575 .34394 L
.73617 .34394 L
.73617 .16187 L
F
.2 .63 .79 r
.73575 .16187 m
.73575 .34394 L
.73617 .34394 L
.73617 .16187 L
s
.678 .847 .902 r
.73617 .16187 m
.73617 .34415 L
.73641 .34415 L
.73641 .16187 L
F
.2 .63 .79 r
.73617 .16187 m
.73617 .34415 L
.73641 .34415 L
.73641 .16187 L
s
.678 .847 .902 r
.73641 .16187 m
.73641 .34431 L
.73704 .34431 L
.73704 .16187 L
F
.2 .63 .79 r
.73641 .16187 m
.73641 .34431 L
.73704 .34431 L
.73704 .16187 L
s
.678 .847 .902 r
.73704 .16187 m
.73704 .345 L
.73751 .345 L
.73751 .16187 L
F
.2 .63 .79 r
.73704 .16187 m
.73704 .345 L
.73751 .345 L
.73751 .16187 L
s
.678 .847 .902 r
.73751 .16187 m
.73751 .34545 L
.73774 .34545 L
.73774 .16187 L
F
.2 .63 .79 r
.73751 .16187 m
.73751 .34545 L
.73774 .34545 L
.73774 .16187 L
s
.678 .847 .902 r
.73774 .16187 m
.73774 .3456 L
.73794 .3456 L
.73794 .16187 L
F
.2 .63 .79 r
.73774 .16187 m
.73774 .3456 L
.73794 .3456 L
.73794 .16187 L
s
.678 .847 .902 r
.73794 .16187 m
.73794 .34578 L
.73826 .34578 L
.73826 .16187 L
F
.2 .63 .79 r
.73794 .16187 m
.73794 .34578 L
.73826 .34578 L
.73826 .16187 L
s
.678 .847 .902 r
.73826 .16187 m
.73826 .3463 L
.73864 .3463 L
.73864 .16187 L
F
.2 .63 .79 r
.73826 .16187 m
.73826 .3463 L
.73864 .3463 L
.73864 .16187 L
s
.678 .847 .902 r
.73864 .16187 m
.73864 .34634 L
.73884 .34634 L
.73884 .16187 L
F
.2 .63 .79 r
.73864 .16187 m
.73864 .34634 L
.73884 .34634 L
.73884 .16187 L
s
.678 .847 .902 r
.73884 .16187 m
.73884 .34684 L
.7393 .34684 L
.7393 .16187 L
F
.2 .63 .79 r
.73884 .16187 m
.73884 .34684 L
.7393 .34684 L
.7393 .16187 L
s
.678 .847 .902 r
.7393 .16187 m
.7393 .34703 L
.73989 .34703 L
.73989 .16187 L
F
.2 .63 .79 r
.7393 .16187 m
.7393 .34703 L
.73989 .34703 L
.73989 .16187 L
s
.678 .847 .902 r
.73989 .16187 m
.73989 .34761 L
.74009 .34761 L
.74009 .16187 L
F
.2 .63 .79 r
.73989 .16187 m
.73989 .34761 L
.74009 .34761 L
.74009 .16187 L
s
.678 .847 .902 r
.74009 .16187 m
.74009 .34779 L
.74037 .34779 L
.74037 .16187 L
F
.2 .63 .79 r
.74009 .16187 m
.74009 .34779 L
.74037 .34779 L
.74037 .16187 L
s
.678 .847 .902 r
.74037 .16187 m
.74037 .34808 L
.74079 .34808 L
.74079 .16187 L
F
.2 .63 .79 r
.74037 .16187 m
.74037 .34808 L
.74079 .34808 L
.74079 .16187 L
s
.678 .847 .902 r
.74079 .16187 m
.74079 .3485 L
.74125 .3485 L
.74125 .16187 L
F
.2 .63 .79 r
.74079 .16187 m
.74079 .3485 L
.74125 .3485 L
.74125 .16187 L
s
.678 .847 .902 r
.74125 .16187 m
.74125 .34877 L
.74183 .34877 L
.74183 .16187 L
F
.2 .63 .79 r
.74125 .16187 m
.74125 .34877 L
.74183 .34877 L
.74183 .16187 L
s
.678 .847 .902 r
.74183 .16187 m
.74183 .34945 L
.7423 .34945 L
.7423 .16187 L
F
.2 .63 .79 r
.74183 .16187 m
.74183 .34945 L
.7423 .34945 L
.7423 .16187 L
s
.678 .847 .902 r
.7423 .16187 m
.7423 .34996 L
.74267 .34996 L
.74267 .16187 L
F
.2 .63 .79 r
.7423 .16187 m
.7423 .34996 L
.74267 .34996 L
.74267 .16187 L
s
.678 .847 .902 r
.74267 .16187 m
.74267 .35032 L
.74313 .35032 L
.74313 .16187 L
F
.2 .63 .79 r
.74267 .16187 m
.74267 .35032 L
.74313 .35032 L
.74313 .16187 L
s
.678 .847 .902 r
.74313 .16187 m
.74313 .35085 L
.74364 .35085 L
.74364 .16187 L
F
.2 .63 .79 r
.74313 .16187 m
.74313 .35085 L
.74364 .35085 L
.74364 .16187 L
s
.678 .847 .902 r
.74364 .16187 m
.74364 .35116 L
.74397 .35116 L
.74397 .16187 L
F
.2 .63 .79 r
.74364 .16187 m
.74364 .35116 L
.74397 .35116 L
.74397 .16187 L
s
.678 .847 .902 r
.74397 .16187 m
.74397 .3515 L
.74437 .3515 L
.74437 .16187 L
F
.2 .63 .79 r
.74397 .16187 m
.74397 .3515 L
.74437 .3515 L
.74437 .16187 L
s
.678 .847 .902 r
.74437 .16187 m
.74437 .35209 L
.74484 .35209 L
.74484 .16187 L
F
.2 .63 .79 r
.74437 .16187 m
.74437 .35209 L
.74484 .35209 L
.74484 .16187 L
s
.678 .847 .902 r
.74484 .16187 m
.74484 .35246 L
.74548 .35246 L
.74548 .16187 L
F
.2 .63 .79 r
.74484 .16187 m
.74484 .35246 L
.74548 .35246 L
.74548 .16187 L
s
.678 .847 .902 r
.74548 .16187 m
.74548 .3531 L
.74603 .3531 L
.74603 .16187 L
F
.2 .63 .79 r
.74548 .16187 m
.74548 .3531 L
.74603 .3531 L
.74603 .16187 L
s
.678 .847 .902 r
.74603 .16187 m
.74603 .35321 L
.74638 .35321 L
.74638 .16187 L
F
.2 .63 .79 r
.74603 .16187 m
.74603 .35321 L
.74638 .35321 L
.74638 .16187 L
s
.678 .847 .902 r
.74638 .16187 m
.74638 .35392 L
.74686 .35392 L
.74686 .16187 L
F
.2 .63 .79 r
.74638 .16187 m
.74638 .35392 L
.74686 .35392 L
.74686 .16187 L
s
.678 .847 .902 r
.74686 .16187 m
.74686 .35405 L
.74721 .35405 L
.74721 .16187 L
F
.2 .63 .79 r
.74686 .16187 m
.74686 .35405 L
.74721 .35405 L
.74721 .16187 L
s
.678 .847 .902 r
.74721 .16187 m
.74721 .35475 L
.74773 .35475 L
.74773 .16187 L
F
.2 .63 .79 r
.74721 .16187 m
.74721 .35475 L
.74773 .35475 L
.74773 .16187 L
s
.678 .847 .902 r
.74773 .16187 m
.74773 .35491 L
.74807 .35491 L
.74807 .16187 L
F
.2 .63 .79 r
.74773 .16187 m
.74773 .35491 L
.74807 .35491 L
.74807 .16187 L
s
.678 .847 .902 r
.74807 .16187 m
.74807 .35527 L
.74841 .35527 L
.74841 .16187 L
F
.2 .63 .79 r
.74807 .16187 m
.74807 .35527 L
.74841 .35527 L
.74841 .16187 L
s
.678 .847 .902 r
.74841 .16187 m
.74841 .35558 L
.74903 .35558 L
.74903 .16187 L
F
.2 .63 .79 r
.74841 .16187 m
.74841 .35558 L
.74903 .35558 L
.74903 .16187 L
s
.678 .847 .902 r
.74903 .16187 m
.74903 .35638 L
.74954 .35638 L
.74954 .16187 L
F
.2 .63 .79 r
.74903 .16187 m
.74903 .35638 L
.74954 .35638 L
.74954 .16187 L
s
.678 .847 .902 r
.74954 .16187 m
.74954 .35676 L
.75006 .35676 L
.75006 .16187 L
F
.2 .63 .79 r
.74954 .16187 m
.74954 .35676 L
.75006 .35676 L
.75006 .16187 L
s
.678 .847 .902 r
.75006 .16187 m
.75006 .35709 L
.75045 .35709 L
.75045 .16187 L
F
.2 .63 .79 r
.75006 .16187 m
.75006 .35709 L
.75045 .35709 L
.75045 .16187 L
s
.678 .847 .902 r
.75045 .16187 m
.75045 .35762 L
.75106 .35762 L
.75106 .16187 L
F
.2 .63 .79 r
.75045 .16187 m
.75045 .35762 L
.75106 .35762 L
.75106 .16187 L
s
.678 .847 .902 r
.75106 .16187 m
.75106 .35804 L
.75148 .35804 L
.75148 .16187 L
F
.2 .63 .79 r
.75106 .16187 m
.75106 .35804 L
.75148 .35804 L
.75148 .16187 L
s
.678 .847 .902 r
.75148 .16187 m
.75148 .35836 L
.75176 .35836 L
.75176 .16187 L
F
.2 .63 .79 r
.75148 .16187 m
.75148 .35836 L
.75176 .35836 L
.75176 .16187 L
s
.678 .847 .902 r
.75176 .16187 m
.75176 .35905 L
.75233 .35905 L
.75233 .16187 L
F
.2 .63 .79 r
.75176 .16187 m
.75176 .35905 L
.75233 .35905 L
.75233 .16187 L
s
.678 .847 .902 r
.75233 .16187 m
.75233 .35922 L
.75255 .35922 L
.75255 .16187 L
F
.2 .63 .79 r
.75233 .16187 m
.75233 .35922 L
.75255 .35922 L
.75255 .16187 L
s
.678 .847 .902 r
.75255 .16187 m
.75255 .35983 L
.75315 .35983 L
.75315 .16187 L
F
.2 .63 .79 r
.75255 .16187 m
.75255 .35983 L
.75315 .35983 L
.75315 .16187 L
s
.678 .847 .902 r
.75315 .16187 m
.75315 .36013 L
.7537 .36013 L
.7537 .16187 L
F
.2 .63 .79 r
.75315 .16187 m
.75315 .36013 L
.7537 .36013 L
.7537 .16187 L
s
.678 .847 .902 r
.7537 .16187 m
.7537 .3605 L
.754 .3605 L
.754 .16187 L
F
.2 .63 .79 r
.7537 .16187 m
.7537 .3605 L
.754 .3605 L
.754 .16187 L
s
.678 .847 .902 r
.754 .16187 m
.754 .36093 L
.75435 .36093 L
.75435 .16187 L
F
.2 .63 .79 r
.754 .16187 m
.754 .36093 L
.75435 .36093 L
.75435 .16187 L
s
.678 .847 .902 r
.75435 .16187 m
.75435 .36115 L
.75481 .36115 L
.75481 .16187 L
F
.2 .63 .79 r
.75435 .16187 m
.75435 .36115 L
.75481 .36115 L
.75481 .16187 L
s
.678 .847 .902 r
.75481 .16187 m
.75481 .36174 L
.75514 .36174 L
.75514 .16187 L
F
.2 .63 .79 r
.75481 .16187 m
.75481 .36174 L
.75514 .36174 L
.75514 .16187 L
s
.678 .847 .902 r
.75514 .16187 m
.75514 .36191 L
.75562 .36191 L
.75562 .16187 L
F
.2 .63 .79 r
.75514 .16187 m
.75514 .36191 L
.75562 .36191 L
.75562 .16187 L
s
.678 .847 .902 r
.75562 .16187 m
.75562 .36225 L
.75596 .36225 L
.75596 .16187 L
F
.2 .63 .79 r
.75562 .16187 m
.75562 .36225 L
.75596 .36225 L
.75596 .16187 L
s
.678 .847 .902 r
.75596 .16187 m
.75596 .3628 L
.75651 .3628 L
.75651 .16187 L
F
.2 .63 .79 r
.75596 .16187 m
.75596 .3628 L
.75651 .3628 L
.75651 .16187 L
s
.678 .847 .902 r
.75651 .16187 m
.75651 .36356 L
.75713 .36356 L
.75713 .16187 L
F
.2 .63 .79 r
.75651 .16187 m
.75651 .36356 L
.75713 .36356 L
.75713 .16187 L
s
.678 .847 .902 r
.75713 .16187 m
.75713 .36391 L
.75777 .36391 L
.75777 .16187 L
F
.2 .63 .79 r
.75713 .16187 m
.75713 .36391 L
.75777 .36391 L
.75777 .16187 L
s
.678 .847 .902 r
.75777 .16187 m
.75777 .36477 L
.7584 .36477 L
.7584 .16187 L
F
.2 .63 .79 r
.75777 .16187 m
.75777 .36477 L
.7584 .36477 L
.7584 .16187 L
s
.678 .847 .902 r
.7584 .16187 m
.7584 .365 L
.75862 .365 L
.75862 .16187 L
F
.2 .63 .79 r
.7584 .16187 m
.7584 .365 L
.75862 .365 L
.75862 .16187 L
s
.678 .847 .902 r
.75862 .16187 m
.75862 .3653 L
.75909 .3653 L
.75909 .16187 L
F
.2 .63 .79 r
.75862 .16187 m
.75862 .3653 L
.75909 .3653 L
.75909 .16187 L
s
.678 .847 .902 r
.75909 .16187 m
.75909 .36596 L
.75957 .36596 L
.75957 .16187 L
F
.2 .63 .79 r
.75909 .16187 m
.75909 .36596 L
.75957 .36596 L
.75957 .16187 L
s
.678 .847 .902 r
.75957 .16187 m
.75957 .36612 L
.75978 .36612 L
.75978 .16187 L
F
.2 .63 .79 r
.75957 .16187 m
.75957 .36612 L
.75978 .36612 L
.75978 .16187 L
s
.678 .847 .902 r
.75978 .16187 m
.75978 .36647 L
.76013 .36647 L
.76013 .16187 L
F
.2 .63 .79 r
.75978 .16187 m
.75978 .36647 L
.76013 .36647 L
.76013 .16187 L
s
.678 .847 .902 r
.76013 .16187 m
.76013 .36706 L
.76072 .36706 L
.76072 .16187 L
F
.2 .63 .79 r
.76013 .16187 m
.76013 .36706 L
.76072 .36706 L
.76072 .16187 L
s
.678 .847 .902 r
.76072 .16187 m
.76072 .36727 L
.761 .36727 L
.761 .16187 L
F
.2 .63 .79 r
.76072 .16187 m
.76072 .36727 L
.761 .36727 L
.761 .16187 L
s
.678 .847 .902 r
.761 .16187 m
.761 .3674 L
.76124 .3674 L
.76124 .16187 L
F
.2 .63 .79 r
.761 .16187 m
.761 .3674 L
.76124 .3674 L
.76124 .16187 L
s
.678 .847 .902 r
.76124 .16187 m
.76124 .36788 L
.7618 .36788 L
.7618 .16187 L
F
.2 .63 .79 r
.76124 .16187 m
.76124 .36788 L
.7618 .36788 L
.7618 .16187 L
s
.678 .847 .902 r
.7618 .16187 m
.7618 .36852 L
.7623 .36852 L
.7623 .16187 L
F
.2 .63 .79 r
.7618 .16187 m
.7618 .36852 L
.7623 .36852 L
.7623 .16187 L
s
.678 .847 .902 r
.7623 .16187 m
.7623 .36888 L
.76266 .36888 L
.76266 .16187 L
F
.2 .63 .79 r
.7623 .16187 m
.7623 .36888 L
.76266 .36888 L
.76266 .16187 L
s
.678 .847 .902 r
.76266 .16187 m
.76266 .3691 L
.76286 .3691 L
.76286 .16187 L
F
.2 .63 .79 r
.76266 .16187 m
.76266 .3691 L
.76286 .3691 L
.76286 .16187 L
s
.678 .847 .902 r
.76286 .16187 m
.76286 .36953 L
.76347 .36953 L
.76347 .16187 L
F
.2 .63 .79 r
.76286 .16187 m
.76286 .36953 L
.76347 .36953 L
.76347 .16187 L
s
.678 .847 .902 r
.76347 .16187 m
.76347 .36994 L
.76406 .36994 L
.76406 .16187 L
F
.2 .63 .79 r
.76347 .16187 m
.76347 .36994 L
.76406 .36994 L
.76406 .16187 L
s
.678 .847 .902 r
.76406 .16187 m
.76406 .37043 L
.7643 .37043 L
.7643 .16187 L
F
.2 .63 .79 r
.76406 .16187 m
.76406 .37043 L
.7643 .37043 L
.7643 .16187 L
s
.678 .847 .902 r
.7643 .16187 m
.7643 .37056 L
.76479 .37056 L
.76479 .16187 L
F
.2 .63 .79 r
.7643 .16187 m
.7643 .37056 L
.76479 .37056 L
.76479 .16187 L
s
.678 .847 .902 r
.76479 .16187 m
.76479 .37115 L
.76513 .37115 L
.76513 .16187 L
F
.2 .63 .79 r
.76479 .16187 m
.76479 .37115 L
.76513 .37115 L
.76513 .16187 L
s
.678 .847 .902 r
.76513 .16187 m
.76513 .37158 L
.76558 .37158 L
.76558 .16187 L
F
.2 .63 .79 r
.76513 .16187 m
.76513 .37158 L
.76558 .37158 L
.76558 .16187 L
s
.678 .847 .902 r
.76558 .16187 m
.76558 .37187 L
.76598 .37187 L
.76598 .16187 L
F
.2 .63 .79 r
.76558 .16187 m
.76558 .37187 L
.76598 .37187 L
.76598 .16187 L
s
.678 .847 .902 r
.76598 .16187 m
.76598 .37216 L
.76632 .37216 L
.76632 .16187 L
F
.2 .63 .79 r
.76598 .16187 m
.76598 .37216 L
.76632 .37216 L
.76632 .16187 L
s
.678 .847 .902 r
.76632 .16187 m
.76632 .37289 L
.76675 .37289 L
.76675 .16187 L
F
.2 .63 .79 r
.76632 .16187 m
.76632 .37289 L
.76675 .37289 L
.76675 .16187 L
s
.678 .847 .902 r
.76675 .16187 m
.76675 .37325 L
.76721 .37325 L
.76721 .16187 L
F
.2 .63 .79 r
.76675 .16187 m
.76675 .37325 L
.76721 .37325 L
.76721 .16187 L
s
.678 .847 .902 r
.76721 .16187 m
.76721 .3737 L
.76762 .3737 L
.76762 .16187 L
F
.2 .63 .79 r
.76721 .16187 m
.76721 .3737 L
.76762 .3737 L
.76762 .16187 L
s
.678 .847 .902 r
.76762 .16187 m
.76762 .37381 L
.76797 .37381 L
.76797 .16187 L
F
.2 .63 .79 r
.76762 .16187 m
.76762 .37381 L
.76797 .37381 L
.76797 .16187 L
s
.678 .847 .902 r
.76797 .16187 m
.76797 .37425 L
.76837 .37425 L
.76837 .16187 L
F
.2 .63 .79 r
.76797 .16187 m
.76797 .37425 L
.76837 .37425 L
.76837 .16187 L
s
.678 .847 .902 r
.76837 .16187 m
.76837 .37467 L
.76899 .37467 L
.76899 .16187 L
F
.2 .63 .79 r
.76837 .16187 m
.76837 .37467 L
.76899 .37467 L
.76899 .16187 L
s
.678 .847 .902 r
.76899 .16187 m
.76899 .37507 L
.76956 .37507 L
.76956 .16187 L
F
.2 .63 .79 r
.76899 .16187 m
.76899 .37507 L
.76956 .37507 L
.76956 .16187 L
s
.678 .847 .902 r
.76956 .16187 m
.76956 .37583 L
.76989 .37583 L
.76989 .16187 L
F
.2 .63 .79 r
.76956 .16187 m
.76956 .37583 L
.76989 .37583 L
.76989 .16187 L
s
.678 .847 .902 r
.76989 .16187 m
.76989 .3761 L
.77014 .3761 L
.77014 .16187 L
F
.2 .63 .79 r
.76989 .16187 m
.76989 .3761 L
.77014 .3761 L
.77014 .16187 L
s
.678 .847 .902 r
.77014 .16187 m
.77014 .37627 L
.77036 .37627 L
.77036 .16187 L
F
.2 .63 .79 r
.77014 .16187 m
.77014 .37627 L
.77036 .37627 L
.77036 .16187 L
s
.678 .847 .902 r
.77036 .16187 m
.77036 .37658 L
.77083 .37658 L
.77083 .16187 L
F
.2 .63 .79 r
.77036 .16187 m
.77036 .37658 L
.77083 .37658 L
.77083 .16187 L
s
.678 .847 .902 r
.77083 .16187 m
.77083 .37701 L
.77112 .37701 L
.77112 .16187 L
F
.2 .63 .79 r
.77083 .16187 m
.77083 .37701 L
.77112 .37701 L
.77112 .16187 L
s
.678 .847 .902 r
.77112 .16187 m
.77112 .37719 L
.77144 .37719 L
.77144 .16187 L
F
.2 .63 .79 r
.77112 .16187 m
.77112 .37719 L
.77144 .37719 L
.77144 .16187 L
s
.678 .847 .902 r
.77144 .16187 m
.77144 .37767 L
.7718 .37767 L
.7718 .16187 L
F
.2 .63 .79 r
.77144 .16187 m
.77144 .37767 L
.7718 .37767 L
.7718 .16187 L
s
.678 .847 .902 r
.7718 .16187 m
.7718 .37799 L
.77212 .37799 L
.77212 .16187 L
F
.2 .63 .79 r
.7718 .16187 m
.7718 .37799 L
.77212 .37799 L
.77212 .16187 L
s
.678 .847 .902 r
.77212 .16187 m
.77212 .37833 L
.77239 .37833 L
.77239 .16187 L
F
.2 .63 .79 r
.77212 .16187 m
.77212 .37833 L
.77239 .37833 L
.77239 .16187 L
s
.678 .847 .902 r
.77239 .16187 m
.77239 .37855 L
.77274 .37855 L
.77274 .16187 L
F
.2 .63 .79 r
.77239 .16187 m
.77239 .37855 L
.77274 .37855 L
.77274 .16187 L
s
.678 .847 .902 r
.77274 .16187 m
.77274 .37883 L
.77314 .37883 L
.77314 .16187 L
F
.2 .63 .79 r
.77274 .16187 m
.77274 .37883 L
.77314 .37883 L
.77314 .16187 L
s
.678 .847 .902 r
.77314 .16187 m
.77314 .37914 L
.77341 .37914 L
.77341 .16187 L
F
.2 .63 .79 r
.77314 .16187 m
.77314 .37914 L
.77341 .37914 L
.77341 .16187 L
s
.678 .847 .902 r
.77341 .16187 m
.77341 .3797 L
.77383 .3797 L
.77383 .16187 L
F
.2 .63 .79 r
.77341 .16187 m
.77341 .3797 L
.77383 .3797 L
.77383 .16187 L
s
.678 .847 .902 r
.77383 .16187 m
.77383 .37979 L
.77403 .37979 L
.77403 .16187 L
F
.2 .63 .79 r
.77383 .16187 m
.77383 .37979 L
.77403 .37979 L
.77403 .16187 L
s
.678 .847 .902 r
.77403 .16187 m
.77403 .38041 L
.77463 .38041 L
.77463 .16187 L
F
.2 .63 .79 r
.77403 .16187 m
.77403 .38041 L
.77463 .38041 L
.77463 .16187 L
s
.678 .847 .902 r
.77463 .16187 m
.77463 .38098 L
.77513 .38098 L
.77513 .16187 L
F
.2 .63 .79 r
.77463 .16187 m
.77463 .38098 L
.77513 .38098 L
.77513 .16187 L
s
.678 .847 .902 r
.77513 .16187 m
.77513 .38125 L
.7754 .38125 L
.7754 .16187 L
F
.2 .63 .79 r
.77513 .16187 m
.77513 .38125 L
.7754 .38125 L
.7754 .16187 L
s
.678 .847 .902 r
.7754 .16187 m
.7754 .38137 L
.77581 .38137 L
.77581 .16187 L
F
.2 .63 .79 r
.7754 .16187 m
.7754 .38137 L
.77581 .38137 L
.77581 .16187 L
s
.678 .847 .902 r
.77581 .16187 m
.77581 .38169 L
.77614 .38169 L
.77614 .16187 L
F
.2 .63 .79 r
.77581 .16187 m
.77581 .38169 L
.77614 .38169 L
.77614 .16187 L
s
.678 .847 .902 r
.77614 .16187 m
.77614 .38202 L
.77642 .38202 L
.77642 .16187 L
F
.2 .63 .79 r
.77614 .16187 m
.77614 .38202 L
.77642 .38202 L
.77642 .16187 L
s
.678 .847 .902 r
.77642 .16187 m
.77642 .38263 L
.77698 .38263 L
.77698 .16187 L
F
.2 .63 .79 r
.77642 .16187 m
.77642 .38263 L
.77698 .38263 L
.77698 .16187 L
s
.678 .847 .902 r
.77698 .16187 m
.77698 .38298 L
.77718 .38298 L
.77718 .16187 L
F
.2 .63 .79 r
.77698 .16187 m
.77698 .38298 L
.77718 .38298 L
.77718 .16187 L
s
.678 .847 .902 r
.77718 .16187 m
.77718 .38325 L
.77752 .38325 L
.77752 .16187 L
F
.2 .63 .79 r
.77718 .16187 m
.77718 .38325 L
.77752 .38325 L
.77752 .16187 L
s
.678 .847 .902 r
.77752 .16187 m
.77752 .38337 L
.77788 .38337 L
.77788 .16187 L
F
.2 .63 .79 r
.77752 .16187 m
.77752 .38337 L
.77788 .38337 L
.77788 .16187 L
s
.678 .847 .902 r
.77788 .16187 m
.77788 .38412 L
.7783 .38412 L
.7783 .16187 L
F
.2 .63 .79 r
.77788 .16187 m
.77788 .38412 L
.7783 .38412 L
.7783 .16187 L
s
.678 .847 .902 r
.7783 .16187 m
.7783 .38417 L
.77889 .38417 L
.77889 .16187 L
F
.2 .63 .79 r
.7783 .16187 m
.7783 .38417 L
.77889 .38417 L
.77889 .16187 L
s
.678 .847 .902 r
.77889 .16187 m
.77889 .38477 L
.7792 .38477 L
.7792 .16187 L
F
.2 .63 .79 r
.77889 .16187 m
.77889 .38477 L
.7792 .38477 L
.7792 .16187 L
s
.678 .847 .902 r
.7792 .16187 m
.7792 .38532 L
.77972 .38532 L
.77972 .16187 L
F
.2 .63 .79 r
.7792 .16187 m
.7792 .38532 L
.77972 .38532 L
.77972 .16187 L
s
.678 .847 .902 r
.77972 .16187 m
.77972 .38565 L
.78004 .38565 L
.78004 .16187 L
F
.2 .63 .79 r
.77972 .16187 m
.77972 .38565 L
.78004 .38565 L
.78004 .16187 L
s
.678 .847 .902 r
.78004 .16187 m
.78004 .38625 L
.78051 .38625 L
.78051 .16187 L
F
.2 .63 .79 r
.78004 .16187 m
.78004 .38625 L
.78051 .38625 L
.78051 .16187 L
s
.678 .847 .902 r
.78051 .16187 m
.78051 .38661 L
.7811 .38661 L
.7811 .16187 L
F
.2 .63 .79 r
.78051 .16187 m
.78051 .38661 L
.7811 .38661 L
.7811 .16187 L
s
.678 .847 .902 r
.7811 .16187 m
.7811 .38724 L
.78149 .38724 L
.78149 .16187 L
F
.2 .63 .79 r
.7811 .16187 m
.7811 .38724 L
.78149 .38724 L
.78149 .16187 L
s
.678 .847 .902 r
.78149 .16187 m
.78149 .38738 L
.78173 .38738 L
.78173 .16187 L
F
.2 .63 .79 r
.78149 .16187 m
.78149 .38738 L
.78173 .38738 L
.78173 .16187 L
s
.678 .847 .902 r
.78173 .16187 m
.78173 .3876 L
.78204 .3876 L
.78204 .16187 L
F
.2 .63 .79 r
.78173 .16187 m
.78173 .3876 L
.78204 .3876 L
.78204 .16187 L
s
.678 .847 .902 r
.78204 .16187 m
.78204 .38788 L
.78242 .38788 L
.78242 .16187 L
F
.2 .63 .79 r
.78204 .16187 m
.78204 .38788 L
.78242 .38788 L
.78242 .16187 L
s
.678 .847 .902 r
.78242 .16187 m
.78242 .38841 L
.78273 .38841 L
.78273 .16187 L
F
.2 .63 .79 r
.78242 .16187 m
.78242 .38841 L
.78273 .38841 L
.78273 .16187 L
s
.678 .847 .902 r
.78273 .16187 m
.78273 .38879 L
.78319 .38879 L
.78319 .16187 L
F
.2 .63 .79 r
.78273 .16187 m
.78273 .38879 L
.78319 .38879 L
.78319 .16187 L
s
.678 .847 .902 r
.78319 .16187 m
.78319 .38899 L
.7835 .38899 L
.7835 .16187 L
F
.2 .63 .79 r
.78319 .16187 m
.78319 .38899 L
.7835 .38899 L
.7835 .16187 L
s
.678 .847 .902 r
.7835 .16187 m
.7835 .38942 L
.78391 .38942 L
.78391 .16187 L
F
.2 .63 .79 r
.7835 .16187 m
.7835 .38942 L
.78391 .38942 L
.78391 .16187 L
s
.678 .847 .902 r
.78391 .16187 m
.78391 .39003 L
.78436 .39003 L
.78436 .16187 L
F
.2 .63 .79 r
.78391 .16187 m
.78391 .39003 L
.78436 .39003 L
.78436 .16187 L
s
.678 .847 .902 r
.78436 .16187 m
.78436 .39041 L
.78474 .39041 L
.78474 .16187 L
F
.2 .63 .79 r
.78436 .16187 m
.78436 .39041 L
.78474 .39041 L
.78474 .16187 L
s
.678 .847 .902 r
.78474 .16187 m
.78474 .39046 L
.78528 .39046 L
.78528 .16187 L
F
.2 .63 .79 r
.78474 .16187 m
.78474 .39046 L
.78528 .39046 L
.78528 .16187 L
s
.678 .847 .902 r
.78528 .16187 m
.78528 .39111 L
.78556 .39111 L
.78556 .16187 L
F
.2 .63 .79 r
.78528 .16187 m
.78528 .39111 L
.78556 .39111 L
.78556 .16187 L
s
.678 .847 .902 r
.78556 .16187 m
.78556 .39157 L
.78591 .39157 L
.78591 .16187 L
F
.2 .63 .79 r
.78556 .16187 m
.78556 .39157 L
.78591 .39157 L
.78591 .16187 L
s
.678 .847 .902 r
.78591 .16187 m
.78591 .39172 L
.78637 .39172 L
.78637 .16187 L
F
.2 .63 .79 r
.78591 .16187 m
.78591 .39172 L
.78637 .39172 L
.78637 .16187 L
s
.678 .847 .902 r
.78637 .16187 m
.78637 .3922 L
.7869 .3922 L
.7869 .16187 L
F
.2 .63 .79 r
.78637 .16187 m
.78637 .3922 L
.7869 .3922 L
.7869 .16187 L
s
.678 .847 .902 r
.7869 .16187 m
.7869 .39304 L
.78747 .39304 L
.78747 .16187 L
F
.2 .63 .79 r
.7869 .16187 m
.7869 .39304 L
.78747 .39304 L
.78747 .16187 L
s
.678 .847 .902 r
.78747 .16187 m
.78747 .39332 L
.78767 .39332 L
.78767 .16187 L
F
.2 .63 .79 r
.78747 .16187 m
.78747 .39332 L
.78767 .39332 L
.78767 .16187 L
s
.678 .847 .902 r
.78767 .16187 m
.78767 .39341 L
.78789 .39341 L
.78789 .16187 L
F
.2 .63 .79 r
.78767 .16187 m
.78767 .39341 L
.78789 .39341 L
.78789 .16187 L
s
.678 .847 .902 r
.78789 .16187 m
.78789 .39368 L
.78847 .39368 L
.78847 .16187 L
F
.2 .63 .79 r
.78789 .16187 m
.78789 .39368 L
.78847 .39368 L
.78847 .16187 L
s
.678 .847 .902 r
.78847 .16187 m
.78847 .3944 L
.78892 .3944 L
.78892 .16187 L
F
.2 .63 .79 r
.78847 .16187 m
.78847 .3944 L
.78892 .3944 L
.78892 .16187 L
s
.678 .847 .902 r
.78892 .16187 m
.78892 .39467 L
.78924 .39467 L
.78924 .16187 L
F
.2 .63 .79 r
.78892 .16187 m
.78892 .39467 L
.78924 .39467 L
.78924 .16187 L
s
.678 .847 .902 r
.78924 .16187 m
.78924 .39535 L
.78978 .39535 L
.78978 .16187 L
F
.2 .63 .79 r
.78924 .16187 m
.78924 .39535 L
.78978 .39535 L
.78978 .16187 L
s
.678 .847 .902 r
.78978 .16187 m
.78978 .39554 L
.79008 .39554 L
.79008 .16187 L
F
.2 .63 .79 r
.78978 .16187 m
.78978 .39554 L
.79008 .39554 L
.79008 .16187 L
s
.678 .847 .902 r
.79008 .16187 m
.79008 .39576 L
.79057 .39576 L
.79057 .16187 L
F
.2 .63 .79 r
.79008 .16187 m
.79008 .39576 L
.79057 .39576 L
.79057 .16187 L
s
.678 .847 .902 r
.79057 .16187 m
.79057 .3964 L
.79114 .3964 L
.79114 .16187 L
F
.2 .63 .79 r
.79057 .16187 m
.79057 .3964 L
.79114 .3964 L
.79114 .16187 L
s
.678 .847 .902 r
.79114 .16187 m
.79114 .39694 L
.79164 .39694 L
.79164 .16187 L
F
.2 .63 .79 r
.79114 .16187 m
.79114 .39694 L
.79164 .39694 L
.79164 .16187 L
s
.678 .847 .902 r
.79164 .16187 m
.79164 .39787 L
.79226 .39787 L
.79226 .16187 L
F
.2 .63 .79 r
.79164 .16187 m
.79164 .39787 L
.79226 .39787 L
.79226 .16187 L
s
.678 .847 .902 r
.79226 .16187 m
.79226 .39817 L
.79257 .39817 L
.79257 .16187 L
F
.2 .63 .79 r
.79226 .16187 m
.79226 .39817 L
.79257 .39817 L
.79257 .16187 L
s
.678 .847 .902 r
.79257 .16187 m
.79257 .39845 L
.79301 .39845 L
.79301 .16187 L
F
.2 .63 .79 r
.79257 .16187 m
.79257 .39845 L
.79301 .39845 L
.79301 .16187 L
s
.678 .847 .902 r
.79301 .16187 m
.79301 .39881 L
.79326 .39881 L
.79326 .16187 L
F
.2 .63 .79 r
.79301 .16187 m
.79301 .39881 L
.79326 .39881 L
.79326 .16187 L
s
.678 .847 .902 r
.79326 .16187 m
.79326 .39927 L
.79375 .39927 L
.79375 .16187 L
F
.2 .63 .79 r
.79326 .16187 m
.79326 .39927 L
.79375 .39927 L
.79375 .16187 L
s
.678 .847 .902 r
.79375 .16187 m
.79375 .3996 L
.79428 .3996 L
.79428 .16187 L
F
.2 .63 .79 r
.79375 .16187 m
.79375 .3996 L
.79428 .3996 L
.79428 .16187 L
s
.678 .847 .902 r
.79428 .16187 m
.79428 .40034 L
.79492 .40034 L
.79492 .16187 L
F
.2 .63 .79 r
.79428 .16187 m
.79428 .40034 L
.79492 .40034 L
.79492 .16187 L
s
.678 .847 .902 r
.79492 .16187 m
.79492 .40093 L
.79542 .40093 L
.79542 .16187 L
F
.2 .63 .79 r
.79492 .16187 m
.79492 .40093 L
.79542 .40093 L
.79542 .16187 L
s
.678 .847 .902 r
.79542 .16187 m
.79542 .40151 L
.79602 .40151 L
.79602 .16187 L
F
.2 .63 .79 r
.79542 .16187 m
.79542 .40151 L
.79602 .40151 L
.79602 .16187 L
s
.678 .847 .902 r
.79602 .16187 m
.79602 .40208 L
.79646 .40208 L
.79646 .16187 L
F
.2 .63 .79 r
.79602 .16187 m
.79602 .40208 L
.79646 .40208 L
.79646 .16187 L
s
.678 .847 .902 r
.79646 .16187 m
.79646 .40249 L
.79693 .40249 L
.79693 .16187 L
F
.2 .63 .79 r
.79646 .16187 m
.79646 .40249 L
.79693 .40249 L
.79693 .16187 L
s
.678 .847 .902 r
.79693 .16187 m
.79693 .40271 L
.79717 .40271 L
.79717 .16187 L
F
.2 .63 .79 r
.79693 .16187 m
.79693 .40271 L
.79717 .40271 L
.79717 .16187 L
s
.678 .847 .902 r
.79717 .16187 m
.79717 .40295 L
.79743 .40295 L
.79743 .16187 L
F
.2 .63 .79 r
.79717 .16187 m
.79717 .40295 L
.79743 .40295 L
.79743 .16187 L
s
.678 .847 .902 r
.79743 .16187 m
.79743 .40315 L
.79794 .40315 L
.79794 .16187 L
F
.2 .63 .79 r
.79743 .16187 m
.79743 .40315 L
.79794 .40315 L
.79794 .16187 L
s
.678 .847 .902 r
.79794 .16187 m
.79794 .40404 L
.7984 .40404 L
.7984 .16187 L
F
.2 .63 .79 r
.79794 .16187 m
.79794 .40404 L
.7984 .40404 L
.7984 .16187 L
s
.678 .847 .902 r
.7984 .16187 m
.7984 .40412 L
.7986 .40412 L
.7986 .16187 L
F
.2 .63 .79 r
.7984 .16187 m
.7984 .40412 L
.7986 .40412 L
.7986 .16187 L
s
.678 .847 .902 r
.7986 .16187 m
.7986 .40437 L
.79892 .40437 L
.79892 .16187 L
F
.2 .63 .79 r
.7986 .16187 m
.7986 .40437 L
.79892 .40437 L
.79892 .16187 L
s
.678 .847 .902 r
.79892 .16187 m
.79892 .40473 L
.79917 .40473 L
.79917 .16187 L
F
.2 .63 .79 r
.79892 .16187 m
.79892 .40473 L
.79917 .40473 L
.79917 .16187 L
s
.678 .847 .902 r
.79917 .16187 m
.79917 .40509 L
.79951 .40509 L
.79951 .16187 L
F
.2 .63 .79 r
.79917 .16187 m
.79917 .40509 L
.79951 .40509 L
.79951 .16187 L
s
.678 .847 .902 r
.79951 .16187 m
.79951 .40531 L
.79981 .40531 L
.79981 .16187 L
F
.2 .63 .79 r
.79951 .16187 m
.79951 .40531 L
.79981 .40531 L
.79981 .16187 L
s
.678 .847 .902 r
.79981 .16187 m
.79981 .40549 L
.80003 .40549 L
.80003 .16187 L
F
.2 .63 .79 r
.79981 .16187 m
.79981 .40549 L
.80003 .40549 L
.80003 .16187 L
s
.678 .847 .902 r
.80003 .16187 m
.80003 .40591 L
.80042 .40591 L
.80042 .16187 L
F
.2 .63 .79 r
.80003 .16187 m
.80003 .40591 L
.80042 .40591 L
.80042 .16187 L
s
.678 .847 .902 r
.80042 .16187 m
.80042 .40627 L
.80082 .40627 L
.80082 .16187 L
F
.2 .63 .79 r
.80042 .16187 m
.80042 .40627 L
.80082 .40627 L
.80082 .16187 L
s
.678 .847 .902 r
.80082 .16187 m
.80082 .40658 L
.80126 .40658 L
.80126 .16187 L
F
.2 .63 .79 r
.80082 .16187 m
.80082 .40658 L
.80126 .40658 L
.80126 .16187 L
s
.678 .847 .902 r
.80126 .16187 m
.80126 .40697 L
.8015 .40697 L
.8015 .16187 L
F
.2 .63 .79 r
.80126 .16187 m
.80126 .40697 L
.8015 .40697 L
.8015 .16187 L
s
.678 .847 .902 r
.8015 .16187 m
.8015 .40739 L
.80177 .40739 L
.80177 .16187 L
F
.2 .63 .79 r
.8015 .16187 m
.8015 .40739 L
.80177 .40739 L
.80177 .16187 L
s
.678 .847 .902 r
.80177 .16187 m
.80177 .40802 L
.80237 .40802 L
.80237 .16187 L
F
.2 .63 .79 r
.80177 .16187 m
.80177 .40802 L
.80237 .40802 L
.80237 .16187 L
s
.678 .847 .902 r
.80237 .16187 m
.80237 .4083 L
.80275 .4083 L
.80275 .16187 L
F
.2 .63 .79 r
.80237 .16187 m
.80237 .4083 L
.80275 .4083 L
.80275 .16187 L
s
.678 .847 .902 r
.80275 .16187 m
.80275 .4086 L
.80313 .4086 L
.80313 .16187 L
F
.2 .63 .79 r
.80275 .16187 m
.80275 .4086 L
.80313 .4086 L
.80313 .16187 L
s
.678 .847 .902 r
.80313 .16187 m
.80313 .40899 L
.80351 .40899 L
.80351 .16187 L
F
.2 .63 .79 r
.80313 .16187 m
.80313 .40899 L
.80351 .40899 L
.80351 .16187 L
s
.678 .847 .902 r
.80351 .16187 m
.80351 .4094 L
.80412 .4094 L
.80412 .16187 L
F
.2 .63 .79 r
.80351 .16187 m
.80351 .4094 L
.80412 .4094 L
.80412 .16187 L
s
.678 .847 .902 r
.80412 .16187 m
.80412 .41031 L
.80463 .41031 L
.80463 .16187 L
F
.2 .63 .79 r
.80412 .16187 m
.80412 .41031 L
.80463 .41031 L
.80463 .16187 L
s
.678 .847 .902 r
.80463 .16187 m
.80463 .41065 L
.80506 .41065 L
.80506 .16187 L
F
.2 .63 .79 r
.80463 .16187 m
.80463 .41065 L
.80506 .41065 L
.80506 .16187 L
s
.678 .847 .902 r
.80506 .16187 m
.80506 .41107 L
.80563 .41107 L
.80563 .16187 L
F
.2 .63 .79 r
.80506 .16187 m
.80506 .41107 L
.80563 .41107 L
.80563 .16187 L
s
.678 .847 .902 r
.80563 .16187 m
.80563 .41154 L
.80596 .41154 L
.80596 .16187 L
F
.2 .63 .79 r
.80563 .16187 m
.80563 .41154 L
.80596 .41154 L
.80596 .16187 L
s
.678 .847 .902 r
.80596 .16187 m
.80596 .41191 L
.80643 .41191 L
.80643 .16187 L
F
.2 .63 .79 r
.80596 .16187 m
.80596 .41191 L
.80643 .41191 L
.80643 .16187 L
s
.678 .847 .902 r
.80643 .16187 m
.80643 .41225 L
.80679 .41225 L
.80679 .16187 L
F
.2 .63 .79 r
.80643 .16187 m
.80643 .41225 L
.80679 .41225 L
.80679 .16187 L
s
.678 .847 .902 r
.80679 .16187 m
.80679 .41264 L
.80703 .41264 L
.80703 .16187 L
F
.2 .63 .79 r
.80679 .16187 m
.80679 .41264 L
.80703 .41264 L
.80703 .16187 L
s
.678 .847 .902 r
.80703 .16187 m
.80703 .41309 L
.80754 .41309 L
.80754 .16187 L
F
.2 .63 .79 r
.80703 .16187 m
.80703 .41309 L
.80754 .41309 L
.80754 .16187 L
s
.678 .847 .902 r
.80754 .16187 m
.80754 .41341 L
.808 .41341 L
.808 .16187 L
F
.2 .63 .79 r
.80754 .16187 m
.80754 .41341 L
.808 .41341 L
.808 .16187 L
s
.678 .847 .902 r
.808 .16187 m
.808 .41399 L
.80823 .41399 L
.80823 .16187 L
F
.2 .63 .79 r
.808 .16187 m
.808 .41399 L
.80823 .41399 L
.80823 .16187 L
s
.678 .847 .902 r
.80823 .16187 m
.80823 .41417 L
.80842 .41417 L
.80842 .16187 L
F
.2 .63 .79 r
.80823 .16187 m
.80823 .41417 L
.80842 .41417 L
.80842 .16187 L
s
.678 .847 .902 r
.80842 .16187 m
.80842 .41453 L
.80878 .41453 L
.80878 .16187 L
F
.2 .63 .79 r
.80842 .16187 m
.80842 .41453 L
.80878 .41453 L
.80878 .16187 L
s
.678 .847 .902 r
.80878 .16187 m
.80878 .41486 L
.80913 .41486 L
.80913 .16187 L
F
.2 .63 .79 r
.80878 .16187 m
.80878 .41486 L
.80913 .41486 L
.80913 .16187 L
s
.678 .847 .902 r
.80913 .16187 m
.80913 .41512 L
.80933 .41512 L
.80933 .16187 L
F
.2 .63 .79 r
.80913 .16187 m
.80913 .41512 L
.80933 .41512 L
.80933 .16187 L
s
.678 .847 .902 r
.80933 .16187 m
.80933 .41527 L
.80977 .41527 L
.80977 .16187 L
F
.2 .63 .79 r
.80933 .16187 m
.80933 .41527 L
.80977 .41527 L
.80977 .16187 L
s
.678 .847 .902 r
.80977 .16187 m
.80977 .41585 L
.81036 .41585 L
.81036 .16187 L
F
.2 .63 .79 r
.80977 .16187 m
.80977 .41585 L
.81036 .41585 L
.81036 .16187 L
s
.678 .847 .902 r
.81036 .16187 m
.81036 .41655 L
.81092 .41655 L
.81092 .16187 L
F
.2 .63 .79 r
.81036 .16187 m
.81036 .41655 L
.81092 .41655 L
.81092 .16187 L
s
.678 .847 .902 r
.81092 .16187 m
.81092 .41726 L
.81151 .41726 L
.81151 .16187 L
F
.2 .63 .79 r
.81092 .16187 m
.81092 .41726 L
.81151 .41726 L
.81151 .16187 L
s
.678 .847 .902 r
.81151 .16187 m
.81151 .41758 L
.81188 .41758 L
.81188 .16187 L
F
.2 .63 .79 r
.81151 .16187 m
.81151 .41758 L
.81188 .41758 L
.81188 .16187 L
s
.678 .847 .902 r
.81188 .16187 m
.81188 .41808 L
.81251 .41808 L
.81251 .16187 L
F
.2 .63 .79 r
.81188 .16187 m
.81188 .41808 L
.81251 .41808 L
.81251 .16187 L
s
.678 .847 .902 r
.81251 .16187 m
.81251 .4184 L
.81287 .4184 L
.81287 .16187 L
F
.2 .63 .79 r
.81251 .16187 m
.81251 .4184 L
.81287 .4184 L
.81287 .16187 L
s
.678 .847 .902 r
.81287 .16187 m
.81287 .41894 L
.81327 .41894 L
.81327 .16187 L
F
.2 .63 .79 r
.81287 .16187 m
.81287 .41894 L
.81327 .41894 L
.81327 .16187 L
s
.678 .847 .902 r
.81327 .16187 m
.81327 .4193 L
.8139 .4193 L
.8139 .16187 L
F
.2 .63 .79 r
.81327 .16187 m
.81327 .4193 L
.8139 .4193 L
.8139 .16187 L
s
.678 .847 .902 r
.8139 .16187 m
.8139 .41986 L
.81411 .41986 L
.81411 .16187 L
F
.2 .63 .79 r
.8139 .16187 m
.8139 .41986 L
.81411 .41986 L
.81411 .16187 L
s
.678 .847 .902 r
.81411 .16187 m
.81411 .4201 L
.8146 .4201 L
.8146 .16187 L
F
.2 .63 .79 r
.81411 .16187 m
.81411 .4201 L
.8146 .4201 L
.8146 .16187 L
s
.678 .847 .902 r
.8146 .16187 m
.8146 .42103 L
.81522 .42103 L
.81522 .16187 L
F
.2 .63 .79 r
.8146 .16187 m
.8146 .42103 L
.81522 .42103 L
.81522 .16187 L
s
.678 .847 .902 r
.81522 .16187 m
.81522 .42134 L
.81546 .42134 L
.81546 .16187 L
F
.2 .63 .79 r
.81522 .16187 m
.81522 .42134 L
.81546 .42134 L
.81546 .16187 L
s
.678 .847 .902 r
.81546 .16187 m
.81546 .42181 L
.81599 .42181 L
.81599 .16187 L
F
.2 .63 .79 r
.81546 .16187 m
.81546 .42181 L
.81599 .42181 L
.81599 .16187 L
s
.678 .847 .902 r
.81599 .16187 m
.81599 .4221 L
.81619 .4221 L
.81619 .16187 L
F
.2 .63 .79 r
.81599 .16187 m
.81599 .4221 L
.81619 .4221 L
.81619 .16187 L
s
.678 .847 .902 r
.81619 .16187 m
.81619 .42244 L
.81664 .42244 L
.81664 .16187 L
F
.2 .63 .79 r
.81619 .16187 m
.81619 .42244 L
.81664 .42244 L
.81664 .16187 L
s
.678 .847 .902 r
.81664 .16187 m
.81664 .42285 L
.81728 .42285 L
.81728 .16187 L
F
.2 .63 .79 r
.81664 .16187 m
.81664 .42285 L
.81728 .42285 L
.81728 .16187 L
s
.678 .847 .902 r
.81728 .16187 m
.81728 .42332 L
.81749 .42332 L
.81749 .16187 L
F
.2 .63 .79 r
.81728 .16187 m
.81728 .42332 L
.81749 .42332 L
.81749 .16187 L
s
.678 .847 .902 r
.81749 .16187 m
.81749 .4237 L
.81787 .4237 L
.81787 .16187 L
F
.2 .63 .79 r
.81749 .16187 m
.81749 .4237 L
.81787 .4237 L
.81787 .16187 L
s
.678 .847 .902 r
.81787 .16187 m
.81787 .42418 L
.81829 .42418 L
.81829 .16187 L
F
.2 .63 .79 r
.81787 .16187 m
.81787 .42418 L
.81829 .42418 L
.81829 .16187 L
s
.678 .847 .902 r
.81829 .16187 m
.81829 .42466 L
.81892 .42466 L
.81892 .16187 L
F
.2 .63 .79 r
.81829 .16187 m
.81829 .42466 L
.81892 .42466 L
.81892 .16187 L
s
.678 .847 .902 r
.81892 .16187 m
.81892 .42513 L
.81941 .42513 L
.81941 .16187 L
F
.2 .63 .79 r
.81892 .16187 m
.81892 .42513 L
.81941 .42513 L
.81941 .16187 L
s
.678 .847 .902 r
.81941 .16187 m
.81941 .42565 L
.81964 .42565 L
.81964 .16187 L
F
.2 .63 .79 r
.81941 .16187 m
.81941 .42565 L
.81964 .42565 L
.81964 .16187 L
s
.678 .847 .902 r
.81964 .16187 m
.81964 .42603 L
.82004 .42603 L
.82004 .16187 L
F
.2 .63 .79 r
.81964 .16187 m
.81964 .42603 L
.82004 .42603 L
.82004 .16187 L
s
.678 .847 .902 r
.82004 .16187 m
.82004 .42622 L
.82043 .42622 L
.82043 .16187 L
F
.2 .63 .79 r
.82004 .16187 m
.82004 .42622 L
.82043 .42622 L
.82043 .16187 L
s
.678 .847 .902 r
.82043 .16187 m
.82043 .427 L
.82095 .427 L
.82095 .16187 L
F
.2 .63 .79 r
.82043 .16187 m
.82043 .427 L
.82095 .427 L
.82095 .16187 L
s
.678 .847 .902 r
.82095 .16187 m
.82095 .42711 L
.82127 .42711 L
.82127 .16187 L
F
.2 .63 .79 r
.82095 .16187 m
.82095 .42711 L
.82127 .42711 L
.82127 .16187 L
s
.678 .847 .902 r
.82127 .16187 m
.82127 .42783 L
.82172 .42783 L
.82172 .16187 L
F
.2 .63 .79 r
.82127 .16187 m
.82127 .42783 L
.82172 .42783 L
.82172 .16187 L
s
.678 .847 .902 r
.82172 .16187 m
.82172 .42801 L
.82193 .42801 L
.82193 .16187 L
F
.2 .63 .79 r
.82172 .16187 m
.82172 .42801 L
.82193 .42801 L
.82193 .16187 L
s
.678 .847 .902 r
.82193 .16187 m
.82193 .42827 L
.82246 .42827 L
.82246 .16187 L
F
.2 .63 .79 r
.82193 .16187 m
.82193 .42827 L
.82246 .42827 L
.82246 .16187 L
s
.678 .847 .902 r
.82246 .16187 m
.82246 .42867 L
.82306 .42867 L
.82306 .16187 L
F
.2 .63 .79 r
.82246 .16187 m
.82246 .42867 L
.82306 .42867 L
.82306 .16187 L
s
.678 .847 .902 r
.82306 .16187 m
.82306 .42937 L
.82329 .42937 L
.82329 .16187 L
F
.2 .63 .79 r
.82306 .16187 m
.82306 .42937 L
.82329 .42937 L
.82329 .16187 L
s
.678 .847 .902 r
.82329 .16187 m
.82329 .4296 L
.82352 .4296 L
.82352 .16187 L
F
.2 .63 .79 r
.82329 .16187 m
.82329 .4296 L
.82352 .4296 L
.82352 .16187 L
s
.678 .847 .902 r
.82352 .16187 m
.82352 .42978 L
.82403 .42978 L
.82403 .16187 L
F
.2 .63 .79 r
.82352 .16187 m
.82352 .42978 L
.82403 .42978 L
.82403 .16187 L
s
.678 .847 .902 r
.82403 .16187 m
.82403 .43054 L
.82433 .43054 L
.82433 .16187 L
F
.2 .63 .79 r
.82403 .16187 m
.82403 .43054 L
.82433 .43054 L
.82433 .16187 L
s
.678 .847 .902 r
.82433 .16187 m
.82433 .43075 L
.82458 .43075 L
.82458 .16187 L
F
.2 .63 .79 r
.82433 .16187 m
.82433 .43075 L
.82458 .43075 L
.82458 .16187 L
s
.678 .847 .902 r
.82458 .16187 m
.82458 .4313 L
.8252 .4313 L
.8252 .16187 L
F
.2 .63 .79 r
.82458 .16187 m
.82458 .4313 L
.8252 .4313 L
.8252 .16187 L
s
.678 .847 .902 r
.8252 .16187 m
.8252 .43171 L
.82582 .43171 L
.82582 .16187 L
F
.2 .63 .79 r
.8252 .16187 m
.8252 .43171 L
.82582 .43171 L
.82582 .16187 L
s
.678 .847 .902 r
.82582 .16187 m
.82582 .43218 L
.82611 .43218 L
.82611 .16187 L
F
.2 .63 .79 r
.82582 .16187 m
.82582 .43218 L
.82611 .43218 L
.82611 .16187 L
s
.678 .847 .902 r
.82611 .16187 m
.82611 .43247 L
.82655 .43247 L
.82655 .16187 L
F
.2 .63 .79 r
.82611 .16187 m
.82611 .43247 L
.82655 .43247 L
.82655 .16187 L
s
.678 .847 .902 r
.82655 .16187 m
.82655 .43312 L
.82717 .43312 L
.82717 .16187 L
F
.2 .63 .79 r
.82655 .16187 m
.82655 .43312 L
.82717 .43312 L
.82717 .16187 L
s
.678 .847 .902 r
.82717 .16187 m
.82717 .43365 L
.82778 .43365 L
.82778 .16187 L
F
.2 .63 .79 r
.82717 .16187 m
.82717 .43365 L
.82778 .43365 L
.82778 .16187 L
s
.678 .847 .902 r
.82778 .16187 m
.82778 .43453 L
.82832 .43453 L
.82832 .16187 L
F
.2 .63 .79 r
.82778 .16187 m
.82778 .43453 L
.82832 .43453 L
.82832 .16187 L
s
.678 .847 .902 r
.82832 .16187 m
.82832 .43482 L
.82853 .43482 L
.82853 .16187 L
F
.2 .63 .79 r
.82832 .16187 m
.82832 .43482 L
.82853 .43482 L
.82853 .16187 L
s
.678 .847 .902 r
.82853 .16187 m
.82853 .4355 L
.82915 .4355 L
.82915 .16187 L
F
.2 .63 .79 r
.82853 .16187 m
.82853 .4355 L
.82915 .4355 L
.82915 .16187 L
s
.678 .847 .902 r
.82915 .16187 m
.82915 .4359 L
.82947 .4359 L
.82947 .16187 L
F
.2 .63 .79 r
.82915 .16187 m
.82915 .4359 L
.82947 .4359 L
.82947 .16187 L
s
.678 .847 .902 r
.82947 .16187 m
.82947 .43641 L
.82997 .43641 L
.82997 .16187 L
F
.2 .63 .79 r
.82947 .16187 m
.82947 .43641 L
.82997 .43641 L
.82997 .16187 L
s
.678 .847 .902 r
.82997 .16187 m
.82997 .43676 L
.83041 .43676 L
.83041 .16187 L
F
.2 .63 .79 r
.82997 .16187 m
.82997 .43676 L
.83041 .43676 L
.83041 .16187 L
s
.678 .847 .902 r
.83041 .16187 m
.83041 .43721 L
.83084 .43721 L
.83084 .16187 L
F
.2 .63 .79 r
.83041 .16187 m
.83041 .43721 L
.83084 .43721 L
.83084 .16187 L
s
.678 .847 .902 r
.83084 .16187 m
.83084 .43739 L
.83128 .43739 L
.83128 .16187 L
F
.2 .63 .79 r
.83084 .16187 m
.83084 .43739 L
.83128 .43739 L
.83128 .16187 L
s
.678 .847 .902 r
.83128 .16187 m
.83128 .43814 L
.83165 .43814 L
.83165 .16187 L
F
.2 .63 .79 r
.83128 .16187 m
.83128 .43814 L
.83165 .43814 L
.83165 .16187 L
s
.678 .847 .902 r
.83165 .16187 m
.83165 .43836 L
.83184 .43836 L
.83184 .16187 L
F
.2 .63 .79 r
.83165 .16187 m
.83165 .43836 L
.83184 .43836 L
.83184 .16187 L
s
.678 .847 .902 r
.83184 .16187 m
.83184 .43884 L
.83224 .43884 L
.83224 .16187 L
F
.2 .63 .79 r
.83184 .16187 m
.83184 .43884 L
.83224 .43884 L
.83224 .16187 L
s
.678 .847 .902 r
.83224 .16187 m
.83224 .43924 L
.83278 .43924 L
.83278 .16187 L
F
.2 .63 .79 r
.83224 .16187 m
.83224 .43924 L
.83278 .43924 L
.83278 .16187 L
s
.678 .847 .902 r
.83278 .16187 m
.83278 .43974 L
.8332 .43974 L
.8332 .16187 L
F
.2 .63 .79 r
.83278 .16187 m
.83278 .43974 L
.8332 .43974 L
.8332 .16187 L
s
.678 .847 .902 r
.8332 .16187 m
.8332 .43999 L
.8338 .43999 L
.8338 .16187 L
F
.2 .63 .79 r
.8332 .16187 m
.8332 .43999 L
.8338 .43999 L
.8338 .16187 L
s
.678 .847 .902 r
.8338 .16187 m
.8338 .44069 L
.83416 .44069 L
.83416 .16187 L
F
.2 .63 .79 r
.8338 .16187 m
.8338 .44069 L
.83416 .44069 L
.83416 .16187 L
s
.678 .847 .902 r
.83416 .16187 m
.83416 .441 L
.83439 .441 L
.83439 .16187 L
F
.2 .63 .79 r
.83416 .16187 m
.83416 .441 L
.83439 .441 L
.83439 .16187 L
s
.678 .847 .902 r
.83439 .16187 m
.83439 .44136 L
.83469 .44136 L
.83469 .16187 L
F
.2 .63 .79 r
.83439 .16187 m
.83439 .44136 L
.83469 .44136 L
.83469 .16187 L
s
.678 .847 .902 r
.83469 .16187 m
.83469 .44172 L
.83523 .44172 L
.83523 .16187 L
F
.2 .63 .79 r
.83469 .16187 m
.83469 .44172 L
.83523 .44172 L
.83523 .16187 L
s
.678 .847 .902 r
.83523 .16187 m
.83523 .44232 L
.83561 .44232 L
.83561 .16187 L
F
.2 .63 .79 r
.83523 .16187 m
.83523 .44232 L
.83561 .44232 L
.83561 .16187 L
s
.678 .847 .902 r
.83561 .16187 m
.83561 .44245 L
.83585 .44245 L
.83585 .16187 L
F
.2 .63 .79 r
.83561 .16187 m
.83561 .44245 L
.83585 .44245 L
.83585 .16187 L
s
.678 .847 .902 r
.83585 .16187 m
.83585 .44278 L
.83605 .44278 L
.83605 .16187 L
F
.2 .63 .79 r
.83585 .16187 m
.83585 .44278 L
.83605 .44278 L
.83605 .16187 L
s
.678 .847 .902 r
.83605 .16187 m
.83605 .44299 L
.83636 .44299 L
.83636 .16187 L
F
.2 .63 .79 r
.83605 .16187 m
.83605 .44299 L
.83636 .44299 L
.83636 .16187 L
s
.678 .847 .902 r
.83636 .16187 m
.83636 .44336 L
.83675 .44336 L
.83675 .16187 L
F
.2 .63 .79 r
.83636 .16187 m
.83636 .44336 L
.83675 .44336 L
.83675 .16187 L
s
.678 .847 .902 r
.83675 .16187 m
.83675 .4436 L
.83702 .4436 L
.83702 .16187 L
F
.2 .63 .79 r
.83675 .16187 m
.83675 .4436 L
.83702 .4436 L
.83702 .16187 L
s
.678 .847 .902 r
.83702 .16187 m
.83702 .44388 L
.83732 .44388 L
.83732 .16187 L
F
.2 .63 .79 r
.83702 .16187 m
.83702 .44388 L
.83732 .44388 L
.83732 .16187 L
s
.678 .847 .902 r
.83732 .16187 m
.83732 .44419 L
.83761 .44419 L
.83761 .16187 L
F
.2 .63 .79 r
.83732 .16187 m
.83732 .44419 L
.83761 .44419 L
.83761 .16187 L
s
.678 .847 .902 r
.83761 .16187 m
.83761 .44475 L
.83801 .44475 L
.83801 .16187 L
F
.2 .63 .79 r
.83761 .16187 m
.83761 .44475 L
.83801 .44475 L
.83801 .16187 L
s
.678 .847 .902 r
.83801 .16187 m
.83801 .44502 L
.8386 .44502 L
.8386 .16187 L
F
.2 .63 .79 r
.83801 .16187 m
.83801 .44502 L
.8386 .44502 L
.8386 .16187 L
s
.678 .847 .902 r
.8386 .16187 m
.8386 .4456 L
.83904 .4456 L
.83904 .16187 L
F
.2 .63 .79 r
.8386 .16187 m
.8386 .4456 L
.83904 .4456 L
.83904 .16187 L
s
.678 .847 .902 r
.83904 .16187 m
.83904 .44619 L
.83952 .44619 L
.83952 .16187 L
F
.2 .63 .79 r
.83904 .16187 m
.83904 .44619 L
.83952 .44619 L
.83952 .16187 L
s
.678 .847 .902 r
.83952 .16187 m
.83952 .44715 L
.84013 .44715 L
.84013 .16187 L
F
.2 .63 .79 r
.83952 .16187 m
.83952 .44715 L
.84013 .44715 L
.84013 .16187 L
s
.678 .847 .902 r
.84013 .16187 m
.84013 .4472 L
.84048 .4472 L
.84048 .16187 L
F
.2 .63 .79 r
.84013 .16187 m
.84013 .4472 L
.84048 .4472 L
.84048 .16187 L
s
.678 .847 .902 r
.84048 .16187 m
.84048 .44761 L
.84075 .44761 L
.84075 .16187 L
F
.2 .63 .79 r
.84048 .16187 m
.84048 .44761 L
.84075 .44761 L
.84075 .16187 L
s
.678 .847 .902 r
.84075 .16187 m
.84075 .44813 L
.84122 .44813 L
.84122 .16187 L
F
.2 .63 .79 r
.84075 .16187 m
.84075 .44813 L
.84122 .44813 L
.84122 .16187 L
s
.678 .847 .902 r
.84122 .16187 m
.84122 .44873 L
.84162 .44873 L
.84162 .16187 L
F
.2 .63 .79 r
.84122 .16187 m
.84122 .44873 L
.84162 .44873 L
.84162 .16187 L
s
.678 .847 .902 r
.84162 .16187 m
.84162 .44893 L
.84206 .44893 L
.84206 .16187 L
F
.2 .63 .79 r
.84162 .16187 m
.84162 .44893 L
.84206 .44893 L
.84206 .16187 L
s
.678 .847 .902 r
.84206 .16187 m
.84206 .4495 L
.84256 .4495 L
.84256 .16187 L
F
.2 .63 .79 r
.84206 .16187 m
.84206 .4495 L
.84256 .4495 L
.84256 .16187 L
s
.678 .847 .902 r
.84256 .16187 m
.84256 .44995 L
.84307 .44995 L
.84307 .16187 L
F
.2 .63 .79 r
.84256 .16187 m
.84256 .44995 L
.84307 .44995 L
.84307 .16187 L
s
.678 .847 .902 r
.84307 .16187 m
.84307 .45037 L
.8433 .45037 L
.8433 .16187 L
F
.2 .63 .79 r
.84307 .16187 m
.84307 .45037 L
.8433 .45037 L
.8433 .16187 L
s
.678 .847 .902 r
.8433 .16187 m
.8433 .45086 L
.84371 .45086 L
.84371 .16187 L
F
.2 .63 .79 r
.8433 .16187 m
.8433 .45086 L
.84371 .45086 L
.84371 .16187 L
s
.678 .847 .902 r
.84371 .16187 m
.84371 .45123 L
.84409 .45123 L
.84409 .16187 L
F
.2 .63 .79 r
.84371 .16187 m
.84371 .45123 L
.84409 .45123 L
.84409 .16187 L
s
.678 .847 .902 r
.84409 .16187 m
.84409 .45191 L
.84469 .45191 L
.84469 .16187 L
F
.2 .63 .79 r
.84409 .16187 m
.84409 .45191 L
.84469 .45191 L
.84469 .16187 L
s
.678 .847 .902 r
.84469 .16187 m
.84469 .4523 L
.84518 .4523 L
.84518 .16187 L
F
.2 .63 .79 r
.84469 .16187 m
.84469 .4523 L
.84518 .4523 L
.84518 .16187 L
s
.678 .847 .902 r
.84518 .16187 m
.84518 .45272 L
.84554 .45272 L
.84554 .16187 L
F
.2 .63 .79 r
.84518 .16187 m
.84518 .45272 L
.84554 .45272 L
.84554 .16187 L
s
.678 .847 .902 r
.84554 .16187 m
.84554 .4533 L
.84591 .4533 L
.84591 .16187 L
F
.2 .63 .79 r
.84554 .16187 m
.84554 .4533 L
.84591 .4533 L
.84591 .16187 L
s
.678 .847 .902 r
.84591 .16187 m
.84591 .45352 L
.8464 .45352 L
.8464 .16187 L
F
.2 .63 .79 r
.84591 .16187 m
.84591 .45352 L
.8464 .45352 L
.8464 .16187 L
s
.678 .847 .902 r
.8464 .16187 m
.8464 .45386 L
.84669 .45386 L
.84669 .16187 L
F
.2 .63 .79 r
.8464 .16187 m
.8464 .45386 L
.84669 .45386 L
.84669 .16187 L
s
.678 .847 .902 r
.84669 .16187 m
.84669 .45427 L
.84698 .45427 L
.84698 .16187 L
F
.2 .63 .79 r
.84669 .16187 m
.84669 .45427 L
.84698 .45427 L
.84698 .16187 L
s
.678 .847 .902 r
.84698 .16187 m
.84698 .4547 L
.84723 .4547 L
.84723 .16187 L
F
.2 .63 .79 r
.84698 .16187 m
.84698 .4547 L
.84723 .4547 L
.84723 .16187 L
s
.678 .847 .902 r
.84723 .16187 m
.84723 .45488 L
.84763 .45488 L
.84763 .16187 L
F
.2 .63 .79 r
.84723 .16187 m
.84723 .45488 L
.84763 .45488 L
.84763 .16187 L
s
.678 .847 .902 r
.84763 .16187 m
.84763 .4554 L
.84815 .4554 L
.84815 .16187 L
F
.2 .63 .79 r
.84763 .16187 m
.84763 .4554 L
.84815 .4554 L
.84815 .16187 L
s
.678 .847 .902 r
.84815 .16187 m
.84815 .45579 L
.84849 .45579 L
.84849 .16187 L
F
.2 .63 .79 r
.84815 .16187 m
.84815 .45579 L
.84849 .45579 L
.84849 .16187 L
s
.678 .847 .902 r
.84849 .16187 m
.84849 .45644 L
.84894 .45644 L
.84894 .16187 L
F
.2 .63 .79 r
.84849 .16187 m
.84849 .45644 L
.84894 .45644 L
.84894 .16187 L
s
.678 .847 .902 r
.84894 .16187 m
.84894 .45655 L
.8495 .45655 L
.8495 .16187 L
F
.2 .63 .79 r
.84894 .16187 m
.84894 .45655 L
.8495 .45655 L
.8495 .16187 L
s
.678 .847 .902 r
.8495 .16187 m
.8495 .45742 L
.85004 .45742 L
.85004 .16187 L
F
.2 .63 .79 r
.8495 .16187 m
.8495 .45742 L
.85004 .45742 L
.85004 .16187 L
s
.678 .847 .902 r
.85004 .16187 m
.85004 .45775 L
.85023 .45775 L
.85023 .16187 L
F
.2 .63 .79 r
.85004 .16187 m
.85004 .45775 L
.85023 .45775 L
.85023 .16187 L
s
.678 .847 .902 r
.85023 .16187 m
.85023 .45811 L
.8506 .45811 L
.8506 .16187 L
F
.2 .63 .79 r
.85023 .16187 m
.85023 .45811 L
.8506 .45811 L
.8506 .16187 L
s
.678 .847 .902 r
.8506 .16187 m
.8506 .45843 L
.85088 .45843 L
.85088 .16187 L
F
.2 .63 .79 r
.8506 .16187 m
.8506 .45843 L
.85088 .45843 L
.85088 .16187 L
s
.678 .847 .902 r
.85088 .16187 m
.85088 .45879 L
.85121 .45879 L
.85121 .16187 L
F
.2 .63 .79 r
.85088 .16187 m
.85088 .45879 L
.85121 .45879 L
.85121 .16187 L
s
.678 .847 .902 r
.85121 .16187 m
.85121 .45927 L
.8516 .45927 L
.8516 .16187 L
F
.2 .63 .79 r
.85121 .16187 m
.85121 .45927 L
.8516 .45927 L
.8516 .16187 L
s
.678 .847 .902 r
.8516 .16187 m
.8516 .45989 L
.85211 .45989 L
.85211 .16187 L
F
.2 .63 .79 r
.8516 .16187 m
.8516 .45989 L
.85211 .45989 L
.85211 .16187 L
s
.678 .847 .902 r
.85211 .16187 m
.85211 .46036 L
.85251 .46036 L
.85251 .16187 L
F
.2 .63 .79 r
.85211 .16187 m
.85211 .46036 L
.85251 .46036 L
.85251 .16187 L
s
.678 .847 .902 r
.85251 .16187 m
.85251 .46039 L
.85281 .46039 L
.85281 .16187 L
F
.2 .63 .79 r
.85251 .16187 m
.85251 .46039 L
.85281 .46039 L
.85281 .16187 L
s
.678 .847 .902 r
.85281 .16187 m
.85281 .46131 L
.85343 .46131 L
.85343 .16187 L
F
.2 .63 .79 r
.85281 .16187 m
.85281 .46131 L
.85343 .46131 L
.85343 .16187 L
s
.678 .847 .902 r
.85343 .16187 m
.85343 .46143 L
.85375 .46143 L
.85375 .16187 L
F
.2 .63 .79 r
.85343 .16187 m
.85343 .46143 L
.85375 .46143 L
.85375 .16187 L
s
.678 .847 .902 r
.85375 .16187 m
.85375 .46175 L
.85418 .46175 L
.85418 .16187 L
F
.2 .63 .79 r
.85375 .16187 m
.85375 .46175 L
.85418 .46175 L
.85418 .16187 L
s
.678 .847 .902 r
.85418 .16187 m
.85418 .4624 L
.85463 .4624 L
.85463 .16187 L
F
.2 .63 .79 r
.85418 .16187 m
.85418 .4624 L
.85463 .4624 L
.85463 .16187 L
s
.678 .847 .902 r
.85463 .16187 m
.85463 .46285 L
.85508 .46285 L
.85508 .16187 L
F
.2 .63 .79 r
.85463 .16187 m
.85463 .46285 L
.85508 .46285 L
.85508 .16187 L
s
.678 .847 .902 r
.85508 .16187 m
.85508 .46327 L
.85567 .46327 L
.85567 .16187 L
F
.2 .63 .79 r
.85508 .16187 m
.85508 .46327 L
.85567 .46327 L
.85567 .16187 L
s
.678 .847 .902 r
.85567 .16187 m
.85567 .4642 L
.85625 .4642 L
.85625 .16187 L
F
.2 .63 .79 r
.85567 .16187 m
.85567 .4642 L
.85625 .4642 L
.85625 .16187 L
s
.678 .847 .902 r
.85625 .16187 m
.85625 .46455 L
.85661 .46455 L
.85661 .16187 L
F
.2 .63 .79 r
.85625 .16187 m
.85625 .46455 L
.85661 .46455 L
.85661 .16187 L
s
.678 .847 .902 r
.85661 .16187 m
.85661 .46514 L
.85695 .46514 L
.85695 .16187 L
F
.2 .63 .79 r
.85661 .16187 m
.85661 .46514 L
.85695 .46514 L
.85695 .16187 L
s
.678 .847 .902 r
.85695 .16187 m
.85695 .46531 L
.85748 .46531 L
.85748 .16187 L
F
.2 .63 .79 r
.85695 .16187 m
.85695 .46531 L
.85748 .46531 L
.85748 .16187 L
s
.678 .847 .902 r
.85748 .16187 m
.85748 .46585 L
.85785 .46585 L
.85785 .16187 L
F
.2 .63 .79 r
.85748 .16187 m
.85748 .46585 L
.85785 .46585 L
.85785 .16187 L
s
.678 .847 .902 r
.85785 .16187 m
.85785 .4666 L
.85833 .4666 L
.85833 .16187 L
F
.2 .63 .79 r
.85785 .16187 m
.85785 .4666 L
.85833 .4666 L
.85833 .16187 L
s
.678 .847 .902 r
.85833 .16187 m
.85833 .46679 L
.85852 .46679 L
.85852 .16187 L
F
.2 .63 .79 r
.85833 .16187 m
.85833 .46679 L
.85852 .46679 L
.85852 .16187 L
s
.678 .847 .902 r
.85852 .16187 m
.85852 .467 L
.8588 .467 L
.8588 .16187 L
F
.2 .63 .79 r
.85852 .16187 m
.85852 .467 L
.8588 .467 L
.8588 .16187 L
s
.678 .847 .902 r
.8588 .16187 m
.8588 .46729 L
.85925 .46729 L
.85925 .16187 L
F
.2 .63 .79 r
.8588 .16187 m
.8588 .46729 L
.85925 .46729 L
.85925 .16187 L
s
.678 .847 .902 r
.85925 .16187 m
.85925 .46791 L
.85982 .46791 L
.85982 .16187 L
F
.2 .63 .79 r
.85925 .16187 m
.85925 .46791 L
.85982 .46791 L
.85982 .16187 L
s
.678 .847 .902 r
.85982 .16187 m
.85982 .46863 L
.86046 .46863 L
.86046 .16187 L
F
.2 .63 .79 r
.85982 .16187 m
.85982 .46863 L
.86046 .46863 L
.86046 .16187 L
s
.678 .847 .902 r
.86046 .16187 m
.86046 .46954 L
.861 .46954 L
.861 .16187 L
F
.2 .63 .79 r
.86046 .16187 m
.86046 .46954 L
.861 .46954 L
.861 .16187 L
s
.678 .847 .902 r
.861 .16187 m
.861 .46991 L
.86137 .46991 L
.86137 .16187 L
F
.2 .63 .79 r
.861 .16187 m
.861 .46991 L
.86137 .46991 L
.86137 .16187 L
s
.678 .847 .902 r
.86137 .16187 m
.86137 .47039 L
.8618 .47039 L
.8618 .16187 L
F
.2 .63 .79 r
.86137 .16187 m
.86137 .47039 L
.8618 .47039 L
.8618 .16187 L
s
.678 .847 .902 r
.8618 .16187 m
.8618 .4708 L
.86224 .4708 L
.86224 .16187 L
F
.2 .63 .79 r
.8618 .16187 m
.8618 .4708 L
.86224 .4708 L
.86224 .16187 L
s
.678 .847 .902 r
.86224 .16187 m
.86224 .47091 L
.86247 .47091 L
.86247 .16187 L
F
.2 .63 .79 r
.86224 .16187 m
.86224 .47091 L
.86247 .47091 L
.86247 .16187 L
s
.678 .847 .902 r
.86247 .16187 m
.86247 .47175 L
.86307 .47175 L
.86307 .16187 L
F
.2 .63 .79 r
.86247 .16187 m
.86247 .47175 L
.86307 .47175 L
.86307 .16187 L
s
.678 .847 .902 r
.86307 .16187 m
.86307 .4721 L
.8634 .4721 L
.8634 .16187 L
F
.2 .63 .79 r
.86307 .16187 m
.86307 .4721 L
.8634 .4721 L
.8634 .16187 L
s
.678 .847 .902 r
.8634 .16187 m
.8634 .47259 L
.86386 .47259 L
.86386 .16187 L
F
.2 .63 .79 r
.8634 .16187 m
.8634 .47259 L
.86386 .47259 L
.86386 .16187 L
s
.678 .847 .902 r
.86386 .16187 m
.86386 .47315 L
.8644 .47315 L
.8644 .16187 L
F
.2 .63 .79 r
.86386 .16187 m
.86386 .47315 L
.8644 .47315 L
.8644 .16187 L
s
.678 .847 .902 r
.8644 .16187 m
.8644 .47356 L
.86475 .47356 L
.86475 .16187 L
F
.2 .63 .79 r
.8644 .16187 m
.8644 .47356 L
.86475 .47356 L
.86475 .16187 L
s
.678 .847 .902 r
.86475 .16187 m
.86475 .47385 L
.86527 .47385 L
.86527 .16187 L
F
.2 .63 .79 r
.86475 .16187 m
.86475 .47385 L
.86527 .47385 L
.86527 .16187 L
s
.678 .847 .902 r
.86527 .16187 m
.86527 .4743 L
.86548 .4743 L
.86548 .16187 L
F
.2 .63 .79 r
.86527 .16187 m
.86527 .4743 L
.86548 .4743 L
.86548 .16187 L
s
.678 .847 .902 r
.86548 .16187 m
.86548 .47483 L
.86606 .47483 L
.86606 .16187 L
F
.2 .63 .79 r
.86548 .16187 m
.86548 .47483 L
.86606 .47483 L
.86606 .16187 L
s
.678 .847 .902 r
.86606 .16187 m
.86606 .47513 L
.86648 .47513 L
.86648 .16187 L
F
.2 .63 .79 r
.86606 .16187 m
.86606 .47513 L
.86648 .47513 L
.86648 .16187 L
s
.678 .847 .902 r
.86648 .16187 m
.86648 .4759 L
.86683 .4759 L
.86683 .16187 L
F
.2 .63 .79 r
.86648 .16187 m
.86648 .4759 L
.86683 .4759 L
.86683 .16187 L
s
.678 .847 .902 r
.86683 .16187 m
.86683 .47618 L
.86733 .47618 L
.86733 .16187 L
F
.2 .63 .79 r
.86683 .16187 m
.86683 .47618 L
.86733 .47618 L
.86733 .16187 L
s
.678 .847 .902 r
.86733 .16187 m
.86733 .47655 L
.86758 .47655 L
.86758 .16187 L
F
.2 .63 .79 r
.86733 .16187 m
.86733 .47655 L
.86758 .47655 L
.86758 .16187 L
s
.678 .847 .902 r
.86758 .16187 m
.86758 .47694 L
.86781 .47694 L
.86781 .16187 L
F
.2 .63 .79 r
.86758 .16187 m
.86758 .47694 L
.86781 .47694 L
.86781 .16187 L
s
.678 .847 .902 r
.86781 .16187 m
.86781 .47703 L
.86833 .47703 L
.86833 .16187 L
F
.2 .63 .79 r
.86781 .16187 m
.86781 .47703 L
.86833 .47703 L
.86833 .16187 L
s
.678 .847 .902 r
.86833 .16187 m
.86833 .47799 L
.86883 .47799 L
.86883 .16187 L
F
.2 .63 .79 r
.86833 .16187 m
.86833 .47799 L
.86883 .47799 L
.86883 .16187 L
s
.678 .847 .902 r
.86883 .16187 m
.86883 .47869 L
.86944 .47869 L
.86944 .16187 L
F
.2 .63 .79 r
.86883 .16187 m
.86883 .47869 L
.86944 .47869 L
.86944 .16187 L
s
.678 .847 .902 r
.86944 .16187 m
.86944 .47902 L
.86986 .47902 L
.86986 .16187 L
F
.2 .63 .79 r
.86944 .16187 m
.86944 .47902 L
.86986 .47902 L
.86986 .16187 L
s
.678 .847 .902 r
.86986 .16187 m
.86986 .47965 L
.87043 .47965 L
.87043 .16187 L
F
.2 .63 .79 r
.86986 .16187 m
.86986 .47965 L
.87043 .47965 L
.87043 .16187 L
s
.678 .847 .902 r
.87043 .16187 m
.87043 .48002 L
.87093 .48002 L
.87093 .16187 L
F
.2 .63 .79 r
.87043 .16187 m
.87043 .48002 L
.87093 .48002 L
.87093 .16187 L
s
.678 .847 .902 r
.87093 .16187 m
.87093 .48066 L
.87119 .48066 L
.87119 .16187 L
F
.2 .63 .79 r
.87093 .16187 m
.87093 .48066 L
.87119 .48066 L
.87119 .16187 L
s
.678 .847 .902 r
.87119 .16187 m
.87119 .48087 L
.87144 .48087 L
.87144 .16187 L
F
.2 .63 .79 r
.87119 .16187 m
.87119 .48087 L
.87144 .48087 L
.87144 .16187 L
s
.678 .847 .902 r
.87144 .16187 m
.87144 .48123 L
.87177 .48123 L
.87177 .16187 L
F
.2 .63 .79 r
.87144 .16187 m
.87144 .48123 L
.87177 .48123 L
.87177 .16187 L
s
.678 .847 .902 r
.87177 .16187 m
.87177 .48147 L
.87202 .48147 L
.87202 .16187 L
F
.2 .63 .79 r
.87177 .16187 m
.87177 .48147 L
.87202 .48147 L
.87202 .16187 L
s
.678 .847 .902 r
.87202 .16187 m
.87202 .48181 L
.87225 .48181 L
.87225 .16187 L
F
.2 .63 .79 r
.87202 .16187 m
.87202 .48181 L
.87225 .48181 L
.87225 .16187 L
s
.678 .847 .902 r
.87225 .16187 m
.87225 .48208 L
.87254 .48208 L
.87254 .16187 L
F
.2 .63 .79 r
.87225 .16187 m
.87225 .48208 L
.87254 .48208 L
.87254 .16187 L
s
.678 .847 .902 r
.87254 .16187 m
.87254 .48236 L
.87273 .48236 L
.87273 .16187 L
F
.2 .63 .79 r
.87254 .16187 m
.87254 .48236 L
.87273 .48236 L
.87273 .16187 L
s
.678 .847 .902 r
.87273 .16187 m
.87273 .48269 L
.87316 .48269 L
.87316 .16187 L
F
.2 .63 .79 r
.87273 .16187 m
.87273 .48269 L
.87316 .48269 L
.87316 .16187 L
s
.678 .847 .902 r
.87316 .16187 m
.87316 .48322 L
.87349 .48322 L
.87349 .16187 L
F
.2 .63 .79 r
.87316 .16187 m
.87316 .48322 L
.87349 .48322 L
.87349 .16187 L
s
.678 .847 .902 r
.87349 .16187 m
.87349 .48378 L
.87405 .48378 L
.87405 .16187 L
F
.2 .63 .79 r
.87349 .16187 m
.87349 .48378 L
.87405 .48378 L
.87405 .16187 L
s
.678 .847 .902 r
.87405 .16187 m
.87405 .48402 L
.87437 .48402 L
.87437 .16187 L
F
.2 .63 .79 r
.87405 .16187 m
.87405 .48402 L
.87437 .48402 L
.87437 .16187 L
s
.678 .847 .902 r
.87437 .16187 m
.87437 .48427 L
.87478 .48427 L
.87478 .16187 L
F
.2 .63 .79 r
.87437 .16187 m
.87437 .48427 L
.87478 .48427 L
.87478 .16187 L
s
.678 .847 .902 r
.87478 .16187 m
.87478 .4848 L
.87516 .4848 L
.87516 .16187 L
F
.2 .63 .79 r
.87478 .16187 m
.87478 .4848 L
.87516 .4848 L
.87516 .16187 L
s
.678 .847 .902 r
.87516 .16187 m
.87516 .48535 L
.8755 .48535 L
.8755 .16187 L
F
.2 .63 .79 r
.87516 .16187 m
.87516 .48535 L
.8755 .48535 L
.8755 .16187 L
s
.678 .847 .902 r
.8755 .16187 m
.8755 .48578 L
.8761 .48578 L
.8761 .16187 L
F
.2 .63 .79 r
.8755 .16187 m
.8755 .48578 L
.8761 .48578 L
.8761 .16187 L
s
.678 .847 .902 r
.8761 .16187 m
.8761 .48652 L
.87665 .48652 L
.87665 .16187 L
F
.2 .63 .79 r
.8761 .16187 m
.8761 .48652 L
.87665 .48652 L
.87665 .16187 L
s
.678 .847 .902 r
.87665 .16187 m
.87665 .48672 L
.87698 .48672 L
.87698 .16187 L
F
.2 .63 .79 r
.87665 .16187 m
.87665 .48672 L
.87698 .48672 L
.87698 .16187 L
s
.678 .847 .902 r
.87698 .16187 m
.87698 .48738 L
.87728 .48738 L
.87728 .16187 L
F
.2 .63 .79 r
.87698 .16187 m
.87698 .48738 L
.87728 .48738 L
.87728 .16187 L
s
.678 .847 .902 r
.87728 .16187 m
.87728 .48753 L
.87755 .48753 L
.87755 .16187 L
F
.2 .63 .79 r
.87728 .16187 m
.87728 .48753 L
.87755 .48753 L
.87755 .16187 L
s
.678 .847 .902 r
.87755 .16187 m
.87755 .48794 L
.87779 .48794 L
.87779 .16187 L
F
.2 .63 .79 r
.87755 .16187 m
.87755 .48794 L
.87779 .48794 L
.87779 .16187 L
s
.678 .847 .902 r
.87779 .16187 m
.87779 .48802 L
.87815 .48802 L
.87815 .16187 L
F
.2 .63 .79 r
.87779 .16187 m
.87779 .48802 L
.87815 .48802 L
.87815 .16187 L
s
.678 .847 .902 r
.87815 .16187 m
.87815 .48858 L
.87866 .48858 L
.87866 .16187 L
F
.2 .63 .79 r
.87815 .16187 m
.87815 .48858 L
.87866 .48858 L
.87866 .16187 L
s
.678 .847 .902 r
.87866 .16187 m
.87866 .48922 L
.879 .48922 L
.879 .16187 L
F
.2 .63 .79 r
.87866 .16187 m
.87866 .48922 L
.879 .48922 L
.879 .16187 L
s
.678 .847 .902 r
.879 .16187 m
.879 .48956 L
.87938 .48956 L
.87938 .16187 L
F
.2 .63 .79 r
.879 .16187 m
.879 .48956 L
.87938 .48956 L
.87938 .16187 L
s
.678 .847 .902 r
.87938 .16187 m
.87938 .4898 L
.87967 .4898 L
.87967 .16187 L
F
.2 .63 .79 r
.87938 .16187 m
.87938 .4898 L
.87967 .4898 L
.87967 .16187 L
s
.678 .847 .902 r
.87967 .16187 m
.87967 .49042 L
.88013 .49042 L
.88013 .16187 L
F
.2 .63 .79 r
.87967 .16187 m
.87967 .49042 L
.88013 .49042 L
.88013 .16187 L
s
.678 .847 .902 r
.88013 .16187 m
.88013 .49079 L
.88033 .49079 L
.88033 .16187 L
F
.2 .63 .79 r
.88013 .16187 m
.88013 .49079 L
.88033 .49079 L
.88033 .16187 L
s
.678 .847 .902 r
.88033 .16187 m
.88033 .49081 L
.88064 .49081 L
.88064 .16187 L
F
.2 .63 .79 r
.88033 .16187 m
.88033 .49081 L
.88064 .49081 L
.88064 .16187 L
s
.678 .847 .902 r
.88064 .16187 m
.88064 .49124 L
.88089 .49124 L
.88089 .16187 L
F
.2 .63 .79 r
.88064 .16187 m
.88064 .49124 L
.88089 .49124 L
.88089 .16187 L
s
.678 .847 .902 r
.88089 .16187 m
.88089 .49182 L
.88126 .49182 L
.88126 .16187 L
F
.2 .63 .79 r
.88089 .16187 m
.88089 .49182 L
.88126 .49182 L
.88126 .16187 L
s
.678 .847 .902 r
.88126 .16187 m
.88126 .49185 L
.88146 .49185 L
.88146 .16187 L
F
.2 .63 .79 r
.88126 .16187 m
.88126 .49185 L
.88146 .49185 L
.88146 .16187 L
s
.678 .847 .902 r
.88146 .16187 m
.88146 .49229 L
.88198 .49229 L
.88198 .16187 L
F
.2 .63 .79 r
.88146 .16187 m
.88146 .49229 L
.88198 .49229 L
.88198 .16187 L
s
.678 .847 .902 r
.88198 .16187 m
.88198 .49286 L
.88254 .49286 L
.88254 .16187 L
F
.2 .63 .79 r
.88198 .16187 m
.88198 .49286 L
.88254 .49286 L
.88254 .16187 L
s
.678 .847 .902 r
.88254 .16187 m
.88254 .49328 L
.88299 .49328 L
.88299 .16187 L
F
.2 .63 .79 r
.88254 .16187 m
.88254 .49328 L
.88299 .49328 L
.88299 .16187 L
s
.678 .847 .902 r
.88299 .16187 m
.88299 .49409 L
.8835 .49409 L
.8835 .16187 L
F
.2 .63 .79 r
.88299 .16187 m
.88299 .49409 L
.8835 .49409 L
.8835 .16187 L
s
.678 .847 .902 r
.8835 .16187 m
.8835 .49441 L
.88381 .49441 L
.88381 .16187 L
F
.2 .63 .79 r
.8835 .16187 m
.8835 .49441 L
.88381 .49441 L
.88381 .16187 L
s
.678 .847 .902 r
.88381 .16187 m
.88381 .49466 L
.88418 .49466 L
.88418 .16187 L
F
.2 .63 .79 r
.88381 .16187 m
.88381 .49466 L
.88418 .49466 L
.88418 .16187 L
s
.678 .847 .902 r
.88418 .16187 m
.88418 .49517 L
.88447 .49517 L
.88447 .16187 L
F
.2 .63 .79 r
.88418 .16187 m
.88418 .49517 L
.88447 .49517 L
.88447 .16187 L
s
.678 .847 .902 r
.88447 .16187 m
.88447 .49545 L
.88503 .49545 L
.88503 .16187 L
F
.2 .63 .79 r
.88447 .16187 m
.88447 .49545 L
.88503 .49545 L
.88503 .16187 L
s
.678 .847 .902 r
.88503 .16187 m
.88503 .49627 L
.88542 .49627 L
.88542 .16187 L
F
.2 .63 .79 r
.88503 .16187 m
.88503 .49627 L
.88542 .49627 L
.88542 .16187 L
s
.678 .847 .902 r
.88542 .16187 m
.88542 .49673 L
.88566 .49673 L
.88566 .16187 L
F
.2 .63 .79 r
.88542 .16187 m
.88542 .49673 L
.88566 .49673 L
.88566 .16187 L
s
.678 .847 .902 r
.88566 .16187 m
.88566 .49698 L
.88629 .49698 L
.88629 .16187 L
F
.2 .63 .79 r
.88566 .16187 m
.88566 .49698 L
.88629 .49698 L
.88629 .16187 L
s
.678 .847 .902 r
.88629 .16187 m
.88629 .49779 L
.88676 .49779 L
.88676 .16187 L
F
.2 .63 .79 r
.88629 .16187 m
.88629 .49779 L
.88676 .49779 L
.88676 .16187 L
s
.678 .847 .902 r
.88676 .16187 m
.88676 .49822 L
.8871 .49822 L
.8871 .16187 L
F
.2 .63 .79 r
.88676 .16187 m
.88676 .49822 L
.8871 .49822 L
.8871 .16187 L
s
.678 .847 .902 r
.8871 .16187 m
.8871 .49885 L
.88762 .49885 L
.88762 .16187 L
F
.2 .63 .79 r
.8871 .16187 m
.8871 .49885 L
.88762 .49885 L
.88762 .16187 L
s
.678 .847 .902 r
.88762 .16187 m
.88762 .49927 L
.88793 .49927 L
.88793 .16187 L
F
.2 .63 .79 r
.88762 .16187 m
.88762 .49927 L
.88793 .49927 L
.88793 .16187 L
s
.678 .847 .902 r
.88793 .16187 m
.88793 .49961 L
.88825 .49961 L
.88825 .16187 L
F
.2 .63 .79 r
.88793 .16187 m
.88793 .49961 L
.88825 .49961 L
.88825 .16187 L
s
.678 .847 .902 r
.88825 .16187 m
.88825 .49971 L
.88886 .49971 L
.88886 .16187 L
F
.2 .63 .79 r
.88825 .16187 m
.88825 .49971 L
.88886 .49971 L
.88886 .16187 L
s
.678 .847 .902 r
.88886 .16187 m
.88886 .50062 L
.88928 .50062 L
.88928 .16187 L
F
.2 .63 .79 r
.88886 .16187 m
.88886 .50062 L
.88928 .50062 L
.88928 .16187 L
s
.678 .847 .902 r
.88928 .16187 m
.88928 .50094 L
.88976 .50094 L
.88976 .16187 L
F
.2 .63 .79 r
.88928 .16187 m
.88928 .50094 L
.88976 .50094 L
.88976 .16187 L
s
.678 .847 .902 r
.88976 .16187 m
.88976 .50167 L
.89008 .50167 L
.89008 .16187 L
F
.2 .63 .79 r
.88976 .16187 m
.88976 .50167 L
.89008 .50167 L
.89008 .16187 L
s
.678 .847 .902 r
.89008 .16187 m
.89008 .50171 L
.89056 .50171 L
.89056 .16187 L
F
.2 .63 .79 r
.89008 .16187 m
.89008 .50171 L
.89056 .50171 L
.89056 .16187 L
s
.678 .847 .902 r
.89056 .16187 m
.89056 .50234 L
.89093 .50234 L
.89093 .16187 L
F
.2 .63 .79 r
.89056 .16187 m
.89056 .50234 L
.89093 .50234 L
.89093 .16187 L
s
.678 .847 .902 r
.89093 .16187 m
.89093 .50275 L
.89123 .50275 L
.89123 .16187 L
F
.2 .63 .79 r
.89093 .16187 m
.89093 .50275 L
.89123 .50275 L
.89123 .16187 L
s
.678 .847 .902 r
.89123 .16187 m
.89123 .50328 L
.89154 .50328 L
.89154 .16187 L
F
.2 .63 .79 r
.89123 .16187 m
.89123 .50328 L
.89154 .50328 L
.89154 .16187 L
s
.678 .847 .902 r
.89154 .16187 m
.89154 .50375 L
.89214 .50375 L
.89214 .16187 L
F
.2 .63 .79 r
.89154 .16187 m
.89154 .50375 L
.89214 .50375 L
.89214 .16187 L
s
.678 .847 .902 r
.89214 .16187 m
.89214 .50445 L
.89258 .50445 L
.89258 .16187 L
F
.2 .63 .79 r
.89214 .16187 m
.89214 .50445 L
.89258 .50445 L
.89258 .16187 L
s
.678 .847 .902 r
.89258 .16187 m
.89258 .50464 L
.89307 .50464 L
.89307 .16187 L
F
.2 .63 .79 r
.89258 .16187 m
.89258 .50464 L
.89307 .50464 L
.89307 .16187 L
s
.678 .847 .902 r
.89307 .16187 m
.89307 .50518 L
.89351 .50518 L
.89351 .16187 L
F
.2 .63 .79 r
.89307 .16187 m
.89307 .50518 L
.89351 .50518 L
.89351 .16187 L
s
.678 .847 .902 r
.89351 .16187 m
.89351 .50577 L
.894 .50577 L
.894 .16187 L
F
.2 .63 .79 r
.89351 .16187 m
.89351 .50577 L
.894 .50577 L
.894 .16187 L
s
.678 .847 .902 r
.894 .16187 m
.894 .50637 L
.89426 .50637 L
.89426 .16187 L
F
.2 .63 .79 r
.894 .16187 m
.894 .50637 L
.89426 .50637 L
.89426 .16187 L
s
.678 .847 .902 r
.89426 .16187 m
.89426 .50683 L
.89465 .50683 L
.89465 .16187 L
F
.2 .63 .79 r
.89426 .16187 m
.89426 .50683 L
.89465 .50683 L
.89465 .16187 L
s
.678 .847 .902 r
.89465 .16187 m
.89465 .50694 L
.89517 .50694 L
.89517 .16187 L
F
.2 .63 .79 r
.89465 .16187 m
.89465 .50694 L
.89517 .50694 L
.89517 .16187 L
s
.678 .847 .902 r
.89517 .16187 m
.89517 .5077 L
.89546 .5077 L
.89546 .16187 L
F
.2 .63 .79 r
.89517 .16187 m
.89517 .5077 L
.89546 .5077 L
.89546 .16187 L
s
.678 .847 .902 r
.89546 .16187 m
.89546 .50798 L
.89567 .50798 L
.89567 .16187 L
F
.2 .63 .79 r
.89546 .16187 m
.89546 .50798 L
.89567 .50798 L
.89567 .16187 L
s
.678 .847 .902 r
.89567 .16187 m
.89567 .50827 L
.89607 .50827 L
.89607 .16187 L
F
.2 .63 .79 r
.89567 .16187 m
.89567 .50827 L
.89607 .50827 L
.89607 .16187 L
s
.678 .847 .902 r
.89607 .16187 m
.89607 .50858 L
.8963 .50858 L
.8963 .16187 L
F
.2 .63 .79 r
.89607 .16187 m
.89607 .50858 L
.8963 .50858 L
.8963 .16187 L
s
.678 .847 .902 r
.8963 .16187 m
.8963 .50883 L
.89689 .50883 L
.89689 .16187 L
F
.2 .63 .79 r
.8963 .16187 m
.8963 .50883 L
.89689 .50883 L
.89689 .16187 L
s
.678 .847 .902 r
.89689 .16187 m
.89689 .5094 L
.89722 .5094 L
.89722 .16187 L
F
.2 .63 .79 r
.89689 .16187 m
.89689 .5094 L
.89722 .5094 L
.89722 .16187 L
s
.678 .847 .902 r
.89722 .16187 m
.89722 .50996 L
.89751 .50996 L
.89751 .16187 L
F
.2 .63 .79 r
.89722 .16187 m
.89722 .50996 L
.89751 .50996 L
.89751 .16187 L
s
.678 .847 .902 r
.89751 .16187 m
.89751 .51043 L
.89805 .51043 L
.89805 .16187 L
F
.2 .63 .79 r
.89751 .16187 m
.89751 .51043 L
.89805 .51043 L
.89805 .16187 L
s
.678 .847 .902 r
.89805 .16187 m
.89805 .51075 L
.89867 .51075 L
.89867 .16187 L
F
.2 .63 .79 r
.89805 .16187 m
.89805 .51075 L
.89867 .51075 L
.89867 .16187 L
s
.678 .847 .902 r
.89867 .16187 m
.89867 .51165 L
.89921 .51165 L
.89921 .16187 L
F
.2 .63 .79 r
.89867 .16187 m
.89867 .51165 L
.89921 .51165 L
.89921 .16187 L
s
.678 .847 .902 r
.89921 .16187 m
.89921 .5122 L
.89967 .5122 L
.89967 .16187 L
F
.2 .63 .79 r
.89921 .16187 m
.89921 .5122 L
.89967 .5122 L
.89967 .16187 L
s
.678 .847 .902 r
.89967 .16187 m
.89967 .51283 L
.90007 .51283 L
.90007 .16187 L
F
.2 .63 .79 r
.89967 .16187 m
.89967 .51283 L
.90007 .51283 L
.90007 .16187 L
s
.678 .847 .902 r
.90007 .16187 m
.90007 .51301 L
.9004 .51301 L
.9004 .16187 L
F
.2 .63 .79 r
.90007 .16187 m
.90007 .51301 L
.9004 .51301 L
.9004 .16187 L
s
.678 .847 .902 r
.9004 .16187 m
.9004 .51343 L
.90078 .51343 L
.90078 .16187 L
F
.2 .63 .79 r
.9004 .16187 m
.9004 .51343 L
.90078 .51343 L
.90078 .16187 L
s
.678 .847 .902 r
.90078 .16187 m
.90078 .51381 L
.90112 .51381 L
.90112 .16187 L
F
.2 .63 .79 r
.90078 .16187 m
.90078 .51381 L
.90112 .51381 L
.90112 .16187 L
s
.678 .847 .902 r
.90112 .16187 m
.90112 .51445 L
.9014 .51445 L
.9014 .16187 L
F
.2 .63 .79 r
.90112 .16187 m
.90112 .51445 L
.9014 .51445 L
.9014 .16187 L
s
.678 .847 .902 r
.9014 .16187 m
.9014 .51468 L
.90177 .51468 L
.90177 .16187 L
F
.2 .63 .79 r
.9014 .16187 m
.9014 .51468 L
.90177 .51468 L
.90177 .16187 L
s
.678 .847 .902 r
.90177 .16187 m
.90177 .5151 L
.90234 .5151 L
.90234 .16187 L
F
.2 .63 .79 r
.90177 .16187 m
.90177 .5151 L
.90234 .5151 L
.90234 .16187 L
s
.678 .847 .902 r
.90234 .16187 m
.90234 .51603 L
.90283 .51603 L
.90283 .16187 L
F
.2 .63 .79 r
.90234 .16187 m
.90234 .51603 L
.90283 .51603 L
.90283 .16187 L
s
.678 .847 .902 r
.90283 .16187 m
.90283 .51645 L
.90332 .51645 L
.90332 .16187 L
F
.2 .63 .79 r
.90283 .16187 m
.90283 .51645 L
.90332 .51645 L
.90332 .16187 L
s
.678 .847 .902 r
.90332 .16187 m
.90332 .51672 L
.90383 .51672 L
.90383 .16187 L
F
.2 .63 .79 r
.90332 .16187 m
.90332 .51672 L
.90383 .51672 L
.90383 .16187 L
s
.678 .847 .902 r
.90383 .16187 m
.90383 .51749 L
.90434 .51749 L
.90434 .16187 L
F
.2 .63 .79 r
.90383 .16187 m
.90383 .51749 L
.90434 .51749 L
.90434 .16187 L
s
.678 .847 .902 r
.90434 .16187 m
.90434 .51814 L
.90463 .51814 L
.90463 .16187 L
F
.2 .63 .79 r
.90434 .16187 m
.90434 .51814 L
.90463 .51814 L
.90463 .16187 L
s
.678 .847 .902 r
.90463 .16187 m
.90463 .51848 L
.90523 .51848 L
.90523 .16187 L
F
.2 .63 .79 r
.90463 .16187 m
.90463 .51848 L
.90523 .51848 L
.90523 .16187 L
s
.678 .847 .902 r
.90523 .16187 m
.90523 .51898 L
.90565 .51898 L
.90565 .16187 L
F
.2 .63 .79 r
.90523 .16187 m
.90523 .51898 L
.90565 .51898 L
.90565 .16187 L
s
.678 .847 .902 r
.90565 .16187 m
.90565 .51961 L
.90613 .51961 L
.90613 .16187 L
F
.2 .63 .79 r
.90565 .16187 m
.90565 .51961 L
.90613 .51961 L
.90613 .16187 L
s
.678 .847 .902 r
.90613 .16187 m
.90613 .52006 L
.90666 .52006 L
.90666 .16187 L
F
.2 .63 .79 r
.90613 .16187 m
.90613 .52006 L
.90666 .52006 L
.90666 .16187 L
s
.678 .847 .902 r
.90666 .16187 m
.90666 .52111 L
.90723 .52111 L
.90723 .16187 L
F
.2 .63 .79 r
.90666 .16187 m
.90666 .52111 L
.90723 .52111 L
.90723 .16187 L
s
.678 .847 .902 r
.90723 .16187 m
.90723 .52118 L
.90769 .52118 L
.90769 .16187 L
F
.2 .63 .79 r
.90723 .16187 m
.90723 .52118 L
.90769 .52118 L
.90769 .16187 L
s
.678 .847 .902 r
.90769 .16187 m
.90769 .52186 L
.90804 .52186 L
.90804 .16187 L
F
.2 .63 .79 r
.90769 .16187 m
.90769 .52186 L
.90804 .52186 L
.90804 .16187 L
s
.678 .847 .902 r
.90804 .16187 m
.90804 .5224 L
.90847 .5224 L
.90847 .16187 L
F
.2 .63 .79 r
.90804 .16187 m
.90804 .5224 L
.90847 .5224 L
.90847 .16187 L
s
.678 .847 .902 r
.90847 .16187 m
.90847 .52267 L
.90869 .52267 L
.90869 .16187 L
F
.2 .63 .79 r
.90847 .16187 m
.90847 .52267 L
.90869 .52267 L
.90869 .16187 L
s
.678 .847 .902 r
.90869 .16187 m
.90869 .52337 L
.90917 .52337 L
.90917 .16187 L
F
.2 .63 .79 r
.90869 .16187 m
.90869 .52337 L
.90917 .52337 L
.90917 .16187 L
s
.678 .847 .902 r
.90917 .16187 m
.90917 .5234 L
.90961 .5234 L
.90961 .16187 L
F
.2 .63 .79 r
.90917 .16187 m
.90917 .5234 L
.90961 .5234 L
.90961 .16187 L
s
.678 .847 .902 r
.90961 .16187 m
.90961 .52408 L
.91023 .52408 L
.91023 .16187 L
F
.2 .63 .79 r
.90961 .16187 m
.90961 .52408 L
.91023 .52408 L
.91023 .16187 L
s
.678 .847 .902 r
.91023 .16187 m
.91023 .52497 L
.91067 .52497 L
.91067 .16187 L
F
.2 .63 .79 r
.91023 .16187 m
.91023 .52497 L
.91067 .52497 L
.91067 .16187 L
s
.678 .847 .902 r
.91067 .16187 m
.91067 .52549 L
.91102 .52549 L
.91102 .16187 L
F
.2 .63 .79 r
.91067 .16187 m
.91067 .52549 L
.91102 .52549 L
.91102 .16187 L
s
.678 .847 .902 r
.91102 .16187 m
.91102 .52577 L
.91127 .52577 L
.91127 .16187 L
F
.2 .63 .79 r
.91102 .16187 m
.91102 .52577 L
.91127 .52577 L
.91127 .16187 L
s
.678 .847 .902 r
.91127 .16187 m
.91127 .52592 L
.91174 .52592 L
.91174 .16187 L
F
.2 .63 .79 r
.91127 .16187 m
.91127 .52592 L
.91174 .52592 L
.91174 .16187 L
s
.678 .847 .902 r
.91174 .16187 m
.91174 .52671 L
.91209 .52671 L
.91209 .16187 L
F
.2 .63 .79 r
.91174 .16187 m
.91174 .52671 L
.91209 .52671 L
.91209 .16187 L
s
.678 .847 .902 r
.91209 .16187 m
.91209 .52711 L
.91271 .52711 L
.91271 .16187 L
F
.2 .63 .79 r
.91209 .16187 m
.91209 .52711 L
.91271 .52711 L
.91271 .16187 L
s
.678 .847 .902 r
.91271 .16187 m
.91271 .52769 L
.91303 .52769 L
.91303 .16187 L
F
.2 .63 .79 r
.91271 .16187 m
.91271 .52769 L
.91303 .52769 L
.91303 .16187 L
s
.678 .847 .902 r
.91303 .16187 m
.91303 .52812 L
.91364 .52812 L
.91364 .16187 L
F
.2 .63 .79 r
.91303 .16187 m
.91303 .52812 L
.91364 .52812 L
.91364 .16187 L
s
.678 .847 .902 r
.91364 .16187 m
.91364 .52873 L
.91415 .52873 L
.91415 .16187 L
F
.2 .63 .79 r
.91364 .16187 m
.91364 .52873 L
.91415 .52873 L
.91415 .16187 L
s
.678 .847 .902 r
.91415 .16187 m
.91415 .52929 L
.91445 .52929 L
.91445 .16187 L
F
.2 .63 .79 r
.91415 .16187 m
.91415 .52929 L
.91445 .52929 L
.91445 .16187 L
s
.678 .847 .902 r
.91445 .16187 m
.91445 .52959 L
.91491 .52959 L
.91491 .16187 L
F
.2 .63 .79 r
.91445 .16187 m
.91445 .52959 L
.91491 .52959 L
.91491 .16187 L
s
.678 .847 .902 r
.91491 .16187 m
.91491 .53032 L
.91541 .53032 L
.91541 .16187 L
F
.2 .63 .79 r
.91491 .16187 m
.91491 .53032 L
.91541 .53032 L
.91541 .16187 L
s
.678 .847 .902 r
.91541 .16187 m
.91541 .53116 L
.91596 .53116 L
.91596 .16187 L
F
.2 .63 .79 r
.91541 .16187 m
.91541 .53116 L
.91596 .53116 L
.91596 .16187 L
s
.678 .847 .902 r
.91596 .16187 m
.91596 .53136 L
.91648 .53136 L
.91648 .16187 L
F
.2 .63 .79 r
.91596 .16187 m
.91596 .53136 L
.91648 .53136 L
.91648 .16187 L
s
.678 .847 .902 r
.91648 .16187 m
.91648 .53235 L
.91709 .53235 L
.91709 .16187 L
F
.2 .63 .79 r
.91648 .16187 m
.91648 .53235 L
.91709 .53235 L
.91709 .16187 L
s
.678 .847 .902 r
.91709 .16187 m
.91709 .53274 L
.9177 .53274 L
.9177 .16187 L
F
.2 .63 .79 r
.91709 .16187 m
.91709 .53274 L
.9177 .53274 L
.9177 .16187 L
s
.678 .847 .902 r
.9177 .16187 m
.9177 .53394 L
.91832 .53394 L
.91832 .16187 L
F
.2 .63 .79 r
.9177 .16187 m
.9177 .53394 L
.91832 .53394 L
.91832 .16187 L
s
.678 .847 .902 r
.91832 .16187 m
.91832 .53401 L
.91856 .53401 L
.91856 .16187 L
F
.2 .63 .79 r
.91832 .16187 m
.91832 .53401 L
.91856 .53401 L
.91856 .16187 L
s
.678 .847 .902 r
.91856 .16187 m
.91856 .53441 L
.91902 .53441 L
.91902 .16187 L
F
.2 .63 .79 r
.91856 .16187 m
.91856 .53441 L
.91902 .53441 L
.91902 .16187 L
s
.678 .847 .902 r
.91902 .16187 m
.91902 .53506 L
.91939 .53506 L
.91939 .16187 L
F
.2 .63 .79 r
.91902 .16187 m
.91902 .53506 L
.91939 .53506 L
.91939 .16187 L
s
.678 .847 .902 r
.91939 .16187 m
.91939 .53563 L
.91998 .53563 L
.91998 .16187 L
F
.2 .63 .79 r
.91939 .16187 m
.91939 .53563 L
.91998 .53563 L
.91998 .16187 L
s
.678 .847 .902 r
.91998 .16187 m
.91998 .53601 L
.92038 .53601 L
.92038 .16187 L
F
.2 .63 .79 r
.91998 .16187 m
.91998 .53601 L
.92038 .53601 L
.92038 .16187 L
s
.678 .847 .902 r
.92038 .16187 m
.92038 .53643 L
.9206 .53643 L
.9206 .16187 L
F
.2 .63 .79 r
.92038 .16187 m
.92038 .53643 L
.9206 .53643 L
.9206 .16187 L
s
.678 .847 .902 r
.9206 .16187 m
.9206 .5368 L
.92098 .5368 L
.92098 .16187 L
F
.2 .63 .79 r
.9206 .16187 m
.9206 .5368 L
.92098 .5368 L
.92098 .16187 L
s
.678 .847 .902 r
.92098 .16187 m
.92098 .53742 L
.92132 .53742 L
.92132 .16187 L
F
.2 .63 .79 r
.92098 .16187 m
.92098 .53742 L
.92132 .53742 L
.92132 .16187 L
s
.678 .847 .902 r
.92132 .16187 m
.92132 .53755 L
.92157 .53755 L
.92157 .16187 L
F
.2 .63 .79 r
.92132 .16187 m
.92132 .53755 L
.92157 .53755 L
.92157 .16187 L
s
.678 .847 .902 r
.92157 .16187 m
.92157 .53805 L
.92216 .53805 L
.92216 .16187 L
F
.2 .63 .79 r
.92157 .16187 m
.92157 .53805 L
.92216 .53805 L
.92216 .16187 L
s
.678 .847 .902 r
.92216 .16187 m
.92216 .53857 L
.92273 .53857 L
.92273 .16187 L
F
.2 .63 .79 r
.92216 .16187 m
.92216 .53857 L
.92273 .53857 L
.92273 .16187 L
s
.678 .847 .902 r
.92273 .16187 m
.92273 .5391 L
.92335 .5391 L
.92335 .16187 L
F
.2 .63 .79 r
.92273 .16187 m
.92273 .5391 L
.92335 .5391 L
.92335 .16187 L
s
.678 .847 .902 r
.92335 .16187 m
.92335 .54007 L
.92361 .54007 L
.92361 .16187 L
F
.2 .63 .79 r
.92335 .16187 m
.92335 .54007 L
.92361 .54007 L
.92361 .16187 L
s
.678 .847 .902 r
.92361 .16187 m
.92361 .54059 L
.92407 .54059 L
.92407 .16187 L
F
.2 .63 .79 r
.92361 .16187 m
.92361 .54059 L
.92407 .54059 L
.92407 .16187 L
s
.678 .847 .902 r
.92407 .16187 m
.92407 .54123 L
.92467 .54123 L
.92467 .16187 L
F
.2 .63 .79 r
.92407 .16187 m
.92407 .54123 L
.92467 .54123 L
.92467 .16187 L
s
.678 .847 .902 r
.92467 .16187 m
.92467 .54161 L
.92497 .54161 L
.92497 .16187 L
F
.2 .63 .79 r
.92467 .16187 m
.92467 .54161 L
.92497 .54161 L
.92497 .16187 L
s
.678 .847 .902 r
.92497 .16187 m
.92497 .54199 L
.92557 .54199 L
.92557 .16187 L
F
.2 .63 .79 r
.92497 .16187 m
.92497 .54199 L
.92557 .54199 L
.92557 .16187 L
s
.678 .847 .902 r
.92557 .16187 m
.92557 .54257 L
.92577 .54257 L
.92577 .16187 L
F
.2 .63 .79 r
.92557 .16187 m
.92557 .54257 L
.92577 .54257 L
.92577 .16187 L
s
.678 .847 .902 r
.92577 .16187 m
.92577 .54274 L
.92605 .54274 L
.92605 .16187 L
F
.2 .63 .79 r
.92577 .16187 m
.92577 .54274 L
.92605 .54274 L
.92605 .16187 L
s
.678 .847 .902 r
.92605 .16187 m
.92605 .54335 L
.92645 .54335 L
.92645 .16187 L
F
.2 .63 .79 r
.92605 .16187 m
.92605 .54335 L
.92645 .54335 L
.92645 .16187 L
s
.678 .847 .902 r
.92645 .16187 m
.92645 .54349 L
.92672 .54349 L
.92672 .16187 L
F
.2 .63 .79 r
.92645 .16187 m
.92645 .54349 L
.92672 .54349 L
.92672 .16187 L
s
.678 .847 .902 r
.92672 .16187 m
.92672 .54401 L
.92695 .54401 L
.92695 .16187 L
F
.2 .63 .79 r
.92672 .16187 m
.92672 .54401 L
.92695 .54401 L
.92695 .16187 L
s
.678 .847 .902 r
.92695 .16187 m
.92695 .54439 L
.92726 .54439 L
.92726 .16187 L
F
.2 .63 .79 r
.92695 .16187 m
.92695 .54439 L
.92726 .54439 L
.92726 .16187 L
s
.678 .847 .902 r
.92726 .16187 m
.92726 .5448 L
.92768 .5448 L
.92768 .16187 L
F
.2 .63 .79 r
.92726 .16187 m
.92726 .5448 L
.92768 .5448 L
.92768 .16187 L
s
.678 .847 .902 r
.92768 .16187 m
.92768 .54512 L
.92789 .54512 L
.92789 .16187 L
F
.2 .63 .79 r
.92768 .16187 m
.92768 .54512 L
.92789 .54512 L
.92789 .16187 L
s
.678 .847 .902 r
.92789 .16187 m
.92789 .54542 L
.9283 .54542 L
.9283 .16187 L
F
.2 .63 .79 r
.92789 .16187 m
.92789 .54542 L
.9283 .54542 L
.9283 .16187 L
s
.678 .847 .902 r
.9283 .16187 m
.9283 .54583 L
.92887 .54583 L
.92887 .16187 L
F
.2 .63 .79 r
.9283 .16187 m
.9283 .54583 L
.92887 .54583 L
.92887 .16187 L
s
.678 .847 .902 r
.92887 .16187 m
.92887 .5464 L
.92934 .5464 L
.92934 .16187 L
F
.2 .63 .79 r
.92887 .16187 m
.92887 .5464 L
.92934 .5464 L
.92934 .16187 L
s
.678 .847 .902 r
.92934 .16187 m
.92934 .54721 L
.92979 .54721 L
.92979 .16187 L
F
.2 .63 .79 r
.92934 .16187 m
.92934 .54721 L
.92979 .54721 L
.92979 .16187 L
s
.678 .847 .902 r
.92979 .16187 m
.92979 .5475 L
.93018 .5475 L
.93018 .16187 L
F
.2 .63 .79 r
.92979 .16187 m
.92979 .5475 L
.93018 .5475 L
.93018 .16187 L
s
.678 .847 .902 r
.93018 .16187 m
.93018 .54822 L
.93056 .54822 L
.93056 .16187 L
F
.2 .63 .79 r
.93018 .16187 m
.93018 .54822 L
.93056 .54822 L
.93056 .16187 L
s
.678 .847 .902 r
.93056 .16187 m
.93056 .54837 L
.93087 .54837 L
.93087 .16187 L
F
.2 .63 .79 r
.93056 .16187 m
.93056 .54837 L
.93087 .54837 L
.93087 .16187 L
s
.678 .847 .902 r
.93087 .16187 m
.93087 .54881 L
.93128 .54881 L
.93128 .16187 L
F
.2 .63 .79 r
.93087 .16187 m
.93087 .54881 L
.93128 .54881 L
.93128 .16187 L
s
.678 .847 .902 r
.93128 .16187 m
.93128 .54953 L
.93171 .54953 L
.93171 .16187 L
F
.2 .63 .79 r
.93128 .16187 m
.93128 .54953 L
.93171 .54953 L
.93171 .16187 L
s
.678 .847 .902 r
.93171 .16187 m
.93171 .54998 L
.93216 .54998 L
.93216 .16187 L
F
.2 .63 .79 r
.93171 .16187 m
.93171 .54998 L
.93216 .54998 L
.93216 .16187 L
s
.678 .847 .902 r
.93216 .16187 m
.93216 .55025 L
.93248 .55025 L
.93248 .16187 L
F
.2 .63 .79 r
.93216 .16187 m
.93216 .55025 L
.93248 .55025 L
.93248 .16187 L
s
.678 .847 .902 r
.93248 .16187 m
.93248 .55075 L
.93282 .55075 L
.93282 .16187 L
F
.2 .63 .79 r
.93248 .16187 m
.93248 .55075 L
.93282 .55075 L
.93282 .16187 L
s
.678 .847 .902 r
.93282 .16187 m
.93282 .55162 L
.93343 .55162 L
.93343 .16187 L
F
.2 .63 .79 r
.93282 .16187 m
.93282 .55162 L
.93343 .55162 L
.93343 .16187 L
s
.678 .847 .902 r
.93343 .16187 m
.93343 .55214 L
.93392 .55214 L
.93392 .16187 L
F
.2 .63 .79 r
.93343 .16187 m
.93343 .55214 L
.93392 .55214 L
.93392 .16187 L
s
.678 .847 .902 r
.93392 .16187 m
.93392 .55237 L
.93413 .55237 L
.93413 .16187 L
F
.2 .63 .79 r
.93392 .16187 m
.93392 .55237 L
.93413 .55237 L
.93413 .16187 L
s
.678 .847 .902 r
.93413 .16187 m
.93413 .55254 L
.93451 .55254 L
.93451 .16187 L
F
.2 .63 .79 r
.93413 .16187 m
.93413 .55254 L
.93451 .55254 L
.93451 .16187 L
s
.678 .847 .902 r
.93451 .16187 m
.93451 .55315 L
.9351 .55315 L
.9351 .16187 L
F
.2 .63 .79 r
.93451 .16187 m
.93451 .55315 L
.9351 .55315 L
.9351 .16187 L
s
.678 .847 .902 r
.9351 .16187 m
.9351 .5539 L
.93551 .5539 L
.93551 .16187 L
F
.2 .63 .79 r
.9351 .16187 m
.9351 .5539 L
.93551 .5539 L
.93551 .16187 L
s
.678 .847 .902 r
.93551 .16187 m
.93551 .55451 L
.93596 .55451 L
.93596 .16187 L
F
.2 .63 .79 r
.93551 .16187 m
.93551 .55451 L
.93596 .55451 L
.93596 .16187 L
s
.678 .847 .902 r
.93596 .16187 m
.93596 .55499 L
.93626 .55499 L
.93626 .16187 L
F
.2 .63 .79 r
.93596 .16187 m
.93596 .55499 L
.93626 .55499 L
.93626 .16187 L
s
.678 .847 .902 r
.93626 .16187 m
.93626 .55526 L
.93681 .55526 L
.93681 .16187 L
F
.2 .63 .79 r
.93626 .16187 m
.93626 .55526 L
.93681 .55526 L
.93681 .16187 L
s
.678 .847 .902 r
.93681 .16187 m
.93681 .55585 L
.9371 .55585 L
.9371 .16187 L
F
.2 .63 .79 r
.93681 .16187 m
.93681 .55585 L
.9371 .55585 L
.9371 .16187 L
s
.678 .847 .902 r
.9371 .16187 m
.9371 .55625 L
.93733 .55625 L
.93733 .16187 L
F
.2 .63 .79 r
.9371 .16187 m
.9371 .55625 L
.93733 .55625 L
.93733 .16187 L
s
.678 .847 .902 r
.93733 .16187 m
.93733 .55627 L
.93761 .55627 L
.93761 .16187 L
F
.2 .63 .79 r
.93733 .16187 m
.93733 .55627 L
.93761 .55627 L
.93761 .16187 L
s
.678 .847 .902 r
.93761 .16187 m
.93761 .55691 L
.93794 .55691 L
.93794 .16187 L
F
.2 .63 .79 r
.93761 .16187 m
.93761 .55691 L
.93794 .55691 L
.93794 .16187 L
s
.678 .847 .902 r
.93794 .16187 m
.93794 .5571 L
.9383 .5571 L
.9383 .16187 L
F
.2 .63 .79 r
.93794 .16187 m
.93794 .5571 L
.9383 .5571 L
.9383 .16187 L
s
.678 .847 .902 r
.9383 .16187 m
.9383 .55776 L
.9387 .55776 L
.9387 .16187 L
F
.2 .63 .79 r
.9383 .16187 m
.9383 .55776 L
.9387 .55776 L
.9387 .16187 L
s
.678 .847 .902 r
.9387 .16187 m
.9387 .55806 L
.93916 .55806 L
.93916 .16187 L
F
.2 .63 .79 r
.9387 .16187 m
.9387 .55806 L
.93916 .55806 L
.93916 .16187 L
s
.678 .847 .902 r
.93916 .16187 m
.93916 .5588 L
.93974 .5588 L
.93974 .16187 L
F
.2 .63 .79 r
.93916 .16187 m
.93916 .5588 L
.93974 .5588 L
.93974 .16187 L
s
.678 .847 .902 r
.93974 .16187 m
.93974 .55939 L
.94036 .55939 L
.94036 .16187 L
F
.2 .63 .79 r
.93974 .16187 m
.93974 .55939 L
.94036 .55939 L
.94036 .16187 L
s
.678 .847 .902 r
.94036 .16187 m
.94036 .56001 L
.94064 .56001 L
.94064 .16187 L
F
.2 .63 .79 r
.94036 .16187 m
.94036 .56001 L
.94064 .56001 L
.94064 .16187 L
s
.678 .847 .902 r
.94064 .16187 m
.94064 .56047 L
.94088 .56047 L
.94088 .16187 L
F
.2 .63 .79 r
.94064 .16187 m
.94064 .56047 L
.94088 .56047 L
.94088 .16187 L
s
.678 .847 .902 r
.94088 .16187 m
.94088 .56077 L
.94122 .56077 L
.94122 .16187 L
F
.2 .63 .79 r
.94088 .16187 m
.94088 .56077 L
.94122 .56077 L
.94122 .16187 L
s
.678 .847 .902 r
.94122 .16187 m
.94122 .56119 L
.94159 .56119 L
.94159 .16187 L
F
.2 .63 .79 r
.94122 .16187 m
.94122 .56119 L
.94159 .56119 L
.94159 .16187 L
s
.678 .847 .902 r
.94159 .16187 m
.94159 .56144 L
.94218 .56144 L
.94218 .16187 L
F
.2 .63 .79 r
.94159 .16187 m
.94159 .56144 L
.94218 .56144 L
.94218 .16187 L
s
.678 .847 .902 r
.94218 .16187 m
.94218 .56229 L
.94272 .56229 L
.94272 .16187 L
F
.2 .63 .79 r
.94218 .16187 m
.94218 .56229 L
.94272 .56229 L
.94272 .16187 L
s
.678 .847 .902 r
.94272 .16187 m
.94272 .563 L
.9431 .563 L
.9431 .16187 L
F
.2 .63 .79 r
.94272 .16187 m
.94272 .563 L
.9431 .563 L
.9431 .16187 L
s
.678 .847 .902 r
.9431 .16187 m
.9431 .56363 L
.94361 .56363 L
.94361 .16187 L
F
.2 .63 .79 r
.9431 .16187 m
.9431 .56363 L
.94361 .56363 L
.94361 .16187 L
s
.678 .847 .902 r
.94361 .16187 m
.94361 .56414 L
.94418 .56414 L
.94418 .16187 L
F
.2 .63 .79 r
.94361 .16187 m
.94361 .56414 L
.94418 .56414 L
.94418 .16187 L
s
.678 .847 .902 r
.94418 .16187 m
.94418 .56453 L
.94453 .56453 L
.94453 .16187 L
F
.2 .63 .79 r
.94418 .16187 m
.94418 .56453 L
.94453 .56453 L
.94453 .16187 L
s
.678 .847 .902 r
.94453 .16187 m
.94453 .56504 L
.94495 .56504 L
.94495 .16187 L
F
.2 .63 .79 r
.94453 .16187 m
.94453 .56504 L
.94495 .56504 L
.94495 .16187 L
s
.678 .847 .902 r
.94495 .16187 m
.94495 .56543 L
.94525 .56543 L
.94525 .16187 L
F
.2 .63 .79 r
.94495 .16187 m
.94495 .56543 L
.94525 .56543 L
.94525 .16187 L
s
.678 .847 .902 r
.94525 .16187 m
.94525 .566 L
.94555 .566 L
.94555 .16187 L
F
.2 .63 .79 r
.94525 .16187 m
.94525 .566 L
.94555 .566 L
.94555 .16187 L
s
.678 .847 .902 r
.94555 .16187 m
.94555 .56615 L
.94579 .56615 L
.94579 .16187 L
F
.2 .63 .79 r
.94555 .16187 m
.94555 .56615 L
.94579 .56615 L
.94579 .16187 L
s
.678 .847 .902 r
.94579 .16187 m
.94579 .56636 L
.94631 .56636 L
.94631 .16187 L
F
.2 .63 .79 r
.94579 .16187 m
.94579 .56636 L
.94631 .56636 L
.94631 .16187 L
s
.678 .847 .902 r
.94631 .16187 m
.94631 .56712 L
.94651 .56712 L
.94651 .16187 L
F
.2 .63 .79 r
.94631 .16187 m
.94631 .56712 L
.94651 .56712 L
.94651 .16187 L
s
.678 .847 .902 r
.94651 .16187 m
.94651 .56749 L
.94677 .56749 L
.94677 .16187 L
F
.2 .63 .79 r
.94651 .16187 m
.94651 .56749 L
.94677 .56749 L
.94677 .16187 L
s
.678 .847 .902 r
.94677 .16187 m
.94677 .56772 L
.94737 .56772 L
.94737 .16187 L
F
.2 .63 .79 r
.94677 .16187 m
.94677 .56772 L
.94737 .56772 L
.94737 .16187 L
s
.678 .847 .902 r
.94737 .16187 m
.94737 .56833 L
.94775 .56833 L
.94775 .16187 L
F
.2 .63 .79 r
.94737 .16187 m
.94737 .56833 L
.94775 .56833 L
.94775 .16187 L
s
.678 .847 .902 r
.94775 .16187 m
.94775 .56893 L
.94823 .56893 L
.94823 .16187 L
F
.2 .63 .79 r
.94775 .16187 m
.94775 .56893 L
.94823 .56893 L
.94823 .16187 L
s
.678 .847 .902 r
.94823 .16187 m
.94823 .56938 L
.94873 .56938 L
.94873 .16187 L
F
.2 .63 .79 r
.94823 .16187 m
.94823 .56938 L
.94873 .56938 L
.94873 .16187 L
s
.678 .847 .902 r
.94873 .16187 m
.94873 .57026 L
.94906 .57026 L
.94906 .16187 L
F
.2 .63 .79 r
.94873 .16187 m
.94873 .57026 L
.94906 .57026 L
.94906 .16187 L
s
.678 .847 .902 r
.94906 .16187 m
.94906 .57062 L
.9495 .57062 L
.9495 .16187 L
F
.2 .63 .79 r
.94906 .16187 m
.94906 .57062 L
.9495 .57062 L
.9495 .16187 L
s
.678 .847 .902 r
.9495 .16187 m
.9495 .57082 L
.94999 .57082 L
.94999 .16187 L
F
.2 .63 .79 r
.9495 .16187 m
.9495 .57082 L
.94999 .57082 L
.94999 .16187 L
s
.678 .847 .902 r
.94999 .16187 m
.94999 .57176 L
.9504 .57176 L
.9504 .16187 L
F
.2 .63 .79 r
.94999 .16187 m
.94999 .57176 L
.9504 .57176 L
.9504 .16187 L
s
.678 .847 .902 r
.9504 .16187 m
.9504 .57189 L
.95069 .57189 L
.95069 .16187 L
F
.2 .63 .79 r
.9504 .16187 m
.9504 .57189 L
.95069 .57189 L
.95069 .16187 L
s
.678 .847 .902 r
.95069 .16187 m
.95069 .57255 L
.95097 .57255 L
.95097 .16187 L
F
.2 .63 .79 r
.95069 .16187 m
.95069 .57255 L
.95097 .57255 L
.95097 .16187 L
s
.678 .847 .902 r
.95097 .16187 m
.95097 .5727 L
.95129 .5727 L
.95129 .16187 L
F
.2 .63 .79 r
.95097 .16187 m
.95097 .5727 L
.95129 .5727 L
.95129 .16187 L
s
.678 .847 .902 r
.95129 .16187 m
.95129 .57328 L
.95175 .57328 L
.95175 .16187 L
F
.2 .63 .79 r
.95129 .16187 m
.95129 .57328 L
.95175 .57328 L
.95175 .16187 L
s
.678 .847 .902 r
.95175 .16187 m
.95175 .57379 L
.95213 .57379 L
.95213 .16187 L
F
.2 .63 .79 r
.95175 .16187 m
.95175 .57379 L
.95213 .57379 L
.95213 .16187 L
s
.678 .847 .902 r
.95213 .16187 m
.95213 .57413 L
.95268 .57413 L
.95268 .16187 L
F
.2 .63 .79 r
.95213 .16187 m
.95213 .57413 L
.95268 .57413 L
.95268 .16187 L
s
.678 .847 .902 r
.95268 .16187 m
.95268 .57492 L
.95313 .57492 L
.95313 .16187 L
F
.2 .63 .79 r
.95268 .16187 m
.95268 .57492 L
.95313 .57492 L
.95313 .16187 L
s
.678 .847 .902 r
.95313 .16187 m
.95313 .57516 L
.95365 .57516 L
.95365 .16187 L
F
.2 .63 .79 r
.95313 .16187 m
.95313 .57516 L
.95365 .57516 L
.95365 .16187 L
s
.678 .847 .902 r
.95365 .16187 m
.95365 .57589 L
.95388 .57589 L
.95388 .16187 L
F
.2 .63 .79 r
.95365 .16187 m
.95365 .57589 L
.95388 .57589 L
.95388 .16187 L
s
.678 .847 .902 r
.95388 .16187 m
.95388 .57638 L
.95419 .57638 L
.95419 .16187 L
F
.2 .63 .79 r
.95388 .16187 m
.95388 .57638 L
.95419 .57638 L
.95419 .16187 L
s
.678 .847 .902 r
.95419 .16187 m
.95419 .57656 L
.95453 .57656 L
.95453 .16187 L
F
.2 .63 .79 r
.95419 .16187 m
.95419 .57656 L
.95453 .57656 L
.95453 .16187 L
s
.678 .847 .902 r
.95453 .16187 m
.95453 .57694 L
.95495 .57694 L
.95495 .16187 L
F
.2 .63 .79 r
.95453 .16187 m
.95453 .57694 L
.95495 .57694 L
.95495 .16187 L
s
.678 .847 .902 r
.95495 .16187 m
.95495 .5774 L
.95556 .5774 L
.95556 .16187 L
F
.2 .63 .79 r
.95495 .16187 m
.95495 .5774 L
.95556 .5774 L
.95556 .16187 L
s
.678 .847 .902 r
.95556 .16187 m
.95556 .57854 L
.956 .57854 L
.956 .16187 L
F
.2 .63 .79 r
.95556 .16187 m
.95556 .57854 L
.956 .57854 L
.956 .16187 L
s
.678 .847 .902 r
.956 .16187 m
.956 .57888 L
.95634 .57888 L
.95634 .16187 L
F
.2 .63 .79 r
.956 .16187 m
.956 .57888 L
.95634 .57888 L
.95634 .16187 L
s
.678 .847 .902 r
.95634 .16187 m
.95634 .57915 L
.95668 .57915 L
.95668 .16187 L
F
.2 .63 .79 r
.95634 .16187 m
.95634 .57915 L
.95668 .57915 L
.95668 .16187 L
s
.678 .847 .902 r
.95668 .16187 m
.95668 .57964 L
.95689 .57964 L
.95689 .16187 L
F
.2 .63 .79 r
.95668 .16187 m
.95668 .57964 L
.95689 .57964 L
.95689 .16187 L
s
.678 .847 .902 r
.95689 .16187 m
.95689 .57989 L
.95714 .57989 L
.95714 .16187 L
F
.2 .63 .79 r
.95689 .16187 m
.95689 .57989 L
.95714 .57989 L
.95714 .16187 L
s
.678 .847 .902 r
.95714 .16187 m
.95714 .58013 L
.95764 .58013 L
.95764 .16187 L
F
.2 .63 .79 r
.95714 .16187 m
.95714 .58013 L
.95764 .58013 L
.95764 .16187 L
s
.678 .847 .902 r
.95764 .16187 m
.95764 .58066 L
.95812 .58066 L
.95812 .16187 L
F
.2 .63 .79 r
.95764 .16187 m
.95764 .58066 L
.95812 .58066 L
.95812 .16187 L
s
.678 .847 .902 r
.95812 .16187 m
.95812 .58168 L
.95863 .58168 L
.95863 .16187 L
F
.2 .63 .79 r
.95812 .16187 m
.95812 .58168 L
.95863 .58168 L
.95863 .16187 L
s
.678 .847 .902 r
.95863 .16187 m
.95863 .58233 L
.95909 .58233 L
.95909 .16187 L
F
.2 .63 .79 r
.95863 .16187 m
.95863 .58233 L
.95909 .58233 L
.95909 .16187 L
s
.678 .847 .902 r
.95909 .16187 m
.95909 .58248 L
.95972 .58248 L
.95972 .16187 L
F
.2 .63 .79 r
.95909 .16187 m
.95909 .58248 L
.95972 .58248 L
.95972 .16187 L
s
.678 .847 .902 r
.95972 .16187 m
.95972 .58324 L
.95999 .58324 L
.95999 .16187 L
F
.2 .63 .79 r
.95972 .16187 m
.95972 .58324 L
.95999 .58324 L
.95999 .16187 L
s
.678 .847 .902 r
.95999 .16187 m
.95999 .58384 L
.9604 .58384 L
.9604 .16187 L
F
.2 .63 .79 r
.95999 .16187 m
.95999 .58384 L
.9604 .58384 L
.9604 .16187 L
s
.678 .847 .902 r
.9604 .16187 m
.9604 .58439 L
.96077 .58439 L
.96077 .16187 L
F
.2 .63 .79 r
.9604 .16187 m
.9604 .58439 L
.96077 .58439 L
.96077 .16187 L
s
.678 .847 .902 r
.96077 .16187 m
.96077 .58488 L
.96127 .58488 L
.96127 .16187 L
F
.2 .63 .79 r
.96077 .16187 m
.96077 .58488 L
.96127 .58488 L
.96127 .16187 L
s
.678 .847 .902 r
.96127 .16187 m
.96127 .58541 L
.96172 .58541 L
.96172 .16187 L
F
.2 .63 .79 r
.96127 .16187 m
.96127 .58541 L
.96172 .58541 L
.96172 .16187 L
s
.678 .847 .902 r
.96172 .16187 m
.96172 .5856 L
.96194 .5856 L
.96194 .16187 L
F
.2 .63 .79 r
.96172 .16187 m
.96172 .5856 L
.96194 .5856 L
.96194 .16187 L
s
.678 .847 .902 r
.96194 .16187 m
.96194 .58622 L
.9624 .58622 L
.9624 .16187 L
F
.2 .63 .79 r
.96194 .16187 m
.96194 .58622 L
.9624 .58622 L
.9624 .16187 L
s
.678 .847 .902 r
.9624 .16187 m
.9624 .58646 L
.96265 .58646 L
.96265 .16187 L
F
.2 .63 .79 r
.9624 .16187 m
.9624 .58646 L
.96265 .58646 L
.96265 .16187 L
s
.678 .847 .902 r
.96265 .16187 m
.96265 .58718 L
.96321 .58718 L
.96321 .16187 L
F
.2 .63 .79 r
.96265 .16187 m
.96265 .58718 L
.96321 .58718 L
.96321 .16187 L
s
.678 .847 .902 r
.96321 .16187 m
.96321 .58755 L
.9634 .58755 L
.9634 .16187 L
F
.2 .63 .79 r
.96321 .16187 m
.96321 .58755 L
.9634 .58755 L
.9634 .16187 L
s
.678 .847 .902 r
.9634 .16187 m
.9634 .58796 L
.96374 .58796 L
.96374 .16187 L
F
.2 .63 .79 r
.9634 .16187 m
.9634 .58796 L
.96374 .58796 L
.96374 .16187 L
s
.678 .847 .902 r
.96374 .16187 m
.96374 .58862 L
.96428 .58862 L
.96428 .16187 L
F
.2 .63 .79 r
.96374 .16187 m
.96374 .58862 L
.96428 .58862 L
.96428 .16187 L
s
.678 .847 .902 r
.96428 .16187 m
.96428 .5889 L
.96461 .5889 L
.96461 .16187 L
F
.2 .63 .79 r
.96428 .16187 m
.96428 .5889 L
.96461 .5889 L
.96461 .16187 L
s
.678 .847 .902 r
.96461 .16187 m
.96461 .58927 L
.96482 .58927 L
.96482 .16187 L
F
.2 .63 .79 r
.96461 .16187 m
.96461 .58927 L
.96482 .58927 L
.96482 .16187 L
s
.678 .847 .902 r
.96482 .16187 m
.96482 .58935 L
.96536 .58935 L
.96536 .16187 L
F
.2 .63 .79 r
.96482 .16187 m
.96482 .58935 L
.96536 .58935 L
.96536 .16187 L
s
.678 .847 .902 r
.96536 .16187 m
.96536 .59015 L
.96575 .59015 L
.96575 .16187 L
F
.2 .63 .79 r
.96536 .16187 m
.96536 .59015 L
.96575 .59015 L
.96575 .16187 L
s
.678 .847 .902 r
.96575 .16187 m
.96575 .59069 L
.96639 .59069 L
.96639 .16187 L
F
.2 .63 .79 r
.96575 .16187 m
.96575 .59069 L
.96639 .59069 L
.96639 .16187 L
s
.678 .847 .902 r
.96639 .16187 m
.96639 .59148 L
.96659 .59148 L
.96659 .16187 L
F
.2 .63 .79 r
.96639 .16187 m
.96639 .59148 L
.96659 .59148 L
.96659 .16187 L
s
.678 .847 .902 r
.96659 .16187 m
.96659 .59173 L
.96706 .59173 L
.96706 .16187 L
F
.2 .63 .79 r
.96659 .16187 m
.96659 .59173 L
.96706 .59173 L
.96706 .16187 L
s
.678 .847 .902 r
.96706 .16187 m
.96706 .59214 L
.96759 .59214 L
.96759 .16187 L
F
.2 .63 .79 r
.96706 .16187 m
.96706 .59214 L
.96759 .59214 L
.96759 .16187 L
s
.678 .847 .902 r
.96759 .16187 m
.96759 .59282 L
.96794 .59282 L
.96794 .16187 L
F
.2 .63 .79 r
.96759 .16187 m
.96759 .59282 L
.96794 .59282 L
.96794 .16187 L
s
.678 .847 .902 r
.96794 .16187 m
.96794 .59321 L
.96827 .59321 L
.96827 .16187 L
F
.2 .63 .79 r
.96794 .16187 m
.96794 .59321 L
.96827 .59321 L
.96827 .16187 L
s
.678 .847 .902 r
.96827 .16187 m
.96827 .59368 L
.96847 .59368 L
.96847 .16187 L
F
.2 .63 .79 r
.96827 .16187 m
.96827 .59368 L
.96847 .59368 L
.96847 .16187 L
s
.678 .847 .902 r
.96847 .16187 m
.96847 .59443 L
.96901 .59443 L
.96901 .16187 L
F
.2 .63 .79 r
.96847 .16187 m
.96847 .59443 L
.96901 .59443 L
.96901 .16187 L
s
.678 .847 .902 r
.96901 .16187 m
.96901 .59476 L
.96928 .59476 L
.96928 .16187 L
F
.2 .63 .79 r
.96901 .16187 m
.96901 .59476 L
.96928 .59476 L
.96928 .16187 L
s
.678 .847 .902 r
.96928 .16187 m
.96928 .59505 L
.96983 .59505 L
.96983 .16187 L
F
.2 .63 .79 r
.96928 .16187 m
.96928 .59505 L
.96983 .59505 L
.96983 .16187 L
s
.678 .847 .902 r
.96983 .16187 m
.96983 .59578 L
.97031 .59578 L
.97031 .16187 L
F
.2 .63 .79 r
.96983 .16187 m
.96983 .59578 L
.97031 .59578 L
.97031 .16187 L
s
.678 .847 .902 r
.97031 .16187 m
.97031 .59612 L
.97053 .59612 L
.97053 .16187 L
F
.2 .63 .79 r
.97031 .16187 m
.97031 .59612 L
.97053 .59612 L
.97053 .16187 L
s
.678 .847 .902 r
.97053 .16187 m
.97053 .59643 L
.97099 .59643 L
.97099 .16187 L
F
.2 .63 .79 r
.97053 .16187 m
.97053 .59643 L
.97099 .59643 L
.97099 .16187 L
s
.678 .847 .902 r
.97099 .16187 m
.97099 .59708 L
.97151 .59708 L
.97151 .16187 L
F
.2 .63 .79 r
.97099 .16187 m
.97099 .59708 L
.97151 .59708 L
.97151 .16187 L
s
.678 .847 .902 r
.97151 .16187 m
.97151 .59776 L
.97172 .59776 L
.97172 .16187 L
F
.2 .63 .79 r
.97151 .16187 m
.97151 .59776 L
.97172 .59776 L
.97172 .16187 L
s
.678 .847 .902 r
.97172 .16187 m
.97172 .59854 L
.97234 .59854 L
.97234 .16187 L
F
.2 .63 .79 r
.97172 .16187 m
.97172 .59854 L
.97234 .59854 L
.97234 .16187 L
s
.678 .847 .902 r
.97234 .16187 m
.97234 .59886 L
.97288 .59886 L
.97288 .16187 L
F
.2 .63 .79 r
.97234 .16187 m
.97234 .59886 L
.97288 .59886 L
.97288 .16187 L
s
.678 .847 .902 r
.97288 .16187 m
.97288 .59956 L
.9734 .59956 L
.9734 .16187 L
F
.2 .63 .79 r
.97288 .16187 m
.97288 .59956 L
.9734 .59956 L
.9734 .16187 L
s
.678 .847 .902 r
.9734 .16187 m
.9734 .60049 L
.9739 .60049 L
.9739 .16187 L
F
.2 .63 .79 r
.9734 .16187 m
.9734 .60049 L
.9739 .60049 L
.9739 .16187 L
s
.678 .847 .902 r
.9739 .16187 m
.9739 .60052 L
.97417 .60052 L
.97417 .16187 L
F
.2 .63 .79 r
.9739 .16187 m
.9739 .60052 L
.97417 .60052 L
.97417 .16187 L
s
.678 .847 .902 r
.97417 .16187 m
.97417 .60128 L
.97457 .60128 L
.97457 .16187 L
F
.2 .63 .79 r
.97417 .16187 m
.97417 .60128 L
.97457 .60128 L
.97457 .16187 L
s
.678 .847 .902 r
.97457 .16187 m
.97457 .60183 L
.97507 .60183 L
.97507 .16187 L
F
.2 .63 .79 r
.97457 .16187 m
.97457 .60183 L
.97507 .60183 L
.97507 .16187 L
s
.678 .847 .902 r
.97507 .16187 m
.97507 .60267 L
.97567 .60267 L
.97567 .16187 L
F
.2 .63 .79 r
.97507 .16187 m
.97507 .60267 L
.97567 .60267 L
.97567 .16187 L
s
.678 .847 .902 r
.97567 .16187 m
.97567 .60318 L
.97619 .60318 L
.97619 .16187 L
F
.2 .63 .79 r
.97567 .16187 m
.97567 .60318 L
.97619 .60318 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02398 .01472 Mdot
.02452 .01472 Mdot
.02479 .01472 Mdot
.02526 .01472 Mdot
.02533 .01472 Mdot
.02584 .01472 Mdot
.02612 .01472 Mdot
.02659 .01472 Mdot
.02724 .01472 Mdot
.02737 .01472 Mdot
.02778 .01473 Mdot
.02806 .01473 Mdot
.02869 .01473 Mdot
.02926 .01473 Mdot
.02967 .01474 Mdot
.02999 .01474 Mdot
.03054 .01474 Mdot
.03079 .01475 Mdot
.03153 .01475 Mdot
.03158 .01475 Mdot
.03208 .01476 Mdot
.03258 .01477 Mdot
.03332 .01477 Mdot
.03352 .01478 Mdot
.03412 .01478 Mdot
.0345 .01479 Mdot
.0349 .01479 Mdot
.03523 .0148 Mdot
.03583 .01481 Mdot
.03616 .01481 Mdot
.03661 .01482 Mdot
.03699 .01483 Mdot
.03744 .01484 Mdot
.03783 .01484 Mdot
.03809 .01485 Mdot
.0385 .01486 Mdot
.03863 .01486 Mdot
.03963 .01488 Mdot
.03971 .01488 Mdot
.0401 .01489 Mdot
.04035 .01489 Mdot
.04072 .0149 Mdot
.04095 .01491 Mdot
.0416 .01492 Mdot
.04197 .01493 Mdot
.04231 .01494 Mdot
.04266 .01495 Mdot
.04321 .01496 Mdot
.04382 .01497 Mdot
.04422 .01499 Mdot
.04456 .01499 Mdot
.04474 .015 Mdot
.04521 .01501 Mdot
.04547 .01502 Mdot
.0458 .01503 Mdot
.04609 .01504 Mdot
.04688 .01506 Mdot
.04708 .01507 Mdot
.04733 .01507 Mdot
.04755 .01508 Mdot
.04849 .01511 Mdot
.04889 .01512 Mdot
.04906 .01513 Mdot
.0494 .01514 Mdot
.04984 .01515 Mdot
.05044 .01518 Mdot
.05078 .01519 Mdot
.05102 .0152 Mdot
.05149 .01521 Mdot
.05198 .01523 Mdot
.05262 .01525 Mdot
.05301 .01527 Mdot
.05317 .01527 Mdot
.0535 .01529 Mdot
.05386 .0153 Mdot
.05421 .01531 Mdot
.05431 .01532 Mdot
.05467 .01533 Mdot
.05545 .01536 Mdot
.05587 .01538 Mdot
.05601 .01539 Mdot
.05663 .01541 Mdot
.05731 .01544 Mdot
.05745 .01545 Mdot
.05778 .01546 Mdot
.05838 .01549 Mdot
.05872 .01551 Mdot
.05891 .01551 Mdot
.0592 .01553 Mdot
.05935 .01553 Mdot
.05992 .01556 Mdot
.06035 .01558 Mdot
.06044 .01559 Mdot
.06106 .01562 Mdot
.06127 .01563 Mdot
.06204 .01566 Mdot
.06223 .01567 Mdot
.06238 .01568 Mdot
.06277 .0157 Mdot
.06304 .01571 Mdot
.06352 .01574 Mdot
.06386 .01576 Mdot
.06462 .0158 Mdot
.06476 .0158 Mdot
.065 .01582 Mdot
.06545 .01584 Mdot
.06592 .01587 Mdot
.06609 .01588 Mdot
.06651 .0159 Mdot
.06704 .01593 Mdot
.06735 .01595 Mdot
.06803 .01598 Mdot
.06851 .01601 Mdot
.06907 .01604 Mdot
.06944 .01607 Mdot
.06991 .01609 Mdot
.07012 .01611 Mdot
.07052 .01613 Mdot
.07068 .01614 Mdot
.07156 .01619 Mdot
.07189 .01622 Mdot
.07235 .01624 Mdot
.07282 .01627 Mdot
.07324 .0163 Mdot
.07347 .01632 Mdot
.07401 .01635 Mdot
.0746 .01639 Mdot
.07482 .0164 Mdot
.07507 .01642 Mdot
.07528 .01643 Mdot
.07557 .01645 Mdot
.07618 .01649 Mdot
.07642 .01651 Mdot
.07679 .01654 Mdot
.07731 .01657 Mdot
.07754 .01659 Mdot
.07791 .01661 Mdot
.07888 .01668 Mdot
.07919 .01671 Mdot
.07974 .01675 Mdot
.08022 .01678 Mdot
.08026 .01678 Mdot
.08095 .01683 Mdot
.08143 .01687 Mdot
.08189 .0169 Mdot
.08241 .01694 Mdot
.08299 .01699 Mdot
.08341 .01702 Mdot
.08401 .01707 Mdot
.08429 .01709 Mdot
.08467 .01712 Mdot
.0853 .01717 Mdot
.08579 .01721 Mdot
.08614 .01724 Mdot
.08644 .01726 Mdot
.08673 .01728 Mdot
.08745 .01734 Mdot
.08787 .01738 Mdot
.08849 .01743 Mdot
.08884 .01746 Mdot
.089 .01747 Mdot
.08967 .01753 Mdot
.09013 .01757 Mdot
.09068 .01762 Mdot
.09076 .01762 Mdot
.09116 .01766 Mdot
.09205 .01774 Mdot
.09244 .01777 Mdot
.09309 .01783 Mdot
.09364 .01788 Mdot
.09385 .0179 Mdot
.0942 .01793 Mdot
.09455 .01796 Mdot
.09511 .01801 Mdot
.0955 .01805 Mdot
.09596 .01809 Mdot
.09634 .01813 Mdot
.09687 .01818 Mdot
.09731 .01822 Mdot
.09769 .01826 Mdot
.09788 .01828 Mdot
.09835 .01832 Mdot
.09867 .01835 Mdot
.09893 .01838 Mdot
.09919 .0184 Mdot
.09951 .01843 Mdot
.10017 .0185 Mdot
.10037 .01852 Mdot
.1008 .01856 Mdot
.10101 .01858 Mdot
.1013 .01861 Mdot
.10168 .01865 Mdot
.10188 .01867 Mdot
.10217 .0187 Mdot
.10255 .01874 Mdot
.10269 .01875 Mdot
.10308 .01879 Mdot
.10343 .01883 Mdot
.10419 .01891 Mdot
.10464 .01896 Mdot
.10509 .019 Mdot
.10538 .01903 Mdot
.10585 .01908 Mdot
.10632 .01913 Mdot
.1066 .01916 Mdot
.10721 .01923 Mdot
.10742 .01925 Mdot
.10786 .0193 Mdot
.10806 .01932 Mdot
.10851 .01937 Mdot
.1089 .01941 Mdot
.10926 .01945 Mdot
.10962 .01949 Mdot
.11041 .01958 Mdot
.11074 .01962 Mdot
.11127 .01968 Mdot
.11176 .01973 Mdot
.11215 .01978 Mdot
.11248 .01982 Mdot
.11303 .01988 Mdot
.11331 .01991 Mdot
.11352 .01994 Mdot
.11396 .01999 Mdot
.11414 .02001 Mdot
.11478 .02009 Mdot
.11533 .02015 Mdot
.11534 .02015 Mdot
.11578 .0202 Mdot
.11613 .02025 Mdot
.11659 .0203 Mdot
.11681 .02033 Mdot
.11762 .02043 Mdot
.1178 .02045 Mdot
.11813 .02049 Mdot
.11878 .02057 Mdot
.11896 .02059 Mdot
.11915 .02061 Mdot
.11964 .02067 Mdot
.11994 .02071 Mdot
.12065 .0208 Mdot
.12097 .02084 Mdot
.12121 .02087 Mdot
.12179 .02095 Mdot
.1224 .02102 Mdot
.12263 .02105 Mdot
.12302 .0211 Mdot
.1234 .02115 Mdot
.12393 .02122 Mdot
.12439 .02128 Mdot
.12459 .02131 Mdot
.12481 .02134 Mdot
.12523 .02139 Mdot
.12575 .02146 Mdot
.12629 .02153 Mdot
.12697 .02162 Mdot
.12727 .02166 Mdot
.12762 .02171 Mdot
.1279 .02175 Mdot
.1281 .02177 Mdot
.12846 .02182 Mdot
.12894 .02189 Mdot
.12985 .02201 Mdot
.12991 .02202 Mdot
.13055 .02211 Mdot
.13094 .02216 Mdot
.13144 .02223 Mdot
.13152 .02224 Mdot
.13221 .02234 Mdot
.13278 .02242 Mdot
.13297 .02245 Mdot
.13347 .02252 Mdot
.13382 .02257 Mdot
.13442 .02265 Mdot
.13474 .0227 Mdot
.13508 .02275 Mdot
.13557 .02282 Mdot
.13606 .02289 Mdot
.13637 .02294 Mdot
.13706 .02304 Mdot
.13757 .02311 Mdot
.13761 .02312 Mdot
.13815 .0232 Mdot
.13843 .02324 Mdot
.13904 .02333 Mdot
.1391 .02334 Mdot
.13992 .02346 Mdot
.14025 .02351 Mdot
.14073 .02359 Mdot
.14119 .02366 Mdot
.14189 .02376 Mdot
.14215 .0238 Mdot
.14259 .02387 Mdot
.14333 .02399 Mdot
.1439 .02407 Mdot
.14445 .02416 Mdot
.14475 .02421 Mdot
.14536 .0243 Mdot
.14545 .02432 Mdot
.14592 .02439 Mdot
.14619 .02443 Mdot
.14662 .0245 Mdot
.14675 .02452 Mdot
.14724 .0246 Mdot
.14739 .02463 Mdot
.14788 .0247 Mdot
.14843 .02479 Mdot
.14887 .02486 Mdot
.14944 .02496 Mdot
.14994 .02504 Mdot
.15027 .02509 Mdot
.1506 .02515 Mdot
.15083 .02518 Mdot
.15091 .0252 Mdot
.15163 .02532 Mdot
.15188 .02536 Mdot
.1523 .02543 Mdot
.15264 .02549 Mdot
.15355 .02564 Mdot
.15385 .02569 Mdot
.15429 .02576 Mdot
.15438 .02578 Mdot
.15474 .02584 Mdot
.15492 .02587 Mdot
.15527 .02593 Mdot
.15543 .02596 Mdot
.15589 .02604 Mdot
.15653 .02615 Mdot
.15709 .02624 Mdot
.15731 .02628 Mdot
.15769 .02635 Mdot
.15825 .02644 Mdot
.15852 .02649 Mdot
.15909 .02659 Mdot
.15958 .02668 Mdot
.16025 .0268 Mdot
.16063 .02686 Mdot
.16094 .02692 Mdot
.16129 .02698 Mdot
.1615 .02702 Mdot
.16188 .02709 Mdot
.16245 .02719 Mdot
.16307 .0273 Mdot
.16357 .02739 Mdot
.16387 .02745 Mdot
.16459 .02758 Mdot
.16493 .02764 Mdot
.16509 .02767 Mdot
.1656 .02776 Mdot
.16597 .02783 Mdot
.16633 .0279 Mdot
.16694 .02801 Mdot
.16753 .02812 Mdot
.16769 .02815 Mdot
.16846 .02829 Mdot
.16886 .02837 Mdot
.16899 .02839 Mdot
.16938 .02847 Mdot
.16963 .02851 Mdot
.1698 .02855 Mdot
.17057 .02869 Mdot
.17141 .02885 Mdot
.17188 .02894 Mdot
.17232 .02903 Mdot
.17254 .02907 Mdot
.17325 .02921 Mdot
.17374 .0293 Mdot
.17422 .0294 Mdot
.17453 .02946 Mdot
.17491 .02953 Mdot
.17512 .02957 Mdot
.17548 .02964 Mdot
.17576 .0297 Mdot
.1762 .02978 Mdot
.17674 .02989 Mdot
.17684 .02991 Mdot
.17738 .03002 Mdot
.17751 .03004 Mdot
.17812 .03017 Mdot
.17819 .03018 Mdot
.17856 .03025 Mdot
.17926 .0304 Mdot
.17968 .03048 Mdot
.17994 .03053 Mdot
.18074 .0307 Mdot
.18123 .0308 Mdot
.1818 .03091 Mdot
.18217 .03099 Mdot
.1829 .03114 Mdot
.1831 .03118 Mdot
.18382 .03133 Mdot
.18402 .03137 Mdot
.18454 .03148 Mdot
.18468 .03151 Mdot
.18498 .03157 Mdot
.1856 .0317 Mdot
.18599 .03178 Mdot
.18629 .03185 Mdot
.1872 .03204 Mdot
.18756 .03212 Mdot
.18818 .03225 Mdot
.18869 .03236 Mdot
.18894 .03241 Mdot
.18912 .03245 Mdot
.18967 .03257 Mdot
.18994 .03263 Mdot
.19021 .03268 Mdot
.19075 .0328 Mdot
.19128 .03292 Mdot
.19149 .03296 Mdot
.19167 .033 Mdot
.19229 .03314 Mdot
.1924 .03316 Mdot
.19285 .03326 Mdot
.19339 .03338 Mdot
.19376 .03346 Mdot
.19421 .03356 Mdot
.1946 .03364 Mdot
.19486 .0337 Mdot
.19565 .03388 Mdot
.1963 .03402 Mdot
.1965 .03407 Mdot
.19689 .03416 Mdot
.19735 .03426 Mdot
.19792 .03439 Mdot
.19819 .03445 Mdot
.19885 .0346 Mdot
.19924 .03469 Mdot
.19957 .03476 Mdot
.20007 .03488 Mdot
.20064 .03501 Mdot
.20131 .03516 Mdot
.2015 .0352 Mdot
.20204 .03533 Mdot
.20253 .03544 Mdot
.20263 .03547 Mdot
.20318 .03559 Mdot
.20379 .03574 Mdot
.20391 .03576 Mdot
.20435 .03587 Mdot
.20461 .03593 Mdot
.20491 .036 Mdot
.20526 .03608 Mdot
.20569 .03618 Mdot
.206 .03626 Mdot
.20643 .03636 Mdot
.20701 .0365 Mdot
.20731 .03657 Mdot
.20777 .03668 Mdot
.20848 .03685 Mdot
.20868 .03689 Mdot
.20902 .03697 Mdot
.20993 .03719 Mdot
.2104 .03731 Mdot
.2105 .03733 Mdot
.21086 .03742 Mdot
.21141 .03755 Mdot
.21174 .03763 Mdot
.21196 .03769 Mdot
.21249 .03782 Mdot
.21262 .03785 Mdot
.2129 .03792 Mdot
.21301 .03795 Mdot
.21365 .0381 Mdot
.21428 .03826 Mdot
.21458 .03833 Mdot
.21518 .03848 Mdot
.21523 .03849 Mdot
.21603 .03869 Mdot
.2162 .03873 Mdot
.21644 .03879 Mdot
.21738 .03903 Mdot
.21767 .0391 Mdot
.21786 .03915 Mdot
.21849 .03931 Mdot
.21873 .03937 Mdot
.21903 .03945 Mdot
.21939 .03954 Mdot
.22019 .03974 Mdot
.22052 .03982 Mdot
.22105 .03996 Mdot
.22147 .04007 Mdot
.22179 .04015 Mdot
.2224 .04031 Mdot
.22278 .04041 Mdot
.22311 .04049 Mdot
.22367 .04064 Mdot
.22418 .04077 Mdot
.2248 .04093 Mdot
.22517 .04103 Mdot
.22536 .04108 Mdot
.22573 .04117 Mdot
.22634 .04133 Mdot
.22653 .04138 Mdot
.22671 .04143 Mdot
.22708 .04153 Mdot
.22748 .04163 Mdot
.22803 .04178 Mdot
.2286 .04193 Mdot
.22887 .042 Mdot
.22948 .04217 Mdot
.23002 .04231 Mdot
.23101 .04258 Mdot
.23135 .04267 Mdot
.23175 .04277 Mdot
.23234 .04293 Mdot
.23266 .04302 Mdot
.23302 .04312 Mdot
.23325 .04318 Mdot
.23354 .04326 Mdot
.23392 .04336 Mdot
.23449 .04352 Mdot
.23475 .04359 Mdot
.23542 .04377 Mdot
.23577 .04387 Mdot
.23596 .04392 Mdot
.23639 .04404 Mdot
.23714 .04425 Mdot
.23736 .04431 Mdot
.23796 .04448 Mdot
.23843 .0446 Mdot
.23881 .04471 Mdot
.23964 .04494 Mdot
.24001 .04505 Mdot
.24034 .04514 Mdot
.24044 .04517 Mdot
.24118 .04538 Mdot
.2413 .04541 Mdot
.2419 .04558 Mdot
.24243 .04573 Mdot
.24281 .04584 Mdot
.2432 .04595 Mdot
.24373 .0461 Mdot
.24398 .04617 Mdot
.2445 .04632 Mdot
.24487 .04643 Mdot
.24518 .04652 Mdot
.2456 .04664 Mdot
.24586 .04671 Mdot
.24613 .04679 Mdot
.24644 .04688 Mdot
.24695 .04703 Mdot
.24719 .0471 Mdot
.24796 .04732 Mdot
.24835 .04743 Mdot
.24869 .04753 Mdot
.24922 .04769 Mdot
.24952 .04778 Mdot
.25024 .04799 Mdot
.25034 .04802 Mdot
.25095 .0482 Mdot
.25121 .04827 Mdot
.2518 .04845 Mdot
.25224 .04858 Mdot
.25265 .0487 Mdot
.2534 .04892 Mdot
.25358 .04898 Mdot
.25373 .04902 Mdot
.25457 .04927 Mdot
.25472 .04932 Mdot
.255 .0494 Mdot
.25558 .04958 Mdot
.25593 .04968 Mdot
.25665 .0499 Mdot
.25696 .04999 Mdot
.2572 .05006 Mdot
.25727 .05008 Mdot
.2579 .05028 Mdot
.25857 .05048 Mdot
.25909 .05064 Mdot
.25951 .05077 Mdot
.25998 .05091 Mdot
.26033 .05102 Mdot
.26069 .05113 Mdot
.26078 .05116 Mdot
.26131 .05132 Mdot
.26154 .05139 Mdot
.26189 .0515 Mdot
.26249 .05169 Mdot
.26272 .05175 Mdot
.26297 .05183 Mdot
.26315 .05189 Mdot
.26346 .05199 Mdot
.26392 .05213 Mdot
.26453 .05232 Mdot
.26517 .05252 Mdot
.26576 .0527 Mdot
.266 .05278 Mdot
.26635 .05289 Mdot
.26692 .05307 Mdot
.26742 .05323 Mdot
.26771 .05332 Mdot
.26801 .05341 Mdot
.26857 .05359 Mdot
.26879 .05366 Mdot
.26943 .05386 Mdot
.26989 .05401 Mdot
.27013 .05409 Mdot
.27023 .05412 Mdot
.27081 .05431 Mdot
.27107 .05439 Mdot
.2716 .05456 Mdot
.27206 .05471 Mdot
.27254 .05486 Mdot
.27314 .05506 Mdot
.27332 .05512 Mdot
.27368 .05523 Mdot
.27435 .05545 Mdot
.27446 .05549 Mdot
.27478 .05559 Mdot
.27526 .05574 Mdot
.27568 .05588 Mdot
.27617 .05604 Mdot
.27662 .05619 Mdot
.27729 .05641 Mdot
.27769 .05654 Mdot
.27788 .05661 Mdot
.27829 .05674 Mdot
.27891 .05694 Mdot
.27919 .05704 Mdot
.27962 .05718 Mdot
.28005 .05732 Mdot
.28035 .05742 Mdot
.28081 .05758 Mdot
.28122 .05771 Mdot
.28169 .05787 Mdot
.28222 .05805 Mdot
.28265 .05819 Mdot
.28332 .05842 Mdot
.28361 .05852 Mdot
.28409 .05868 Mdot
.28471 .05889 Mdot
.28511 .05902 Mdot
.28558 .05918 Mdot
.28581 .05926 Mdot
.2859 .05929 Mdot
.28625 .05941 Mdot
.28642 .05947 Mdot
.28664 .05954 Mdot
.28712 .05971 Mdot
.28776 .05993 Mdot
.28805 .06002 Mdot
.28846 .06017 Mdot
.28898 .06035 Mdot
.28923 .06043 Mdot
.28959 .06056 Mdot
.28985 .06065 Mdot
.29055 .06089 Mdot
.29113 .06109 Mdot
.29156 .06124 Mdot
.29226 .06148 Mdot
.29261 .0616 Mdot
.293 .06174 Mdot
.29342 .06189 Mdot
.29369 .06198 Mdot
.29409 .06212 Mdot
.29455 .06228 Mdot
.29538 .06257 Mdot
.29568 .06268 Mdot
.2964 .06294 Mdot
.29646 .06296 Mdot
.29689 .06311 Mdot
.29727 .06324 Mdot
.29782 .06344 Mdot
.29832 .06362 Mdot
.29857 .06371 Mdot
.29901 .06386 Mdot
.29929 .06396 Mdot
.29971 .06411 Mdot
.30003 .06423 Mdot
.3004 .06436 Mdot
.30068 .06446 Mdot
.30113 .06462 Mdot
.30163 .0648 Mdot
.30245 .0651 Mdot
.30268 .06518 Mdot
.30298 .06529 Mdot
.30319 .06537 Mdot
.3038 .06559 Mdot
.30428 .06576 Mdot
.30493 .066 Mdot
.30528 .06613 Mdot
.30592 .06636 Mdot
.30617 .06645 Mdot
.30673 .06666 Mdot
.30721 .06683 Mdot
.30732 .06688 Mdot
.30781 .06706 Mdot
.30791 .06709 Mdot
.3083 .06724 Mdot
.30874 .0674 Mdot
.30897 .06748 Mdot
.30942 .06765 Mdot
.30984 .06781 Mdot
.31015 .06792 Mdot
.31103 .06825 Mdot
.31169 .06849 Mdot
.31224 .0687 Mdot
.31228 .06872 Mdot
.313 .06899 Mdot
.31305 .069 Mdot
.31385 .0693 Mdot
.31427 .06946 Mdot
.31456 .06957 Mdot
.31486 .06969 Mdot
.31541 .06989 Mdot
.31602 .07012 Mdot
.31607 .07014 Mdot
.31698 .07049 Mdot
.31741 .07066 Mdot
.3178 .0708 Mdot
.31798 .07087 Mdot
.31852 .07108 Mdot
.31908 .07129 Mdot
.31943 .07143 Mdot
.3195 .07145 Mdot
.31973 .07154 Mdot
.32003 .07166 Mdot
.32047 .07183 Mdot
.32066 .0719 Mdot
.32092 .072 Mdot
.32135 .07217 Mdot
.32177 .07233 Mdot
.32208 .07245 Mdot
.32245 .07259 Mdot
.3232 .07288 Mdot
.32332 .07293 Mdot
.32399 .07319 Mdot
.32453 .0734 Mdot
.32507 .07361 Mdot
.3254 .07374 Mdot
.32598 .07397 Mdot
.32676 .07427 Mdot
.32718 .07444 Mdot
.32747 .07455 Mdot
.32811 .07481 Mdot
.32876 .07506 Mdot
.32888 .07511 Mdot
.32945 .07533 Mdot
.32992 .07552 Mdot
.33045 .07573 Mdot
.33085 .07589 Mdot
.33116 .07602 Mdot
.33127 .07606 Mdot
.33173 .07624 Mdot
.33216 .07642 Mdot
.33276 .07666 Mdot
.33284 .07669 Mdot
.33329 .07687 Mdot
.33371 .07704 Mdot
.33433 .07729 Mdot
.33438 .07731 Mdot
.33503 .07757 Mdot
.33527 .07767 Mdot
.33595 .07794 Mdot
.33629 .07808 Mdot
.33635 .0781 Mdot
.33668 .07824 Mdot
.33712 .07842 Mdot
.33756 .0786 Mdot
.33805 .0788 Mdot
.33885 .07912 Mdot
.33912 .07923 Mdot
.33931 .07931 Mdot
.33965 .07945 Mdot
.33989 .07955 Mdot
.3409 .07996 Mdot
.34111 .08005 Mdot
.34149 .0802 Mdot
.34184 .08035 Mdot
.34234 .08056 Mdot
.34237 .08057 Mdot
.34302 .08084 Mdot
.34339 .08099 Mdot
.34359 .08108 Mdot
.34421 .08133 Mdot
.34464 .08151 Mdot
.34533 .0818 Mdot
.34544 .08184 Mdot
.34607 .08211 Mdot
.34632 .08221 Mdot
.34687 .08244 Mdot
.34737 .08265 Mdot
.34784 .08285 Mdot
.34801 .08292 Mdot
.34863 .08318 Mdot
.34873 .08323 Mdot
.34925 .08344 Mdot
.3499 .08372 Mdot
.35052 .08398 Mdot
.35069 .08406 Mdot
.35112 .08424 Mdot
.35189 .08456 Mdot
.35217 .08468 Mdot
.35268 .0849 Mdot
.35286 .08498 Mdot
.35329 .08516 Mdot
.35372 .08535 Mdot
.35436 .08562 Mdot
.35488 .08585 Mdot
.35567 .08618 Mdot
.35591 .08629 Mdot
.35613 .08638 Mdot
.35656 .08657 Mdot
.35692 .08672 Mdot
.35738 .08692 Mdot
.35776 .08708 Mdot
.35838 .08736 Mdot
.35889 .08758 Mdot
.35928 .08775 Mdot
.35957 .08787 Mdot
.36021 .08815 Mdot
.36055 .0883 Mdot
.361 .0885 Mdot
.3616 .08876 Mdot
.36206 .08896 Mdot
.36215 .089 Mdot
.36256 .08918 Mdot
.36319 .08946 Mdot
.36365 .08966 Mdot
.36403 .08983 Mdot
.36414 .08988 Mdot
.36445 .09002 Mdot
.36505 .09028 Mdot
.36531 .09039 Mdot
.36628 .09083 Mdot
.3664 .09088 Mdot
.36672 .09102 Mdot
.36728 .09127 Mdot
.36741 .09133 Mdot
.36799 .09159 Mdot
.36826 .09171 Mdot
.36838 .09176 Mdot
.36901 .09204 Mdot
.36932 .09218 Mdot
.36983 .09241 Mdot
.36996 .09247 Mdot
.37014 .09255 Mdot
.37094 .09291 Mdot
.37168 .09325 Mdot
.37172 .09327 Mdot
.37222 .09349 Mdot
.37242 .09358 Mdot
.37273 .09372 Mdot
.37327 .09396 Mdot
.37379 .0942 Mdot
.37441 .09448 Mdot
.37457 .09456 Mdot
.3748 .09466 Mdot
.37556 .095 Mdot
.37597 .09519 Mdot
.3761 .09526 Mdot
.37633 .09536 Mdot
.37669 .09552 Mdot
.37689 .09562 Mdot
.37774 .09601 Mdot
.3781 .09617 Mdot
.37895 .09656 Mdot
.37931 .09673 Mdot
.3798 .09695 Mdot
.38035 .09721 Mdot
.38063 .09734 Mdot
.38107 .09754 Mdot
.38154 .09776 Mdot
.38198 .09796 Mdot
.38257 .09824 Mdot
.38283 .09836 Mdot
.38336 .09861 Mdot
.38371 .09877 Mdot
.38412 .09896 Mdot
.38467 .09922 Mdot
.38521 .09947 Mdot
.38564 .09968 Mdot
.38586 .09978 Mdot
.38633 .1 Mdot
.38675 .1002 Mdot
.38717 .10039 Mdot
.38738 .10049 Mdot
.38828 .10092 Mdot
.38902 .10127 Mdot
.38919 .10135 Mdot
.3895 .1015 Mdot
.38973 .10161 Mdot
.39013 .1018 Mdot
.39067 .10205 Mdot
.39076 .1021 Mdot
.39131 .10236 Mdot
.39159 .10249 Mdot
.39176 .10257 Mdot
.3922 .10278 Mdot
.39259 .10297 Mdot
.3928 .10307 Mdot
.39307 .1032 Mdot
.39336 .10334 Mdot
.39438 .10383 Mdot
.39462 .10394 Mdot
.39497 .10411 Mdot
.39561 .10442 Mdot
.39588 .10455 Mdot
.39661 .1049 Mdot
.39695 .10507 Mdot
.39728 .10523 Mdot
.39774 .10545 Mdot
.39787 .10551 Mdot
.39852 .10583 Mdot
.39913 .10613 Mdot
.3994 .10626 Mdot
.40008 .10659 Mdot
.4003 .1067 Mdot
.40066 .10687 Mdot
.40091 .107 Mdot
.40104 .10706 Mdot
.40147 .10727 Mdot
.4021 .10758 Mdot
.40246 .10775 Mdot
.40289 .10797 Mdot
.40293 .10799 Mdot
.40354 .10829 Mdot
.40404 .10853 Mdot
.40444 .10873 Mdot
.40512 .10907 Mdot
.40555 .10928 Mdot
.40572 .10937 Mdot
.40654 .10977 Mdot
.40698 .10999 Mdot
.40755 .11027 Mdot
.4079 .11045 Mdot
.40846 .11073 Mdot
.4088 .1109 Mdot
.40961 .1113 Mdot
.40981 .1114 Mdot
.41053 .11176 Mdot
.41081 .11191 Mdot
.41097 .11198 Mdot
.41166 .11233 Mdot
.41231 .11266 Mdot
.41275 .11288 Mdot
.4131 .11306 Mdot
.41324 .11313 Mdot
.41396 .11349 Mdot
.41448 .11376 Mdot
.41481 .11392 Mdot
.41527 .11416 Mdot
.41554 .1143 Mdot
.41619 .11463 Mdot
.41661 .11484 Mdot
.41707 .11507 Mdot
.41737 .11523 Mdot
.41759 .11534 Mdot
.41776 .11543 Mdot
.41828 .11569 Mdot
.41889 .116 Mdot
.41929 .11621 Mdot
.41977 .11646 Mdot
.42043 .1168 Mdot
.42062 .1169 Mdot
.4212 .11719 Mdot
.42208 .11765 Mdot
.42221 .11772 Mdot
.42284 .11804 Mdot
.42331 .11828 Mdot
.42349 .11838 Mdot
.42391 .1186 Mdot
.42433 .11882 Mdot
.42474 .11903 Mdot
.42498 .11915 Mdot
.4252 .11927 Mdot
.42574 .11955 Mdot
.42621 .11979 Mdot
.42654 .11997 Mdot
.42676 .12008 Mdot
.42705 .12023 Mdot
.42722 .12032 Mdot
.42774 .12059 Mdot
.428 .12073 Mdot
.42827 .12088 Mdot
.42868 .12109 Mdot
.429 .12126 Mdot
.4294 .12147 Mdot
.42953 .12154 Mdot
.43006 .12181 Mdot
.4306 .1221 Mdot
.431 .12231 Mdot
.43155 .1226 Mdot
.43198 .12283 Mdot
.43215 .12292 Mdot
.43242 .12307 Mdot
.43305 .1234 Mdot
.43359 .12369 Mdot
.43414 .12398 Mdot
.4343 .12406 Mdot
.43487 .12436 Mdot
.43505 .12446 Mdot
.43587 .1249 Mdot
.43605 .125 Mdot
.43616 .12505 Mdot
.43674 .12537 Mdot
.43686 .12543 Mdot
.43712 .12557 Mdot
.43778 .12593 Mdot
.4381 .1261 Mdot
.43834 .12623 Mdot
.43871 .12643 Mdot
.43923 .1267 Mdot
.4397 .12696 Mdot
.44 .12712 Mdot
.4404 .12734 Mdot
.44088 .1276 Mdot
.44112 .12773 Mdot
.44146 .12791 Mdot
.44207 .12824 Mdot
.44262 .12854 Mdot
.44292 .1287 Mdot
.44335 .12894 Mdot
.44367 .12911 Mdot
.4439 .12924 Mdot
.44422 .12941 Mdot
.44474 .1297 Mdot
.44483 .12974 Mdot
.44534 .13002 Mdot
.44616 .13047 Mdot
.44657 .1307 Mdot
.44708 .13098 Mdot
.44747 .13119 Mdot
.44808 .13152 Mdot
.44813 .13156 Mdot
.44864 .13184 Mdot
.44911 .13209 Mdot
.44964 .13239 Mdot
.4503 .13275 Mdot
.45044 .13283 Mdot
.45094 .13311 Mdot
.45175 .13356 Mdot
.45193 .13366 Mdot
.45244 .13394 Mdot
.45278 .13413 Mdot
.45299 .13425 Mdot
.45335 .13445 Mdot
.45371 .13465 Mdot
.45381 .1347 Mdot
.4545 .13509 Mdot
.45487 .13529 Mdot
.45546 .13563 Mdot
.45577 .1358 Mdot
.45607 .13597 Mdot
.45635 .13612 Mdot
.45664 .13629 Mdot
.45706 .13653 Mdot
.45712 .13656 Mdot
.4576 .13683 Mdot
.45778 .13693 Mdot
.45837 .13726 Mdot
.45868 .13744 Mdot
.45906 .13765 Mdot
.45909 .13767 Mdot
.45942 .13785 Mdot
.46012 .13825 Mdot
.46054 .13849 Mdot
.46096 .13873 Mdot
.46158 .13908 Mdot
.46195 .13929 Mdot
.46242 .13956 Mdot
.46302 .1399 Mdot
.46323 .14002 Mdot
.46366 .14027 Mdot
.46419 .14057 Mdot
.46447 .14073 Mdot
.46505 .14106 Mdot
.46538 .14125 Mdot
.46586 .14152 Mdot
.46611 .14166 Mdot
.46631 .14178 Mdot
.46696 .14216 Mdot
.46745 .14244 Mdot
.46757 .14251 Mdot
.46809 .1428 Mdot
.46856 .14308 Mdot
.46881 .14322 Mdot
.46926 .14348 Mdot
.46933 .14352 Mdot
.46956 .14366 Mdot
.46984 .14381 Mdot
.47026 .14406 Mdot
.4705 .1442 Mdot
.4709 .14443 Mdot
.47091 .14444 Mdot
.47142 .14473 Mdot
.47219 .14518 Mdot
.4724 .1453 Mdot
.47278 .14552 Mdot
.47309 .14571 Mdot
.47379 .14611 Mdot
.47418 .14634 Mdot
.47479 .1467 Mdot
.47488 .14675 Mdot
.47534 .14702 Mdot
.47559 .14717 Mdot
.47609 .14746 Mdot
.47647 .14768 Mdot
.47695 .14797 Mdot
.47731 .14818 Mdot
.4777 .14841 Mdot
.47791 .14853 Mdot
.47811 .14865 Mdot
.47842 .14883 Mdot
.47885 .14909 Mdot
.47941 .14942 Mdot
.4796 .14953 Mdot
.47976 .14962 Mdot
.48004 .14979 Mdot
.48049 .15006 Mdot
.48096 .15033 Mdot
.4814 .15059 Mdot
.48179 .15083 Mdot
.48207 .151 Mdot
.48238 .15118 Mdot
.48271 .15137 Mdot
.48304 .15157 Mdot
.48324 .15169 Mdot
.48392 .1521 Mdot
.48413 .15222 Mdot
.48465 .15253 Mdot
.48509 .15279 Mdot
.48561 .15311 Mdot
.48591 .15329 Mdot
.48646 .15362 Mdot
.48697 .15392 Mdot
.48745 .15421 Mdot
.48769 .15436 Mdot
.48865 .15493 Mdot
.48886 .15506 Mdot
.48906 .15518 Mdot
.48936 .15536 Mdot
.48998 .15574 Mdot
.49013 .15583 Mdot
.49053 .15607 Mdot
.49114 .15644 Mdot
.49145 .15663 Mdot
.49199 .15695 Mdot
.49257 .15731 Mdot
.49301 .15758 Mdot
.4933 .15775 Mdot
.49422 .15831 Mdot
.49461 .15855 Mdot
.49478 .15866 Mdot
.4954 .15904 Mdot
.49577 .15926 Mdot
.49595 .15937 Mdot
.49648 .1597 Mdot
.49663 .15979 Mdot
.49687 .15994 Mdot
.49759 .16038 Mdot
.49824 .16078 Mdot
.49853 .16096 Mdot
.4989 .16119 Mdot
.49924 .16139 Mdot
.49967 .16166 Mdot
.50019 .16198 Mdot
.50051 .16218 Mdot
.50077 .16234 Mdot
.5012 .16261 Mdot
.50194 .16307 Mdot
.50244 .16338 Mdot
.5028 .1636 Mdot
.50322 .16386 Mdot
.50341 .16398 Mdot
.50392 .1643 Mdot
.50418 .16446 Mdot
.50454 .16469 Mdot
.50505 .165 Mdot
.50525 .16513 Mdot
.50561 .16535 Mdot
.50593 .16555 Mdot
.50615 .16569 Mdot
.50641 .16586 Mdot
.50676 .16608 Mdot
.5075 .16654 Mdot
.50755 .16657 Mdot
.50829 .16703 Mdot
.50852 .16718 Mdot
.5088 .16736 Mdot
.50949 .16779 Mdot
.5099 .16805 Mdot
.51025 .16827 Mdot
.51055 .16846 Mdot
.511 .16874 Mdot
.51132 .16895 Mdot
.51205 .16941 Mdot
.51223 .16952 Mdot
.51264 .16978 Mdot
.51318 .17012 Mdot
.51332 .17021 Mdot
.51401 .17065 Mdot
.5144 .1709 Mdot
.51459 .17102 Mdot
.5149 .17122 Mdot
.51534 .1715 Mdot
.51583 .17181 Mdot
.51656 .17228 Mdot
.51672 .17238 Mdot
.51735 .17279 Mdot
.51769 .173 Mdot
.51817 .17331 Mdot
.51875 .17368 Mdot
.51905 .17387 Mdot
.51952 .17418 Mdot
.51977 .17434 Mdot
.51988 .17441 Mdot
.52033 .1747 Mdot
.52052 .17482 Mdot
.5206 .17487 Mdot
.52098 .17512 Mdot
.52158 .1755 Mdot
.522 .17578 Mdot
.52224 .17593 Mdot
.52244 .17606 Mdot
.52317 .17653 Mdot
.52369 .17687 Mdot
.52404 .1771 Mdot
.52471 .17753 Mdot
.52479 .17758 Mdot
.52521 .17786 Mdot
.52567 .17816 Mdot
.52612 .17845 Mdot
.52667 .17881 Mdot
.52691 .17897 Mdot
.52738 .17927 Mdot
.52763 .17944 Mdot
.52831 .17988 Mdot
.52864 .1801 Mdot
.52935 .18056 Mdot
.52954 .18069 Mdot
.5302 .18112 Mdot
.53052 .18133 Mdot
.53099 .18164 Mdot
.53112 .18173 Mdot
.53148 .18197 Mdot
.53223 .18246 Mdot
.53228 .18249 Mdot
.5329 .1829 Mdot
.53331 .18317 Mdot
.53353 .18332 Mdot
.53397 .18361 Mdot
.5343 .18383 Mdot
.53454 .18399 Mdot
.53509 .18435 Mdot
.53525 .18446 Mdot
.53591 .1849 Mdot
.53666 .1854 Mdot
.53689 .18555 Mdot
.53728 .18581 Mdot
.53809 .18635 Mdot
.53824 .18645 Mdot
.53883 .18684 Mdot
.5394 .18723 Mdot
.53969 .18742 Mdot
.53996 .1876 Mdot
.54033 .18785 Mdot
.54089 .18822 Mdot
.54105 .18833 Mdot
.54128 .18848 Mdot
.54203 .18899 Mdot
.54249 .1893 Mdot
.5429 .18958 Mdot
.54339 .1899 Mdot
.5439 .19025 Mdot
.54414 .19041 Mdot
.54467 .19077 Mdot
.54478 .19085 Mdot
.54564 .19143 Mdot
.54578 .19152 Mdot
.54639 .19194 Mdot
.54677 .19219 Mdot
.54736 .19259 Mdot
.54794 .19298 Mdot
.54819 .19316 Mdot
.54836 .19327 Mdot
.54888 .19363 Mdot
.54909 .19377 Mdot
.54946 .19402 Mdot
.55022 .19454 Mdot
.55073 .19489 Mdot
.55101 .19508 Mdot
.55168 .19554 Mdot
.55216 .19587 Mdot
.55269 .19623 Mdot
.5528 .19631 Mdot
.55354 .19681 Mdot
.55417 .19725 Mdot
.55439 .1974 Mdot
.5547 .19761 Mdot
.55496 .19779 Mdot
.55566 .19827 Mdot
.55599 .1985 Mdot
.55641 .1988 Mdot
.55658 .19891 Mdot
.55709 .19927 Mdot
.55739 .19947 Mdot
.558 .19989 Mdot
.55865 .20035 Mdot
.559 .20059 Mdot
.55981 .20115 Mdot
.5603 .2015 Mdot
.56049 .20162 Mdot
.56096 .20196 Mdot
.56118 .2021 Mdot
.56213 .20277 Mdot
.56241 .20296 Mdot
.56246 .203 Mdot
.56293 .20333 Mdot
.56356 .20377 Mdot
.56399 .20407 Mdot
.56403 .2041 Mdot
.56465 .20454 Mdot
.56483 .20466 Mdot
.56548 .20511 Mdot
.56557 .20518 Mdot
.56588 .2054 Mdot
.56631 .2057 Mdot
.56662 .20592 Mdot
.56704 .20621 Mdot
.56723 .20635 Mdot
.56771 .20669 Mdot
.56853 .20727 Mdot
.5687 .20739 Mdot
.56922 .20775 Mdot
.56962 .20804 Mdot
.56992 .20825 Mdot
.57036 .20856 Mdot
.57053 .20868 Mdot
.57112 .2091 Mdot
.57144 .20933 Mdot
.57168 .2095 Mdot
.57231 .20995 Mdot
.57238 .21 Mdot
.57346 .21077 Mdot
.5738 .21101 Mdot
.57405 .21119 Mdot
.57478 .21171 Mdot
.57489 .21179 Mdot
.57539 .21215 Mdot
.57557 .21228 Mdot
.57603 .21261 Mdot
.57635 .21284 Mdot
.57693 .21325 Mdot
.5772 .21344 Mdot
.57769 .2138 Mdot
.57788 .21393 Mdot
.5784 .21431 Mdot
.57893 .21469 Mdot
.57935 .21499 Mdot
.5798 .21532 Mdot
.58008 .21552 Mdot
.58048 .21581 Mdot
.58075 .21601 Mdot
.58137 .21645 Mdot
.58143 .21649 Mdot
.58242 .21721 Mdot
.58266 .21739 Mdot
.58306 .21767 Mdot
.58357 .21805 Mdot
.58392 .2183 Mdot
.58413 .21846 Mdot
.58428 .21856 Mdot
.5847 .21887 Mdot
.58496 .21906 Mdot
.58528 .21929 Mdot
.58614 .21992 Mdot
.58644 .22013 Mdot
.58702 .22056 Mdot
.58729 .22076 Mdot
.58759 .22098 Mdot
.58817 .2214 Mdot
.58861 .22173 Mdot
.58887 .22192 Mdot
.58921 .22217 Mdot
.58961 .22246 Mdot
.58979 .22259 Mdot
.59017 .22287 Mdot
.59057 .22317 Mdot
.59115 .22359 Mdot
.59149 .22384 Mdot
.59176 .22404 Mdot
.59233 .22446 Mdot
.59269 .22473 Mdot
.59318 .22509 Mdot
.59393 .22564 Mdot
.59411 .22577 Mdot
.59449 .22606 Mdot
.59516 .22655 Mdot
.59577 .227 Mdot
.59615 .22729 Mdot
.59637 .22745 Mdot
.59671 .22771 Mdot
.59758 .22835 Mdot
.59811 .22874 Mdot
.59847 .22902 Mdot
.59864 .22914 Mdot
.59914 .22952 Mdot
.59986 .23005 Mdot
.60022 .23032 Mdot
.60069 .23068 Mdot
.60142 .23122 Mdot
.60148 .23127 Mdot
.60185 .23154 Mdot
.60235 .23192 Mdot
.603 .23241 Mdot
.60367 .23291 Mdot
.60378 .23299 Mdot
.60427 .23336 Mdot
.60452 .23355 Mdot
.60547 .23427 Mdot
.60594 .23463 Mdot
.60658 .23511 Mdot
.60684 .2353 Mdot
.60725 .23562 Mdot
.60804 .23621 Mdot
.60844 .23651 Mdot
.60871 .23672 Mdot
.60904 .23697 Mdot
.60981 .23756 Mdot
.61012 .2378 Mdot
.61044 .23804 Mdot
.61059 .23815 Mdot
.61099 .23846 Mdot
.61145 .23881 Mdot
.61204 .23926 Mdot
.61278 .23982 Mdot
.61302 .24001 Mdot
.61342 .24031 Mdot
.61386 .24065 Mdot
.61451 .24115 Mdot
.61457 .24119 Mdot
.61519 .24167 Mdot
.61564 .24202 Mdot
.61577 .24212 Mdot
.61602 .2423 Mdot
.61648 .24266 Mdot
.61681 .24291 Mdot
.61709 .24313 Mdot
.61764 .24355 Mdot
.61805 .24387 Mdot
.61834 .24409 Mdot
.61877 .24443 Mdot
.61923 .24478 Mdot
.61961 .24508 Mdot
.62013 .24547 Mdot
.62043 .24571 Mdot
.62094 .24611 Mdot
.62105 .24619 Mdot
.62145 .2465 Mdot
.62222 .24709 Mdot
.62262 .24741 Mdot
.62284 .24758 Mdot
.62329 .24793 Mdot
.62394 .24844 Mdot
.6244 .24879 Mdot
.62502 .24928 Mdot
.62544 .2496 Mdot
.62579 .24987 Mdot
.62618 .25018 Mdot
.6266 .25051 Mdot
.62687 .25072 Mdot
.62709 .25089 Mdot
.62754 .25125 Mdot
.62785 .25149 Mdot
.62853 .25202 Mdot
.62896 .25236 Mdot
.62929 .25262 Mdot
.62946 .25275 Mdot
.62984 .25305 Mdot
.62993 .25312 Mdot
.63048 .25356 Mdot
.631 .25396 Mdot
.63132 .25421 Mdot
.6316 .25443 Mdot
.63186 .25464 Mdot
.63258 .25521 Mdot
.63305 .25558 Mdot
.63327 .25576 Mdot
.63366 .25606 Mdot
.63378 .25616 Mdot
.63406 .25638 Mdot
.63433 .2566 Mdot
.63502 .25714 Mdot
.63522 .2573 Mdot
.63571 .25769 Mdot
.63606 .25797 Mdot
.63669 .25847 Mdot
.63712 .25881 Mdot
.63729 .25895 Mdot
.63756 .25917 Mdot
.63833 .25977 Mdot
.63847 .25989 Mdot
.63881 .26016 Mdot
.63894 .26026 Mdot
.63951 .26072 Mdot
.63958 .26077 Mdot
.63991 .26104 Mdot
.6406 .26159 Mdot
.64077 .26173 Mdot
.64093 .26186 Mdot
.64125 .26211 Mdot
.64158 .26237 Mdot
.64242 .26305 Mdot
.64282 .26337 Mdot
.64285 .2634 Mdot
.64346 .26388 Mdot
.64372 .2641 Mdot
.64452 .26474 Mdot
.64476 .26493 Mdot
.64539 .26544 Mdot
.64571 .2657 Mdot
.64643 .26628 Mdot
.64671 .26651 Mdot
.64692 .26668 Mdot
.64728 .26697 Mdot
.64787 .26744 Mdot
.64804 .26758 Mdot
.64828 .26778 Mdot
.64858 .26802 Mdot
.64914 .26848 Mdot
.64957 .26882 Mdot
.65016 .26931 Mdot
.65082 .26984 Mdot
.651 .26998 Mdot
.65164 .2705 Mdot
.65185 .27067 Mdot
.65228 .27103 Mdot
.65292 .27155 Mdot
.65355 .27207 Mdot
.65367 .27216 Mdot
.65407 .27249 Mdot
.65467 .27298 Mdot
.6553 .2735 Mdot
.65583 .27393 Mdot
.6565 .27448 Mdot
.65675 .27469 Mdot
.65732 .27516 Mdot
.65743 .27525 Mdot
.6581 .2758 Mdot
.65834 .27599 Mdot
.65887 .27643 Mdot
.65934 .27682 Mdot
.65962 .27705 Mdot
.66029 .2776 Mdot
.66052 .2778 Mdot
.66082 .27804 Mdot
.66129 .27843 Mdot
.66184 .27889 Mdot
.66208 .27909 Mdot
.66217 .27916 Mdot
.66287 .27974 Mdot
.66321 .28002 Mdot
.66335 .28014 Mdot
.66377 .28048 Mdot
.66443 .28103 Mdot
.66475 .2813 Mdot
.66538 .28182 Mdot
.66586 .28223 Mdot
.66656 .28281 Mdot
.66698 .28316 Mdot
.66748 .28358 Mdot
.66788 .28391 Mdot
.66806 .28407 Mdot
.66846 .2844 Mdot
.66901 .28485 Mdot
.66925 .28506 Mdot
.66979 .28551 Mdot
.66999 .28568 Mdot
.67042 .28603 Mdot
.67095 .28648 Mdot
.67129 .28677 Mdot
.67145 .2869 Mdot
.67172 .28713 Mdot
.67238 .28769 Mdot
.67259 .28786 Mdot
.6729 .28813 Mdot
.67337 .28852 Mdot
.6737 .2888 Mdot
.67409 .28912 Mdot
.67432 .28932 Mdot
.67483 .28976 Mdot
.67527 .29012 Mdot
.6757 .29048 Mdot
.67653 .29119 Mdot
.67666 .2913 Mdot
.6772 .29176 Mdot
.67771 .29219 Mdot
.67816 .29257 Mdot
.67845 .29282 Mdot
.67893 .29323 Mdot
.67922 .29347 Mdot
.67981 .29398 Mdot
.68037 .29445 Mdot
.68092 .29492 Mdot
.68114 .29511 Mdot
.68141 .29534 Mdot
.68197 .29582 Mdot
.68225 .29605 Mdot
.68264 .29639 Mdot
.68316 .29684 Mdot
.68365 .29726 Mdot
.68407 .29762 Mdot
.68427 .29779 Mdot
.68463 .29809 Mdot
.68487 .2983 Mdot
.68515 .29854 Mdot
.68522 .2986 Mdot
.68596 .29923 Mdot
.6862 .29944 Mdot
.68656 .29975 Mdot
.68664 .29982 Mdot
.6871 .30022 Mdot
.6873 .30039 Mdot
.68839 .30133 Mdot
.68876 .30165 Mdot
.68913 .30197 Mdot
.68941 .30221 Mdot
.68996 .30269 Mdot
.69002 .30274 Mdot
.69055 .30319 Mdot
.69068 .30331 Mdot
.69137 .30391 Mdot
.69154 .30405 Mdot
.69206 .3045 Mdot
.69242 .30482 Mdot
.69275 .3051 Mdot
.69342 .30568 Mdot
.69361 .30585 Mdot
.6943 .30645 Mdot
.69463 .30674 Mdot
.69529 .30731 Mdot
.69573 .3077 Mdot
.69618 .30808 Mdot
.69681 .30864 Mdot
.69716 .30894 Mdot
.69739 .30914 Mdot
.69792 .30961 Mdot
.6987 .31029 Mdot
.69927 .31079 Mdot
.69948 .31097 Mdot
.69994 .31138 Mdot
.7003 .3117 Mdot
.7007 .31204 Mdot
.70096 .31227 Mdot
.70137 .31263 Mdot
.70165 .31288 Mdot
.70249 .31362 Mdot
.70268 .31379 Mdot
.70325 .31429 Mdot
.70363 .31462 Mdot
.70414 .31507 Mdot
.70469 .31556 Mdot
.70477 .31563 Mdot
.70534 .31614 Mdot
.70596 .31669 Mdot
.70635 .31703 Mdot
.70663 .31728 Mdot
.70686 .31748 Mdot
.70724 .31782 Mdot
.7074 .31796 Mdot
.70786 .31836 Mdot
.70836 .31882 Mdot
.70882 .31922 Mdot
.70929 .31964 Mdot
.70932 .31967 Mdot
.71 .32028 Mdot
.71028 .32052 Mdot
.71038 .32061 Mdot
.71079 .32098 Mdot
.71152 .32162 Mdot
.71159 .32169 Mdot
.71212 .32216 Mdot
.71225 .32228 Mdot
.71239 .32241 Mdot
.71257 .32257 Mdot
.71278 .32276 Mdot
.71321 .32314 Mdot
.71339 .3233 Mdot
.71396 .32381 Mdot
.71419 .32401 Mdot
.71454 .32433 Mdot
.71491 .32466 Mdot
.71519 .32491 Mdot
.71564 .32532 Mdot
.71614 .32577 Mdot
.71686 .32641 Mdot
.71708 .32661 Mdot
.71754 .32702 Mdot
.71785 .3273 Mdot
.71831 .32772 Mdot
.71851 .32789 Mdot
.71873 .3281 Mdot
.71938 .32868 Mdot
.71984 .3291 Mdot
.7201 .32933 Mdot
.72055 .32973 Mdot
.72086 .33002 Mdot
.72151 .33061 Mdot
.72178 .33086 Mdot
.72225 .33127 Mdot
.72267 .33166 Mdot
.72296 .33192 Mdot
.72324 .33218 Mdot
.72356 .33247 Mdot
.72414 .33299 Mdot
.72462 .33343 Mdot
.72492 .3337 Mdot
.72537 .33412 Mdot
.72576 .33447 Mdot
.72591 .33461 Mdot
.72613 .3348 Mdot
.72699 .33559 Mdot
.72728 .33586 Mdot
.72787 .3364 Mdot
.72837 .33685 Mdot
.72877 .33722 Mdot
.72902 .33745 Mdot
.72939 .33779 Mdot
.72966 .33803 Mdot
.72999 .33833 Mdot
.73037 .33868 Mdot
.73049 .33879 Mdot
.73086 .33914 Mdot
.73152 .33974 Mdot
.73181 .34 Mdot
.73219 .34036 Mdot
.73245 .3406 Mdot
.73257 .3407 Mdot
.73315 .34124 Mdot
.73338 .34145 Mdot
.73349 .34155 Mdot
.73393 .34195 Mdot
.73406 .34207 Mdot
.73499 .34293 Mdot
.73531 .34323 Mdot
.73609 .34394 Mdot
.73631 .34415 Mdot
.73648 .34431 Mdot
.73723 .345 Mdot
.73772 .34545 Mdot
.73787 .3456 Mdot
.73807 .34578 Mdot
.73863 .3463 Mdot
.73867 .34634 Mdot
.73921 .34684 Mdot
.73942 .34703 Mdot
.74005 .34761 Mdot
.74023 .34779 Mdot
.74054 .34808 Mdot
.741 .3485 Mdot
.74128 .34877 Mdot
.74202 .34945 Mdot
.74256 .34996 Mdot
.74295 .35032 Mdot
.74352 .35085 Mdot
.74384 .35116 Mdot
.74422 .3515 Mdot
.74484 .35209 Mdot
.74524 .35246 Mdot
.74593 .3531 Mdot
.74604 .35321 Mdot
.7468 .35392 Mdot
.74694 .35405 Mdot
.74768 .35475 Mdot
.74785 .35491 Mdot
.74824 .35527 Mdot
.74856 .35558 Mdot
.74942 .35638 Mdot
.74982 .35676 Mdot
.75017 .35709 Mdot
.75073 .35762 Mdot
.75117 .35804 Mdot
.75151 .35836 Mdot
.75225 .35905 Mdot
.75242 .35922 Mdot
.75307 .35983 Mdot
.75338 .36013 Mdot
.75377 .3605 Mdot
.75422 .36093 Mdot
.75446 .36115 Mdot
.75508 .36174 Mdot
.75526 .36191 Mdot
.75562 .36225 Mdot
.7562 .3628 Mdot
.75699 .36356 Mdot
.75737 .36391 Mdot
.75827 .36477 Mdot
.75851 .365 Mdot
.75882 .3653 Mdot
.75952 .36596 Mdot
.75969 .36612 Mdot
.76004 .36647 Mdot
.76066 .36706 Mdot
.76089 .36727 Mdot
.76103 .3674 Mdot
.76152 .36788 Mdot
.76219 .36852 Mdot
.76257 .36888 Mdot
.76279 .3691 Mdot
.76324 .36953 Mdot
.76367 .36994 Mdot
.76418 .37043 Mdot
.76431 .37056 Mdot
.76493 .37115 Mdot
.76538 .37158 Mdot
.76568 .37187 Mdot
.76598 .37216 Mdot
.76674 .37289 Mdot
.76711 .37325 Mdot
.76758 .3737 Mdot
.76769 .37381 Mdot
.76815 .37425 Mdot
.76858 .37467 Mdot
.769 .37507 Mdot
.76978 .37583 Mdot
.77006 .3761 Mdot
.77024 .37627 Mdot
.77055 .37658 Mdot
.771 .37701 Mdot
.77118 .37719 Mdot
.77168 .37767 Mdot
.77201 .37799 Mdot
.77236 .37833 Mdot
.77258 .37855 Mdot
.77287 .37883 Mdot
.77319 .37914 Mdot
.77377 .3797 Mdot
.77386 .37979 Mdot
.77449 .38041 Mdot
.77508 .38098 Mdot
.77536 .38125 Mdot
.77548 .38137 Mdot
.77581 .38169 Mdot
.77614 .38202 Mdot
.77678 .38263 Mdot
.77713 .38298 Mdot
.77741 .38325 Mdot
.77753 .38337 Mdot
.77829 .38412 Mdot
.77834 .38417 Mdot
.77896 .38477 Mdot
.77952 .38532 Mdot
.77986 .38565 Mdot
.78046 .38625 Mdot
.78083 .38661 Mdot
.78147 .38724 Mdot
.78162 .38738 Mdot
.78184 .3876 Mdot
.78213 .38788 Mdot
.78267 .38841 Mdot
.78305 .38879 Mdot
.78325 .38899 Mdot
.78368 .38942 Mdot
.78431 .39003 Mdot
.78469 .39041 Mdot
.78474 .39046 Mdot
.7854 .39111 Mdot
.78586 .39157 Mdot
.78602 .39172 Mdot
.7865 .3922 Mdot
.78735 .39304 Mdot
.78764 .39332 Mdot
.78772 .39341 Mdot
.78799 .39368 Mdot
.78872 .3944 Mdot
.78899 .39467 Mdot
.78968 .39535 Mdot
.78986 .39554 Mdot
.79009 .39576 Mdot
.79074 .3964 Mdot
.79127 .39694 Mdot
.79221 .39787 Mdot
.79251 .39817 Mdot
.79279 .39845 Mdot
.79315 .39881 Mdot
.79361 .39927 Mdot
.79394 .3996 Mdot
.79468 .40034 Mdot
.79527 .40093 Mdot
.79584 .40151 Mdot
.79642 .40208 Mdot
.79682 .40249 Mdot
.79704 .40271 Mdot
.79729 .40295 Mdot
.79748 .40315 Mdot
.79837 .40404 Mdot
.79844 .40412 Mdot
.79869 .40437 Mdot
.79906 .40473 Mdot
.79941 .40509 Mdot
.79963 .40531 Mdot
.79981 .40549 Mdot
.80023 .40591 Mdot
.80059 .40627 Mdot
.80089 .40658 Mdot
.80128 .40697 Mdot
.80169 .40739 Mdot
.80232 .40802 Mdot
.8026 .4083 Mdot
.80289 .4086 Mdot
.80328 .40899 Mdot
.80368 .4094 Mdot
.80458 .41031 Mdot
.80491 .41065 Mdot
.80533 .41107 Mdot
.8058 .41154 Mdot
.80616 .41191 Mdot
.8065 .41225 Mdot
.80688 .41264 Mdot
.80732 .41309 Mdot
.80763 .41341 Mdot
.80821 .41399 Mdot
.80838 .41417 Mdot
.80873 .41453 Mdot
.80905 .41486 Mdot
.80931 .41512 Mdot
.80946 .41527 Mdot
.81003 .41585 Mdot
.81072 .41655 Mdot
.81141 .41726 Mdot
.81172 .41758 Mdot
.81221 .41808 Mdot
.81252 .4184 Mdot
.81305 .41894 Mdot
.8134 .4193 Mdot
.81395 .41986 Mdot
.81419 .4201 Mdot
.81509 .42103 Mdot
.81539 .42134 Mdot
.81585 .42181 Mdot
.81614 .4221 Mdot
.81646 .42244 Mdot
.81686 .42285 Mdot
.81731 .42332 Mdot
.81769 .4237 Mdot
.81815 .42418 Mdot
.81862 .42466 Mdot
.81907 .42513 Mdot
.81958 .42565 Mdot
.81995 .42603 Mdot
.82012 .42622 Mdot
.82088 .427 Mdot
.82098 .42711 Mdot
.82169 .42783 Mdot
.82185 .42801 Mdot
.82211 .42827 Mdot
.82249 .42867 Mdot
.82317 .42937 Mdot
.82339 .4296 Mdot
.82356 .42978 Mdot
.8243 .43054 Mdot
.8245 .43075 Mdot
.82502 .4313 Mdot
.82542 .43171 Mdot
.82587 .43218 Mdot
.82615 .43247 Mdot
.82678 .43312 Mdot
.82729 .43365 Mdot
.82813 .43453 Mdot
.82841 .43482 Mdot
.82906 .4355 Mdot
.82944 .4359 Mdot
.82992 .43641 Mdot
.83026 .43676 Mdot
.83069 .43721 Mdot
.83086 .43739 Mdot
.83158 .43814 Mdot
.83179 .43836 Mdot
.83224 .43884 Mdot
.83263 .43924 Mdot
.8331 .43974 Mdot
.83334 .43999 Mdot
.834 .44069 Mdot
.8343 .441 Mdot
.83465 .44136 Mdot
.83499 .44172 Mdot
.83556 .44232 Mdot
.83568 .44245 Mdot
.83599 .44278 Mdot
.83619 .44299 Mdot
.83655 .44336 Mdot
.83677 .4436 Mdot
.83703 .44388 Mdot
.83733 .44419 Mdot
.83786 .44475 Mdot
.83811 .44502 Mdot
.83866 .4456 Mdot
.83922 .44619 Mdot
.84013 .44715 Mdot
.84018 .4472 Mdot
.84056 .44761 Mdot
.84105 .44813 Mdot
.84162 .44873 Mdot
.84181 .44893 Mdot
.84234 .4495 Mdot
.84277 .44995 Mdot
.84317 .45037 Mdot
.84362 .45086 Mdot
.84397 .45123 Mdot
.84461 .45191 Mdot
.84497 .4523 Mdot
.84537 .45272 Mdot
.84591 .4533 Mdot
.84612 .45352 Mdot
.84643 .45386 Mdot
.84682 .45427 Mdot
.84722 .4547 Mdot
.84739 .45488 Mdot
.84788 .4554 Mdot
.84824 .45579 Mdot
.84885 .45644 Mdot
.84895 .45655 Mdot
.84976 .45742 Mdot
.85007 .45775 Mdot
.85041 .45811 Mdot
.8507 .45843 Mdot
.85104 .45879 Mdot
.85149 .45927 Mdot
.85207 .45989 Mdot
.8525 .46036 Mdot
.85253 .46039 Mdot
.85339 .46131 Mdot
.8535 .46143 Mdot
.85379 .46175 Mdot
.8544 .4624 Mdot
.85481 .46285 Mdot
.85521 .46327 Mdot
.85607 .4642 Mdot
.85639 .46455 Mdot
.85694 .46514 Mdot
.85709 .46531 Mdot
.85759 .46585 Mdot
.85828 .4666 Mdot
.85846 .46679 Mdot
.85865 .467 Mdot
.85892 .46729 Mdot
.85949 .46791 Mdot
.86016 .46863 Mdot
.86099 .46954 Mdot
.86133 .46991 Mdot
.86177 .47039 Mdot
.86215 .4708 Mdot
.86226 .47091 Mdot
.86302 .47175 Mdot
.86335 .4721 Mdot
.86379 .47259 Mdot
.86431 .47315 Mdot
.86469 .47356 Mdot
.86495 .47385 Mdot
.86537 .4743 Mdot
.86584 .47483 Mdot
.86612 .47513 Mdot
.86683 .4759 Mdot
.86708 .47618 Mdot
.86742 .47655 Mdot
.86777 .47694 Mdot
.86786 .47703 Mdot
.86874 .47799 Mdot
.86937 .47869 Mdot
.86967 .47902 Mdot
.87025 .47965 Mdot
.87058 .48002 Mdot
.87117 .48066 Mdot
.87136 .48087 Mdot
.87169 .48123 Mdot
.8719 .48147 Mdot
.87222 .48181 Mdot
.87246 .48208 Mdot
.87271 .48236 Mdot
.87301 .48269 Mdot
.87349 .48322 Mdot
.874 .48378 Mdot
.87421 .48402 Mdot
.87444 .48427 Mdot
.87492 .4848 Mdot
.87542 .48535 Mdot
.87581 .48578 Mdot
.87648 .48652 Mdot
.87665 .48672 Mdot
.87726 .48738 Mdot
.87739 .48753 Mdot
.87776 .48794 Mdot
.87784 .48802 Mdot
.87834 .48858 Mdot
.87892 .48922 Mdot
.87922 .48956 Mdot
.87944 .4898 Mdot
.87999 .49042 Mdot
.88032 .49079 Mdot
.88035 .49081 Mdot
.88073 .49124 Mdot
.88125 .49182 Mdot
.88128 .49185 Mdot
.88168 .49229 Mdot
.88219 .49286 Mdot
.88257 .49328 Mdot
.88329 .49409 Mdot
.88357 .49441 Mdot
.88381 .49466 Mdot
.88426 .49517 Mdot
.88451 .49545 Mdot
.88524 .49627 Mdot
.88565 .49673 Mdot
.88588 .49698 Mdot
.8866 .49779 Mdot
.88699 .49822 Mdot
.88755 .49885 Mdot
.88792 .49927 Mdot
.88823 .49961 Mdot
.88831 .49971 Mdot
.88913 .50062 Mdot
.88941 .50094 Mdot
.89006 .50167 Mdot
.8901 .50171 Mdot
.89066 .50234 Mdot
.89102 .50275 Mdot
.89149 .50328 Mdot
.89191 .50375 Mdot
.89253 .50445 Mdot
.8927 .50464 Mdot
.89318 .50518 Mdot
.8937 .50577 Mdot
.89423 .50637 Mdot
.89463 .50683 Mdot
.89473 .50694 Mdot
.89541 .5077 Mdot
.89565 .50798 Mdot
.89591 .50827 Mdot
.89618 .50858 Mdot
.8964 .50883 Mdot
.8969 .5094 Mdot
.8974 .50996 Mdot
.89782 .51043 Mdot
.8981 .51075 Mdot
.89889 .51165 Mdot
.89937 .5122 Mdot
.89993 .51283 Mdot
.90009 .51301 Mdot
.90046 .51343 Mdot
.90079 .51381 Mdot
.90135 .51445 Mdot
.90156 .51468 Mdot
.90192 .5151 Mdot
.90274 .51603 Mdot
.90311 .51645 Mdot
.90334 .51672 Mdot
.90402 .51749 Mdot
.90459 .51814 Mdot
.90488 .51848 Mdot
.90532 .51898 Mdot
.90588 .51961 Mdot
.90626 .52006 Mdot
.90718 .52111 Mdot
.90724 .52118 Mdot
.90784 .52186 Mdot
.9083 .5224 Mdot
.90855 .52267 Mdot
.90915 .52337 Mdot
.90917 .5234 Mdot
.90977 .52408 Mdot
.91054 .52497 Mdot
.91099 .52549 Mdot
.91124 .52577 Mdot
.91137 .52592 Mdot
.91206 .52671 Mdot
.9124 .52711 Mdot
.9129 .52769 Mdot
.91327 .52812 Mdot
.91381 .52873 Mdot
.91429 .52929 Mdot
.91455 .52959 Mdot
.91518 .53032 Mdot
.9159 .53116 Mdot
.91608 .53136 Mdot
.91693 .53235 Mdot
.91727 .53274 Mdot
.9183 .53394 Mdot
.91837 .53401 Mdot
.91871 .53441 Mdot
.91927 .53506 Mdot
.91976 .53563 Mdot
.92008 .53601 Mdot
.92045 .53643 Mdot
.92076 .5368 Mdot
.9213 .53742 Mdot
.9214 .53755 Mdot
.92184 .53805 Mdot
.92228 .53857 Mdot
.92274 .5391 Mdot
.92357 .54007 Mdot
.92401 .54059 Mdot
.92456 .54123 Mdot
.92488 .54161 Mdot
.92521 .54199 Mdot
.9257 .54257 Mdot
.92585 .54274 Mdot
.92637 .54335 Mdot
.92649 .54349 Mdot
.92693 .54401 Mdot
.92726 .54439 Mdot
.9276 .5448 Mdot
.92788 .54512 Mdot
.92814 .54542 Mdot
.92848 .54583 Mdot
.92897 .5464 Mdot
.92966 .54721 Mdot
.9299 .5475 Mdot
.93052 .54822 Mdot
.93065 .54837 Mdot
.93102 .54881 Mdot
.93163 .54953 Mdot
.93201 .54998 Mdot
.93224 .55025 Mdot
.93266 .55075 Mdot
.9334 .55162 Mdot
.93385 .55214 Mdot
.93404 .55237 Mdot
.93418 .55254 Mdot
.9347 .55315 Mdot
.93533 .5539 Mdot
.93585 .55451 Mdot
.93626 .55499 Mdot
.93648 .55526 Mdot
.93698 .55585 Mdot
.93732 .55625 Mdot
.93734 .55627 Mdot
.93788 .55691 Mdot
.93803 .5571 Mdot
.93859 .55776 Mdot
.93884 .55806 Mdot
.93946 .5588 Mdot
.93996 .55939 Mdot
.94048 .56001 Mdot
.94087 .56047 Mdot
.94112 .56077 Mdot
.94147 .56119 Mdot
.94168 .56144 Mdot
.9424 .56229 Mdot
.943 .563 Mdot
.94352 .56363 Mdot
.94394 .56414 Mdot
.94427 .56453 Mdot
.9447 .56504 Mdot
.94503 .56543 Mdot
.9455 .566 Mdot
.94563 .56615 Mdot
.9458 .56636 Mdot
.94644 .56712 Mdot
.94675 .56749 Mdot
.94694 .56772 Mdot
.94745 .56833 Mdot
.94795 .56893 Mdot
.94832 .56938 Mdot
.94906 .57026 Mdot
.94936 .57062 Mdot
.94952 .57082 Mdot
.9503 .57176 Mdot
.95041 .57189 Mdot
.95097 .57255 Mdot
.95109 .5727 Mdot
.95157 .57328 Mdot
.95199 .57379 Mdot
.95227 .57413 Mdot
.95293 .57492 Mdot
.95313 .57516 Mdot
.95373 .57589 Mdot
.95414 .57638 Mdot
.95429 .57656 Mdot
.95461 .57694 Mdot
.95499 .5774 Mdot
.95593 .57854 Mdot
.95621 .57888 Mdot
.95643 .57915 Mdot
.95684 .57964 Mdot
.95705 .57989 Mdot
.95724 .58013 Mdot
.95768 .58066 Mdot
.95852 .58168 Mdot
.95906 .58233 Mdot
.95918 .58248 Mdot
.95981 .58324 Mdot
.9603 .58384 Mdot
.96075 .58439 Mdot
.96115 .58488 Mdot
.96159 .58541 Mdot
.96174 .5856 Mdot
.96226 .58622 Mdot
.96245 .58646 Mdot
.96304 .58718 Mdot
.96335 .58755 Mdot
.96368 .58796 Mdot
.96422 .58862 Mdot
.96445 .5889 Mdot
.96476 .58927 Mdot
.96482 .58935 Mdot
.96547 .59015 Mdot
.96592 .59069 Mdot
.96657 .59148 Mdot
.96677 .59173 Mdot
.9671 .59214 Mdot
.96766 .59282 Mdot
.96798 .59321 Mdot
.96836 .59368 Mdot
.96897 .59443 Mdot
.96924 .59476 Mdot
.96948 .59505 Mdot
.97007 .59578 Mdot
.97035 .59612 Mdot
.9706 .59643 Mdot
.97113 .59708 Mdot
.97168 .59776 Mdot
.97231 .59854 Mdot
.97258 .59886 Mdot
.97315 .59956 Mdot
.9739 .60049 Mdot
.97392 .60052 Mdot
.97454 .60128 Mdot
.97499 .60183 Mdot
.97567 .60267 Mdot
.97608 .60318 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2321) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00133906) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666686) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<0
0000103jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V
000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H010000002
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
000H0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000o`3j
l>JL0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003j
l>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V00000000
00002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000o`3jl>JL0?[`iP40oooo000P0?[`iP800000
0P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP00
0000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V10000003
0?[`iP@000000`3jl>H4000000@0n_3V0`0000030?[`iP@00000o`3jl>JM0?[`iP40oooo000P0?[`
iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP0000000000
00D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3j
l>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3jl>H20000
00D0n_3V0P0000050?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V0P00003o0?[`
iYl0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3j
l>H09@3jl>H2000000030?[`iP000000000000X0n_3V0P0000050?[`iP8000001@3jl>H2000000D0
n_3V0P0000040?[`iP80000000<0n_3V0000000000000`3jl>H200000?l0n_3VWP3jl>H10?ooo`00
7`3jl>H6000000@0n_3V0P00000_0?[`iPD00000:03jl>H3000000`0n_3V0`0000040?[`iP<00000
103jl>H3000000@0n_3V0`0000030?[`iP<000001@3jl>H300000?l0n_3VW03jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@0
0000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803j
l>H6000000050?[`iP00000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V
0P000000103jl>H000000000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H2000000D0
n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000?l0
n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000
0P3jl>H010000000n_3V0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`
iP800000103jl>H200000080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3j
l>H00000000000030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP80
0000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080
n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H200000003
0?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V
0P0000000`3jl>H00000000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V
0P0000020?[`iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`
iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP800000
00<0n_3V000000000000103jl>H200000?l0n_3VWP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P00
00000`3jl>H00000000000020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000
003jl>H300000080n_3V0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V
0P0000000`3jl>H00000000000090?[`iP@000000`3jl>H4000000<0n_3V100000030?[`iP@00000
0`3jl>H4000000H0n_3V0P00003o0?[`iYd0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3j
l>H5000000<0n_3V100000030?[`iP80000000<0n_3V000000000000100000000`3jl>H000000000
00020?[`iP@00000103jl>H200000300n_3V0P0000000`3jl>H00000000000090?[`iP8000001@3j
l>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000P0n_3V0P00003o0?[`iYd0n_3V0@3o
ool00280n_3V0P00000;0?[`iP8000008P3jl>H200000300n_3V0P0000000`3jl>H000000000000:
0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000@0n_3V00<00000
0?[`iP3jl>H00P00003o0?[`iYd0n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H40000
0340n_3V0`00000<0?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H30000
0080n_3V1@00003o0?[`iYd0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V
00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP00
0000n_3V0P0000020?[`iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200
n_3V0`0000000`3jl>H0000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`
iP030000003jl>H0000001P0n_3V1@00003K0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`
iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000
000000P0n_3V100000000`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP000000
00000000003jl>H000000?[`iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000@0n_3V
0`0000030?[`iPH000000P3jl>H3000000@0n_3V0`0000030?[`iP<000001@3jl>H3000000@0n_3V
0`00001[0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@000000103jl>H000000000
000000020?[`iP80000000<0n_3V0000000000002@3jl>H5000000T0n_3V0P00003O0?[`iP800000
103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0
n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`
iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP030000003jl>H0n_3V
008000000P3jl>H00`000000n_3V0?[`iP02000000@0n_3V0P0000030?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000006X0n_3V0@3oool00280n_3V0`00000Y0?[`iP80
0000gP3jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H0
00000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP0000000000
00T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H20000
00H0n_3V0P0000050?[`iP8000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V000000000000JP3jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000;0?[`iP80
0000g@3jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0
n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`
iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP0000000000
00T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H20000
00H0n_3V0P0000050?[`iP8000000`3jl>H400000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V000000000000JP3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002X0
n_3V0P00003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H0
00000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0`000000103jl>H000000000003jl>H2
00000080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02
000001P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP000000000000@0n_3V0P0000040?[`iP<00000103jl>H3000000<0n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H4000006/0n_3V0@3oool0
0200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H2
000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@00
00020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`00
00000`3jl>H00000000000020?[`iP@000000P3jl>H3000000030?[`iP000000000000L000006@3j
l>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V000000000000103jl>H2000000H0n_3V0P0000050?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000020?[`iP800000K@3jl>H10?ooo`00C@3jl>H2
000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2
00000280n_3V0P0000020?[`iP800000;P3jl>H2000000030?[`iP000000000000T0n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H4000000<0n_3V00<00000
0?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V008000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000030?[`iP800000K03jl>H10?ooo`00CP3jl>H30000
0=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000006@3jl>H30000
00030?[`iP000000000000800000;P3jl>H3000000/0n_3V0`0000040?[`iP<000001@3jl>H20000
00@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP<00000JP3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V
0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H1
0?ooo`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H000000P3j
l>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`iP000000
00000080000000@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000
003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH00000
0`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000H00000
6P3jl>H5000000<0n_3V0`0000030?[`iPD000000P3jl>H600000;40n_3V0@3oool00240n_3V0P00
00000`3jl>H0000000000005000000050?[`iP00000000000000003jl>H01000000;0?[`iPD00000
2@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V
0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP04
0000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V0000
00000000n_3V0P0000020?[`iP8000002`3jl>H5000000T0n_3V0P0000050?[`iP030000003jl>H0
n_3V008000000P3jl>H2000000L0n_3V0P00002c0?[`iP40oooo000R0?[`iP<00000:03jl>H20000
00030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000000`3jl>H4000001X0n_3V0P0000070?[`iP8000000`3jl>H20000
00H0n_3V0P00002c0?[`iP40oooo000R0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD0
00002@3jl>H2000000030?[`iP00000000000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0
n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P000000103jl>H000000000003jl>H4000000d0n_3V1@00000;0?[`iP8000001P3jl>H20000
00@0n_3V0P0000050?[`iP800000/`3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002L0
n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080
n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2
000001`0n_3V0P0000030?[`iP<000001P3jl>H2000000@0n_3V0P00002c0?[`iP40oooo000P0?[`
iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3j
l>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@0000030?[`iPD000006@3j
l>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP80000000<0n_3V000000000000103j
l>H200000;<0n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V
000000000000403jl>H2000000`0n_3V0P00000h0?[`iP80000000<0n_3V0000000000000P3jl>H0
0`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H00000000000020?[`iP@00000/`3jl>H1
0?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`
iP800000<@3jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H200000;<0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iRH0oooP0P00001/
0?ooh0800000103oon02000000@0oooP0P00001[0?ooh0D00000J@3oon0500000080oooP0P000004
0?ooh0800000J`3oon04000002<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP
000006X0oooP00@000000?ooh03oon000000203oon0010000000oooP0?ooh000001/0?ooh0030000
003oon00oooP06/0oooP00<000000?ooh03oon001`3oon0010000000oooP0?ooh000001Z0?ooh003
0000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0
oooP00@000000?ooh03oon0000002`3oon000`000000oooP0?ooh01Z0?ooh0030000003oon00oooP
06/0oooP00<000000?ooh03oon002P3oon000`000000oooP0?ooh01Y0?ooh0030000003oon00oooP
02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?oo
h03oon0000002@3oon02000006d0oooP00<000000?ooh03oon00J`3oon000`000000oooP0?ooh008
0?ooh0800000K@3oon000`000000oooP0?ooh00R0?ooh1h0n_3V0@3oool001d0n_3V9@3oon001000
0000oooP0?ooh000001Z0?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03oon00K03o
on000`000000oooP0?ooh01[0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00JP3o
on0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3oool001d0n_3V9P3oon02000006`0oooP0P00
000:0?ooh0<00000J`3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000002@0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3oon3o00000>X00000603oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003o
on00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00L@3oon000`00
0000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ00oooP1@0000060?ooh0030000003oon00oooP00P0oooP5000003o0?ooh<X0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon00
0`000000oooP0?ooh0070?ooh2@00000o`3oon2k0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP100000060?ooh08000006P000?lB0000
0?l0oooP[P3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>H:0?ooh0@00000103oon000`000000
oooP0?ooh0060?ooh0030000003oon00oooP00P0oooP6`0000080000oa800000o`3oon2Y0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0oooP
00<000000?ooh03oon002@3oon0A0<f5?a4000002P000?l?00000?l0oooPXP3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02000000P0oooP00<000000?ooh03oon002@3o
on0P0<f5?``000002@000?l<00000?l0oooPW03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh2X0cHDo2`0000080000o`X00000o`3oon2F
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP<P3=QCl;000000D0003o2P00003o0?ooh940oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon0i0<f5?`T000001@000?l900000?l0
oooPS@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh3l0cHDo200000050000o`T00000o`3oon280?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPA@3=QCl7000000D0003o2@00
003o0?ooh8<0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon1:0<f5?`L000001@000?l800000?l0oooPO`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh4l0cHDo1`0000040000
o`P00000o`3oon1k0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooPD`3=QCl7000000D0003o1`00003o0?ooh7L0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1H0<f5?`L00000
10000?l600000?l0oooPM03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh5`0cHDo1`0000040000o`H00000o`3oon1`0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon1P0<f5?`L000000`000?l6
00000?l0oooPJ`3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooPI03=QCl6000000@0003o1@00003o0?ooh6X0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1W0<f5?`L000000`000?l600000?l0
oooPIP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh6/0cHDo1P0000040000o`D00000o`3oon1S0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPKP3=QCl7000000<0003o1@00
003o0?ooh600oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon1b0<f5?`H000000`000?l500000?l0oooPG@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh7D0cHDo1P0000020000
o`H00000o`3oon1J0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooPN03=QCl5000000<0003o1P00003o0?ooh5L0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1k0<f5?`D00000
0`000?l600000?l0oooPE03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh7h0cHDo1@0000020000o`H00000o`3oon1B0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPP@3=QCl4
000000<0003o1P00003o0?ooh4l0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon240<f5?`@000000`000?l600000?l0oooPC03oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh8L0
cHDo100000030000o`D00000o`3oon1:0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPR@3=QCl500000080003o1P00003o0?ooh4L0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`0000090?ooh8`0cHDo1000
00030000o`D00000o`3oon130?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon2?0<f5?`@000000`000?l500000?l0oooP@P3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh980cHDo100000020000
o`D00000o`3oon100?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP00T0oooPU03=QCl4000000<0003o1@00003o0?ooh3d0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2G0<f5?`@00000
0`000?l400000?l0oooP>`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh9T0cHDo1@0000020000o`@00000o`3oon0i0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPV`3=QCl5
00000080003o1000003o0?ooh3L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon2N0<f5?`@000000P000?l500000?l0oooP=03oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh:00
cHDo100000020000o`D00000o`3oon0b0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooPX`3=QCl3000000<0003o1000003o0?ooh300oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on2U0<f5?`@000000P000?l400000?l0oooP;P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh:L0cHDo100000020000o`D00000o`3oon0[
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooPZ@3=QCl400000080003o1@00003o0?ooh2T0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2[0<f5?`@000000`000?l300000?l0
oooP:03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh:h0cHDo100000020000o`@00000o`3oon0U0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon2`0<f5?`@000000P000?l400000?l0oooP8@3o
on03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP/P3=QCl4
00000080003o1000003o0?ooh240oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon2d0<f5?`@000000P000?l400000?l0oooP7`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh;H0
cHDo100000020000o`@00000o`3oon0M0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP00T0oooP^03=QCl400000080003o1000003o0?ooh1/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on2j0<f5?`@000000P000?l400000?l0oooP6@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh;`0cHDo100000020000o`@00000o`3oon0G
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
00T0oooP_P3=QCl400000080003o1000003o0?ooh1D0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon300<f5?`@000000P000?l300000?l0
oooP503oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh0090?ooh<80cHDo100000020000o`<00000o`3oon0B0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPa03=QCl400000080003o0`00
003o0?ooh100oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon360<f5?`@0000000<0003o0000000000000P00003o0?ooh0h0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon380<f5
?`<000000P000?l400000?l0oooP303oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh<T0cHDo100000020000o`@00000o`3oon0:0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon3;0<f5?`@00000
00<0003o0000000000000P00003o0?ooh0L0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh0090?ooh<d0cHDo0`0000020000o`@00000o`3oon070?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPc`3=QCl3
00000080003o1000003o0?ooh0D0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon002@3oon3A0<f5?`<000000P000?l400000?l0oooP0`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=<0
cHDo0`0000000`000?l000000000000200000?l0oooP0P3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=@0cHDo0`0000020000o`@00000
o`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh=H0cHDo0`0000020000o`@00000o@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=P0cHDo0`0000020000o`@00000n`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h=X0cHDo0`0000000`000?l000000000000200000?X0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon3K0<f5?`<000000P000?l400000?P0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon3M0<f5?`<000000P000?l300000?L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon3O0<f5?`<0000000<0003o0000000000000P00
003e0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon00
0`000000oooP0?ooh0090?ooh>00cHDo0`0000020000o`@00000l`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00
oooP00T0oooPhP3=QCl300000080003o0`00003b0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP100000080?ooh>L000000P000?oX
000000P0oooP1000000H0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh0000007
0?ooh0030000003oon00oooP0>h0oooP100000000`000?l000000000000200000><0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh0000007
0?ooh0030000003oon00oooP0?00oooP0`0000020000o`<00000hP0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03b0?oo
h0<0000000<0003o0000000000000P00003P03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00l`3oon0300000080003o0`00003O03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
m@3oon03000000030000o`000000000000800000g@0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?H0oooP0`0000020000o`<00000g00c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?P0oooP0`0000000`000?l000000000000200000=X0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03i0?ooh0<0000000<0003o0000
000000000`00003H03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00n`3oon0200000080003o1000003G03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o@3oon02000000030000
o`000000000000<00000e@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?h0oooP0P0000020000o`@00000e00cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP0@3oon02
000000030000o`000000000000<00000dP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP0P3oon0200000080003o1000003A03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon040?ooh080000000<0003o0000000000000P00003@03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh0D0oooP0P0000020000o`@00000
cP0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on070?ooh080000000<0003o0000000000000P00003=03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon080?ooh08000000P000?l4
00000</0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh0X0oooP0P0000000`000?l000000000000200000<X0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0/0
oooP0P0000020000o`@00000b00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooP303oon03000000030000o`000000000000800000
a`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP3P3oon0200000080003o0`00003603>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0@0?ooh080000000<0003o
0000000000000P00003403>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon0A0?ooh08000000P000?l300000<<0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh180
oooP0`0000000`000?l000000000000200000<40<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1@0oooP0P0000020000o`<00000
`00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP5@3oon03000000040000o`000000000000000;l0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1H0oooP0`00
00020000o`<00000_@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP603oon03000000040000o`000000000000000;`0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon0300000?l0oooP6P3oon02
00000080003o0`00002j03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh1/0oooP0`00000010000?l0000000000000002i03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0L0?oo
h0<0000000@0003o0000000000000000^00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP7@3oon0300000080003o0P00002g03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0O0?ooh0<0000000@0003o0000000000000000]@0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP803oon0300000004
0000o`000000000000000;@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh240oooP0`0000020000o`<00000/P0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
8`3oon03000000040000o`000000000000000;40<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2@0oooP0`00000010000?l00000
00000000002`03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP
00<000000?ooh03oon00o`3oon0U0?ooh0<000000P000?l200000:l0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2L0oooP0`00
000010000?l0000000000000002]03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0X0?ooh0<0000000@0003o0000000000000000
[00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP:P3oon0200000080003o0P00002[03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0[0?ooh0<0000000@0003o
0000000000000000Z@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0<00000o`3oon0/0?ooh0<0000000@0003o0000000000000000Z00cXLX90?ooh0<00000603o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0]0?ooh0<000000P000?l2
00000:L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh2h0oooP1000000010000?l0000000000000002U03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0`0?oo
h0<0000000@0003o0000000000000000Y00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<@3oon03000000040000o`0000000000
00000:<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh380oooP0`0000020000o`800000XP0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP=03oon0300000003
0000o`00000000000:40<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh3D0oooP0`00000010000?l0000000000000002O03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon0f0?ooh0<000000P000?l2000009h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP100000000`000?l000000000
002M03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon0i0?ooh0<0000000<0003o000000000000W00cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP>P3oon030000
00040000o`0000000000000009X0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3/0oooP0`0000020000o`800000V@0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP?03oon04000000030000o`000000000009P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3h0oooP0`0000000`000?l00000
0000002G03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
003o0?ooh3l0oooP0`0000000`000?l000000000002F03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh400oooP0`0000000`000?l000000000002E
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon110?ooh0<0000000@0003o0000000000000000T`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP@P3oon030000
0080003o0P00002B03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon130?ooh0@0000000<0003o000000000000T@0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
A@3oon03000000030000o`00000000000900<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4H0oooP0`0000000`000?l000000000
002?03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon170?ooh0<0000000@0003o0000000000000000S@0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPB03oon03
000000040000o`0000000000000008`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4X0oooP0P00000010000?l0000000000000
002;03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon1;0?ooh080000000@0003o0000000000000000RP0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPC03oon02
000000040000o`0000000000000008T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00o`3oon1=0?ooh08000000P000?l2
000008P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`00
0000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPCP3oon03000000040000o`0000000000
000008H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`00
0000oooP0?ooh0060?ooh0@00000o`3oon1>0?ooh0<0000000@0003o0000000000000000Q@0cXLX8
0?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`00
0000oooP0?ooh03o0?ooh540oooP0P00000010000?l0000000000000002403>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`00
0000oooP0?ooh03o0?ooh580oooP0P00000010000?l0000000000000002303>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP
0?l0oooPD`3oon02000000040000o`000000000000000880<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5@0oooP0P0000001000
0?l0000000000000002103>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon1E0?ooh080000000@0003o0000000000000000P00cXLX;
0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP
0?l0oooPEP3oon02000000040000o`0000000000000007l0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5L0oooP0P0000020000
o`<00000O@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPF03oon03000000040000o`0000000000000007`0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5X0
oooP0P00000010000?l0000000000000001k03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1K0?ooh080000000@0003o00000000
00000000NP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPG03oon02000000040000o`0000000000000007T0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh5d0
oooP0P00000010000?l0000000000000001h03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1N0?ooh080000000@0003o00000000
00000000M`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon1O0?ooh080000000@0003o0000000000000000MP0cXLX90?ooh0<00000603oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?ooh080000000@0003o00000000
00000000M@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPH@3oon0200000080003o0P00001d03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1R0?ooh0<00000
00<0003o000000000000L`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPH`3oon03000000040000o`000000000000000740<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh6@0oooP0`00000010000?l0000000000000001`03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1V0?ooh080000000@0
003o0000000000000000K`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPI`3oon02000000040000o`0000000000000006h0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh6P0oooP0P00000010000?l0000000000000001]03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1Y0?ooh080000000@0
003o0000000000000000K00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPJP3oon02000000040000o`0000000000000006/0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh6/0oooP0P00000010000?l0000000000000001Z03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1/0?ooh080000000@0
003o0000000000000000J@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPK@3oon02000000040000o`0000000000000006P0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh6h0oooP0P00000010000?l0000000000000001W03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh6l0oooP0P0000020000o`800000IP0c
XLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1`
0?ooh0<0000000<0003o000000000000I@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL@3oon03000000030000o`0000000000
06@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh780oooP0`0000000`000?l000000000001S03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1c0?ooh0<00000
00<0003o000000000000HP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPM03oon03000000030000o`00000000000640<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7D0oooP0`0000000`000?l000000000001P03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1f0?ooh0<0000000<0003o0000
00000000G`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPM`3oon03000000030000o`000000000005h0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7P0oooP
0`0000000`000?l000000000001M03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1j0?ooh080000000<0003o000000000000G00c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPN`3oon02000000030000o`000000000005/0<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh7/0oooP0`0000000`00
0?l000000000001J03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon1l0?ooh0<0000000<0003o000000000000F@0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon1n0?ooh0800000
00<0003o000000000000F00cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1o0?ooh080000000<0003o000000000000E`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPO`3oon03
000000030000o`000000000005H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh800oooP0`0000000`000?l000000000001E03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon220?ooh080000000<0003o000000000000E00cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPPP3oon03000000030000
o`000000000005<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8<0oooP0`0000000`000?l000000000001B03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon25
0?ooh080000000<0003o000000000000D@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQP3oon02000000030000o`0000000000
0500<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh8L0oooP0P0000000`000?l000000000001?03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon270?ooh0<00000
00<0003o000000000000CP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPR03oon03000000030000o`000000000004d0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh8T0oooP0`0000000`000?l000000000001<03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2:0?ooh0<0000000<0003o0000
00000000B`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon2;0?ooh0<0000000<0003o000000000000BP0cXLX90?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2<0?ooh0<0000000<0003o000000000000
B@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPS@3oon03000000030000o`000000000004P0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8h0oooP0`000000
0`000?l000000000001703>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2?0?ooh0<0000000<0003o000000000000AP0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPT03oon02000000040000o`0000000000000004D0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh940oooP0P00000010000?l0
000000000000001403>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2B0?ooh080000000@0003o0000000000000000@`0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPT`3oon02000000040000o`000000000000000480<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9@0oooP0P00000010000?l0
000000000000001103>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2E0?ooh080000000@0003o0000000000000000@00cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPUP3oon02000000040000o`0000000000000003l0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9L0oooP0P0000000`000?l0
00000000000o03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP
100000070?ooh0030000003oon00oooP0?l0oooPV03oon02000000030000o`000000000003h0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?oo
h0080?ooh0030000003oon00oooP0?l0oooPV@3oon02000000030000o`000000000003d0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon000`000000oooP0?ooh007
0?ooh0@00000o`3oon2I0?ooh003000000000?l0000000800000?00cXLX80?ooh0@00000603oon0N
0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh03o0?oo
h9/0oooP00<000000000o`0000000P00000k03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?oo
h9/0oooP0P00000010000?l0000000000000000j03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPW03oon020000
00040000o`0000000000000003T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9d0oooP0P00000010000?l0000000000000000h
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2N0?ooh080000000@0003o0000000000000000=`0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPW`3oon020000
00040000o`0000000000000003H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:00oooP0P00000010000?l0000000000000000e
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2Q0?ooh080000000@0003o0000000000000000=00cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPXP3oon020000
00040000o`0000000000000003<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:<0oooP0P00000010000?l0000000000000000b
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon2T0?ooh080000000@0003o0000000000000000<@0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPY@3oon020000
00030000o`00000000000340<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:H0oooP0P0000000`000?l000000000000`03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh:L0oooP
0P0000000`000?l000000000000_03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh:P0oooP0P0000000`000?l000000000000^03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2X
0?ooh080000000@0003o0000000000000000;@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ@3oon02000000040000o`000000
0000000002`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:X0oooP0P00000010000?l0000000000000000[03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2[
0?ooh080000000@0003o0000000000000000:P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[03oon02000000040000o`000000
0000000002T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh:d0oooP0P0000000`000?l000000000000Y03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2^0?oo
h080000000<0003o000000000000:00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[`3oon02000000030000o`000000000002L0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh;00oooP0P0000000`000?l000000000000V03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2a0?ooh080000000<0
003o0000000000009@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooP/@3oon03000000030000o`000000000002@0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h;80oooP0`0000000`000?l000000000000S03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh;<0oooP0`0000000`000?l000000000000R03>QbPT0
oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;@0oooP
0`0000000`000?l000000000000Q03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2e0?ooh080000000<0003o0000000000008@0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP]P3oon02000000030000o`00000000000200<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;L0oooP0P0000000`00
0?l000000000000O03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon2g0?ooh0<0000000<0003o0000000000007P0cXLX;0?ooh003
0000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP
^03oon03000000030000o`000000000001d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;T0oooP0`0000000`000?l000000000
000L03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2j0?ooh080000000@0003o00000000000000006`0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP^`3oon02
000000030000o`000000000001/0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;`0oooP0P0000000`000?l000000000000J03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon2m0?ooh080000000<0003o0000000000006@0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP_@3oon03000000030000
o`000000000001P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh;h0oooP0`0000000`000?l000000000000G03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2o
0?ooh080000000@0003o00000000000000005P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon300?ooh080000000<0003o0000000000005P0cXLX9
0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon310?oo
h080000000<0003o0000000000005@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`P3oon02000000030000o`000000000001@0
<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP
0?ooh03o0?ooh<<0oooP0P0000000`000?l000000000000C03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon340?ooh080000000<0
003o0000000000004P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPa03oon02000000040000o`000000000000000140<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh<D0oooP0P00000010000?l0000000000000000@03>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon360?ooh080000000@0003o
00000000000000003`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPa`3oon02000000030000o`000000000000l0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h<P0oooP0P0000000`000?l000000000000>03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon390?ooh080000000<0003o00000000
00003@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooPb@3oon02000000040000o`0000000000000000`0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<X0oooP
0P0000000`000?l000000000000<03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3;0?ooh080000000<0003o0000000000002`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon3<
0?ooh080000000<0003o0000000000002P0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon3=0?ooh080000000<0003o0000000000002@0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPcP3oon02000000030000o`000000000000P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<l0oooP0P0000000`000?l00000
0000000703>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon3?0?ooh080000000@0003o00000000000000001P0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd03o
on02000000030000o`000000000000H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=40oooP0P0000000`000?l0000000000005
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon3B0?ooh080000000<0003o000000000000100cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPd`3oon0200000003
0000o`000000000000<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh=<0oooP0`0000000`000?l000000000000203>QbP/0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3o
on3D0?ooh0<0000000@0003o000000000000<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=D0oooP0P00000010000?l000000000
000cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203o
on000`000000oooP0?ooh03o0?ooh=H0oooP0P0000000`000?l000000000000;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP000000L0oooP00<0
00000?ooh03oon00o`3oon3G0?ooh080000000<0003o0000000000002P3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon3F
0?ooh0<0000000<0003o0000003oon001P3oon04000001P0oooP7P3jl>H10?ooo`007@3jl>HC0?oo
h0030000003oon00oooP00D0oooP00<000000?ooh03oon00o`3oon3H0?ooh0@000002P3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000oooP0?ooh00000070?oo
h0030000003oon00oooP0?l0oooPf@3oon02000000/0oooP00<000000?ooh03oon005P3oon0N0?[`
iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP
00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3o
on000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740oooP00<000000?ooh03oon00L@3o
on000`000000oooP0?ooh01a0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D
0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP
01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l00000jP00000H0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00g03jl>H400000080n_3V200000020?[`iP@0
000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V00000000000010000000
103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V00<000002@3j
l>H500000080n_3V100000020?[`iPD000004P3jl>H6000000H0n_3V00<000000?[`iP3jl>H0103j
l>H3000000040?[`iP000000000000000>@0n_3V0@3oool00=d0n_3V0P0000020?[`iP8000000`3j
l>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP0400000080
n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000T0
n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P000000
0`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F
0?[`iP800000203jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000i@3jl>H1
0?ooo`00g@3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H20000
00030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2
000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2
000000`0n_3V1@0000050?[`iP8000001P3jl>H5000000H0n_3V0`00003V0?[`iP40oooo003M0?[`
iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0
n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H00000
0?[`iP02000000/0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`iP800000
203jl>H00`000000n_3V0?[`iP060?[`iP<00000iP3jl>H10?ooo`00g@3jl>H200000080n_3V0P00
00030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H000000?[`iP80
0000103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00002P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V
008000002`3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V
0180n_3V0P0000080?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003U0?[`
iP40oooo003M0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H400000003
0?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0
n_3V0`0000000`3jl>H0000000000007000000/0n_3V1@0000020?[`iP@000000P3jl>H300000003
0?[`iP000000000001<0n_3V0P00000?0?[`iP<0000000D0n_3V00000000000000000?[`iP040000
0=l0n_3V0@3oool00=d0n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3j
l>H0603jl>H200000240n_3V1000000H0?[`iP030000003jl>H0n_3V0=l0n_3V0@3oool00=`0n_3V
1P0000040?[`iP800000;`3jl>H5000001/0n_3V0`00000Q0?[`iP8000006@3jl>H00`000000n_3V
0?[`iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<000000?[`iP3jl>H0g@3jl>H10?ooo`00o`3jl>Ie
0?[`iP040000003jl>H0n_3V00000=l0n_3V0@3oool00?l0n_3VMP3jl>H200000>00n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.47619 0.161866 0.147151 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 .894 .882 r
.02381 .16187 m
.02381 .01472 L
.02419 .01472 L
.02419 .16187 L
F
.804 .522 .247 r
.5 Mabswid
.02381 .16187 m
.02381 .01472 L
.02419 .01472 L
.02419 .16187 L
s
1 .894 .882 r
.02419 .16187 m
.02419 .01472 L
.02465 .01472 L
.02465 .16187 L
F
.804 .522 .247 r
.02419 .16187 m
.02419 .01472 L
.02465 .01472 L
.02465 .16187 L
s
1 .894 .882 r
.02465 .16187 m
.02465 .01472 L
.02501 .01472 L
.02501 .16187 L
F
.804 .522 .247 r
.02465 .16187 m
.02465 .01472 L
.02501 .01472 L
.02501 .16187 L
s
1 .894 .882 r
.02501 .16187 m
.02501 .01472 L
.0254 .01472 L
.0254 .16187 L
F
.804 .522 .247 r
.02501 .16187 m
.02501 .01472 L
.0254 .01472 L
.0254 .16187 L
s
1 .894 .882 r
.0254 .16187 m
.0254 .01472 L
.02572 .01472 L
.02572 .16187 L
F
.804 .522 .247 r
.0254 .16187 m
.0254 .01472 L
.02572 .01472 L
.02572 .16187 L
s
1 .894 .882 r
.02572 .16187 m
.02572 .01472 L
.02615 .01472 L
.02615 .16187 L
F
.804 .522 .247 r
.02572 .16187 m
.02572 .01472 L
.02615 .01472 L
.02615 .16187 L
s
1 .894 .882 r
.02615 .16187 m
.02615 .01472 L
.02635 .01472 L
.02635 .16187 L
F
.804 .522 .247 r
.02615 .16187 m
.02615 .01472 L
.02635 .01472 L
.02635 .16187 L
s
1 .894 .882 r
.02635 .16187 m
.02635 .01472 L
.02676 .01472 L
.02676 .16187 L
F
.804 .522 .247 r
.02635 .16187 m
.02635 .01472 L
.02676 .01472 L
.02676 .16187 L
s
1 .894 .882 r
.02676 .16187 m
.02676 .01472 L
.02713 .01472 L
.02713 .16187 L
F
.804 .522 .247 r
.02676 .16187 m
.02676 .01472 L
.02713 .01472 L
.02713 .16187 L
s
1 .894 .882 r
.02713 .16187 m
.02713 .01472 L
.02743 .01472 L
.02743 .16187 L
F
.804 .522 .247 r
.02713 .16187 m
.02713 .01472 L
.02743 .01472 L
.02743 .16187 L
s
1 .894 .882 r
.02743 .16187 m
.02743 .01472 L
.02781 .01472 L
.02781 .16187 L
F
.804 .522 .247 r
.02743 .16187 m
.02743 .01472 L
.02781 .01472 L
.02781 .16187 L
s
1 .894 .882 r
.02781 .16187 m
.02781 .01473 L
.02816 .01473 L
.02816 .16187 L
F
.804 .522 .247 r
.02781 .16187 m
.02781 .01473 L
.02816 .01473 L
.02816 .16187 L
s
1 .894 .882 r
.02816 .16187 m
.02816 .01473 L
.02847 .01473 L
.02847 .16187 L
F
.804 .522 .247 r
.02816 .16187 m
.02816 .01473 L
.02847 .01473 L
.02847 .16187 L
s
1 .894 .882 r
.02847 .16187 m
.02847 .01473 L
.02869 .01473 L
.02869 .16187 L
F
.804 .522 .247 r
.02847 .16187 m
.02847 .01473 L
.02869 .01473 L
.02869 .16187 L
s
1 .894 .882 r
.02869 .16187 m
.02869 .01473 L
.02913 .01473 L
.02913 .16187 L
F
.804 .522 .247 r
.02869 .16187 m
.02869 .01473 L
.02913 .01473 L
.02913 .16187 L
s
1 .894 .882 r
.02913 .16187 m
.02913 .01473 L
.02949 .01473 L
.02949 .16187 L
F
.804 .522 .247 r
.02913 .16187 m
.02913 .01473 L
.02949 .01473 L
.02949 .16187 L
s
1 .894 .882 r
.02949 .16187 m
.02949 .01474 L
.02965 .01474 L
.02965 .16187 L
F
.804 .522 .247 r
.02949 .16187 m
.02949 .01474 L
.02965 .01474 L
.02965 .16187 L
s
1 .894 .882 r
.02965 .16187 m
.02965 .01474 L
.03003 .01474 L
.03003 .16187 L
F
.804 .522 .247 r
.02965 .16187 m
.02965 .01474 L
.03003 .01474 L
.03003 .16187 L
s
1 .894 .882 r
.03003 .16187 m
.03003 .01474 L
.03047 .01474 L
.03047 .16187 L
F
.804 .522 .247 r
.03003 .16187 m
.03003 .01474 L
.03047 .01474 L
.03047 .16187 L
s
1 .894 .882 r
.03047 .16187 m
.03047 .01475 L
.03082 .01475 L
.03082 .16187 L
F
.804 .522 .247 r
.03047 .16187 m
.03047 .01475 L
.03082 .01475 L
.03082 .16187 L
s
1 .894 .882 r
.03082 .16187 m
.03082 .01475 L
.031 .01475 L
.031 .16187 L
F
.804 .522 .247 r
.03082 .16187 m
.03082 .01475 L
.031 .01475 L
.031 .16187 L
s
1 .894 .882 r
.031 .16187 m
.031 .01475 L
.03144 .01475 L
.03144 .16187 L
F
.804 .522 .247 r
.031 .16187 m
.031 .01475 L
.03144 .01475 L
.03144 .16187 L
s
1 .894 .882 r
.03144 .16187 m
.03144 .01476 L
.03189 .01476 L
.03189 .16187 L
F
.804 .522 .247 r
.03144 .16187 m
.03144 .01476 L
.03189 .01476 L
.03189 .16187 L
s
1 .894 .882 r
.03189 .16187 m
.03189 .01476 L
.03231 .01476 L
.03231 .16187 L
F
.804 .522 .247 r
.03189 .16187 m
.03189 .01476 L
.03231 .01476 L
.03231 .16187 L
s
1 .894 .882 r
.03231 .16187 m
.03231 .01476 L
.03261 .01476 L
.03261 .16187 L
F
.804 .522 .247 r
.03231 .16187 m
.03231 .01476 L
.03261 .01476 L
.03261 .16187 L
s
1 .894 .882 r
.03261 .16187 m
.03261 .01477 L
.03307 .01477 L
.03307 .16187 L
F
.804 .522 .247 r
.03261 .16187 m
.03261 .01477 L
.03307 .01477 L
.03307 .16187 L
s
1 .894 .882 r
.03307 .16187 m
.03307 .01477 L
.03331 .01477 L
.03331 .16187 L
F
.804 .522 .247 r
.03307 .16187 m
.03307 .01477 L
.03331 .01477 L
.03331 .16187 L
s
1 .894 .882 r
.03331 .16187 m
.03331 .01478 L
.03348 .01478 L
.03348 .16187 L
F
.804 .522 .247 r
.03331 .16187 m
.03331 .01478 L
.03348 .01478 L
.03348 .16187 L
s
1 .894 .882 r
.03348 .16187 m
.03348 .01478 L
.03396 .01478 L
.03396 .16187 L
F
.804 .522 .247 r
.03348 .16187 m
.03348 .01478 L
.03396 .01478 L
.03396 .16187 L
s
1 .894 .882 r
.03396 .16187 m
.03396 .01478 L
.03414 .01478 L
.03414 .16187 L
F
.804 .522 .247 r
.03396 .16187 m
.03396 .01478 L
.03414 .01478 L
.03414 .16187 L
s
1 .894 .882 r
.03414 .16187 m
.03414 .01479 L
.03432 .01479 L
.03432 .16187 L
F
.804 .522 .247 r
.03414 .16187 m
.03414 .01479 L
.03432 .01479 L
.03432 .16187 L
s
1 .894 .882 r
.03432 .16187 m
.03432 .01479 L
.03458 .01479 L
.03458 .16187 L
F
.804 .522 .247 r
.03432 .16187 m
.03432 .01479 L
.03458 .01479 L
.03458 .16187 L
s
1 .894 .882 r
.03458 .16187 m
.03458 .01479 L
.03484 .01479 L
.03484 .16187 L
F
.804 .522 .247 r
.03458 .16187 m
.03458 .01479 L
.03484 .01479 L
.03484 .16187 L
s
1 .894 .882 r
.03484 .16187 m
.03484 .0148 L
.03521 .0148 L
.03521 .16187 L
F
.804 .522 .247 r
.03484 .16187 m
.03484 .0148 L
.03521 .0148 L
.03521 .16187 L
s
1 .894 .882 r
.03521 .16187 m
.03521 .0148 L
.0355 .0148 L
.0355 .16187 L
F
.804 .522 .247 r
.03521 .16187 m
.03521 .0148 L
.0355 .0148 L
.0355 .16187 L
s
1 .894 .882 r
.0355 .16187 m
.0355 .0148 L
.0359 .0148 L
.0359 .16187 L
F
.804 .522 .247 r
.0355 .16187 m
.0355 .0148 L
.0359 .0148 L
.0359 .16187 L
s
1 .894 .882 r
.0359 .16187 m
.0359 .01481 L
.03634 .01481 L
.03634 .16187 L
F
.804 .522 .247 r
.0359 .16187 m
.0359 .01481 L
.03634 .01481 L
.03634 .16187 L
s
1 .894 .882 r
.03634 .16187 m
.03634 .01482 L
.03665 .01482 L
.03665 .16187 L
F
.804 .522 .247 r
.03634 .16187 m
.03634 .01482 L
.03665 .01482 L
.03665 .16187 L
s
1 .894 .882 r
.03665 .16187 m
.03665 .01482 L
.03699 .01482 L
.03699 .16187 L
F
.804 .522 .247 r
.03665 .16187 m
.03665 .01482 L
.03699 .01482 L
.03699 .16187 L
s
1 .894 .882 r
.03699 .16187 m
.03699 .01483 L
.03717 .01483 L
.03717 .16187 L
F
.804 .522 .247 r
.03699 .16187 m
.03699 .01483 L
.03717 .01483 L
.03717 .16187 L
s
1 .894 .882 r
.03717 .16187 m
.03717 .01484 L
.0376 .01484 L
.0376 .16187 L
F
.804 .522 .247 r
.03717 .16187 m
.03717 .01484 L
.0376 .01484 L
.0376 .16187 L
s
1 .894 .882 r
.0376 .16187 m
.0376 .01484 L
.03802 .01484 L
.03802 .16187 L
F
.804 .522 .247 r
.0376 .16187 m
.0376 .01484 L
.03802 .01484 L
.03802 .16187 L
s
1 .894 .882 r
.03802 .16187 m
.03802 .01485 L
.03841 .01485 L
.03841 .16187 L
F
.804 .522 .247 r
.03802 .16187 m
.03802 .01485 L
.03841 .01485 L
.03841 .16187 L
s
1 .894 .882 r
.03841 .16187 m
.03841 .01485 L
.03873 .01485 L
.03873 .16187 L
F
.804 .522 .247 r
.03841 .16187 m
.03841 .01485 L
.03873 .01485 L
.03873 .16187 L
s
1 .894 .882 r
.03873 .16187 m
.03873 .01486 L
.03913 .01486 L
.03913 .16187 L
F
.804 .522 .247 r
.03873 .16187 m
.03873 .01486 L
.03913 .01486 L
.03913 .16187 L
s
1 .894 .882 r
.03913 .16187 m
.03913 .01487 L
.0396 .01487 L
.0396 .16187 L
F
.804 .522 .247 r
.03913 .16187 m
.03913 .01487 L
.0396 .01487 L
.0396 .16187 L
s
1 .894 .882 r
.0396 .16187 m
.0396 .01488 L
.04004 .01488 L
.04004 .16187 L
F
.804 .522 .247 r
.0396 .16187 m
.0396 .01488 L
.04004 .01488 L
.04004 .16187 L
s
1 .894 .882 r
.04004 .16187 m
.04004 .01489 L
.04043 .01489 L
.04043 .16187 L
F
.804 .522 .247 r
.04004 .16187 m
.04004 .01489 L
.04043 .01489 L
.04043 .16187 L
s
1 .894 .882 r
.04043 .16187 m
.04043 .0149 L
.04068 .0149 L
.04068 .16187 L
F
.804 .522 .247 r
.04043 .16187 m
.04043 .0149 L
.04068 .0149 L
.04068 .16187 L
s
1 .894 .882 r
.04068 .16187 m
.04068 .0149 L
.04084 .0149 L
.04084 .16187 L
F
.804 .522 .247 r
.04068 .16187 m
.04068 .0149 L
.04084 .0149 L
.04084 .16187 L
s
1 .894 .882 r
.04084 .16187 m
.04084 .0149 L
.04119 .0149 L
.04119 .16187 L
F
.804 .522 .247 r
.04084 .16187 m
.04084 .0149 L
.04119 .0149 L
.04119 .16187 L
s
1 .894 .882 r
.04119 .16187 m
.04119 .01492 L
.04155 .01492 L
.04155 .16187 L
F
.804 .522 .247 r
.04119 .16187 m
.04119 .01492 L
.04155 .01492 L
.04155 .16187 L
s
1 .894 .882 r
.04155 .16187 m
.04155 .01492 L
.04182 .01492 L
.04182 .16187 L
F
.804 .522 .247 r
.04155 .16187 m
.04155 .01492 L
.04182 .01492 L
.04182 .16187 L
s
1 .894 .882 r
.04182 .16187 m
.04182 .01493 L
.04228 .01493 L
.04228 .16187 L
F
.804 .522 .247 r
.04182 .16187 m
.04182 .01493 L
.04228 .01493 L
.04228 .16187 L
s
1 .894 .882 r
.04228 .16187 m
.04228 .01494 L
.0426 .01494 L
.0426 .16187 L
F
.804 .522 .247 r
.04228 .16187 m
.04228 .01494 L
.0426 .01494 L
.0426 .16187 L
s
1 .894 .882 r
.0426 .16187 m
.0426 .01495 L
.04285 .01495 L
.04285 .16187 L
F
.804 .522 .247 r
.0426 .16187 m
.0426 .01495 L
.04285 .01495 L
.04285 .16187 L
s
1 .894 .882 r
.04285 .16187 m
.04285 .01495 L
.04301 .01495 L
.04301 .16187 L
F
.804 .522 .247 r
.04285 .16187 m
.04285 .01495 L
.04301 .01495 L
.04301 .16187 L
s
1 .894 .882 r
.04301 .16187 m
.04301 .01496 L
.04325 .01496 L
.04325 .16187 L
F
.804 .522 .247 r
.04301 .16187 m
.04301 .01496 L
.04325 .01496 L
.04325 .16187 L
s
1 .894 .882 r
.04325 .16187 m
.04325 .01496 L
.04342 .01496 L
.04342 .16187 L
F
.804 .522 .247 r
.04325 .16187 m
.04325 .01496 L
.04342 .01496 L
.04342 .16187 L
s
1 .894 .882 r
.04342 .16187 m
.04342 .01497 L
.04377 .01497 L
.04377 .16187 L
F
.804 .522 .247 r
.04342 .16187 m
.04342 .01497 L
.04377 .01497 L
.04377 .16187 L
s
1 .894 .882 r
.04377 .16187 m
.04377 .01498 L
.04398 .01498 L
.04398 .16187 L
F
.804 .522 .247 r
.04377 .16187 m
.04377 .01498 L
.04398 .01498 L
.04398 .16187 L
s
1 .894 .882 r
.04398 .16187 m
.04398 .01499 L
.0444 .01499 L
.0444 .16187 L
F
.804 .522 .247 r
.04398 .16187 m
.04398 .01499 L
.0444 .01499 L
.0444 .16187 L
s
1 .894 .882 r
.0444 .16187 m
.0444 .01499 L
.04472 .01499 L
.04472 .16187 L
F
.804 .522 .247 r
.0444 .16187 m
.0444 .01499 L
.04472 .01499 L
.04472 .16187 L
s
1 .894 .882 r
.04472 .16187 m
.04472 .015 L
.04505 .015 L
.04505 .16187 L
F
.804 .522 .247 r
.04472 .16187 m
.04472 .015 L
.04505 .015 L
.04505 .16187 L
s
1 .894 .882 r
.04505 .16187 m
.04505 .01501 L
.04531 .01501 L
.04531 .16187 L
F
.804 .522 .247 r
.04505 .16187 m
.04505 .01501 L
.04531 .01501 L
.04531 .16187 L
s
1 .894 .882 r
.04531 .16187 m
.04531 .01502 L
.04547 .01502 L
.04547 .16187 L
F
.804 .522 .247 r
.04531 .16187 m
.04531 .01502 L
.04547 .01502 L
.04547 .16187 L
s
1 .894 .882 r
.04547 .16187 m
.04547 .01502 L
.04588 .01502 L
.04588 .16187 L
F
.804 .522 .247 r
.04547 .16187 m
.04547 .01502 L
.04588 .01502 L
.04588 .16187 L
s
1 .894 .882 r
.04588 .16187 m
.04588 .01503 L
.04603 .01503 L
.04603 .16187 L
F
.804 .522 .247 r
.04588 .16187 m
.04588 .01503 L
.04603 .01503 L
.04603 .16187 L
s
1 .894 .882 r
.04603 .16187 m
.04603 .01504 L
.04639 .01504 L
.04639 .16187 L
F
.804 .522 .247 r
.04603 .16187 m
.04603 .01504 L
.04639 .01504 L
.04639 .16187 L
s
1 .894 .882 r
.04639 .16187 m
.04639 .01505 L
.04657 .01505 L
.04657 .16187 L
F
.804 .522 .247 r
.04639 .16187 m
.04639 .01505 L
.04657 .01505 L
.04657 .16187 L
s
1 .894 .882 r
.04657 .16187 m
.04657 .01505 L
.04704 .01505 L
.04704 .16187 L
F
.804 .522 .247 r
.04657 .16187 m
.04657 .01505 L
.04704 .01505 L
.04704 .16187 L
s
1 .894 .882 r
.04704 .16187 m
.04704 .01507 L
.04729 .01507 L
.04729 .16187 L
F
.804 .522 .247 r
.04704 .16187 m
.04704 .01507 L
.04729 .01507 L
.04729 .16187 L
s
1 .894 .882 r
.04729 .16187 m
.04729 .01508 L
.04754 .01508 L
.04754 .16187 L
F
.804 .522 .247 r
.04729 .16187 m
.04729 .01508 L
.04754 .01508 L
.04754 .16187 L
s
1 .894 .882 r
.04754 .16187 m
.04754 .01509 L
.04772 .01509 L
.04772 .16187 L
F
.804 .522 .247 r
.04754 .16187 m
.04754 .01509 L
.04772 .01509 L
.04772 .16187 L
s
1 .894 .882 r
.04772 .16187 m
.04772 .01509 L
.04798 .01509 L
.04798 .16187 L
F
.804 .522 .247 r
.04772 .16187 m
.04772 .01509 L
.04798 .01509 L
.04798 .16187 L
s
1 .894 .882 r
.04798 .16187 m
.04798 .0151 L
.04836 .0151 L
.04836 .16187 L
F
.804 .522 .247 r
.04798 .16187 m
.04798 .0151 L
.04836 .0151 L
.04836 .16187 L
s
1 .894 .882 r
.04836 .16187 m
.04836 .01511 L
.04884 .01511 L
.04884 .16187 L
F
.804 .522 .247 r
.04836 .16187 m
.04836 .01511 L
.04884 .01511 L
.04884 .16187 L
s
1 .894 .882 r
.04884 .16187 m
.04884 .01513 L
.04904 .01513 L
.04904 .16187 L
F
.804 .522 .247 r
.04884 .16187 m
.04884 .01513 L
.04904 .01513 L
.04904 .16187 L
s
1 .894 .882 r
.04904 .16187 m
.04904 .01513 L
.04949 .01513 L
.04949 .16187 L
F
.804 .522 .247 r
.04904 .16187 m
.04904 .01513 L
.04949 .01513 L
.04949 .16187 L
s
1 .894 .882 r
.04949 .16187 m
.04949 .01514 L
.04976 .01514 L
.04976 .16187 L
F
.804 .522 .247 r
.04949 .16187 m
.04949 .01514 L
.04976 .01514 L
.04976 .16187 L
s
1 .894 .882 r
.04976 .16187 m
.04976 .01516 L
.05023 .01516 L
.05023 .16187 L
F
.804 .522 .247 r
.04976 .16187 m
.04976 .01516 L
.05023 .01516 L
.05023 .16187 L
s
1 .894 .882 r
.05023 .16187 m
.05023 .01518 L
.05068 .01518 L
.05068 .16187 L
F
.804 .522 .247 r
.05023 .16187 m
.05023 .01518 L
.05068 .01518 L
.05068 .16187 L
s
1 .894 .882 r
.05068 .16187 m
.05068 .0152 L
.0511 .0152 L
.0511 .16187 L
F
.804 .522 .247 r
.05068 .16187 m
.05068 .0152 L
.0511 .0152 L
.0511 .16187 L
s
1 .894 .882 r
.0511 .16187 m
.0511 .01521 L
.05151 .01521 L
.05151 .16187 L
F
.804 .522 .247 r
.0511 .16187 m
.0511 .01521 L
.05151 .01521 L
.05151 .16187 L
s
1 .894 .882 r
.05151 .16187 m
.05151 .01522 L
.05193 .01522 L
.05193 .16187 L
F
.804 .522 .247 r
.05151 .16187 m
.05151 .01522 L
.05193 .01522 L
.05193 .16187 L
s
1 .894 .882 r
.05193 .16187 m
.05193 .01523 L
.0521 .01523 L
.0521 .16187 L
F
.804 .522 .247 r
.05193 .16187 m
.05193 .01523 L
.0521 .01523 L
.0521 .16187 L
s
1 .894 .882 r
.0521 .16187 m
.0521 .01524 L
.05235 .01524 L
.05235 .16187 L
F
.804 .522 .247 r
.0521 .16187 m
.0521 .01524 L
.05235 .01524 L
.05235 .16187 L
s
1 .894 .882 r
.05235 .16187 m
.05235 .01525 L
.05258 .01525 L
.05258 .16187 L
F
.804 .522 .247 r
.05235 .16187 m
.05235 .01525 L
.05258 .01525 L
.05258 .16187 L
s
1 .894 .882 r
.05258 .16187 m
.05258 .01525 L
.05288 .01525 L
.05288 .16187 L
F
.804 .522 .247 r
.05258 .16187 m
.05258 .01525 L
.05288 .01525 L
.05288 .16187 L
s
1 .894 .882 r
.05288 .16187 m
.05288 .01527 L
.05304 .01527 L
.05304 .16187 L
F
.804 .522 .247 r
.05288 .16187 m
.05288 .01527 L
.05304 .01527 L
.05304 .16187 L
s
1 .894 .882 r
.05304 .16187 m
.05304 .01527 L
.05338 .01527 L
.05338 .16187 L
F
.804 .522 .247 r
.05304 .16187 m
.05304 .01527 L
.05338 .01527 L
.05338 .16187 L
s
1 .894 .882 r
.05338 .16187 m
.05338 .01529 L
.0536 .01529 L
.0536 .16187 L
F
.804 .522 .247 r
.05338 .16187 m
.05338 .01529 L
.0536 .01529 L
.0536 .16187 L
s
1 .894 .882 r
.0536 .16187 m
.0536 .01529 L
.05404 .01529 L
.05404 .16187 L
F
.804 .522 .247 r
.0536 .16187 m
.0536 .01529 L
.05404 .01529 L
.05404 .16187 L
s
1 .894 .882 r
.05404 .16187 m
.05404 .01533 L
.05451 .01533 L
.05451 .16187 L
F
.804 .522 .247 r
.05404 .16187 m
.05404 .01533 L
.05451 .01533 L
.05451 .16187 L
s
1 .894 .882 r
.05451 .16187 m
.05451 .01533 L
.05487 .01533 L
.05487 .16187 L
F
.804 .522 .247 r
.05451 .16187 m
.05451 .01533 L
.05487 .01533 L
.05487 .16187 L
s
1 .894 .882 r
.05487 .16187 m
.05487 .01535 L
.05534 .01535 L
.05534 .16187 L
F
.804 .522 .247 r
.05487 .16187 m
.05487 .01535 L
.05534 .01535 L
.05534 .16187 L
s
1 .894 .882 r
.05534 .16187 m
.05534 .01537 L
.05567 .01537 L
.05567 .16187 L
F
.804 .522 .247 r
.05534 .16187 m
.05534 .01537 L
.05567 .01537 L
.05567 .16187 L
s
1 .894 .882 r
.05567 .16187 m
.05567 .01539 L
.05611 .01539 L
.05611 .16187 L
F
.804 .522 .247 r
.05567 .16187 m
.05567 .01539 L
.05611 .01539 L
.05611 .16187 L
s
1 .894 .882 r
.05611 .16187 m
.05611 .0154 L
.05636 .0154 L
.05636 .16187 L
F
.804 .522 .247 r
.05611 .16187 m
.05611 .0154 L
.05636 .0154 L
.05636 .16187 L
s
1 .894 .882 r
.05636 .16187 m
.05636 .01541 L
.05659 .01541 L
.05659 .16187 L
F
.804 .522 .247 r
.05636 .16187 m
.05636 .01541 L
.05659 .01541 L
.05659 .16187 L
s
1 .894 .882 r
.05659 .16187 m
.05659 .01542 L
.05693 .01542 L
.05693 .16187 L
F
.804 .522 .247 r
.05659 .16187 m
.05659 .01542 L
.05693 .01542 L
.05693 .16187 L
s
1 .894 .882 r
.05693 .16187 m
.05693 .01543 L
.05733 .01543 L
.05733 .16187 L
F
.804 .522 .247 r
.05693 .16187 m
.05693 .01543 L
.05733 .01543 L
.05733 .16187 L
s
1 .894 .882 r
.05733 .16187 m
.05733 .01544 L
.05762 .01544 L
.05762 .16187 L
F
.804 .522 .247 r
.05733 .16187 m
.05733 .01544 L
.05762 .01544 L
.05762 .16187 L
s
1 .894 .882 r
.05762 .16187 m
.05762 .01547 L
.05807 .01547 L
.05807 .16187 L
F
.804 .522 .247 r
.05762 .16187 m
.05762 .01547 L
.05807 .01547 L
.05807 .16187 L
s
1 .894 .882 r
.05807 .16187 m
.05807 .01549 L
.05843 .01549 L
.05843 .16187 L
F
.804 .522 .247 r
.05807 .16187 m
.05807 .01549 L
.05843 .01549 L
.05843 .16187 L
s
1 .894 .882 r
.05843 .16187 m
.05843 .01551 L
.05887 .01551 L
.05887 .16187 L
F
.804 .522 .247 r
.05843 .16187 m
.05843 .01551 L
.05887 .01551 L
.05887 .16187 L
s
1 .894 .882 r
.05887 .16187 m
.05887 .01552 L
.05923 .01552 L
.05923 .16187 L
F
.804 .522 .247 r
.05887 .16187 m
.05887 .01552 L
.05923 .01552 L
.05923 .16187 L
s
1 .894 .882 r
.05923 .16187 m
.05923 .01554 L
.05942 .01554 L
.05942 .16187 L
F
.804 .522 .247 r
.05923 .16187 m
.05923 .01554 L
.05942 .01554 L
.05942 .16187 L
s
1 .894 .882 r
.05942 .16187 m
.05942 .01554 L
.05985 .01554 L
.05985 .16187 L
F
.804 .522 .247 r
.05942 .16187 m
.05942 .01554 L
.05985 .01554 L
.05985 .16187 L
s
1 .894 .882 r
.05985 .16187 m
.05985 .01557 L
.06027 .01557 L
.06027 .16187 L
F
.804 .522 .247 r
.05985 .16187 m
.05985 .01557 L
.06027 .01557 L
.06027 .16187 L
s
1 .894 .882 r
.06027 .16187 m
.06027 .01558 L
.06052 .01558 L
.06052 .16187 L
F
.804 .522 .247 r
.06027 .16187 m
.06027 .01558 L
.06052 .01558 L
.06052 .16187 L
s
1 .894 .882 r
.06052 .16187 m
.06052 .01561 L
.06098 .01561 L
.06098 .16187 L
F
.804 .522 .247 r
.06052 .16187 m
.06052 .01561 L
.06098 .01561 L
.06098 .16187 L
s
1 .894 .882 r
.06098 .16187 m
.06098 .01563 L
.06126 .01563 L
.06126 .16187 L
F
.804 .522 .247 r
.06098 .16187 m
.06098 .01563 L
.06126 .01563 L
.06126 .16187 L
s
1 .894 .882 r
.06126 .16187 m
.06126 .01564 L
.06166 .01564 L
.06166 .16187 L
F
.804 .522 .247 r
.06126 .16187 m
.06126 .01564 L
.06166 .01564 L
.06166 .16187 L
s
1 .894 .882 r
.06166 .16187 m
.06166 .01565 L
.06207 .01565 L
.06207 .16187 L
F
.804 .522 .247 r
.06166 .16187 m
.06166 .01565 L
.06207 .01565 L
.06207 .16187 L
s
1 .894 .882 r
.06207 .16187 m
.06207 .01568 L
.06245 .01568 L
.06245 .16187 L
F
.804 .522 .247 r
.06207 .16187 m
.06207 .01568 L
.06245 .01568 L
.06245 .16187 L
s
1 .894 .882 r
.06245 .16187 m
.06245 .0157 L
.06279 .0157 L
.06279 .16187 L
F
.804 .522 .247 r
.06245 .16187 m
.06245 .0157 L
.06279 .0157 L
.06279 .16187 L
s
1 .894 .882 r
.06279 .16187 m
.06279 .01572 L
.06321 .01572 L
.06321 .16187 L
F
.804 .522 .247 r
.06279 .16187 m
.06279 .01572 L
.06321 .01572 L
.06321 .16187 L
s
1 .894 .882 r
.06321 .16187 m
.06321 .01572 L
.06341 .01572 L
.06341 .16187 L
F
.804 .522 .247 r
.06321 .16187 m
.06321 .01572 L
.06341 .01572 L
.06341 .16187 L
s
1 .894 .882 r
.06341 .16187 m
.06341 .01575 L
.06381 .01575 L
.06381 .16187 L
F
.804 .522 .247 r
.06341 .16187 m
.06341 .01575 L
.06381 .01575 L
.06381 .16187 L
s
1 .894 .882 r
.06381 .16187 m
.06381 .01576 L
.06397 .01576 L
.06397 .16187 L
F
.804 .522 .247 r
.06381 .16187 m
.06381 .01576 L
.06397 .01576 L
.06397 .16187 L
s
1 .894 .882 r
.06397 .16187 m
.06397 .01576 L
.06444 .01576 L
.06444 .16187 L
F
.804 .522 .247 r
.06397 .16187 m
.06397 .01576 L
.06444 .01576 L
.06444 .16187 L
s
1 .894 .882 r
.06444 .16187 m
.06444 .0158 L
.06488 .0158 L
.06488 .16187 L
F
.804 .522 .247 r
.06444 .16187 m
.06444 .0158 L
.06488 .0158 L
.06488 .16187 L
s
1 .894 .882 r
.06488 .16187 m
.06488 .01583 L
.06521 .01583 L
.06521 .16187 L
F
.804 .522 .247 r
.06488 .16187 m
.06488 .01583 L
.06521 .01583 L
.06521 .16187 L
s
1 .894 .882 r
.06521 .16187 m
.06521 .01583 L
.06552 .01583 L
.06552 .16187 L
F
.804 .522 .247 r
.06521 .16187 m
.06521 .01583 L
.06552 .01583 L
.06552 .16187 L
s
1 .894 .882 r
.06552 .16187 m
.06552 .01585 L
.06573 .01585 L
.06573 .16187 L
F
.804 .522 .247 r
.06552 .16187 m
.06552 .01585 L
.06573 .01585 L
.06573 .16187 L
s
1 .894 .882 r
.06573 .16187 m
.06573 .01587 L
.06604 .01587 L
.06604 .16187 L
F
.804 .522 .247 r
.06573 .16187 m
.06573 .01587 L
.06604 .01587 L
.06604 .16187 L
s
1 .894 .882 r
.06604 .16187 m
.06604 .01588 L
.0664 .01588 L
.0664 .16187 L
F
.804 .522 .247 r
.06604 .16187 m
.06604 .01588 L
.0664 .01588 L
.0664 .16187 L
s
1 .894 .882 r
.0664 .16187 m
.0664 .0159 L
.06684 .0159 L
.06684 .16187 L
F
.804 .522 .247 r
.0664 .16187 m
.0664 .0159 L
.06684 .0159 L
.06684 .16187 L
s
1 .894 .882 r
.06684 .16187 m
.06684 .01593 L
.06711 .01593 L
.06711 .16187 L
F
.804 .522 .247 r
.06684 .16187 m
.06684 .01593 L
.06711 .01593 L
.06711 .16187 L
s
1 .894 .882 r
.06711 .16187 m
.06711 .01594 L
.06755 .01594 L
.06755 .16187 L
F
.804 .522 .247 r
.06711 .16187 m
.06711 .01594 L
.06755 .01594 L
.06755 .16187 L
s
1 .894 .882 r
.06755 .16187 m
.06755 .01596 L
.06786 .01596 L
.06786 .16187 L
F
.804 .522 .247 r
.06755 .16187 m
.06755 .01596 L
.06786 .01596 L
.06786 .16187 L
s
1 .894 .882 r
.06786 .16187 m
.06786 .01598 L
.06802 .01598 L
.06802 .16187 L
F
.804 .522 .247 r
.06786 .16187 m
.06786 .01598 L
.06802 .01598 L
.06802 .16187 L
s
1 .894 .882 r
.06802 .16187 m
.06802 .01599 L
.06837 .01599 L
.06837 .16187 L
F
.804 .522 .247 r
.06802 .16187 m
.06802 .01599 L
.06837 .01599 L
.06837 .16187 L
s
1 .894 .882 r
.06837 .16187 m
.06837 .01602 L
.0687 .01602 L
.0687 .16187 L
F
.804 .522 .247 r
.06837 .16187 m
.06837 .01602 L
.0687 .01602 L
.0687 .16187 L
s
1 .894 .882 r
.0687 .16187 m
.0687 .01603 L
.06905 .01603 L
.06905 .16187 L
F
.804 .522 .247 r
.0687 .16187 m
.0687 .01603 L
.06905 .01603 L
.06905 .16187 L
s
1 .894 .882 r
.06905 .16187 m
.06905 .01605 L
.06941 .01605 L
.06941 .16187 L
F
.804 .522 .247 r
.06905 .16187 m
.06905 .01605 L
.06941 .01605 L
.06941 .16187 L
s
1 .894 .882 r
.06941 .16187 m
.06941 .01608 L
.06985 .01608 L
.06985 .16187 L
F
.804 .522 .247 r
.06941 .16187 m
.06941 .01608 L
.06985 .01608 L
.06985 .16187 L
s
1 .894 .882 r
.06985 .16187 m
.06985 .01611 L
.07027 .01611 L
.07027 .16187 L
F
.804 .522 .247 r
.06985 .16187 m
.06985 .01611 L
.07027 .01611 L
.07027 .16187 L
s
1 .894 .882 r
.07027 .16187 m
.07027 .01613 L
.07073 .01613 L
.07073 .16187 L
F
.804 .522 .247 r
.07027 .16187 m
.07027 .01613 L
.07073 .01613 L
.07073 .16187 L
s
1 .894 .882 r
.07073 .16187 m
.07073 .01615 L
.07091 .01615 L
.07091 .16187 L
F
.804 .522 .247 r
.07073 .16187 m
.07073 .01615 L
.07091 .01615 L
.07091 .16187 L
s
1 .894 .882 r
.07091 .16187 m
.07091 .01616 L
.07107 .01616 L
.07107 .16187 L
F
.804 .522 .247 r
.07091 .16187 m
.07091 .01616 L
.07107 .01616 L
.07107 .16187 L
s
1 .894 .882 r
.07107 .16187 m
.07107 .01618 L
.07143 .01618 L
.07143 .16187 L
F
.804 .522 .247 r
.07107 .16187 m
.07107 .01618 L
.07143 .01618 L
.07143 .16187 L
s
1 .894 .882 r
.07143 .16187 m
.07143 .01619 L
.07164 .01619 L
.07164 .16187 L
F
.804 .522 .247 r
.07143 .16187 m
.07143 .01619 L
.07164 .01619 L
.07164 .16187 L
s
1 .894 .882 r
.07164 .16187 m
.07164 .01621 L
.07181 .01621 L
.07181 .16187 L
F
.804 .522 .247 r
.07164 .16187 m
.07164 .01621 L
.07181 .01621 L
.07181 .16187 L
s
1 .894 .882 r
.07181 .16187 m
.07181 .01622 L
.07199 .01622 L
.07199 .16187 L
F
.804 .522 .247 r
.07181 .16187 m
.07181 .01622 L
.07199 .01622 L
.07199 .16187 L
s
1 .894 .882 r
.07199 .16187 m
.07199 .01625 L
.07241 .01625 L
.07241 .16187 L
F
.804 .522 .247 r
.07199 .16187 m
.07199 .01625 L
.07241 .01625 L
.07241 .16187 L
s
1 .894 .882 r
.07241 .16187 m
.07241 .01625 L
.07278 .01625 L
.07278 .16187 L
F
.804 .522 .247 r
.07241 .16187 m
.07241 .01625 L
.07278 .01625 L
.07278 .16187 L
s
1 .894 .882 r
.07278 .16187 m
.07278 .01629 L
.07313 .01629 L
.07313 .16187 L
F
.804 .522 .247 r
.07278 .16187 m
.07278 .01629 L
.07313 .01629 L
.07313 .16187 L
s
1 .894 .882 r
.07313 .16187 m
.07313 .01629 L
.07359 .01629 L
.07359 .16187 L
F
.804 .522 .247 r
.07313 .16187 m
.07313 .01629 L
.07359 .01629 L
.07359 .16187 L
s
1 .894 .882 r
.07359 .16187 m
.07359 .01633 L
.07385 .01633 L
.07385 .16187 L
F
.804 .522 .247 r
.07359 .16187 m
.07359 .01633 L
.07385 .01633 L
.07385 .16187 L
s
1 .894 .882 r
.07385 .16187 m
.07385 .01635 L
.07402 .01635 L
.07402 .16187 L
F
.804 .522 .247 r
.07385 .16187 m
.07385 .01635 L
.07402 .01635 L
.07402 .16187 L
s
1 .894 .882 r
.07402 .16187 m
.07402 .01636 L
.07441 .01636 L
.07441 .16187 L
F
.804 .522 .247 r
.07402 .16187 m
.07402 .01636 L
.07441 .01636 L
.07441 .16187 L
s
1 .894 .882 r
.07441 .16187 m
.07441 .01638 L
.07475 .01638 L
.07475 .16187 L
F
.804 .522 .247 r
.07441 .16187 m
.07441 .01638 L
.07475 .01638 L
.07475 .16187 L
s
1 .894 .882 r
.07475 .16187 m
.07475 .01642 L
.07506 .01642 L
.07506 .16187 L
F
.804 .522 .247 r
.07475 .16187 m
.07475 .01642 L
.07506 .01642 L
.07506 .16187 L
s
1 .894 .882 r
.07506 .16187 m
.07506 .01643 L
.07541 .01643 L
.07541 .16187 L
F
.804 .522 .247 r
.07506 .16187 m
.07506 .01643 L
.07541 .01643 L
.07541 .16187 L
s
1 .894 .882 r
.07541 .16187 m
.07541 .01645 L
.07579 .01645 L
.07579 .16187 L
F
.804 .522 .247 r
.07541 .16187 m
.07541 .01645 L
.07579 .01645 L
.07579 .16187 L
s
1 .894 .882 r
.07579 .16187 m
.07579 .01649 L
.07627 .01649 L
.07627 .16187 L
F
.804 .522 .247 r
.07579 .16187 m
.07579 .01649 L
.07627 .01649 L
.07627 .16187 L
s
1 .894 .882 r
.07627 .16187 m
.07627 .01653 L
.07675 .01653 L
.07675 .16187 L
F
.804 .522 .247 r
.07627 .16187 m
.07627 .01653 L
.07675 .01653 L
.07675 .16187 L
s
1 .894 .882 r
.07675 .16187 m
.07675 .01657 L
.07724 .01657 L
.07724 .16187 L
F
.804 .522 .247 r
.07675 .16187 m
.07675 .01657 L
.07724 .01657 L
.07724 .16187 L
s
1 .894 .882 r
.07724 .16187 m
.07724 .01657 L
.0774 .01657 L
.0774 .16187 L
F
.804 .522 .247 r
.07724 .16187 m
.07724 .01657 L
.0774 .01657 L
.0774 .16187 L
s
1 .894 .882 r
.0774 .16187 m
.0774 .01658 L
.07759 .01658 L
.07759 .16187 L
F
.804 .522 .247 r
.0774 .16187 m
.0774 .01658 L
.07759 .01658 L
.07759 .16187 L
s
1 .894 .882 r
.07759 .16187 m
.07759 .0166 L
.07781 .0166 L
.07781 .16187 L
F
.804 .522 .247 r
.07759 .16187 m
.07759 .0166 L
.07781 .0166 L
.07781 .16187 L
s
1 .894 .882 r
.07781 .16187 m
.07781 .01661 L
.07797 .01661 L
.07797 .16187 L
F
.804 .522 .247 r
.07781 .16187 m
.07781 .01661 L
.07797 .01661 L
.07797 .16187 L
s
1 .894 .882 r
.07797 .16187 m
.07797 .01665 L
.07846 .01665 L
.07846 .16187 L
F
.804 .522 .247 r
.07797 .16187 m
.07797 .01665 L
.07846 .01665 L
.07846 .16187 L
s
1 .894 .882 r
.07846 .16187 m
.07846 .01666 L
.07863 .01666 L
.07863 .16187 L
F
.804 .522 .247 r
.07846 .16187 m
.07846 .01666 L
.07863 .01666 L
.07863 .16187 L
s
1 .894 .882 r
.07863 .16187 m
.07863 .01668 L
.07897 .01668 L
.07897 .16187 L
F
.804 .522 .247 r
.07863 .16187 m
.07863 .01668 L
.07897 .01668 L
.07897 .16187 L
s
1 .894 .882 r
.07897 .16187 m
.07897 .0167 L
.07943 .0167 L
.07943 .16187 L
F
.804 .522 .247 r
.07897 .16187 m
.07897 .0167 L
.07943 .0167 L
.07943 .16187 L
s
1 .894 .882 r
.07943 .16187 m
.07943 .01675 L
.07989 .01675 L
.07989 .16187 L
F
.804 .522 .247 r
.07943 .16187 m
.07943 .01675 L
.07989 .01675 L
.07989 .16187 L
s
1 .894 .882 r
.07989 .16187 m
.07989 .01679 L
.08037 .01679 L
.08037 .16187 L
F
.804 .522 .247 r
.07989 .16187 m
.07989 .01679 L
.08037 .01679 L
.08037 .16187 L
s
1 .894 .882 r
.08037 .16187 m
.08037 .01681 L
.08079 .01681 L
.08079 .16187 L
F
.804 .522 .247 r
.08037 .16187 m
.08037 .01681 L
.08079 .01681 L
.08079 .16187 L
s
1 .894 .882 r
.08079 .16187 m
.08079 .01682 L
.08101 .01682 L
.08101 .16187 L
F
.804 .522 .247 r
.08079 .16187 m
.08079 .01682 L
.08101 .01682 L
.08101 .16187 L
s
1 .894 .882 r
.08101 .16187 m
.08101 .01684 L
.08128 .01684 L
.08128 .16187 L
F
.804 .522 .247 r
.08101 .16187 m
.08101 .01684 L
.08128 .01684 L
.08128 .16187 L
s
1 .894 .882 r
.08128 .16187 m
.08128 .01687 L
.08144 .01687 L
.08144 .16187 L
F
.804 .522 .247 r
.08128 .16187 m
.08128 .01687 L
.08144 .01687 L
.08144 .16187 L
s
1 .894 .882 r
.08144 .16187 m
.08144 .01688 L
.08175 .01688 L
.08175 .16187 L
F
.804 .522 .247 r
.08144 .16187 m
.08144 .01688 L
.08175 .01688 L
.08175 .16187 L
s
1 .894 .882 r
.08175 .16187 m
.08175 .0169 L
.08196 .0169 L
.08196 .16187 L
F
.804 .522 .247 r
.08175 .16187 m
.08175 .0169 L
.08196 .0169 L
.08196 .16187 L
s
1 .894 .882 r
.08196 .16187 m
.08196 .01693 L
.08232 .01693 L
.08232 .16187 L
F
.804 .522 .247 r
.08196 .16187 m
.08196 .01693 L
.08232 .01693 L
.08232 .16187 L
s
1 .894 .882 r
.08232 .16187 m
.08232 .01695 L
.08264 .01695 L
.08264 .16187 L
F
.804 .522 .247 r
.08232 .16187 m
.08232 .01695 L
.08264 .01695 L
.08264 .16187 L
s
1 .894 .882 r
.08264 .16187 m
.08264 .01699 L
.08313 .01699 L
.08313 .16187 L
F
.804 .522 .247 r
.08264 .16187 m
.08264 .01699 L
.08313 .01699 L
.08313 .16187 L
s
1 .894 .882 r
.08313 .16187 m
.08313 .01702 L
.08348 .01702 L
.08348 .16187 L
F
.804 .522 .247 r
.08313 .16187 m
.08313 .01702 L
.08348 .01702 L
.08348 .16187 L
s
1 .894 .882 r
.08348 .16187 m
.08348 .01705 L
.08395 .01705 L
.08395 .16187 L
F
.804 .522 .247 r
.08348 .16187 m
.08348 .01705 L
.08395 .01705 L
.08395 .16187 L
s
1 .894 .882 r
.08395 .16187 m
.08395 .01706 L
.08428 .01706 L
.08428 .16187 L
F
.804 .522 .247 r
.08395 .16187 m
.08395 .01706 L
.08428 .01706 L
.08428 .16187 L
s
1 .894 .882 r
.08428 .16187 m
.08428 .0171 L
.08444 .0171 L
.08444 .16187 L
F
.804 .522 .247 r
.08428 .16187 m
.08428 .0171 L
.08444 .0171 L
.08444 .16187 L
s
1 .894 .882 r
.08444 .16187 m
.08444 .01712 L
.0848 .01712 L
.0848 .16187 L
F
.804 .522 .247 r
.08444 .16187 m
.08444 .01712 L
.0848 .01712 L
.0848 .16187 L
s
1 .894 .882 r
.0848 .16187 m
.0848 .01715 L
.08525 .01715 L
.08525 .16187 L
F
.804 .522 .247 r
.0848 .16187 m
.0848 .01715 L
.08525 .01715 L
.08525 .16187 L
s
1 .894 .882 r
.08525 .16187 m
.08525 .01719 L
.08554 .01719 L
.08554 .16187 L
F
.804 .522 .247 r
.08525 .16187 m
.08525 .01719 L
.08554 .01719 L
.08554 .16187 L
s
1 .894 .882 r
.08554 .16187 m
.08554 .01721 L
.08598 .01721 L
.08598 .16187 L
F
.804 .522 .247 r
.08554 .16187 m
.08554 .01721 L
.08598 .01721 L
.08598 .16187 L
s
1 .894 .882 r
.08598 .16187 m
.08598 .01724 L
.08632 .01724 L
.08632 .16187 L
F
.804 .522 .247 r
.08598 .16187 m
.08598 .01724 L
.08632 .01724 L
.08632 .16187 L
s
1 .894 .882 r
.08632 .16187 m
.08632 .01727 L
.08678 .01727 L
.08678 .16187 L
F
.804 .522 .247 r
.08632 .16187 m
.08632 .01727 L
.08678 .01727 L
.08678 .16187 L
s
1 .894 .882 r
.08678 .16187 m
.08678 .0173 L
.08704 .0173 L
.08704 .16187 L
F
.804 .522 .247 r
.08678 .16187 m
.08678 .0173 L
.08704 .0173 L
.08704 .16187 L
s
1 .894 .882 r
.08704 .16187 m
.08704 .01733 L
.08729 .01733 L
.08729 .16187 L
F
.804 .522 .247 r
.08704 .16187 m
.08704 .01733 L
.08729 .01733 L
.08729 .16187 L
s
1 .894 .882 r
.08729 .16187 m
.08729 .01734 L
.08766 .01734 L
.08766 .16187 L
F
.804 .522 .247 r
.08729 .16187 m
.08729 .01734 L
.08766 .01734 L
.08766 .16187 L
s
1 .894 .882 r
.08766 .16187 m
.08766 .01739 L
.08815 .01739 L
.08815 .16187 L
F
.804 .522 .247 r
.08766 .16187 m
.08766 .01739 L
.08815 .01739 L
.08815 .16187 L
s
1 .894 .882 r
.08815 .16187 m
.08815 .01741 L
.08843 .01741 L
.08843 .16187 L
F
.804 .522 .247 r
.08815 .16187 m
.08815 .01741 L
.08843 .01741 L
.08843 .16187 L
s
1 .894 .882 r
.08843 .16187 m
.08843 .01743 L
.08874 .01743 L
.08874 .16187 L
F
.804 .522 .247 r
.08843 .16187 m
.08843 .01743 L
.08874 .01743 L
.08874 .16187 L
s
1 .894 .882 r
.08874 .16187 m
.08874 .01745 L
.08904 .01745 L
.08904 .16187 L
F
.804 .522 .247 r
.08874 .16187 m
.08874 .01745 L
.08904 .01745 L
.08904 .16187 L
s
1 .894 .882 r
.08904 .16187 m
.08904 .01749 L
.08941 .01749 L
.08941 .16187 L
F
.804 .522 .247 r
.08904 .16187 m
.08904 .01749 L
.08941 .01749 L
.08941 .16187 L
s
1 .894 .882 r
.08941 .16187 m
.08941 .01752 L
.08968 .01752 L
.08968 .16187 L
F
.804 .522 .247 r
.08941 .16187 m
.08941 .01752 L
.08968 .01752 L
.08968 .16187 L
s
1 .894 .882 r
.08968 .16187 m
.08968 .01756 L
.09017 .01756 L
.09017 .16187 L
F
.804 .522 .247 r
.08968 .16187 m
.08968 .01756 L
.09017 .01756 L
.09017 .16187 L
s
1 .894 .882 r
.09017 .16187 m
.09017 .01759 L
.09041 .01759 L
.09041 .16187 L
F
.804 .522 .247 r
.09017 .16187 m
.09017 .01759 L
.09041 .01759 L
.09041 .16187 L
s
1 .894 .882 r
.09041 .16187 m
.09041 .0176 L
.09057 .0176 L
.09057 .16187 L
F
.804 .522 .247 r
.09041 .16187 m
.09041 .0176 L
.09057 .0176 L
.09057 .16187 L
s
1 .894 .882 r
.09057 .16187 m
.09057 .01761 L
.09101 .01761 L
.09101 .16187 L
F
.804 .522 .247 r
.09057 .16187 m
.09057 .01761 L
.09101 .01761 L
.09101 .16187 L
s
1 .894 .882 r
.09101 .16187 m
.09101 .01765 L
.09116 .01765 L
.09116 .16187 L
F
.804 .522 .247 r
.09101 .16187 m
.09101 .01765 L
.09116 .01765 L
.09116 .16187 L
s
1 .894 .882 r
.09116 .16187 m
.09116 .01769 L
.09154 .01769 L
.09154 .16187 L
F
.804 .522 .247 r
.09116 .16187 m
.09116 .01769 L
.09154 .01769 L
.09154 .16187 L
s
1 .894 .882 r
.09154 .16187 m
.09154 .01769 L
.09172 .01769 L
.09172 .16187 L
F
.804 .522 .247 r
.09154 .16187 m
.09154 .01769 L
.09172 .01769 L
.09172 .16187 L
s
1 .894 .882 r
.09172 .16187 m
.09172 .01773 L
.09197 .01773 L
.09197 .16187 L
F
.804 .522 .247 r
.09172 .16187 m
.09172 .01773 L
.09197 .01773 L
.09197 .16187 L
s
1 .894 .882 r
.09197 .16187 m
.09197 .01774 L
.09246 .01774 L
.09246 .16187 L
F
.804 .522 .247 r
.09197 .16187 m
.09197 .01774 L
.09246 .01774 L
.09246 .16187 L
s
1 .894 .882 r
.09246 .16187 m
.09246 .01777 L
.09263 .01777 L
.09263 .16187 L
F
.804 .522 .247 r
.09246 .16187 m
.09246 .01777 L
.09263 .01777 L
.09263 .16187 L
s
1 .894 .882 r
.09263 .16187 m
.09263 .0178 L
.09285 .0178 L
.09285 .16187 L
F
.804 .522 .247 r
.09263 .16187 m
.09263 .0178 L
.09285 .0178 L
.09285 .16187 L
s
1 .894 .882 r
.09285 .16187 m
.09285 .01781 L
.09331 .01781 L
.09331 .16187 L
F
.804 .522 .247 r
.09285 .16187 m
.09285 .01781 L
.09331 .01781 L
.09331 .16187 L
s
1 .894 .882 r
.09331 .16187 m
.09331 .01786 L
.0935 .01786 L
.0935 .16187 L
F
.804 .522 .247 r
.09331 .16187 m
.09331 .01786 L
.0935 .01786 L
.0935 .16187 L
s
1 .894 .882 r
.0935 .16187 m
.0935 .01788 L
.09382 .01788 L
.09382 .16187 L
F
.804 .522 .247 r
.0935 .16187 m
.0935 .01788 L
.09382 .01788 L
.09382 .16187 L
s
1 .894 .882 r
.09382 .16187 m
.09382 .01792 L
.09408 .01792 L
.09408 .16187 L
F
.804 .522 .247 r
.09382 .16187 m
.09382 .01792 L
.09408 .01792 L
.09408 .16187 L
s
1 .894 .882 r
.09408 .16187 m
.09408 .01794 L
.09442 .01794 L
.09442 .16187 L
F
.804 .522 .247 r
.09408 .16187 m
.09408 .01794 L
.09442 .01794 L
.09442 .16187 L
s
1 .894 .882 r
.09442 .16187 m
.09442 .01799 L
.09486 .01799 L
.09486 .16187 L
F
.804 .522 .247 r
.09442 .16187 m
.09442 .01799 L
.09486 .01799 L
.09486 .16187 L
s
1 .894 .882 r
.09486 .16187 m
.09486 .01801 L
.0953 .01801 L
.0953 .16187 L
F
.804 .522 .247 r
.09486 .16187 m
.09486 .01801 L
.0953 .01801 L
.0953 .16187 L
s
1 .894 .882 r
.0953 .16187 m
.0953 .01804 L
.09556 .01804 L
.09556 .16187 L
F
.804 .522 .247 r
.0953 .16187 m
.0953 .01804 L
.09556 .01804 L
.09556 .16187 L
s
1 .894 .882 r
.09556 .16187 m
.09556 .01806 L
.09576 .01806 L
.09576 .16187 L
F
.804 .522 .247 r
.09556 .16187 m
.09556 .01806 L
.09576 .01806 L
.09576 .16187 L
s
1 .894 .882 r
.09576 .16187 m
.09576 .0181 L
.09604 .0181 L
.09604 .16187 L
F
.804 .522 .247 r
.09576 .16187 m
.09576 .0181 L
.09604 .0181 L
.09604 .16187 L
s
1 .894 .882 r
.09604 .16187 m
.09604 .01811 L
.09633 .01811 L
.09633 .16187 L
F
.804 .522 .247 r
.09604 .16187 m
.09604 .01811 L
.09633 .01811 L
.09633 .16187 L
s
1 .894 .882 r
.09633 .16187 m
.09633 .01815 L
.09671 .01815 L
.09671 .16187 L
F
.804 .522 .247 r
.09633 .16187 m
.09633 .01815 L
.09671 .01815 L
.09671 .16187 L
s
1 .894 .882 r
.09671 .16187 m
.09671 .01818 L
.09714 .01818 L
.09714 .16187 L
F
.804 .522 .247 r
.09671 .16187 m
.09671 .01818 L
.09714 .01818 L
.09714 .16187 L
s
1 .894 .882 r
.09714 .16187 m
.09714 .01821 L
.09742 .01821 L
.09742 .16187 L
F
.804 .522 .247 r
.09714 .16187 m
.09714 .01821 L
.09742 .01821 L
.09742 .16187 L
s
1 .894 .882 r
.09742 .16187 m
.09742 .01824 L
.09762 .01824 L
.09762 .16187 L
F
.804 .522 .247 r
.09742 .16187 m
.09742 .01824 L
.09762 .01824 L
.09762 .16187 L
s
1 .894 .882 r
.09762 .16187 m
.09762 .01826 L
.09799 .01826 L
.09799 .16187 L
F
.804 .522 .247 r
.09762 .16187 m
.09762 .01826 L
.09799 .01826 L
.09799 .16187 L
s
1 .894 .882 r
.09799 .16187 m
.09799 .01831 L
.09847 .01831 L
.09847 .16187 L
F
.804 .522 .247 r
.09799 .16187 m
.09799 .01831 L
.09847 .01831 L
.09847 .16187 L
s
1 .894 .882 r
.09847 .16187 m
.09847 .01834 L
.09875 .01834 L
.09875 .16187 L
F
.804 .522 .247 r
.09847 .16187 m
.09847 .01834 L
.09875 .01834 L
.09875 .16187 L
s
1 .894 .882 r
.09875 .16187 m
.09875 .01838 L
.09905 .01838 L
.09905 .16187 L
F
.804 .522 .247 r
.09875 .16187 m
.09875 .01838 L
.09905 .01838 L
.09905 .16187 L
s
1 .894 .882 r
.09905 .16187 m
.09905 .01839 L
.09939 .01839 L
.09939 .16187 L
F
.804 .522 .247 r
.09905 .16187 m
.09905 .01839 L
.09939 .01839 L
.09939 .16187 L
s
1 .894 .882 r
.09939 .16187 m
.09939 .01844 L
.09977 .01844 L
.09977 .16187 L
F
.804 .522 .247 r
.09939 .16187 m
.09939 .01844 L
.09977 .01844 L
.09977 .16187 L
s
1 .894 .882 r
.09977 .16187 m
.09977 .01848 L
.10006 .01848 L
.10006 .16187 L
F
.804 .522 .247 r
.09977 .16187 m
.09977 .01848 L
.10006 .01848 L
.10006 .16187 L
s
1 .894 .882 r
.10006 .16187 m
.10006 .0185 L
.10034 .0185 L
.10034 .16187 L
F
.804 .522 .247 r
.10006 .16187 m
.10006 .0185 L
.10034 .0185 L
.10034 .16187 L
s
1 .894 .882 r
.10034 .16187 m
.10034 .01853 L
.1006 .01853 L
.1006 .16187 L
F
.804 .522 .247 r
.10034 .16187 m
.10034 .01853 L
.1006 .01853 L
.1006 .16187 L
s
1 .894 .882 r
.1006 .16187 m
.1006 .01856 L
.10101 .01856 L
.10101 .16187 L
F
.804 .522 .247 r
.1006 .16187 m
.1006 .01856 L
.10101 .01856 L
.10101 .16187 L
s
1 .894 .882 r
.10101 .16187 m
.10101 .01858 L
.10126 .01858 L
.10126 .16187 L
F
.804 .522 .247 r
.10101 .16187 m
.10101 .01858 L
.10126 .01858 L
.10126 .16187 L
s
1 .894 .882 r
.10126 .16187 m
.10126 .01865 L
.10171 .01865 L
.10171 .16187 L
F
.804 .522 .247 r
.10126 .16187 m
.10126 .01865 L
.10171 .01865 L
.10171 .16187 L
s
1 .894 .882 r
.10171 .16187 m
.10171 .01866 L
.10186 .01866 L
.10186 .16187 L
F
.804 .522 .247 r
.10171 .16187 m
.10171 .01866 L
.10186 .01866 L
.10186 .16187 L
s
1 .894 .882 r
.10186 .16187 m
.10186 .01868 L
.10208 .01868 L
.10208 .16187 L
F
.804 .522 .247 r
.10186 .16187 m
.10186 .01868 L
.10208 .01868 L
.10208 .16187 L
s
1 .894 .882 r
.10208 .16187 m
.10208 .01869 L
.10238 .01869 L
.10238 .16187 L
F
.804 .522 .247 r
.10208 .16187 m
.10208 .01869 L
.10238 .01869 L
.10238 .16187 L
s
1 .894 .882 r
.10238 .16187 m
.10238 .01873 L
.10253 .01873 L
.10253 .16187 L
F
.804 .522 .247 r
.10238 .16187 m
.10238 .01873 L
.10253 .01873 L
.10253 .16187 L
s
1 .894 .882 r
.10253 .16187 m
.10253 .01876 L
.10292 .01876 L
.10292 .16187 L
F
.804 .522 .247 r
.10253 .16187 m
.10253 .01876 L
.10292 .01876 L
.10292 .16187 L
s
1 .894 .882 r
.10292 .16187 m
.10292 .01878 L
.10309 .01878 L
.10309 .16187 L
F
.804 .522 .247 r
.10292 .16187 m
.10292 .01878 L
.10309 .01878 L
.10309 .16187 L
s
1 .894 .882 r
.10309 .16187 m
.10309 .0188 L
.10325 .0188 L
.10325 .16187 L
F
.804 .522 .247 r
.10309 .16187 m
.10309 .0188 L
.10325 .0188 L
.10325 .16187 L
s
1 .894 .882 r
.10325 .16187 m
.10325 .01882 L
.10361 .01882 L
.10361 .16187 L
F
.804 .522 .247 r
.10325 .16187 m
.10325 .01882 L
.10361 .01882 L
.10361 .16187 L
s
1 .894 .882 r
.10361 .16187 m
.10361 .01886 L
.10377 .01886 L
.10377 .16187 L
F
.804 .522 .247 r
.10361 .16187 m
.10361 .01886 L
.10377 .01886 L
.10377 .16187 L
s
1 .894 .882 r
.10377 .16187 m
.10377 .01889 L
.10399 .01889 L
.10399 .16187 L
F
.804 .522 .247 r
.10377 .16187 m
.10377 .01889 L
.10399 .01889 L
.10399 .16187 L
s
1 .894 .882 r
.10399 .16187 m
.10399 .01889 L
.10437 .01889 L
.10437 .16187 L
F
.804 .522 .247 r
.10399 .16187 m
.10399 .01889 L
.10437 .01889 L
.10437 .16187 L
s
1 .894 .882 r
.10437 .16187 m
.10437 .01895 L
.10468 .01895 L
.10468 .16187 L
F
.804 .522 .247 r
.10437 .16187 m
.10437 .01895 L
.10468 .01895 L
.10468 .16187 L
s
1 .894 .882 r
.10468 .16187 m
.10468 .01898 L
.10496 .01898 L
.10496 .16187 L
F
.804 .522 .247 r
.10468 .16187 m
.10468 .01898 L
.10496 .01898 L
.10496 .16187 L
s
1 .894 .882 r
.10496 .16187 m
.10496 .019 L
.10519 .019 L
.10519 .16187 L
F
.804 .522 .247 r
.10496 .16187 m
.10496 .019 L
.10519 .019 L
.10519 .16187 L
s
1 .894 .882 r
.10519 .16187 m
.10519 .01901 L
.10544 .01901 L
.10544 .16187 L
F
.804 .522 .247 r
.10519 .16187 m
.10519 .01901 L
.10544 .01901 L
.10544 .16187 L
s
1 .894 .882 r
.10544 .16187 m
.10544 .01904 L
.10593 .01904 L
.10593 .16187 L
F
.804 .522 .247 r
.10544 .16187 m
.10544 .01904 L
.10593 .01904 L
.10593 .16187 L
s
1 .894 .882 r
.10593 .16187 m
.10593 .01912 L
.10637 .01912 L
.10637 .16187 L
F
.804 .522 .247 r
.10593 .16187 m
.10593 .01912 L
.10637 .01912 L
.10637 .16187 L
s
1 .894 .882 r
.10637 .16187 m
.10637 .01914 L
.10672 .01914 L
.10672 .16187 L
F
.804 .522 .247 r
.10637 .16187 m
.10637 .01914 L
.10672 .01914 L
.10672 .16187 L
s
1 .894 .882 r
.10672 .16187 m
.10672 .01919 L
.10717 .01919 L
.10717 .16187 L
F
.804 .522 .247 r
.10672 .16187 m
.10672 .01919 L
.10717 .01919 L
.10717 .16187 L
s
1 .894 .882 r
.10717 .16187 m
.10717 .01925 L
.10753 .01925 L
.10753 .16187 L
F
.804 .522 .247 r
.10717 .16187 m
.10717 .01925 L
.10753 .01925 L
.10753 .16187 L
s
1 .894 .882 r
.10753 .16187 m
.10753 .0193 L
.10785 .0193 L
.10785 .16187 L
F
.804 .522 .247 r
.10753 .16187 m
.10753 .0193 L
.10785 .0193 L
.10785 .16187 L
s
1 .894 .882 r
.10785 .16187 m
.10785 .01933 L
.10828 .01933 L
.10828 .16187 L
F
.804 .522 .247 r
.10785 .16187 m
.10785 .01933 L
.10828 .01933 L
.10828 .16187 L
s
1 .894 .882 r
.10828 .16187 m
.10828 .01935 L
.10864 .01935 L
.10864 .16187 L
F
.804 .522 .247 r
.10828 .16187 m
.10828 .01935 L
.10864 .01935 L
.10864 .16187 L
s
1 .894 .882 r
.10864 .16187 m
.10864 .01942 L
.10904 .01942 L
.10904 .16187 L
F
.804 .522 .247 r
.10864 .16187 m
.10864 .01942 L
.10904 .01942 L
.10904 .16187 L
s
1 .894 .882 r
.10904 .16187 m
.10904 .01944 L
.10935 .01944 L
.10935 .16187 L
F
.804 .522 .247 r
.10904 .16187 m
.10904 .01944 L
.10935 .01944 L
.10935 .16187 L
s
1 .894 .882 r
.10935 .16187 m
.10935 .01947 L
.1097 .01947 L
.1097 .16187 L
F
.804 .522 .247 r
.10935 .16187 m
.10935 .01947 L
.1097 .01947 L
.1097 .16187 L
s
1 .894 .882 r
.1097 .16187 m
.1097 .0195 L
.10991 .0195 L
.10991 .16187 L
F
.804 .522 .247 r
.1097 .16187 m
.1097 .0195 L
.10991 .0195 L
.10991 .16187 L
s
1 .894 .882 r
.10991 .16187 m
.10991 .01953 L
.11031 .01953 L
.11031 .16187 L
F
.804 .522 .247 r
.10991 .16187 m
.10991 .01953 L
.11031 .01953 L
.11031 .16187 L
s
1 .894 .882 r
.11031 .16187 m
.11031 .0196 L
.11072 .0196 L
.11072 .16187 L
F
.804 .522 .247 r
.11031 .16187 m
.11031 .0196 L
.11072 .0196 L
.11072 .16187 L
s
1 .894 .882 r
.11072 .16187 m
.11072 .01964 L
.11106 .01964 L
.11106 .16187 L
F
.804 .522 .247 r
.11072 .16187 m
.11072 .01964 L
.11106 .01964 L
.11106 .16187 L
s
1 .894 .882 r
.11106 .16187 m
.11106 .01967 L
.11125 .01967 L
.11125 .16187 L
F
.804 .522 .247 r
.11106 .16187 m
.11106 .01967 L
.11125 .01967 L
.11125 .16187 L
s
1 .894 .882 r
.11125 .16187 m
.11125 .0197 L
.11145 .0197 L
.11145 .16187 L
F
.804 .522 .247 r
.11125 .16187 m
.11125 .0197 L
.11145 .0197 L
.11145 .16187 L
s
1 .894 .882 r
.11145 .16187 m
.11145 .01974 L
.11184 .01974 L
.11184 .16187 L
F
.804 .522 .247 r
.11145 .16187 m
.11145 .01974 L
.11184 .01974 L
.11184 .16187 L
s
1 .894 .882 r
.11184 .16187 m
.11184 .01976 L
.1121 .01976 L
.1121 .16187 L
F
.804 .522 .247 r
.11184 .16187 m
.11184 .01976 L
.1121 .01976 L
.1121 .16187 L
s
1 .894 .882 r
.1121 .16187 m
.1121 .01979 L
.11241 .01979 L
.11241 .16187 L
F
.804 .522 .247 r
.1121 .16187 m
.1121 .01979 L
.11241 .01979 L
.11241 .16187 L
s
1 .894 .882 r
.11241 .16187 m
.11241 .01982 L
.11279 .01982 L
.11279 .16187 L
F
.804 .522 .247 r
.11241 .16187 m
.11241 .01982 L
.11279 .01982 L
.11279 .16187 L
s
1 .894 .882 r
.11279 .16187 m
.11279 .01986 L
.11305 .01986 L
.11305 .16187 L
F
.804 .522 .247 r
.11279 .16187 m
.11279 .01986 L
.11305 .01986 L
.11305 .16187 L
s
1 .894 .882 r
.11305 .16187 m
.11305 .01989 L
.11323 .01989 L
.11323 .16187 L
F
.804 .522 .247 r
.11305 .16187 m
.11305 .01989 L
.11323 .01989 L
.11323 .16187 L
s
1 .894 .882 r
.11323 .16187 m
.11323 .01992 L
.11343 .01992 L
.11343 .16187 L
F
.804 .522 .247 r
.11323 .16187 m
.11323 .01992 L
.11343 .01992 L
.11343 .16187 L
s
1 .894 .882 r
.11343 .16187 m
.11343 .01993 L
.11381 .01993 L
.11381 .16187 L
F
.804 .522 .247 r
.11343 .16187 m
.11343 .01993 L
.11381 .01993 L
.11381 .16187 L
s
1 .894 .882 r
.11381 .16187 m
.11381 .02 L
.11412 .02 L
.11412 .16187 L
F
.804 .522 .247 r
.11381 .16187 m
.11381 .02 L
.11412 .02 L
.11412 .16187 L
s
1 .894 .882 r
.11412 .16187 m
.11412 .02001 L
.11445 .02001 L
.11445 .16187 L
F
.804 .522 .247 r
.11412 .16187 m
.11412 .02001 L
.11445 .02001 L
.11445 .16187 L
s
1 .894 .882 r
.11445 .16187 m
.11445 .02006 L
.11468 .02006 L
.11468 .16187 L
F
.804 .522 .247 r
.11445 .16187 m
.11445 .02006 L
.11468 .02006 L
.11468 .16187 L
s
1 .894 .882 r
.11468 .16187 m
.11468 .02009 L
.11486 .02009 L
.11486 .16187 L
F
.804 .522 .247 r
.11468 .16187 m
.11468 .02009 L
.11486 .02009 L
.11486 .16187 L
s
1 .894 .882 r
.11486 .16187 m
.11486 .02014 L
.11534 .02014 L
.11534 .16187 L
F
.804 .522 .247 r
.11486 .16187 m
.11486 .02014 L
.11534 .02014 L
.11534 .16187 L
s
1 .894 .882 r
.11534 .16187 m
.11534 .02017 L
.11574 .02017 L
.11574 .16187 L
F
.804 .522 .247 r
.11534 .16187 m
.11534 .02017 L
.11574 .02017 L
.11574 .16187 L
s
1 .894 .882 r
.11574 .16187 m
.11574 .02021 L
.1161 .02021 L
.1161 .16187 L
F
.804 .522 .247 r
.11574 .16187 m
.11574 .02021 L
.1161 .02021 L
.1161 .16187 L
s
1 .894 .882 r
.1161 .16187 m
.1161 .02027 L
.11637 .02027 L
.11637 .16187 L
F
.804 .522 .247 r
.1161 .16187 m
.1161 .02027 L
.11637 .02027 L
.11637 .16187 L
s
1 .894 .882 r
.11637 .16187 m
.11637 .0203 L
.11669 .0203 L
.11669 .16187 L
F
.804 .522 .247 r
.11637 .16187 m
.11637 .0203 L
.11669 .0203 L
.11669 .16187 L
s
1 .894 .882 r
.11669 .16187 m
.11669 .02032 L
.11688 .02032 L
.11688 .16187 L
F
.804 .522 .247 r
.11669 .16187 m
.11669 .02032 L
.11688 .02032 L
.11688 .16187 L
s
1 .894 .882 r
.11688 .16187 m
.11688 .02034 L
.11718 .02034 L
.11718 .16187 L
F
.804 .522 .247 r
.11688 .16187 m
.11688 .02034 L
.11718 .02034 L
.11718 .16187 L
s
1 .894 .882 r
.11718 .16187 m
.11718 .0204 L
.11754 .0204 L
.11754 .16187 L
F
.804 .522 .247 r
.11718 .16187 m
.11718 .0204 L
.11754 .0204 L
.11754 .16187 L
s
1 .894 .882 r
.11754 .16187 m
.11754 .02046 L
.11794 .02046 L
.11794 .16187 L
F
.804 .522 .247 r
.11754 .16187 m
.11754 .02046 L
.11794 .02046 L
.11794 .16187 L
s
1 .894 .882 r
.11794 .16187 m
.11794 .0205 L
.11829 .0205 L
.11829 .16187 L
F
.804 .522 .247 r
.11794 .16187 m
.11794 .0205 L
.11829 .0205 L
.11829 .16187 L
s
1 .894 .882 r
.11829 .16187 m
.11829 .02052 L
.11854 .02052 L
.11854 .16187 L
F
.804 .522 .247 r
.11829 .16187 m
.11829 .02052 L
.11854 .02052 L
.11854 .16187 L
s
1 .894 .882 r
.11854 .16187 m
.11854 .02057 L
.11886 .02057 L
.11886 .16187 L
F
.804 .522 .247 r
.11854 .16187 m
.11854 .02057 L
.11886 .02057 L
.11886 .16187 L
s
1 .894 .882 r
.11886 .16187 m
.11886 .02058 L
.11901 .02058 L
.11901 .16187 L
F
.804 .522 .247 r
.11886 .16187 m
.11886 .02058 L
.11901 .02058 L
.11901 .16187 L
s
1 .894 .882 r
.11901 .16187 m
.11901 .0206 L
.11925 .0206 L
.11925 .16187 L
F
.804 .522 .247 r
.11901 .16187 m
.11901 .0206 L
.11925 .0206 L
.11925 .16187 L
s
1 .894 .882 r
.11925 .16187 m
.11925 .02067 L
.11969 .02067 L
.11969 .16187 L
F
.804 .522 .247 r
.11925 .16187 m
.11925 .02067 L
.11969 .02067 L
.11969 .16187 L
s
1 .894 .882 r
.11969 .16187 m
.11969 .0207 L
.12011 .0207 L
.12011 .16187 L
F
.804 .522 .247 r
.11969 .16187 m
.11969 .0207 L
.12011 .0207 L
.12011 .16187 L
s
1 .894 .882 r
.12011 .16187 m
.12011 .02077 L
.1205 .02077 L
.1205 .16187 L
F
.804 .522 .247 r
.12011 .16187 m
.12011 .02077 L
.1205 .02077 L
.1205 .16187 L
s
1 .894 .882 r
.1205 .16187 m
.1205 .02078 L
.1207 .02078 L
.1207 .16187 L
F
.804 .522 .247 r
.1205 .16187 m
.1205 .02078 L
.1207 .02078 L
.1207 .16187 L
s
1 .894 .882 r
.1207 .16187 m
.1207 .02082 L
.12109 .02082 L
.12109 .16187 L
F
.804 .522 .247 r
.1207 .16187 m
.1207 .02082 L
.12109 .02082 L
.12109 .16187 L
s
1 .894 .882 r
.12109 .16187 m
.12109 .02086 L
.12128 .02086 L
.12128 .16187 L
F
.804 .522 .247 r
.12109 .16187 m
.12109 .02086 L
.12128 .02086 L
.12128 .16187 L
s
1 .894 .882 r
.12128 .16187 m
.12128 .02088 L
.1215 .02088 L
.1215 .16187 L
F
.804 .522 .247 r
.12128 .16187 m
.12128 .02088 L
.1215 .02088 L
.1215 .16187 L
s
1 .894 .882 r
.1215 .16187 m
.1215 .02095 L
.12186 .02095 L
.12186 .16187 L
F
.804 .522 .247 r
.1215 .16187 m
.1215 .02095 L
.12186 .02095 L
.12186 .16187 L
s
1 .894 .882 r
.12186 .16187 m
.12186 .02095 L
.12217 .02095 L
.12217 .16187 L
F
.804 .522 .247 r
.12186 .16187 m
.12186 .02095 L
.12217 .02095 L
.12217 .16187 L
s
1 .894 .882 r
.12217 .16187 m
.12217 .02101 L
.12233 .02101 L
.12233 .16187 L
F
.804 .522 .247 r
.12217 .16187 m
.12217 .02101 L
.12233 .02101 L
.12233 .16187 L
s
1 .894 .882 r
.12233 .16187 m
.12233 .02102 L
.12256 .02102 L
.12256 .16187 L
F
.804 .522 .247 r
.12233 .16187 m
.12233 .02102 L
.12256 .02102 L
.12256 .16187 L
s
1 .894 .882 r
.12256 .16187 m
.12256 .02108 L
.12302 .02108 L
.12302 .16187 L
F
.804 .522 .247 r
.12256 .16187 m
.12256 .02108 L
.12302 .02108 L
.12302 .16187 L
s
1 .894 .882 r
.12302 .16187 m
.12302 .02115 L
.12346 .02115 L
.12346 .16187 L
F
.804 .522 .247 r
.12302 .16187 m
.12302 .02115 L
.12346 .02115 L
.12346 .16187 L
s
1 .894 .882 r
.12346 .16187 m
.12346 .0212 L
.12384 .0212 L
.12384 .16187 L
F
.804 .522 .247 r
.12346 .16187 m
.12346 .0212 L
.12384 .0212 L
.12384 .16187 L
s
1 .894 .882 r
.12384 .16187 m
.12384 .02124 L
.12425 .02124 L
.12425 .16187 L
F
.804 .522 .247 r
.12384 .16187 m
.12384 .02124 L
.12425 .02124 L
.12425 .16187 L
s
1 .894 .882 r
.12425 .16187 m
.12425 .02127 L
.12466 .02127 L
.12466 .16187 L
F
.804 .522 .247 r
.12425 .16187 m
.12425 .02127 L
.12466 .02127 L
.12466 .16187 L
s
1 .894 .882 r
.12466 .16187 m
.12466 .02134 L
.12495 .02134 L
.12495 .16187 L
F
.804 .522 .247 r
.12466 .16187 m
.12466 .02134 L
.12495 .02134 L
.12495 .16187 L
s
1 .894 .882 r
.12495 .16187 m
.12495 .02136 L
.12511 .02136 L
.12511 .16187 L
F
.804 .522 .247 r
.12495 .16187 m
.12495 .02136 L
.12511 .02136 L
.12511 .16187 L
s
1 .894 .882 r
.12511 .16187 m
.12511 .02139 L
.12527 .02139 L
.12527 .16187 L
F
.804 .522 .247 r
.12511 .16187 m
.12511 .02139 L
.12527 .02139 L
.12527 .16187 L
s
1 .894 .882 r
.12527 .16187 m
.12527 .02141 L
.12548 .02141 L
.12548 .16187 L
F
.804 .522 .247 r
.12527 .16187 m
.12527 .02141 L
.12548 .02141 L
.12548 .16187 L
s
1 .894 .882 r
.12548 .16187 m
.12548 .02143 L
.12567 .02143 L
.12567 .16187 L
F
.804 .522 .247 r
.12548 .16187 m
.12548 .02143 L
.12567 .02143 L
.12567 .16187 L
s
1 .894 .882 r
.12567 .16187 m
.12567 .02147 L
.12601 .02147 L
.12601 .16187 L
F
.804 .522 .247 r
.12567 .16187 m
.12567 .02147 L
.12601 .02147 L
.12601 .16187 L
s
1 .894 .882 r
.12601 .16187 m
.12601 .0215 L
.12616 .0215 L
.12616 .16187 L
F
.804 .522 .247 r
.12601 .16187 m
.12601 .0215 L
.12616 .0215 L
.12616 .16187 L
s
1 .894 .882 r
.12616 .16187 m
.12616 .02153 L
.12662 .02153 L
.12662 .16187 L
F
.804 .522 .247 r
.12616 .16187 m
.12616 .02153 L
.12662 .02153 L
.12662 .16187 L
s
1 .894 .882 r
.12662 .16187 m
.12662 .02159 L
.12686 .02159 L
.12686 .16187 L
F
.804 .522 .247 r
.12662 .16187 m
.12662 .02159 L
.12686 .02159 L
.12686 .16187 L
s
1 .894 .882 r
.12686 .16187 m
.12686 .02166 L
.12727 .02166 L
.12727 .16187 L
F
.804 .522 .247 r
.12686 .16187 m
.12686 .02166 L
.12727 .02166 L
.12727 .16187 L
s
1 .894 .882 r
.12727 .16187 m
.12727 .02168 L
.12754 .02168 L
.12754 .16187 L
F
.804 .522 .247 r
.12727 .16187 m
.12727 .02168 L
.12754 .02168 L
.12754 .16187 L
s
1 .894 .882 r
.12754 .16187 m
.12754 .02171 L
.12794 .02171 L
.12794 .16187 L
F
.804 .522 .247 r
.12754 .16187 m
.12754 .02171 L
.12794 .02171 L
.12794 .16187 L
s
1 .894 .882 r
.12794 .16187 m
.12794 .02175 L
.12828 .02175 L
.12828 .16187 L
F
.804 .522 .247 r
.12794 .16187 m
.12794 .02175 L
.12828 .02175 L
.12828 .16187 L
s
1 .894 .882 r
.12828 .16187 m
.12828 .02183 L
.12865 .02183 L
.12865 .16187 L
F
.804 .522 .247 r
.12828 .16187 m
.12828 .02183 L
.12865 .02183 L
.12865 .16187 L
s
1 .894 .882 r
.12865 .16187 m
.12865 .02186 L
.12884 .02186 L
.12884 .16187 L
F
.804 .522 .247 r
.12865 .16187 m
.12865 .02186 L
.12884 .02186 L
.12884 .16187 L
s
1 .894 .882 r
.12884 .16187 m
.12884 .02188 L
.12903 .02188 L
.12903 .16187 L
F
.804 .522 .247 r
.12884 .16187 m
.12884 .02188 L
.12903 .02188 L
.12903 .16187 L
s
1 .894 .882 r
.12903 .16187 m
.12903 .0219 L
.1292 .0219 L
.1292 .16187 L
F
.804 .522 .247 r
.12903 .16187 m
.12903 .0219 L
.1292 .0219 L
.1292 .16187 L
s
1 .894 .882 r
.1292 .16187 m
.1292 .02197 L
.12957 .02197 L
.12957 .16187 L
F
.804 .522 .247 r
.1292 .16187 m
.1292 .02197 L
.12957 .02197 L
.12957 .16187 L
s
1 .894 .882 r
.12957 .16187 m
.12957 .02199 L
.13002 .02199 L
.13002 .16187 L
F
.804 .522 .247 r
.12957 .16187 m
.12957 .02199 L
.13002 .02199 L
.13002 .16187 L
s
1 .894 .882 r
.13002 .16187 m
.13002 .02206 L
.13025 .02206 L
.13025 .16187 L
F
.804 .522 .247 r
.13002 .16187 m
.13002 .02206 L
.13025 .02206 L
.13025 .16187 L
s
1 .894 .882 r
.13025 .16187 m
.13025 .02207 L
.13046 .02207 L
.13046 .16187 L
F
.804 .522 .247 r
.13025 .16187 m
.13025 .02207 L
.13046 .02207 L
.13046 .16187 L
s
1 .894 .882 r
.13046 .16187 m
.13046 .02211 L
.13094 .02211 L
.13094 .16187 L
F
.804 .522 .247 r
.13046 .16187 m
.13046 .02211 L
.13094 .02211 L
.13094 .16187 L
s
1 .894 .882 r
.13094 .16187 m
.13094 .02218 L
.13114 .02218 L
.13114 .16187 L
F
.804 .522 .247 r
.13094 .16187 m
.13094 .02218 L
.13114 .02218 L
.13114 .16187 L
s
1 .894 .882 r
.13114 .16187 m
.13114 .02221 L
.13145 .02221 L
.13145 .16187 L
F
.804 .522 .247 r
.13114 .16187 m
.13114 .02221 L
.13145 .02221 L
.13145 .16187 L
s
1 .894 .882 r
.13145 .16187 m
.13145 .02226 L
.13186 .02226 L
.13186 .16187 L
F
.804 .522 .247 r
.13145 .16187 m
.13145 .02226 L
.13186 .02226 L
.13186 .16187 L
s
1 .894 .882 r
.13186 .16187 m
.13186 .02235 L
.13233 .02235 L
.13233 .16187 L
F
.804 .522 .247 r
.13186 .16187 m
.13186 .02235 L
.13233 .02235 L
.13233 .16187 L
s
1 .894 .882 r
.13233 .16187 m
.13233 .02236 L
.13251 .02236 L
.13251 .16187 L
F
.804 .522 .247 r
.13233 .16187 m
.13233 .02236 L
.13251 .02236 L
.13251 .16187 L
s
1 .894 .882 r
.13251 .16187 m
.13251 .02238 L
.13276 .02238 L
.13276 .16187 L
F
.804 .522 .247 r
.13251 .16187 m
.13251 .02238 L
.13276 .02238 L
.13276 .16187 L
s
1 .894 .882 r
.13276 .16187 m
.13276 .02243 L
.13314 .02243 L
.13314 .16187 L
F
.804 .522 .247 r
.13276 .16187 m
.13276 .02243 L
.13314 .02243 L
.13314 .16187 L
s
1 .894 .882 r
.13314 .16187 m
.13314 .02249 L
.1334 .02249 L
.1334 .16187 L
F
.804 .522 .247 r
.13314 .16187 m
.13314 .02249 L
.1334 .02249 L
.1334 .16187 L
s
1 .894 .882 r
.1334 .16187 m
.1334 .02252 L
.13358 .02252 L
.13358 .16187 L
F
.804 .522 .247 r
.1334 .16187 m
.1334 .02252 L
.13358 .02252 L
.13358 .16187 L
s
1 .894 .882 r
.13358 .16187 m
.13358 .02256 L
.13386 .02256 L
.13386 .16187 L
F
.804 .522 .247 r
.13358 .16187 m
.13358 .02256 L
.13386 .02256 L
.13386 .16187 L
s
1 .894 .882 r
.13386 .16187 m
.13386 .02261 L
.13415 .02261 L
.13415 .16187 L
F
.804 .522 .247 r
.13386 .16187 m
.13386 .02261 L
.13415 .02261 L
.13415 .16187 L
s
1 .894 .882 r
.13415 .16187 m
.13415 .02264 L
.1345 .02264 L
.1345 .16187 L
F
.804 .522 .247 r
.13415 .16187 m
.13415 .02264 L
.1345 .02264 L
.1345 .16187 L
s
1 .894 .882 r
.1345 .16187 m
.1345 .02272 L
.1349 .02272 L
.1349 .16187 L
F
.804 .522 .247 r
.1345 .16187 m
.1345 .02272 L
.1349 .02272 L
.1349 .16187 L
s
1 .894 .882 r
.1349 .16187 m
.1349 .02275 L
.13527 .02275 L
.13527 .16187 L
F
.804 .522 .247 r
.1349 .16187 m
.1349 .02275 L
.13527 .02275 L
.13527 .16187 L
s
1 .894 .882 r
.13527 .16187 m
.13527 .02283 L
.13571 .02283 L
.13571 .16187 L
F
.804 .522 .247 r
.13527 .16187 m
.13527 .02283 L
.13571 .02283 L
.13571 .16187 L
s
1 .894 .882 r
.13571 .16187 m
.13571 .0229 L
.13618 .0229 L
.13618 .16187 L
F
.804 .522 .247 r
.13571 .16187 m
.13571 .0229 L
.13618 .0229 L
.13618 .16187 L
s
1 .894 .882 r
.13618 .16187 m
.13618 .02293 L
.13654 .02293 L
.13654 .16187 L
F
.804 .522 .247 r
.13618 .16187 m
.13618 .02293 L
.13654 .02293 L
.13654 .16187 L
s
1 .894 .882 r
.13654 .16187 m
.13654 .02297 L
.13687 .02297 L
.13687 .16187 L
F
.804 .522 .247 r
.13654 .16187 m
.13654 .02297 L
.13687 .02297 L
.13687 .16187 L
s
1 .894 .882 r
.13687 .16187 m
.13687 .02305 L
.13729 .02305 L
.13729 .16187 L
F
.804 .522 .247 r
.13687 .16187 m
.13687 .02305 L
.13729 .02305 L
.13729 .16187 L
s
1 .894 .882 r
.13729 .16187 m
.13729 .0231 L
.13754 .0231 L
.13754 .16187 L
F
.804 .522 .247 r
.13729 .16187 m
.13729 .0231 L
.13754 .0231 L
.13754 .16187 L
s
1 .894 .882 r
.13754 .16187 m
.13754 .02312 L
.13794 .02312 L
.13794 .16187 L
F
.804 .522 .247 r
.13754 .16187 m
.13754 .02312 L
.13794 .02312 L
.13794 .16187 L
s
1 .894 .882 r
.13794 .16187 m
.13794 .02319 L
.13819 .02319 L
.13819 .16187 L
F
.804 .522 .247 r
.13794 .16187 m
.13794 .02319 L
.13819 .02319 L
.13819 .16187 L
s
1 .894 .882 r
.13819 .16187 m
.13819 .02323 L
.13854 .02323 L
.13854 .16187 L
F
.804 .522 .247 r
.13819 .16187 m
.13819 .02323 L
.13854 .02323 L
.13854 .16187 L
s
1 .894 .882 r
.13854 .16187 m
.13854 .02328 L
.1388 .02328 L
.1388 .16187 L
F
.804 .522 .247 r
.13854 .16187 m
.13854 .02328 L
.1388 .02328 L
.1388 .16187 L
s
1 .894 .882 r
.1388 .16187 m
.1388 .02332 L
.13916 .02332 L
.13916 .16187 L
F
.804 .522 .247 r
.1388 .16187 m
.1388 .02332 L
.13916 .02332 L
.13916 .16187 L
s
1 .894 .882 r
.13916 .16187 m
.13916 .02341 L
.13959 .02341 L
.13959 .16187 L
F
.804 .522 .247 r
.13916 .16187 m
.13916 .02341 L
.13959 .02341 L
.13959 .16187 L
s
1 .894 .882 r
.13959 .16187 m
.13959 .02341 L
.14001 .02341 L
.14001 .16187 L
F
.804 .522 .247 r
.13959 .16187 m
.13959 .02341 L
.14001 .02341 L
.14001 .16187 L
s
1 .894 .882 r
.14001 .16187 m
.14001 .02351 L
.1403 .02351 L
.1403 .16187 L
F
.804 .522 .247 r
.14001 .16187 m
.14001 .02351 L
.1403 .02351 L
.1403 .16187 L
s
1 .894 .882 r
.1403 .16187 m
.1403 .02354 L
.14063 .02354 L
.14063 .16187 L
F
.804 .522 .247 r
.1403 .16187 m
.1403 .02354 L
.14063 .02354 L
.14063 .16187 L
s
1 .894 .882 r
.14063 .16187 m
.14063 .02362 L
.14095 .02362 L
.14095 .16187 L
F
.804 .522 .247 r
.14063 .16187 m
.14063 .02362 L
.14095 .02362 L
.14095 .16187 L
s
1 .894 .882 r
.14095 .16187 m
.14095 .02364 L
.14115 .02364 L
.14115 .16187 L
F
.804 .522 .247 r
.14095 .16187 m
.14095 .02364 L
.14115 .02364 L
.14115 .16187 L
s
1 .894 .882 r
.14115 .16187 m
.14115 .02366 L
.14132 .02366 L
.14132 .16187 L
F
.804 .522 .247 r
.14115 .16187 m
.14115 .02366 L
.14132 .02366 L
.14132 .16187 L
s
1 .894 .882 r
.14132 .16187 m
.14132 .02371 L
.14162 .02371 L
.14162 .16187 L
F
.804 .522 .247 r
.14132 .16187 m
.14132 .02371 L
.14162 .02371 L
.14162 .16187 L
s
1 .894 .882 r
.14162 .16187 m
.14162 .02373 L
.1418 .02373 L
.1418 .16187 L
F
.804 .522 .247 r
.14162 .16187 m
.14162 .02373 L
.1418 .02373 L
.1418 .16187 L
s
1 .894 .882 r
.1418 .16187 m
.1418 .02381 L
.14221 .02381 L
.14221 .16187 L
F
.804 .522 .247 r
.1418 .16187 m
.1418 .02381 L
.14221 .02381 L
.14221 .16187 L
s
1 .894 .882 r
.14221 .16187 m
.14221 .02385 L
.14252 .02385 L
.14252 .16187 L
F
.804 .522 .247 r
.14221 .16187 m
.14221 .02385 L
.14252 .02385 L
.14252 .16187 L
s
1 .894 .882 r
.14252 .16187 m
.14252 .02391 L
.14291 .02391 L
.14291 .16187 L
F
.804 .522 .247 r
.14252 .16187 m
.14252 .02391 L
.14291 .02391 L
.14291 .16187 L
s
1 .894 .882 r
.14291 .16187 m
.14291 .02396 L
.14321 .02396 L
.14321 .16187 L
F
.804 .522 .247 r
.14291 .16187 m
.14291 .02396 L
.14321 .02396 L
.14321 .16187 L
s
1 .894 .882 r
.14321 .16187 m
.14321 .02398 L
.14367 .02398 L
.14367 .16187 L
F
.804 .522 .247 r
.14321 .16187 m
.14321 .02398 L
.14367 .02398 L
.14367 .16187 L
s
1 .894 .882 r
.14367 .16187 m
.14367 .02409 L
.14401 .02409 L
.14401 .16187 L
F
.804 .522 .247 r
.14367 .16187 m
.14367 .02409 L
.14401 .02409 L
.14401 .16187 L
s
1 .894 .882 r
.14401 .16187 m
.14401 .0241 L
.14418 .0241 L
.14418 .16187 L
F
.804 .522 .247 r
.14401 .16187 m
.14401 .0241 L
.14418 .0241 L
.14418 .16187 L
s
1 .894 .882 r
.14418 .16187 m
.14418 .02416 L
.14465 .02416 L
.14465 .16187 L
F
.804 .522 .247 r
.14418 .16187 m
.14418 .02416 L
.14465 .02416 L
.14465 .16187 L
s
1 .894 .882 r
.14465 .16187 m
.14465 .02421 L
.14484 .02421 L
.14484 .16187 L
F
.804 .522 .247 r
.14465 .16187 m
.14465 .02421 L
.14484 .02421 L
.14484 .16187 L
s
1 .894 .882 r
.14484 .16187 m
.14484 .02422 L
.14508 .02422 L
.14508 .16187 L
F
.804 .522 .247 r
.14484 .16187 m
.14484 .02422 L
.14508 .02422 L
.14508 .16187 L
s
1 .894 .882 r
.14508 .16187 m
.14508 .02427 L
.14534 .02427 L
.14534 .16187 L
F
.804 .522 .247 r
.14508 .16187 m
.14508 .02427 L
.14534 .02427 L
.14534 .16187 L
s
1 .894 .882 r
.14534 .16187 m
.14534 .02431 L
.1457 .02431 L
.1457 .16187 L
F
.804 .522 .247 r
.14534 .16187 m
.14534 .02431 L
.1457 .02431 L
.1457 .16187 L
s
1 .894 .882 r
.1457 .16187 m
.1457 .02441 L
.14604 .02441 L
.14604 .16187 L
F
.804 .522 .247 r
.1457 .16187 m
.1457 .02441 L
.14604 .02441 L
.14604 .16187 L
s
1 .894 .882 r
.14604 .16187 m
.14604 .02444 L
.14651 .02444 L
.14651 .16187 L
F
.804 .522 .247 r
.14604 .16187 m
.14604 .02444 L
.14651 .02444 L
.14651 .16187 L
s
1 .894 .882 r
.14651 .16187 m
.14651 .02454 L
.1469 .02454 L
.1469 .16187 L
F
.804 .522 .247 r
.14651 .16187 m
.14651 .02454 L
.1469 .02454 L
.1469 .16187 L
s
1 .894 .882 r
.1469 .16187 m
.1469 .02456 L
.14732 .02456 L
.14732 .16187 L
F
.804 .522 .247 r
.1469 .16187 m
.1469 .02456 L
.14732 .02456 L
.14732 .16187 L
s
1 .894 .882 r
.14732 .16187 m
.14732 .02468 L
.14773 .02468 L
.14773 .16187 L
F
.804 .522 .247 r
.14732 .16187 m
.14732 .02468 L
.14773 .02468 L
.14773 .16187 L
s
1 .894 .882 r
.14773 .16187 m
.14773 .02472 L
.14806 .02472 L
.14806 .16187 L
F
.804 .522 .247 r
.14773 .16187 m
.14773 .02472 L
.14806 .02472 L
.14806 .16187 L
s
1 .894 .882 r
.14806 .16187 m
.14806 .02475 L
.14827 .02475 L
.14827 .16187 L
F
.804 .522 .247 r
.14806 .16187 m
.14806 .02475 L
.14827 .02475 L
.14827 .16187 L
s
1 .894 .882 r
.14827 .16187 m
.14827 .02478 L
.14852 .02478 L
.14852 .16187 L
F
.804 .522 .247 r
.14827 .16187 m
.14827 .02478 L
.14852 .02478 L
.14852 .16187 L
s
1 .894 .882 r
.14852 .16187 m
.14852 .02482 L
.14887 .02482 L
.14887 .16187 L
F
.804 .522 .247 r
.14852 .16187 m
.14852 .02482 L
.14887 .02482 L
.14887 .16187 L
s
1 .894 .882 r
.14887 .16187 m
.14887 .02489 L
.14918 .02489 L
.14918 .16187 L
F
.804 .522 .247 r
.14887 .16187 m
.14887 .02489 L
.14918 .02489 L
.14918 .16187 L
s
1 .894 .882 r
.14918 .16187 m
.14918 .02496 L
.14959 .02496 L
.14959 .16187 L
F
.804 .522 .247 r
.14918 .16187 m
.14918 .02496 L
.14959 .02496 L
.14959 .16187 L
s
1 .894 .882 r
.14959 .16187 m
.14959 .02502 L
.1498 .02502 L
.1498 .16187 L
F
.804 .522 .247 r
.14959 .16187 m
.14959 .02502 L
.1498 .02502 L
.1498 .16187 L
s
1 .894 .882 r
.1498 .16187 m
.1498 .02503 L
.15023 .02503 L
.15023 .16187 L
F
.804 .522 .247 r
.1498 .16187 m
.1498 .02503 L
.15023 .02503 L
.15023 .16187 L
s
1 .894 .882 r
.15023 .16187 m
.15023 .02515 L
.15073 .02515 L
.15073 .16187 L
F
.804 .522 .247 r
.15023 .16187 m
.15023 .02515 L
.15073 .02515 L
.15073 .16187 L
s
1 .894 .882 r
.15073 .16187 m
.15073 .02519 L
.15089 .02519 L
.15089 .16187 L
F
.804 .522 .247 r
.15073 .16187 m
.15073 .02519 L
.15089 .02519 L
.15089 .16187 L
s
1 .894 .882 r
.15089 .16187 m
.15089 .02521 L
.15129 .02521 L
.15129 .16187 L
F
.804 .522 .247 r
.15089 .16187 m
.15089 .02521 L
.15129 .02521 L
.15129 .16187 L
s
1 .894 .882 r
.15129 .16187 m
.15129 .02527 L
.15176 .02527 L
.15176 .16187 L
F
.804 .522 .247 r
.15129 .16187 m
.15129 .02527 L
.15176 .02527 L
.15176 .16187 L
s
1 .894 .882 r
.15176 .16187 m
.15176 .02539 L
.15206 .02539 L
.15206 .16187 L
F
.804 .522 .247 r
.15176 .16187 m
.15176 .02539 L
.15206 .02539 L
.15206 .16187 L
s
1 .894 .882 r
.15206 .16187 m
.15206 .02542 L
.15255 .02542 L
.15255 .16187 L
F
.804 .522 .247 r
.15206 .16187 m
.15206 .02542 L
.15255 .02542 L
.15255 .16187 L
s
1 .894 .882 r
.15255 .16187 m
.15255 .02551 L
.15297 .02551 L
.15297 .16187 L
F
.804 .522 .247 r
.15255 .16187 m
.15255 .02551 L
.15297 .02551 L
.15297 .16187 L
s
1 .894 .882 r
.15297 .16187 m
.15297 .02558 L
.1534 .02558 L
.1534 .16187 L
F
.804 .522 .247 r
.15297 .16187 m
.15297 .02558 L
.1534 .02558 L
.1534 .16187 L
s
1 .894 .882 r
.1534 .16187 m
.1534 .02564 L
.15361 .02564 L
.15361 .16187 L
F
.804 .522 .247 r
.1534 .16187 m
.1534 .02564 L
.15361 .02564 L
.15361 .16187 L
s
1 .894 .882 r
.15361 .16187 m
.15361 .02565 L
.15399 .02565 L
.15399 .16187 L
F
.804 .522 .247 r
.15361 .16187 m
.15361 .02565 L
.15399 .02565 L
.15399 .16187 L
s
1 .894 .882 r
.15399 .16187 m
.15399 .02573 L
.15419 .02573 L
.15419 .16187 L
F
.804 .522 .247 r
.15399 .16187 m
.15399 .02573 L
.15419 .02573 L
.15419 .16187 L
s
1 .894 .882 r
.15419 .16187 m
.15419 .02577 L
.15443 .02577 L
.15443 .16187 L
F
.804 .522 .247 r
.15419 .16187 m
.15419 .02577 L
.15443 .02577 L
.15443 .16187 L
s
1 .894 .882 r
.15443 .16187 m
.15443 .0258 L
.15467 .0258 L
.15467 .16187 L
F
.804 .522 .247 r
.15443 .16187 m
.15443 .0258 L
.15467 .0258 L
.15467 .16187 L
s
1 .894 .882 r
.15467 .16187 m
.15467 .02583 L
.15514 .02583 L
.15514 .16187 L
F
.804 .522 .247 r
.15467 .16187 m
.15467 .02583 L
.15514 .02583 L
.15514 .16187 L
s
1 .894 .882 r
.15514 .16187 m
.15514 .02592 L
.15542 .02592 L
.15542 .16187 L
F
.804 .522 .247 r
.15514 .16187 m
.15514 .02592 L
.15542 .02592 L
.15542 .16187 L
s
1 .894 .882 r
.15542 .16187 m
.15542 .02599 L
.15574 .02599 L
.15574 .16187 L
F
.804 .522 .247 r
.15542 .16187 m
.15542 .02599 L
.15574 .02599 L
.15574 .16187 L
s
1 .894 .882 r
.15574 .16187 m
.15574 .02606 L
.15615 .02606 L
.15615 .16187 L
F
.804 .522 .247 r
.15574 .16187 m
.15574 .02606 L
.15615 .02606 L
.15615 .16187 L
s
1 .894 .882 r
.15615 .16187 m
.15615 .02612 L
.15655 .02612 L
.15655 .16187 L
F
.804 .522 .247 r
.15615 .16187 m
.15615 .02612 L
.15655 .02612 L
.15655 .16187 L
s
1 .894 .882 r
.15655 .16187 m
.15655 .02615 L
.15672 .02615 L
.15672 .16187 L
F
.804 .522 .247 r
.15655 .16187 m
.15655 .02615 L
.15672 .02615 L
.15672 .16187 L
s
1 .894 .882 r
.15672 .16187 m
.15672 .02621 L
.15719 .02621 L
.15719 .16187 L
F
.804 .522 .247 r
.15672 .16187 m
.15672 .02621 L
.15719 .02621 L
.15719 .16187 L
s
1 .894 .882 r
.15719 .16187 m
.15719 .02627 L
.15743 .02627 L
.15743 .16187 L
F
.804 .522 .247 r
.15719 .16187 m
.15719 .02627 L
.15743 .02627 L
.15743 .16187 L
s
1 .894 .882 r
.15743 .16187 m
.15743 .02637 L
.15792 .02637 L
.15792 .16187 L
F
.804 .522 .247 r
.15743 .16187 m
.15743 .02637 L
.15792 .02637 L
.15792 .16187 L
s
1 .894 .882 r
.15792 .16187 m
.15792 .02639 L
.15837 .02639 L
.15837 .16187 L
F
.804 .522 .247 r
.15792 .16187 m
.15792 .02639 L
.15837 .02639 L
.15837 .16187 L
s
1 .894 .882 r
.15837 .16187 m
.15837 .02647 L
.15856 .02647 L
.15856 .16187 L
F
.804 .522 .247 r
.15837 .16187 m
.15837 .02647 L
.15856 .02647 L
.15856 .16187 L
s
1 .894 .882 r
.15856 .16187 m
.15856 .02651 L
.1588 .02651 L
.1588 .16187 L
F
.804 .522 .247 r
.15856 .16187 m
.15856 .02651 L
.1588 .02651 L
.1588 .16187 L
s
1 .894 .882 r
.1588 .16187 m
.1588 .02662 L
.15927 .02662 L
.15927 .16187 L
F
.804 .522 .247 r
.1588 .16187 m
.1588 .02662 L
.15927 .02662 L
.15927 .16187 L
s
1 .894 .882 r
.15927 .16187 m
.15927 .02665 L
.15947 .02665 L
.15947 .16187 L
F
.804 .522 .247 r
.15927 .16187 m
.15927 .02665 L
.15947 .02665 L
.15947 .16187 L
s
1 .894 .882 r
.15947 .16187 m
.15947 .02666 L
.15967 .02666 L
.15967 .16187 L
F
.804 .522 .247 r
.15947 .16187 m
.15947 .02666 L
.15967 .02666 L
.15967 .16187 L
s
1 .894 .882 r
.15967 .16187 m
.15967 .02672 L
.1601 .02672 L
.1601 .16187 L
F
.804 .522 .247 r
.15967 .16187 m
.15967 .02672 L
.1601 .02672 L
.1601 .16187 L
s
1 .894 .882 r
.1601 .16187 m
.1601 .02682 L
.16058 .02682 L
.16058 .16187 L
F
.804 .522 .247 r
.1601 .16187 m
.1601 .02682 L
.16058 .02682 L
.16058 .16187 L
s
1 .894 .882 r
.16058 .16187 m
.16058 .02686 L
.16085 .02686 L
.16085 .16187 L
F
.804 .522 .247 r
.16058 .16187 m
.16058 .02686 L
.16085 .02686 L
.16085 .16187 L
s
1 .894 .882 r
.16085 .16187 m
.16085 .02693 L
.16112 .02693 L
.16112 .16187 L
F
.804 .522 .247 r
.16085 .16187 m
.16085 .02693 L
.16112 .02693 L
.16112 .16187 L
s
1 .894 .882 r
.16112 .16187 m
.16112 .02698 L
.16148 .02698 L
.16148 .16187 L
F
.804 .522 .247 r
.16112 .16187 m
.16112 .02698 L
.16148 .02698 L
.16148 .16187 L
s
1 .894 .882 r
.16148 .16187 m
.16148 .02704 L
.16173 .02704 L
.16173 .16187 L
F
.804 .522 .247 r
.16148 .16187 m
.16148 .02704 L
.16173 .02704 L
.16173 .16187 L
s
1 .894 .882 r
.16173 .16187 m
.16173 .02709 L
.16195 .02709 L
.16195 .16187 L
F
.804 .522 .247 r
.16173 .16187 m
.16173 .02709 L
.16195 .02709 L
.16195 .16187 L
s
1 .894 .882 r
.16195 .16187 m
.16195 .02713 L
.16213 .02713 L
.16213 .16187 L
F
.804 .522 .247 r
.16195 .16187 m
.16195 .02713 L
.16213 .02713 L
.16213 .16187 L
s
1 .894 .882 r
.16213 .16187 m
.16213 .02714 L
.1624 .02714 L
.1624 .16187 L
F
.804 .522 .247 r
.16213 .16187 m
.16213 .02714 L
.1624 .02714 L
.1624 .16187 L
s
1 .894 .882 r
.1624 .16187 m
.1624 .0272 L
.16267 .0272 L
.16267 .16187 L
F
.804 .522 .247 r
.1624 .16187 m
.1624 .0272 L
.16267 .0272 L
.16267 .16187 L
s
1 .894 .882 r
.16267 .16187 m
.16267 .02727 L
.1631 .02727 L
.1631 .16187 L
F
.804 .522 .247 r
.16267 .16187 m
.16267 .02727 L
.1631 .02727 L
.1631 .16187 L
s
1 .894 .882 r
.1631 .16187 m
.1631 .02733 L
.16344 .02733 L
.16344 .16187 L
F
.804 .522 .247 r
.1631 .16187 m
.1631 .02733 L
.16344 .02733 L
.16344 .16187 L
s
1 .894 .882 r
.16344 .16187 m
.16344 .0274 L
.16381 .0274 L
.16381 .16187 L
F
.804 .522 .247 r
.16344 .16187 m
.16344 .0274 L
.16381 .0274 L
.16381 .16187 L
s
1 .894 .882 r
.16381 .16187 m
.16381 .02749 L
.16416 .02749 L
.16416 .16187 L
F
.804 .522 .247 r
.16381 .16187 m
.16381 .02749 L
.16416 .02749 L
.16416 .16187 L
s
1 .894 .882 r
.16416 .16187 m
.16416 .02754 L
.16457 .02754 L
.16457 .16187 L
F
.804 .522 .247 r
.16416 .16187 m
.16416 .02754 L
.16457 .02754 L
.16457 .16187 L
s
1 .894 .882 r
.16457 .16187 m
.16457 .02764 L
.16494 .02764 L
.16494 .16187 L
F
.804 .522 .247 r
.16457 .16187 m
.16457 .02764 L
.16494 .02764 L
.16494 .16187 L
s
1 .894 .882 r
.16494 .16187 m
.16494 .02765 L
.16521 .02765 L
.16521 .16187 L
F
.804 .522 .247 r
.16494 .16187 m
.16494 .02765 L
.16521 .02765 L
.16521 .16187 L
s
1 .894 .882 r
.16521 .16187 m
.16521 .0277 L
.16557 .0277 L
.16557 .16187 L
F
.804 .522 .247 r
.16521 .16187 m
.16521 .0277 L
.16557 .0277 L
.16557 .16187 L
s
1 .894 .882 r
.16557 .16187 m
.16557 .02779 L
.16601 .02779 L
.16601 .16187 L
F
.804 .522 .247 r
.16557 .16187 m
.16557 .02779 L
.16601 .02779 L
.16601 .16187 L
s
1 .894 .882 r
.16601 .16187 m
.16601 .02789 L
.16634 .02789 L
.16634 .16187 L
F
.804 .522 .247 r
.16601 .16187 m
.16601 .02789 L
.16634 .02789 L
.16634 .16187 L
s
1 .894 .882 r
.16634 .16187 m
.16634 .02793 L
.16652 .02793 L
.16652 .16187 L
F
.804 .522 .247 r
.16634 .16187 m
.16634 .02793 L
.16652 .02793 L
.16652 .16187 L
s
1 .894 .882 r
.16652 .16187 m
.16652 .02795 L
.16691 .02795 L
.16691 .16187 L
F
.804 .522 .247 r
.16652 .16187 m
.16652 .02795 L
.16691 .02795 L
.16691 .16187 L
s
1 .894 .882 r
.16691 .16187 m
.16691 .02805 L
.1673 .02805 L
.1673 .16187 L
F
.804 .522 .247 r
.16691 .16187 m
.16691 .02805 L
.1673 .02805 L
.1673 .16187 L
s
1 .894 .882 r
.1673 .16187 m
.1673 .02812 L
.16757 .02812 L
.16757 .16187 L
F
.804 .522 .247 r
.1673 .16187 m
.1673 .02812 L
.16757 .02812 L
.16757 .16187 L
s
1 .894 .882 r
.16757 .16187 m
.16757 .02816 L
.16781 .02816 L
.16781 .16187 L
F
.804 .522 .247 r
.16757 .16187 m
.16757 .02816 L
.16781 .02816 L
.16781 .16187 L
s
1 .894 .882 r
.16781 .16187 m
.16781 .02822 L
.16821 .02822 L
.16821 .16187 L
F
.804 .522 .247 r
.16781 .16187 m
.16781 .02822 L
.16821 .02822 L
.16821 .16187 L
s
1 .894 .882 r
.16821 .16187 m
.16821 .02827 L
.16848 .02827 L
.16848 .16187 L
F
.804 .522 .247 r
.16821 .16187 m
.16821 .02827 L
.16848 .02827 L
.16848 .16187 L
s
1 .894 .882 r
.16848 .16187 m
.16848 .02831 L
.16863 .02831 L
.16863 .16187 L
F
.804 .522 .247 r
.16848 .16187 m
.16848 .02831 L
.16863 .02831 L
.16863 .16187 L
s
1 .894 .882 r
.16863 .16187 m
.16863 .02833 L
.169 .02833 L
.169 .16187 L
F
.804 .522 .247 r
.16863 .16187 m
.16863 .02833 L
.169 .02833 L
.169 .16187 L
s
1 .894 .882 r
.169 .16187 m
.169 .0284 L
.1693 .0284 L
.1693 .16187 L
F
.804 .522 .247 r
.169 .16187 m
.169 .0284 L
.1693 .0284 L
.1693 .16187 L
s
1 .894 .882 r
.1693 .16187 m
.1693 .02848 L
.1695 .02848 L
.1695 .16187 L
F
.804 .522 .247 r
.1693 .16187 m
.1693 .02848 L
.1695 .02848 L
.1695 .16187 L
s
1 .894 .882 r
.1695 .16187 m
.1695 .02853 L
.16997 .02853 L
.16997 .16187 L
F
.804 .522 .247 r
.1695 .16187 m
.1695 .02853 L
.16997 .02853 L
.16997 .16187 L
s
1 .894 .882 r
.16997 .16187 m
.16997 .02862 L
.17021 .02862 L
.17021 .16187 L
F
.804 .522 .247 r
.16997 .16187 m
.16997 .02862 L
.17021 .02862 L
.17021 .16187 L
s
1 .894 .882 r
.17021 .16187 m
.17021 .02865 L
.17039 .02865 L
.17039 .16187 L
F
.804 .522 .247 r
.17021 .16187 m
.17021 .02865 L
.17039 .02865 L
.17039 .16187 L
s
1 .894 .882 r
.17039 .16187 m
.17039 .02866 L
.17065 .02866 L
.17065 .16187 L
F
.804 .522 .247 r
.17039 .16187 m
.17039 .02866 L
.17065 .02866 L
.17065 .16187 L
s
1 .894 .882 r
.17065 .16187 m
.17065 .02871 L
.17092 .02871 L
.17092 .16187 L
F
.804 .522 .247 r
.17065 .16187 m
.17065 .02871 L
.17092 .02871 L
.17092 .16187 L
s
1 .894 .882 r
.17092 .16187 m
.17092 .0288 L
.17129 .0288 L
.17129 .16187 L
F
.804 .522 .247 r
.17092 .16187 m
.17092 .0288 L
.17129 .0288 L
.17129 .16187 L
s
1 .894 .882 r
.17129 .16187 m
.17129 .02888 L
.17161 .02888 L
.17161 .16187 L
F
.804 .522 .247 r
.17129 .16187 m
.17129 .02888 L
.17161 .02888 L
.17161 .16187 L
s
1 .894 .882 r
.17161 .16187 m
.17161 .02893 L
.17195 .02893 L
.17195 .16187 L
F
.804 .522 .247 r
.17161 .16187 m
.17161 .02893 L
.17195 .02893 L
.17195 .16187 L
s
1 .894 .882 r
.17195 .16187 m
.17195 .02896 L
.17235 .02896 L
.17235 .16187 L
F
.804 .522 .247 r
.17195 .16187 m
.17195 .02896 L
.17235 .02896 L
.17235 .16187 L
s
1 .894 .882 r
.17235 .16187 m
.17235 .02904 L
.17259 .02904 L
.17259 .16187 L
F
.804 .522 .247 r
.17235 .16187 m
.17235 .02904 L
.17259 .02904 L
.17259 .16187 L
s
1 .894 .882 r
.17259 .16187 m
.17259 .02914 L
.17304 .02914 L
.17304 .16187 L
F
.804 .522 .247 r
.17259 .16187 m
.17259 .02914 L
.17304 .02914 L
.17304 .16187 L
s
1 .894 .882 r
.17304 .16187 m
.17304 .02918 L
.17343 .02918 L
.17343 .16187 L
F
.804 .522 .247 r
.17304 .16187 m
.17304 .02918 L
.17343 .02918 L
.17343 .16187 L
s
1 .894 .882 r
.17343 .16187 m
.17343 .02925 L
.17365 .02925 L
.17365 .16187 L
F
.804 .522 .247 r
.17343 .16187 m
.17343 .02925 L
.17365 .02925 L
.17365 .16187 L
s
1 .894 .882 r
.17365 .16187 m
.17365 .02929 L
.17386 .02929 L
.17386 .16187 L
F
.804 .522 .247 r
.17365 .16187 m
.17365 .02929 L
.17386 .02929 L
.17386 .16187 L
s
1 .894 .882 r
.17386 .16187 m
.17386 .02934 L
.17407 .02934 L
.17407 .16187 L
F
.804 .522 .247 r
.17386 .16187 m
.17386 .02934 L
.17407 .02934 L
.17407 .16187 L
s
1 .894 .882 r
.17407 .16187 m
.17407 .02941 L
.17457 .02941 L
.17457 .16187 L
F
.804 .522 .247 r
.17407 .16187 m
.17407 .02941 L
.17457 .02941 L
.17457 .16187 L
s
1 .894 .882 r
.17457 .16187 m
.17457 .0295 L
.175 .0295 L
.175 .16187 L
F
.804 .522 .247 r
.17457 .16187 m
.17457 .0295 L
.175 .0295 L
.175 .16187 L
s
1 .894 .882 r
.175 .16187 m
.175 .0296 L
.17547 .0296 L
.17547 .16187 L
F
.804 .522 .247 r
.175 .16187 m
.175 .0296 L
.17547 .0296 L
.17547 .16187 L
s
1 .894 .882 r
.17547 .16187 m
.17547 .02969 L
.17577 .02969 L
.17577 .16187 L
F
.804 .522 .247 r
.17547 .16187 m
.17547 .02969 L
.17577 .02969 L
.17577 .16187 L
s
1 .894 .882 r
.17577 .16187 m
.17577 .0297 L
.17614 .0297 L
.17614 .16187 L
F
.804 .522 .247 r
.17577 .16187 m
.17577 .0297 L
.17614 .0297 L
.17614 .16187 L
s
1 .894 .882 r
.17614 .16187 m
.17614 .02978 L
.17657 .02978 L
.17657 .16187 L
F
.804 .522 .247 r
.17614 .16187 m
.17614 .02978 L
.17657 .02978 L
.17657 .16187 L
s
1 .894 .882 r
.17657 .16187 m
.17657 .02988 L
.17682 .02988 L
.17682 .16187 L
F
.804 .522 .247 r
.17657 .16187 m
.17657 .02988 L
.17682 .02988 L
.17682 .16187 L
s
1 .894 .882 r
.17682 .16187 m
.17682 .02993 L
.17697 .02993 L
.17697 .16187 L
F
.804 .522 .247 r
.17682 .16187 m
.17682 .02993 L
.17697 .02993 L
.17697 .16187 L
s
1 .894 .882 r
.17697 .16187 m
.17697 .02996 L
.17728 .02996 L
.17728 .16187 L
F
.804 .522 .247 r
.17697 .16187 m
.17697 .02996 L
.17728 .02996 L
.17728 .16187 L
s
1 .894 .882 r
.17728 .16187 m
.17728 .03006 L
.17774 .03006 L
.17774 .16187 L
F
.804 .522 .247 r
.17728 .16187 m
.17728 .03006 L
.17774 .03006 L
.17774 .16187 L
s
1 .894 .882 r
.17774 .16187 m
.17774 .03011 L
.17789 .03011 L
.17789 .16187 L
F
.804 .522 .247 r
.17774 .16187 m
.17774 .03011 L
.17789 .03011 L
.17789 .16187 L
s
1 .894 .882 r
.17789 .16187 m
.17789 .03021 L
.17836 .03021 L
.17836 .16187 L
F
.804 .522 .247 r
.17789 .16187 m
.17789 .03021 L
.17836 .03021 L
.17836 .16187 L
s
1 .894 .882 r
.17836 .16187 m
.17836 .03023 L
.17856 .03023 L
.17856 .16187 L
F
.804 .522 .247 r
.17836 .16187 m
.17836 .03023 L
.17856 .03023 L
.17856 .16187 L
s
1 .894 .882 r
.17856 .16187 m
.17856 .03029 L
.1789 .03029 L
.1789 .16187 L
F
.804 .522 .247 r
.17856 .16187 m
.17856 .03029 L
.1789 .03029 L
.1789 .16187 L
s
1 .894 .882 r
.1789 .16187 m
.1789 .03038 L
.17917 .03038 L
.17917 .16187 L
F
.804 .522 .247 r
.1789 .16187 m
.1789 .03038 L
.17917 .03038 L
.17917 .16187 L
s
1 .894 .882 r
.17917 .16187 m
.17917 .03039 L
.17946 .03039 L
.17946 .16187 L
F
.804 .522 .247 r
.17917 .16187 m
.17917 .03039 L
.17946 .03039 L
.17946 .16187 L
s
1 .894 .882 r
.17946 .16187 m
.17946 .03048 L
.17982 .03048 L
.17982 .16187 L
F
.804 .522 .247 r
.17946 .16187 m
.17946 .03048 L
.17982 .03048 L
.17982 .16187 L
s
1 .894 .882 r
.17982 .16187 m
.17982 .03055 L
.18025 .03055 L
.18025 .16187 L
F
.804 .522 .247 r
.17982 .16187 m
.17982 .03055 L
.18025 .03055 L
.18025 .16187 L
s
1 .894 .882 r
.18025 .16187 m
.18025 .03062 L
.18042 .03062 L
.18042 .16187 L
F
.804 .522 .247 r
.18025 .16187 m
.18025 .03062 L
.18042 .03062 L
.18042 .16187 L
s
1 .894 .882 r
.18042 .16187 m
.18042 .03067 L
.18076 .03067 L
.18076 .16187 L
F
.804 .522 .247 r
.18042 .16187 m
.18042 .03067 L
.18076 .03067 L
.18076 .16187 L
s
1 .894 .882 r
.18076 .16187 m
.18076 .03075 L
.18121 .03075 L
.18121 .16187 L
F
.804 .522 .247 r
.18076 .16187 m
.18076 .03075 L
.18121 .03075 L
.18121 .16187 L
s
1 .894 .882 r
.18121 .16187 m
.18121 .03081 L
.18158 .03081 L
.18158 .16187 L
F
.804 .522 .247 r
.18121 .16187 m
.18121 .03081 L
.18158 .03081 L
.18158 .16187 L
s
1 .894 .882 r
.18158 .16187 m
.18158 .03092 L
.18203 .03092 L
.18203 .16187 L
F
.804 .522 .247 r
.18158 .16187 m
.18158 .03092 L
.18203 .03092 L
.18203 .16187 L
s
1 .894 .882 r
.18203 .16187 m
.18203 .03097 L
.1823 .03097 L
.1823 .16187 L
F
.804 .522 .247 r
.18203 .16187 m
.18203 .03097 L
.1823 .03097 L
.1823 .16187 L
s
1 .894 .882 r
.1823 .16187 m
.1823 .03111 L
.18276 .03111 L
.18276 .16187 L
F
.804 .522 .247 r
.1823 .16187 m
.1823 .03111 L
.18276 .03111 L
.18276 .16187 L
s
1 .894 .882 r
.18276 .16187 m
.18276 .03119 L
.18319 .03119 L
.18319 .16187 L
F
.804 .522 .247 r
.18276 .16187 m
.18276 .03119 L
.18319 .03119 L
.18319 .16187 L
s
1 .894 .882 r
.18319 .16187 m
.18319 .03129 L
.18366 .03129 L
.18366 .16187 L
F
.804 .522 .247 r
.18319 .16187 m
.18319 .03129 L
.18366 .03129 L
.18366 .16187 L
s
1 .894 .882 r
.18366 .16187 m
.18366 .03133 L
.18412 .03133 L
.18412 .16187 L
F
.804 .522 .247 r
.18366 .16187 m
.18366 .03133 L
.18412 .03133 L
.18412 .16187 L
s
1 .894 .882 r
.18412 .16187 m
.18412 .03144 L
.18435 .03144 L
.18435 .16187 L
F
.804 .522 .247 r
.18412 .16187 m
.18412 .03144 L
.18435 .03144 L
.18435 .16187 L
s
1 .894 .882 r
.18435 .16187 m
.18435 .03147 L
.1845 .03147 L
.1845 .16187 L
F
.804 .522 .247 r
.18435 .16187 m
.18435 .03147 L
.1845 .03147 L
.1845 .16187 L
s
1 .894 .882 r
.1845 .16187 m
.1845 .03151 L
.18487 .03151 L
.18487 .16187 L
F
.804 .522 .247 r
.1845 .16187 m
.1845 .03151 L
.18487 .03151 L
.18487 .16187 L
s
1 .894 .882 r
.18487 .16187 m
.18487 .03161 L
.18533 .03161 L
.18533 .16187 L
F
.804 .522 .247 r
.18487 .16187 m
.18487 .03161 L
.18533 .03161 L
.18533 .16187 L
s
1 .894 .882 r
.18533 .16187 m
.18533 .03169 L
.18573 .03169 L
.18573 .16187 L
F
.804 .522 .247 r
.18533 .16187 m
.18533 .03169 L
.18573 .03169 L
.18573 .16187 L
s
1 .894 .882 r
.18573 .16187 m
.18573 .03174 L
.18592 .03174 L
.18592 .16187 L
F
.804 .522 .247 r
.18573 .16187 m
.18573 .03174 L
.18592 .03174 L
.18592 .16187 L
s
1 .894 .882 r
.18592 .16187 m
.18592 .03184 L
.18628 .03184 L
.18628 .16187 L
F
.804 .522 .247 r
.18592 .16187 m
.18592 .03184 L
.18628 .03184 L
.18628 .16187 L
s
1 .894 .882 r
.18628 .16187 m
.18628 .03187 L
.18643 .03187 L
.18643 .16187 L
F
.804 .522 .247 r
.18628 .16187 m
.18628 .03187 L
.18643 .03187 L
.18643 .16187 L
s
1 .894 .882 r
.18643 .16187 m
.18643 .0319 L
.18678 .0319 L
.18678 .16187 L
F
.804 .522 .247 r
.18643 .16187 m
.18643 .0319 L
.18678 .0319 L
.18678 .16187 L
s
1 .894 .882 r
.18678 .16187 m
.18678 .032 L
.18712 .032 L
.18712 .16187 L
F
.804 .522 .247 r
.18678 .16187 m
.18678 .032 L
.18712 .032 L
.18712 .16187 L
s
1 .894 .882 r
.18712 .16187 m
.18712 .03207 L
.18735 .03207 L
.18735 .16187 L
F
.804 .522 .247 r
.18712 .16187 m
.18712 .03207 L
.18735 .03207 L
.18735 .16187 L
s
1 .894 .882 r
.18735 .16187 m
.18735 .03211 L
.1877 .03211 L
.1877 .16187 L
F
.804 .522 .247 r
.18735 .16187 m
.18735 .03211 L
.1877 .03211 L
.1877 .16187 L
s
1 .894 .882 r
.1877 .16187 m
.1877 .03221 L
.18819 .03221 L
.18819 .16187 L
F
.804 .522 .247 r
.1877 .16187 m
.1877 .03221 L
.18819 .03221 L
.18819 .16187 L
s
1 .894 .882 r
.18819 .16187 m
.18819 .03227 L
.18859 .03227 L
.18859 .16187 L
F
.804 .522 .247 r
.18819 .16187 m
.18819 .03227 L
.18859 .03227 L
.18859 .16187 L
s
1 .894 .882 r
.18859 .16187 m
.18859 .03234 L
.1888 .03234 L
.1888 .16187 L
F
.804 .522 .247 r
.18859 .16187 m
.18859 .03234 L
.1888 .03234 L
.1888 .16187 L
s
1 .894 .882 r
.1888 .16187 m
.1888 .03241 L
.18896 .03241 L
.18896 .16187 L
F
.804 .522 .247 r
.1888 .16187 m
.1888 .03241 L
.18896 .03241 L
.18896 .16187 L
s
1 .894 .882 r
.18896 .16187 m
.18896 .03242 L
.18914 .03242 L
.18914 .16187 L
F
.804 .522 .247 r
.18896 .16187 m
.18896 .03242 L
.18914 .03242 L
.18914 .16187 L
s
1 .894 .882 r
.18914 .16187 m
.18914 .03249 L
.18932 .03249 L
.18932 .16187 L
F
.804 .522 .247 r
.18914 .16187 m
.18914 .03249 L
.18932 .03249 L
.18932 .16187 L
s
1 .894 .882 r
.18932 .16187 m
.18932 .03253 L
.18958 .03253 L
.18958 .16187 L
F
.804 .522 .247 r
.18932 .16187 m
.18932 .03253 L
.18958 .03253 L
.18958 .16187 L
s
1 .894 .882 r
.18958 .16187 m
.18958 .03261 L
.18995 .03261 L
.18995 .16187 L
F
.804 .522 .247 r
.18958 .16187 m
.18958 .03261 L
.18995 .03261 L
.18995 .16187 L
s
1 .894 .882 r
.18995 .16187 m
.18995 .03264 L
.19017 .03264 L
.19017 .16187 L
F
.804 .522 .247 r
.18995 .16187 m
.18995 .03264 L
.19017 .03264 L
.19017 .16187 L
s
1 .894 .882 r
.19017 .16187 m
.19017 .03268 L
.19041 .03268 L
.19041 .16187 L
F
.804 .522 .247 r
.19017 .16187 m
.19017 .03268 L
.19041 .03268 L
.19041 .16187 L
s
1 .894 .882 r
.19041 .16187 m
.19041 .03277 L
.19069 .03277 L
.19069 .16187 L
F
.804 .522 .247 r
.19041 .16187 m
.19041 .03277 L
.19069 .03277 L
.19069 .16187 L
s
1 .894 .882 r
.19069 .16187 m
.19069 .03282 L
.1911 .03282 L
.1911 .16187 L
F
.804 .522 .247 r
.19069 .16187 m
.19069 .03282 L
.1911 .03282 L
.1911 .16187 L
s
1 .894 .882 r
.1911 .16187 m
.1911 .0329 L
.19158 .0329 L
.19158 .16187 L
F
.804 .522 .247 r
.1911 .16187 m
.1911 .0329 L
.19158 .0329 L
.19158 .16187 L
s
1 .894 .882 r
.19158 .16187 m
.19158 .033 L
.19182 .033 L
.19182 .16187 L
F
.804 .522 .247 r
.19158 .16187 m
.19158 .033 L
.19182 .033 L
.19182 .16187 L
s
1 .894 .882 r
.19182 .16187 m
.19182 .03305 L
.19222 .03305 L
.19222 .16187 L
F
.804 .522 .247 r
.19182 .16187 m
.19182 .03305 L
.19222 .03305 L
.19222 .16187 L
s
1 .894 .882 r
.19222 .16187 m
.19222 .03319 L
.19266 .03319 L
.19266 .16187 L
F
.804 .522 .247 r
.19222 .16187 m
.19222 .03319 L
.19266 .03319 L
.19266 .16187 L
s
1 .894 .882 r
.19266 .16187 m
.19266 .03325 L
.19289 .03325 L
.19289 .16187 L
F
.804 .522 .247 r
.19266 .16187 m
.19266 .03325 L
.19289 .03325 L
.19289 .16187 L
s
1 .894 .882 r
.19289 .16187 m
.19289 .03327 L
.19308 .03327 L
.19308 .16187 L
F
.804 .522 .247 r
.19289 .16187 m
.19289 .03327 L
.19308 .03327 L
.19308 .16187 L
s
1 .894 .882 r
.19308 .16187 m
.19308 .03332 L
.19328 .03332 L
.19328 .16187 L
F
.804 .522 .247 r
.19308 .16187 m
.19308 .03332 L
.19328 .03332 L
.19328 .16187 L
s
1 .894 .882 r
.19328 .16187 m
.19328 .03345 L
.1937 .03345 L
.1937 .16187 L
F
.804 .522 .247 r
.19328 .16187 m
.19328 .03345 L
.1937 .03345 L
.1937 .16187 L
s
1 .894 .882 r
.1937 .16187 m
.1937 .03348 L
.19408 .03348 L
.19408 .16187 L
F
.804 .522 .247 r
.1937 .16187 m
.1937 .03348 L
.19408 .03348 L
.19408 .16187 L
s
1 .894 .882 r
.19408 .16187 m
.19408 .03356 L
.19443 .03356 L
.19443 .16187 L
F
.804 .522 .247 r
.19408 .16187 m
.19408 .03356 L
.19443 .03356 L
.19443 .16187 L
s
1 .894 .882 r
.19443 .16187 m
.19443 .03364 L
.19488 .03364 L
.19488 .16187 L
F
.804 .522 .247 r
.19443 .16187 m
.19443 .03364 L
.19488 .03364 L
.19488 .16187 L
s
1 .894 .882 r
.19488 .16187 m
.19488 .03373 L
.1951 .03373 L
.1951 .16187 L
F
.804 .522 .247 r
.19488 .16187 m
.19488 .03373 L
.1951 .03373 L
.1951 .16187 L
s
1 .894 .882 r
.1951 .16187 m
.1951 .03382 L
.19549 .03382 L
.19549 .16187 L
F
.804 .522 .247 r
.1951 .16187 m
.1951 .03382 L
.19549 .03382 L
.19549 .16187 L
s
1 .894 .882 r
.19549 .16187 m
.19549 .03386 L
.19593 .03386 L
.19593 .16187 L
F
.804 .522 .247 r
.19549 .16187 m
.19549 .03386 L
.19593 .03386 L
.19593 .16187 L
s
1 .894 .882 r
.19593 .16187 m
.19593 .03395 L
.19631 .03395 L
.19631 .16187 L
F
.804 .522 .247 r
.19593 .16187 m
.19593 .03395 L
.19631 .03395 L
.19631 .16187 L
s
1 .894 .882 r
.19631 .16187 m
.19631 .03406 L
.19652 .03406 L
.19652 .16187 L
F
.804 .522 .247 r
.19631 .16187 m
.19631 .03406 L
.19652 .03406 L
.19652 .16187 L
s
1 .894 .882 r
.19652 .16187 m
.19652 .03412 L
.19687 .03412 L
.19687 .16187 L
F
.804 .522 .247 r
.19652 .16187 m
.19652 .03412 L
.19687 .03412 L
.19687 .16187 L
s
1 .894 .882 r
.19687 .16187 m
.19687 .03417 L
.19729 .03417 L
.19729 .16187 L
F
.804 .522 .247 r
.19687 .16187 m
.19687 .03417 L
.19729 .03417 L
.19729 .16187 L
s
1 .894 .882 r
.19729 .16187 m
.19729 .03428 L
.19756 .03428 L
.19756 .16187 L
F
.804 .522 .247 r
.19729 .16187 m
.19729 .03428 L
.19756 .03428 L
.19756 .16187 L
s
1 .894 .882 r
.19756 .16187 m
.19756 .03438 L
.19789 .03438 L
.19789 .16187 L
F
.804 .522 .247 r
.19756 .16187 m
.19756 .03438 L
.19789 .03438 L
.19789 .16187 L
s
1 .894 .882 r
.19789 .16187 m
.19789 .0344 L
.19817 .0344 L
.19817 .16187 L
F
.804 .522 .247 r
.19789 .16187 m
.19789 .0344 L
.19817 .0344 L
.19817 .16187 L
s
1 .894 .882 r
.19817 .16187 m
.19817 .03445 L
.1985 .03445 L
.1985 .16187 L
F
.804 .522 .247 r
.19817 .16187 m
.19817 .03445 L
.1985 .03445 L
.1985 .16187 L
s
1 .894 .882 r
.1985 .16187 m
.1985 .03461 L
.19897 .03461 L
.19897 .16187 L
F
.804 .522 .247 r
.1985 .16187 m
.1985 .03461 L
.19897 .03461 L
.19897 .16187 L
s
1 .894 .882 r
.19897 .16187 m
.19897 .03468 L
.19939 .03468 L
.19939 .16187 L
F
.804 .522 .247 r
.19897 .16187 m
.19897 .03468 L
.19939 .03468 L
.19939 .16187 L
s
1 .894 .882 r
.19939 .16187 m
.19939 .03473 L
.19967 .03473 L
.19967 .16187 L
F
.804 .522 .247 r
.19939 .16187 m
.19939 .03473 L
.19967 .03473 L
.19967 .16187 L
s
1 .894 .882 r
.19967 .16187 m
.19967 .03483 L
.19992 .03483 L
.19992 .16187 L
F
.804 .522 .247 r
.19967 .16187 m
.19967 .03483 L
.19992 .03483 L
.19992 .16187 L
s
1 .894 .882 r
.19992 .16187 m
.19992 .03487 L
.20013 .03487 L
.20013 .16187 L
F
.804 .522 .247 r
.19992 .16187 m
.19992 .03487 L
.20013 .03487 L
.20013 .16187 L
s
1 .894 .882 r
.20013 .16187 m
.20013 .03499 L
.20061 .03499 L
.20061 .16187 L
F
.804 .522 .247 r
.20013 .16187 m
.20013 .03499 L
.20061 .03499 L
.20061 .16187 L
s
1 .894 .882 r
.20061 .16187 m
.20061 .03502 L
.20081 .03502 L
.20081 .16187 L
F
.804 .522 .247 r
.20061 .16187 m
.20061 .03502 L
.20081 .03502 L
.20081 .16187 L
s
1 .894 .882 r
.20081 .16187 m
.20081 .03508 L
.20101 .03508 L
.20101 .16187 L
F
.804 .522 .247 r
.20081 .16187 m
.20081 .03508 L
.20101 .03508 L
.20101 .16187 L
s
1 .894 .882 r
.20101 .16187 m
.20101 .03511 L
.20118 .03511 L
.20118 .16187 L
F
.804 .522 .247 r
.20101 .16187 m
.20101 .03511 L
.20118 .03511 L
.20118 .16187 L
s
1 .894 .882 r
.20118 .16187 m
.20118 .03517 L
.20137 .03517 L
.20137 .16187 L
F
.804 .522 .247 r
.20118 .16187 m
.20118 .03517 L
.20137 .03517 L
.20137 .16187 L
s
1 .894 .882 r
.20137 .16187 m
.20137 .03518 L
.2017 .03518 L
.2017 .16187 L
F
.804 .522 .247 r
.20137 .16187 m
.20137 .03518 L
.2017 .03518 L
.2017 .16187 L
s
1 .894 .882 r
.2017 .16187 m
.2017 .03526 L
.20203 .03526 L
.20203 .16187 L
F
.804 .522 .247 r
.2017 .16187 m
.2017 .03526 L
.20203 .03526 L
.20203 .16187 L
s
1 .894 .882 r
.20203 .16187 m
.20203 .03533 L
.20225 .03533 L
.20225 .16187 L
F
.804 .522 .247 r
.20203 .16187 m
.20203 .03533 L
.20225 .03533 L
.20225 .16187 L
s
1 .894 .882 r
.20225 .16187 m
.20225 .03542 L
.20271 .03542 L
.20271 .16187 L
F
.804 .522 .247 r
.20225 .16187 m
.20225 .03542 L
.20271 .03542 L
.20271 .16187 L
s
1 .894 .882 r
.20271 .16187 m
.20271 .03552 L
.20314 .03552 L
.20314 .16187 L
F
.804 .522 .247 r
.20271 .16187 m
.20271 .03552 L
.20314 .03552 L
.20314 .16187 L
s
1 .894 .882 r
.20314 .16187 m
.20314 .03567 L
.20352 .03567 L
.20352 .16187 L
F
.804 .522 .247 r
.20314 .16187 m
.20314 .03567 L
.20352 .03567 L
.20352 .16187 L
s
1 .894 .882 r
.20352 .16187 m
.20352 .03574 L
.20385 .03574 L
.20385 .16187 L
F
.804 .522 .247 r
.20352 .16187 m
.20352 .03574 L
.20385 .03574 L
.20385 .16187 L
s
1 .894 .882 r
.20385 .16187 m
.20385 .03581 L
.20424 .03581 L
.20424 .16187 L
F
.804 .522 .247 r
.20385 .16187 m
.20385 .03581 L
.20424 .03581 L
.20424 .16187 L
s
1 .894 .882 r
.20424 .16187 m
.20424 .03588 L
.20448 .03588 L
.20448 .16187 L
F
.804 .522 .247 r
.20424 .16187 m
.20424 .03588 L
.20448 .03588 L
.20448 .16187 L
s
1 .894 .882 r
.20448 .16187 m
.20448 .03597 L
.20493 .03597 L
.20493 .16187 L
F
.804 .522 .247 r
.20448 .16187 m
.20448 .03597 L
.20493 .03597 L
.20493 .16187 L
s
1 .894 .882 r
.20493 .16187 m
.20493 .03602 L
.20514 .03602 L
.20514 .16187 L
F
.804 .522 .247 r
.20493 .16187 m
.20493 .03602 L
.20514 .03602 L
.20514 .16187 L
s
1 .894 .882 r
.20514 .16187 m
.20514 .03609 L
.20535 .03609 L
.20535 .16187 L
F
.804 .522 .247 r
.20514 .16187 m
.20514 .03609 L
.20535 .03609 L
.20535 .16187 L
s
1 .894 .882 r
.20535 .16187 m
.20535 .03615 L
.2058 .03615 L
.2058 .16187 L
F
.804 .522 .247 r
.20535 .16187 m
.20535 .03615 L
.2058 .03615 L
.2058 .16187 L
s
1 .894 .882 r
.2058 .16187 m
.2058 .03625 L
.20607 .03625 L
.20607 .16187 L
F
.804 .522 .247 r
.2058 .16187 m
.2058 .03625 L
.20607 .03625 L
.20607 .16187 L
s
1 .894 .882 r
.20607 .16187 m
.20607 .0363 L
.2063 .0363 L
.2063 .16187 L
F
.804 .522 .247 r
.20607 .16187 m
.20607 .0363 L
.2063 .0363 L
.2063 .16187 L
s
1 .894 .882 r
.2063 .16187 m
.2063 .03633 L
.20659 .03633 L
.20659 .16187 L
F
.804 .522 .247 r
.2063 .16187 m
.2063 .03633 L
.20659 .03633 L
.20659 .16187 L
s
1 .894 .882 r
.20659 .16187 m
.20659 .03641 L
.20689 .03641 L
.20689 .16187 L
F
.804 .522 .247 r
.20659 .16187 m
.20659 .03641 L
.20689 .03641 L
.20689 .16187 L
s
1 .894 .882 r
.20689 .16187 m
.20689 .0365 L
.20707 .0365 L
.20707 .16187 L
F
.804 .522 .247 r
.20689 .16187 m
.20689 .0365 L
.20707 .0365 L
.20707 .16187 L
s
1 .894 .882 r
.20707 .16187 m
.20707 .03655 L
.20723 .03655 L
.20723 .16187 L
F
.804 .522 .247 r
.20707 .16187 m
.20707 .03655 L
.20723 .03655 L
.20723 .16187 L
s
1 .894 .882 r
.20723 .16187 m
.20723 .03656 L
.20753 .03656 L
.20753 .16187 L
F
.804 .522 .247 r
.20723 .16187 m
.20723 .03656 L
.20753 .03656 L
.20753 .16187 L
s
1 .894 .882 r
.20753 .16187 m
.20753 .03667 L
.20778 .03667 L
.20778 .16187 L
F
.804 .522 .247 r
.20753 .16187 m
.20753 .03667 L
.20778 .03667 L
.20778 .16187 L
s
1 .894 .882 r
.20778 .16187 m
.20778 .03671 L
.20825 .03671 L
.20825 .16187 L
F
.804 .522 .247 r
.20778 .16187 m
.20778 .03671 L
.20825 .03671 L
.20825 .16187 L
s
1 .894 .882 r
.20825 .16187 m
.20825 .03681 L
.2084 .03681 L
.2084 .16187 L
F
.804 .522 .247 r
.20825 .16187 m
.20825 .03681 L
.2084 .03681 L
.2084 .16187 L
s
1 .894 .882 r
.2084 .16187 m
.2084 .03684 L
.20865 .03684 L
.20865 .16187 L
F
.804 .522 .247 r
.2084 .16187 m
.2084 .03684 L
.20865 .03684 L
.20865 .16187 L
s
1 .894 .882 r
.20865 .16187 m
.20865 .03696 L
.20907 .03696 L
.20907 .16187 L
F
.804 .522 .247 r
.20865 .16187 m
.20865 .03696 L
.20907 .03696 L
.20907 .16187 L
s
1 .894 .882 r
.20907 .16187 m
.20907 .03699 L
.20935 .03699 L
.20935 .16187 L
F
.804 .522 .247 r
.20907 .16187 m
.20907 .03699 L
.20935 .03699 L
.20935 .16187 L
s
1 .894 .882 r
.20935 .16187 m
.20935 .03711 L
.20978 .03711 L
.20978 .16187 L
F
.804 .522 .247 r
.20935 .16187 m
.20935 .03711 L
.20978 .03711 L
.20978 .16187 L
s
1 .894 .882 r
.20978 .16187 m
.20978 .03722 L
.21006 .03722 L
.21006 .16187 L
F
.804 .522 .247 r
.20978 .16187 m
.20978 .03722 L
.21006 .03722 L
.21006 .16187 L
s
1 .894 .882 r
.21006 .16187 m
.21006 .03728 L
.21054 .03728 L
.21054 .16187 L
F
.804 .522 .247 r
.21006 .16187 m
.21006 .03728 L
.21054 .03728 L
.21054 .16187 L
s
1 .894 .882 r
.21054 .16187 m
.21054 .03735 L
.21093 .03735 L
.21093 .16187 L
F
.804 .522 .247 r
.21054 .16187 m
.21054 .03735 L
.21093 .03735 L
.21093 .16187 L
s
1 .894 .882 r
.21093 .16187 m
.21093 .03748 L
.21117 .03748 L
.21117 .16187 L
F
.804 .522 .247 r
.21093 .16187 m
.21093 .03748 L
.21117 .03748 L
.21117 .16187 L
s
1 .894 .882 r
.21117 .16187 m
.21117 .03751 L
.21156 .03751 L
.21156 .16187 L
F
.804 .522 .247 r
.21117 .16187 m
.21117 .03751 L
.21156 .03751 L
.21156 .16187 L
s
1 .894 .882 r
.21156 .16187 m
.21156 .03765 L
.21195 .03765 L
.21195 .16187 L
F
.804 .522 .247 r
.21156 .16187 m
.21156 .03765 L
.21195 .03765 L
.21195 .16187 L
s
1 .894 .882 r
.21195 .16187 m
.21195 .03772 L
.21237 .03772 L
.21237 .16187 L
F
.804 .522 .247 r
.21195 .16187 m
.21195 .03772 L
.21237 .03772 L
.21237 .16187 L
s
1 .894 .882 r
.21237 .16187 m
.21237 .0378 L
.21256 .0378 L
.21256 .16187 L
F
.804 .522 .247 r
.21237 .16187 m
.21237 .0378 L
.21256 .0378 L
.21256 .16187 L
s
1 .894 .882 r
.21256 .16187 m
.21256 .03787 L
.21288 .03787 L
.21288 .16187 L
F
.804 .522 .247 r
.21256 .16187 m
.21256 .03787 L
.21288 .03787 L
.21288 .16187 L
s
1 .894 .882 r
.21288 .16187 m
.21288 .03794 L
.21332 .03794 L
.21332 .16187 L
F
.804 .522 .247 r
.21288 .16187 m
.21288 .03794 L
.21332 .03794 L
.21332 .16187 L
s
1 .894 .882 r
.21332 .16187 m
.21332 .03808 L
.21362 .03808 L
.21362 .16187 L
F
.804 .522 .247 r
.21332 .16187 m
.21332 .03808 L
.21362 .03808 L
.21362 .16187 L
s
1 .894 .882 r
.21362 .16187 m
.21362 .03817 L
.21407 .03817 L
.21407 .16187 L
F
.804 .522 .247 r
.21362 .16187 m
.21362 .03817 L
.21407 .03817 L
.21407 .16187 L
s
1 .894 .882 r
.21407 .16187 m
.21407 .03822 L
.21425 .03822 L
.21425 .16187 L
F
.804 .522 .247 r
.21407 .16187 m
.21407 .03822 L
.21425 .03822 L
.21425 .16187 L
s
1 .894 .882 r
.21425 .16187 m
.21425 .03832 L
.21453 .03832 L
.21453 .16187 L
F
.804 .522 .247 r
.21425 .16187 m
.21425 .03832 L
.21453 .03832 L
.21453 .16187 L
s
1 .894 .882 r
.21453 .16187 m
.21453 .03838 L
.2148 .03838 L
.2148 .16187 L
F
.804 .522 .247 r
.21453 .16187 m
.21453 .03838 L
.2148 .03838 L
.2148 .16187 L
s
1 .894 .882 r
.2148 .16187 m
.2148 .03847 L
.21523 .03847 L
.21523 .16187 L
F
.804 .522 .247 r
.2148 .16187 m
.2148 .03847 L
.21523 .03847 L
.21523 .16187 L
s
1 .894 .882 r
.21523 .16187 m
.21523 .03851 L
.2156 .03851 L
.2156 .16187 L
F
.804 .522 .247 r
.21523 .16187 m
.21523 .03851 L
.2156 .03851 L
.2156 .16187 L
s
1 .894 .882 r
.2156 .16187 m
.2156 .03859 L
.21578 .03859 L
.21578 .16187 L
F
.804 .522 .247 r
.2156 .16187 m
.2156 .03859 L
.21578 .03859 L
.21578 .16187 L
s
1 .894 .882 r
.21578 .16187 m
.21578 .03868 L
.21608 .03868 L
.21608 .16187 L
F
.804 .522 .247 r
.21578 .16187 m
.21578 .03868 L
.21608 .03868 L
.21608 .16187 L
s
1 .894 .882 r
.21608 .16187 m
.21608 .03872 L
.21651 .03872 L
.21651 .16187 L
F
.804 .522 .247 r
.21608 .16187 m
.21608 .03872 L
.21651 .03872 L
.21651 .16187 L
s
1 .894 .882 r
.21651 .16187 m
.21651 .03887 L
.21678 .03887 L
.21678 .16187 L
F
.804 .522 .247 r
.21651 .16187 m
.21651 .03887 L
.21678 .03887 L
.21678 .16187 L
s
1 .894 .882 r
.21678 .16187 m
.21678 .0389 L
.21703 .0389 L
.21703 .16187 L
F
.804 .522 .247 r
.21678 .16187 m
.21678 .0389 L
.21703 .0389 L
.21703 .16187 L
s
1 .894 .882 r
.21703 .16187 m
.21703 .03897 L
.2172 .03897 L
.2172 .16187 L
F
.804 .522 .247 r
.21703 .16187 m
.21703 .03897 L
.2172 .03897 L
.2172 .16187 L
s
1 .894 .882 r
.2172 .16187 m
.2172 .03905 L
.21769 .03905 L
.21769 .16187 L
F
.804 .522 .247 r
.2172 .16187 m
.2172 .03905 L
.21769 .03905 L
.21769 .16187 L
s
1 .894 .882 r
.21769 .16187 m
.21769 .03923 L
.21816 .03923 L
.21816 .16187 L
F
.804 .522 .247 r
.21769 .16187 m
.21769 .03923 L
.21816 .03923 L
.21816 .16187 L
s
1 .894 .882 r
.21816 .16187 m
.21816 .03929 L
.21844 .03929 L
.21844 .16187 L
F
.804 .522 .247 r
.21816 .16187 m
.21816 .03929 L
.21844 .03929 L
.21844 .16187 L
s
1 .894 .882 r
.21844 .16187 m
.21844 .03933 L
.21871 .03933 L
.21871 .16187 L
F
.804 .522 .247 r
.21844 .16187 m
.21844 .03933 L
.21871 .03933 L
.21871 .16187 L
s
1 .894 .882 r
.21871 .16187 m
.21871 .03945 L
.2191 .03945 L
.2191 .16187 L
F
.804 .522 .247 r
.21871 .16187 m
.21871 .03945 L
.2191 .03945 L
.2191 .16187 L
s
1 .894 .882 r
.2191 .16187 m
.2191 .03951 L
.21934 .03951 L
.21934 .16187 L
F
.804 .522 .247 r
.2191 .16187 m
.2191 .03951 L
.21934 .03951 L
.21934 .16187 L
s
1 .894 .882 r
.21934 .16187 m
.21934 .03956 L
.21971 .03956 L
.21971 .16187 L
F
.804 .522 .247 r
.21934 .16187 m
.21934 .03956 L
.21971 .03956 L
.21971 .16187 L
s
1 .894 .882 r
.21971 .16187 m
.21971 .03963 L
.22005 .03963 L
.22005 .16187 L
F
.804 .522 .247 r
.21971 .16187 m
.21971 .03963 L
.22005 .03963 L
.22005 .16187 L
s
1 .894 .882 r
.22005 .16187 m
.22005 .03976 L
.2204 .03976 L
.2204 .16187 L
F
.804 .522 .247 r
.22005 .16187 m
.22005 .03976 L
.2204 .03976 L
.2204 .16187 L
s
1 .894 .882 r
.2204 .16187 m
.2204 .03983 L
.22081 .03983 L
.22081 .16187 L
F
.804 .522 .247 r
.2204 .16187 m
.2204 .03983 L
.22081 .03983 L
.22081 .16187 L
s
1 .894 .882 r
.22081 .16187 m
.22081 .03991 L
.22123 .03991 L
.22123 .16187 L
F
.804 .522 .247 r
.22081 .16187 m
.22081 .03991 L
.22123 .03991 L
.22123 .16187 L
s
1 .894 .882 r
.22123 .16187 m
.22123 .04003 L
.22142 .04003 L
.22142 .16187 L
F
.804 .522 .247 r
.22123 .16187 m
.22123 .04003 L
.22142 .04003 L
.22142 .16187 L
s
1 .894 .882 r
.22142 .16187 m
.22142 .04015 L
.22182 .04015 L
.22182 .16187 L
F
.804 .522 .247 r
.22142 .16187 m
.22142 .04015 L
.22182 .04015 L
.22182 .16187 L
s
1 .894 .882 r
.22182 .16187 m
.22182 .04025 L
.2222 .04025 L
.2222 .16187 L
F
.804 .522 .247 r
.22182 .16187 m
.22182 .04025 L
.2222 .04025 L
.2222 .16187 L
s
1 .894 .882 r
.2222 .16187 m
.2222 .04026 L
.22249 .04026 L
.22249 .16187 L
F
.804 .522 .247 r
.2222 .16187 m
.2222 .04026 L
.22249 .04026 L
.22249 .16187 L
s
1 .894 .882 r
.22249 .16187 m
.22249 .04038 L
.22289 .04038 L
.22289 .16187 L
F
.804 .522 .247 r
.22249 .16187 m
.22249 .04038 L
.22289 .04038 L
.22289 .16187 L
s
1 .894 .882 r
.22289 .16187 m
.22289 .04045 L
.22335 .04045 L
.22335 .16187 L
F
.804 .522 .247 r
.22289 .16187 m
.22289 .04045 L
.22335 .04045 L
.22335 .16187 L
s
1 .894 .882 r
.22335 .16187 m
.22335 .04059 L
.22351 .04059 L
.22351 .16187 L
F
.804 .522 .247 r
.22335 .16187 m
.22335 .04059 L
.22351 .04059 L
.22351 .16187 L
s
1 .894 .882 r
.22351 .16187 m
.22351 .04066 L
.22376 .04066 L
.22376 .16187 L
F
.804 .522 .247 r
.22351 .16187 m
.22351 .04066 L
.22376 .04066 L
.22376 .16187 L
s
1 .894 .882 r
.22376 .16187 m
.22376 .04072 L
.22401 .04072 L
.22401 .16187 L
F
.804 .522 .247 r
.22376 .16187 m
.22376 .04072 L
.22401 .04072 L
.22401 .16187 L
s
1 .894 .882 r
.22401 .16187 m
.22401 .04077 L
.22419 .04077 L
.22419 .16187 L
F
.804 .522 .247 r
.22401 .16187 m
.22401 .04077 L
.22419 .04077 L
.22419 .16187 L
s
1 .894 .882 r
.22419 .16187 m
.22419 .04087 L
.22458 .04087 L
.22458 .16187 L
F
.804 .522 .247 r
.22419 .16187 m
.22419 .04087 L
.22458 .04087 L
.22458 .16187 L
s
1 .894 .882 r
.22458 .16187 m
.22458 .04094 L
.22507 .04094 L
.22507 .16187 L
F
.804 .522 .247 r
.22458 .16187 m
.22458 .04094 L
.22507 .04094 L
.22507 .16187 L
s
1 .894 .882 r
.22507 .16187 m
.22507 .04102 L
.2253 .04102 L
.2253 .16187 L
F
.804 .522 .247 r
.22507 .16187 m
.22507 .04102 L
.2253 .04102 L
.2253 .16187 L
s
1 .894 .882 r
.2253 .16187 m
.2253 .04108 L
.22548 .04108 L
.22548 .16187 L
F
.804 .522 .247 r
.2253 .16187 m
.2253 .04108 L
.22548 .04108 L
.22548 .16187 L
s
1 .894 .882 r
.22548 .16187 m
.22548 .04121 L
.22589 .04121 L
.22589 .16187 L
F
.804 .522 .247 r
.22548 .16187 m
.22548 .04121 L
.22589 .04121 L
.22589 .16187 L
s
1 .894 .882 r
.22589 .16187 m
.22589 .04127 L
.22625 .04127 L
.22625 .16187 L
F
.804 .522 .247 r
.22589 .16187 m
.22589 .04127 L
.22625 .04127 L
.22625 .16187 L
s
1 .894 .882 r
.22625 .16187 m
.22625 .04142 L
.2267 .04142 L
.2267 .16187 L
F
.804 .522 .247 r
.22625 .16187 m
.22625 .04142 L
.2267 .04142 L
.2267 .16187 L
s
1 .894 .882 r
.2267 .16187 m
.2267 .04147 L
.22699 .04147 L
.22699 .16187 L
F
.804 .522 .247 r
.2267 .16187 m
.2267 .04147 L
.22699 .04147 L
.22699 .16187 L
s
1 .894 .882 r
.22699 .16187 m
.22699 .04152 L
.2273 .04152 L
.2273 .16187 L
F
.804 .522 .247 r
.22699 .16187 m
.22699 .04152 L
.2273 .04152 L
.2273 .16187 L
s
1 .894 .882 r
.2273 .16187 m
.2273 .04162 L
.22779 .04162 L
.22779 .16187 L
F
.804 .522 .247 r
.2273 .16187 m
.2273 .04162 L
.22779 .04162 L
.22779 .16187 L
s
1 .894 .882 r
.22779 .16187 m
.22779 .04177 L
.22805 .04177 L
.22805 .16187 L
F
.804 .522 .247 r
.22779 .16187 m
.22779 .04177 L
.22805 .04177 L
.22805 .16187 L
s
1 .894 .882 r
.22805 .16187 m
.22805 .04189 L
.22848 .04189 L
.22848 .16187 L
F
.804 .522 .247 r
.22805 .16187 m
.22805 .04189 L
.22848 .04189 L
.22848 .16187 L
s
1 .894 .882 r
.22848 .16187 m
.22848 .04199 L
.22887 .04199 L
.22887 .16187 L
F
.804 .522 .247 r
.22848 .16187 m
.22848 .04199 L
.22887 .04199 L
.22887 .16187 L
s
1 .894 .882 r
.22887 .16187 m
.22887 .04201 L
.22908 .04201 L
.22908 .16187 L
F
.804 .522 .247 r
.22887 .16187 m
.22887 .04201 L
.22908 .04201 L
.22908 .16187 L
s
1 .894 .882 r
.22908 .16187 m
.22908 .04209 L
.2293 .04209 L
.2293 .16187 L
F
.804 .522 .247 r
.22908 .16187 m
.22908 .04209 L
.2293 .04209 L
.2293 .16187 L
s
1 .894 .882 r
.2293 .16187 m
.2293 .04212 L
.22948 .04212 L
.22948 .16187 L
F
.804 .522 .247 r
.2293 .16187 m
.2293 .04212 L
.22948 .04212 L
.22948 .16187 L
s
1 .894 .882 r
.22948 .16187 m
.22948 .0422 L
.22964 .0422 L
.22964 .16187 L
F
.804 .522 .247 r
.22948 .16187 m
.22948 .0422 L
.22964 .0422 L
.22964 .16187 L
s
1 .894 .882 r
.22964 .16187 m
.22964 .04221 L
.23005 .04221 L
.23005 .16187 L
F
.804 .522 .247 r
.22964 .16187 m
.22964 .04221 L
.23005 .04221 L
.23005 .16187 L
s
1 .894 .882 r
.23005 .16187 m
.23005 .0424 L
.23036 .0424 L
.23036 .16187 L
F
.804 .522 .247 r
.23005 .16187 m
.23005 .0424 L
.23036 .0424 L
.23036 .16187 L
s
1 .894 .882 r
.23036 .16187 m
.23036 .04245 L
.23058 .04245 L
.23058 .16187 L
F
.804 .522 .247 r
.23036 .16187 m
.23036 .04245 L
.23058 .04245 L
.23058 .16187 L
s
1 .894 .882 r
.23058 .16187 m
.23058 .04246 L
.23106 .04246 L
.23106 .16187 L
F
.804 .522 .247 r
.23058 .16187 m
.23058 .04246 L
.23106 .04246 L
.23106 .16187 L
s
1 .894 .882 r
.23106 .16187 m
.23106 .0426 L
.23138 .0426 L
.23138 .16187 L
F
.804 .522 .247 r
.23106 .16187 m
.23106 .0426 L
.23138 .0426 L
.23138 .16187 L
s
1 .894 .882 r
.23138 .16187 m
.23138 .04268 L
.23157 .04268 L
.23157 .16187 L
F
.804 .522 .247 r
.23138 .16187 m
.23138 .04268 L
.23157 .04268 L
.23157 .16187 L
s
1 .894 .882 r
.23157 .16187 m
.23157 .04277 L
.23176 .04277 L
.23176 .16187 L
F
.804 .522 .247 r
.23157 .16187 m
.23157 .04277 L
.23176 .04277 L
.23176 .16187 L
s
1 .894 .882 r
.23176 .16187 m
.23176 .04278 L
.23201 .04278 L
.23201 .16187 L
F
.804 .522 .247 r
.23176 .16187 m
.23176 .04278 L
.23201 .04278 L
.23201 .16187 L
s
1 .894 .882 r
.23201 .16187 m
.23201 .04289 L
.23232 .04289 L
.23232 .16187 L
F
.804 .522 .247 r
.23201 .16187 m
.23201 .04289 L
.23232 .04289 L
.23232 .16187 L
s
1 .894 .882 r
.23232 .16187 m
.23232 .04302 L
.23278 .04302 L
.23278 .16187 L
F
.804 .522 .247 r
.23232 .16187 m
.23232 .04302 L
.23278 .04302 L
.23278 .16187 L
s
1 .894 .882 r
.23278 .16187 m
.23278 .04308 L
.23294 .04308 L
.23294 .16187 L
F
.804 .522 .247 r
.23278 .16187 m
.23278 .04308 L
.23294 .04308 L
.23294 .16187 L
s
1 .894 .882 r
.23294 .16187 m
.23294 .0431 L
.23327 .0431 L
.23327 .16187 L
F
.804 .522 .247 r
.23294 .16187 m
.23294 .0431 L
.23327 .0431 L
.23327 .16187 L
s
1 .894 .882 r
.23327 .16187 m
.23327 .0433 L
.23371 .0433 L
.23371 .16187 L
F
.804 .522 .247 r
.23327 .16187 m
.23327 .0433 L
.23371 .0433 L
.23371 .16187 L
s
1 .894 .882 r
.23371 .16187 m
.23371 .04334 L
.23387 .04334 L
.23387 .16187 L
F
.804 .522 .247 r
.23371 .16187 m
.23371 .04334 L
.23387 .04334 L
.23387 .16187 L
s
1 .894 .882 r
.23387 .16187 m
.23387 .04344 L
.23423 .04344 L
.23423 .16187 L
F
.804 .522 .247 r
.23387 .16187 m
.23387 .04344 L
.23423 .04344 L
.23423 .16187 L
s
1 .894 .882 r
.23423 .16187 m
.23423 .04349 L
.2344 .04349 L
.2344 .16187 L
F
.804 .522 .247 r
.23423 .16187 m
.23423 .04349 L
.2344 .04349 L
.2344 .16187 L
s
1 .894 .882 r
.2344 .16187 m
.2344 .04358 L
.23484 .04358 L
.23484 .16187 L
F
.804 .522 .247 r
.2344 .16187 m
.2344 .04358 L
.23484 .04358 L
.23484 .16187 L
s
1 .894 .882 r
.23484 .16187 m
.23484 .04362 L
.23524 .04362 L
.23524 .16187 L
F
.804 .522 .247 r
.23484 .16187 m
.23484 .04362 L
.23524 .04362 L
.23524 .16187 L
s
1 .894 .882 r
.23524 .16187 m
.23524 .04373 L
.23566 .04373 L
.23566 .16187 L
F
.804 .522 .247 r
.23524 .16187 m
.23524 .04373 L
.23566 .04373 L
.23566 .16187 L
s
1 .894 .882 r
.23566 .16187 m
.23566 .04391 L
.23593 .04391 L
.23593 .16187 L
F
.804 .522 .247 r
.23566 .16187 m
.23566 .04391 L
.23593 .04391 L
.23593 .16187 L
s
1 .894 .882 r
.23593 .16187 m
.23593 .04397 L
.23631 .04397 L
.23631 .16187 L
F
.804 .522 .247 r
.23593 .16187 m
.23593 .04397 L
.23631 .04397 L
.23631 .16187 L
s
1 .894 .882 r
.23631 .16187 m
.23631 .04407 L
.23663 .04407 L
.23663 .16187 L
F
.804 .522 .247 r
.23631 .16187 m
.23631 .04407 L
.23663 .04407 L
.23663 .16187 L
s
1 .894 .882 r
.23663 .16187 m
.23663 .04421 L
.23702 .04421 L
.23702 .16187 L
F
.804 .522 .247 r
.23663 .16187 m
.23663 .04421 L
.23702 .04421 L
.23702 .16187 L
s
1 .894 .882 r
.23702 .16187 m
.23702 .04422 L
.23728 .04422 L
.23728 .16187 L
F
.804 .522 .247 r
.23702 .16187 m
.23702 .04422 L
.23728 .04422 L
.23728 .16187 L
s
1 .894 .882 r
.23728 .16187 m
.23728 .04435 L
.23774 .04435 L
.23774 .16187 L
F
.804 .522 .247 r
.23728 .16187 m
.23728 .04435 L
.23774 .04435 L
.23774 .16187 L
s
1 .894 .882 r
.23774 .16187 m
.23774 .04444 L
.23791 .04444 L
.23791 .16187 L
F
.804 .522 .247 r
.23774 .16187 m
.23774 .04444 L
.23791 .04444 L
.23791 .16187 L
s
1 .894 .882 r
.23791 .16187 m
.23791 .04446 L
.23822 .04446 L
.23822 .16187 L
F
.804 .522 .247 r
.23791 .16187 m
.23791 .04446 L
.23822 .04446 L
.23822 .16187 L
s
1 .894 .882 r
.23822 .16187 m
.23822 .04455 L
.23849 .04455 L
.23849 .16187 L
F
.804 .522 .247 r
.23822 .16187 m
.23822 .04455 L
.23849 .04455 L
.23849 .16187 L
s
1 .894 .882 r
.23849 .16187 m
.23849 .04466 L
.23878 .04466 L
.23878 .16187 L
F
.804 .522 .247 r
.23849 .16187 m
.23849 .04466 L
.23878 .04466 L
.23878 .16187 L
s
1 .894 .882 r
.23878 .16187 m
.23878 .04478 L
.23924 .04478 L
.23924 .16187 L
F
.804 .522 .247 r
.23878 .16187 m
.23878 .04478 L
.23924 .04478 L
.23924 .16187 L
s
1 .894 .882 r
.23924 .16187 m
.23924 .04484 L
.23952 .04484 L
.23952 .16187 L
F
.804 .522 .247 r
.23924 .16187 m
.23924 .04484 L
.23952 .04484 L
.23952 .16187 L
s
1 .894 .882 r
.23952 .16187 m
.23952 .04496 L
.23969 .04496 L
.23969 .16187 L
F
.804 .522 .247 r
.23952 .16187 m
.23952 .04496 L
.23969 .04496 L
.23969 .16187 L
s
1 .894 .882 r
.23969 .16187 m
.23969 .04507 L
.24015 .04507 L
.24015 .16187 L
F
.804 .522 .247 r
.23969 .16187 m
.23969 .04507 L
.24015 .04507 L
.24015 .16187 L
s
1 .894 .882 r
.24015 .16187 m
.24015 .04512 L
.2403 .04512 L
.2403 .16187 L
F
.804 .522 .247 r
.24015 .16187 m
.24015 .04512 L
.2403 .04512 L
.2403 .16187 L
s
1 .894 .882 r
.2403 .16187 m
.2403 .04518 L
.24057 .04518 L
.24057 .16187 L
F
.804 .522 .247 r
.2403 .16187 m
.2403 .04518 L
.24057 .04518 L
.24057 .16187 L
s
1 .894 .882 r
.24057 .16187 m
.24057 .04529 L
.2409 .04529 L
.2409 .16187 L
F
.804 .522 .247 r
.24057 .16187 m
.24057 .04529 L
.2409 .04529 L
.2409 .16187 L
s
1 .894 .882 r
.2409 .16187 m
.2409 .04534 L
.24107 .04534 L
.24107 .16187 L
F
.804 .522 .247 r
.2409 .16187 m
.2409 .04534 L
.24107 .04534 L
.24107 .16187 L
s
1 .894 .882 r
.24107 .16187 m
.24107 .04535 L
.24156 .04535 L
.24156 .16187 L
F
.804 .522 .247 r
.24107 .16187 m
.24107 .04535 L
.24156 .04535 L
.24156 .16187 L
s
1 .894 .882 r
.24156 .16187 m
.24156 .04556 L
.24196 .04556 L
.24196 .16187 L
F
.804 .522 .247 r
.24156 .16187 m
.24156 .04556 L
.24196 .04556 L
.24196 .16187 L
s
1 .894 .882 r
.24196 .16187 m
.24196 .0456 L
.24227 .0456 L
.24227 .16187 L
F
.804 .522 .247 r
.24196 .16187 m
.24196 .0456 L
.24227 .0456 L
.24227 .16187 L
s
1 .894 .882 r
.24227 .16187 m
.24227 .0457 L
.24249 .0457 L
.24249 .16187 L
F
.804 .522 .247 r
.24227 .16187 m
.24227 .0457 L
.24249 .0457 L
.24249 .16187 L
s
1 .894 .882 r
.24249 .16187 m
.24249 .04575 L
.24273 .04575 L
.24273 .16187 L
F
.804 .522 .247 r
.24249 .16187 m
.24249 .04575 L
.24273 .04575 L
.24273 .16187 L
s
1 .894 .882 r
.24273 .16187 m
.24273 .0459 L
.24319 .0459 L
.24319 .16187 L
F
.804 .522 .247 r
.24273 .16187 m
.24273 .0459 L
.24319 .0459 L
.24319 .16187 L
s
1 .894 .882 r
.24319 .16187 m
.24319 .04595 L
.24339 .04595 L
.24339 .16187 L
F
.804 .522 .247 r
.24319 .16187 m
.24319 .04595 L
.24339 .04595 L
.24339 .16187 L
s
1 .894 .882 r
.24339 .16187 m
.24339 .04606 L
.24371 .04606 L
.24371 .16187 L
F
.804 .522 .247 r
.24339 .16187 m
.24339 .04606 L
.24371 .04606 L
.24371 .16187 L
s
1 .894 .882 r
.24371 .16187 m
.24371 .04615 L
.24412 .04615 L
.24412 .16187 L
F
.804 .522 .247 r
.24371 .16187 m
.24371 .04615 L
.24412 .04615 L
.24412 .16187 L
s
1 .894 .882 r
.24412 .16187 m
.24412 .04626 L
.24435 .04626 L
.24435 .16187 L
F
.804 .522 .247 r
.24412 .16187 m
.24412 .04626 L
.24435 .04626 L
.24435 .16187 L
s
1 .894 .882 r
.24435 .16187 m
.24435 .04639 L
.24477 .04639 L
.24477 .16187 L
F
.804 .522 .247 r
.24435 .16187 m
.24435 .04639 L
.24477 .04639 L
.24477 .16187 L
s
1 .894 .882 r
.24477 .16187 m
.24477 .04641 L
.24513 .04641 L
.24513 .16187 L
F
.804 .522 .247 r
.24477 .16187 m
.24477 .04641 L
.24513 .04641 L
.24513 .16187 L
s
1 .894 .882 r
.24513 .16187 m
.24513 .0466 L
.24552 .0466 L
.24552 .16187 L
F
.804 .522 .247 r
.24513 .16187 m
.24513 .0466 L
.24552 .0466 L
.24552 .16187 L
s
1 .894 .882 r
.24552 .16187 m
.24552 .04669 L
.24592 .04669 L
.24592 .16187 L
F
.804 .522 .247 r
.24552 .16187 m
.24552 .04669 L
.24592 .04669 L
.24592 .16187 L
s
1 .894 .882 r
.24592 .16187 m
.24592 .04681 L
.24623 .04681 L
.24623 .16187 L
F
.804 .522 .247 r
.24592 .16187 m
.24592 .04681 L
.24623 .04681 L
.24623 .16187 L
s
1 .894 .882 r
.24623 .16187 m
.24623 .04686 L
.24645 .04686 L
.24645 .16187 L
F
.804 .522 .247 r
.24623 .16187 m
.24623 .04686 L
.24645 .04686 L
.24645 .16187 L
s
1 .894 .882 r
.24645 .16187 m
.24645 .04692 L
.24687 .04692 L
.24687 .16187 L
F
.804 .522 .247 r
.24645 .16187 m
.24645 .04692 L
.24687 .04692 L
.24687 .16187 L
s
1 .894 .882 r
.24687 .16187 m
.24687 .04705 L
.24714 .04705 L
.24714 .16187 L
F
.804 .522 .247 r
.24687 .16187 m
.24687 .04705 L
.24714 .04705 L
.24714 .16187 L
s
1 .894 .882 r
.24714 .16187 m
.24714 .04716 L
.24743 .04716 L
.24743 .16187 L
F
.804 .522 .247 r
.24714 .16187 m
.24714 .04716 L
.24743 .04716 L
.24743 .16187 L
s
1 .894 .882 r
.24743 .16187 m
.24743 .04722 L
.24767 .04722 L
.24767 .16187 L
F
.804 .522 .247 r
.24743 .16187 m
.24743 .04722 L
.24767 .04722 L
.24767 .16187 L
s
1 .894 .882 r
.24767 .16187 m
.24767 .04729 L
.24809 .04729 L
.24809 .16187 L
F
.804 .522 .247 r
.24767 .16187 m
.24767 .04729 L
.24809 .04729 L
.24809 .16187 L
s
1 .894 .882 r
.24809 .16187 m
.24809 .0474 L
.24825 .0474 L
.24825 .16187 L
F
.804 .522 .247 r
.24809 .16187 m
.24809 .0474 L
.24825 .0474 L
.24825 .16187 L
s
1 .894 .882 r
.24825 .16187 m
.24825 .04741 L
.24868 .04741 L
.24868 .16187 L
F
.804 .522 .247 r
.24825 .16187 m
.24825 .04741 L
.24868 .04741 L
.24868 .16187 L
s
1 .894 .882 r
.24868 .16187 m
.24868 .04759 L
.24891 .04759 L
.24891 .16187 L
F
.804 .522 .247 r
.24868 .16187 m
.24868 .04759 L
.24891 .04759 L
.24891 .16187 L
s
1 .894 .882 r
.24891 .16187 m
.24891 .04765 L
.24933 .04765 L
.24933 .16187 L
F
.804 .522 .247 r
.24891 .16187 m
.24891 .04765 L
.24933 .04765 L
.24933 .16187 L
s
1 .894 .882 r
.24933 .16187 m
.24933 .04774 L
.24959 .04774 L
.24959 .16187 L
F
.804 .522 .247 r
.24933 .16187 m
.24933 .04774 L
.24959 .04774 L
.24959 .16187 L
s
1 .894 .882 r
.24959 .16187 m
.24959 .04787 L
.24985 .04787 L
.24985 .16187 L
F
.804 .522 .247 r
.24959 .16187 m
.24959 .04787 L
.24985 .04787 L
.24985 .16187 L
s
1 .894 .882 r
.24985 .16187 m
.24985 .04791 L
.25001 .04791 L
.25001 .16187 L
F
.804 .522 .247 r
.24985 .16187 m
.24985 .04791 L
.25001 .04791 L
.25001 .16187 L
s
1 .894 .882 r
.25001 .16187 m
.25001 .04796 L
.25034 .04796 L
.25034 .16187 L
F
.804 .522 .247 r
.25001 .16187 m
.25001 .04796 L
.25034 .04796 L
.25034 .16187 L
s
1 .894 .882 r
.25034 .16187 m
.25034 .04806 L
.25063 .04806 L
.25063 .16187 L
F
.804 .522 .247 r
.25034 .16187 m
.25034 .04806 L
.25063 .04806 L
.25063 .16187 L
s
1 .894 .882 r
.25063 .16187 m
.25063 .04816 L
.25084 .04816 L
.25084 .16187 L
F
.804 .522 .247 r
.25063 .16187 m
.25063 .04816 L
.25084 .04816 L
.25084 .16187 L
s
1 .894 .882 r
.25084 .16187 m
.25084 .04817 L
.25117 .04817 L
.25117 .16187 L
F
.804 .522 .247 r
.25084 .16187 m
.25084 .04817 L
.25117 .04817 L
.25117 .16187 L
s
1 .894 .882 r
.25117 .16187 m
.25117 .04838 L
.25158 .04838 L
.25158 .16187 L
F
.804 .522 .247 r
.25117 .16187 m
.25117 .04838 L
.25158 .04838 L
.25158 .16187 L
s
1 .894 .882 r
.25158 .16187 m
.25158 .04844 L
.25179 .04844 L
.25179 .16187 L
F
.804 .522 .247 r
.25158 .16187 m
.25158 .04844 L
.25179 .04844 L
.25179 .16187 L
s
1 .894 .882 r
.25179 .16187 m
.25179 .04852 L
.25207 .04852 L
.25207 .16187 L
F
.804 .522 .247 r
.25179 .16187 m
.25179 .04852 L
.25207 .04852 L
.25207 .16187 L
s
1 .894 .882 r
.25207 .16187 m
.25207 .04865 L
.25253 .04865 L
.25253 .16187 L
F
.804 .522 .247 r
.25207 .16187 m
.25207 .04865 L
.25253 .04865 L
.25253 .16187 L
s
1 .894 .882 r
.25253 .16187 m
.25253 .04867 L
.2527 .04867 L
.2527 .16187 L
F
.804 .522 .247 r
.25253 .16187 m
.25253 .04867 L
.2527 .04867 L
.2527 .16187 L
s
1 .894 .882 r
.2527 .16187 m
.2527 .04873 L
.253 .04873 L
.253 .16187 L
F
.804 .522 .247 r
.2527 .16187 m
.2527 .04873 L
.253 .04873 L
.253 .16187 L
s
1 .894 .882 r
.253 .16187 m
.253 .04881 L
.25347 .04881 L
.25347 .16187 L
F
.804 .522 .247 r
.253 .16187 m
.253 .04881 L
.25347 .04881 L
.25347 .16187 L
s
1 .894 .882 r
.25347 .16187 m
.25347 .04897 L
.25386 .04897 L
.25386 .16187 L
F
.804 .522 .247 r
.25347 .16187 m
.25347 .04897 L
.25386 .04897 L
.25386 .16187 L
s
1 .894 .882 r
.25386 .16187 m
.25386 .04912 L
.2541 .04912 L
.2541 .16187 L
F
.804 .522 .247 r
.25386 .16187 m
.25386 .04912 L
.2541 .04912 L
.2541 .16187 L
s
1 .894 .882 r
.2541 .16187 m
.2541 .04917 L
.25427 .04917 L
.25427 .16187 L
F
.804 .522 .247 r
.2541 .16187 m
.2541 .04917 L
.25427 .04917 L
.25427 .16187 L
s
1 .894 .882 r
.25427 .16187 m
.25427 .04919 L
.25461 .04919 L
.25461 .16187 L
F
.804 .522 .247 r
.25427 .16187 m
.25427 .04919 L
.25461 .04919 L
.25461 .16187 L
s
1 .894 .882 r
.25461 .16187 m
.25461 .04932 L
.2549 .04932 L
.2549 .16187 L
F
.804 .522 .247 r
.25461 .16187 m
.25461 .04932 L
.2549 .04932 L
.2549 .16187 L
s
1 .894 .882 r
.2549 .16187 m
.2549 .04941 L
.25522 .04941 L
.25522 .16187 L
F
.804 .522 .247 r
.2549 .16187 m
.2549 .04941 L
.25522 .04941 L
.25522 .16187 L
s
1 .894 .882 r
.25522 .16187 m
.25522 .0495 L
.25537 .0495 L
.25537 .16187 L
F
.804 .522 .247 r
.25522 .16187 m
.25522 .0495 L
.25537 .0495 L
.25537 .16187 L
s
1 .894 .882 r
.25537 .16187 m
.25537 .04952 L
.25576 .04952 L
.25576 .16187 L
F
.804 .522 .247 r
.25537 .16187 m
.25537 .04952 L
.25576 .04952 L
.25576 .16187 L
s
1 .894 .882 r
.25576 .16187 m
.25576 .04966 L
.25598 .04966 L
.25598 .16187 L
F
.804 .522 .247 r
.25576 .16187 m
.25576 .04966 L
.25598 .04966 L
.25598 .16187 L
s
1 .894 .882 r
.25598 .16187 m
.25598 .04981 L
.25637 .04981 L
.25637 .16187 L
F
.804 .522 .247 r
.25598 .16187 m
.25598 .04981 L
.25637 .04981 L
.25637 .16187 L
s
1 .894 .882 r
.25637 .16187 m
.25637 .04988 L
.25676 .04988 L
.25676 .16187 L
F
.804 .522 .247 r
.25637 .16187 m
.25637 .04988 L
.25676 .04988 L
.25676 .16187 L
s
1 .894 .882 r
.25676 .16187 m
.25676 .04994 L
.25703 .04994 L
.25703 .16187 L
F
.804 .522 .247 r
.25676 .16187 m
.25676 .04994 L
.25703 .04994 L
.25703 .16187 L
s
1 .894 .882 r
.25703 .16187 m
.25703 .05006 L
.25724 .05006 L
.25724 .16187 L
F
.804 .522 .247 r
.25703 .16187 m
.25703 .05006 L
.25724 .05006 L
.25724 .16187 L
s
1 .894 .882 r
.25724 .16187 m
.25724 .05011 L
.25744 .05011 L
.25744 .16187 L
F
.804 .522 .247 r
.25724 .16187 m
.25724 .05011 L
.25744 .05011 L
.25744 .16187 L
s
1 .894 .882 r
.25744 .16187 m
.25744 .05014 L
.2577 .05014 L
.2577 .16187 L
F
.804 .522 .247 r
.25744 .16187 m
.25744 .05014 L
.2577 .05014 L
.2577 .16187 L
s
1 .894 .882 r
.2577 .16187 m
.2577 .05023 L
.2579 .05023 L
.2579 .16187 L
F
.804 .522 .247 r
.2577 .16187 m
.2577 .05023 L
.2579 .05023 L
.2579 .16187 L
s
1 .894 .882 r
.2579 .16187 m
.2579 .05036 L
.25827 .05036 L
.25827 .16187 L
F
.804 .522 .247 r
.2579 .16187 m
.2579 .05036 L
.25827 .05036 L
.25827 .16187 L
s
1 .894 .882 r
.25827 .16187 m
.25827 .05044 L
.25856 .05044 L
.25856 .16187 L
F
.804 .522 .247 r
.25827 .16187 m
.25827 .05044 L
.25856 .05044 L
.25856 .16187 L
s
1 .894 .882 r
.25856 .16187 m
.25856 .05048 L
.25875 .05048 L
.25875 .16187 L
F
.804 .522 .247 r
.25856 .16187 m
.25856 .05048 L
.25875 .05048 L
.25875 .16187 L
s
1 .894 .882 r
.25875 .16187 m
.25875 .05057 L
.25916 .05057 L
.25916 .16187 L
F
.804 .522 .247 r
.25875 .16187 m
.25875 .05057 L
.25916 .05057 L
.25916 .16187 L
s
1 .894 .882 r
.25916 .16187 m
.25916 .05076 L
.25957 .05076 L
.25957 .16187 L
F
.804 .522 .247 r
.25916 .16187 m
.25916 .05076 L
.25957 .05076 L
.25957 .16187 L
s
1 .894 .882 r
.25957 .16187 m
.25957 .05082 L
.25983 .05082 L
.25983 .16187 L
F
.804 .522 .247 r
.25957 .16187 m
.25957 .05082 L
.25983 .05082 L
.25983 .16187 L
s
1 .894 .882 r
.25983 .16187 m
.25983 .05097 L
.26022 .05097 L
.26022 .16187 L
F
.804 .522 .247 r
.25983 .16187 m
.25983 .05097 L
.26022 .05097 L
.26022 .16187 L
s
1 .894 .882 r
.26022 .16187 m
.26022 .05101 L
.26065 .05101 L
.26065 .16187 L
F
.804 .522 .247 r
.26022 .16187 m
.26022 .05101 L
.26065 .05101 L
.26065 .16187 L
s
1 .894 .882 r
.26065 .16187 m
.26065 .05115 L
.26082 .05115 L
.26082 .16187 L
F
.804 .522 .247 r
.26065 .16187 m
.26065 .05115 L
.26082 .05115 L
.26082 .16187 L
s
1 .894 .882 r
.26082 .16187 m
.26082 .0512 L
.26098 .0512 L
.26098 .16187 L
F
.804 .522 .247 r
.26082 .16187 m
.26082 .0512 L
.26098 .0512 L
.26098 .16187 L
s
1 .894 .882 r
.26098 .16187 m
.26098 .05124 L
.26135 .05124 L
.26135 .16187 L
F
.804 .522 .247 r
.26098 .16187 m
.26098 .05124 L
.26135 .05124 L
.26135 .16187 L
s
1 .894 .882 r
.26135 .16187 m
.26135 .05134 L
.2616 .05134 L
.2616 .16187 L
F
.804 .522 .247 r
.26135 .16187 m
.26135 .05134 L
.2616 .05134 L
.2616 .16187 L
s
1 .894 .882 r
.2616 .16187 m
.2616 .05143 L
.26196 .05143 L
.26196 .16187 L
F
.804 .522 .247 r
.2616 .16187 m
.2616 .05143 L
.26196 .05143 L
.26196 .16187 L
s
1 .894 .882 r
.26196 .16187 m
.26196 .05154 L
.2623 .05154 L
.2623 .16187 L
F
.804 .522 .247 r
.26196 .16187 m
.26196 .05154 L
.2623 .05154 L
.2623 .16187 L
s
1 .894 .882 r
.2623 .16187 m
.2623 .05167 L
.26266 .05167 L
.26266 .16187 L
F
.804 .522 .247 r
.2623 .16187 m
.2623 .05167 L
.26266 .05167 L
.26266 .16187 L
s
1 .894 .882 r
.26266 .16187 m
.26266 .05174 L
.26301 .05174 L
.26301 .16187 L
F
.804 .522 .247 r
.26266 .16187 m
.26266 .05174 L
.26301 .05174 L
.26301 .16187 L
s
1 .894 .882 r
.26301 .16187 m
.26301 .05191 L
.2633 .05191 L
.2633 .16187 L
F
.804 .522 .247 r
.26301 .16187 m
.26301 .05191 L
.2633 .05191 L
.2633 .16187 L
s
1 .894 .882 r
.2633 .16187 m
.2633 .05196 L
.26375 .05196 L
.26375 .16187 L
F
.804 .522 .247 r
.2633 .16187 m
.2633 .05196 L
.26375 .05196 L
.26375 .16187 L
s
1 .894 .882 r
.26375 .16187 m
.26375 .05219 L
.26421 .05219 L
.26421 .16187 L
F
.804 .522 .247 r
.26375 .16187 m
.26375 .05219 L
.26421 .05219 L
.26421 .16187 L
s
1 .894 .882 r
.26421 .16187 m
.26421 .05228 L
.26444 .05228 L
.26444 .16187 L
F
.804 .522 .247 r
.26421 .16187 m
.26421 .05228 L
.26444 .05228 L
.26444 .16187 L
s
1 .894 .882 r
.26444 .16187 m
.26444 .05235 L
.26466 .05235 L
.26466 .16187 L
F
.804 .522 .247 r
.26444 .16187 m
.26444 .05235 L
.26466 .05235 L
.26466 .16187 L
s
1 .894 .882 r
.26466 .16187 m
.26466 .05244 L
.26506 .05244 L
.26506 .16187 L
F
.804 .522 .247 r
.26466 .16187 m
.26466 .05244 L
.26506 .05244 L
.26506 .16187 L
s
1 .894 .882 r
.26506 .16187 m
.26506 .05257 L
.26541 .05257 L
.26541 .16187 L
F
.804 .522 .247 r
.26506 .16187 m
.26506 .05257 L
.26541 .05257 L
.26541 .16187 L
s
1 .894 .882 r
.26541 .16187 m
.26541 .05263 L
.26558 .05263 L
.26558 .16187 L
F
.804 .522 .247 r
.26541 .16187 m
.26541 .05263 L
.26558 .05263 L
.26558 .16187 L
s
1 .894 .882 r
.26558 .16187 m
.26558 .05267 L
.26592 .05267 L
.26592 .16187 L
F
.804 .522 .247 r
.26558 .16187 m
.26558 .05267 L
.26592 .05267 L
.26592 .16187 L
s
1 .894 .882 r
.26592 .16187 m
.26592 .05276 L
.26618 .05276 L
.26618 .16187 L
F
.804 .522 .247 r
.26592 .16187 m
.26592 .05276 L
.26618 .05276 L
.26618 .16187 L
s
1 .894 .882 r
.26618 .16187 m
.26618 .0529 L
.26649 .0529 L
.26649 .16187 L
F
.804 .522 .247 r
.26618 .16187 m
.26618 .0529 L
.26649 .0529 L
.26649 .16187 L
s
1 .894 .882 r
.26649 .16187 m
.26649 .05297 L
.26675 .05297 L
.26675 .16187 L
F
.804 .522 .247 r
.26649 .16187 m
.26649 .05297 L
.26675 .05297 L
.26675 .16187 L
s
1 .894 .882 r
.26675 .16187 m
.26675 .05308 L
.26717 .05308 L
.26717 .16187 L
F
.804 .522 .247 r
.26675 .16187 m
.26675 .05308 L
.26717 .05308 L
.26717 .16187 L
s
1 .894 .882 r
.26717 .16187 m
.26717 .05318 L
.26732 .05318 L
.26732 .16187 L
F
.804 .522 .247 r
.26717 .16187 m
.26717 .05318 L
.26732 .05318 L
.26732 .16187 L
s
1 .894 .882 r
.26732 .16187 m
.26732 .0533 L
.26773 .0533 L
.26773 .16187 L
F
.804 .522 .247 r
.26732 .16187 m
.26732 .0533 L
.26773 .0533 L
.26773 .16187 L
s
1 .894 .882 r
.26773 .16187 m
.26773 .05335 L
.26804 .05335 L
.26804 .16187 L
F
.804 .522 .247 r
.26773 .16187 m
.26773 .05335 L
.26804 .05335 L
.26804 .16187 L
s
1 .894 .882 r
.26804 .16187 m
.26804 .05354 L
.26845 .05354 L
.26845 .16187 L
F
.804 .522 .247 r
.26804 .16187 m
.26804 .05354 L
.26845 .05354 L
.26845 .16187 L
s
1 .894 .882 r
.26845 .16187 m
.26845 .05358 L
.26893 .05358 L
.26893 .16187 L
F
.804 .522 .247 r
.26845 .16187 m
.26845 .05358 L
.26893 .05358 L
.26893 .16187 L
s
1 .894 .882 r
.26893 .16187 m
.26893 .05374 L
.26911 .05374 L
.26911 .16187 L
F
.804 .522 .247 r
.26893 .16187 m
.26893 .05374 L
.26911 .05374 L
.26911 .16187 L
s
1 .894 .882 r
.26911 .16187 m
.26911 .05377 L
.26933 .05377 L
.26933 .16187 L
F
.804 .522 .247 r
.26911 .16187 m
.26911 .05377 L
.26933 .05377 L
.26933 .16187 L
s
1 .894 .882 r
.26933 .16187 m
.26933 .05388 L
.26953 .05388 L
.26953 .16187 L
F
.804 .522 .247 r
.26933 .16187 m
.26933 .05388 L
.26953 .05388 L
.26953 .16187 L
s
1 .894 .882 r
.26953 .16187 m
.26953 .0539 L
.2698 .0539 L
.2698 .16187 L
F
.804 .522 .247 r
.26953 .16187 m
.26953 .0539 L
.2698 .0539 L
.2698 .16187 L
s
1 .894 .882 r
.2698 .16187 m
.2698 .05401 L
.27012 .05401 L
.27012 .16187 L
F
.804 .522 .247 r
.2698 .16187 m
.2698 .05401 L
.27012 .05401 L
.27012 .16187 L
s
1 .894 .882 r
.27012 .16187 m
.27012 .0541 L
.27048 .0541 L
.27048 .16187 L
F
.804 .522 .247 r
.27012 .16187 m
.27012 .0541 L
.27048 .0541 L
.27048 .16187 L
s
1 .894 .882 r
.27048 .16187 m
.27048 .0542 L
.27089 .0542 L
.27089 .16187 L
F
.804 .522 .247 r
.27048 .16187 m
.27048 .0542 L
.27089 .0542 L
.27089 .16187 L
s
1 .894 .882 r
.27089 .16187 m
.27089 .05442 L
.2712 .05442 L
.2712 .16187 L
F
.804 .522 .247 r
.27089 .16187 m
.27089 .05442 L
.2712 .05442 L
.2712 .16187 L
s
1 .894 .882 r
.2712 .16187 m
.2712 .05448 L
.27155 .05448 L
.27155 .16187 L
F
.804 .522 .247 r
.2712 .16187 m
.2712 .05448 L
.27155 .05448 L
.27155 .16187 L
s
1 .894 .882 r
.27155 .16187 m
.27155 .05457 L
.27183 .05457 L
.27183 .16187 L
F
.804 .522 .247 r
.27155 .16187 m
.27155 .05457 L
.27183 .05457 L
.27183 .16187 L
s
1 .894 .882 r
.27183 .16187 m
.27183 .05464 L
.27216 .05464 L
.27216 .16187 L
F
.804 .522 .247 r
.27183 .16187 m
.27183 .05464 L
.27216 .05464 L
.27216 .16187 L
s
1 .894 .882 r
.27216 .16187 m
.27216 .05476 L
.27258 .05476 L
.27258 .16187 L
F
.804 .522 .247 r
.27216 .16187 m
.27216 .05476 L
.27258 .05476 L
.27258 .16187 L
s
1 .894 .882 r
.27258 .16187 m
.27258 .05497 L
.27307 .05497 L
.27307 .16187 L
F
.804 .522 .247 r
.27258 .16187 m
.27258 .05497 L
.27307 .05497 L
.27307 .16187 L
s
1 .894 .882 r
.27307 .16187 m
.27307 .05508 L
.27332 .05508 L
.27332 .16187 L
F
.804 .522 .247 r
.27307 .16187 m
.27307 .05508 L
.27332 .05508 L
.27332 .16187 L
s
1 .894 .882 r
.27332 .16187 m
.27332 .05524 L
.2738 .05524 L
.2738 .16187 L
F
.804 .522 .247 r
.27332 .16187 m
.27332 .05524 L
.2738 .05524 L
.2738 .16187 L
s
1 .894 .882 r
.2738 .16187 m
.2738 .05528 L
.2741 .05528 L
.2741 .16187 L
F
.804 .522 .247 r
.2738 .16187 m
.2738 .05528 L
.2741 .05528 L
.2741 .16187 L
s
1 .894 .882 r
.2741 .16187 m
.2741 .05546 L
.27444 .05546 L
.27444 .16187 L
F
.804 .522 .247 r
.2741 .16187 m
.2741 .05546 L
.27444 .05546 L
.27444 .16187 L
s
1 .894 .882 r
.27444 .16187 m
.27444 .0555 L
.27492 .0555 L
.27492 .16187 L
F
.804 .522 .247 r
.27444 .16187 m
.27444 .0555 L
.27492 .0555 L
.27492 .16187 L
s
1 .894 .882 r
.27492 .16187 m
.27492 .05566 L
.27513 .05566 L
.27513 .16187 L
F
.804 .522 .247 r
.27492 .16187 m
.27492 .05566 L
.27513 .05566 L
.27513 .16187 L
s
1 .894 .882 r
.27513 .16187 m
.27513 .05573 L
.27543 .05573 L
.27543 .16187 L
F
.804 .522 .247 r
.27513 .16187 m
.27513 .05573 L
.27543 .05573 L
.27543 .16187 L
s
1 .894 .882 r
.27543 .16187 m
.27543 .05581 L
.27584 .05581 L
.27584 .16187 L
F
.804 .522 .247 r
.27543 .16187 m
.27543 .05581 L
.27584 .05581 L
.27584 .16187 L
s
1 .894 .882 r
.27584 .16187 m
.27584 .05603 L
.27616 .05603 L
.27616 .16187 L
F
.804 .522 .247 r
.27584 .16187 m
.27584 .05603 L
.27616 .05603 L
.27616 .16187 L
s
1 .894 .882 r
.27616 .16187 m
.27616 .05609 L
.27645 .05609 L
.27645 .16187 L
F
.804 .522 .247 r
.27616 .16187 m
.27616 .05609 L
.27645 .05609 L
.27645 .16187 L
s
1 .894 .882 r
.27645 .16187 m
.27645 .05615 L
.27677 .05615 L
.27677 .16187 L
F
.804 .522 .247 r
.27645 .16187 m
.27645 .05615 L
.27677 .05615 L
.27677 .16187 L
s
1 .894 .882 r
.27677 .16187 m
.27677 .0563 L
.27715 .0563 L
.27715 .16187 L
F
.804 .522 .247 r
.27677 .16187 m
.27677 .0563 L
.27715 .0563 L
.27715 .16187 L
s
1 .894 .882 r
.27715 .16187 m
.27715 .05643 L
.2774 .05643 L
.2774 .16187 L
F
.804 .522 .247 r
.27715 .16187 m
.27715 .05643 L
.2774 .05643 L
.2774 .16187 L
s
1 .894 .882 r
.2774 .16187 m
.2774 .05651 L
.27763 .05651 L
.27763 .16187 L
F
.804 .522 .247 r
.2774 .16187 m
.2774 .05651 L
.27763 .05651 L
.27763 .16187 L
s
1 .894 .882 r
.27763 .16187 m
.27763 .05653 L
.27782 .05653 L
.27782 .16187 L
F
.804 .522 .247 r
.27763 .16187 m
.27763 .05653 L
.27782 .05653 L
.27782 .16187 L
s
1 .894 .882 r
.27782 .16187 m
.27782 .05661 L
.27803 .05661 L
.27803 .16187 L
F
.804 .522 .247 r
.27782 .16187 m
.27782 .05661 L
.27803 .05661 L
.27803 .16187 L
s
1 .894 .882 r
.27803 .16187 m
.27803 .05673 L
.27842 .05673 L
.27842 .16187 L
F
.804 .522 .247 r
.27803 .16187 m
.27803 .05673 L
.27842 .05673 L
.27842 .16187 L
s
1 .894 .882 r
.27842 .16187 m
.27842 .05686 L
.27874 .05686 L
.27874 .16187 L
F
.804 .522 .247 r
.27842 .16187 m
.27842 .05686 L
.27874 .05686 L
.27874 .16187 L
s
1 .894 .882 r
.27874 .16187 m
.27874 .05692 L
.2791 .05692 L
.2791 .16187 L
F
.804 .522 .247 r
.27874 .16187 m
.27874 .05692 L
.2791 .05692 L
.2791 .16187 L
s
1 .894 .882 r
.2791 .16187 m
.2791 .05711 L
.27945 .05711 L
.27945 .16187 L
F
.804 .522 .247 r
.2791 .16187 m
.2791 .05711 L
.27945 .05711 L
.27945 .16187 L
s
1 .894 .882 r
.27945 .16187 m
.27945 .05716 L
.27971 .05716 L
.27971 .16187 L
F
.804 .522 .247 r
.27945 .16187 m
.27945 .05716 L
.27971 .05716 L
.27971 .16187 L
s
1 .894 .882 r
.27971 .16187 m
.27971 .05732 L
.28019 .05732 L
.28019 .16187 L
F
.804 .522 .247 r
.27971 .16187 m
.27971 .05732 L
.28019 .05732 L
.28019 .16187 L
s
1 .894 .882 r
.28019 .16187 m
.28019 .05739 L
.28063 .05739 L
.28063 .16187 L
F
.804 .522 .247 r
.28019 .16187 m
.28019 .05739 L
.28063 .05739 L
.28063 .16187 L
s
1 .894 .882 r
.28063 .16187 m
.28063 .05755 L
.28098 .05755 L
.28098 .16187 L
F
.804 .522 .247 r
.28063 .16187 m
.28063 .05755 L
.28098 .05755 L
.28098 .16187 L
s
1 .894 .882 r
.28098 .16187 m
.28098 .05768 L
.28114 .05768 L
.28114 .16187 L
F
.804 .522 .247 r
.28098 .16187 m
.28098 .05768 L
.28114 .05768 L
.28114 .16187 L
s
1 .894 .882 r
.28114 .16187 m
.28114 .05783 L
.28163 .05783 L
.28163 .16187 L
F
.804 .522 .247 r
.28114 .16187 m
.28114 .05783 L
.28163 .05783 L
.28163 .16187 L
s
1 .894 .882 r
.28163 .16187 m
.28163 .05786 L
.28192 .05786 L
.28192 .16187 L
F
.804 .522 .247 r
.28163 .16187 m
.28163 .05786 L
.28192 .05786 L
.28192 .16187 L
s
1 .894 .882 r
.28192 .16187 m
.28192 .05797 L
.28208 .05797 L
.28208 .16187 L
F
.804 .522 .247 r
.28192 .16187 m
.28192 .05797 L
.28208 .05797 L
.28208 .16187 L
s
1 .894 .882 r
.28208 .16187 m
.28208 .05804 L
.28225 .05804 L
.28225 .16187 L
F
.804 .522 .247 r
.28208 .16187 m
.28208 .05804 L
.28225 .05804 L
.28225 .16187 L
s
1 .894 .882 r
.28225 .16187 m
.28225 .05813 L
.28268 .05813 L
.28268 .16187 L
F
.804 .522 .247 r
.28225 .16187 m
.28225 .05813 L
.28268 .05813 L
.28268 .16187 L
s
1 .894 .882 r
.28268 .16187 m
.28268 .05832 L
.28316 .05832 L
.28316 .16187 L
F
.804 .522 .247 r
.28268 .16187 m
.28268 .05832 L
.28316 .05832 L
.28316 .16187 L
s
1 .894 .882 r
.28316 .16187 m
.28316 .05839 L
.2834 .05839 L
.2834 .16187 L
F
.804 .522 .247 r
.28316 .16187 m
.28316 .05839 L
.2834 .05839 L
.2834 .16187 L
s
1 .894 .882 r
.2834 .16187 m
.2834 .05854 L
.28374 .05854 L
.28374 .16187 L
F
.804 .522 .247 r
.2834 .16187 m
.2834 .05854 L
.28374 .05854 L
.28374 .16187 L
s
1 .894 .882 r
.28374 .16187 m
.28374 .05856 L
.28402 .05856 L
.28402 .16187 L
F
.804 .522 .247 r
.28374 .16187 m
.28374 .05856 L
.28402 .05856 L
.28402 .16187 L
s
1 .894 .882 r
.28402 .16187 m
.28402 .05872 L
.28434 .05872 L
.28434 .16187 L
F
.804 .522 .247 r
.28402 .16187 m
.28402 .05872 L
.28434 .05872 L
.28434 .16187 L
s
1 .894 .882 r
.28434 .16187 m
.28434 .05886 L
.28469 .05886 L
.28469 .16187 L
F
.804 .522 .247 r
.28434 .16187 m
.28434 .05886 L
.28469 .05886 L
.28469 .16187 L
s
1 .894 .882 r
.28469 .16187 m
.28469 .05888 L
.28493 .05888 L
.28493 .16187 L
F
.804 .522 .247 r
.28469 .16187 m
.28469 .05888 L
.28493 .05888 L
.28493 .16187 L
s
1 .894 .882 r
.28493 .16187 m
.28493 .05898 L
.28512 .05898 L
.28512 .16187 L
F
.804 .522 .247 r
.28493 .16187 m
.28493 .05898 L
.28512 .05898 L
.28512 .16187 L
s
1 .894 .882 r
.28512 .16187 m
.28512 .05907 L
.2854 .05907 L
.2854 .16187 L
F
.804 .522 .247 r
.28512 .16187 m
.28512 .05907 L
.2854 .05907 L
.2854 .16187 L
s
1 .894 .882 r
.2854 .16187 m
.2854 .05918 L
.28569 .05918 L
.28569 .16187 L
F
.804 .522 .247 r
.2854 .16187 m
.2854 .05918 L
.28569 .05918 L
.28569 .16187 L
s
1 .894 .882 r
.28569 .16187 m
.28569 .05927 L
.28604 .05927 L
.28604 .16187 L
F
.804 .522 .247 r
.28569 .16187 m
.28569 .05927 L
.28604 .05927 L
.28604 .16187 L
s
1 .894 .882 r
.28604 .16187 m
.28604 .0594 L
.2864 .0594 L
.2864 .16187 L
F
.804 .522 .247 r
.28604 .16187 m
.28604 .0594 L
.2864 .0594 L
.2864 .16187 L
s
1 .894 .882 r
.2864 .16187 m
.2864 .05948 L
.2868 .05948 L
.2868 .16187 L
F
.804 .522 .247 r
.2864 .16187 m
.2864 .05948 L
.2868 .05948 L
.2868 .16187 L
s
1 .894 .882 r
.2868 .16187 m
.2868 .0597 L
.28723 .0597 L
.28723 .16187 L
F
.804 .522 .247 r
.2868 .16187 m
.2868 .0597 L
.28723 .0597 L
.28723 .16187 L
s
1 .894 .882 r
.28723 .16187 m
.28723 .05975 L
.28747 .05975 L
.28747 .16187 L
F
.804 .522 .247 r
.28723 .16187 m
.28723 .05975 L
.28747 .05975 L
.28747 .16187 L
s
1 .894 .882 r
.28747 .16187 m
.28747 .05993 L
.28785 .05993 L
.28785 .16187 L
F
.804 .522 .247 r
.28747 .16187 m
.28747 .05993 L
.28785 .05993 L
.28785 .16187 L
s
1 .894 .882 r
.28785 .16187 m
.28785 .05996 L
.2883 .05996 L
.2883 .16187 L
F
.804 .522 .247 r
.28785 .16187 m
.28785 .05996 L
.2883 .05996 L
.2883 .16187 L
s
1 .894 .882 r
.2883 .16187 m
.2883 .06014 L
.28853 .06014 L
.28853 .16187 L
F
.804 .522 .247 r
.2883 .16187 m
.2883 .06014 L
.28853 .06014 L
.28853 .16187 L
s
1 .894 .882 r
.28853 .16187 m
.28853 .06021 L
.28876 .06021 L
.28876 .16187 L
F
.804 .522 .247 r
.28853 .16187 m
.28853 .06021 L
.28876 .06021 L
.28876 .16187 L
s
1 .894 .882 r
.28876 .16187 m
.28876 .06039 L
.28914 .06039 L
.28914 .16187 L
F
.804 .522 .247 r
.28876 .16187 m
.28876 .06039 L
.28914 .06039 L
.28914 .16187 L
s
1 .894 .882 r
.28914 .16187 m
.28914 .0605 L
.28944 .0605 L
.28944 .16187 L
F
.804 .522 .247 r
.28914 .16187 m
.28914 .0605 L
.28944 .0605 L
.28944 .16187 L
s
1 .894 .882 r
.28944 .16187 m
.28944 .06058 L
.28966 .06058 L
.28966 .16187 L
F
.804 .522 .247 r
.28944 .16187 m
.28944 .06058 L
.28966 .06058 L
.28966 .16187 L
s
1 .894 .882 r
.28966 .16187 m
.28966 .06062 L
.28987 .06062 L
.28987 .16187 L
F
.804 .522 .247 r
.28966 .16187 m
.28966 .06062 L
.28987 .06062 L
.28987 .16187 L
s
1 .894 .882 r
.28987 .16187 m
.28987 .06072 L
.29031 .06072 L
.29031 .16187 L
F
.804 .522 .247 r
.28987 .16187 m
.28987 .06072 L
.29031 .06072 L
.29031 .16187 L
s
1 .894 .882 r
.29031 .16187 m
.29031 .06083 L
.29062 .06083 L
.29062 .16187 L
F
.804 .522 .247 r
.29031 .16187 m
.29031 .06083 L
.29062 .06083 L
.29062 .16187 L
s
1 .894 .882 r
.29062 .16187 m
.29062 .06102 L
.29109 .06102 L
.29109 .16187 L
F
.804 .522 .247 r
.29062 .16187 m
.29062 .06102 L
.29109 .06102 L
.29109 .16187 L
s
1 .894 .882 r
.29109 .16187 m
.29109 .06117 L
.29146 .06117 L
.29146 .16187 L
F
.804 .522 .247 r
.29109 .16187 m
.29109 .06117 L
.29146 .06117 L
.29146 .16187 L
s
1 .894 .882 r
.29146 .16187 m
.29146 .06124 L
.29177 .06124 L
.29177 .16187 L
F
.804 .522 .247 r
.29146 .16187 m
.29146 .06124 L
.29177 .06124 L
.29177 .16187 L
s
1 .894 .882 r
.29177 .16187 m
.29177 .06142 L
.29225 .06142 L
.29225 .16187 L
F
.804 .522 .247 r
.29177 .16187 m
.29177 .06142 L
.29225 .06142 L
.29225 .16187 L
s
1 .894 .882 r
.29225 .16187 m
.29225 .06155 L
.29252 .06155 L
.29252 .16187 L
F
.804 .522 .247 r
.29225 .16187 m
.29225 .06155 L
.29252 .06155 L
.29252 .16187 L
s
1 .894 .882 r
.29252 .16187 m
.29252 .06164 L
.29279 .06164 L
.29279 .16187 L
F
.804 .522 .247 r
.29252 .16187 m
.29252 .06164 L
.29279 .06164 L
.29279 .16187 L
s
1 .894 .882 r
.29279 .16187 m
.29279 .06168 L
.29306 .06168 L
.29306 .16187 L
F
.804 .522 .247 r
.29279 .16187 m
.29279 .06168 L
.29306 .06168 L
.29306 .16187 L
s
1 .894 .882 r
.29306 .16187 m
.29306 .06178 L
.29342 .06178 L
.29342 .16187 L
F
.804 .522 .247 r
.29306 .16187 m
.29306 .06178 L
.29342 .06178 L
.29342 .16187 L
s
1 .894 .882 r
.29342 .16187 m
.29342 .06192 L
.29389 .06192 L
.29389 .16187 L
F
.804 .522 .247 r
.29342 .16187 m
.29342 .06192 L
.29389 .06192 L
.29389 .16187 L
s
1 .894 .882 r
.29389 .16187 m
.29389 .06209 L
.2943 .06209 L
.2943 .16187 L
F
.804 .522 .247 r
.29389 .16187 m
.29389 .06209 L
.2943 .06209 L
.2943 .16187 L
s
1 .894 .882 r
.2943 .16187 m
.2943 .06229 L
.29469 .06229 L
.29469 .16187 L
F
.804 .522 .247 r
.2943 .16187 m
.2943 .06229 L
.29469 .06229 L
.29469 .16187 L
s
1 .894 .882 r
.29469 .16187 m
.29469 .06234 L
.29514 .06234 L
.29514 .16187 L
F
.804 .522 .247 r
.29469 .16187 m
.29469 .06234 L
.29514 .06234 L
.29514 .16187 L
s
1 .894 .882 r
.29514 .16187 m
.29514 .06252 L
.29533 .06252 L
.29533 .16187 L
F
.804 .522 .247 r
.29514 .16187 m
.29514 .06252 L
.29533 .06252 L
.29533 .16187 L
s
1 .894 .882 r
.29533 .16187 m
.29533 .06258 L
.29565 .06258 L
.29565 .16187 L
F
.804 .522 .247 r
.29533 .16187 m
.29533 .06258 L
.29565 .06258 L
.29565 .16187 L
s
1 .894 .882 r
.29565 .16187 m
.29565 .06272 L
.29582 .06272 L
.29582 .16187 L
F
.804 .522 .247 r
.29565 .16187 m
.29565 .06272 L
.29582 .06272 L
.29582 .16187 L
s
1 .894 .882 r
.29582 .16187 m
.29582 .06273 L
.29597 .06273 L
.29597 .16187 L
F
.804 .522 .247 r
.29582 .16187 m
.29582 .06273 L
.29597 .06273 L
.29597 .16187 L
s
1 .894 .882 r
.29597 .16187 m
.29597 .0628 L
.29642 .0628 L
.29642 .16187 L
F
.804 .522 .247 r
.29597 .16187 m
.29597 .0628 L
.29642 .0628 L
.29642 .16187 L
s
1 .894 .882 r
.29642 .16187 m
.29642 .06302 L
.29665 .06302 L
.29665 .16187 L
F
.804 .522 .247 r
.29642 .16187 m
.29642 .06302 L
.29665 .06302 L
.29665 .16187 L
s
1 .894 .882 r
.29665 .16187 m
.29665 .06312 L
.29694 .06312 L
.29694 .16187 L
F
.804 .522 .247 r
.29665 .16187 m
.29665 .06312 L
.29694 .06312 L
.29694 .16187 L
s
1 .894 .882 r
.29694 .16187 m
.29694 .06314 L
.29727 .06314 L
.29727 .16187 L
F
.804 .522 .247 r
.29694 .16187 m
.29694 .06314 L
.29727 .06314 L
.29727 .16187 L
s
1 .894 .882 r
.29727 .16187 m
.29727 .06326 L
.29765 .06326 L
.29765 .16187 L
F
.804 .522 .247 r
.29727 .16187 m
.29727 .06326 L
.29765 .06326 L
.29765 .16187 L
s
1 .894 .882 r
.29765 .16187 m
.29765 .0634 L
.29782 .0634 L
.29782 .16187 L
F
.804 .522 .247 r
.29765 .16187 m
.29765 .0634 L
.29782 .0634 L
.29782 .16187 L
s
1 .894 .882 r
.29782 .16187 m
.29782 .06351 L
.29815 .06351 L
.29815 .16187 L
F
.804 .522 .247 r
.29782 .16187 m
.29782 .06351 L
.29815 .06351 L
.29815 .16187 L
s
1 .894 .882 r
.29815 .16187 m
.29815 .06361 L
.29833 .06361 L
.29833 .16187 L
F
.804 .522 .247 r
.29815 .16187 m
.29815 .06361 L
.29833 .06361 L
.29833 .16187 L
s
1 .894 .882 r
.29833 .16187 m
.29833 .06368 L
.29873 .06368 L
.29873 .16187 L
F
.804 .522 .247 r
.29833 .16187 m
.29833 .06368 L
.29873 .06368 L
.29873 .16187 L
s
1 .894 .882 r
.29873 .16187 m
.29873 .06383 L
.29903 .06383 L
.29903 .16187 L
F
.804 .522 .247 r
.29873 .16187 m
.29873 .06383 L
.29903 .06383 L
.29903 .16187 L
s
1 .894 .882 r
.29903 .16187 m
.29903 .06388 L
.2992 .06388 L
.2992 .16187 L
F
.804 .522 .247 r
.29903 .16187 m
.29903 .06388 L
.2992 .06388 L
.2992 .16187 L
s
1 .894 .882 r
.2992 .16187 m
.2992 .06395 L
.29938 .06395 L
.29938 .16187 L
F
.804 .522 .247 r
.2992 .16187 m
.2992 .06395 L
.29938 .06395 L
.29938 .16187 L
s
1 .894 .882 r
.29938 .16187 m
.29938 .06406 L
.29966 .06406 L
.29966 .16187 L
F
.804 .522 .247 r
.29938 .16187 m
.29938 .06406 L
.29966 .06406 L
.29966 .16187 L
s
1 .894 .882 r
.29966 .16187 m
.29966 .06415 L
.29983 .06415 L
.29983 .16187 L
F
.804 .522 .247 r
.29966 .16187 m
.29966 .06415 L
.29983 .06415 L
.29983 .16187 L
s
1 .894 .882 r
.29983 .16187 m
.29983 .06416 L
.30023 .06416 L
.30023 .16187 L
F
.804 .522 .247 r
.29983 .16187 m
.29983 .06416 L
.30023 .06416 L
.30023 .16187 L
s
1 .894 .882 r
.30023 .16187 m
.30023 .06431 L
.30054 .06431 L
.30054 .16187 L
F
.804 .522 .247 r
.30023 .16187 m
.30023 .06431 L
.30054 .06431 L
.30054 .16187 L
s
1 .894 .882 r
.30054 .16187 m
.30054 .06446 L
.30084 .06446 L
.30084 .16187 L
F
.804 .522 .247 r
.30054 .16187 m
.30054 .06446 L
.30084 .06446 L
.30084 .16187 L
s
1 .894 .882 r
.30084 .16187 m
.30084 .06458 L
.30109 .06458 L
.30109 .16187 L
F
.804 .522 .247 r
.30084 .16187 m
.30084 .06458 L
.30109 .06458 L
.30109 .16187 L
s
1 .894 .882 r
.30109 .16187 m
.30109 .06463 L
.30125 .06463 L
.30125 .16187 L
F
.804 .522 .247 r
.30109 .16187 m
.30109 .06463 L
.30125 .06463 L
.30125 .16187 L
s
1 .894 .882 r
.30125 .16187 m
.30125 .06479 L
.30161 .06479 L
.30161 .16187 L
F
.804 .522 .247 r
.30125 .16187 m
.30125 .06479 L
.30161 .06479 L
.30161 .16187 L
s
1 .894 .882 r
.30161 .16187 m
.30161 .06488 L
.30187 .06488 L
.30187 .16187 L
F
.804 .522 .247 r
.30161 .16187 m
.30161 .06488 L
.30187 .06488 L
.30187 .16187 L
s
1 .894 .882 r
.30187 .16187 m
.30187 .06495 L
.30229 .06495 L
.30229 .16187 L
F
.804 .522 .247 r
.30187 .16187 m
.30187 .06495 L
.30229 .06495 L
.30229 .16187 L
s
1 .894 .882 r
.30229 .16187 m
.30229 .06512 L
.30277 .06512 L
.30277 .16187 L
F
.804 .522 .247 r
.30229 .16187 m
.30229 .06512 L
.30277 .06512 L
.30277 .16187 L
s
1 .894 .882 r
.30277 .16187 m
.30277 .06534 L
.30312 .06534 L
.30312 .16187 L
F
.804 .522 .247 r
.30277 .16187 m
.30277 .06534 L
.30312 .06534 L
.30312 .16187 L
s
1 .894 .882 r
.30312 .16187 m
.30312 .06544 L
.30343 .06544 L
.30343 .16187 L
F
.804 .522 .247 r
.30312 .16187 m
.30312 .06544 L
.30343 .06544 L
.30343 .16187 L
s
1 .894 .882 r
.30343 .16187 m
.30343 .06551 L
.30376 .06551 L
.30376 .16187 L
F
.804 .522 .247 r
.30343 .16187 m
.30343 .06551 L
.30376 .06551 L
.30376 .16187 L
s
1 .894 .882 r
.30376 .16187 m
.30376 .06564 L
.30411 .06564 L
.30411 .16187 L
F
.804 .522 .247 r
.30376 .16187 m
.30376 .06564 L
.30411 .06564 L
.30411 .16187 L
s
1 .894 .882 r
.30411 .16187 m
.30411 .06575 L
.30427 .06575 L
.30427 .16187 L
F
.804 .522 .247 r
.30411 .16187 m
.30411 .06575 L
.30427 .06575 L
.30427 .16187 L
s
1 .894 .882 r
.30427 .16187 m
.30427 .06588 L
.30469 .06588 L
.30469 .16187 L
F
.804 .522 .247 r
.30427 .16187 m
.30427 .06588 L
.30469 .06588 L
.30469 .16187 L
s
1 .894 .882 r
.30469 .16187 m
.30469 .06592 L
.305 .06592 L
.305 .16187 L
F
.804 .522 .247 r
.30469 .16187 m
.30469 .06592 L
.305 .06592 L
.305 .16187 L
s
1 .894 .882 r
.305 .16187 m
.305 .06608 L
.30517 .06608 L
.30517 .16187 L
F
.804 .522 .247 r
.305 .16187 m
.305 .06608 L
.30517 .06608 L
.30517 .16187 L
s
1 .894 .882 r
.30517 .16187 m
.30517 .06625 L
.30565 .06625 L
.30565 .16187 L
F
.804 .522 .247 r
.30517 .16187 m
.30517 .06625 L
.30565 .06625 L
.30565 .16187 L
s
1 .894 .882 r
.30565 .16187 m
.30565 .06628 L
.30581 .06628 L
.30581 .16187 L
F
.804 .522 .247 r
.30565 .16187 m
.30565 .06628 L
.30581 .06628 L
.30581 .16187 L
s
1 .894 .882 r
.30581 .16187 m
.30581 .06634 L
.30597 .06634 L
.30597 .16187 L
F
.804 .522 .247 r
.30581 .16187 m
.30581 .06634 L
.30597 .06634 L
.30597 .16187 L
s
1 .894 .882 r
.30597 .16187 m
.30597 .06652 L
.30646 .06652 L
.30646 .16187 L
F
.804 .522 .247 r
.30597 .16187 m
.30597 .06652 L
.30646 .06652 L
.30646 .16187 L
s
1 .894 .882 r
.30646 .16187 m
.30646 .06667 L
.30691 .06667 L
.30691 .16187 L
F
.804 .522 .247 r
.30646 .16187 m
.30646 .06667 L
.30691 .06667 L
.30691 .16187 L
s
1 .894 .882 r
.30691 .16187 m
.30691 .06681 L
.30728 .06681 L
.30728 .16187 L
F
.804 .522 .247 r
.30691 .16187 m
.30691 .06681 L
.30728 .06681 L
.30728 .16187 L
s
1 .894 .882 r
.30728 .16187 m
.30728 .06694 L
.30776 .06694 L
.30776 .16187 L
F
.804 .522 .247 r
.30728 .16187 m
.30728 .06694 L
.30776 .06694 L
.30776 .16187 L
s
1 .894 .882 r
.30776 .16187 m
.30776 .0671 L
.308 .0671 L
.308 .16187 L
F
.804 .522 .247 r
.30776 .16187 m
.30776 .0671 L
.308 .0671 L
.308 .16187 L
s
1 .894 .882 r
.308 .16187 m
.308 .06719 L
.30828 .06719 L
.30828 .16187 L
F
.804 .522 .247 r
.308 .16187 m
.308 .06719 L
.30828 .06719 L
.30828 .16187 L
s
1 .894 .882 r
.30828 .16187 m
.30828 .06725 L
.3085 .06725 L
.3085 .16187 L
F
.804 .522 .247 r
.30828 .16187 m
.30828 .06725 L
.3085 .06725 L
.3085 .16187 L
s
1 .894 .882 r
.3085 .16187 m
.3085 .06742 L
.30888 .06742 L
.30888 .16187 L
F
.804 .522 .247 r
.3085 .16187 m
.3085 .06742 L
.30888 .06742 L
.30888 .16187 L
s
1 .894 .882 r
.30888 .16187 m
.30888 .06748 L
.3091 .06748 L
.3091 .16187 L
F
.804 .522 .247 r
.30888 .16187 m
.30888 .06748 L
.3091 .06748 L
.3091 .16187 L
s
1 .894 .882 r
.3091 .16187 m
.3091 .06764 L
.30953 .06764 L
.30953 .16187 L
F
.804 .522 .247 r
.3091 .16187 m
.3091 .06764 L
.30953 .06764 L
.30953 .16187 L
s
1 .894 .882 r
.30953 .16187 m
.30953 .06773 L
.30998 .06773 L
.30998 .16187 L
F
.804 .522 .247 r
.30953 .16187 m
.30953 .06773 L
.30998 .06773 L
.30998 .16187 L
s
1 .894 .882 r
.30998 .16187 m
.30998 .06792 L
.31042 .06792 L
.31042 .16187 L
F
.804 .522 .247 r
.30998 .16187 m
.30998 .06792 L
.31042 .06792 L
.31042 .16187 L
s
1 .894 .882 r
.31042 .16187 m
.31042 .06811 L
.31066 .06811 L
.31066 .16187 L
F
.804 .522 .247 r
.31042 .16187 m
.31042 .06811 L
.31066 .06811 L
.31066 .16187 L
s
1 .894 .882 r
.31066 .16187 m
.31066 .06817 L
.31088 .06817 L
.31088 .16187 L
F
.804 .522 .247 r
.31066 .16187 m
.31066 .06817 L
.31088 .06817 L
.31088 .16187 L
s
1 .894 .882 r
.31088 .16187 m
.31088 .06823 L
.31117 .06823 L
.31117 .16187 L
F
.804 .522 .247 r
.31088 .16187 m
.31088 .06823 L
.31117 .06823 L
.31117 .16187 L
s
1 .894 .882 r
.31117 .16187 m
.31117 .0684 L
.31144 .0684 L
.31144 .16187 L
F
.804 .522 .247 r
.31117 .16187 m
.31117 .0684 L
.31144 .0684 L
.31144 .16187 L
s
1 .894 .882 r
.31144 .16187 m
.31144 .06846 L
.31182 .06846 L
.31182 .16187 L
F
.804 .522 .247 r
.31144 .16187 m
.31144 .06846 L
.31182 .06846 L
.31182 .16187 L
s
1 .894 .882 r
.31182 .16187 m
.31182 .06861 L
.31202 .06861 L
.31202 .16187 L
F
.804 .522 .247 r
.31182 .16187 m
.31182 .06861 L
.31202 .06861 L
.31202 .16187 L
s
1 .894 .882 r
.31202 .16187 m
.31202 .0687 L
.31239 .0687 L
.31239 .16187 L
F
.804 .522 .247 r
.31202 .16187 m
.31202 .0687 L
.31239 .0687 L
.31239 .16187 L
s
1 .894 .882 r
.31239 .16187 m
.31239 .06891 L
.31284 .06891 L
.31284 .16187 L
F
.804 .522 .247 r
.31239 .16187 m
.31239 .06891 L
.31284 .06891 L
.31284 .16187 L
s
1 .894 .882 r
.31284 .16187 m
.31284 .06899 L
.3132 .06899 L
.3132 .16187 L
F
.804 .522 .247 r
.31284 .16187 m
.31284 .06899 L
.3132 .06899 L
.3132 .16187 L
s
1 .894 .882 r
.3132 .16187 m
.3132 .06913 L
.31341 .06913 L
.31341 .16187 L
F
.804 .522 .247 r
.3132 .16187 m
.3132 .06913 L
.31341 .06913 L
.31341 .16187 L
s
1 .894 .882 r
.31341 .16187 m
.31341 .06917 L
.31377 .06917 L
.31377 .16187 L
F
.804 .522 .247 r
.31341 .16187 m
.31341 .06917 L
.31377 .06917 L
.31377 .16187 L
s
1 .894 .882 r
.31377 .16187 m
.31377 .06936 L
.3142 .06936 L
.3142 .16187 L
F
.804 .522 .247 r
.31377 .16187 m
.31377 .06936 L
.3142 .06936 L
.3142 .16187 L
s
1 .894 .882 r
.3142 .16187 m
.3142 .06953 L
.31456 .06953 L
.31456 .16187 L
F
.804 .522 .247 r
.3142 .16187 m
.3142 .06953 L
.31456 .06953 L
.31456 .16187 L
s
1 .894 .882 r
.31456 .16187 m
.31456 .06959 L
.31481 .06959 L
.31481 .16187 L
F
.804 .522 .247 r
.31456 .16187 m
.31456 .06959 L
.31481 .06959 L
.31481 .16187 L
s
1 .894 .882 r
.31481 .16187 m
.31481 .06978 L
.31529 .06978 L
.31529 .16187 L
F
.804 .522 .247 r
.31481 .16187 m
.31481 .06978 L
.31529 .06978 L
.31529 .16187 L
s
1 .894 .882 r
.31529 .16187 m
.31529 .06986 L
.31574 .06986 L
.31574 .16187 L
F
.804 .522 .247 r
.31529 .16187 m
.31529 .06986 L
.31574 .06986 L
.31574 .16187 L
s
1 .894 .882 r
.31574 .16187 m
.31574 .07011 L
.31601 .07011 L
.31601 .16187 L
F
.804 .522 .247 r
.31574 .16187 m
.31574 .07011 L
.31601 .07011 L
.31601 .16187 L
s
1 .894 .882 r
.31601 .16187 m
.31601 .07022 L
.31647 .07022 L
.31647 .16187 L
F
.804 .522 .247 r
.31601 .16187 m
.31601 .07022 L
.31647 .07022 L
.31647 .16187 L
s
1 .894 .882 r
.31647 .16187 m
.31647 .07036 L
.31688 .07036 L
.31688 .16187 L
F
.804 .522 .247 r
.31647 .16187 m
.31647 .07036 L
.31688 .07036 L
.31688 .16187 L
s
1 .894 .882 r
.31688 .16187 m
.31688 .07047 L
.3171 .07047 L
.3171 .16187 L
F
.804 .522 .247 r
.31688 .16187 m
.31688 .07047 L
.3171 .07047 L
.3171 .16187 L
s
1 .894 .882 r
.3171 .16187 m
.3171 .07057 L
.31729 .07057 L
.31729 .16187 L
F
.804 .522 .247 r
.3171 .16187 m
.3171 .07057 L
.31729 .07057 L
.31729 .16187 L
s
1 .894 .882 r
.31729 .16187 m
.31729 .07067 L
.31747 .07067 L
.31747 .16187 L
F
.804 .522 .247 r
.31729 .16187 m
.31729 .07067 L
.31747 .07067 L
.31747 .16187 L
s
1 .894 .882 r
.31747 .16187 m
.31747 .07071 L
.31793 .07071 L
.31793 .16187 L
F
.804 .522 .247 r
.31747 .16187 m
.31747 .07071 L
.31793 .07071 L
.31793 .16187 L
s
1 .894 .882 r
.31793 .16187 m
.31793 .07094 L
.31819 .07094 L
.31819 .16187 L
F
.804 .522 .247 r
.31793 .16187 m
.31793 .07094 L
.31819 .07094 L
.31819 .16187 L
s
1 .894 .882 r
.31819 .16187 m
.31819 .07105 L
.31863 .07105 L
.31863 .16187 L
F
.804 .522 .247 r
.31819 .16187 m
.31819 .07105 L
.31863 .07105 L
.31863 .16187 L
s
1 .894 .882 r
.31863 .16187 m
.31863 .07116 L
.31908 .07116 L
.31908 .16187 L
F
.804 .522 .247 r
.31863 .16187 m
.31863 .07116 L
.31908 .07116 L
.31908 .16187 L
s
1 .894 .882 r
.31908 .16187 m
.31908 .0714 L
.3194 .0714 L
.3194 .16187 L
F
.804 .522 .247 r
.31908 .16187 m
.31908 .0714 L
.3194 .0714 L
.3194 .16187 L
s
1 .894 .882 r
.3194 .16187 m
.3194 .07159 L
.31989 .07159 L
.31989 .16187 L
F
.804 .522 .247 r
.3194 .16187 m
.3194 .07159 L
.31989 .07159 L
.31989 .16187 L
s
1 .894 .882 r
.31989 .16187 m
.31989 .07162 L
.3201 .07162 L
.3201 .16187 L
F
.804 .522 .247 r
.31989 .16187 m
.31989 .07162 L
.3201 .07162 L
.3201 .16187 L
s
1 .894 .882 r
.3201 .16187 m
.3201 .07174 L
.3205 .07174 L
.3205 .16187 L
F
.804 .522 .247 r
.3201 .16187 m
.3201 .07174 L
.3205 .07174 L
.3205 .16187 L
s
1 .894 .882 r
.3205 .16187 m
.3205 .07188 L
.32094 .07188 L
.32094 .16187 L
F
.804 .522 .247 r
.3205 .16187 m
.3205 .07188 L
.32094 .07188 L
.32094 .16187 L
s
1 .894 .882 r
.32094 .16187 m
.32094 .07201 L
.32113 .07201 L
.32113 .16187 L
F
.804 .522 .247 r
.32094 .16187 m
.32094 .07201 L
.32113 .07201 L
.32113 .16187 L
s
1 .894 .882 r
.32113 .16187 m
.32113 .07218 L
.32147 .07218 L
.32147 .16187 L
F
.804 .522 .247 r
.32113 .16187 m
.32113 .07218 L
.32147 .07218 L
.32147 .16187 L
s
1 .894 .882 r
.32147 .16187 m
.32147 .07227 L
.3218 .07227 L
.3218 .16187 L
F
.804 .522 .247 r
.32147 .16187 m
.32147 .07227 L
.3218 .07227 L
.3218 .16187 L
s
1 .894 .882 r
.3218 .16187 m
.3218 .07234 L
.32203 .07234 L
.32203 .16187 L
F
.804 .522 .247 r
.3218 .16187 m
.3218 .07234 L
.32203 .07234 L
.32203 .16187 L
s
1 .894 .882 r
.32203 .16187 m
.32203 .07248 L
.32228 .07248 L
.32228 .16187 L
F
.804 .522 .247 r
.32203 .16187 m
.32203 .07248 L
.32228 .07248 L
.32228 .16187 L
s
1 .894 .882 r
.32228 .16187 m
.32228 .07254 L
.32275 .07254 L
.32275 .16187 L
F
.804 .522 .247 r
.32228 .16187 m
.32228 .07254 L
.32275 .07254 L
.32275 .16187 L
s
1 .894 .882 r
.32275 .16187 m
.32275 .07273 L
.32298 .07273 L
.32298 .16187 L
F
.804 .522 .247 r
.32275 .16187 m
.32275 .07273 L
.32298 .07273 L
.32298 .16187 L
s
1 .894 .882 r
.32298 .16187 m
.32298 .07283 L
.32322 .07283 L
.32322 .16187 L
F
.804 .522 .247 r
.32298 .16187 m
.32298 .07283 L
.32322 .07283 L
.32322 .16187 L
s
1 .894 .882 r
.32322 .16187 m
.32322 .07294 L
.32352 .07294 L
.32352 .16187 L
F
.804 .522 .247 r
.32322 .16187 m
.32322 .07294 L
.32352 .07294 L
.32352 .16187 L
s
1 .894 .882 r
.32352 .16187 m
.32352 .07303 L
.32387 .07303 L
.32387 .16187 L
F
.804 .522 .247 r
.32352 .16187 m
.32352 .07303 L
.32387 .07303 L
.32387 .16187 L
s
1 .894 .882 r
.32387 .16187 m
.32387 .07321 L
.32413 .07321 L
.32413 .16187 L
F
.804 .522 .247 r
.32387 .16187 m
.32387 .07321 L
.32413 .07321 L
.32413 .16187 L
s
1 .894 .882 r
.32413 .16187 m
.32413 .07337 L
.32445 .07337 L
.32445 .16187 L
F
.804 .522 .247 r
.32413 .16187 m
.32413 .07337 L
.32445 .07337 L
.32445 .16187 L
s
1 .894 .882 r
.32445 .16187 m
.32445 .07339 L
.32468 .07339 L
.32468 .16187 L
F
.804 .522 .247 r
.32445 .16187 m
.32445 .07339 L
.32468 .07339 L
.32468 .16187 L
s
1 .894 .882 r
.32468 .16187 m
.32468 .07354 L
.32498 .07354 L
.32498 .16187 L
F
.804 .522 .247 r
.32468 .16187 m
.32468 .07354 L
.32498 .07354 L
.32498 .16187 L
s
1 .894 .882 r
.32498 .16187 m
.32498 .07365 L
.32522 .07365 L
.32522 .16187 L
F
.804 .522 .247 r
.32498 .16187 m
.32498 .07365 L
.32522 .07365 L
.32522 .16187 L
s
1 .894 .882 r
.32522 .16187 m
.32522 .07378 L
.32557 .07378 L
.32557 .16187 L
F
.804 .522 .247 r
.32522 .16187 m
.32522 .07378 L
.32557 .07378 L
.32557 .16187 L
s
1 .894 .882 r
.32557 .16187 m
.32557 .07387 L
.32603 .07387 L
.32603 .16187 L
F
.804 .522 .247 r
.32557 .16187 m
.32557 .07387 L
.32603 .07387 L
.32603 .16187 L
s
1 .894 .882 r
.32603 .16187 m
.32603 .07399 L
.32638 .07399 L
.32638 .16187 L
F
.804 .522 .247 r
.32603 .16187 m
.32603 .07399 L
.32638 .07399 L
.32638 .16187 L
s
1 .894 .882 r
.32638 .16187 m
.32638 .07418 L
.32666 .07418 L
.32666 .16187 L
F
.804 .522 .247 r
.32638 .16187 m
.32638 .07418 L
.32666 .07418 L
.32666 .16187 L
s
1 .894 .882 r
.32666 .16187 m
.32666 .0743 L
.32684 .0743 L
.32684 .16187 L
F
.804 .522 .247 r
.32666 .16187 m
.32666 .0743 L
.32684 .0743 L
.32684 .16187 L
s
1 .894 .882 r
.32684 .16187 m
.32684 .07439 L
.3273 .07439 L
.3273 .16187 L
F
.804 .522 .247 r
.32684 .16187 m
.32684 .07439 L
.3273 .07439 L
.3273 .16187 L
s
1 .894 .882 r
.3273 .16187 m
.3273 .07458 L
.32759 .07458 L
.32759 .16187 L
F
.804 .522 .247 r
.3273 .16187 m
.3273 .07458 L
.32759 .07458 L
.32759 .16187 L
s
1 .894 .882 r
.32759 .16187 m
.32759 .07463 L
.32797 .07463 L
.32797 .16187 L
F
.804 .522 .247 r
.32759 .16187 m
.32759 .07463 L
.32797 .07463 L
.32797 .16187 L
s
1 .894 .882 r
.32797 .16187 m
.32797 .07481 L
.3282 .07481 L
.3282 .16187 L
F
.804 .522 .247 r
.32797 .16187 m
.32797 .07481 L
.3282 .07481 L
.3282 .16187 L
s
1 .894 .882 r
.3282 .16187 m
.3282 .07491 L
.32861 .07491 L
.32861 .16187 L
F
.804 .522 .247 r
.3282 .16187 m
.3282 .07491 L
.32861 .07491 L
.32861 .16187 L
s
1 .894 .882 r
.32861 .16187 m
.32861 .07502 L
.32905 .07502 L
.32905 .16187 L
F
.804 .522 .247 r
.32861 .16187 m
.32861 .07502 L
.32905 .07502 L
.32905 .16187 L
s
1 .894 .882 r
.32905 .16187 m
.32905 .07524 L
.32924 .07524 L
.32924 .16187 L
F
.804 .522 .247 r
.32905 .16187 m
.32905 .07524 L
.32924 .07524 L
.32924 .16187 L
s
1 .894 .882 r
.32924 .16187 m
.32924 .07529 L
.3294 .07529 L
.3294 .16187 L
F
.804 .522 .247 r
.32924 .16187 m
.32924 .07529 L
.3294 .07529 L
.3294 .16187 L
s
1 .894 .882 r
.3294 .16187 m
.3294 .07543 L
.32971 .07543 L
.32971 .16187 L
F
.804 .522 .247 r
.3294 .16187 m
.3294 .07543 L
.32971 .07543 L
.32971 .16187 L
s
1 .894 .882 r
.32971 .16187 m
.32971 .07544 L
.33016 .07544 L
.33016 .16187 L
F
.804 .522 .247 r
.32971 .16187 m
.32971 .07544 L
.33016 .07544 L
.33016 .16187 L
s
1 .894 .882 r
.33016 .16187 m
.33016 .07572 L
.33062 .07572 L
.33062 .16187 L
F
.804 .522 .247 r
.33016 .16187 m
.33016 .07572 L
.33062 .07572 L
.33062 .16187 L
s
1 .894 .882 r
.33062 .16187 m
.33062 .07584 L
.33103 .07584 L
.33103 .16187 L
F
.804 .522 .247 r
.33062 .16187 m
.33062 .07584 L
.33103 .07584 L
.33103 .16187 L
s
1 .894 .882 r
.33103 .16187 m
.33103 .076 L
.33119 .076 L
.33119 .16187 L
F
.804 .522 .247 r
.33103 .16187 m
.33103 .076 L
.33119 .076 L
.33119 .16187 L
s
1 .894 .882 r
.33119 .16187 m
.33119 .07611 L
.33145 .07611 L
.33145 .16187 L
F
.804 .522 .247 r
.33119 .16187 m
.33119 .07611 L
.33145 .07611 L
.33145 .16187 L
s
1 .894 .882 r
.33145 .16187 m
.33145 .07625 L
.33179 .07625 L
.33179 .16187 L
F
.804 .522 .247 r
.33145 .16187 m
.33145 .07625 L
.33179 .07625 L
.33179 .16187 L
s
1 .894 .882 r
.33179 .16187 m
.33179 .07629 L
.33202 .07629 L
.33202 .16187 L
F
.804 .522 .247 r
.33179 .16187 m
.33179 .07629 L
.33202 .07629 L
.33202 .16187 L
s
1 .894 .882 r
.33202 .16187 m
.33202 .07641 L
.33244 .07641 L
.33244 .16187 L
F
.804 .522 .247 r
.33202 .16187 m
.33202 .07641 L
.33244 .07641 L
.33244 .16187 L
s
1 .894 .882 r
.33244 .16187 m
.33244 .07656 L
.33289 .07656 L
.33289 .16187 L
F
.804 .522 .247 r
.33244 .16187 m
.33244 .07656 L
.33289 .07656 L
.33289 .16187 L
s
1 .894 .882 r
.33289 .16187 m
.33289 .07672 L
.33314 .07672 L
.33314 .16187 L
F
.804 .522 .247 r
.33289 .16187 m
.33289 .07672 L
.33314 .07672 L
.33314 .16187 L
s
1 .894 .882 r
.33314 .16187 m
.33314 .07689 L
.33351 .07689 L
.33351 .16187 L
F
.804 .522 .247 r
.33314 .16187 m
.33314 .07689 L
.33351 .07689 L
.33351 .16187 L
s
1 .894 .882 r
.33351 .16187 m
.33351 .07714 L
.33398 .07714 L
.33398 .16187 L
F
.804 .522 .247 r
.33351 .16187 m
.33351 .07714 L
.33398 .07714 L
.33398 .16187 L
s
1 .894 .882 r
.33398 .16187 m
.33398 .07716 L
.33422 .07716 L
.33422 .16187 L
F
.804 .522 .247 r
.33398 .16187 m
.33398 .07716 L
.33422 .07716 L
.33422 .16187 L
s
1 .894 .882 r
.33422 .16187 m
.33422 .07736 L
.33469 .07736 L
.33469 .16187 L
F
.804 .522 .247 r
.33422 .16187 m
.33422 .07736 L
.33469 .07736 L
.33469 .16187 L
s
1 .894 .882 r
.33469 .16187 m
.33469 .07751 L
.33502 .07751 L
.33502 .16187 L
F
.804 .522 .247 r
.33469 .16187 m
.33469 .07751 L
.33502 .07751 L
.33502 .16187 L
s
1 .894 .882 r
.33502 .16187 m
.33502 .0776 L
.33517 .0776 L
.33517 .16187 L
F
.804 .522 .247 r
.33502 .16187 m
.33502 .0776 L
.33517 .0776 L
.33517 .16187 L
s
1 .894 .882 r
.33517 .16187 m
.33517 .07768 L
.33562 .07768 L
.33562 .16187 L
F
.804 .522 .247 r
.33517 .16187 m
.33517 .07768 L
.33562 .07768 L
.33562 .16187 L
s
1 .894 .882 r
.33562 .16187 m
.33562 .07785 L
.33586 .07785 L
.33586 .16187 L
F
.804 .522 .247 r
.33562 .16187 m
.33562 .07785 L
.33586 .07785 L
.33586 .16187 L
s
1 .894 .882 r
.33586 .16187 m
.33586 .078 L
.3361 .078 L
.3361 .16187 L
F
.804 .522 .247 r
.33586 .16187 m
.33586 .078 L
.3361 .078 L
.3361 .16187 L
s
1 .894 .882 r
.3361 .16187 m
.3361 .07801 L
.33634 .07801 L
.33634 .16187 L
F
.804 .522 .247 r
.3361 .16187 m
.3361 .07801 L
.33634 .07801 L
.33634 .16187 L
s
1 .894 .882 r
.33634 .16187 m
.33634 .07811 L
.3365 .07811 L
.3365 .16187 L
F
.804 .522 .247 r
.33634 .16187 m
.33634 .07811 L
.3365 .07811 L
.3365 .16187 L
s
1 .894 .882 r
.3365 .16187 m
.3365 .07821 L
.33668 .07821 L
.33668 .16187 L
F
.804 .522 .247 r
.3365 .16187 m
.3365 .07821 L
.33668 .07821 L
.33668 .16187 L
s
1 .894 .882 r
.33668 .16187 m
.33668 .07827 L
.33692 .07827 L
.33692 .16187 L
F
.804 .522 .247 r
.33668 .16187 m
.33668 .07827 L
.33692 .07827 L
.33692 .16187 L
s
1 .894 .882 r
.33692 .16187 m
.33692 .07836 L
.33734 .07836 L
.33734 .16187 L
F
.804 .522 .247 r
.33692 .16187 m
.33692 .07836 L
.33734 .07836 L
.33734 .16187 L
s
1 .894 .882 r
.33734 .16187 m
.33734 .07852 L
.33754 .07852 L
.33754 .16187 L
F
.804 .522 .247 r
.33734 .16187 m
.33734 .07852 L
.33754 .07852 L
.33754 .16187 L
s
1 .894 .882 r
.33754 .16187 m
.33754 .0786 L
.33775 .0786 L
.33775 .16187 L
F
.804 .522 .247 r
.33754 .16187 m
.33754 .0786 L
.33775 .0786 L
.33775 .16187 L
s
1 .894 .882 r
.33775 .16187 m
.33775 .07868 L
.33808 .07868 L
.33808 .16187 L
F
.804 .522 .247 r
.33775 .16187 m
.33775 .07868 L
.33808 .07868 L
.33808 .16187 L
s
1 .894 .882 r
.33808 .16187 m
.33808 .07891 L
.33849 .07891 L
.33849 .16187 L
F
.804 .522 .247 r
.33808 .16187 m
.33808 .07891 L
.33849 .07891 L
.33849 .16187 L
s
1 .894 .882 r
.33849 .16187 m
.33849 .07903 L
.33892 .07903 L
.33892 .16187 L
F
.804 .522 .247 r
.33849 .16187 m
.33849 .07903 L
.33892 .07903 L
.33892 .16187 L
s
1 .894 .882 r
.33892 .16187 m
.33892 .07918 L
.33929 .07918 L
.33929 .16187 L
F
.804 .522 .247 r
.33892 .16187 m
.33892 .07918 L
.33929 .07918 L
.33929 .16187 L
s
1 .894 .882 r
.33929 .16187 m
.33929 .07938 L
.33953 .07938 L
.33953 .16187 L
F
.804 .522 .247 r
.33929 .16187 m
.33929 .07938 L
.33953 .07938 L
.33953 .16187 L
s
1 .894 .882 r
.33953 .16187 m
.33953 .07946 L
.34001 .07946 L
.34001 .16187 L
F
.804 .522 .247 r
.33953 .16187 m
.33953 .07946 L
.34001 .07946 L
.34001 .16187 L
s
1 .894 .882 r
.34001 .16187 m
.34001 .07963 L
.34048 .07963 L
.34048 .16187 L
F
.804 .522 .247 r
.34001 .16187 m
.34001 .07963 L
.34048 .07963 L
.34048 .16187 L
s
1 .894 .882 r
.34048 .16187 m
.34048 .0798 L
.34074 .0798 L
.34074 .16187 L
F
.804 .522 .247 r
.34048 .16187 m
.34048 .0798 L
.34074 .0798 L
.34074 .16187 L
s
1 .894 .882 r
.34074 .16187 m
.34074 .07994 L
.3411 .07994 L
.3411 .16187 L
F
.804 .522 .247 r
.34074 .16187 m
.34074 .07994 L
.3411 .07994 L
.3411 .16187 L
s
1 .894 .882 r
.3411 .16187 m
.3411 .08007 L
.34127 .08007 L
.34127 .16187 L
F
.804 .522 .247 r
.3411 .16187 m
.3411 .08007 L
.34127 .08007 L
.34127 .16187 L
s
1 .894 .882 r
.34127 .16187 m
.34127 .08012 L
.34164 .08012 L
.34164 .16187 L
F
.804 .522 .247 r
.34127 .16187 m
.34127 .08012 L
.34164 .08012 L
.34164 .16187 L
s
1 .894 .882 r
.34164 .16187 m
.34164 .08032 L
.34193 .08032 L
.34193 .16187 L
F
.804 .522 .247 r
.34164 .16187 m
.34164 .08032 L
.34193 .08032 L
.34193 .16187 L
s
1 .894 .882 r
.34193 .16187 m
.34193 .08044 L
.34211 .08044 L
.34211 .16187 L
F
.804 .522 .247 r
.34193 .16187 m
.34193 .08044 L
.34211 .08044 L
.34211 .16187 L
s
1 .894 .882 r
.34211 .16187 m
.34211 .08052 L
.34227 .08052 L
.34227 .16187 L
F
.804 .522 .247 r
.34211 .16187 m
.34211 .08052 L
.34227 .08052 L
.34227 .16187 L
s
1 .894 .882 r
.34227 .16187 m
.34227 .08066 L
.34269 .08066 L
.34269 .16187 L
F
.804 .522 .247 r
.34227 .16187 m
.34227 .08066 L
.34269 .08066 L
.34269 .16187 L
s
1 .894 .882 r
.34269 .16187 m
.34269 .0807 L
.34289 .0807 L
.34289 .16187 L
F
.804 .522 .247 r
.34269 .16187 m
.34269 .0807 L
.34289 .0807 L
.34289 .16187 L
s
1 .894 .882 r
.34289 .16187 m
.34289 .08091 L
.34332 .08091 L
.34332 .16187 L
F
.804 .522 .247 r
.34289 .16187 m
.34289 .08091 L
.34332 .08091 L
.34332 .16187 L
s
1 .894 .882 r
.34332 .16187 m
.34332 .08109 L
.34373 .08109 L
.34373 .16187 L
F
.804 .522 .247 r
.34332 .16187 m
.34332 .08109 L
.34373 .08109 L
.34373 .16187 L
s
1 .894 .882 r
.34373 .16187 m
.34373 .08124 L
.34413 .08124 L
.34413 .16187 L
F
.804 .522 .247 r
.34373 .16187 m
.34373 .08124 L
.34413 .08124 L
.34413 .16187 L
s
1 .894 .882 r
.34413 .16187 m
.34413 .08133 L
.3443 .08133 L
.3443 .16187 L
F
.804 .522 .247 r
.34413 .16187 m
.34413 .08133 L
.3443 .08133 L
.3443 .16187 L
s
1 .894 .882 r
.3443 .16187 m
.3443 .08143 L
.34464 .08143 L
.34464 .16187 L
F
.804 .522 .247 r
.3443 .16187 m
.3443 .08143 L
.34464 .08143 L
.34464 .16187 L
s
1 .894 .882 r
.34464 .16187 m
.34464 .08163 L
.34513 .08163 L
.34513 .16187 L
F
.804 .522 .247 r
.34464 .16187 m
.34464 .08163 L
.34513 .08163 L
.34513 .16187 L
s
1 .894 .882 r
.34513 .16187 m
.34513 .08178 L
.34548 .08178 L
.34548 .16187 L
F
.804 .522 .247 r
.34513 .16187 m
.34513 .08178 L
.34548 .08178 L
.34548 .16187 L
s
1 .894 .882 r
.34548 .16187 m
.34548 .08191 L
.34592 .08191 L
.34592 .16187 L
F
.804 .522 .247 r
.34548 .16187 m
.34548 .08191 L
.34592 .08191 L
.34592 .16187 L
s
1 .894 .882 r
.34592 .16187 m
.34592 .08207 L
.34608 .08207 L
.34608 .16187 L
F
.804 .522 .247 r
.34592 .16187 m
.34592 .08207 L
.34608 .08207 L
.34608 .16187 L
s
1 .894 .882 r
.34608 .16187 m
.34608 .0822 L
.34631 .0822 L
.34631 .16187 L
F
.804 .522 .247 r
.34608 .16187 m
.34608 .0822 L
.34631 .0822 L
.34631 .16187 L
s
1 .894 .882 r
.34631 .16187 m
.34631 .08223 L
.34672 .08223 L
.34672 .16187 L
F
.804 .522 .247 r
.34631 .16187 m
.34631 .08223 L
.34672 .08223 L
.34672 .16187 L
s
1 .894 .882 r
.34672 .16187 m
.34672 .08239 L
.34695 .08239 L
.34695 .16187 L
F
.804 .522 .247 r
.34672 .16187 m
.34672 .08239 L
.34695 .08239 L
.34695 .16187 L
s
1 .894 .882 r
.34695 .16187 m
.34695 .08258 L
.34736 .08258 L
.34736 .16187 L
F
.804 .522 .247 r
.34695 .16187 m
.34695 .08258 L
.34736 .08258 L
.34736 .16187 L
s
1 .894 .882 r
.34736 .16187 m
.34736 .08271 L
.34759 .08271 L
.34759 .16187 L
F
.804 .522 .247 r
.34736 .16187 m
.34736 .08271 L
.34759 .08271 L
.34759 .16187 L
s
1 .894 .882 r
.34759 .16187 m
.34759 .08292 L
.34803 .08292 L
.34803 .16187 L
F
.804 .522 .247 r
.34759 .16187 m
.34759 .08292 L
.34803 .08292 L
.34803 .16187 L
s
1 .894 .882 r
.34803 .16187 m
.34803 .08312 L
.34848 .08312 L
.34848 .16187 L
F
.804 .522 .247 r
.34803 .16187 m
.34803 .08312 L
.34848 .08312 L
.34848 .16187 L
s
1 .894 .882 r
.34848 .16187 m
.34848 .08315 L
.34868 .08315 L
.34868 .16187 L
F
.804 .522 .247 r
.34848 .16187 m
.34848 .08315 L
.34868 .08315 L
.34868 .16187 L
s
1 .894 .882 r
.34868 .16187 m
.34868 .08323 L
.3489 .08323 L
.3489 .16187 L
F
.804 .522 .247 r
.34868 .16187 m
.34868 .08323 L
.3489 .08323 L
.3489 .16187 L
s
1 .894 .882 r
.3489 .16187 m
.3489 .08337 L
.3491 .08337 L
.3491 .16187 L
F
.804 .522 .247 r
.3489 .16187 m
.3489 .08337 L
.3491 .08337 L
.3491 .16187 L
s
1 .894 .882 r
.3491 .16187 m
.3491 .08346 L
.34942 .08346 L
.34942 .16187 L
F
.804 .522 .247 r
.3491 .16187 m
.3491 .08346 L
.34942 .08346 L
.34942 .16187 L
s
1 .894 .882 r
.34942 .16187 m
.34942 .08356 L
.34958 .08356 L
.34958 .16187 L
F
.804 .522 .247 r
.34942 .16187 m
.34942 .08356 L
.34958 .08356 L
.34958 .16187 L
s
1 .894 .882 r
.34958 .16187 m
.34958 .08362 L
.34979 .08362 L
.34979 .16187 L
F
.804 .522 .247 r
.34958 .16187 m
.34958 .08362 L
.34979 .08362 L
.34979 .16187 L
s
1 .894 .882 r
.34979 .16187 m
.34979 .08368 L
.35007 .08368 L
.35007 .16187 L
F
.804 .522 .247 r
.34979 .16187 m
.34979 .08368 L
.35007 .08368 L
.35007 .16187 L
s
1 .894 .882 r
.35007 .16187 m
.35007 .08385 L
.35033 .08385 L
.35033 .16187 L
F
.804 .522 .247 r
.35007 .16187 m
.35007 .08385 L
.35033 .08385 L
.35033 .16187 L
s
1 .894 .882 r
.35033 .16187 m
.35033 .08399 L
.35056 .08399 L
.35056 .16187 L
F
.804 .522 .247 r
.35033 .16187 m
.35033 .08399 L
.35056 .08399 L
.35056 .16187 L
s
1 .894 .882 r
.35056 .16187 m
.35056 .08408 L
.35084 .08408 L
.35084 .16187 L
F
.804 .522 .247 r
.35056 .16187 m
.35056 .08408 L
.35084 .08408 L
.35084 .16187 L
s
1 .894 .882 r
.35084 .16187 m
.35084 .0842 L
.35122 .0842 L
.35122 .16187 L
F
.804 .522 .247 r
.35084 .16187 m
.35084 .0842 L
.35122 .0842 L
.35122 .16187 L
s
1 .894 .882 r
.35122 .16187 m
.35122 .0843 L
.35145 .0843 L
.35145 .16187 L
F
.804 .522 .247 r
.35122 .16187 m
.35122 .0843 L
.35145 .0843 L
.35145 .16187 L
s
1 .894 .882 r
.35145 .16187 m
.35145 .08446 L
.35184 .08446 L
.35184 .16187 L
F
.804 .522 .247 r
.35145 .16187 m
.35145 .08446 L
.35184 .08446 L
.35184 .16187 L
s
1 .894 .882 r
.35184 .16187 m
.35184 .08456 L
.35213 .08456 L
.35213 .16187 L
F
.804 .522 .247 r
.35184 .16187 m
.35184 .08456 L
.35213 .08456 L
.35213 .16187 L
s
1 .894 .882 r
.35213 .16187 m
.35213 .08467 L
.3523 .08467 L
.3523 .16187 L
F
.804 .522 .247 r
.35213 .16187 m
.35213 .08467 L
.3523 .08467 L
.3523 .16187 L
s
1 .894 .882 r
.3523 .16187 m
.3523 .08485 L
.35258 .08485 L
.35258 .16187 L
F
.804 .522 .247 r
.3523 .16187 m
.3523 .08485 L
.35258 .08485 L
.35258 .16187 L
s
1 .894 .882 r
.35258 .16187 m
.35258 .08488 L
.35295 .08488 L
.35295 .16187 L
F
.804 .522 .247 r
.35258 .16187 m
.35258 .08488 L
.35295 .08488 L
.35295 .16187 L
s
1 .894 .882 r
.35295 .16187 m
.35295 .08504 L
.35317 .08504 L
.35317 .16187 L
F
.804 .522 .247 r
.35295 .16187 m
.35295 .08504 L
.35317 .08504 L
.35317 .16187 L
s
1 .894 .882 r
.35317 .16187 m
.35317 .08521 L
.35342 .08521 L
.35342 .16187 L
F
.804 .522 .247 r
.35317 .16187 m
.35317 .08521 L
.35342 .08521 L
.35342 .16187 L
s
1 .894 .882 r
.35342 .16187 m
.35342 .08529 L
.35362 .08529 L
.35362 .16187 L
F
.804 .522 .247 r
.35342 .16187 m
.35342 .08529 L
.35362 .08529 L
.35362 .16187 L
s
1 .894 .882 r
.35362 .16187 m
.35362 .0854 L
.35408 .0854 L
.35408 .16187 L
F
.804 .522 .247 r
.35362 .16187 m
.35362 .0854 L
.35408 .0854 L
.35408 .16187 L
s
1 .894 .882 r
.35408 .16187 m
.35408 .08562 L
.35455 .08562 L
.35455 .16187 L
F
.804 .522 .247 r
.35408 .16187 m
.35408 .08562 L
.35455 .08562 L
.35455 .16187 L
s
1 .894 .882 r
.35455 .16187 m
.35455 .08583 L
.35486 .08583 L
.35486 .16187 L
F
.804 .522 .247 r
.35455 .16187 m
.35455 .08583 L
.35486 .08583 L
.35486 .16187 L
s
1 .894 .882 r
.35486 .16187 m
.35486 .08592 L
.35509 .08592 L
.35509 .16187 L
F
.804 .522 .247 r
.35486 .16187 m
.35486 .08592 L
.35509 .08592 L
.35509 .16187 L
s
1 .894 .882 r
.35509 .16187 m
.35509 .08596 L
.3555 .08596 L
.3555 .16187 L
F
.804 .522 .247 r
.35509 .16187 m
.35509 .08596 L
.3555 .08596 L
.3555 .16187 L
s
1 .894 .882 r
.3555 .16187 m
.3555 .08617 L
.3559 .08617 L
.3559 .16187 L
F
.804 .522 .247 r
.3555 .16187 m
.3555 .08617 L
.3559 .08617 L
.3559 .16187 L
s
1 .894 .882 r
.3559 .16187 m
.3559 .08629 L
.35616 .08629 L
.35616 .16187 L
F
.804 .522 .247 r
.3559 .16187 m
.3559 .08629 L
.35616 .08629 L
.35616 .16187 L
s
1 .894 .882 r
.35616 .16187 m
.35616 .08645 L
.35657 .08645 L
.35657 .16187 L
F
.804 .522 .247 r
.35616 .16187 m
.35616 .08645 L
.35657 .08645 L
.35657 .16187 L
s
1 .894 .882 r
.35657 .16187 m
.35657 .08665 L
.35696 .08665 L
.35696 .16187 L
F
.804 .522 .247 r
.35657 .16187 m
.35657 .08665 L
.35696 .08665 L
.35696 .16187 L
s
1 .894 .882 r
.35696 .16187 m
.35696 .08687 L
.35729 .08687 L
.35729 .16187 L
F
.804 .522 .247 r
.35696 .16187 m
.35696 .08687 L
.35729 .08687 L
.35729 .16187 L
s
1 .894 .882 r
.35729 .16187 m
.35729 .08689 L
.35776 .08689 L
.35776 .16187 L
F
.804 .522 .247 r
.35729 .16187 m
.35729 .08689 L
.35776 .08689 L
.35776 .16187 L
s
1 .894 .882 r
.35776 .16187 m
.35776 .08719 L
.35807 .08719 L
.35807 .16187 L
F
.804 .522 .247 r
.35776 .16187 m
.35776 .08719 L
.35807 .08719 L
.35807 .16187 L
s
1 .894 .882 r
.35807 .16187 m
.35807 .08729 L
.35837 .08729 L
.35837 .16187 L
F
.804 .522 .247 r
.35807 .16187 m
.35807 .08729 L
.35837 .08729 L
.35837 .16187 L
s
1 .894 .882 r
.35837 .16187 m
.35837 .08737 L
.35857 .08737 L
.35857 .16187 L
F
.804 .522 .247 r
.35837 .16187 m
.35837 .08737 L
.35857 .08737 L
.35857 .16187 L
s
1 .894 .882 r
.35857 .16187 m
.35857 .08749 L
.35881 .08749 L
.35881 .16187 L
F
.804 .522 .247 r
.35857 .16187 m
.35857 .08749 L
.35881 .08749 L
.35881 .16187 L
s
1 .894 .882 r
.35881 .16187 m
.35881 .0876 L
.35903 .0876 L
.35903 .16187 L
F
.804 .522 .247 r
.35881 .16187 m
.35881 .0876 L
.35903 .0876 L
.35903 .16187 L
s
1 .894 .882 r
.35903 .16187 m
.35903 .08781 L
.35945 .08781 L
.35945 .16187 L
F
.804 .522 .247 r
.35903 .16187 m
.35903 .08781 L
.35945 .08781 L
.35945 .16187 L
s
1 .894 .882 r
.35945 .16187 m
.35945 .08783 L
.35984 .08783 L
.35984 .16187 L
F
.804 .522 .247 r
.35945 .16187 m
.35945 .08783 L
.35984 .08783 L
.35984 .16187 L
s
1 .894 .882 r
.35984 .16187 m
.35984 .08804 L
.36006 .08804 L
.36006 .16187 L
F
.804 .522 .247 r
.35984 .16187 m
.35984 .08804 L
.36006 .08804 L
.36006 .16187 L
s
1 .894 .882 r
.36006 .16187 m
.36006 .08821 L
.3605 .08821 L
.3605 .16187 L
F
.804 .522 .247 r
.36006 .16187 m
.36006 .08821 L
.3605 .08821 L
.3605 .16187 L
s
1 .894 .882 r
.3605 .16187 m
.3605 .08834 L
.36068 .08834 L
.36068 .16187 L
F
.804 .522 .247 r
.3605 .16187 m
.3605 .08834 L
.36068 .08834 L
.36068 .16187 L
s
1 .894 .882 r
.36068 .16187 m
.36068 .08848 L
.36101 .08848 L
.36101 .16187 L
F
.804 .522 .247 r
.36068 .16187 m
.36068 .08848 L
.36101 .08848 L
.36101 .16187 L
s
1 .894 .882 r
.36101 .16187 m
.36101 .08862 L
.36146 .08862 L
.36146 .16187 L
F
.804 .522 .247 r
.36101 .16187 m
.36101 .08862 L
.36146 .08862 L
.36146 .16187 L
s
1 .894 .882 r
.36146 .16187 m
.36146 .08884 L
.36186 .08884 L
.36186 .16187 L
F
.804 .522 .247 r
.36146 .16187 m
.36146 .08884 L
.36186 .08884 L
.36186 .16187 L
s
1 .894 .882 r
.36186 .16187 m
.36186 .0889 L
.36208 .0889 L
.36208 .16187 L
F
.804 .522 .247 r
.36186 .16187 m
.36186 .0889 L
.36208 .0889 L
.36208 .16187 L
s
1 .894 .882 r
.36208 .16187 m
.36208 .08901 L
.36242 .08901 L
.36242 .16187 L
F
.804 .522 .247 r
.36208 .16187 m
.36208 .08901 L
.36242 .08901 L
.36242 .16187 L
s
1 .894 .882 r
.36242 .16187 m
.36242 .08919 L
.36271 .08919 L
.36271 .16187 L
F
.804 .522 .247 r
.36242 .16187 m
.36242 .08919 L
.36271 .08919 L
.36271 .16187 L
s
1 .894 .882 r
.36271 .16187 m
.36271 .08937 L
.36302 .08937 L
.36302 .16187 L
F
.804 .522 .247 r
.36271 .16187 m
.36271 .08937 L
.36302 .08937 L
.36302 .16187 L
s
1 .894 .882 r
.36302 .16187 m
.36302 .0894 L
.36332 .0894 L
.36332 .16187 L
F
.804 .522 .247 r
.36302 .16187 m
.36302 .0894 L
.36332 .0894 L
.36332 .16187 L
s
1 .894 .882 r
.36332 .16187 m
.36332 .08971 L
.36377 .08971 L
.36377 .16187 L
F
.804 .522 .247 r
.36332 .16187 m
.36332 .08971 L
.36377 .08971 L
.36377 .16187 L
s
1 .894 .882 r
.36377 .16187 m
.36377 .08975 L
.36394 .08975 L
.36394 .16187 L
F
.804 .522 .247 r
.36377 .16187 m
.36377 .08975 L
.36394 .08975 L
.36394 .16187 L
s
1 .894 .882 r
.36394 .16187 m
.36394 .0899 L
.36433 .0899 L
.36433 .16187 L
F
.804 .522 .247 r
.36394 .16187 m
.36394 .0899 L
.36433 .0899 L
.36433 .16187 L
s
1 .894 .882 r
.36433 .16187 m
.36433 .09008 L
.36474 .09008 L
.36474 .16187 L
F
.804 .522 .247 r
.36433 .16187 m
.36433 .09008 L
.36474 .09008 L
.36474 .16187 L
s
1 .894 .882 r
.36474 .16187 m
.36474 .09015 L
.36499 .09015 L
.36499 .16187 L
F
.804 .522 .247 r
.36474 .16187 m
.36474 .09015 L
.36499 .09015 L
.36499 .16187 L
s
1 .894 .882 r
.36499 .16187 m
.36499 .09029 L
.36519 .09029 L
.36519 .16187 L
F
.804 .522 .247 r
.36499 .16187 m
.36499 .09029 L
.36519 .09029 L
.36519 .16187 L
s
1 .894 .882 r
.36519 .16187 m
.36519 .09043 L
.36543 .09043 L
.36543 .16187 L
F
.804 .522 .247 r
.36519 .16187 m
.36519 .09043 L
.36543 .09043 L
.36543 .16187 L
s
1 .894 .882 r
.36543 .16187 m
.36543 .09047 L
.36567 .09047 L
.36567 .16187 L
F
.804 .522 .247 r
.36543 .16187 m
.36543 .09047 L
.36567 .09047 L
.36567 .16187 L
s
1 .894 .882 r
.36567 .16187 m
.36567 .09064 L
.36588 .09064 L
.36588 .16187 L
F
.804 .522 .247 r
.36567 .16187 m
.36567 .09064 L
.36588 .09064 L
.36588 .16187 L
s
1 .894 .882 r
.36588 .16187 m
.36588 .09083 L
.36633 .09083 L
.36633 .16187 L
F
.804 .522 .247 r
.36588 .16187 m
.36588 .09083 L
.36633 .09083 L
.36633 .16187 L
s
1 .894 .882 r
.36633 .16187 m
.36633 .09087 L
.36649 .09087 L
.36649 .16187 L
F
.804 .522 .247 r
.36633 .16187 m
.36633 .09087 L
.36649 .09087 L
.36649 .16187 L
s
1 .894 .882 r
.36649 .16187 m
.36649 .09095 L
.36681 .09095 L
.36681 .16187 L
F
.804 .522 .247 r
.36649 .16187 m
.36649 .09095 L
.36681 .09095 L
.36681 .16187 L
s
1 .894 .882 r
.36681 .16187 m
.36681 .09117 L
.36712 .09117 L
.36712 .16187 L
F
.804 .522 .247 r
.36681 .16187 m
.36681 .09117 L
.36712 .09117 L
.36712 .16187 L
s
1 .894 .882 r
.36712 .16187 m
.36712 .09127 L
.3675 .09127 L
.3675 .16187 L
F
.804 .522 .247 r
.36712 .16187 m
.36712 .09127 L
.3675 .09127 L
.3675 .16187 L
s
1 .894 .882 r
.3675 .16187 m
.3675 .09143 L
.36771 .09143 L
.36771 .16187 L
F
.804 .522 .247 r
.3675 .16187 m
.3675 .09143 L
.36771 .09143 L
.36771 .16187 L
s
1 .894 .882 r
.36771 .16187 m
.36771 .09151 L
.36799 .09151 L
.36799 .16187 L
F
.804 .522 .247 r
.36771 .16187 m
.36771 .09151 L
.36799 .09151 L
.36799 .16187 L
s
1 .894 .882 r
.36799 .16187 m
.36799 .09179 L
.36847 .09179 L
.36847 .16187 L
F
.804 .522 .247 r
.36799 .16187 m
.36799 .09179 L
.36847 .09179 L
.36847 .16187 L
s
1 .894 .882 r
.36847 .16187 m
.36847 .09196 L
.36889 .09196 L
.36889 .16187 L
F
.804 .522 .247 r
.36847 .16187 m
.36847 .09196 L
.36889 .09196 L
.36889 .16187 L
s
1 .894 .882 r
.36889 .16187 m
.36889 .0921 L
.36919 .0921 L
.36919 .16187 L
F
.804 .522 .247 r
.36889 .16187 m
.36889 .0921 L
.36919 .0921 L
.36919 .16187 L
s
1 .894 .882 r
.36919 .16187 m
.36919 .09213 L
.36941 .09213 L
.36941 .16187 L
F
.804 .522 .247 r
.36919 .16187 m
.36919 .09213 L
.36941 .09213 L
.36941 .16187 L
s
1 .894 .882 r
.36941 .16187 m
.36941 .0923 L
.36968 .0923 L
.36968 .16187 L
F
.804 .522 .247 r
.36941 .16187 m
.36941 .0923 L
.36968 .0923 L
.36968 .16187 L
s
1 .894 .882 r
.36968 .16187 m
.36968 .09238 L
.36997 .09238 L
.36997 .16187 L
F
.804 .522 .247 r
.36968 .16187 m
.36968 .09238 L
.36997 .09238 L
.36997 .16187 L
s
1 .894 .882 r
.36997 .16187 m
.36997 .09267 L
.37045 .09267 L
.37045 .16187 L
F
.804 .522 .247 r
.36997 .16187 m
.36997 .09267 L
.37045 .09267 L
.37045 .16187 L
s
1 .894 .882 r
.37045 .16187 m
.37045 .09286 L
.37086 .09286 L
.37086 .16187 L
F
.804 .522 .247 r
.37045 .16187 m
.37045 .09286 L
.37086 .09286 L
.37086 .16187 L
s
1 .894 .882 r
.37086 .16187 m
.37086 .09297 L
.37118 .09297 L
.37118 .16187 L
F
.804 .522 .247 r
.37086 .16187 m
.37086 .09297 L
.37118 .09297 L
.37118 .16187 L
s
1 .894 .882 r
.37118 .16187 m
.37118 .09311 L
.37144 .09311 L
.37144 .16187 L
F
.804 .522 .247 r
.37118 .16187 m
.37118 .09311 L
.37144 .09311 L
.37144 .16187 L
s
1 .894 .882 r
.37144 .16187 m
.37144 .09317 L
.37168 .09317 L
.37168 .16187 L
F
.804 .522 .247 r
.37144 .16187 m
.37144 .09317 L
.37168 .09317 L
.37168 .16187 L
s
1 .894 .882 r
.37168 .16187 m
.37168 .09326 L
.37183 .09326 L
.37183 .16187 L
F
.804 .522 .247 r
.37168 .16187 m
.37168 .09326 L
.37183 .09326 L
.37183 .16187 L
s
1 .894 .882 r
.37183 .16187 m
.37183 .09337 L
.37204 .09337 L
.37204 .16187 L
F
.804 .522 .247 r
.37183 .16187 m
.37183 .09337 L
.37204 .09337 L
.37204 .16187 L
s
1 .894 .882 r
.37204 .16187 m
.37204 .09344 L
.37224 .09344 L
.37224 .16187 L
F
.804 .522 .247 r
.37204 .16187 m
.37204 .09344 L
.37224 .09344 L
.37224 .16187 L
s
1 .894 .882 r
.37224 .16187 m
.37224 .09353 L
.3724 .09353 L
.3724 .16187 L
F
.804 .522 .247 r
.37224 .16187 m
.37224 .09353 L
.3724 .09353 L
.3724 .16187 L
s
1 .894 .882 r
.3724 .16187 m
.3724 .09358 L
.3728 .09358 L
.3728 .16187 L
F
.804 .522 .247 r
.3724 .16187 m
.3724 .09358 L
.3728 .09358 L
.3728 .16187 L
s
1 .894 .882 r
.3728 .16187 m
.3728 .0938 L
.37295 .0938 L
.37295 .16187 L
F
.804 .522 .247 r
.3728 .16187 m
.3728 .0938 L
.37295 .0938 L
.37295 .16187 L
s
1 .894 .882 r
.37295 .16187 m
.37295 .09387 L
.37319 .09387 L
.37319 .16187 L
F
.804 .522 .247 r
.37295 .16187 m
.37295 .09387 L
.37319 .09387 L
.37319 .16187 L
s
1 .894 .882 r
.37319 .16187 m
.37319 .09397 L
.37368 .09397 L
.37368 .16187 L
F
.804 .522 .247 r
.37319 .16187 m
.37319 .09397 L
.37368 .09397 L
.37368 .16187 L
s
1 .894 .882 r
.37368 .16187 m
.37368 .09424 L
.37391 .09424 L
.37391 .16187 L
F
.804 .522 .247 r
.37368 .16187 m
.37368 .09424 L
.37391 .09424 L
.37391 .16187 L
s
1 .894 .882 r
.37391 .16187 m
.37391 .0944 L
.37425 .0944 L
.37425 .16187 L
F
.804 .522 .247 r
.37391 .16187 m
.37391 .0944 L
.37425 .0944 L
.37425 .16187 L
s
1 .894 .882 r
.37425 .16187 m
.37425 .09441 L
.3746 .09441 L
.3746 .16187 L
F
.804 .522 .247 r
.37425 .16187 m
.37425 .09441 L
.3746 .09441 L
.3746 .16187 L
s
1 .894 .882 r
.3746 .16187 m
.3746 .09467 L
.37503 .09467 L
.37503 .16187 L
F
.804 .522 .247 r
.3746 .16187 m
.3746 .09467 L
.37503 .09467 L
.37503 .16187 L
s
1 .894 .882 r
.37503 .16187 m
.37503 .09487 L
.37546 .09487 L
.37546 .16187 L
F
.804 .522 .247 r
.37503 .16187 m
.37503 .09487 L
.37546 .09487 L
.37546 .16187 L
s
1 .894 .882 r
.37546 .16187 m
.37546 .09496 L
.37582 .09496 L
.37582 .16187 L
F
.804 .522 .247 r
.37546 .16187 m
.37546 .09496 L
.37582 .09496 L
.37582 .16187 L
s
1 .894 .882 r
.37582 .16187 m
.37582 .09517 L
.37623 .09517 L
.37623 .16187 L
F
.804 .522 .247 r
.37582 .16187 m
.37582 .09517 L
.37623 .09517 L
.37623 .16187 L
s
1 .894 .882 r
.37623 .16187 m
.37623 .0954 L
.37651 .0954 L
.37651 .16187 L
F
.804 .522 .247 r
.37623 .16187 m
.37623 .0954 L
.37651 .0954 L
.37651 .16187 L
s
1 .894 .882 r
.37651 .16187 m
.37651 .09552 L
.37688 .09552 L
.37688 .16187 L
F
.804 .522 .247 r
.37651 .16187 m
.37651 .09552 L
.37688 .09552 L
.37688 .16187 L
s
1 .894 .882 r
.37688 .16187 m
.37688 .09565 L
.37711 .09565 L
.37711 .16187 L
F
.804 .522 .247 r
.37688 .16187 m
.37688 .09565 L
.37711 .09565 L
.37711 .16187 L
s
1 .894 .882 r
.37711 .16187 m
.37711 .09584 L
.37739 .09584 L
.37739 .16187 L
F
.804 .522 .247 r
.37711 .16187 m
.37711 .09584 L
.37739 .09584 L
.37739 .16187 L
s
1 .894 .882 r
.37739 .16187 m
.37739 .09595 L
.37767 .09595 L
.37767 .16187 L
F
.804 .522 .247 r
.37739 .16187 m
.37739 .09595 L
.37767 .09595 L
.37767 .16187 L
s
1 .894 .882 r
.37767 .16187 m
.37767 .09608 L
.37813 .09608 L
.37813 .16187 L
F
.804 .522 .247 r
.37767 .16187 m
.37767 .09608 L
.37813 .09608 L
.37813 .16187 L
s
1 .894 .882 r
.37813 .16187 m
.37813 .09631 L
.37853 .09631 L
.37853 .16187 L
F
.804 .522 .247 r
.37813 .16187 m
.37813 .09631 L
.37853 .09631 L
.37853 .16187 L
s
1 .894 .882 r
.37853 .16187 m
.37853 .09638 L
.37869 .09638 L
.37869 .16187 L
F
.804 .522 .247 r
.37853 .16187 m
.37853 .09638 L
.37869 .09638 L
.37869 .16187 L
s
1 .894 .882 r
.37869 .16187 m
.37869 .09649 L
.37889 .09649 L
.37889 .16187 L
F
.804 .522 .247 r
.37869 .16187 m
.37869 .09649 L
.37889 .09649 L
.37889 .16187 L
s
1 .894 .882 r
.37889 .16187 m
.37889 .09659 L
.37934 .09659 L
.37934 .16187 L
F
.804 .522 .247 r
.37889 .16187 m
.37889 .09659 L
.37934 .09659 L
.37934 .16187 L
s
1 .894 .882 r
.37934 .16187 m
.37934 .09676 L
.37968 .09676 L
.37968 .16187 L
F
.804 .522 .247 r
.37934 .16187 m
.37934 .09676 L
.37968 .09676 L
.37968 .16187 L
s
1 .894 .882 r
.37968 .16187 m
.37968 .09708 L
.38013 .09708 L
.38013 .16187 L
F
.804 .522 .247 r
.37968 .16187 m
.37968 .09708 L
.38013 .09708 L
.38013 .16187 L
s
1 .894 .882 r
.38013 .16187 m
.38013 .09711 L
.38032 .09711 L
.38032 .16187 L
F
.804 .522 .247 r
.38013 .16187 m
.38013 .09711 L
.38032 .09711 L
.38032 .16187 L
s
1 .894 .882 r
.38032 .16187 m
.38032 .09721 L
.38052 .09721 L
.38052 .16187 L
F
.804 .522 .247 r
.38032 .16187 m
.38032 .09721 L
.38052 .09721 L
.38052 .16187 L
s
1 .894 .882 r
.38052 .16187 m
.38052 .09734 L
.38085 .09734 L
.38085 .16187 L
F
.804 .522 .247 r
.38052 .16187 m
.38052 .09734 L
.38085 .09734 L
.38085 .16187 L
s
1 .894 .882 r
.38085 .16187 m
.38085 .09751 L
.38121 .09751 L
.38121 .16187 L
F
.804 .522 .247 r
.38085 .16187 m
.38085 .09751 L
.38121 .09751 L
.38121 .16187 L
s
1 .894 .882 r
.38121 .16187 m
.38121 .09769 L
.3814 .09769 L
.3814 .16187 L
F
.804 .522 .247 r
.38121 .16187 m
.38121 .09769 L
.3814 .09769 L
.3814 .16187 L
s
1 .894 .882 r
.3814 .16187 m
.3814 .09776 L
.38186 .09776 L
.38186 .16187 L
F
.804 .522 .247 r
.3814 .16187 m
.3814 .09776 L
.38186 .09776 L
.38186 .16187 L
s
1 .894 .882 r
.38186 .16187 m
.38186 .09801 L
.38235 .09801 L
.38235 .16187 L
F
.804 .522 .247 r
.38186 .16187 m
.38186 .09801 L
.38235 .09801 L
.38235 .16187 L
s
1 .894 .882 r
.38235 .16187 m
.38235 .09817 L
.38251 .09817 L
.38251 .16187 L
F
.804 .522 .247 r
.38235 .16187 m
.38235 .09817 L
.38251 .09817 L
.38251 .16187 L
s
1 .894 .882 r
.38251 .16187 m
.38251 .09825 L
.38276 .09825 L
.38276 .16187 L
F
.804 .522 .247 r
.38251 .16187 m
.38251 .09825 L
.38276 .09825 L
.38276 .16187 L
s
1 .894 .882 r
.38276 .16187 m
.38276 .09839 L
.38294 .09839 L
.38294 .16187 L
F
.804 .522 .247 r
.38276 .16187 m
.38276 .09839 L
.38294 .09839 L
.38294 .16187 L
s
1 .894 .882 r
.38294 .16187 m
.38294 .09847 L
.38322 .09847 L
.38322 .16187 L
F
.804 .522 .247 r
.38294 .16187 m
.38294 .09847 L
.38322 .09847 L
.38322 .16187 L
s
1 .894 .882 r
.38322 .16187 m
.38322 .09856 L
.38345 .09856 L
.38345 .16187 L
F
.804 .522 .247 r
.38322 .16187 m
.38322 .09856 L
.38345 .09856 L
.38345 .16187 L
s
1 .894 .882 r
.38345 .16187 m
.38345 .09879 L
.38391 .09879 L
.38391 .16187 L
F
.804 .522 .247 r
.38345 .16187 m
.38345 .09879 L
.38391 .09879 L
.38391 .16187 L
s
1 .894 .882 r
.38391 .16187 m
.38391 .09891 L
.38422 .09891 L
.38422 .16187 L
F
.804 .522 .247 r
.38391 .16187 m
.38391 .09891 L
.38422 .09891 L
.38422 .16187 L
s
1 .894 .882 r
.38422 .16187 m
.38422 .09902 L
.38441 .09902 L
.38441 .16187 L
F
.804 .522 .247 r
.38422 .16187 m
.38422 .09902 L
.38441 .09902 L
.38441 .16187 L
s
1 .894 .882 r
.38441 .16187 m
.38441 .09914 L
.38486 .09914 L
.38486 .16187 L
F
.804 .522 .247 r
.38441 .16187 m
.38441 .09914 L
.38486 .09914 L
.38486 .16187 L
s
1 .894 .882 r
.38486 .16187 m
.38486 .09944 L
.38519 .09944 L
.38519 .16187 L
F
.804 .522 .247 r
.38486 .16187 m
.38486 .09944 L
.38519 .09944 L
.38519 .16187 L
s
1 .894 .882 r
.38519 .16187 m
.38519 .09959 L
.38553 .09959 L
.38553 .16187 L
F
.804 .522 .247 r
.38519 .16187 m
.38519 .09959 L
.38553 .09959 L
.38553 .16187 L
s
1 .894 .882 r
.38553 .16187 m
.38553 .09967 L
.38581 .09967 L
.38581 .16187 L
F
.804 .522 .247 r
.38553 .16187 m
.38553 .09967 L
.38581 .09967 L
.38581 .16187 L
s
1 .894 .882 r
.38581 .16187 m
.38581 .09976 L
.38625 .09976 L
.38625 .16187 L
F
.804 .522 .247 r
.38581 .16187 m
.38581 .09976 L
.38625 .09976 L
.38625 .16187 L
s
1 .894 .882 r
.38625 .16187 m
.38625 .10001 L
.38652 .10001 L
.38652 .16187 L
F
.804 .522 .247 r
.38625 .16187 m
.38625 .10001 L
.38652 .10001 L
.38652 .16187 L
s
1 .894 .882 r
.38652 .16187 m
.38652 .10019 L
.38691 .10019 L
.38691 .16187 L
F
.804 .522 .247 r
.38652 .16187 m
.38652 .10019 L
.38691 .10019 L
.38691 .16187 L
s
1 .894 .882 r
.38691 .16187 m
.38691 .10033 L
.38735 .10033 L
.38735 .16187 L
F
.804 .522 .247 r
.38691 .16187 m
.38691 .10033 L
.38735 .10033 L
.38735 .16187 L
s
1 .894 .882 r
.38735 .16187 m
.38735 .10051 L
.38782 .10051 L
.38782 .16187 L
F
.804 .522 .247 r
.38735 .16187 m
.38735 .10051 L
.38782 .10051 L
.38782 .16187 L
s
1 .894 .882 r
.38782 .16187 m
.38782 .10073 L
.38805 .10073 L
.38805 .16187 L
F
.804 .522 .247 r
.38782 .16187 m
.38782 .10073 L
.38805 .10073 L
.38805 .16187 L
s
1 .894 .882 r
.38805 .16187 m
.38805 .10087 L
.38839 .10087 L
.38839 .16187 L
F
.804 .522 .247 r
.38805 .16187 m
.38805 .10087 L
.38839 .10087 L
.38839 .16187 L
s
1 .894 .882 r
.38839 .16187 m
.38839 .10108 L
.38864 .10108 L
.38864 .16187 L
F
.804 .522 .247 r
.38839 .16187 m
.38839 .10108 L
.38864 .10108 L
.38864 .16187 L
s
1 .894 .882 r
.38864 .16187 m
.38864 .10118 L
.38891 .10118 L
.38891 .16187 L
F
.804 .522 .247 r
.38864 .16187 m
.38864 .10118 L
.38891 .10118 L
.38891 .16187 L
s
1 .894 .882 r
.38891 .16187 m
.38891 .10125 L
.3891 .10125 L
.3891 .16187 L
F
.804 .522 .247 r
.38891 .16187 m
.38891 .10125 L
.3891 .10125 L
.3891 .16187 L
s
1 .894 .882 r
.3891 .16187 m
.3891 .10131 L
.38946 .10131 L
.38946 .16187 L
F
.804 .522 .247 r
.3891 .16187 m
.3891 .10131 L
.38946 .10131 L
.38946 .16187 L
s
1 .894 .882 r
.38946 .16187 m
.38946 .10154 L
.38971 .10154 L
.38971 .16187 L
F
.804 .522 .247 r
.38946 .16187 m
.38946 .10154 L
.38971 .10154 L
.38971 .16187 L
s
1 .894 .882 r
.38971 .16187 m
.38971 .10163 L
.38997 .10163 L
.38997 .16187 L
F
.804 .522 .247 r
.38971 .16187 m
.38971 .10163 L
.38997 .10163 L
.38997 .16187 L
s
1 .894 .882 r
.38997 .16187 m
.38997 .10172 L
.3904 .10172 L
.3904 .16187 L
F
.804 .522 .247 r
.38997 .16187 m
.38997 .10172 L
.3904 .10172 L
.3904 .16187 L
s
1 .894 .882 r
.3904 .16187 m
.3904 .10197 L
.39074 .10197 L
.39074 .16187 L
F
.804 .522 .247 r
.3904 .16187 m
.3904 .10197 L
.39074 .10197 L
.39074 .16187 L
s
1 .894 .882 r
.39074 .16187 m
.39074 .1021 L
.3912 .1021 L
.3912 .16187 L
F
.804 .522 .247 r
.39074 .16187 m
.39074 .1021 L
.3912 .1021 L
.3912 .16187 L
s
1 .894 .882 r
.3912 .16187 m
.3912 .10232 L
.39138 .10232 L
.39138 .16187 L
F
.804 .522 .247 r
.3912 .16187 m
.3912 .10232 L
.39138 .10232 L
.39138 .16187 L
s
1 .894 .882 r
.39138 .16187 m
.39138 .10247 L
.39183 .10247 L
.39183 .16187 L
F
.804 .522 .247 r
.39138 .16187 m
.39138 .10247 L
.39183 .10247 L
.39183 .16187 L
s
1 .894 .882 r
.39183 .16187 m
.39183 .10269 L
.39201 .10269 L
.39201 .16187 L
F
.804 .522 .247 r
.39183 .16187 m
.39183 .10269 L
.39201 .10269 L
.39201 .16187 L
s
1 .894 .882 r
.39201 .16187 m
.39201 .10289 L
.39243 .10289 L
.39243 .16187 L
F
.804 .522 .247 r
.39201 .16187 m
.39201 .10289 L
.39243 .10289 L
.39243 .16187 L
s
1 .894 .882 r
.39243 .16187 m
.39243 .10299 L
.39265 .10299 L
.39265 .16187 L
F
.804 .522 .247 r
.39243 .16187 m
.39243 .10299 L
.39265 .10299 L
.39265 .16187 L
s
1 .894 .882 r
.39265 .16187 m
.39265 .10306 L
.39293 .10306 L
.39293 .16187 L
F
.804 .522 .247 r
.39265 .16187 m
.39265 .10306 L
.39293 .10306 L
.39293 .16187 L
s
1 .894 .882 r
.39293 .16187 m
.39293 .10315 L
.39325 .10315 L
.39325 .16187 L
F
.804 .522 .247 r
.39293 .16187 m
.39293 .10315 L
.39325 .10315 L
.39325 .16187 L
s
1 .894 .882 r
.39325 .16187 m
.39325 .10337 L
.39354 .10337 L
.39354 .16187 L
F
.804 .522 .247 r
.39325 .16187 m
.39325 .10337 L
.39354 .10337 L
.39354 .16187 L
s
1 .894 .882 r
.39354 .16187 m
.39354 .10354 L
.39382 .10354 L
.39382 .16187 L
F
.804 .522 .247 r
.39354 .16187 m
.39354 .10354 L
.39382 .10354 L
.39382 .16187 L
s
1 .894 .882 r
.39382 .16187 m
.39382 .10359 L
.39431 .10359 L
.39431 .16187 L
F
.804 .522 .247 r
.39382 .16187 m
.39382 .10359 L
.39431 .10359 L
.39431 .16187 L
s
1 .894 .882 r
.39431 .16187 m
.39431 .10391 L
.39473 .10391 L
.39473 .16187 L
F
.804 .522 .247 r
.39431 .16187 m
.39431 .10391 L
.39473 .10391 L
.39473 .16187 L
s
1 .894 .882 r
.39473 .16187 m
.39473 .10406 L
.39508 .10406 L
.39508 .16187 L
F
.804 .522 .247 r
.39473 .16187 m
.39473 .10406 L
.39508 .10406 L
.39508 .16187 L
s
1 .894 .882 r
.39508 .16187 m
.39508 .10427 L
.39538 .10427 L
.39538 .16187 L
F
.804 .522 .247 r
.39508 .16187 m
.39508 .10427 L
.39538 .10427 L
.39538 .16187 L
s
1 .894 .882 r
.39538 .16187 m
.39538 .10448 L
.39578 .10448 L
.39578 .16187 L
F
.804 .522 .247 r
.39538 .16187 m
.39538 .10448 L
.39578 .10448 L
.39578 .16187 L
s
1 .894 .882 r
.39578 .16187 m
.39578 .10453 L
.39602 .10453 L
.39602 .16187 L
F
.804 .522 .247 r
.39578 .16187 m
.39578 .10453 L
.39602 .10453 L
.39602 .16187 L
s
1 .894 .882 r
.39602 .16187 m
.39602 .10467 L
.39627 .10467 L
.39627 .16187 L
F
.804 .522 .247 r
.39602 .16187 m
.39602 .10467 L
.39627 .10467 L
.39627 .16187 L
s
1 .894 .882 r
.39627 .16187 m
.39627 .10474 L
.39644 .10474 L
.39644 .16187 L
F
.804 .522 .247 r
.39627 .16187 m
.39627 .10474 L
.39644 .10474 L
.39644 .16187 L
s
1 .894 .882 r
.39644 .16187 m
.39644 .10491 L
.3968 .10491 L
.3968 .16187 L
F
.804 .522 .247 r
.39644 .16187 m
.39644 .10491 L
.3968 .10491 L
.3968 .16187 L
s
1 .894 .882 r
.3968 .16187 m
.3968 .10503 L
.39717 .10503 L
.39717 .16187 L
F
.804 .522 .247 r
.3968 .16187 m
.3968 .10503 L
.39717 .10503 L
.39717 .16187 L
s
1 .894 .882 r
.39717 .16187 m
.39717 .1054 L
.39766 .1054 L
.39766 .16187 L
F
.804 .522 .247 r
.39717 .16187 m
.39717 .1054 L
.39766 .1054 L
.39766 .16187 L
s
1 .894 .882 r
.39766 .16187 m
.39766 .10556 L
.39807 .10556 L
.39807 .16187 L
F
.804 .522 .247 r
.39766 .16187 m
.39766 .10556 L
.39807 .10556 L
.39807 .16187 L
s
1 .894 .882 r
.39807 .16187 m
.39807 .10571 L
.39849 .10571 L
.39849 .16187 L
F
.804 .522 .247 r
.39807 .16187 m
.39807 .10571 L
.39849 .10571 L
.39849 .16187 L
s
1 .894 .882 r
.39849 .16187 m
.39849 .1059 L
.39866 .1059 L
.39866 .16187 L
F
.804 .522 .247 r
.39849 .16187 m
.39849 .1059 L
.39866 .1059 L
.39866 .16187 L
s
1 .894 .882 r
.39866 .16187 m
.39866 .10598 L
.39884 .10598 L
.39884 .16187 L
F
.804 .522 .247 r
.39866 .16187 m
.39866 .10598 L
.39884 .10598 L
.39884 .16187 L
s
1 .894 .882 r
.39884 .16187 m
.39884 .10611 L
.39922 .10611 L
.39922 .16187 L
F
.804 .522 .247 r
.39884 .16187 m
.39884 .10611 L
.39922 .10611 L
.39922 .16187 L
s
1 .894 .882 r
.39922 .16187 m
.39922 .1062 L
.39968 .1062 L
.39968 .16187 L
F
.804 .522 .247 r
.39922 .16187 m
.39922 .1062 L
.39968 .1062 L
.39968 .16187 L
s
1 .894 .882 r
.39968 .16187 m
.39968 .1064 L
.40017 .1064 L
.40017 .16187 L
F
.804 .522 .247 r
.39968 .16187 m
.39968 .1064 L
.40017 .1064 L
.40017 .16187 L
s
1 .894 .882 r
.40017 .16187 m
.40017 .10674 L
.40041 .10674 L
.40041 .16187 L
F
.804 .522 .247 r
.40017 .16187 m
.40017 .10674 L
.40041 .10674 L
.40041 .16187 L
s
1 .894 .882 r
.40041 .16187 m
.40041 .10687 L
.40073 .10687 L
.40073 .16187 L
F
.804 .522 .247 r
.40041 .16187 m
.40041 .10687 L
.40073 .10687 L
.40073 .16187 L
s
1 .894 .882 r
.40073 .16187 m
.40073 .107 L
.40105 .107 L
.40105 .16187 L
F
.804 .522 .247 r
.40073 .16187 m
.40073 .107 L
.40105 .107 L
.40105 .16187 L
s
1 .894 .882 r
.40105 .16187 m
.40105 .10721 L
.40137 .10721 L
.40137 .16187 L
F
.804 .522 .247 r
.40105 .16187 m
.40105 .10721 L
.40137 .10721 L
.40137 .16187 L
s
1 .894 .882 r
.40137 .16187 m
.40137 .10729 L
.40182 .10729 L
.40182 .16187 L
F
.804 .522 .247 r
.40137 .16187 m
.40137 .10729 L
.40182 .10729 L
.40182 .16187 L
s
1 .894 .882 r
.40182 .16187 m
.40182 .10752 L
.402 .10752 L
.402 .16187 L
F
.804 .522 .247 r
.40182 .16187 m
.40182 .10752 L
.402 .10752 L
.402 .16187 L
s
1 .894 .882 r
.402 .16187 m
.402 .10761 L
.40233 .10761 L
.40233 .16187 L
F
.804 .522 .247 r
.402 .16187 m
.402 .10761 L
.40233 .10761 L
.40233 .16187 L
s
1 .894 .882 r
.40233 .16187 m
.40233 .10775 L
.40271 .10775 L
.40271 .16187 L
F
.804 .522 .247 r
.40233 .16187 m
.40233 .10775 L
.40271 .10775 L
.40271 .16187 L
s
1 .894 .882 r
.40271 .16187 m
.40271 .108 L
.40296 .108 L
.40296 .16187 L
F
.804 .522 .247 r
.40271 .16187 m
.40271 .108 L
.40296 .108 L
.40296 .16187 L
s
1 .894 .882 r
.40296 .16187 m
.40296 .10803 L
.40334 .10803 L
.40334 .16187 L
F
.804 .522 .247 r
.40296 .16187 m
.40296 .10803 L
.40334 .10803 L
.40334 .16187 L
s
1 .894 .882 r
.40334 .16187 m
.40334 .10832 L
.40376 .10832 L
.40376 .16187 L
F
.804 .522 .247 r
.40334 .16187 m
.40334 .10832 L
.40376 .10832 L
.40376 .16187 L
s
1 .894 .882 r
.40376 .16187 m
.40376 .10841 L
.40405 .10841 L
.40405 .16187 L
F
.804 .522 .247 r
.40376 .16187 m
.40376 .10841 L
.40405 .10841 L
.40405 .16187 L
s
1 .894 .882 r
.40405 .16187 m
.40405 .10867 L
.40454 .10867 L
.40454 .16187 L
F
.804 .522 .247 r
.40405 .16187 m
.40405 .10867 L
.40454 .10867 L
.40454 .16187 L
s
1 .894 .882 r
.40454 .16187 m
.40454 .1088 L
.40489 .1088 L
.40489 .16187 L
F
.804 .522 .247 r
.40454 .16187 m
.40454 .1088 L
.40489 .1088 L
.40489 .16187 L
s
1 .894 .882 r
.40489 .16187 m
.40489 .10897 L
.4051 .10897 L
.4051 .16187 L
F
.804 .522 .247 r
.40489 .16187 m
.40489 .10897 L
.4051 .10897 L
.4051 .16187 L
s
1 .894 .882 r
.4051 .16187 m
.4051 .10924 L
.40552 .10924 L
.40552 .16187 L
F
.804 .522 .247 r
.4051 .16187 m
.4051 .10924 L
.40552 .10924 L
.40552 .16187 L
s
1 .894 .882 r
.40552 .16187 m
.40552 .10941 L
.40601 .10941 L
.40601 .16187 L
F
.804 .522 .247 r
.40552 .16187 m
.40552 .10941 L
.40601 .10941 L
.40601 .16187 L
s
1 .894 .882 r
.40601 .16187 m
.40601 .10958 L
.40644 .10958 L
.40644 .16187 L
F
.804 .522 .247 r
.40601 .16187 m
.40601 .10958 L
.40644 .10958 L
.40644 .16187 L
s
1 .894 .882 r
.40644 .16187 m
.40644 .10982 L
.40672 .10982 L
.40672 .16187 L
F
.804 .522 .247 r
.40644 .16187 m
.40644 .10982 L
.40672 .10982 L
.40672 .16187 L
s
1 .894 .882 r
.40672 .16187 m
.40672 .11005 L
.40712 .11005 L
.40712 .16187 L
F
.804 .522 .247 r
.40672 .16187 m
.40672 .11005 L
.40712 .11005 L
.40712 .16187 L
s
1 .894 .882 r
.40712 .16187 m
.40712 .11022 L
.40758 .11022 L
.40758 .16187 L
F
.804 .522 .247 r
.40712 .16187 m
.40712 .11022 L
.40758 .11022 L
.40758 .16187 L
s
1 .894 .882 r
.40758 .16187 m
.40758 .11036 L
.40778 .11036 L
.40778 .16187 L
F
.804 .522 .247 r
.40758 .16187 m
.40758 .11036 L
.40778 .11036 L
.40778 .16187 L
s
1 .894 .882 r
.40778 .16187 m
.40778 .11048 L
.40809 .11048 L
.40809 .16187 L
F
.804 .522 .247 r
.40778 .16187 m
.40778 .11048 L
.40809 .11048 L
.40809 .16187 L
s
1 .894 .882 r
.40809 .16187 m
.40809 .11072 L
.40849 .11072 L
.40849 .16187 L
F
.804 .522 .247 r
.40809 .16187 m
.40809 .11072 L
.40849 .11072 L
.40849 .16187 L
s
1 .894 .882 r
.40849 .16187 m
.40849 .11088 L
.40885 .11088 L
.40885 .16187 L
F
.804 .522 .247 r
.40849 .16187 m
.40849 .11088 L
.40885 .11088 L
.40885 .16187 L
s
1 .894 .882 r
.40885 .16187 m
.40885 .1111 L
.40923 .1111 L
.40923 .16187 L
F
.804 .522 .247 r
.40885 .16187 m
.40885 .1111 L
.40923 .1111 L
.40923 .16187 L
s
1 .894 .882 r
.40923 .16187 m
.40923 .11134 L
.4097 .11134 L
.4097 .16187 L
F
.804 .522 .247 r
.40923 .16187 m
.40923 .11134 L
.4097 .11134 L
.4097 .16187 L
s
1 .894 .882 r
.4097 .16187 m
.4097 .11147 L
.40993 .11147 L
.40993 .16187 L
F
.804 .522 .247 r
.4097 .16187 m
.4097 .11147 L
.40993 .11147 L
.40993 .16187 L
s
1 .894 .882 r
.40993 .16187 m
.40993 .11156 L
.41034 .11156 L
.41034 .16187 L
F
.804 .522 .247 r
.40993 .16187 m
.40993 .11156 L
.41034 .11156 L
.41034 .16187 L
s
1 .894 .882 r
.41034 .16187 m
.41034 .11168 L
.41069 .11168 L
.41069 .16187 L
F
.804 .522 .247 r
.41034 .16187 m
.41034 .11168 L
.41069 .11168 L
.41069 .16187 L
s
1 .894 .882 r
.41069 .16187 m
.41069 .11192 L
.41098 .11192 L
.41098 .16187 L
F
.804 .522 .247 r
.41069 .16187 m
.41069 .11192 L
.41098 .11192 L
.41098 .16187 L
s
1 .894 .882 r
.41098 .16187 m
.41098 .11211 L
.41132 .11211 L
.41132 .16187 L
F
.804 .522 .247 r
.41098 .16187 m
.41098 .11211 L
.41132 .11211 L
.41132 .16187 L
s
1 .894 .882 r
.41132 .16187 m
.41132 .11224 L
.41163 .11224 L
.41163 .16187 L
F
.804 .522 .247 r
.41132 .16187 m
.41132 .11224 L
.41163 .11224 L
.41163 .16187 L
s
1 .894 .882 r
.41163 .16187 m
.41163 .11252 L
.41208 .11252 L
.41208 .16187 L
F
.804 .522 .247 r
.41163 .16187 m
.41163 .11252 L
.41208 .11252 L
.41208 .16187 L
s
1 .894 .882 r
.41208 .16187 m
.41208 .11271 L
.41245 .11271 L
.41245 .16187 L
F
.804 .522 .247 r
.41208 .16187 m
.41208 .11271 L
.41245 .11271 L
.41245 .16187 L
s
1 .894 .882 r
.41245 .16187 m
.41245 .11279 L
.41264 .11279 L
.41264 .16187 L
F
.804 .522 .247 r
.41245 .16187 m
.41245 .11279 L
.41264 .11279 L
.41264 .16187 L
s
1 .894 .882 r
.41264 .16187 m
.41264 .11298 L
.41296 .11298 L
.41296 .16187 L
F
.804 .522 .247 r
.41264 .16187 m
.41264 .11298 L
.41296 .11298 L
.41296 .16187 L
s
1 .894 .882 r
.41296 .16187 m
.41296 .11309 L
.41321 .11309 L
.41321 .16187 L
F
.804 .522 .247 r
.41296 .16187 m
.41296 .11309 L
.41321 .11309 L
.41321 .16187 L
s
1 .894 .882 r
.41321 .16187 m
.41321 .11323 L
.41352 .11323 L
.41352 .16187 L
F
.804 .522 .247 r
.41321 .16187 m
.41321 .11323 L
.41352 .11323 L
.41352 .16187 L
s
1 .894 .882 r
.41352 .16187 m
.41352 .11337 L
.41378 .11337 L
.41378 .16187 L
F
.804 .522 .247 r
.41352 .16187 m
.41352 .11337 L
.41378 .11337 L
.41378 .16187 L
s
1 .894 .882 r
.41378 .16187 m
.41378 .11346 L
.4141 .11346 L
.4141 .16187 L
F
.804 .522 .247 r
.41378 .16187 m
.41378 .11346 L
.4141 .11346 L
.4141 .16187 L
s
1 .894 .882 r
.4141 .16187 m
.4141 .11363 L
.41441 .11363 L
.41441 .16187 L
F
.804 .522 .247 r
.4141 .16187 m
.4141 .11363 L
.41441 .11363 L
.41441 .16187 L
s
1 .894 .882 r
.41441 .16187 m
.41441 .11373 L
.41459 .11373 L
.41459 .16187 L
F
.804 .522 .247 r
.41441 .16187 m
.41441 .11373 L
.41459 .11373 L
.41459 .16187 L
s
1 .894 .882 r
.41459 .16187 m
.41459 .11396 L
.41494 .11396 L
.41494 .16187 L
F
.804 .522 .247 r
.41459 .16187 m
.41459 .11396 L
.41494 .11396 L
.41494 .16187 L
s
1 .894 .882 r
.41494 .16187 m
.41494 .11411 L
.41529 .11411 L
.41529 .16187 L
F
.804 .522 .247 r
.41494 .16187 m
.41494 .11411 L
.41529 .11411 L
.41529 .16187 L
s
1 .894 .882 r
.41529 .16187 m
.41529 .11427 L
.41555 .11427 L
.41555 .16187 L
F
.804 .522 .247 r
.41529 .16187 m
.41529 .11427 L
.41555 .11427 L
.41555 .16187 L
s
1 .894 .882 r
.41555 .16187 m
.41555 .1144 L
.41592 .1144 L
.41592 .16187 L
F
.804 .522 .247 r
.41555 .16187 m
.41555 .1144 L
.41592 .1144 L
.41592 .16187 L
s
1 .894 .882 r
.41592 .16187 m
.41592 .11469 L
.41636 .11469 L
.41636 .16187 L
F
.804 .522 .247 r
.41592 .16187 m
.41592 .11469 L
.41636 .11469 L
.41636 .16187 L
s
1 .894 .882 r
.41636 .16187 m
.41636 .11494 L
.41684 .11494 L
.41684 .16187 L
F
.804 .522 .247 r
.41636 .16187 m
.41636 .11494 L
.41684 .11494 L
.41684 .16187 L
s
1 .894 .882 r
.41684 .16187 m
.41684 .11512 L
.41721 .11512 L
.41721 .16187 L
F
.804 .522 .247 r
.41684 .16187 m
.41684 .11512 L
.41721 .11512 L
.41721 .16187 L
s
1 .894 .882 r
.41721 .16187 m
.41721 .11526 L
.41759 .11526 L
.41759 .16187 L
F
.804 .522 .247 r
.41721 .16187 m
.41721 .11526 L
.41759 .11526 L
.41759 .16187 L
s
1 .894 .882 r
.41759 .16187 m
.41759 .11551 L
.41796 .11551 L
.41796 .16187 L
F
.804 .522 .247 r
.41759 .16187 m
.41759 .11551 L
.41796 .11551 L
.41796 .16187 L
s
1 .894 .882 r
.41796 .16187 m
.41796 .11558 L
.41818 .11558 L
.41818 .16187 L
F
.804 .522 .247 r
.41796 .16187 m
.41796 .11558 L
.41818 .11558 L
.41818 .16187 L
s
1 .894 .882 r
.41818 .16187 m
.41818 .11571 L
.41835 .11571 L
.41835 .16187 L
F
.804 .522 .247 r
.41818 .16187 m
.41818 .11571 L
.41835 .11571 L
.41835 .16187 L
s
1 .894 .882 r
.41835 .16187 m
.41835 .11574 L
.41859 .11574 L
.41859 .16187 L
F
.804 .522 .247 r
.41835 .16187 m
.41835 .11574 L
.41859 .11574 L
.41859 .16187 L
s
1 .894 .882 r
.41859 .16187 m
.41859 .11587 L
.41877 .11587 L
.41877 .16187 L
F
.804 .522 .247 r
.41859 .16187 m
.41859 .11587 L
.41877 .11587 L
.41877 .16187 L
s
1 .894 .882 r
.41877 .16187 m
.41877 .11614 L
.41916 .11614 L
.41916 .16187 L
F
.804 .522 .247 r
.41877 .16187 m
.41877 .11614 L
.41916 .11614 L
.41916 .16187 L
s
1 .894 .882 r
.41916 .16187 m
.41916 .11625 L
.41938 .11625 L
.41938 .16187 L
F
.804 .522 .247 r
.41916 .16187 m
.41916 .11625 L
.41938 .11625 L
.41938 .16187 L
s
1 .894 .882 r
.41938 .16187 m
.41938 .11629 L
.41973 .11629 L
.41973 .16187 L
F
.804 .522 .247 r
.41938 .16187 m
.41938 .11629 L
.41973 .11629 L
.41973 .16187 L
s
1 .894 .882 r
.41973 .16187 m
.41973 .11659 L
.42021 .11659 L
.42021 .16187 L
F
.804 .522 .247 r
.41973 .16187 m
.41973 .11659 L
.42021 .11659 L
.42021 .16187 L
s
1 .894 .882 r
.42021 .16187 m
.42021 .1168 L
.42045 .1168 L
.42045 .16187 L
F
.804 .522 .247 r
.42021 .16187 m
.42021 .1168 L
.42045 .1168 L
.42045 .16187 L
s
1 .894 .882 r
.42045 .16187 m
.42045 .11684 L
.4209 .11684 L
.4209 .16187 L
F
.804 .522 .247 r
.42045 .16187 m
.42045 .11684 L
.4209 .11684 L
.4209 .16187 L
s
1 .894 .882 r
.4209 .16187 m
.4209 .11708 L
.42109 .11708 L
.42109 .16187 L
F
.804 .522 .247 r
.4209 .16187 m
.4209 .11708 L
.42109 .11708 L
.42109 .16187 L
s
1 .894 .882 r
.42109 .16187 m
.42109 .11731 L
.42146 .11731 L
.42146 .16187 L
F
.804 .522 .247 r
.42109 .16187 m
.42109 .11731 L
.42146 .11731 L
.42146 .16187 L
s
1 .894 .882 r
.42146 .16187 m
.42146 .11746 L
.42187 .11746 L
.42187 .16187 L
F
.804 .522 .247 r
.42146 .16187 m
.42146 .11746 L
.42187 .11746 L
.42187 .16187 L
s
1 .894 .882 r
.42187 .16187 m
.42187 .11764 L
.42215 .11764 L
.42215 .16187 L
F
.804 .522 .247 r
.42187 .16187 m
.42187 .11764 L
.42215 .11764 L
.42215 .16187 L
s
1 .894 .882 r
.42215 .16187 m
.42215 .11772 L
.42231 .11772 L
.42231 .16187 L
F
.804 .522 .247 r
.42215 .16187 m
.42215 .11772 L
.42231 .11772 L
.42231 .16187 L
s
1 .894 .882 r
.42231 .16187 m
.42231 .11778 L
.42248 .11778 L
.42248 .16187 L
F
.804 .522 .247 r
.42231 .16187 m
.42231 .11778 L
.42248 .11778 L
.42248 .16187 L
s
1 .894 .882 r
.42248 .16187 m
.42248 .11795 L
.42268 .11795 L
.42268 .16187 L
F
.804 .522 .247 r
.42248 .16187 m
.42248 .11795 L
.42268 .11795 L
.42268 .16187 L
s
1 .894 .882 r
.42268 .16187 m
.42268 .11805 L
.42286 .11805 L
.42286 .16187 L
F
.804 .522 .247 r
.42268 .16187 m
.42268 .11805 L
.42286 .11805 L
.42286 .16187 L
s
1 .894 .882 r
.42286 .16187 m
.42286 .11818 L
.42315 .11818 L
.42315 .16187 L
F
.804 .522 .247 r
.42286 .16187 m
.42286 .11818 L
.42315 .11818 L
.42315 .16187 L
s
1 .894 .882 r
.42315 .16187 m
.42315 .11822 L
.42336 .11822 L
.42336 .16187 L
F
.804 .522 .247 r
.42315 .16187 m
.42315 .11822 L
.42336 .11822 L
.42336 .16187 L
s
1 .894 .882 r
.42336 .16187 m
.42336 .11831 L
.42357 .11831 L
.42357 .16187 L
F
.804 .522 .247 r
.42336 .16187 m
.42336 .11831 L
.42357 .11831 L
.42357 .16187 L
s
1 .894 .882 r
.42357 .16187 m
.42357 .11844 L
.42387 .11844 L
.42387 .16187 L
F
.804 .522 .247 r
.42357 .16187 m
.42357 .11844 L
.42387 .11844 L
.42387 .16187 L
s
1 .894 .882 r
.42387 .16187 m
.42387 .11863 L
.42427 .11863 L
.42427 .16187 L
F
.804 .522 .247 r
.42387 .16187 m
.42387 .11863 L
.42427 .11863 L
.42427 .16187 L
s
1 .894 .882 r
.42427 .16187 m
.42427 .11884 L
.42461 .11884 L
.42461 .16187 L
F
.804 .522 .247 r
.42427 .16187 m
.42427 .11884 L
.42461 .11884 L
.42461 .16187 L
s
1 .894 .882 r
.42461 .16187 m
.42461 .1191 L
.4251 .1191 L
.4251 .16187 L
F
.804 .522 .247 r
.42461 .16187 m
.42461 .1191 L
.4251 .1191 L
.4251 .16187 L
s
1 .894 .882 r
.4251 .16187 m
.4251 .11926 L
.42536 .11926 L
.42536 .16187 L
F
.804 .522 .247 r
.4251 .16187 m
.4251 .11926 L
.42536 .11926 L
.42536 .16187 L
s
1 .894 .882 r
.42536 .16187 m
.42536 .11939 L
.42568 .11939 L
.42568 .16187 L
F
.804 .522 .247 r
.42536 .16187 m
.42536 .11939 L
.42568 .11939 L
.42568 .16187 L
s
1 .894 .882 r
.42568 .16187 m
.42568 .11953 L
.42599 .11953 L
.42599 .16187 L
F
.804 .522 .247 r
.42568 .16187 m
.42568 .11953 L
.42599 .11953 L
.42599 .16187 L
s
1 .894 .882 r
.42599 .16187 m
.42599 .11975 L
.42622 .11975 L
.42622 .16187 L
F
.804 .522 .247 r
.42599 .16187 m
.42599 .11975 L
.42622 .11975 L
.42622 .16187 L
s
1 .894 .882 r
.42622 .16187 m
.42622 .11985 L
.42643 .11985 L
.42643 .16187 L
F
.804 .522 .247 r
.42622 .16187 m
.42622 .11985 L
.42643 .11985 L
.42643 .16187 L
s
1 .894 .882 r
.42643 .16187 m
.42643 .11992 L
.42687 .11992 L
.42687 .16187 L
F
.804 .522 .247 r
.42643 .16187 m
.42643 .11992 L
.42687 .11992 L
.42687 .16187 L
s
1 .894 .882 r
.42687 .16187 m
.42687 .12022 L
.42719 .12022 L
.42719 .16187 L
F
.804 .522 .247 r
.42687 .16187 m
.42687 .12022 L
.42719 .12022 L
.42719 .16187 L
s
1 .894 .882 r
.42719 .16187 m
.42719 .12036 L
.42735 .12036 L
.42735 .16187 L
F
.804 .522 .247 r
.42719 .16187 m
.42719 .12036 L
.42735 .12036 L
.42735 .16187 L
s
1 .894 .882 r
.42735 .16187 m
.42735 .12043 L
.42759 .12043 L
.42759 .16187 L
F
.804 .522 .247 r
.42735 .16187 m
.42735 .12043 L
.42759 .12043 L
.42759 .16187 L
s
1 .894 .882 r
.42759 .16187 m
.42759 .12065 L
.42799 .12065 L
.42799 .16187 L
F
.804 .522 .247 r
.42759 .16187 m
.42759 .12065 L
.42799 .12065 L
.42799 .16187 L
s
1 .894 .882 r
.42799 .16187 m
.42799 .12086 L
.42843 .12086 L
.42843 .16187 L
F
.804 .522 .247 r
.42799 .16187 m
.42799 .12086 L
.42843 .12086 L
.42843 .16187 L
s
1 .894 .882 r
.42843 .16187 m
.42843 .12096 L
.42868 .12096 L
.42868 .16187 L
F
.804 .522 .247 r
.42843 .16187 m
.42843 .12096 L
.42868 .12096 L
.42868 .16187 L
s
1 .894 .882 r
.42868 .16187 m
.42868 .12123 L
.42913 .12123 L
.42913 .16187 L
F
.804 .522 .247 r
.42868 .16187 m
.42868 .12123 L
.42913 .12123 L
.42913 .16187 L
s
1 .894 .882 r
.42913 .16187 m
.42913 .12138 L
.42951 .12138 L
.42951 .16187 L
F
.804 .522 .247 r
.42913 .16187 m
.42913 .12138 L
.42951 .12138 L
.42951 .16187 L
s
1 .894 .882 r
.42951 .16187 m
.42951 .12164 L
.42994 .12164 L
.42994 .16187 L
F
.804 .522 .247 r
.42951 .16187 m
.42951 .12164 L
.42994 .12164 L
.42994 .16187 L
s
1 .894 .882 r
.42994 .16187 m
.42994 .12176 L
.43012 .12176 L
.43012 .16187 L
F
.804 .522 .247 r
.42994 .16187 m
.42994 .12176 L
.43012 .12176 L
.43012 .16187 L
s
1 .894 .882 r
.43012 .16187 m
.43012 .12199 L
.43055 .12199 L
.43055 .16187 L
F
.804 .522 .247 r
.43012 .16187 m
.43012 .12199 L
.43055 .12199 L
.43055 .16187 L
s
1 .894 .882 r
.43055 .16187 m
.43055 .12213 L
.43079 .12213 L
.43079 .16187 L
F
.804 .522 .247 r
.43055 .16187 m
.43055 .12213 L
.43079 .12213 L
.43079 .16187 L
s
1 .894 .882 r
.43079 .16187 m
.43079 .12226 L
.43115 .12226 L
.43115 .16187 L
F
.804 .522 .247 r
.43079 .16187 m
.43079 .12226 L
.43115 .12226 L
.43115 .16187 L
s
1 .894 .882 r
.43115 .16187 m
.43115 .12241 L
.43162 .12241 L
.43162 .16187 L
F
.804 .522 .247 r
.43115 .16187 m
.43115 .12241 L
.43162 .12241 L
.43162 .16187 L
s
1 .894 .882 r
.43162 .16187 m
.43162 .12271 L
.43189 .12271 L
.43189 .16187 L
F
.804 .522 .247 r
.43162 .16187 m
.43162 .12271 L
.43189 .12271 L
.43189 .16187 L
s
1 .894 .882 r
.43189 .16187 m
.43189 .12281 L
.43223 .12281 L
.43223 .16187 L
F
.804 .522 .247 r
.43189 .16187 m
.43189 .12281 L
.43223 .12281 L
.43223 .16187 L
s
1 .894 .882 r
.43223 .16187 m
.43223 .12305 L
.4324 .12305 L
.4324 .16187 L
F
.804 .522 .247 r
.43223 .16187 m
.43223 .12305 L
.4324 .12305 L
.4324 .16187 L
s
1 .894 .882 r
.4324 .16187 m
.4324 .12318 L
.43287 .12318 L
.43287 .16187 L
F
.804 .522 .247 r
.4324 .16187 m
.4324 .12318 L
.43287 .12318 L
.43287 .16187 L
s
1 .894 .882 r
.43287 .16187 m
.43287 .12331 L
.43303 .12331 L
.43303 .16187 L
F
.804 .522 .247 r
.43287 .16187 m
.43287 .12331 L
.43303 .12331 L
.43303 .16187 L
s
1 .894 .882 r
.43303 .16187 m
.43303 .12347 L
.43319 .12347 L
.43319 .16187 L
F
.804 .522 .247 r
.43303 .16187 m
.43303 .12347 L
.43319 .12347 L
.43319 .16187 L
s
1 .894 .882 r
.43319 .16187 m
.43319 .12364 L
.43354 .12364 L
.43354 .16187 L
F
.804 .522 .247 r
.43319 .16187 m
.43319 .12364 L
.43354 .12364 L
.43354 .16187 L
s
1 .894 .882 r
.43354 .16187 m
.43354 .12384 L
.43393 .12384 L
.43393 .16187 L
F
.804 .522 .247 r
.43354 .16187 m
.43354 .12384 L
.43393 .12384 L
.43393 .16187 L
s
1 .894 .882 r
.43393 .16187 m
.43393 .12404 L
.43437 .12404 L
.43437 .16187 L
F
.804 .522 .247 r
.43393 .16187 m
.43393 .12404 L
.43437 .12404 L
.43437 .16187 L
s
1 .894 .882 r
.43437 .16187 m
.43437 .1242 L
.43458 .1242 L
.43458 .16187 L
F
.804 .522 .247 r
.43437 .16187 m
.43437 .1242 L
.43458 .1242 L
.43458 .16187 L
s
1 .894 .882 r
.43458 .16187 m
.43458 .12425 L
.43476 .12425 L
.43476 .16187 L
F
.804 .522 .247 r
.43458 .16187 m
.43458 .12425 L
.43476 .12425 L
.43476 .16187 L
s
1 .894 .882 r
.43476 .16187 m
.43476 .12436 L
.43514 .12436 L
.43514 .16187 L
F
.804 .522 .247 r
.43476 .16187 m
.43476 .12436 L
.43514 .12436 L
.43514 .16187 L
s
1 .894 .882 r
.43514 .16187 m
.43514 .1246 L
.43549 .1246 L
.43549 .16187 L
F
.804 .522 .247 r
.43514 .16187 m
.43514 .1246 L
.43549 .1246 L
.43549 .16187 L
s
1 .894 .882 r
.43549 .16187 m
.43549 .12474 L
.43579 .12474 L
.43579 .16187 L
F
.804 .522 .247 r
.43549 .16187 m
.43549 .12474 L
.43579 .12474 L
.43579 .16187 L
s
1 .894 .882 r
.43579 .16187 m
.43579 .12496 L
.43602 .12496 L
.43602 .16187 L
F
.804 .522 .247 r
.43579 .16187 m
.43579 .12496 L
.43602 .12496 L
.43602 .16187 L
s
1 .894 .882 r
.43602 .16187 m
.43602 .12501 L
.43631 .12501 L
.43631 .16187 L
F
.804 .522 .247 r
.43602 .16187 m
.43602 .12501 L
.43631 .12501 L
.43631 .16187 L
s
1 .894 .882 r
.43631 .16187 m
.43631 .12532 L
.4367 .12532 L
.4367 .16187 L
F
.804 .522 .247 r
.43631 .16187 m
.43631 .12532 L
.4367 .12532 L
.4367 .16187 L
s
1 .894 .882 r
.4367 .16187 m
.4367 .12535 L
.4371 .12535 L
.4371 .16187 L
F
.804 .522 .247 r
.4367 .16187 m
.4367 .12535 L
.4371 .12535 L
.4371 .16187 L
s
1 .894 .882 r
.4371 .16187 m
.4371 .12561 L
.4374 .12561 L
.4374 .16187 L
F
.804 .522 .247 r
.4371 .16187 m
.4371 .12561 L
.4374 .12561 L
.4374 .16187 L
s
1 .894 .882 r
.4374 .16187 m
.4374 .12574 L
.43765 .12574 L
.43765 .16187 L
F
.804 .522 .247 r
.4374 .16187 m
.4374 .12574 L
.43765 .12574 L
.43765 .16187 L
s
1 .894 .882 r
.43765 .16187 m
.43765 .12591 L
.4381 .12591 L
.4381 .16187 L
F
.804 .522 .247 r
.43765 .16187 m
.43765 .12591 L
.4381 .12591 L
.4381 .16187 L
s
1 .894 .882 r
.4381 .16187 m
.4381 .1262 L
.43842 .1262 L
.43842 .16187 L
F
.804 .522 .247 r
.4381 .16187 m
.4381 .1262 L
.43842 .1262 L
.43842 .16187 L
s
1 .894 .882 r
.43842 .16187 m
.43842 .12628 L
.43885 .12628 L
.43885 .16187 L
F
.804 .522 .247 r
.43842 .16187 m
.43842 .12628 L
.43885 .12628 L
.43885 .16187 L
s
1 .894 .882 r
.43885 .16187 m
.43885 .1265 L
.43912 .1265 L
.43912 .16187 L
F
.804 .522 .247 r
.43885 .16187 m
.43885 .1265 L
.43912 .1265 L
.43912 .16187 L
s
1 .894 .882 r
.43912 .16187 m
.43912 .12678 L
.43945 .12678 L
.43945 .16187 L
F
.804 .522 .247 r
.43912 .16187 m
.43912 .12678 L
.43945 .12678 L
.43945 .16187 L
s
1 .894 .882 r
.43945 .16187 m
.43945 .12694 L
.43991 .12694 L
.43991 .16187 L
F
.804 .522 .247 r
.43945 .16187 m
.43945 .12694 L
.43991 .12694 L
.43991 .16187 L
s
1 .894 .882 r
.43991 .16187 m
.43991 .12709 L
.44033 .12709 L
.44033 .16187 L
F
.804 .522 .247 r
.43991 .16187 m
.43991 .12709 L
.44033 .12709 L
.44033 .16187 L
s
1 .894 .882 r
.44033 .16187 m
.44033 .12738 L
.44062 .12738 L
.44062 .16187 L
F
.804 .522 .247 r
.44033 .16187 m
.44033 .12738 L
.44062 .12738 L
.44062 .16187 L
s
1 .894 .882 r
.44062 .16187 m
.44062 .12755 L
.44094 .12755 L
.44094 .16187 L
F
.804 .522 .247 r
.44062 .16187 m
.44062 .12755 L
.44094 .12755 L
.44094 .16187 L
s
1 .894 .882 r
.44094 .16187 m
.44094 .12776 L
.44139 .12776 L
.44139 .16187 L
F
.804 .522 .247 r
.44094 .16187 m
.44094 .12776 L
.44139 .12776 L
.44139 .16187 L
s
1 .894 .882 r
.44139 .16187 m
.44139 .12789 L
.44159 .12789 L
.44159 .16187 L
F
.804 .522 .247 r
.44139 .16187 m
.44139 .12789 L
.44159 .12789 L
.44159 .16187 L
s
1 .894 .882 r
.44159 .16187 m
.44159 .12813 L
.44199 .12813 L
.44199 .16187 L
F
.804 .522 .247 r
.44159 .16187 m
.44159 .12813 L
.44199 .12813 L
.44199 .16187 L
s
1 .894 .882 r
.44199 .16187 m
.44199 .12836 L
.44236 .12836 L
.44236 .16187 L
F
.804 .522 .247 r
.44199 .16187 m
.44199 .12836 L
.44236 .12836 L
.44236 .16187 L
s
1 .894 .882 r
.44236 .16187 m
.44236 .12853 L
.44274 .12853 L
.44274 .16187 L
F
.804 .522 .247 r
.44236 .16187 m
.44236 .12853 L
.44274 .12853 L
.44274 .16187 L
s
1 .894 .882 r
.44274 .16187 m
.44274 .12868 L
.44293 .12868 L
.44293 .16187 L
F
.804 .522 .247 r
.44274 .16187 m
.44274 .12868 L
.44293 .12868 L
.44293 .16187 L
s
1 .894 .882 r
.44293 .16187 m
.44293 .12874 L
.44309 .12874 L
.44309 .16187 L
F
.804 .522 .247 r
.44293 .16187 m
.44293 .12874 L
.44309 .12874 L
.44309 .16187 L
s
1 .894 .882 r
.44309 .16187 m
.44309 .12883 L
.44325 .12883 L
.44325 .16187 L
F
.804 .522 .247 r
.44309 .16187 m
.44309 .12883 L
.44325 .12883 L
.44325 .16187 L
s
1 .894 .882 r
.44325 .16187 m
.44325 .12893 L
.44349 .12893 L
.44349 .16187 L
F
.804 .522 .247 r
.44325 .16187 m
.44325 .12893 L
.44349 .12893 L
.44349 .16187 L
s
1 .894 .882 r
.44349 .16187 m
.44349 .12924 L
.44393 .12924 L
.44393 .16187 L
F
.804 .522 .247 r
.44349 .16187 m
.44349 .12924 L
.44393 .12924 L
.44393 .16187 L
s
1 .894 .882 r
.44393 .16187 m
.44393 .1293 L
.4443 .1293 L
.4443 .16187 L
F
.804 .522 .247 r
.44393 .16187 m
.44393 .1293 L
.4443 .1293 L
.4443 .16187 L
s
1 .894 .882 r
.4443 .16187 m
.4443 .12953 L
.44457 .12953 L
.44457 .16187 L
F
.804 .522 .247 r
.4443 .16187 m
.4443 .12953 L
.44457 .12953 L
.44457 .16187 L
s
1 .894 .882 r
.44457 .16187 m
.44457 .12966 L
.44489 .12966 L
.44489 .16187 L
F
.804 .522 .247 r
.44457 .16187 m
.44457 .12966 L
.44489 .12966 L
.44489 .16187 L
s
1 .894 .882 r
.44489 .16187 m
.44489 .12988 L
.44518 .12988 L
.44518 .16187 L
F
.804 .522 .247 r
.44489 .16187 m
.44489 .12988 L
.44518 .12988 L
.44518 .16187 L
s
1 .894 .882 r
.44518 .16187 m
.44518 .12995 L
.44546 .12995 L
.44546 .16187 L
F
.804 .522 .247 r
.44518 .16187 m
.44518 .12995 L
.44546 .12995 L
.44546 .16187 L
s
1 .894 .882 r
.44546 .16187 m
.44546 .13013 L
.44576 .13013 L
.44576 .16187 L
F
.804 .522 .247 r
.44546 .16187 m
.44546 .13013 L
.44576 .13013 L
.44576 .16187 L
s
1 .894 .882 r
.44576 .16187 m
.44576 .13031 L
.44591 .13031 L
.44591 .16187 L
F
.804 .522 .247 r
.44576 .16187 m
.44576 .13031 L
.44591 .13031 L
.44591 .16187 L
s
1 .894 .882 r
.44591 .16187 m
.44591 .13045 L
.44627 .13045 L
.44627 .16187 L
F
.804 .522 .247 r
.44591 .16187 m
.44591 .13045 L
.44627 .13045 L
.44627 .16187 L
s
1 .894 .882 r
.44627 .16187 m
.44627 .13054 L
.44642 .13054 L
.44642 .16187 L
F
.804 .522 .247 r
.44627 .16187 m
.44627 .13054 L
.44642 .13054 L
.44642 .16187 L
s
1 .894 .882 r
.44642 .16187 m
.44642 .13074 L
.44688 .13074 L
.44688 .16187 L
F
.804 .522 .247 r
.44642 .16187 m
.44642 .13074 L
.44688 .13074 L
.44688 .16187 L
s
1 .894 .882 r
.44688 .16187 m
.44688 .13089 L
.44706 .13089 L
.44706 .16187 L
F
.804 .522 .247 r
.44688 .16187 m
.44688 .13089 L
.44706 .13089 L
.44706 .16187 L
s
1 .894 .882 r
.44706 .16187 m
.44706 .13109 L
.4475 .13109 L
.4475 .16187 L
F
.804 .522 .247 r
.44706 .16187 m
.44706 .13109 L
.4475 .13109 L
.4475 .16187 L
s
1 .894 .882 r
.4475 .16187 m
.4475 .1313 L
.44785 .1313 L
.44785 .16187 L
F
.804 .522 .247 r
.4475 .16187 m
.4475 .1313 L
.44785 .1313 L
.44785 .16187 L
s
1 .894 .882 r
.44785 .16187 m
.44785 .13155 L
.44814 .13155 L
.44814 .16187 L
F
.804 .522 .247 r
.44785 .16187 m
.44785 .13155 L
.44814 .13155 L
.44814 .16187 L
s
1 .894 .882 r
.44814 .16187 m
.44814 .13165 L
.44836 .13165 L
.44836 .16187 L
F
.804 .522 .247 r
.44814 .16187 m
.44814 .13165 L
.44836 .13165 L
.44836 .16187 L
s
1 .894 .882 r
.44836 .16187 m
.44836 .13175 L
.44874 .13175 L
.44874 .16187 L
F
.804 .522 .247 r
.44836 .16187 m
.44836 .13175 L
.44874 .13175 L
.44874 .16187 L
s
1 .894 .882 r
.44874 .16187 m
.44874 .1321 L
.44918 .1321 L
.44918 .16187 L
F
.804 .522 .247 r
.44874 .16187 m
.44874 .1321 L
.44918 .1321 L
.44918 .16187 L
s
1 .894 .882 r
.44918 .16187 m
.44918 .13216 L
.4496 .13216 L
.4496 .16187 L
F
.804 .522 .247 r
.44918 .16187 m
.44918 .13216 L
.4496 .13216 L
.4496 .16187 L
s
1 .894 .882 r
.4496 .16187 m
.4496 .13238 L
.44992 .13238 L
.44992 .16187 L
F
.804 .522 .247 r
.4496 .16187 m
.4496 .13238 L
.44992 .13238 L
.44992 .16187 L
s
1 .894 .882 r
.44992 .16187 m
.44992 .13265 L
.45027 .13265 L
.45027 .16187 L
F
.804 .522 .247 r
.44992 .16187 m
.44992 .13265 L
.45027 .13265 L
.45027 .16187 L
s
1 .894 .882 r
.45027 .16187 m
.45027 .13284 L
.4507 .13284 L
.4507 .16187 L
F
.804 .522 .247 r
.45027 .16187 m
.45027 .13284 L
.4507 .13284 L
.4507 .16187 L
s
1 .894 .882 r
.4507 .16187 m
.4507 .13313 L
.4511 .13313 L
.4511 .16187 L
F
.804 .522 .247 r
.4507 .16187 m
.4507 .13313 L
.4511 .13313 L
.4511 .16187 L
s
1 .894 .882 r
.4511 .16187 m
.4511 .13329 L
.45134 .13329 L
.45134 .16187 L
F
.804 .522 .247 r
.4511 .16187 m
.4511 .13329 L
.45134 .13329 L
.45134 .16187 L
s
1 .894 .882 r
.45134 .16187 m
.45134 .13346 L
.45173 .13346 L
.45173 .16187 L
F
.804 .522 .247 r
.45134 .16187 m
.45134 .13346 L
.45173 .13346 L
.45173 .16187 L
s
1 .894 .882 r
.45173 .16187 m
.45173 .13357 L
.45193 .13357 L
.45193 .16187 L
F
.804 .522 .247 r
.45173 .16187 m
.45173 .13357 L
.45193 .13357 L
.45193 .16187 L
s
1 .894 .882 r
.45193 .16187 m
.45193 .13369 L
.45222 .13369 L
.45222 .16187 L
F
.804 .522 .247 r
.45193 .16187 m
.45193 .13369 L
.45222 .13369 L
.45222 .16187 L
s
1 .894 .882 r
.45222 .16187 m
.45222 .13391 L
.45263 .13391 L
.45263 .16187 L
F
.804 .522 .247 r
.45222 .16187 m
.45222 .13391 L
.45263 .13391 L
.45263 .16187 L
s
1 .894 .882 r
.45263 .16187 m
.45263 .13418 L
.45288 .13418 L
.45288 .16187 L
F
.804 .522 .247 r
.45263 .16187 m
.45263 .13418 L
.45288 .13418 L
.45288 .16187 L
s
1 .894 .882 r
.45288 .16187 m
.45288 .13422 L
.4533 .13422 L
.4533 .16187 L
F
.804 .522 .247 r
.45288 .16187 m
.45288 .13422 L
.4533 .13422 L
.4533 .16187 L
s
1 .894 .882 r
.4533 .16187 m
.4533 .13468 L
.45378 .13468 L
.45378 .16187 L
F
.804 .522 .247 r
.4533 .16187 m
.4533 .13468 L
.45378 .13468 L
.45378 .16187 L
s
1 .894 .882 r
.45378 .16187 m
.45378 .13484 L
.45419 .13484 L
.45419 .16187 L
F
.804 .522 .247 r
.45378 .16187 m
.45378 .13484 L
.45419 .13484 L
.45419 .16187 L
s
1 .894 .882 r
.45419 .16187 m
.45419 .135 L
.45456 .135 L
.45456 .16187 L
F
.804 .522 .247 r
.45419 .16187 m
.45419 .135 L
.45456 .135 L
.45456 .16187 L
s
1 .894 .882 r
.45456 .16187 m
.45456 .13515 L
.45498 .13515 L
.45498 .16187 L
F
.804 .522 .247 r
.45456 .16187 m
.45456 .13515 L
.45498 .13515 L
.45498 .16187 L
s
1 .894 .882 r
.45498 .16187 m
.45498 .1354 L
.45515 .1354 L
.45515 .16187 L
F
.804 .522 .247 r
.45498 .16187 m
.45498 .1354 L
.45515 .1354 L
.45515 .16187 L
s
1 .894 .882 r
.45515 .16187 m
.45515 .13555 L
.45552 .13555 L
.45552 .16187 L
F
.804 .522 .247 r
.45515 .16187 m
.45515 .13555 L
.45552 .13555 L
.45552 .16187 L
s
1 .894 .882 r
.45552 .16187 m
.45552 .13588 L
.45595 .13588 L
.45595 .16187 L
F
.804 .522 .247 r
.45552 .16187 m
.45552 .13588 L
.45595 .13588 L
.45595 .16187 L
s
1 .894 .882 r
.45595 .16187 m
.45595 .13597 L
.45617 .13597 L
.45617 .16187 L
F
.804 .522 .247 r
.45595 .16187 m
.45595 .13597 L
.45617 .13597 L
.45617 .16187 L
s
1 .894 .882 r
.45617 .16187 m
.45617 .13613 L
.45654 .13613 L
.45654 .16187 L
F
.804 .522 .247 r
.45617 .16187 m
.45617 .13613 L
.45654 .13613 L
.45654 .16187 L
s
1 .894 .882 r
.45654 .16187 m
.45654 .13636 L
.45684 .13636 L
.45684 .16187 L
F
.804 .522 .247 r
.45654 .16187 m
.45654 .13636 L
.45684 .13636 L
.45684 .16187 L
s
1 .894 .882 r
.45684 .16187 m
.45684 .13647 L
.45704 .13647 L
.45704 .16187 L
F
.804 .522 .247 r
.45684 .16187 m
.45684 .13647 L
.45704 .13647 L
.45704 .16187 L
s
1 .894 .882 r
.45704 .16187 m
.45704 .13662 L
.4573 .13662 L
.4573 .16187 L
F
.804 .522 .247 r
.45704 .16187 m
.45704 .13662 L
.4573 .13662 L
.4573 .16187 L
s
1 .894 .882 r
.4573 .16187 m
.4573 .13677 L
.45774 .13677 L
.45774 .16187 L
F
.804 .522 .247 r
.4573 .16187 m
.4573 .13677 L
.45774 .13677 L
.45774 .16187 L
s
1 .894 .882 r
.45774 .16187 m
.45774 .13709 L
.45822 .13709 L
.45822 .16187 L
F
.804 .522 .247 r
.45774 .16187 m
.45774 .13709 L
.45822 .13709 L
.45822 .16187 L
s
1 .894 .882 r
.45822 .16187 m
.45822 .13718 L
.45856 .13718 L
.45856 .16187 L
F
.804 .522 .247 r
.45822 .16187 m
.45822 .13718 L
.45856 .13718 L
.45856 .16187 L
s
1 .894 .882 r
.45856 .16187 m
.45856 .13743 L
.45889 .13743 L
.45889 .16187 L
F
.804 .522 .247 r
.45856 .16187 m
.45856 .13743 L
.45889 .13743 L
.45889 .16187 L
s
1 .894 .882 r
.45889 .16187 m
.45889 .13763 L
.45907 .13763 L
.45907 .16187 L
F
.804 .522 .247 r
.45889 .16187 m
.45889 .13763 L
.45907 .13763 L
.45907 .16187 L
s
1 .894 .882 r
.45907 .16187 m
.45907 .13787 L
.45946 .13787 L
.45946 .16187 L
F
.804 .522 .247 r
.45907 .16187 m
.45907 .13787 L
.45946 .13787 L
.45946 .16187 L
s
1 .894 .882 r
.45946 .16187 m
.45946 .13799 L
.4599 .13799 L
.4599 .16187 L
F
.804 .522 .247 r
.45946 .16187 m
.45946 .13799 L
.4599 .13799 L
.4599 .16187 L
s
1 .894 .882 r
.4599 .16187 m
.4599 .13814 L
.46017 .13814 L
.46017 .16187 L
F
.804 .522 .247 r
.4599 .16187 m
.4599 .13814 L
.46017 .13814 L
.46017 .16187 L
s
1 .894 .882 r
.46017 .16187 m
.46017 .13839 L
.46056 .13839 L
.46056 .16187 L
F
.804 .522 .247 r
.46017 .16187 m
.46017 .13839 L
.46056 .13839 L
.46056 .16187 L
s
1 .894 .882 r
.46056 .16187 m
.46056 .13865 L
.46103 .13865 L
.46103 .16187 L
F
.804 .522 .247 r
.46056 .16187 m
.46056 .13865 L
.46103 .13865 L
.46103 .16187 L
s
1 .894 .882 r
.46103 .16187 m
.46103 .13885 L
.46138 .13885 L
.46138 .16187 L
F
.804 .522 .247 r
.46103 .16187 m
.46103 .13885 L
.46138 .13885 L
.46138 .16187 L
s
1 .894 .882 r
.46138 .16187 m
.46138 .13915 L
.46172 .13915 L
.46172 .16187 L
F
.804 .522 .247 r
.46138 .16187 m
.46138 .13915 L
.46172 .13915 L
.46172 .16187 L
s
1 .894 .882 r
.46172 .16187 m
.46172 .13928 L
.46212 .13928 L
.46212 .16187 L
F
.804 .522 .247 r
.46172 .16187 m
.46172 .13928 L
.46212 .13928 L
.46212 .16187 L
s
1 .894 .882 r
.46212 .16187 m
.46212 .13949 L
.46233 .13949 L
.46233 .16187 L
F
.804 .522 .247 r
.46212 .16187 m
.46212 .13949 L
.46233 .13949 L
.46233 .16187 L
s
1 .894 .882 r
.46233 .16187 m
.46233 .13951 L
.46279 .13951 L
.46279 .16187 L
F
.804 .522 .247 r
.46233 .16187 m
.46233 .13951 L
.46279 .13951 L
.46279 .16187 L
s
1 .894 .882 r
.46279 .16187 m
.46279 .13996 L
.46321 .13996 L
.46321 .16187 L
F
.804 .522 .247 r
.46279 .16187 m
.46279 .13996 L
.46321 .13996 L
.46321 .16187 L
s
1 .894 .882 r
.46321 .16187 m
.46321 .14002 L
.46359 .14002 L
.46359 .16187 L
F
.804 .522 .247 r
.46321 .16187 m
.46321 .14002 L
.46359 .14002 L
.46359 .16187 L
s
1 .894 .882 r
.46359 .16187 m
.46359 .1403 L
.46391 .1403 L
.46391 .16187 L
F
.804 .522 .247 r
.46359 .16187 m
.46359 .1403 L
.46391 .1403 L
.46391 .16187 L
s
1 .894 .882 r
.46391 .16187 m
.46391 .14042 L
.4641 .14042 L
.4641 .16187 L
F
.804 .522 .247 r
.46391 .16187 m
.46391 .14042 L
.4641 .14042 L
.4641 .16187 L
s
1 .894 .882 r
.4641 .16187 m
.4641 .14056 L
.46445 .14056 L
.46445 .16187 L
F
.804 .522 .247 r
.4641 .16187 m
.4641 .14056 L
.46445 .14056 L
.46445 .16187 L
s
1 .894 .882 r
.46445 .16187 m
.46445 .14076 L
.4646 .14076 L
.4646 .16187 L
F
.804 .522 .247 r
.46445 .16187 m
.46445 .14076 L
.4646 .14076 L
.4646 .16187 L
s
1 .894 .882 r
.4646 .16187 m
.4646 .14087 L
.46477 .14087 L
.46477 .16187 L
F
.804 .522 .247 r
.4646 .16187 m
.4646 .14087 L
.46477 .14087 L
.46477 .16187 L
s
1 .894 .882 r
.46477 .16187 m
.46477 .14104 L
.46525 .14104 L
.46525 .16187 L
F
.804 .522 .247 r
.46477 .16187 m
.46477 .14104 L
.46525 .14104 L
.46525 .16187 L
s
1 .894 .882 r
.46525 .16187 m
.46525 .14124 L
.46549 .14124 L
.46549 .16187 L
F
.804 .522 .247 r
.46525 .16187 m
.46525 .14124 L
.46549 .14124 L
.46549 .16187 L
s
1 .894 .882 r
.46549 .16187 m
.46549 .14132 L
.46569 .14132 L
.46569 .16187 L
F
.804 .522 .247 r
.46549 .16187 m
.46549 .14132 L
.46569 .14132 L
.46569 .16187 L
s
1 .894 .882 r
.46569 .16187 m
.46569 .14153 L
.46587 .14153 L
.46587 .16187 L
F
.804 .522 .247 r
.46569 .16187 m
.46569 .14153 L
.46587 .14153 L
.46587 .16187 L
s
1 .894 .882 r
.46587 .16187 m
.46587 .14161 L
.46616 .14161 L
.46616 .16187 L
F
.804 .522 .247 r
.46587 .16187 m
.46587 .14161 L
.46616 .14161 L
.46616 .16187 L
s
1 .894 .882 r
.46616 .16187 m
.46616 .14173 L
.46657 .14173 L
.46657 .16187 L
F
.804 .522 .247 r
.46616 .16187 m
.46616 .14173 L
.46657 .14173 L
.46657 .16187 L
s
1 .894 .882 r
.46657 .16187 m
.46657 .14196 L
.46673 .14196 L
.46673 .16187 L
F
.804 .522 .247 r
.46657 .16187 m
.46657 .14196 L
.46673 .14196 L
.46673 .16187 L
s
1 .894 .882 r
.46673 .16187 m
.46673 .14203 L
.46702 .14203 L
.46702 .16187 L
F
.804 .522 .247 r
.46673 .16187 m
.46673 .14203 L
.46702 .14203 L
.46702 .16187 L
s
1 .894 .882 r
.46702 .16187 m
.46702 .1422 L
.46736 .1422 L
.46736 .16187 L
F
.804 .522 .247 r
.46702 .16187 m
.46702 .1422 L
.46736 .1422 L
.46736 .16187 L
s
1 .894 .882 r
.46736 .16187 m
.46736 .14239 L
.46763 .14239 L
.46763 .16187 L
F
.804 .522 .247 r
.46736 .16187 m
.46736 .14239 L
.46763 .14239 L
.46763 .16187 L
s
1 .894 .882 r
.46763 .16187 m
.46763 .14268 L
.4679 .14268 L
.4679 .16187 L
F
.804 .522 .247 r
.46763 .16187 m
.46763 .14268 L
.4679 .14268 L
.4679 .16187 L
s
1 .894 .882 r
.4679 .16187 m
.4679 .14278 L
.46821 .14278 L
.46821 .16187 L
F
.804 .522 .247 r
.4679 .16187 m
.4679 .14278 L
.46821 .14278 L
.46821 .16187 L
s
1 .894 .882 r
.46821 .16187 m
.46821 .14305 L
.4687 .14305 L
.4687 .16187 L
F
.804 .522 .247 r
.46821 .16187 m
.46821 .14305 L
.4687 .14305 L
.4687 .16187 L
s
1 .894 .882 r
.4687 .16187 m
.4687 .14319 L
.46913 .14319 L
.46913 .16187 L
F
.804 .522 .247 r
.4687 .16187 m
.4687 .14319 L
.46913 .14319 L
.46913 .16187 L
s
1 .894 .882 r
.46913 .16187 m
.46913 .14348 L
.46948 .14348 L
.46948 .16187 L
F
.804 .522 .247 r
.46913 .16187 m
.46913 .14348 L
.46948 .14348 L
.46948 .16187 L
s
1 .894 .882 r
.46948 .16187 m
.46948 .1437 L
.46974 .1437 L
.46974 .16187 L
F
.804 .522 .247 r
.46948 .16187 m
.46948 .1437 L
.46974 .1437 L
.46974 .16187 L
s
1 .894 .882 r
.46974 .16187 m
.46974 .14381 L
.46991 .14381 L
.46991 .16187 L
F
.804 .522 .247 r
.46974 .16187 m
.46974 .14381 L
.46991 .14381 L
.46991 .16187 L
s
1 .894 .882 r
.46991 .16187 m
.46991 .14388 L
.47006 .14388 L
.47006 .16187 L
F
.804 .522 .247 r
.46991 .16187 m
.46991 .14388 L
.47006 .14388 L
.47006 .16187 L
s
1 .894 .882 r
.47006 .16187 m
.47006 .14404 L
.47053 .14404 L
.47053 .16187 L
F
.804 .522 .247 r
.47006 .16187 m
.47006 .14404 L
.47053 .14404 L
.47053 .16187 L
s
1 .894 .882 r
.47053 .16187 m
.47053 .14427 L
.47096 .14427 L
.47096 .16187 L
F
.804 .522 .247 r
.47053 .16187 m
.47053 .14427 L
.47096 .14427 L
.47096 .16187 L
s
1 .894 .882 r
.47096 .16187 m
.47096 .14459 L
.47144 .14459 L
.47144 .16187 L
F
.804 .522 .247 r
.47096 .16187 m
.47096 .14459 L
.47144 .14459 L
.47144 .16187 L
s
1 .894 .882 r
.47144 .16187 m
.47144 .14476 L
.47173 .14476 L
.47173 .16187 L
F
.804 .522 .247 r
.47144 .16187 m
.47144 .14476 L
.47173 .14476 L
.47173 .16187 L
s
1 .894 .882 r
.47173 .16187 m
.47173 .14513 L
.47219 .14513 L
.47219 .16187 L
F
.804 .522 .247 r
.47173 .16187 m
.47173 .14513 L
.47219 .14513 L
.47219 .16187 L
s
1 .894 .882 r
.47219 .16187 m
.47219 .14531 L
.4726 .14531 L
.4726 .16187 L
F
.804 .522 .247 r
.47219 .16187 m
.47219 .14531 L
.4726 .14531 L
.4726 .16187 L
s
1 .894 .882 r
.4726 .16187 m
.4726 .14569 L
.47309 .14569 L
.47309 .16187 L
F
.804 .522 .247 r
.4726 .16187 m
.4726 .14569 L
.47309 .14569 L
.47309 .16187 L
s
1 .894 .882 r
.47309 .16187 m
.47309 .14578 L
.47329 .14578 L
.47329 .16187 L
F
.804 .522 .247 r
.47309 .16187 m
.47309 .14578 L
.47329 .14578 L
.47329 .16187 L
s
1 .894 .882 r
.47329 .16187 m
.47329 .14599 L
.4737 .14599 L
.4737 .16187 L
F
.804 .522 .247 r
.47329 .16187 m
.47329 .14599 L
.4737 .14599 L
.4737 .16187 L
s
1 .894 .882 r
.4737 .16187 m
.4737 .14618 L
.47407 .14618 L
.47407 .16187 L
F
.804 .522 .247 r
.4737 .16187 m
.4737 .14618 L
.47407 .14618 L
.47407 .16187 L
s
1 .894 .882 r
.47407 .16187 m
.47407 .14637 L
.47442 .14637 L
.47442 .16187 L
F
.804 .522 .247 r
.47407 .16187 m
.47407 .14637 L
.47442 .14637 L
.47442 .16187 L
s
1 .894 .882 r
.47442 .16187 m
.47442 .14656 L
.47471 .14656 L
.47471 .16187 L
F
.804 .522 .247 r
.47442 .16187 m
.47442 .14656 L
.47471 .14656 L
.47471 .16187 L
s
1 .894 .882 r
.47471 .16187 m
.47471 .14673 L
.47511 .14673 L
.47511 .16187 L
F
.804 .522 .247 r
.47471 .16187 m
.47471 .14673 L
.47511 .14673 L
.47511 .16187 L
s
1 .894 .882 r
.47511 .16187 m
.47511 .14695 L
.47534 .14695 L
.47534 .16187 L
F
.804 .522 .247 r
.47511 .16187 m
.47511 .14695 L
.47534 .14695 L
.47534 .16187 L
s
1 .894 .882 r
.47534 .16187 m
.47534 .14706 L
.47549 .14706 L
.47549 .16187 L
F
.804 .522 .247 r
.47534 .16187 m
.47534 .14706 L
.47549 .14706 L
.47549 .16187 L
s
1 .894 .882 r
.47549 .16187 m
.47549 .14715 L
.47565 .14715 L
.47565 .16187 L
F
.804 .522 .247 r
.47549 .16187 m
.47549 .14715 L
.47565 .14715 L
.47565 .16187 L
s
1 .894 .882 r
.47565 .16187 m
.47565 .14728 L
.47594 .14728 L
.47594 .16187 L
F
.804 .522 .247 r
.47565 .16187 m
.47565 .14728 L
.47594 .14728 L
.47594 .16187 L
s
1 .894 .882 r
.47594 .16187 m
.47594 .14738 L
.47634 .14738 L
.47634 .16187 L
F
.804 .522 .247 r
.47594 .16187 m
.47594 .14738 L
.47634 .14738 L
.47634 .16187 L
s
1 .894 .882 r
.47634 .16187 m
.47634 .14768 L
.4765 .14768 L
.4765 .16187 L
F
.804 .522 .247 r
.47634 .16187 m
.47634 .14768 L
.4765 .14768 L
.4765 .16187 L
s
1 .894 .882 r
.4765 .16187 m
.4765 .14774 L
.47673 .14774 L
.47673 .16187 L
F
.804 .522 .247 r
.4765 .16187 m
.4765 .14774 L
.47673 .14774 L
.47673 .16187 L
s
1 .894 .882 r
.47673 .16187 m
.47673 .14785 L
.47715 .14785 L
.47715 .16187 L
F
.804 .522 .247 r
.47673 .16187 m
.47673 .14785 L
.47715 .14785 L
.47715 .16187 L
s
1 .894 .882 r
.47715 .16187 m
.47715 .14815 L
.47744 .14815 L
.47744 .16187 L
F
.804 .522 .247 r
.47715 .16187 m
.47715 .14815 L
.47744 .14815 L
.47744 .16187 L
s
1 .894 .882 r
.47744 .16187 m
.47744 .14832 L
.47792 .14832 L
.47792 .16187 L
F
.804 .522 .247 r
.47744 .16187 m
.47744 .14832 L
.47792 .14832 L
.47792 .16187 L
s
1 .894 .882 r
.47792 .16187 m
.47792 .14867 L
.47815 .14867 L
.47815 .16187 L
F
.804 .522 .247 r
.47792 .16187 m
.47792 .14867 L
.47815 .14867 L
.47815 .16187 L
s
1 .894 .882 r
.47815 .16187 m
.47815 .14886 L
.47859 .14886 L
.47859 .16187 L
F
.804 .522 .247 r
.47815 .16187 m
.47815 .14886 L
.47859 .14886 L
.47859 .16187 L
s
1 .894 .882 r
.47859 .16187 m
.47859 .14897 L
.47895 .14897 L
.47895 .16187 L
F
.804 .522 .247 r
.47859 .16187 m
.47859 .14897 L
.47895 .14897 L
.47895 .16187 L
s
1 .894 .882 r
.47895 .16187 m
.47895 .14936 L
.47944 .14936 L
.47944 .16187 L
F
.804 .522 .247 r
.47895 .16187 m
.47895 .14936 L
.47944 .14936 L
.47944 .16187 L
s
1 .894 .882 r
.47944 .16187 m
.47944 .14966 L
.47987 .14966 L
.47987 .16187 L
F
.804 .522 .247 r
.47944 .16187 m
.47944 .14966 L
.47987 .14966 L
.47987 .16187 L
s
1 .894 .882 r
.47987 .16187 m
.47987 .14994 L
.48034 .14994 L
.48034 .16187 L
F
.804 .522 .247 r
.47987 .16187 m
.47987 .14994 L
.48034 .14994 L
.48034 .16187 L
s
1 .894 .882 r
.48034 .16187 m
.48034 .15013 L
.48079 .15013 L
.48079 .16187 L
F
.804 .522 .247 r
.48034 .16187 m
.48034 .15013 L
.48079 .15013 L
.48079 .16187 L
s
1 .894 .882 r
.48079 .16187 m
.48079 .15047 L
.48128 .15047 L
.48128 .16187 L
F
.804 .522 .247 r
.48079 .16187 m
.48079 .15047 L
.48128 .15047 L
.48128 .16187 L
s
1 .894 .882 r
.48128 .16187 m
.48128 .15059 L
.48165 .15059 L
.48165 .16187 L
F
.804 .522 .247 r
.48128 .16187 m
.48128 .15059 L
.48165 .15059 L
.48165 .16187 L
s
1 .894 .882 r
.48165 .16187 m
.48165 .15077 L
.48186 .15077 L
.48186 .16187 L
F
.804 .522 .247 r
.48165 .16187 m
.48165 .15077 L
.48186 .15077 L
.48186 .16187 L
s
1 .894 .882 r
.48186 .16187 m
.48186 .15088 L
.48209 .15088 L
.48209 .16187 L
F
.804 .522 .247 r
.48186 .16187 m
.48186 .15088 L
.48209 .15088 L
.48209 .16187 L
s
1 .894 .882 r
.48209 .16187 m
.48209 .15106 L
.48238 .15106 L
.48238 .16187 L
F
.804 .522 .247 r
.48209 .16187 m
.48209 .15106 L
.48238 .15106 L
.48238 .16187 L
s
1 .894 .882 r
.48238 .16187 m
.48238 .15129 L
.48261 .15129 L
.48261 .16187 L
F
.804 .522 .247 r
.48238 .16187 m
.48238 .15129 L
.48261 .15129 L
.48261 .16187 L
s
1 .894 .882 r
.48261 .16187 m
.48261 .15146 L
.48291 .15146 L
.48291 .16187 L
F
.804 .522 .247 r
.48261 .16187 m
.48261 .15146 L
.48291 .15146 L
.48291 .16187 L
s
1 .894 .882 r
.48291 .16187 m
.48291 .15165 L
.4834 .15165 L
.4834 .16187 L
F
.804 .522 .247 r
.48291 .16187 m
.48291 .15165 L
.4834 .15165 L
.4834 .16187 L
s
1 .894 .882 r
.4834 .16187 m
.4834 .15194 L
.48368 .15194 L
.48368 .16187 L
F
.804 .522 .247 r
.4834 .16187 m
.4834 .15194 L
.48368 .15194 L
.48368 .16187 L
s
1 .894 .882 r
.48368 .16187 m
.48368 .152 L
.4839 .152 L
.4839 .16187 L
F
.804 .522 .247 r
.48368 .16187 m
.48368 .152 L
.4839 .152 L
.4839 .16187 L
s
1 .894 .882 r
.4839 .16187 m
.4839 .15212 L
.48407 .15212 L
.48407 .16187 L
F
.804 .522 .247 r
.4839 .16187 m
.4839 .15212 L
.48407 .15212 L
.48407 .16187 L
s
1 .894 .882 r
.48407 .16187 m
.48407 .15225 L
.4843 .15225 L
.4843 .16187 L
F
.804 .522 .247 r
.48407 .16187 m
.48407 .15225 L
.4843 .15225 L
.4843 .16187 L
s
1 .894 .882 r
.4843 .16187 m
.4843 .15235 L
.48456 .15235 L
.48456 .16187 L
F
.804 .522 .247 r
.4843 .16187 m
.4843 .15235 L
.48456 .15235 L
.48456 .16187 L
s
1 .894 .882 r
.48456 .16187 m
.48456 .1525 L
.48505 .1525 L
.48505 .16187 L
F
.804 .522 .247 r
.48456 .16187 m
.48456 .1525 L
.48505 .1525 L
.48505 .16187 L
s
1 .894 .882 r
.48505 .16187 m
.48505 .15282 L
.48529 .15282 L
.48529 .16187 L
F
.804 .522 .247 r
.48505 .16187 m
.48505 .15282 L
.48529 .15282 L
.48529 .16187 L
s
1 .894 .882 r
.48529 .16187 m
.48529 .15294 L
.48571 .15294 L
.48571 .16187 L
F
.804 .522 .247 r
.48529 .16187 m
.48529 .15294 L
.48571 .15294 L
.48571 .16187 L
s
1 .894 .882 r
.48571 .16187 m
.48571 .15333 L
.486 .15333 L
.486 .16187 L
F
.804 .522 .247 r
.48571 .16187 m
.48571 .15333 L
.486 .15333 L
.486 .16187 L
s
1 .894 .882 r
.486 .16187 m
.486 .15336 L
.48641 .15336 L
.48641 .16187 L
F
.804 .522 .247 r
.486 .16187 m
.486 .15336 L
.48641 .15336 L
.48641 .16187 L
s
1 .894 .882 r
.48641 .16187 m
.48641 .15369 L
.48669 .15369 L
.48669 .16187 L
F
.804 .522 .247 r
.48641 .16187 m
.48641 .15369 L
.48669 .15369 L
.48669 .16187 L
s
1 .894 .882 r
.48669 .16187 m
.48669 .15387 L
.4869 .15387 L
.4869 .16187 L
F
.804 .522 .247 r
.48669 .16187 m
.48669 .15387 L
.4869 .15387 L
.4869 .16187 L
s
1 .894 .882 r
.4869 .16187 m
.4869 .15392 L
.48719 .15392 L
.48719 .16187 L
F
.804 .522 .247 r
.4869 .16187 m
.4869 .15392 L
.48719 .15392 L
.48719 .16187 L
s
1 .894 .882 r
.48719 .16187 m
.48719 .15411 L
.48767 .15411 L
.48767 .16187 L
F
.804 .522 .247 r
.48719 .16187 m
.48719 .15411 L
.48767 .15411 L
.48767 .16187 L
s
1 .894 .882 r
.48767 .16187 m
.48767 .15448 L
.48797 .15448 L
.48797 .16187 L
F
.804 .522 .247 r
.48767 .16187 m
.48767 .15448 L
.48797 .15448 L
.48797 .16187 L
s
1 .894 .882 r
.48797 .16187 m
.48797 .15457 L
.48823 .15457 L
.48823 .16187 L
F
.804 .522 .247 r
.48797 .16187 m
.48797 .15457 L
.48823 .15457 L
.48823 .16187 L
s
1 .894 .882 r
.48823 .16187 m
.48823 .15475 L
.48851 .15475 L
.48851 .16187 L
F
.804 .522 .247 r
.48823 .16187 m
.48823 .15475 L
.48851 .15475 L
.48851 .16187 L
s
1 .894 .882 r
.48851 .16187 m
.48851 .15499 L
.48877 .15499 L
.48877 .16187 L
F
.804 .522 .247 r
.48851 .16187 m
.48851 .15499 L
.48877 .15499 L
.48877 .16187 L
s
1 .894 .882 r
.48877 .16187 m
.48877 .15509 L
.48901 .15509 L
.48901 .16187 L
F
.804 .522 .247 r
.48877 .16187 m
.48877 .15509 L
.48901 .15509 L
.48901 .16187 L
s
1 .894 .882 r
.48901 .16187 m
.48901 .15518 L
.48919 .15518 L
.48919 .16187 L
F
.804 .522 .247 r
.48901 .16187 m
.48901 .15518 L
.48919 .15518 L
.48919 .16187 L
s
1 .894 .882 r
.48919 .16187 m
.48919 .15528 L
.48968 .15528 L
.48968 .16187 L
F
.804 .522 .247 r
.48919 .16187 m
.48919 .15528 L
.48968 .15528 L
.48968 .16187 L
s
1 .894 .882 r
.48968 .16187 m
.48968 .15557 L
.48984 .15557 L
.48984 .16187 L
F
.804 .522 .247 r
.48968 .16187 m
.48968 .15557 L
.48984 .15557 L
.48984 .16187 L
s
1 .894 .882 r
.48984 .16187 m
.48984 .15585 L
.49027 .15585 L
.49027 .16187 L
F
.804 .522 .247 r
.48984 .16187 m
.48984 .15585 L
.49027 .15585 L
.49027 .16187 L
s
1 .894 .882 r
.49027 .16187 m
.49027 .156 L
.49046 .156 L
.49046 .16187 L
F
.804 .522 .247 r
.49027 .16187 m
.49027 .156 L
.49046 .156 L
.49046 .16187 L
s
1 .894 .882 r
.49046 .16187 m
.49046 .15605 L
.49082 .15605 L
.49082 .16187 L
F
.804 .522 .247 r
.49046 .16187 m
.49046 .15605 L
.49082 .15605 L
.49082 .16187 L
s
1 .894 .882 r
.49082 .16187 m
.49082 .15644 L
.49125 .15644 L
.49125 .16187 L
F
.804 .522 .247 r
.49082 .16187 m
.49082 .15644 L
.49125 .15644 L
.49125 .16187 L
s
1 .894 .882 r
.49125 .16187 m
.49125 .1566 L
.49166 .1566 L
.49166 .16187 L
F
.804 .522 .247 r
.49125 .16187 m
.49125 .1566 L
.49166 .1566 L
.49166 .16187 L
s
1 .894 .882 r
.49166 .16187 m
.49166 .15682 L
.49212 .15682 L
.49212 .16187 L
F
.804 .522 .247 r
.49166 .16187 m
.49166 .15682 L
.49212 .15682 L
.49212 .16187 L
s
1 .894 .882 r
.49212 .16187 m
.49212 .15717 L
.49235 .15717 L
.49235 .16187 L
F
.804 .522 .247 r
.49212 .16187 m
.49212 .15717 L
.49235 .15717 L
.49235 .16187 L
s
1 .894 .882 r
.49235 .16187 m
.49235 .15735 L
.49279 .15735 L
.49279 .16187 L
F
.804 .522 .247 r
.49235 .16187 m
.49235 .15735 L
.49279 .15735 L
.49279 .16187 L
s
1 .894 .882 r
.49279 .16187 m
.49279 .15745 L
.49311 .15745 L
.49311 .16187 L
F
.804 .522 .247 r
.49279 .16187 m
.49279 .15745 L
.49311 .15745 L
.49311 .16187 L
s
1 .894 .882 r
.49311 .16187 m
.49311 .15765 L
.49329 .15765 L
.49329 .16187 L
F
.804 .522 .247 r
.49311 .16187 m
.49311 .15765 L
.49329 .15765 L
.49329 .16187 L
s
1 .894 .882 r
.49329 .16187 m
.49329 .15775 L
.49373 .15775 L
.49373 .16187 L
F
.804 .522 .247 r
.49329 .16187 m
.49329 .15775 L
.49373 .15775 L
.49373 .16187 L
s
1 .894 .882 r
.49373 .16187 m
.49373 .15808 L
.49391 .15808 L
.49391 .16187 L
F
.804 .522 .247 r
.49373 .16187 m
.49373 .15808 L
.49391 .15808 L
.49391 .16187 L
s
1 .894 .882 r
.49391 .16187 m
.49391 .15817 L
.49409 .15817 L
.49409 .16187 L
F
.804 .522 .247 r
.49391 .16187 m
.49391 .15817 L
.49409 .15817 L
.49409 .16187 L
s
1 .894 .882 r
.49409 .16187 m
.49409 .15829 L
.49455 .15829 L
.49455 .16187 L
F
.804 .522 .247 r
.49409 .16187 m
.49409 .15829 L
.49455 .15829 L
.49455 .16187 L
s
1 .894 .882 r
.49455 .16187 m
.49455 .15867 L
.49486 .15867 L
.49486 .16187 L
F
.804 .522 .247 r
.49455 .16187 m
.49455 .15867 L
.49486 .15867 L
.49486 .16187 L
s
1 .894 .882 r
.49486 .16187 m
.49486 .15875 L
.49504 .15875 L
.49504 .16187 L
F
.804 .522 .247 r
.49486 .16187 m
.49486 .15875 L
.49504 .15875 L
.49504 .16187 L
s
1 .894 .882 r
.49504 .16187 m
.49504 .15897 L
.49542 .15897 L
.49542 .16187 L
F
.804 .522 .247 r
.49504 .16187 m
.49504 .15897 L
.49542 .15897 L
.49542 .16187 L
s
1 .894 .882 r
.49542 .16187 m
.49542 .15924 L
.49577 .15924 L
.49577 .16187 L
F
.804 .522 .247 r
.49542 .16187 m
.49542 .15924 L
.49577 .15924 L
.49577 .16187 L
s
1 .894 .882 r
.49577 .16187 m
.49577 .15931 L
.49594 .15931 L
.49594 .16187 L
F
.804 .522 .247 r
.49577 .16187 m
.49577 .15931 L
.49594 .15931 L
.49594 .16187 L
s
1 .894 .882 r
.49594 .16187 m
.49594 .15949 L
.49636 .15949 L
.49636 .16187 L
F
.804 .522 .247 r
.49594 .16187 m
.49594 .15949 L
.49636 .15949 L
.49636 .16187 L
s
1 .894 .882 r
.49636 .16187 m
.49636 .15964 L
.49664 .15964 L
.49664 .16187 L
F
.804 .522 .247 r
.49636 .16187 m
.49636 .15964 L
.49664 .15964 L
.49664 .16187 L
s
1 .894 .882 r
.49664 .16187 m
.49664 .15992 L
.49696 .15992 L
.49696 .16187 L
F
.804 .522 .247 r
.49664 .16187 m
.49664 .15992 L
.49696 .15992 L
.49696 .16187 L
s
1 .894 .882 r
.49696 .16187 m
.49696 .16003 L
.49714 .16003 L
.49714 .16187 L
F
.804 .522 .247 r
.49696 .16187 m
.49696 .16003 L
.49714 .16003 L
.49714 .16187 L
s
1 .894 .882 r
.49714 .16187 m
.49714 .16019 L
.49754 .16019 L
.49754 .16187 L
F
.804 .522 .247 r
.49714 .16187 m
.49714 .16019 L
.49754 .16019 L
.49754 .16187 L
s
1 .894 .882 r
.49754 .16187 m
.49754 .16042 L
.49789 .16042 L
.49789 .16187 L
F
.804 .522 .247 r
.49754 .16187 m
.49754 .16042 L
.49789 .16042 L
.49789 .16187 L
s
1 .894 .882 r
.49789 .16187 m
.49789 .16072 L
.49816 .16072 L
.49816 .16187 L
F
.804 .522 .247 r
.49789 .16187 m
.49789 .16072 L
.49816 .16072 L
.49816 .16187 L
s
1 .894 .882 r
.49816 .16187 m
.49816 .16078 L
.49848 .16078 L
.49848 .16187 L
F
.804 .522 .247 r
.49816 .16187 m
.49816 .16078 L
.49848 .16078 L
.49848 .16187 L
s
1 .894 .882 r
.49848 .16187 m
.49848 .1611 L
.49893 .1611 L
.49893 .16187 L
F
.804 .522 .247 r
.49848 .16187 m
.49848 .1611 L
.49893 .1611 L
.49893 .16187 L
s
1 .894 .882 r
.49893 .16187 m
.49893 .16147 L
.49936 .16147 L
.49936 .16187 L
F
.804 .522 .247 r
.49893 .16187 m
.49893 .16147 L
.49936 .16147 L
.49936 .16187 L
s
1 .894 .882 r
.49936 .16187 m
.49936 .16161 L
.49967 .16161 L
.49967 .16187 L
F
.804 .522 .247 r
.49936 .16187 m
.49936 .16161 L
.49967 .16161 L
.49967 .16187 L
s
1 .894 .882 r
.49967 .16187 m
.49967 .16171 L
.4999 .16171 L
.4999 .16187 L
F
.804 .522 .247 r
.49967 .16187 m
.49967 .16171 L
.4999 .16171 L
.4999 .16187 L
s
.678 .847 .902 r
.4999 .16187 m
.4999 .1619 L
.50007 .1619 L
.50007 .16187 L
F
.2 .63 .79 r
.4999 .16187 m
.4999 .1619 L
.50007 .1619 L
.50007 .16187 L
s
.678 .847 .902 r
.50007 .16187 m
.50007 .16207 L
.50033 .16207 L
.50033 .16187 L
F
.2 .63 .79 r
.50007 .16187 m
.50007 .16207 L
.50033 .16207 L
.50033 .16187 L
s
.678 .847 .902 r
.50033 .16187 m
.50033 .16217 L
.5006 .16217 L
.5006 .16187 L
F
.2 .63 .79 r
.50033 .16187 m
.50033 .16217 L
.5006 .16217 L
.5006 .16187 L
s
.678 .847 .902 r
.5006 .16187 m
.5006 .16229 L
.50088 .16229 L
.50088 .16187 L
F
.2 .63 .79 r
.5006 .16187 m
.5006 .16229 L
.50088 .16229 L
.50088 .16187 L
s
.678 .847 .902 r
.50088 .16187 m
.50088 .16253 L
.50136 .16253 L
.50136 .16187 L
F
.2 .63 .79 r
.50088 .16187 m
.50088 .16253 L
.50136 .16253 L
.50136 .16187 L
s
.678 .847 .902 r
.50136 .16187 m
.50136 .16279 L
.50159 .16279 L
.50159 .16187 L
F
.2 .63 .79 r
.50136 .16187 m
.50136 .16279 L
.50159 .16279 L
.50159 .16187 L
s
.678 .847 .902 r
.50159 .16187 m
.50159 .16293 L
.50189 .16293 L
.50189 .16187 L
F
.2 .63 .79 r
.50159 .16187 m
.50159 .16293 L
.50189 .16293 L
.50189 .16187 L
s
.678 .847 .902 r
.50189 .16187 m
.50189 .16318 L
.50236 .16318 L
.50236 .16187 L
F
.2 .63 .79 r
.50189 .16187 m
.50189 .16318 L
.50236 .16318 L
.50236 .16187 L
s
.678 .847 .902 r
.50236 .16187 m
.50236 .16333 L
.50281 .16333 L
.50281 .16187 L
F
.2 .63 .79 r
.50236 .16187 m
.50236 .16333 L
.50281 .16333 L
.50281 .16187 L
s
.678 .847 .902 r
.50281 .16187 m
.50281 .16381 L
.50315 .16381 L
.50315 .16187 L
F
.2 .63 .79 r
.50281 .16187 m
.50281 .16381 L
.50315 .16381 L
.50315 .16187 L
s
.678 .847 .902 r
.50315 .16187 m
.50315 .16397 L
.50358 .16397 L
.50358 .16187 L
F
.2 .63 .79 r
.50315 .16187 m
.50315 .16397 L
.50358 .16397 L
.50358 .16187 L
s
.678 .847 .902 r
.50358 .16187 m
.50358 .16412 L
.50403 .16412 L
.50403 .16187 L
F
.2 .63 .79 r
.50358 .16187 m
.50358 .16412 L
.50403 .16412 L
.50403 .16187 L
s
.678 .847 .902 r
.50403 .16187 m
.50403 .16443 L
.50421 .16443 L
.50421 .16187 L
F
.2 .63 .79 r
.50403 .16187 m
.50403 .16443 L
.50421 .16443 L
.50421 .16187 L
s
.678 .847 .902 r
.50421 .16187 m
.50421 .16459 L
.50442 .16459 L
.50442 .16187 L
F
.2 .63 .79 r
.50421 .16187 m
.50421 .16459 L
.50442 .16459 L
.50442 .16187 L
s
.678 .847 .902 r
.50442 .16187 m
.50442 .16476 L
.50468 .16476 L
.50468 .16187 L
F
.2 .63 .79 r
.50442 .16187 m
.50442 .16476 L
.50468 .16476 L
.50468 .16187 L
s
.678 .847 .902 r
.50468 .16187 m
.50468 .16497 L
.5051 .16497 L
.5051 .16187 L
F
.2 .63 .79 r
.50468 .16187 m
.50468 .16497 L
.5051 .16497 L
.5051 .16187 L
s
.678 .847 .902 r
.5051 .16187 m
.5051 .16506 L
.50537 .16506 L
.50537 .16187 L
F
.2 .63 .79 r
.5051 .16187 m
.5051 .16506 L
.50537 .16506 L
.50537 .16187 L
s
.678 .847 .902 r
.50537 .16187 m
.50537 .16532 L
.50572 .16532 L
.50572 .16187 L
F
.2 .63 .79 r
.50537 .16187 m
.50537 .16532 L
.50572 .16532 L
.50572 .16187 L
s
.678 .847 .902 r
.50572 .16187 m
.50572 .16572 L
.5062 .16572 L
.5062 .16187 L
F
.2 .63 .79 r
.50572 .16187 m
.50572 .16572 L
.5062 .16572 L
.5062 .16187 L
s
.678 .847 .902 r
.5062 .16187 m
.5062 .1658 L
.50646 .1658 L
.50646 .16187 L
F
.2 .63 .79 r
.5062 .16187 m
.5062 .1658 L
.50646 .1658 L
.50646 .16187 L
s
.678 .847 .902 r
.50646 .16187 m
.50646 .16598 L
.50676 .16598 L
.50676 .16187 L
F
.2 .63 .79 r
.50646 .16187 m
.50646 .16598 L
.50676 .16598 L
.50676 .16187 L
s
.678 .847 .902 r
.50676 .16187 m
.50676 .16621 L
.50717 .16621 L
.50717 .16187 L
F
.2 .63 .79 r
.50676 .16187 m
.50676 .16621 L
.50717 .16621 L
.50717 .16187 L
s
.678 .847 .902 r
.50717 .16187 m
.50717 .16639 L
.5075 .16639 L
.5075 .16187 L
F
.2 .63 .79 r
.50717 .16187 m
.50717 .16639 L
.5075 .16639 L
.5075 .16187 L
s
.678 .847 .902 r
.5075 .16187 m
.5075 .16656 L
.50767 .16656 L
.50767 .16187 L
F
.2 .63 .79 r
.5075 .16187 m
.5075 .16656 L
.50767 .16656 L
.50767 .16187 L
s
.678 .847 .902 r
.50767 .16187 m
.50767 .16674 L
.50795 .16674 L
.50795 .16187 L
F
.2 .63 .79 r
.50767 .16187 m
.50767 .16674 L
.50795 .16674 L
.50795 .16187 L
s
.678 .847 .902 r
.50795 .16187 m
.50795 .16692 L
.50825 .16692 L
.50825 .16187 L
F
.2 .63 .79 r
.50795 .16187 m
.50795 .16692 L
.50825 .16692 L
.50825 .16187 L
s
.678 .847 .902 r
.50825 .16187 m
.50825 .1671 L
.50845 .1671 L
.50845 .16187 L
F
.2 .63 .79 r
.50825 .16187 m
.50825 .1671 L
.50845 .1671 L
.50845 .16187 L
s
.678 .847 .902 r
.50845 .16187 m
.50845 .16735 L
.50883 .16735 L
.50883 .16187 L
F
.2 .63 .79 r
.50845 .16187 m
.50845 .16735 L
.50883 .16735 L
.50883 .16187 L
s
.678 .847 .902 r
.50883 .16187 m
.50883 .16741 L
.50913 .16741 L
.50913 .16187 L
F
.2 .63 .79 r
.50883 .16187 m
.50883 .16741 L
.50913 .16741 L
.50913 .16187 L
s
.678 .847 .902 r
.50913 .16187 m
.50913 .16769 L
.50935 .16769 L
.50935 .16187 L
F
.2 .63 .79 r
.50913 .16187 m
.50913 .16769 L
.50935 .16769 L
.50935 .16187 L
s
.678 .847 .902 r
.50935 .16187 m
.50935 .16776 L
.50974 .16776 L
.50974 .16187 L
F
.2 .63 .79 r
.50935 .16187 m
.50935 .16776 L
.50974 .16776 L
.50974 .16187 L
s
.678 .847 .902 r
.50974 .16187 m
.50974 .16805 L
.51014 .16805 L
.51014 .16187 L
F
.2 .63 .79 r
.50974 .16187 m
.50974 .16805 L
.51014 .16805 L
.51014 .16187 L
s
.678 .847 .902 r
.51014 .16187 m
.51014 .16824 L
.51048 .16824 L
.51048 .16187 L
F
.2 .63 .79 r
.51014 .16187 m
.51014 .16824 L
.51048 .16824 L
.51048 .16187 L
s
.678 .847 .902 r
.51048 .16187 m
.51048 .16865 L
.51085 .16865 L
.51085 .16187 L
F
.2 .63 .79 r
.51048 .16187 m
.51048 .16865 L
.51085 .16865 L
.51085 .16187 L
s
.678 .847 .902 r
.51085 .16187 m
.51085 .16885 L
.51131 .16885 L
.51131 .16187 L
F
.2 .63 .79 r
.51085 .16187 m
.51085 .16885 L
.51131 .16885 L
.51131 .16187 L
s
.678 .847 .902 r
.51131 .16187 m
.51131 .16902 L
.51175 .16902 L
.51175 .16187 L
F
.2 .63 .79 r
.51131 .16187 m
.51131 .16902 L
.51175 .16902 L
.51175 .16187 L
s
.678 .847 .902 r
.51175 .16187 m
.51175 .16935 L
.51207 .16935 L
.51207 .16187 L
F
.2 .63 .79 r
.51175 .16187 m
.51175 .16935 L
.51207 .16935 L
.51207 .16187 L
s
.678 .847 .902 r
.51207 .16187 m
.51207 .16944 L
.51237 .16944 L
.51237 .16187 L
F
.2 .63 .79 r
.51207 .16187 m
.51207 .16944 L
.51237 .16944 L
.51237 .16187 L
s
.678 .847 .902 r
.51237 .16187 m
.51237 .16978 L
.51271 .16978 L
.51271 .16187 L
F
.2 .63 .79 r
.51237 .16187 m
.51237 .16978 L
.51271 .16978 L
.51271 .16187 L
s
.678 .847 .902 r
.51271 .16187 m
.51271 .16989 L
.51288 .16989 L
.51288 .16187 L
F
.2 .63 .79 r
.51271 .16187 m
.51271 .16989 L
.51288 .16989 L
.51288 .16187 L
s
.678 .847 .902 r
.51288 .16187 m
.51288 .16999 L
.51308 .16999 L
.51308 .16187 L
F
.2 .63 .79 r
.51288 .16187 m
.51288 .16999 L
.51308 .16999 L
.51308 .16187 L
s
.678 .847 .902 r
.51308 .16187 m
.51308 .17023 L
.51352 .17023 L
.51352 .16187 L
F
.2 .63 .79 r
.51308 .16187 m
.51308 .17023 L
.51352 .17023 L
.51352 .16187 L
s
.678 .847 .902 r
.51352 .16187 m
.51352 .17052 L
.51387 .17052 L
.51387 .16187 L
F
.2 .63 .79 r
.51352 .16187 m
.51352 .17052 L
.51387 .17052 L
.51387 .16187 L
s
.678 .847 .902 r
.51387 .16187 m
.51387 .17058 L
.51428 .17058 L
.51428 .16187 L
F
.2 .63 .79 r
.51387 .16187 m
.51387 .17058 L
.51428 .17058 L
.51428 .16187 L
s
.678 .847 .902 r
.51428 .16187 m
.51428 .17106 L
.51466 .17106 L
.51466 .16187 L
F
.2 .63 .79 r
.51428 .16187 m
.51428 .17106 L
.51466 .17106 L
.51466 .16187 L
s
.678 .847 .902 r
.51466 .16187 m
.51466 .17108 L
.51484 .17108 L
.51484 .16187 L
F
.2 .63 .79 r
.51466 .16187 m
.51466 .17108 L
.51484 .17108 L
.51484 .16187 L
s
.678 .847 .902 r
.51484 .16187 m
.51484 .17124 L
.51501 .17124 L
.51501 .16187 L
F
.2 .63 .79 r
.51484 .16187 m
.51484 .17124 L
.51501 .17124 L
.51501 .16187 L
s
.678 .847 .902 r
.51501 .16187 m
.51501 .1715 L
.5154 .1715 L
.5154 .16187 L
F
.2 .63 .79 r
.51501 .16187 m
.51501 .1715 L
.5154 .1715 L
.5154 .16187 L
s
.678 .847 .902 r
.5154 .16187 m
.5154 .1716 L
.51565 .1716 L
.51565 .16187 L
F
.2 .63 .79 r
.5154 .16187 m
.5154 .1716 L
.51565 .1716 L
.51565 .16187 L
s
.678 .847 .902 r
.51565 .16187 m
.51565 .17183 L
.51601 .17183 L
.51601 .16187 L
F
.2 .63 .79 r
.51565 .16187 m
.51565 .17183 L
.51601 .17183 L
.51601 .16187 L
s
.678 .847 .902 r
.51601 .16187 m
.51601 .17219 L
.51648 .17219 L
.51648 .16187 L
F
.2 .63 .79 r
.51601 .16187 m
.51601 .17219 L
.51648 .17219 L
.51648 .16187 L
s
.678 .847 .902 r
.51648 .16187 m
.51648 .17233 L
.51664 .17233 L
.51664 .16187 L
F
.2 .63 .79 r
.51648 .16187 m
.51648 .17233 L
.51664 .17233 L
.51664 .16187 L
s
.678 .847 .902 r
.51664 .16187 m
.51664 .1724 L
.51708 .1724 L
.51708 .16187 L
F
.2 .63 .79 r
.51664 .16187 m
.51664 .1724 L
.51708 .1724 L
.51708 .16187 L
s
.678 .847 .902 r
.51708 .16187 m
.51708 .17273 L
.51737 .17273 L
.51737 .16187 L
F
.2 .63 .79 r
.51708 .16187 m
.51708 .17273 L
.51737 .17273 L
.51737 .16187 L
s
.678 .847 .902 r
.51737 .16187 m
.51737 .17289 L
.51759 .17289 L
.51759 .16187 L
F
.2 .63 .79 r
.51737 .16187 m
.51737 .17289 L
.51759 .17289 L
.51759 .16187 L
s
.678 .847 .902 r
.51759 .16187 m
.51759 .17303 L
.51785 .17303 L
.51785 .16187 L
F
.2 .63 .79 r
.51759 .16187 m
.51759 .17303 L
.51785 .17303 L
.51785 .16187 L
s
.678 .847 .902 r
.51785 .16187 m
.51785 .17311 L
.51809 .17311 L
.51809 .16187 L
F
.2 .63 .79 r
.51785 .16187 m
.51785 .17311 L
.51809 .17311 L
.51809 .16187 L
s
.678 .847 .902 r
.51809 .16187 m
.51809 .17343 L
.51851 .17343 L
.51851 .16187 L
F
.2 .63 .79 r
.51809 .16187 m
.51809 .17343 L
.51851 .17343 L
.51851 .16187 L
s
.678 .847 .902 r
.51851 .16187 m
.51851 .17368 L
.51877 .17368 L
.51877 .16187 L
F
.2 .63 .79 r
.51851 .16187 m
.51851 .17368 L
.51877 .17368 L
.51877 .16187 L
s
.678 .847 .902 r
.51877 .16187 m
.51877 .17374 L
.51907 .17374 L
.51907 .16187 L
F
.2 .63 .79 r
.51877 .16187 m
.51877 .17374 L
.51907 .17374 L
.51907 .16187 L
s
.678 .847 .902 r
.51907 .16187 m
.51907 .174 L
.5195 .174 L
.5195 .16187 L
F
.2 .63 .79 r
.51907 .16187 m
.51907 .174 L
.5195 .174 L
.5195 .16187 L
s
.678 .847 .902 r
.5195 .16187 m
.5195 .17424 L
.51975 .17424 L
.51975 .16187 L
F
.2 .63 .79 r
.5195 .16187 m
.5195 .17424 L
.51975 .17424 L
.51975 .16187 L
s
.678 .847 .902 r
.51975 .16187 m
.51975 .17436 L
.52016 .17436 L
.52016 .16187 L
F
.2 .63 .79 r
.51975 .16187 m
.51975 .17436 L
.52016 .17436 L
.52016 .16187 L
s
.678 .847 .902 r
.52016 .16187 m
.52016 .17472 L
.52044 .17472 L
.52044 .16187 L
F
.2 .63 .79 r
.52016 .16187 m
.52016 .17472 L
.52044 .17472 L
.52044 .16187 L
s
.678 .847 .902 r
.52044 .16187 m
.52044 .175 L
.52082 .175 L
.52082 .16187 L
F
.2 .63 .79 r
.52044 .16187 m
.52044 .175 L
.52082 .175 L
.52082 .16187 L
s
.678 .847 .902 r
.52082 .16187 m
.52082 .17519 L
.52113 .17519 L
.52113 .16187 L
F
.2 .63 .79 r
.52082 .16187 m
.52082 .17519 L
.52113 .17519 L
.52113 .16187 L
s
.678 .847 .902 r
.52113 .16187 m
.52113 .17525 L
.52133 .17525 L
.52133 .16187 L
F
.2 .63 .79 r
.52113 .16187 m
.52113 .17525 L
.52133 .17525 L
.52133 .16187 L
s
.678 .847 .902 r
.52133 .16187 m
.52133 .1755 L
.5217 .1755 L
.5217 .16187 L
F
.2 .63 .79 r
.52133 .16187 m
.52133 .1755 L
.5217 .1755 L
.5217 .16187 L
s
.678 .847 .902 r
.5217 .16187 m
.5217 .17588 L
.52218 .17588 L
.52218 .16187 L
F
.2 .63 .79 r
.5217 .16187 m
.5217 .17588 L
.52218 .17588 L
.52218 .16187 L
s
.678 .847 .902 r
.52218 .16187 m
.52218 .17603 L
.52246 .17603 L
.52246 .16187 L
F
.2 .63 .79 r
.52218 .16187 m
.52218 .17603 L
.52246 .17603 L
.52246 .16187 L
s
.678 .847 .902 r
.52246 .16187 m
.52246 .17617 L
.52264 .17617 L
.52264 .16187 L
F
.2 .63 .79 r
.52246 .16187 m
.52246 .17617 L
.52264 .17617 L
.52264 .16187 L
s
.678 .847 .902 r
.52264 .16187 m
.52264 .17643 L
.52311 .17643 L
.52311 .16187 L
F
.2 .63 .79 r
.52264 .16187 m
.52264 .17643 L
.52311 .17643 L
.52311 .16187 L
s
.678 .847 .902 r
.52311 .16187 m
.52311 .17664 L
.52349 .17664 L
.52349 .16187 L
F
.2 .63 .79 r
.52311 .16187 m
.52311 .17664 L
.52349 .17664 L
.52349 .16187 L
s
.678 .847 .902 r
.52349 .16187 m
.52349 .1768 L
.5239 .1768 L
.5239 .16187 L
F
.2 .63 .79 r
.52349 .16187 m
.52349 .1768 L
.5239 .1768 L
.5239 .16187 L
s
.678 .847 .902 r
.5239 .16187 m
.5239 .17713 L
.5241 .17713 L
.5241 .16187 L
F
.2 .63 .79 r
.5239 .16187 m
.5239 .17713 L
.5241 .17713 L
.5241 .16187 L
s
.678 .847 .902 r
.5241 .16187 m
.5241 .17739 L
.52457 .17739 L
.52457 .16187 L
F
.2 .63 .79 r
.5241 .16187 m
.5241 .17739 L
.52457 .17739 L
.52457 .16187 L
s
.678 .847 .902 r
.52457 .16187 m
.52457 .17753 L
.525 .17753 L
.525 .16187 L
F
.2 .63 .79 r
.52457 .16187 m
.52457 .17753 L
.525 .17753 L
.525 .16187 L
s
.678 .847 .902 r
.525 .16187 m
.525 .17782 L
.52526 .17782 L
.52526 .16187 L
F
.2 .63 .79 r
.525 .16187 m
.525 .17782 L
.52526 .17782 L
.52526 .16187 L
s
.678 .847 .902 r
.52526 .16187 m
.52526 .17798 L
.52573 .17798 L
.52573 .16187 L
F
.2 .63 .79 r
.52526 .16187 m
.52526 .17798 L
.52573 .17798 L
.52573 .16187 L
s
.678 .847 .902 r
.52573 .16187 m
.52573 .17826 L
.52609 .17826 L
.52609 .16187 L
F
.2 .63 .79 r
.52573 .16187 m
.52573 .17826 L
.52609 .17826 L
.52609 .16187 L
s
.678 .847 .902 r
.52609 .16187 m
.52609 .17849 L
.52642 .17849 L
.52642 .16187 L
F
.2 .63 .79 r
.52609 .16187 m
.52609 .17849 L
.52642 .17849 L
.52642 .16187 L
s
.678 .847 .902 r
.52642 .16187 m
.52642 .17886 L
.52676 .17886 L
.52676 .16187 L
F
.2 .63 .79 r
.52642 .16187 m
.52642 .17886 L
.52676 .17886 L
.52676 .16187 L
s
.678 .847 .902 r
.52676 .16187 m
.52676 .17896 L
.52712 .17896 L
.52712 .16187 L
F
.2 .63 .79 r
.52676 .16187 m
.52676 .17896 L
.52712 .17896 L
.52712 .16187 L
s
.678 .847 .902 r
.52712 .16187 m
.52712 .17911 L
.52733 .17911 L
.52733 .16187 L
F
.2 .63 .79 r
.52712 .16187 m
.52712 .17911 L
.52733 .17911 L
.52733 .16187 L
s
.678 .847 .902 r
.52733 .16187 m
.52733 .17946 L
.52772 .17946 L
.52772 .16187 L
F
.2 .63 .79 r
.52733 .16187 m
.52733 .17946 L
.52772 .17946 L
.52772 .16187 L
s
.678 .847 .902 r
.52772 .16187 m
.52772 .17957 L
.52796 .17957 L
.52796 .16187 L
F
.2 .63 .79 r
.52772 .16187 m
.52772 .17957 L
.52796 .17957 L
.52796 .16187 L
s
.678 .847 .902 r
.52796 .16187 m
.52796 .17973 L
.5284 .17973 L
.5284 .16187 L
F
.2 .63 .79 r
.52796 .16187 m
.52796 .17973 L
.5284 .17973 L
.5284 .16187 L
s
.678 .847 .902 r
.5284 .16187 m
.5284 .18002 L
.52882 .18002 L
.52882 .16187 L
F
.2 .63 .79 r
.5284 .16187 m
.5284 .18002 L
.52882 .18002 L
.52882 .16187 L
s
.678 .847 .902 r
.52882 .16187 m
.52882 .18032 L
.52898 .18032 L
.52898 .16187 L
F
.2 .63 .79 r
.52882 .16187 m
.52882 .18032 L
.52898 .18032 L
.52898 .16187 L
s
.678 .847 .902 r
.52898 .16187 m
.52898 .18049 L
.5294 .18049 L
.5294 .16187 L
F
.2 .63 .79 r
.52898 .16187 m
.52898 .18049 L
.5294 .18049 L
.5294 .16187 L
s
.678 .847 .902 r
.5294 .16187 m
.5294 .18084 L
.52979 .18084 L
.52979 .16187 L
F
.2 .63 .79 r
.5294 .16187 m
.5294 .18084 L
.52979 .18084 L
.52979 .16187 L
s
.678 .847 .902 r
.52979 .16187 m
.52979 .18093 L
.52998 .18093 L
.52998 .16187 L
F
.2 .63 .79 r
.52979 .16187 m
.52979 .18093 L
.52998 .18093 L
.52998 .16187 L
s
.678 .847 .902 r
.52998 .16187 m
.52998 .18109 L
.53016 .18109 L
.53016 .16187 L
F
.2 .63 .79 r
.52998 .16187 m
.52998 .18109 L
.53016 .18109 L
.53016 .16187 L
s
.678 .847 .902 r
.53016 .16187 m
.53016 .18125 L
.53045 .18125 L
.53045 .16187 L
F
.2 .63 .79 r
.53016 .16187 m
.53016 .18125 L
.53045 .18125 L
.53045 .16187 L
s
.678 .847 .902 r
.53045 .16187 m
.53045 .18133 L
.5308 .18133 L
.5308 .16187 L
F
.2 .63 .79 r
.53045 .16187 m
.53045 .18133 L
.5308 .18133 L
.5308 .16187 L
s
.678 .847 .902 r
.5308 .16187 m
.5308 .18164 L
.53101 .18164 L
.53101 .16187 L
F
.2 .63 .79 r
.5308 .16187 m
.5308 .18164 L
.53101 .18164 L
.53101 .16187 L
s
.678 .847 .902 r
.53101 .16187 m
.53101 .18173 L
.53131 .18173 L
.53131 .16187 L
F
.2 .63 .79 r
.53101 .16187 m
.53101 .18173 L
.53131 .18173 L
.53131 .16187 L
s
.678 .847 .902 r
.53131 .16187 m
.53131 .182 L
.53168 .182 L
.53168 .16187 L
F
.2 .63 .79 r
.53131 .16187 m
.53131 .182 L
.53168 .182 L
.53168 .16187 L
s
.678 .847 .902 r
.53168 .16187 m
.53168 .18215 L
.53198 .18215 L
.53198 .16187 L
F
.2 .63 .79 r
.53168 .16187 m
.53168 .18215 L
.53198 .18215 L
.53198 .16187 L
s
.678 .847 .902 r
.53198 .16187 m
.53198 .1823 L
.53222 .1823 L
.53222 .16187 L
F
.2 .63 .79 r
.53198 .16187 m
.53198 .1823 L
.53222 .1823 L
.53222 .16187 L
s
.678 .847 .902 r
.53222 .16187 m
.53222 .18246 L
.53257 .18246 L
.53257 .16187 L
F
.2 .63 .79 r
.53222 .16187 m
.53222 .18246 L
.53257 .18246 L
.53257 .16187 L
s
.678 .847 .902 r
.53257 .16187 m
.53257 .18269 L
.53283 .18269 L
.53283 .16187 L
F
.2 .63 .79 r
.53257 .16187 m
.53257 .18269 L
.53283 .18269 L
.53283 .16187 L
s
.678 .847 .902 r
.53283 .16187 m
.53283 .18306 L
.53315 .18306 L
.53315 .16187 L
F
.2 .63 .79 r
.53283 .16187 m
.53283 .18306 L
.53315 .18306 L
.53315 .16187 L
s
.678 .847 .902 r
.53315 .16187 m
.53315 .18325 L
.53352 .18325 L
.53352 .16187 L
F
.2 .63 .79 r
.53315 .16187 m
.53315 .18325 L
.53352 .18325 L
.53352 .16187 L
s
.678 .847 .902 r
.53352 .16187 m
.53352 .1834 L
.5337 .1834 L
.5337 .16187 L
F
.2 .63 .79 r
.53352 .16187 m
.53352 .1834 L
.5337 .1834 L
.5337 .16187 L
s
.678 .847 .902 r
.5337 .16187 m
.5337 .18344 L
.5341 .18344 L
.5341 .16187 L
F
.2 .63 .79 r
.5337 .16187 m
.5337 .18344 L
.5341 .18344 L
.5341 .16187 L
s
.678 .847 .902 r
.5341 .16187 m
.5341 .18387 L
.53455 .18387 L
.53455 .16187 L
F
.2 .63 .79 r
.5341 .16187 m
.5341 .18387 L
.53455 .18387 L
.53455 .16187 L
s
.678 .847 .902 r
.53455 .16187 m
.53455 .18415 L
.53487 .18415 L
.53487 .16187 L
F
.2 .63 .79 r
.53455 .16187 m
.53455 .18415 L
.53487 .18415 L
.53487 .16187 L
s
.678 .847 .902 r
.53487 .16187 m
.53487 .18437 L
.53514 .18437 L
.53514 .16187 L
F
.2 .63 .79 r
.53487 .16187 m
.53487 .18437 L
.53514 .18437 L
.53514 .16187 L
s
.678 .847 .902 r
.53514 .16187 m
.53514 .18451 L
.53546 .18451 L
.53546 .16187 L
F
.2 .63 .79 r
.53514 .16187 m
.53514 .18451 L
.53546 .18451 L
.53546 .16187 L
s
.678 .847 .902 r
.53546 .16187 m
.53546 .18463 L
.53561 .18463 L
.53561 .16187 L
F
.2 .63 .79 r
.53546 .16187 m
.53546 .18463 L
.53561 .18463 L
.53561 .16187 L
s
.678 .847 .902 r
.53561 .16187 m
.53561 .18482 L
.53601 .18482 L
.53601 .16187 L
F
.2 .63 .79 r
.53561 .16187 m
.53561 .18482 L
.53601 .18482 L
.53601 .16187 L
s
.678 .847 .902 r
.53601 .16187 m
.53601 .18496 L
.53626 .18496 L
.53626 .16187 L
F
.2 .63 .79 r
.53601 .16187 m
.53601 .18496 L
.53626 .18496 L
.53626 .16187 L
s
.678 .847 .902 r
.53626 .16187 m
.53626 .18513 L
.53665 .18513 L
.53665 .16187 L
F
.2 .63 .79 r
.53626 .16187 m
.53626 .18513 L
.53665 .18513 L
.53665 .16187 L
s
.678 .847 .902 r
.53665 .16187 m
.53665 .18545 L
.53691 .18545 L
.53691 .16187 L
F
.2 .63 .79 r
.53665 .16187 m
.53665 .18545 L
.53691 .18545 L
.53691 .16187 L
s
.678 .847 .902 r
.53691 .16187 m
.53691 .18575 L
.53726 .18575 L
.53726 .16187 L
F
.2 .63 .79 r
.53691 .16187 m
.53691 .18575 L
.53726 .18575 L
.53726 .16187 L
s
.678 .847 .902 r
.53726 .16187 m
.53726 .1858 L
.53748 .1858 L
.53748 .16187 L
F
.2 .63 .79 r
.53726 .16187 m
.53726 .1858 L
.53748 .1858 L
.53748 .16187 L
s
.678 .847 .902 r
.53748 .16187 m
.53748 .18597 L
.53773 .18597 L
.53773 .16187 L
F
.2 .63 .79 r
.53748 .16187 m
.53748 .18597 L
.53773 .18597 L
.53773 .16187 L
s
.678 .847 .902 r
.53773 .16187 m
.53773 .18615 L
.53814 .18615 L
.53814 .16187 L
F
.2 .63 .79 r
.53773 .16187 m
.53773 .18615 L
.53814 .18615 L
.53814 .16187 L
s
.678 .847 .902 r
.53814 .16187 m
.53814 .18655 L
.53841 .18655 L
.53841 .16187 L
F
.2 .63 .79 r
.53814 .16187 m
.53814 .18655 L
.53841 .18655 L
.53841 .16187 L
s
.678 .847 .902 r
.53841 .16187 m
.53841 .18676 L
.53883 .18676 L
.53883 .16187 L
F
.2 .63 .79 r
.53841 .16187 m
.53841 .18676 L
.53883 .18676 L
.53883 .16187 L
s
.678 .847 .902 r
.53883 .16187 m
.53883 .18699 L
.53921 .18699 L
.53921 .16187 L
F
.2 .63 .79 r
.53883 .16187 m
.53883 .18699 L
.53921 .18699 L
.53921 .16187 L
s
.678 .847 .902 r
.53921 .16187 m
.53921 .18724 L
.53946 .18724 L
.53946 .16187 L
F
.2 .63 .79 r
.53921 .16187 m
.53921 .18724 L
.53946 .18724 L
.53946 .16187 L
s
.678 .847 .902 r
.53946 .16187 m
.53946 .18738 L
.53964 .18738 L
.53964 .16187 L
F
.2 .63 .79 r
.53946 .16187 m
.53946 .18738 L
.53964 .18738 L
.53964 .16187 L
s
.678 .847 .902 r
.53964 .16187 m
.53964 .18748 L
.53985 .18748 L
.53985 .16187 L
F
.2 .63 .79 r
.53964 .16187 m
.53964 .18748 L
.53985 .18748 L
.53985 .16187 L
s
.678 .847 .902 r
.53985 .16187 m
.53985 .18763 L
.54012 .18763 L
.54012 .16187 L
F
.2 .63 .79 r
.53985 .16187 m
.53985 .18763 L
.54012 .18763 L
.54012 .16187 L
s
.678 .847 .902 r
.54012 .16187 m
.54012 .18797 L
.54055 .18797 L
.54055 .16187 L
F
.2 .63 .79 r
.54012 .16187 m
.54012 .18797 L
.54055 .18797 L
.54055 .16187 L
s
.678 .847 .902 r
.54055 .16187 m
.54055 .18802 L
.54085 .18802 L
.54085 .16187 L
F
.2 .63 .79 r
.54055 .16187 m
.54055 .18802 L
.54085 .18802 L
.54085 .16187 L
s
.678 .847 .902 r
.54085 .16187 m
.54085 .1883 L
.54103 .1883 L
.54103 .16187 L
F
.2 .63 .79 r
.54085 .16187 m
.54085 .1883 L
.54103 .1883 L
.54103 .16187 L
s
.678 .847 .902 r
.54103 .16187 m
.54103 .18844 L
.54138 .18844 L
.54138 .16187 L
F
.2 .63 .79 r
.54103 .16187 m
.54103 .18844 L
.54138 .18844 L
.54138 .16187 L
s
.678 .847 .902 r
.54138 .16187 m
.54138 .18867 L
.54185 .18867 L
.54185 .16187 L
F
.2 .63 .79 r
.54138 .16187 m
.54138 .18867 L
.54185 .18867 L
.54185 .16187 L
s
.678 .847 .902 r
.54185 .16187 m
.54185 .18899 L
.54234 .18899 L
.54234 .16187 L
F
.2 .63 .79 r
.54185 .16187 m
.54185 .18899 L
.54234 .18899 L
.54234 .16187 L
s
.678 .847 .902 r
.54234 .16187 m
.54234 .18945 L
.54274 .18945 L
.54274 .16187 L
F
.2 .63 .79 r
.54234 .16187 m
.54234 .18945 L
.54274 .18945 L
.54274 .16187 L
s
.678 .847 .902 r
.54274 .16187 m
.54274 .18958 L
.54291 .18958 L
.54291 .16187 L
F
.2 .63 .79 r
.54274 .16187 m
.54274 .18958 L
.54291 .18958 L
.54291 .16187 L
s
.678 .847 .902 r
.54291 .16187 m
.54291 .18961 L
.54338 .18961 L
.54338 .16187 L
F
.2 .63 .79 r
.54291 .16187 m
.54291 .18961 L
.54338 .18961 L
.54338 .16187 L
s
.678 .847 .902 r
.54338 .16187 m
.54338 .19005 L
.54362 .19005 L
.54362 .16187 L
F
.2 .63 .79 r
.54338 .16187 m
.54338 .19005 L
.54362 .19005 L
.54362 .16187 L
s
.678 .847 .902 r
.54362 .16187 m
.54362 .19024 L
.54392 .19024 L
.54392 .16187 L
F
.2 .63 .79 r
.54362 .16187 m
.54362 .19024 L
.54392 .19024 L
.54392 .16187 L
s
.678 .847 .902 r
.54392 .16187 m
.54392 .19043 L
.54419 .19043 L
.54419 .16187 L
F
.2 .63 .79 r
.54392 .16187 m
.54392 .19043 L
.54419 .19043 L
.54419 .16187 L
s
.678 .847 .902 r
.54419 .16187 m
.54419 .19062 L
.54454 .19062 L
.54454 .16187 L
F
.2 .63 .79 r
.54419 .16187 m
.54419 .19062 L
.54454 .19062 L
.54454 .16187 L
s
.678 .847 .902 r
.54454 .16187 m
.54454 .19071 L
.54493 .19071 L
.54493 .16187 L
F
.2 .63 .79 r
.54454 .16187 m
.54454 .19071 L
.54493 .19071 L
.54493 .16187 L
s
.678 .847 .902 r
.54493 .16187 m
.54493 .19107 L
.54516 .19107 L
.54516 .16187 L
F
.2 .63 .79 r
.54493 .16187 m
.54493 .19107 L
.54516 .19107 L
.54516 .16187 L
s
.678 .847 .902 r
.54516 .16187 m
.54516 .19118 L
.54532 .19118 L
.54532 .16187 L
F
.2 .63 .79 r
.54516 .16187 m
.54516 .19118 L
.54532 .19118 L
.54532 .16187 L
s
.678 .847 .902 r
.54532 .16187 m
.54532 .19139 L
.54576 .19139 L
.54576 .16187 L
F
.2 .63 .79 r
.54532 .16187 m
.54532 .19139 L
.54576 .19139 L
.54576 .16187 L
s
.678 .847 .902 r
.54576 .16187 m
.54576 .19154 L
.54602 .19154 L
.54602 .16187 L
F
.2 .63 .79 r
.54576 .16187 m
.54576 .19154 L
.54602 .19154 L
.54602 .16187 L
s
.678 .847 .902 r
.54602 .16187 m
.54602 .19171 L
.54632 .19171 L
.54632 .16187 L
F
.2 .63 .79 r
.54602 .16187 m
.54602 .19171 L
.54632 .19171 L
.54632 .16187 L
s
.678 .847 .902 r
.54632 .16187 m
.54632 .19191 L
.5466 .19191 L
.5466 .16187 L
F
.2 .63 .79 r
.54632 .16187 m
.54632 .19191 L
.5466 .19191 L
.5466 .16187 L
s
.678 .847 .902 r
.5466 .16187 m
.5466 .19225 L
.54694 .19225 L
.54694 .16187 L
F
.2 .63 .79 r
.5466 .16187 m
.5466 .19225 L
.54694 .19225 L
.54694 .16187 L
s
.678 .847 .902 r
.54694 .16187 m
.54694 .19235 L
.54716 .19235 L
.54716 .16187 L
F
.2 .63 .79 r
.54694 .16187 m
.54694 .19235 L
.54716 .19235 L
.54716 .16187 L
s
.678 .847 .902 r
.54716 .16187 m
.54716 .19254 L
.5474 .19254 L
.5474 .16187 L
F
.2 .63 .79 r
.54716 .16187 m
.54716 .19254 L
.5474 .19254 L
.5474 .16187 L
s
.678 .847 .902 r
.5474 .16187 m
.5474 .19268 L
.54756 .19268 L
.54756 .16187 L
F
.2 .63 .79 r
.5474 .16187 m
.5474 .19268 L
.54756 .19268 L
.54756 .16187 L
s
.678 .847 .902 r
.54756 .16187 m
.54756 .19295 L
.54796 .19295 L
.54796 .16187 L
F
.2 .63 .79 r
.54756 .16187 m
.54756 .19295 L
.54796 .19295 L
.54796 .16187 L
s
.678 .847 .902 r
.54796 .16187 m
.54796 .19304 L
.54837 .19304 L
.54837 .16187 L
F
.2 .63 .79 r
.54796 .16187 m
.54796 .19304 L
.54837 .19304 L
.54837 .16187 L
s
.678 .847 .902 r
.54837 .16187 m
.54837 .19337 L
.54857 .19337 L
.54857 .16187 L
F
.2 .63 .79 r
.54837 .16187 m
.54837 .19337 L
.54857 .19337 L
.54857 .16187 L
s
.678 .847 .902 r
.54857 .16187 m
.54857 .19342 L
.54888 .19342 L
.54888 .16187 L
F
.2 .63 .79 r
.54857 .16187 m
.54857 .19342 L
.54888 .19342 L
.54888 .16187 L
s
.678 .847 .902 r
.54888 .16187 m
.54888 .19376 L
.5493 .19376 L
.5493 .16187 L
F
.2 .63 .79 r
.54888 .16187 m
.54888 .19376 L
.5493 .19376 L
.5493 .16187 L
s
.678 .847 .902 r
.5493 .16187 m
.5493 .19413 L
.54972 .19413 L
.54972 .16187 L
F
.2 .63 .79 r
.5493 .16187 m
.5493 .19413 L
.54972 .19413 L
.54972 .16187 L
s
.678 .847 .902 r
.54972 .16187 m
.54972 .19435 L
.55001 .19435 L
.55001 .16187 L
F
.2 .63 .79 r
.54972 .16187 m
.54972 .19435 L
.55001 .19435 L
.55001 .16187 L
s
.678 .847 .902 r
.55001 .16187 m
.55001 .19442 L
.55029 .19442 L
.55029 .16187 L
F
.2 .63 .79 r
.55001 .16187 m
.55001 .19442 L
.55029 .19442 L
.55029 .16187 L
s
.678 .847 .902 r
.55029 .16187 m
.55029 .19471 L
.55074 .19471 L
.55074 .16187 L
F
.2 .63 .79 r
.55029 .16187 m
.55029 .19471 L
.55074 .19471 L
.55074 .16187 L
s
.678 .847 .902 r
.55074 .16187 m
.55074 .19508 L
.55107 .19508 L
.55107 .16187 L
F
.2 .63 .79 r
.55074 .16187 m
.55074 .19508 L
.55107 .19508 L
.55107 .16187 L
s
.678 .847 .902 r
.55107 .16187 m
.55107 .1954 L
.55155 .1954 L
.55155 .16187 L
F
.2 .63 .79 r
.55107 .16187 m
.55107 .1954 L
.55155 .1954 L
.55155 .16187 L
s
.678 .847 .902 r
.55155 .16187 m
.55155 .19547 L
.55171 .19547 L
.55171 .16187 L
F
.2 .63 .79 r
.55155 .16187 m
.55155 .19547 L
.55171 .19547 L
.55171 .16187 L
s
.678 .847 .902 r
.55171 .16187 m
.55171 .19567 L
.55196 .19567 L
.55196 .16187 L
F
.2 .63 .79 r
.55171 .16187 m
.55171 .19567 L
.55196 .19567 L
.55196 .16187 L
s
.678 .847 .902 r
.55196 .16187 m
.55196 .19593 L
.55238 .19593 L
.55238 .16187 L
F
.2 .63 .79 r
.55196 .16187 m
.55196 .19593 L
.55238 .19593 L
.55238 .16187 L
s
.678 .847 .902 r
.55238 .16187 m
.55238 .1963 L
.55279 .1963 L
.55279 .16187 L
F
.2 .63 .79 r
.55238 .16187 m
.55238 .1963 L
.55279 .1963 L
.55279 .16187 L
s
.678 .847 .902 r
.55279 .16187 m
.55279 .19643 L
.55327 .19643 L
.55327 .16187 L
F
.2 .63 .79 r
.55279 .16187 m
.55279 .19643 L
.55327 .19643 L
.55327 .16187 L
s
.678 .847 .902 r
.55327 .16187 m
.55327 .19664 L
.55357 .19664 L
.55357 .16187 L
F
.2 .63 .79 r
.55327 .16187 m
.55327 .19664 L
.55357 .19664 L
.55357 .16187 L
s
.678 .847 .902 r
.55357 .16187 m
.55357 .19695 L
.55389 .19695 L
.55389 .16187 L
F
.2 .63 .79 r
.55357 .16187 m
.55357 .19695 L
.55389 .19695 L
.55389 .16187 L
s
.678 .847 .902 r
.55389 .16187 m
.55389 .1972 L
.55415 .1972 L
.55415 .16187 L
F
.2 .63 .79 r
.55389 .16187 m
.55389 .1972 L
.55415 .1972 L
.55415 .16187 L
s
.678 .847 .902 r
.55415 .16187 m
.55415 .19729 L
.55449 .19729 L
.55449 .16187 L
F
.2 .63 .79 r
.55415 .16187 m
.55415 .19729 L
.55449 .19729 L
.55449 .16187 L
s
.678 .847 .902 r
.55449 .16187 m
.55449 .19756 L
.55495 .19756 L
.55495 .16187 L
F
.2 .63 .79 r
.55449 .16187 m
.55449 .19756 L
.55495 .19756 L
.55495 .16187 L
s
.678 .847 .902 r
.55495 .16187 m
.55495 .19783 L
.55519 .19783 L
.55519 .16187 L
F
.2 .63 .79 r
.55495 .16187 m
.55495 .19783 L
.55519 .19783 L
.55519 .16187 L
s
.678 .847 .902 r
.55519 .16187 m
.55519 .19799 L
.55536 .19799 L
.55536 .16187 L
F
.2 .63 .79 r
.55519 .16187 m
.55519 .19799 L
.55536 .19799 L
.55536 .16187 L
s
.678 .847 .902 r
.55536 .16187 m
.55536 .19822 L
.55569 .19822 L
.55569 .16187 L
F
.2 .63 .79 r
.55536 .16187 m
.55536 .19822 L
.55569 .19822 L
.55569 .16187 L
s
.678 .847 .902 r
.55569 .16187 m
.55569 .19836 L
.55589 .19836 L
.55589 .16187 L
F
.2 .63 .79 r
.55569 .16187 m
.55569 .19836 L
.55589 .19836 L
.55589 .16187 L
s
.678 .847 .902 r
.55589 .16187 m
.55589 .19846 L
.55622 .19846 L
.55622 .16187 L
F
.2 .63 .79 r
.55589 .16187 m
.55589 .19846 L
.55622 .19846 L
.55622 .16187 L
s
.678 .847 .902 r
.55622 .16187 m
.55622 .19886 L
.55667 .19886 L
.55667 .16187 L
F
.2 .63 .79 r
.55622 .16187 m
.55622 .19886 L
.55667 .19886 L
.55667 .16187 L
s
.678 .847 .902 r
.55667 .16187 m
.55667 .19905 L
.55684 .19905 L
.55684 .16187 L
F
.2 .63 .79 r
.55667 .16187 m
.55667 .19905 L
.55684 .19905 L
.55684 .16187 L
s
.678 .847 .902 r
.55684 .16187 m
.55684 .19909 L
.55712 .19909 L
.55712 .16187 L
F
.2 .63 .79 r
.55684 .16187 m
.55684 .19909 L
.55712 .19909 L
.55712 .16187 L
s
.678 .847 .902 r
.55712 .16187 m
.55712 .19939 L
.55752 .19939 L
.55752 .16187 L
F
.2 .63 .79 r
.55712 .16187 m
.55712 .19939 L
.55752 .19939 L
.55752 .16187 L
s
.678 .847 .902 r
.55752 .16187 m
.55752 .19975 L
.55783 .19975 L
.55783 .16187 L
F
.2 .63 .79 r
.55752 .16187 m
.55752 .19975 L
.55783 .19975 L
.55783 .16187 L
s
.678 .847 .902 r
.55783 .16187 m
.55783 .19993 L
.5582 .19993 L
.5582 .16187 L
F
.2 .63 .79 r
.55783 .16187 m
.55783 .19993 L
.5582 .19993 L
.5582 .16187 L
s
.678 .847 .902 r
.5582 .16187 m
.5582 .20017 L
.55853 .20017 L
.55853 .16187 L
F
.2 .63 .79 r
.5582 .16187 m
.5582 .20017 L
.55853 .20017 L
.55853 .16187 L
s
.678 .847 .902 r
.55853 .16187 m
.55853 .20035 L
.55875 .20035 L
.55875 .16187 L
F
.2 .63 .79 r
.55853 .16187 m
.55853 .20035 L
.55875 .20035 L
.55875 .16187 L
s
.678 .847 .902 r
.55875 .16187 m
.55875 .20043 L
.55906 .20043 L
.55906 .16187 L
F
.2 .63 .79 r
.55875 .16187 m
.55875 .20043 L
.55906 .20043 L
.55906 .16187 L
s
.678 .847 .902 r
.55906 .16187 m
.55906 .20075 L
.55943 .20075 L
.55943 .16187 L
F
.2 .63 .79 r
.55906 .16187 m
.55906 .20075 L
.55943 .20075 L
.55943 .16187 L
s
.678 .847 .902 r
.55943 .16187 m
.55943 .20104 L
.55966 .20104 L
.55966 .16187 L
F
.2 .63 .79 r
.55943 .16187 m
.55943 .20104 L
.55966 .20104 L
.55966 .16187 L
s
.678 .847 .902 r
.55966 .16187 m
.55966 .20122 L
.55995 .20122 L
.55995 .16187 L
F
.2 .63 .79 r
.55966 .16187 m
.55966 .20122 L
.55995 .20122 L
.55995 .16187 L
s
.678 .847 .902 r
.55995 .16187 m
.55995 .20127 L
.56034 .20127 L
.56034 .16187 L
F
.2 .63 .79 r
.55995 .16187 m
.55995 .20127 L
.56034 .20127 L
.56034 .16187 L
s
.678 .847 .902 r
.56034 .16187 m
.56034 .20153 L
.56072 .20153 L
.56072 .16187 L
F
.2 .63 .79 r
.56034 .16187 m
.56034 .20153 L
.56072 .20153 L
.56072 .16187 L
s
.678 .847 .902 r
.56072 .16187 m
.56072 .20206 L
.56114 .20206 L
.56114 .16187 L
F
.2 .63 .79 r
.56072 .16187 m
.56072 .20206 L
.56114 .20206 L
.56114 .16187 L
s
.678 .847 .902 r
.56114 .16187 m
.56114 .2022 L
.56161 .2022 L
.56161 .16187 L
F
.2 .63 .79 r
.56114 .16187 m
.56114 .2022 L
.56161 .2022 L
.56161 .16187 L
s
.678 .847 .902 r
.56161 .16187 m
.56161 .20246 L
.5619 .20246 L
.5619 .16187 L
F
.2 .63 .79 r
.56161 .16187 m
.56161 .20246 L
.5619 .20246 L
.5619 .16187 L
s
.678 .847 .902 r
.5619 .16187 m
.5619 .2027 L
.56208 .2027 L
.56208 .16187 L
F
.2 .63 .79 r
.5619 .16187 m
.5619 .2027 L
.56208 .2027 L
.56208 .16187 L
s
.678 .847 .902 r
.56208 .16187 m
.56208 .20293 L
.56253 .20293 L
.56253 .16187 L
F
.2 .63 .79 r
.56208 .16187 m
.56208 .20293 L
.56253 .20293 L
.56253 .16187 L
s
.678 .847 .902 r
.56253 .16187 m
.56253 .20308 L
.5629 .20308 L
.5629 .16187 L
F
.2 .63 .79 r
.56253 .16187 m
.56253 .20308 L
.5629 .20308 L
.5629 .16187 L
s
.678 .847 .902 r
.5629 .16187 m
.5629 .20349 L
.56317 .20349 L
.56317 .16187 L
F
.2 .63 .79 r
.5629 .16187 m
.5629 .20349 L
.56317 .20349 L
.56317 .16187 L
s
.678 .847 .902 r
.56317 .16187 m
.56317 .20352 L
.56351 .20352 L
.56351 .16187 L
F
.2 .63 .79 r
.56317 .16187 m
.56317 .20352 L
.56351 .20352 L
.56351 .16187 L
s
.678 .847 .902 r
.56351 .16187 m
.56351 .20378 L
.56391 .20378 L
.56391 .16187 L
F
.2 .63 .79 r
.56351 .16187 m
.56351 .20378 L
.56391 .20378 L
.56391 .16187 L
s
.678 .847 .902 r
.56391 .16187 m
.56391 .20415 L
.5641 .20415 L
.5641 .16187 L
F
.2 .63 .79 r
.56391 .16187 m
.56391 .20415 L
.5641 .20415 L
.5641 .16187 L
s
.678 .847 .902 r
.5641 .16187 m
.5641 .20422 L
.56441 .20422 L
.56441 .16187 L
F
.2 .63 .79 r
.5641 .16187 m
.5641 .20422 L
.56441 .20422 L
.56441 .16187 L
s
.678 .847 .902 r
.56441 .16187 m
.56441 .20446 L
.56473 .20446 L
.56473 .16187 L
F
.2 .63 .79 r
.56441 .16187 m
.56441 .20446 L
.56473 .20446 L
.56473 .16187 L
s
.678 .847 .902 r
.56473 .16187 m
.56473 .20462 L
.565 .20462 L
.565 .16187 L
F
.2 .63 .79 r
.56473 .16187 m
.56473 .20462 L
.565 .20462 L
.565 .16187 L
s
.678 .847 .902 r
.565 .16187 m
.565 .2049 L
.56528 .2049 L
.56528 .16187 L
F
.2 .63 .79 r
.565 .16187 m
.565 .2049 L
.56528 .2049 L
.56528 .16187 L
s
.678 .847 .902 r
.56528 .16187 m
.56528 .20502 L
.56543 .20502 L
.56543 .16187 L
F
.2 .63 .79 r
.56528 .16187 m
.56528 .20502 L
.56543 .20502 L
.56543 .16187 L
s
.678 .847 .902 r
.56543 .16187 m
.56543 .20534 L
.56587 .20534 L
.56587 .16187 L
F
.2 .63 .79 r
.56543 .16187 m
.56543 .20534 L
.56587 .20534 L
.56587 .16187 L
s
.678 .847 .902 r
.56587 .16187 m
.56587 .20556 L
.56631 .20556 L
.56631 .16187 L
F
.2 .63 .79 r
.56587 .16187 m
.56587 .20556 L
.56631 .20556 L
.56631 .16187 L
s
.678 .847 .902 r
.56631 .16187 m
.56631 .20571 L
.5665 .20571 L
.5665 .16187 L
F
.2 .63 .79 r
.56631 .16187 m
.56631 .20571 L
.5665 .20571 L
.5665 .16187 L
s
.678 .847 .902 r
.5665 .16187 m
.5665 .20593 L
.56684 .20593 L
.56684 .16187 L
F
.2 .63 .79 r
.5665 .16187 m
.5665 .20593 L
.56684 .20593 L
.56684 .16187 L
s
.678 .847 .902 r
.56684 .16187 m
.56684 .20614 L
.56705 .20614 L
.56705 .16187 L
F
.2 .63 .79 r
.56684 .16187 m
.56684 .20614 L
.56705 .20614 L
.56705 .16187 L
s
.678 .847 .902 r
.56705 .16187 m
.56705 .20637 L
.56741 .20637 L
.56741 .16187 L
F
.2 .63 .79 r
.56705 .16187 m
.56705 .20637 L
.56741 .20637 L
.56741 .16187 L
s
.678 .847 .902 r
.56741 .16187 m
.56741 .20653 L
.56781 .20653 L
.56781 .16187 L
F
.2 .63 .79 r
.56741 .16187 m
.56741 .20653 L
.56781 .20653 L
.56781 .16187 L
s
.678 .847 .902 r
.56781 .16187 m
.56781 .20685 L
.56824 .20685 L
.56824 .16187 L
F
.2 .63 .79 r
.56781 .16187 m
.56781 .20685 L
.56824 .20685 L
.56824 .16187 L
s
.678 .847 .902 r
.56824 .16187 m
.56824 .20715 L
.56857 .20715 L
.56857 .16187 L
F
.2 .63 .79 r
.56824 .16187 m
.56824 .20715 L
.56857 .20715 L
.56857 .16187 L
s
.678 .847 .902 r
.56857 .16187 m
.56857 .2075 L
.569 .2075 L
.569 .16187 L
F
.2 .63 .79 r
.56857 .16187 m
.56857 .2075 L
.569 .2075 L
.569 .16187 L
s
.678 .847 .902 r
.569 .16187 m
.569 .20786 L
.56943 .20786 L
.56943 .16187 L
F
.2 .63 .79 r
.569 .16187 m
.569 .20786 L
.56943 .20786 L
.56943 .16187 L
s
.678 .847 .902 r
.56943 .16187 m
.56943 .20792 L
.56972 .20792 L
.56972 .16187 L
F
.2 .63 .79 r
.56943 .16187 m
.56943 .20792 L
.56972 .20792 L
.56972 .16187 L
s
.678 .847 .902 r
.56972 .16187 m
.56972 .20823 L
.57002 .20823 L
.57002 .16187 L
F
.2 .63 .79 r
.56972 .16187 m
.56972 .20823 L
.57002 .20823 L
.57002 .16187 L
s
.678 .847 .902 r
.57002 .16187 m
.57002 .20833 L
.57048 .20833 L
.57048 .16187 L
F
.2 .63 .79 r
.57002 .16187 m
.57002 .20833 L
.57048 .20833 L
.57048 .16187 L
s
.678 .847 .902 r
.57048 .16187 m
.57048 .20876 L
.57069 .20876 L
.57069 .16187 L
F
.2 .63 .79 r
.57048 .16187 m
.57048 .20876 L
.57069 .20876 L
.57069 .16187 L
s
.678 .847 .902 r
.57069 .16187 m
.57069 .20881 L
.57086 .20881 L
.57086 .16187 L
F
.2 .63 .79 r
.57069 .16187 m
.57069 .20881 L
.57086 .20881 L
.57086 .16187 L
s
.678 .847 .902 r
.57086 .16187 m
.57086 .20908 L
.57131 .20908 L
.57131 .16187 L
F
.2 .63 .79 r
.57086 .16187 m
.57086 .20908 L
.57131 .20908 L
.57131 .16187 L
s
.678 .847 .902 r
.57131 .16187 m
.57131 .20937 L
.57152 .20937 L
.57152 .16187 L
F
.2 .63 .79 r
.57131 .16187 m
.57131 .20937 L
.57152 .20937 L
.57152 .16187 L
s
.678 .847 .902 r
.57152 .16187 m
.57152 .20948 L
.57169 .20948 L
.57169 .16187 L
F
.2 .63 .79 r
.57152 .16187 m
.57152 .20948 L
.57169 .20948 L
.57169 .16187 L
s
.678 .847 .902 r
.57169 .16187 m
.57169 .2097 L
.57205 .2097 L
.57205 .16187 L
F
.2 .63 .79 r
.57169 .16187 m
.57169 .2097 L
.57205 .2097 L
.57205 .16187 L
s
.678 .847 .902 r
.57205 .16187 m
.57205 .20977 L
.57231 .20977 L
.57231 .16187 L
F
.2 .63 .79 r
.57205 .16187 m
.57205 .20977 L
.57231 .20977 L
.57231 .16187 L
s
.678 .847 .902 r
.57231 .16187 m
.57231 .21018 L
.57275 .21018 L
.57275 .16187 L
F
.2 .63 .79 r
.57231 .16187 m
.57231 .21018 L
.57275 .21018 L
.57275 .16187 L
s
.678 .847 .902 r
.57275 .16187 m
.57275 .21029 L
.57313 .21029 L
.57313 .16187 L
F
.2 .63 .79 r
.57275 .16187 m
.57275 .21029 L
.57313 .21029 L
.57313 .16187 L
s
.678 .847 .902 r
.57313 .16187 m
.57313 .21062 L
.57348 .21062 L
.57348 .16187 L
F
.2 .63 .79 r
.57313 .16187 m
.57313 .21062 L
.57348 .21062 L
.57348 .16187 L
s
.678 .847 .902 r
.57348 .16187 m
.57348 .21083 L
.5738 .21083 L
.5738 .16187 L
F
.2 .63 .79 r
.57348 .16187 m
.57348 .21083 L
.5738 .21083 L
.5738 .16187 L
s
.678 .847 .902 r
.5738 .16187 m
.5738 .21104 L
.57395 .21104 L
.57395 .16187 L
F
.2 .63 .79 r
.5738 .16187 m
.5738 .21104 L
.57395 .21104 L
.57395 .16187 L
s
.678 .847 .902 r
.57395 .16187 m
.57395 .21113 L
.57429 .21113 L
.57429 .16187 L
F
.2 .63 .79 r
.57395 .16187 m
.57395 .21113 L
.57429 .21113 L
.57429 .16187 L
s
.678 .847 .902 r
.57429 .16187 m
.57429 .21147 L
.57445 .21147 L
.57445 .16187 L
F
.2 .63 .79 r
.57429 .16187 m
.57429 .21147 L
.57445 .21147 L
.57445 .16187 L
s
.678 .847 .902 r
.57445 .16187 m
.57445 .21162 L
.5747 .21162 L
.5747 .16187 L
F
.2 .63 .79 r
.57445 .16187 m
.57445 .21162 L
.5747 .21162 L
.5747 .16187 L
s
.678 .847 .902 r
.5747 .16187 m
.5747 .21178 L
.57499 .21178 L
.57499 .16187 L
F
.2 .63 .79 r
.5747 .16187 m
.5747 .21178 L
.57499 .21178 L
.57499 .16187 L
s
.678 .847 .902 r
.57499 .16187 m
.57499 .21212 L
.57541 .21212 L
.57541 .16187 L
F
.2 .63 .79 r
.57499 .16187 m
.57499 .21212 L
.57541 .21212 L
.57541 .16187 L
s
.678 .847 .902 r
.57541 .16187 m
.57541 .21226 L
.57564 .21226 L
.57564 .16187 L
F
.2 .63 .79 r
.57541 .16187 m
.57541 .21226 L
.57564 .21226 L
.57564 .16187 L
s
.678 .847 .902 r
.57564 .16187 m
.57564 .21245 L
.57605 .21245 L
.57605 .16187 L
F
.2 .63 .79 r
.57564 .16187 m
.57564 .21245 L
.57605 .21245 L
.57605 .16187 L
s
.678 .847 .902 r
.57605 .16187 m
.57605 .21286 L
.5764 .21286 L
.5764 .16187 L
F
.2 .63 .79 r
.57605 .16187 m
.57605 .21286 L
.5764 .21286 L
.5764 .16187 L
s
.678 .847 .902 r
.5764 .16187 m
.5764 .21287 L
.57688 .21287 L
.57688 .16187 L
F
.2 .63 .79 r
.5764 .16187 m
.5764 .21287 L
.57688 .21287 L
.57688 .16187 L
s
.678 .847 .902 r
.57688 .16187 m
.57688 .2134 L
.57731 .2134 L
.57731 .16187 L
F
.2 .63 .79 r
.57688 .16187 m
.57688 .2134 L
.57731 .2134 L
.57731 .16187 L
s
.678 .847 .902 r
.57731 .16187 m
.57731 .21369 L
.57758 .21369 L
.57758 .16187 L
F
.2 .63 .79 r
.57731 .16187 m
.57731 .21369 L
.57758 .21369 L
.57758 .16187 L
s
.678 .847 .902 r
.57758 .16187 m
.57758 .21397 L
.57795 .21397 L
.57795 .16187 L
F
.2 .63 .79 r
.57758 .16187 m
.57758 .21397 L
.57795 .21397 L
.57795 .16187 L
s
.678 .847 .902 r
.57795 .16187 m
.57795 .21407 L
.57837 .21407 L
.57837 .16187 L
F
.2 .63 .79 r
.57795 .16187 m
.57795 .21407 L
.57837 .21407 L
.57837 .16187 L
s
.678 .847 .902 r
.57837 .16187 m
.57837 .21443 L
.57878 .21443 L
.57878 .16187 L
F
.2 .63 .79 r
.57837 .16187 m
.57837 .21443 L
.57878 .21443 L
.57878 .16187 L
s
.678 .847 .902 r
.57878 .16187 m
.57878 .21466 L
.5791 .21466 L
.5791 .16187 L
F
.2 .63 .79 r
.57878 .16187 m
.57878 .21466 L
.5791 .21466 L
.5791 .16187 L
s
.678 .847 .902 r
.5791 .16187 m
.5791 .21482 L
.5794 .21482 L
.5794 .16187 L
F
.2 .63 .79 r
.5791 .16187 m
.5791 .21482 L
.5794 .21482 L
.5794 .16187 L
s
.678 .847 .902 r
.5794 .16187 m
.5794 .21519 L
.5798 .21519 L
.5798 .16187 L
F
.2 .63 .79 r
.5794 .16187 m
.5794 .21519 L
.5798 .21519 L
.5798 .16187 L
s
.678 .847 .902 r
.5798 .16187 m
.5798 .21542 L
.58 .21542 L
.58 .16187 L
F
.2 .63 .79 r
.5798 .16187 m
.5798 .21542 L
.58 .21542 L
.58 .16187 L
s
.678 .847 .902 r
.58 .16187 m
.58 .21551 L
.5802 .21551 L
.5802 .16187 L
F
.2 .63 .79 r
.58 .16187 m
.58 .21551 L
.5802 .21551 L
.5802 .16187 L
s
.678 .847 .902 r
.5802 .16187 m
.5802 .21569 L
.58056 .21569 L
.58056 .16187 L
F
.2 .63 .79 r
.5802 .16187 m
.5802 .21569 L
.58056 .21569 L
.58056 .16187 L
s
.678 .847 .902 r
.58056 .16187 m
.58056 .21592 L
.58072 .21592 L
.58072 .16187 L
F
.2 .63 .79 r
.58056 .16187 m
.58056 .21592 L
.58072 .21592 L
.58072 .16187 L
s
.678 .847 .902 r
.58072 .16187 m
.58072 .21608 L
.58107 .21608 L
.58107 .16187 L
F
.2 .63 .79 r
.58072 .16187 m
.58072 .21608 L
.58107 .21608 L
.58107 .16187 L
s
.678 .847 .902 r
.58107 .16187 m
.58107 .21625 L
.58144 .21625 L
.58144 .16187 L
F
.2 .63 .79 r
.58107 .16187 m
.58107 .21625 L
.58144 .21625 L
.58144 .16187 L
s
.678 .847 .902 r
.58144 .16187 m
.58144 .21653 L
.5818 .21653 L
.5818 .16187 L
F
.2 .63 .79 r
.58144 .16187 m
.58144 .21653 L
.5818 .21653 L
.5818 .16187 L
s
.678 .847 .902 r
.5818 .16187 m
.5818 .21685 L
.58212 .21685 L
.58212 .16187 L
F
.2 .63 .79 r
.5818 .16187 m
.5818 .21685 L
.58212 .21685 L
.58212 .16187 L
s
.678 .847 .902 r
.58212 .16187 m
.58212 .2171 L
.58244 .2171 L
.58244 .16187 L
F
.2 .63 .79 r
.58212 .16187 m
.58212 .2171 L
.58244 .2171 L
.58244 .16187 L
s
.678 .847 .902 r
.58244 .16187 m
.58244 .21728 L
.58271 .21728 L
.58271 .16187 L
F
.2 .63 .79 r
.58244 .16187 m
.58244 .21728 L
.58271 .21728 L
.58271 .16187 L
s
.678 .847 .902 r
.58271 .16187 m
.58271 .2175 L
.58294 .2175 L
.58294 .16187 L
F
.2 .63 .79 r
.58271 .16187 m
.58271 .2175 L
.58294 .2175 L
.58294 .16187 L
s
.678 .847 .902 r
.58294 .16187 m
.58294 .21774 L
.58332 .21774 L
.58332 .16187 L
F
.2 .63 .79 r
.58294 .16187 m
.58294 .21774 L
.58332 .21774 L
.58332 .16187 L
s
.678 .847 .902 r
.58332 .16187 m
.58332 .21801 L
.58357 .21801 L
.58357 .16187 L
F
.2 .63 .79 r
.58332 .16187 m
.58332 .21801 L
.58357 .21801 L
.58357 .16187 L
s
.678 .847 .902 r
.58357 .16187 m
.58357 .21826 L
.58392 .21826 L
.58392 .16187 L
F
.2 .63 .79 r
.58357 .16187 m
.58357 .21826 L
.58392 .21826 L
.58392 .16187 L
s
.678 .847 .902 r
.58392 .16187 m
.58392 .21843 L
.58428 .21843 L
.58428 .16187 L
F
.2 .63 .79 r
.58392 .16187 m
.58392 .21843 L
.58428 .21843 L
.58428 .16187 L
s
.678 .847 .902 r
.58428 .16187 m
.58428 .21872 L
.58468 .21872 L
.58468 .16187 L
F
.2 .63 .79 r
.58428 .16187 m
.58428 .21872 L
.58468 .21872 L
.58468 .16187 L
s
.678 .847 .902 r
.58468 .16187 m
.58468 .21891 L
.58499 .21891 L
.58499 .16187 L
F
.2 .63 .79 r
.58468 .16187 m
.58468 .21891 L
.58499 .21891 L
.58499 .16187 L
s
.678 .847 .902 r
.58499 .16187 m
.58499 .21924 L
.58522 .21924 L
.58522 .16187 L
F
.2 .63 .79 r
.58499 .16187 m
.58499 .21924 L
.58522 .21924 L
.58522 .16187 L
s
.678 .847 .902 r
.58522 .16187 m
.58522 .21945 L
.5857 .21945 L
.5857 .16187 L
F
.2 .63 .79 r
.58522 .16187 m
.58522 .21945 L
.5857 .21945 L
.5857 .16187 L
s
.678 .847 .902 r
.5857 .16187 m
.5857 .21969 L
.58617 .21969 L
.58617 .16187 L
F
.2 .63 .79 r
.5857 .16187 m
.5857 .21969 L
.58617 .21969 L
.58617 .16187 L
s
.678 .847 .902 r
.58617 .16187 m
.58617 .22016 L
.58657 .22016 L
.58657 .16187 L
F
.2 .63 .79 r
.58617 .16187 m
.58617 .22016 L
.58657 .22016 L
.58657 .16187 L
s
.678 .847 .902 r
.58657 .16187 m
.58657 .22042 L
.58697 .22042 L
.58697 .16187 L
F
.2 .63 .79 r
.58657 .16187 m
.58657 .22042 L
.58697 .22042 L
.58697 .16187 L
s
.678 .847 .902 r
.58697 .16187 m
.58697 .22065 L
.5873 .22065 L
.5873 .16187 L
F
.2 .63 .79 r
.58697 .16187 m
.58697 .22065 L
.5873 .22065 L
.5873 .16187 L
s
.678 .847 .902 r
.5873 .16187 m
.5873 .22088 L
.58751 .22088 L
.58751 .16187 L
F
.2 .63 .79 r
.5873 .16187 m
.5873 .22088 L
.58751 .22088 L
.58751 .16187 L
s
.678 .847 .902 r
.58751 .16187 m
.58751 .22093 L
.58785 .22093 L
.58785 .16187 L
F
.2 .63 .79 r
.58751 .16187 m
.58751 .22093 L
.58785 .22093 L
.58785 .16187 L
s
.678 .847 .902 r
.58785 .16187 m
.58785 .22126 L
.5882 .22126 L
.5882 .16187 L
F
.2 .63 .79 r
.58785 .16187 m
.58785 .22126 L
.5882 .22126 L
.5882 .16187 L
s
.678 .847 .902 r
.5882 .16187 m
.5882 .2215 L
.58866 .2215 L
.58866 .16187 L
F
.2 .63 .79 r
.5882 .16187 m
.5882 .2215 L
.58866 .2215 L
.58866 .16187 L
s
.678 .847 .902 r
.58866 .16187 m
.58866 .22181 L
.58886 .22181 L
.58886 .16187 L
F
.2 .63 .79 r
.58866 .16187 m
.58866 .22181 L
.58886 .22181 L
.58886 .16187 L
s
.678 .847 .902 r
.58886 .16187 m
.58886 .22198 L
.58901 .22198 L
.58901 .16187 L
F
.2 .63 .79 r
.58886 .16187 m
.58886 .22198 L
.58901 .22198 L
.58901 .16187 L
s
.678 .847 .902 r
.58901 .16187 m
.58901 .22211 L
.58948 .22211 L
.58948 .16187 L
F
.2 .63 .79 r
.58901 .16187 m
.58901 .22211 L
.58948 .22211 L
.58948 .16187 L
s
.678 .847 .902 r
.58948 .16187 m
.58948 .22239 L
.58973 .22239 L
.58973 .16187 L
F
.2 .63 .79 r
.58948 .16187 m
.58948 .22239 L
.58973 .22239 L
.58973 .16187 L
s
.678 .847 .902 r
.58973 .16187 m
.58973 .2228 L
.5901 .2228 L
.5901 .16187 L
F
.2 .63 .79 r
.58973 .16187 m
.58973 .2228 L
.5901 .2228 L
.5901 .16187 L
s
.678 .847 .902 r
.5901 .16187 m
.5901 .22287 L
.59042 .22287 L
.59042 .16187 L
F
.2 .63 .79 r
.5901 .16187 m
.5901 .22287 L
.59042 .22287 L
.59042 .16187 L
s
.678 .847 .902 r
.59042 .16187 m
.59042 .22331 L
.59077 .22331 L
.59077 .16187 L
F
.2 .63 .79 r
.59042 .16187 m
.59042 .22331 L
.59077 .22331 L
.59077 .16187 L
s
.678 .847 .902 r
.59077 .16187 m
.59077 .22339 L
.59094 .22339 L
.59094 .16187 L
F
.2 .63 .79 r
.59077 .16187 m
.59077 .22339 L
.59094 .22339 L
.59094 .16187 L
s
.678 .847 .902 r
.59094 .16187 m
.59094 .22356 L
.59142 .22356 L
.59142 .16187 L
F
.2 .63 .79 r
.59094 .16187 m
.59094 .22356 L
.59142 .22356 L
.59142 .16187 L
s
.678 .847 .902 r
.59142 .16187 m
.59142 .22385 L
.59164 .22385 L
.59164 .16187 L
F
.2 .63 .79 r
.59142 .16187 m
.59142 .22385 L
.59164 .22385 L
.59164 .16187 L
s
.678 .847 .902 r
.59164 .16187 m
.59164 .22401 L
.59213 .22401 L
.59213 .16187 L
F
.2 .63 .79 r
.59164 .16187 m
.59164 .22401 L
.59213 .22401 L
.59213 .16187 L
s
.678 .847 .902 r
.59213 .16187 m
.59213 .22434 L
.59243 .22434 L
.59243 .16187 L
F
.2 .63 .79 r
.59213 .16187 m
.59213 .22434 L
.59243 .22434 L
.59243 .16187 L
s
.678 .847 .902 r
.59243 .16187 m
.59243 .22467 L
.59266 .22467 L
.59266 .16187 L
F
.2 .63 .79 r
.59243 .16187 m
.59243 .22467 L
.59266 .22467 L
.59266 .16187 L
s
.678 .847 .902 r
.59266 .16187 m
.59266 .22474 L
.59306 .22474 L
.59306 .16187 L
F
.2 .63 .79 r
.59266 .16187 m
.59266 .22474 L
.59306 .22474 L
.59306 .16187 L
s
.678 .847 .902 r
.59306 .16187 m
.59306 .22505 L
.59347 .22505 L
.59347 .16187 L
F
.2 .63 .79 r
.59306 .16187 m
.59306 .22505 L
.59347 .22505 L
.59347 .16187 L
s
.678 .847 .902 r
.59347 .16187 m
.59347 .22543 L
.59377 .22543 L
.59377 .16187 L
F
.2 .63 .79 r
.59347 .16187 m
.59347 .22543 L
.59377 .22543 L
.59377 .16187 L
s
.678 .847 .902 r
.59377 .16187 m
.59377 .22563 L
.59404 .22563 L
.59404 .16187 L
F
.2 .63 .79 r
.59377 .16187 m
.59377 .22563 L
.59404 .22563 L
.59404 .16187 L
s
.678 .847 .902 r
.59404 .16187 m
.59404 .22576 L
.59419 .22576 L
.59419 .16187 L
F
.2 .63 .79 r
.59404 .16187 m
.59404 .22576 L
.59419 .22576 L
.59419 .16187 L
s
.678 .847 .902 r
.59419 .16187 m
.59419 .22589 L
.59434 .22589 L
.59434 .16187 L
F
.2 .63 .79 r
.59419 .16187 m
.59419 .22589 L
.59434 .22589 L
.59434 .16187 L
s
.678 .847 .902 r
.59434 .16187 m
.59434 .22596 L
.59481 .22596 L
.59481 .16187 L
F
.2 .63 .79 r
.59434 .16187 m
.59434 .22596 L
.59481 .22596 L
.59481 .16187 L
s
.678 .847 .902 r
.59481 .16187 m
.59481 .22642 L
.59501 .22642 L
.59501 .16187 L
F
.2 .63 .79 r
.59481 .16187 m
.59481 .22642 L
.59501 .22642 L
.59501 .16187 L
s
.678 .847 .902 r
.59501 .16187 m
.59501 .22651 L
.5953 .22651 L
.5953 .16187 L
F
.2 .63 .79 r
.59501 .16187 m
.59501 .22651 L
.5953 .22651 L
.5953 .16187 L
s
.678 .847 .902 r
.5953 .16187 m
.5953 .2267 L
.5956 .2267 L
.5956 .16187 L
F
.2 .63 .79 r
.5953 .16187 m
.5953 .2267 L
.5956 .2267 L
.5956 .16187 L
s
.678 .847 .902 r
.5956 .16187 m
.5956 .22697 L
.59575 .22697 L
.59575 .16187 L
F
.2 .63 .79 r
.5956 .16187 m
.5956 .22697 L
.59575 .22697 L
.59575 .16187 L
s
.678 .847 .902 r
.59575 .16187 m
.59575 .22705 L
.5959 .22705 L
.5959 .16187 L
F
.2 .63 .79 r
.59575 .16187 m
.59575 .22705 L
.5959 .22705 L
.5959 .16187 L
s
.678 .847 .902 r
.5959 .16187 m
.5959 .22725 L
.59619 .22725 L
.59619 .16187 L
F
.2 .63 .79 r
.5959 .16187 m
.5959 .22725 L
.59619 .22725 L
.59619 .16187 L
s
.678 .847 .902 r
.59619 .16187 m
.59619 .22754 L
.59651 .22754 L
.59651 .16187 L
F
.2 .63 .79 r
.59619 .16187 m
.59619 .22754 L
.59651 .22754 L
.59651 .16187 L
s
.678 .847 .902 r
.59651 .16187 m
.59651 .22776 L
.59691 .22776 L
.59691 .16187 L
F
.2 .63 .79 r
.59651 .16187 m
.59651 .22776 L
.59691 .22776 L
.59691 .16187 L
s
.678 .847 .902 r
.59691 .16187 m
.59691 .22798 L
.59718 .22798 L
.59718 .16187 L
F
.2 .63 .79 r
.59691 .16187 m
.59691 .22798 L
.59718 .22798 L
.59718 .16187 L
s
.678 .847 .902 r
.59718 .16187 m
.59718 .22822 L
.59764 .22822 L
.59764 .16187 L
F
.2 .63 .79 r
.59718 .16187 m
.59718 .22822 L
.59764 .22822 L
.59764 .16187 L
s
.678 .847 .902 r
.59764 .16187 m
.59764 .22872 L
.59811 .22872 L
.59811 .16187 L
F
.2 .63 .79 r
.59764 .16187 m
.59764 .22872 L
.59811 .22872 L
.59811 .16187 L
s
.678 .847 .902 r
.59811 .16187 m
.59811 .22876 L
.59848 .22876 L
.59848 .16187 L
F
.2 .63 .79 r
.59811 .16187 m
.59811 .22876 L
.59848 .22876 L
.59848 .16187 L
s
.678 .847 .902 r
.59848 .16187 m
.59848 .22908 L
.59877 .22908 L
.59877 .16187 L
F
.2 .63 .79 r
.59848 .16187 m
.59848 .22908 L
.59877 .22908 L
.59877 .16187 L
s
.678 .847 .902 r
.59877 .16187 m
.59877 .22927 L
.59916 .22927 L
.59916 .16187 L
F
.2 .63 .79 r
.59877 .16187 m
.59877 .22927 L
.59916 .22927 L
.59916 .16187 L
s
.678 .847 .902 r
.59916 .16187 m
.59916 .2298 L
.59963 .2298 L
.59963 .16187 L
F
.2 .63 .79 r
.59916 .16187 m
.59916 .2298 L
.59963 .2298 L
.59963 .16187 L
s
.678 .847 .902 r
.59963 .16187 m
.59963 .23003 L
.59984 .23003 L
.59984 .16187 L
F
.2 .63 .79 r
.59963 .16187 m
.59963 .23003 L
.59984 .23003 L
.59984 .16187 L
s
.678 .847 .902 r
.59984 .16187 m
.59984 .23011 L
.60005 .23011 L
.60005 .16187 L
F
.2 .63 .79 r
.59984 .16187 m
.59984 .23011 L
.60005 .23011 L
.60005 .16187 L
s
.678 .847 .902 r
.60005 .16187 m
.60005 .23055 L
.60053 .23055 L
.60053 .16187 L
F
.2 .63 .79 r
.60005 .16187 m
.60005 .23055 L
.60053 .23055 L
.60053 .16187 L
s
.678 .847 .902 r
.60053 .16187 m
.60053 .23065 L
.60074 .23065 L
.60074 .16187 L
F
.2 .63 .79 r
.60053 .16187 m
.60053 .23065 L
.60074 .23065 L
.60074 .16187 L
s
.678 .847 .902 r
.60074 .16187 m
.60074 .23082 L
.60114 .23082 L
.60114 .16187 L
F
.2 .63 .79 r
.60074 .16187 m
.60074 .23082 L
.60114 .23082 L
.60114 .16187 L
s
.678 .847 .902 r
.60114 .16187 m
.60114 .23131 L
.60157 .23131 L
.60157 .16187 L
F
.2 .63 .79 r
.60114 .16187 m
.60114 .23131 L
.60157 .23131 L
.60157 .16187 L
s
.678 .847 .902 r
.60157 .16187 m
.60157 .23156 L
.60205 .23156 L
.60205 .16187 L
F
.2 .63 .79 r
.60157 .16187 m
.60157 .23156 L
.60205 .23156 L
.60205 .16187 L
s
.678 .847 .902 r
.60205 .16187 m
.60205 .23171 L
.60226 .23171 L
.60226 .16187 L
F
.2 .63 .79 r
.60205 .16187 m
.60205 .23171 L
.60226 .23171 L
.60226 .16187 L
s
.678 .847 .902 r
.60226 .16187 m
.60226 .23196 L
.60269 .23196 L
.60269 .16187 L
F
.2 .63 .79 r
.60226 .16187 m
.60226 .23196 L
.60269 .23196 L
.60269 .16187 L
s
.678 .847 .902 r
.60269 .16187 m
.60269 .2322 L
.60306 .2322 L
.60306 .16187 L
F
.2 .63 .79 r
.60269 .16187 m
.60269 .2322 L
.60306 .2322 L
.60306 .16187 L
s
.678 .847 .902 r
.60306 .16187 m
.60306 .23254 L
.60339 .23254 L
.60339 .16187 L
F
.2 .63 .79 r
.60306 .16187 m
.60306 .23254 L
.60339 .23254 L
.60339 .16187 L
s
.678 .847 .902 r
.60339 .16187 m
.60339 .23298 L
.6038 .23298 L
.6038 .16187 L
F
.2 .63 .79 r
.60339 .16187 m
.60339 .23298 L
.6038 .23298 L
.6038 .16187 L
s
.678 .847 .902 r
.6038 .16187 m
.6038 .23318 L
.60423 .23318 L
.60423 .16187 L
F
.2 .63 .79 r
.6038 .16187 m
.6038 .23318 L
.60423 .23318 L
.60423 .16187 L
s
.678 .847 .902 r
.60423 .16187 m
.60423 .23349 L
.6046 .23349 L
.6046 .16187 L
F
.2 .63 .79 r
.60423 .16187 m
.60423 .23349 L
.6046 .23349 L
.6046 .16187 L
s
.678 .847 .902 r
.6046 .16187 m
.6046 .23371 L
.60478 .23371 L
.60478 .16187 L
F
.2 .63 .79 r
.6046 .16187 m
.6046 .23371 L
.60478 .23371 L
.60478 .16187 L
s
.678 .847 .902 r
.60478 .16187 m
.60478 .23375 L
.60501 .23375 L
.60501 .16187 L
F
.2 .63 .79 r
.60478 .16187 m
.60478 .23375 L
.60501 .23375 L
.60501 .16187 L
s
.678 .847 .902 r
.60501 .16187 m
.60501 .23404 L
.6052 .23404 L
.6052 .16187 L
F
.2 .63 .79 r
.60501 .16187 m
.60501 .23404 L
.6052 .23404 L
.6052 .16187 L
s
.678 .847 .902 r
.6052 .16187 m
.6052 .23423 L
.60544 .23423 L
.60544 .16187 L
F
.2 .63 .79 r
.6052 .16187 m
.6052 .23423 L
.60544 .23423 L
.60544 .16187 L
s
.678 .847 .902 r
.60544 .16187 m
.60544 .23428 L
.60566 .23428 L
.60566 .16187 L
F
.2 .63 .79 r
.60544 .16187 m
.60544 .23428 L
.60566 .23428 L
.60566 .16187 L
s
.678 .847 .902 r
.60566 .16187 m
.60566 .23443 L
.60591 .23443 L
.60591 .16187 L
F
.2 .63 .79 r
.60566 .16187 m
.60566 .23443 L
.60591 .23443 L
.60591 .16187 L
s
.678 .847 .902 r
.60591 .16187 m
.60591 .23478 L
.60622 .23478 L
.60622 .16187 L
F
.2 .63 .79 r
.60591 .16187 m
.60591 .23478 L
.60622 .23478 L
.60622 .16187 L
s
.678 .847 .902 r
.60622 .16187 m
.60622 .23506 L
.60667 .23506 L
.60667 .16187 L
F
.2 .63 .79 r
.60622 .16187 m
.60622 .23506 L
.60667 .23506 L
.60667 .16187 L
s
.678 .847 .902 r
.60667 .16187 m
.60667 .2352 L
.60699 .2352 L
.60699 .16187 L
F
.2 .63 .79 r
.60667 .16187 m
.60667 .2352 L
.60699 .2352 L
.60699 .16187 L
s
.678 .847 .902 r
.60699 .16187 m
.60699 .23549 L
.60726 .23549 L
.60726 .16187 L
F
.2 .63 .79 r
.60699 .16187 m
.60699 .23549 L
.60726 .23549 L
.60726 .16187 L
s
.678 .847 .902 r
.60726 .16187 m
.60726 .23578 L
.6075 .23578 L
.6075 .16187 L
F
.2 .63 .79 r
.60726 .16187 m
.60726 .23578 L
.6075 .23578 L
.6075 .16187 L
s
.678 .847 .902 r
.6075 .16187 m
.6075 .23587 L
.6079 .23587 L
.6079 .16187 L
F
.2 .63 .79 r
.6075 .16187 m
.6075 .23587 L
.6079 .23587 L
.6079 .16187 L
s
.678 .847 .902 r
.6079 .16187 m
.6079 .23614 L
.60823 .23614 L
.60823 .16187 L
F
.2 .63 .79 r
.6079 .16187 m
.6079 .23614 L
.60823 .23614 L
.60823 .16187 L
s
.678 .847 .902 r
.60823 .16187 m
.60823 .23648 L
.60844 .23648 L
.60844 .16187 L
F
.2 .63 .79 r
.60823 .16187 m
.60823 .23648 L
.60844 .23648 L
.60844 .16187 L
s
.678 .847 .902 r
.60844 .16187 m
.60844 .23663 L
.60877 .23663 L
.60877 .16187 L
F
.2 .63 .79 r
.60844 .16187 m
.60844 .23663 L
.60877 .23663 L
.60877 .16187 L
s
.678 .847 .902 r
.60877 .16187 m
.60877 .23688 L
.60922 .23688 L
.60922 .16187 L
F
.2 .63 .79 r
.60877 .16187 m
.60877 .23688 L
.60922 .23688 L
.60922 .16187 L
s
.678 .847 .902 r
.60922 .16187 m
.60922 .23724 L
.60957 .23724 L
.60957 .16187 L
F
.2 .63 .79 r
.60922 .16187 m
.60922 .23724 L
.60957 .23724 L
.60957 .16187 L
s
.678 .847 .902 r
.60957 .16187 m
.60957 .23745 L
.60972 .23745 L
.60972 .16187 L
F
.2 .63 .79 r
.60957 .16187 m
.60957 .23745 L
.60972 .23745 L
.60972 .16187 L
s
.678 .847 .902 r
.60972 .16187 m
.60972 .23753 L
.61011 .23753 L
.61011 .16187 L
F
.2 .63 .79 r
.60972 .16187 m
.60972 .23753 L
.61011 .23753 L
.61011 .16187 L
s
.678 .847 .902 r
.61011 .16187 m
.61011 .23783 L
.61034 .23783 L
.61034 .16187 L
F
.2 .63 .79 r
.61011 .16187 m
.61011 .23783 L
.61034 .23783 L
.61034 .16187 L
s
.678 .847 .902 r
.61034 .16187 m
.61034 .23798 L
.6105 .23798 L
.6105 .16187 L
F
.2 .63 .79 r
.61034 .16187 m
.61034 .23798 L
.6105 .23798 L
.6105 .16187 L
s
.678 .847 .902 r
.6105 .16187 m
.6105 .23822 L
.61075 .23822 L
.61075 .16187 L
F
.2 .63 .79 r
.6105 .16187 m
.6105 .23822 L
.61075 .23822 L
.61075 .16187 L
s
.678 .847 .902 r
.61075 .16187 m
.61075 .23848 L
.6112 .23848 L
.6112 .16187 L
F
.2 .63 .79 r
.61075 .16187 m
.61075 .23848 L
.6112 .23848 L
.6112 .16187 L
s
.678 .847 .902 r
.6112 .16187 m
.6112 .23879 L
.61154 .23879 L
.61154 .16187 L
F
.2 .63 .79 r
.6112 .16187 m
.6112 .23879 L
.61154 .23879 L
.61154 .16187 L
s
.678 .847 .902 r
.61154 .16187 m
.61154 .23905 L
.61202 .23905 L
.61202 .16187 L
F
.2 .63 .79 r
.61154 .16187 m
.61154 .23905 L
.61202 .23905 L
.61202 .16187 L
s
.678 .847 .902 r
.61202 .16187 m
.61202 .23933 L
.61218 .23933 L
.61218 .16187 L
F
.2 .63 .79 r
.61202 .16187 m
.61202 .23933 L
.61218 .23933 L
.61218 .16187 L
s
.678 .847 .902 r
.61218 .16187 m
.61218 .23961 L
.61259 .23961 L
.61259 .16187 L
F
.2 .63 .79 r
.61218 .16187 m
.61218 .23961 L
.61259 .23961 L
.61259 .16187 L
s
.678 .847 .902 r
.61259 .16187 m
.61259 .23982 L
.61284 .23982 L
.61284 .16187 L
F
.2 .63 .79 r
.61259 .16187 m
.61259 .23982 L
.61284 .23982 L
.61284 .16187 L
s
.678 .847 .902 r
.61284 .16187 m
.61284 .23995 L
.61324 .23995 L
.61324 .16187 L
F
.2 .63 .79 r
.61284 .16187 m
.61284 .23995 L
.61324 .23995 L
.61324 .16187 L
s
.678 .847 .902 r
.61324 .16187 m
.61324 .24036 L
.61365 .24036 L
.61365 .16187 L
F
.2 .63 .79 r
.61324 .16187 m
.61324 .24036 L
.61365 .24036 L
.61365 .16187 L
s
.678 .847 .902 r
.61365 .16187 m
.61365 .24049 L
.6139 .24049 L
.6139 .16187 L
F
.2 .63 .79 r
.61365 .16187 m
.61365 .24049 L
.6139 .24049 L
.6139 .16187 L
s
.678 .847 .902 r
.6139 .16187 m
.6139 .24069 L
.61419 .24069 L
.61419 .16187 L
F
.2 .63 .79 r
.6139 .16187 m
.6139 .24069 L
.61419 .24069 L
.61419 .16187 L
s
.678 .847 .902 r
.61419 .16187 m
.61419 .24093 L
.61442 .24093 L
.61442 .16187 L
F
.2 .63 .79 r
.61419 .16187 m
.61419 .24093 L
.61442 .24093 L
.61442 .16187 L
s
.678 .847 .902 r
.61442 .16187 m
.61442 .24113 L
.6147 .24113 L
.6147 .16187 L
F
.2 .63 .79 r
.61442 .16187 m
.61442 .24113 L
.6147 .24113 L
.6147 .16187 L
s
.678 .847 .902 r
.6147 .16187 m
.6147 .24131 L
.61485 .24131 L
.61485 .16187 L
F
.2 .63 .79 r
.6147 .16187 m
.6147 .24131 L
.61485 .24131 L
.61485 .16187 L
s
.678 .847 .902 r
.61485 .16187 m
.61485 .24166 L
.61525 .24166 L
.61525 .16187 L
F
.2 .63 .79 r
.61485 .16187 m
.61485 .24166 L
.61525 .24166 L
.61525 .16187 L
s
.678 .847 .902 r
.61525 .16187 m
.61525 .24172 L
.61564 .24172 L
.61564 .16187 L
F
.2 .63 .79 r
.61525 .16187 m
.61525 .24172 L
.61564 .24172 L
.61564 .16187 L
s
.678 .847 .902 r
.61564 .16187 m
.61564 .24209 L
.61585 .24209 L
.61585 .16187 L
F
.2 .63 .79 r
.61564 .16187 m
.61564 .24209 L
.61585 .24209 L
.61585 .16187 L
s
.678 .847 .902 r
.61585 .16187 m
.61585 .24235 L
.61617 .24235 L
.61617 .16187 L
F
.2 .63 .79 r
.61585 .16187 m
.61585 .24235 L
.61617 .24235 L
.61617 .16187 L
s
.678 .847 .902 r
.61617 .16187 m
.61617 .24259 L
.61661 .24259 L
.61661 .16187 L
F
.2 .63 .79 r
.61617 .16187 m
.61617 .24259 L
.61661 .24259 L
.61661 .16187 L
s
.678 .847 .902 r
.61661 .16187 m
.61661 .24283 L
.61679 .24283 L
.61679 .16187 L
F
.2 .63 .79 r
.61661 .16187 m
.61661 .24283 L
.61679 .24283 L
.61679 .16187 L
s
.678 .847 .902 r
.61679 .16187 m
.61679 .24304 L
.617 .24304 L
.617 .16187 L
F
.2 .63 .79 r
.61679 .16187 m
.61679 .24304 L
.617 .24304 L
.617 .16187 L
s
.678 .847 .902 r
.617 .16187 m
.617 .24325 L
.61743 .24325 L
.61743 .16187 L
F
.2 .63 .79 r
.617 .16187 m
.617 .24325 L
.61743 .24325 L
.61743 .16187 L
s
.678 .847 .902 r
.61743 .16187 m
.61743 .24346 L
.61778 .24346 L
.61778 .16187 L
F
.2 .63 .79 r
.61743 .16187 m
.61743 .24346 L
.61778 .24346 L
.61778 .16187 L
s
.678 .847 .902 r
.61778 .16187 m
.61778 .24371 L
.61794 .24371 L
.61794 .16187 L
F
.2 .63 .79 r
.61778 .16187 m
.61778 .24371 L
.61794 .24371 L
.61794 .16187 L
s
.678 .847 .902 r
.61794 .16187 m
.61794 .24383 L
.6184 .24383 L
.6184 .16187 L
F
.2 .63 .79 r
.61794 .16187 m
.61794 .24383 L
.6184 .24383 L
.6184 .16187 L
s
.678 .847 .902 r
.6184 .16187 m
.6184 .24449 L
.61887 .24449 L
.61887 .16187 L
F
.2 .63 .79 r
.6184 .16187 m
.6184 .24449 L
.61887 .24449 L
.61887 .16187 L
s
.678 .847 .902 r
.61887 .16187 m
.61887 .24458 L
.61903 .24458 L
.61903 .16187 L
F
.2 .63 .79 r
.61887 .16187 m
.61887 .24458 L
.61903 .24458 L
.61903 .16187 L
s
.678 .847 .902 r
.61903 .16187 m
.61903 .24475 L
.61921 .24475 L
.61921 .16187 L
F
.2 .63 .79 r
.61903 .16187 m
.61903 .24475 L
.61921 .24475 L
.61921 .16187 L
s
.678 .847 .902 r
.61921 .16187 m
.61921 .24491 L
.61966 .24491 L
.61966 .16187 L
F
.2 .63 .79 r
.61921 .16187 m
.61921 .24491 L
.61966 .24491 L
.61966 .16187 L
s
.678 .847 .902 r
.61966 .16187 m
.61966 .24514 L
.61986 .24514 L
.61986 .16187 L
F
.2 .63 .79 r
.61966 .16187 m
.61966 .24514 L
.61986 .24514 L
.61986 .16187 L
s
.678 .847 .902 r
.61986 .16187 m
.61986 .24553 L
.62026 .24553 L
.62026 .16187 L
F
.2 .63 .79 r
.61986 .16187 m
.61986 .24553 L
.62026 .24553 L
.62026 .16187 L
s
.678 .847 .902 r
.62026 .16187 m
.62026 .2457 L
.62053 .2457 L
.62053 .16187 L
F
.2 .63 .79 r
.62026 .16187 m
.62026 .2457 L
.62053 .2457 L
.62053 .16187 L
s
.678 .847 .902 r
.62053 .16187 m
.62053 .24591 L
.62072 .24591 L
.62072 .16187 L
F
.2 .63 .79 r
.62053 .16187 m
.62053 .24591 L
.62072 .24591 L
.62072 .16187 L
s
.678 .847 .902 r
.62072 .16187 m
.62072 .24598 L
.62117 .24598 L
.62117 .16187 L
F
.2 .63 .79 r
.62072 .16187 m
.62072 .24598 L
.62117 .24598 L
.62117 .16187 L
s
.678 .847 .902 r
.62117 .16187 m
.62117 .24643 L
.62142 .24643 L
.62142 .16187 L
F
.2 .63 .79 r
.62117 .16187 m
.62117 .24643 L
.62142 .24643 L
.62142 .16187 L
s
.678 .847 .902 r
.62142 .16187 m
.62142 .24654 L
.62161 .24654 L
.62161 .16187 L
F
.2 .63 .79 r
.62142 .16187 m
.62142 .24654 L
.62161 .24654 L
.62161 .16187 L
s
.678 .847 .902 r
.62161 .16187 m
.62161 .2468 L
.62202 .2468 L
.62202 .16187 L
F
.2 .63 .79 r
.62161 .16187 m
.62161 .2468 L
.62202 .2468 L
.62202 .16187 L
s
.678 .847 .902 r
.62202 .16187 m
.62202 .24726 L
.62246 .24726 L
.62246 .16187 L
F
.2 .63 .79 r
.62202 .16187 m
.62202 .24726 L
.62246 .24726 L
.62246 .16187 L
s
.678 .847 .902 r
.62246 .16187 m
.62246 .24753 L
.6228 .24753 L
.6228 .16187 L
F
.2 .63 .79 r
.62246 .16187 m
.62246 .24753 L
.6228 .24753 L
.6228 .16187 L
s
.678 .847 .902 r
.6228 .16187 m
.6228 .24765 L
.6231 .24765 L
.6231 .16187 L
F
.2 .63 .79 r
.6228 .16187 m
.6228 .24765 L
.6231 .24765 L
.6231 .16187 L
s
.678 .847 .902 r
.6231 .16187 m
.6231 .24779 L
.62344 .24779 L
.62344 .16187 L
F
.2 .63 .79 r
.6231 .16187 m
.6231 .24779 L
.62344 .24779 L
.62344 .16187 L
s
.678 .847 .902 r
.62344 .16187 m
.62344 .24809 L
.62371 .24809 L
.62371 .16187 L
F
.2 .63 .79 r
.62344 .16187 m
.62344 .24809 L
.62371 .24809 L
.62371 .16187 L
s
.678 .847 .902 r
.62371 .16187 m
.62371 .24839 L
.62411 .24839 L
.62411 .16187 L
F
.2 .63 .79 r
.62371 .16187 m
.62371 .24839 L
.62411 .24839 L
.62411 .16187 L
s
.678 .847 .902 r
.62411 .16187 m
.62411 .24875 L
.62437 .24875 L
.62437 .16187 L
F
.2 .63 .79 r
.62411 .16187 m
.62411 .24875 L
.62437 .24875 L
.62437 .16187 L
s
.678 .847 .902 r
.62437 .16187 m
.62437 .24881 L
.62465 .24881 L
.62465 .16187 L
F
.2 .63 .79 r
.62437 .16187 m
.62437 .24881 L
.62465 .24881 L
.62465 .16187 L
s
.678 .847 .902 r
.62465 .16187 m
.62465 .24916 L
.62498 .24916 L
.62498 .16187 L
F
.2 .63 .79 r
.62465 .16187 m
.62465 .24916 L
.62498 .24916 L
.62498 .16187 L
s
.678 .847 .902 r
.62498 .16187 m
.62498 .24927 L
.62517 .24927 L
.62517 .16187 L
F
.2 .63 .79 r
.62498 .16187 m
.62498 .24927 L
.62517 .24927 L
.62517 .16187 L
s
.678 .847 .902 r
.62517 .16187 m
.62517 .2495 L
.62542 .2495 L
.62542 .16187 L
F
.2 .63 .79 r
.62517 .16187 m
.62517 .2495 L
.62542 .2495 L
.62542 .16187 L
s
.678 .847 .902 r
.62542 .16187 m
.62542 .2496 L
.62573 .2496 L
.62573 .16187 L
F
.2 .63 .79 r
.62542 .16187 m
.62542 .2496 L
.62573 .2496 L
.62573 .16187 L
s
.678 .847 .902 r
.62573 .16187 m
.62573 .25002 L
.62608 .25002 L
.62608 .16187 L
F
.2 .63 .79 r
.62573 .16187 m
.62573 .25002 L
.62608 .25002 L
.62608 .16187 L
s
.678 .847 .902 r
.62608 .16187 m
.62608 .25019 L
.62627 .25019 L
.62627 .16187 L
F
.2 .63 .79 r
.62608 .16187 m
.62608 .25019 L
.62627 .25019 L
.62627 .16187 L
s
.678 .847 .902 r
.62627 .16187 m
.62627 .25037 L
.62648 .25037 L
.62648 .16187 L
F
.2 .63 .79 r
.62627 .16187 m
.62627 .25037 L
.62648 .25037 L
.62648 .16187 L
s
.678 .847 .902 r
.62648 .16187 m
.62648 .2506 L
.62684 .2506 L
.62684 .16187 L
F
.2 .63 .79 r
.62648 .16187 m
.62648 .2506 L
.62684 .2506 L
.62684 .16187 L
s
.678 .847 .902 r
.62684 .16187 m
.62684 .25082 L
.62713 .25082 L
.62713 .16187 L
F
.2 .63 .79 r
.62684 .16187 m
.62684 .25082 L
.62713 .25082 L
.62713 .16187 L
s
.678 .847 .902 r
.62713 .16187 m
.62713 .25109 L
.62741 .25109 L
.62741 .16187 L
F
.2 .63 .79 r
.62713 .16187 m
.62713 .25109 L
.62741 .25109 L
.62741 .16187 L
s
.678 .847 .902 r
.62741 .16187 m
.62741 .25118 L
.62784 .25118 L
.62784 .16187 L
F
.2 .63 .79 r
.62741 .16187 m
.62741 .25118 L
.62784 .25118 L
.62784 .16187 L
s
.678 .847 .902 r
.62784 .16187 m
.62784 .25169 L
.62816 .25169 L
.62816 .16187 L
F
.2 .63 .79 r
.62784 .16187 m
.62784 .25169 L
.62816 .25169 L
.62816 .16187 L
s
.678 .847 .902 r
.62816 .16187 m
.62816 .25184 L
.6285 .25184 L
.6285 .16187 L
F
.2 .63 .79 r
.62816 .16187 m
.62816 .25184 L
.6285 .25184 L
.6285 .16187 L
s
.678 .847 .902 r
.6285 .16187 m
.6285 .25213 L
.62867 .25213 L
.62867 .16187 L
F
.2 .63 .79 r
.6285 .16187 m
.6285 .25213 L
.62867 .25213 L
.62867 .16187 L
s
.678 .847 .902 r
.62867 .16187 m
.62867 .25234 L
.62907 .25234 L
.62907 .16187 L
F
.2 .63 .79 r
.62867 .16187 m
.62867 .25234 L
.62907 .25234 L
.62907 .16187 L
s
.678 .847 .902 r
.62907 .16187 m
.62907 .25252 L
.62947 .25252 L
.62947 .16187 L
F
.2 .63 .79 r
.62907 .16187 m
.62907 .25252 L
.62947 .25252 L
.62947 .16187 L
s
.678 .847 .902 r
.62947 .16187 m
.62947 .2529 L
.62986 .2529 L
.62986 .16187 L
F
.2 .63 .79 r
.62947 .16187 m
.62947 .2529 L
.62986 .2529 L
.62986 .16187 L
s
.678 .847 .902 r
.62986 .16187 m
.62986 .25307 L
.63017 .25307 L
.63017 .16187 L
F
.2 .63 .79 r
.62986 .16187 m
.62986 .25307 L
.63017 .25307 L
.63017 .16187 L
s
.678 .847 .902 r
.63017 .16187 m
.63017 .25336 L
.63043 .25336 L
.63043 .16187 L
F
.2 .63 .79 r
.63017 .16187 m
.63017 .25336 L
.63043 .25336 L
.63043 .16187 L
s
.678 .847 .902 r
.63043 .16187 m
.63043 .25354 L
.63063 .25354 L
.63063 .16187 L
F
.2 .63 .79 r
.63043 .16187 m
.63043 .25354 L
.63063 .25354 L
.63063 .16187 L
s
.678 .847 .902 r
.63063 .16187 m
.63063 .25372 L
.6309 .25372 L
.6309 .16187 L
F
.2 .63 .79 r
.63063 .16187 m
.63063 .25372 L
.6309 .25372 L
.6309 .16187 L
s
.678 .847 .902 r
.6309 .16187 m
.6309 .25408 L
.63131 .25408 L
.63131 .16187 L
F
.2 .63 .79 r
.6309 .16187 m
.6309 .25408 L
.63131 .25408 L
.63131 .16187 L
s
.678 .847 .902 r
.63131 .16187 m
.63131 .25433 L
.63179 .25433 L
.63179 .16187 L
F
.2 .63 .79 r
.63131 .16187 m
.63131 .25433 L
.63179 .25433 L
.63179 .16187 L
s
.678 .847 .902 r
.63179 .16187 m
.63179 .25492 L
.63221 .25492 L
.63221 .16187 L
F
.2 .63 .79 r
.63179 .16187 m
.63179 .25492 L
.63221 .25492 L
.63221 .16187 L
s
.678 .847 .902 r
.63221 .16187 m
.63221 .25511 L
.63264 .25511 L
.63264 .16187 L
F
.2 .63 .79 r
.63221 .16187 m
.63221 .25511 L
.63264 .25511 L
.63264 .16187 L
s
.678 .847 .902 r
.63264 .16187 m
.63264 .25539 L
.63301 .25539 L
.63301 .16187 L
F
.2 .63 .79 r
.63264 .16187 m
.63264 .25539 L
.63301 .25539 L
.63301 .16187 L
s
.678 .847 .902 r
.63301 .16187 m
.63301 .25577 L
.63339 .25577 L
.63339 .16187 L
F
.2 .63 .79 r
.63301 .16187 m
.63301 .25577 L
.63339 .25577 L
.63339 .16187 L
s
.678 .847 .902 r
.63339 .16187 m
.63339 .25604 L
.63364 .25604 L
.63364 .16187 L
F
.2 .63 .79 r
.63339 .16187 m
.63339 .25604 L
.63364 .25604 L
.63364 .16187 L
s
.678 .847 .902 r
.63364 .16187 m
.63364 .25621 L
.63387 .25621 L
.63387 .16187 L
F
.2 .63 .79 r
.63364 .16187 m
.63364 .25621 L
.63387 .25621 L
.63387 .16187 L
s
.678 .847 .902 r
.63387 .16187 m
.63387 .25645 L
.6342 .25645 L
.6342 .16187 L
F
.2 .63 .79 r
.63387 .16187 m
.63387 .25645 L
.6342 .25645 L
.6342 .16187 L
s
.678 .847 .902 r
.6342 .16187 m
.6342 .2565 L
.63452 .2565 L
.63452 .16187 L
F
.2 .63 .79 r
.6342 .16187 m
.6342 .2565 L
.63452 .2565 L
.63452 .16187 L
s
.678 .847 .902 r
.63452 .16187 m
.63452 .25683 L
.6349 .25683 L
.6349 .16187 L
F
.2 .63 .79 r
.63452 .16187 m
.63452 .25683 L
.6349 .25683 L
.6349 .16187 L
s
.678 .847 .902 r
.6349 .16187 m
.6349 .25717 L
.63533 .25717 L
.63533 .16187 L
F
.2 .63 .79 r
.6349 .16187 m
.6349 .25717 L
.63533 .25717 L
.63533 .16187 L
s
.678 .847 .902 r
.63533 .16187 m
.63533 .2574 L
.63553 .2574 L
.63553 .16187 L
F
.2 .63 .79 r
.63533 .16187 m
.63533 .2574 L
.63553 .2574 L
.63553 .16187 L
s
.678 .847 .902 r
.63553 .16187 m
.63553 .25783 L
.63591 .25783 L
.63591 .16187 L
F
.2 .63 .79 r
.63553 .16187 m
.63553 .25783 L
.63591 .25783 L
.63591 .16187 L
s
.678 .847 .902 r
.63591 .16187 m
.63591 .25793 L
.63612 .25793 L
.63612 .16187 L
F
.2 .63 .79 r
.63591 .16187 m
.63591 .25793 L
.63612 .25793 L
.63612 .16187 L
s
.678 .847 .902 r
.63612 .16187 m
.63612 .25819 L
.63636 .25819 L
.63636 .16187 L
F
.2 .63 .79 r
.63612 .16187 m
.63612 .25819 L
.63636 .25819 L
.63636 .16187 L
s
.678 .847 .902 r
.63636 .16187 m
.63636 .25822 L
.63654 .25822 L
.63654 .16187 L
F
.2 .63 .79 r
.63636 .16187 m
.63636 .25822 L
.63654 .25822 L
.63654 .16187 L
s
.678 .847 .902 r
.63654 .16187 m
.63654 .25845 L
.63701 .25845 L
.63701 .16187 L
F
.2 .63 .79 r
.63654 .16187 m
.63654 .25845 L
.63701 .25845 L
.63701 .16187 L
s
.678 .847 .902 r
.63701 .16187 m
.63701 .25878 L
.63731 .25878 L
.63731 .16187 L
F
.2 .63 .79 r
.63701 .16187 m
.63701 .25878 L
.63731 .25878 L
.63731 .16187 L
s
.678 .847 .902 r
.63731 .16187 m
.63731 .2591 L
.63765 .2591 L
.63765 .16187 L
F
.2 .63 .79 r
.63731 .16187 m
.63731 .2591 L
.63765 .2591 L
.63765 .16187 L
s
.678 .847 .902 r
.63765 .16187 m
.63765 .25926 L
.638 .25926 L
.638 .16187 L
F
.2 .63 .79 r
.63765 .16187 m
.63765 .25926 L
.638 .25926 L
.638 .16187 L
s
.678 .847 .902 r
.638 .16187 m
.638 .25954 L
.63837 .25954 L
.63837 .16187 L
F
.2 .63 .79 r
.638 .16187 m
.638 .25954 L
.63837 .25954 L
.63837 .16187 L
s
.678 .847 .902 r
.63837 .16187 m
.63837 .25982 L
.63862 .25982 L
.63862 .16187 L
F
.2 .63 .79 r
.63837 .16187 m
.63837 .25982 L
.63862 .25982 L
.63862 .16187 L
s
.678 .847 .902 r
.63862 .16187 m
.63862 .26005 L
.63884 .26005 L
.63884 .16187 L
F
.2 .63 .79 r
.63862 .16187 m
.63862 .26005 L
.63884 .26005 L
.63884 .16187 L
s
.678 .847 .902 r
.63884 .16187 m
.63884 .26035 L
.63927 .26035 L
.63927 .16187 L
F
.2 .63 .79 r
.63884 .16187 m
.63884 .26035 L
.63927 .26035 L
.63927 .16187 L
s
.678 .847 .902 r
.63927 .16187 m
.63927 .26076 L
.63965 .26076 L
.63965 .16187 L
F
.2 .63 .79 r
.63927 .16187 m
.63927 .26076 L
.63965 .26076 L
.63965 .16187 L
s
.678 .847 .902 r
.63965 .16187 m
.63965 .26084 L
.63997 .26084 L
.63997 .16187 L
F
.2 .63 .79 r
.63965 .16187 m
.63965 .26084 L
.63997 .26084 L
.63997 .16187 L
s
.678 .847 .902 r
.63997 .16187 m
.63997 .26124 L
.64025 .26124 L
.64025 .16187 L
F
.2 .63 .79 r
.63997 .16187 m
.63997 .26124 L
.64025 .26124 L
.64025 .16187 L
s
.678 .847 .902 r
.64025 .16187 m
.64025 .26132 L
.64047 .26132 L
.64047 .16187 L
F
.2 .63 .79 r
.64025 .16187 m
.64025 .26132 L
.64047 .26132 L
.64047 .16187 L
s
.678 .847 .902 r
.64047 .16187 m
.64047 .26149 L
.64095 .26149 L
.64095 .16187 L
F
.2 .63 .79 r
.64047 .16187 m
.64047 .26149 L
.64095 .26149 L
.64095 .16187 L
s
.678 .847 .902 r
.64095 .16187 m
.64095 .26189 L
.64117 .26189 L
.64117 .16187 L
F
.2 .63 .79 r
.64095 .16187 m
.64095 .26189 L
.64117 .26189 L
.64117 .16187 L
s
.678 .847 .902 r
.64117 .16187 m
.64117 .26217 L
.64136 .26217 L
.64136 .16187 L
F
.2 .63 .79 r
.64117 .16187 m
.64117 .26217 L
.64136 .26217 L
.64136 .16187 L
s
.678 .847 .902 r
.64136 .16187 m
.64136 .26227 L
.64175 .26227 L
.64175 .16187 L
F
.2 .63 .79 r
.64136 .16187 m
.64136 .26227 L
.64175 .26227 L
.64175 .16187 L
s
.678 .847 .902 r
.64175 .16187 m
.64175 .26276 L
.64206 .26276 L
.64206 .16187 L
F
.2 .63 .79 r
.64175 .16187 m
.64175 .26276 L
.64206 .26276 L
.64206 .16187 L
s
.678 .847 .902 r
.64206 .16187 m
.64206 .26298 L
.64239 .26298 L
.64239 .16187 L
F
.2 .63 .79 r
.64206 .16187 m
.64206 .26298 L
.64239 .26298 L
.64239 .16187 L
s
.678 .847 .902 r
.64239 .16187 m
.64239 .26313 L
.64265 .26313 L
.64265 .16187 L
F
.2 .63 .79 r
.64239 .16187 m
.64239 .26313 L
.64265 .26313 L
.64265 .16187 L
s
.678 .847 .902 r
.64265 .16187 m
.64265 .26326 L
.64298 .26326 L
.64298 .16187 L
F
.2 .63 .79 r
.64265 .16187 m
.64265 .26326 L
.64298 .26326 L
.64298 .16187 L
s
.678 .847 .902 r
.64298 .16187 m
.64298 .26352 L
.64341 .26352 L
.64341 .16187 L
F
.2 .63 .79 r
.64298 .16187 m
.64298 .26352 L
.64341 .26352 L
.64341 .16187 L
s
.678 .847 .902 r
.64341 .16187 m
.64341 .26392 L
.64367 .26392 L
.64367 .16187 L
F
.2 .63 .79 r
.64341 .16187 m
.64341 .26392 L
.64367 .26392 L
.64367 .16187 L
s
.678 .847 .902 r
.64367 .16187 m
.64367 .26413 L
.64384 .26413 L
.64384 .16187 L
F
.2 .63 .79 r
.64367 .16187 m
.64367 .26413 L
.64384 .26413 L
.64384 .16187 L
s
.678 .847 .902 r
.64384 .16187 m
.64384 .26419 L
.64415 .26419 L
.64415 .16187 L
F
.2 .63 .79 r
.64384 .16187 m
.64384 .26419 L
.64415 .26419 L
.64415 .16187 L
s
.678 .847 .902 r
.64415 .16187 m
.64415 .26471 L
.64459 .26471 L
.64459 .16187 L
F
.2 .63 .79 r
.64415 .16187 m
.64415 .26471 L
.64459 .26471 L
.64459 .16187 L
s
.678 .847 .902 r
.64459 .16187 m
.64459 .26485 L
.64503 .26485 L
.64503 .16187 L
F
.2 .63 .79 r
.64459 .16187 m
.64459 .26485 L
.64503 .26485 L
.64503 .16187 L
s
.678 .847 .902 r
.64503 .16187 m
.64503 .26517 L
.64536 .26517 L
.64536 .16187 L
F
.2 .63 .79 r
.64503 .16187 m
.64503 .26517 L
.64536 .26517 L
.64536 .16187 L
s
.678 .847 .902 r
.64536 .16187 m
.64536 .26575 L
.64581 .26575 L
.64581 .16187 L
F
.2 .63 .79 r
.64536 .16187 m
.64536 .26575 L
.64581 .26575 L
.64581 .16187 L
s
.678 .847 .902 r
.64581 .16187 m
.64581 .2659 L
.64603 .2659 L
.64603 .16187 L
F
.2 .63 .79 r
.64581 .16187 m
.64581 .2659 L
.64603 .2659 L
.64603 .16187 L
s
.678 .847 .902 r
.64603 .16187 m
.64603 .26599 L
.64638 .26599 L
.64638 .16187 L
F
.2 .63 .79 r
.64603 .16187 m
.64603 .26599 L
.64638 .26599 L
.64638 .16187 L
s
.678 .847 .902 r
.64638 .16187 m
.64638 .26641 L
.64664 .26641 L
.64664 .16187 L
F
.2 .63 .79 r
.64638 .16187 m
.64638 .26641 L
.64664 .26641 L
.64664 .16187 L
s
.678 .847 .902 r
.64664 .16187 m
.64664 .2665 L
.64679 .2665 L
.64679 .16187 L
F
.2 .63 .79 r
.64664 .16187 m
.64664 .2665 L
.64679 .2665 L
.64679 .16187 L
s
.678 .847 .902 r
.64679 .16187 m
.64679 .26683 L
.64713 .26683 L
.64713 .16187 L
F
.2 .63 .79 r
.64679 .16187 m
.64679 .26683 L
.64713 .26683 L
.64713 .16187 L
s
.678 .847 .902 r
.64713 .16187 m
.64713 .26686 L
.6473 .26686 L
.6473 .16187 L
F
.2 .63 .79 r
.64713 .16187 m
.64713 .26686 L
.6473 .26686 L
.6473 .16187 L
s
.678 .847 .902 r
.6473 .16187 m
.6473 .26703 L
.64778 .26703 L
.64778 .16187 L
F
.2 .63 .79 r
.6473 .16187 m
.6473 .26703 L
.64778 .26703 L
.64778 .16187 L
s
.678 .847 .902 r
.64778 .16187 m
.64778 .26751 L
.6482 .26751 L
.6482 .16187 L
F
.2 .63 .79 r
.64778 .16187 m
.64778 .26751 L
.6482 .26751 L
.6482 .16187 L
s
.678 .847 .902 r
.6482 .16187 m
.6482 .26797 L
.64855 .26797 L
.64855 .16187 L
F
.2 .63 .79 r
.6482 .16187 m
.6482 .26797 L
.64855 .26797 L
.64855 .16187 L
s
.678 .847 .902 r
.64855 .16187 m
.64855 .26835 L
.649 .26835 L
.649 .16187 L
F
.2 .63 .79 r
.64855 .16187 m
.64855 .26835 L
.649 .26835 L
.649 .16187 L
s
.678 .847 .902 r
.649 .16187 m
.649 .26846 L
.64943 .26846 L
.64943 .16187 L
F
.2 .63 .79 r
.649 .16187 m
.649 .26846 L
.64943 .26846 L
.64943 .16187 L
s
.678 .847 .902 r
.64943 .16187 m
.64943 .26874 L
.64961 .26874 L
.64961 .16187 L
F
.2 .63 .79 r
.64943 .16187 m
.64943 .26874 L
.64961 .26874 L
.64961 .16187 L
s
.678 .847 .902 r
.64961 .16187 m
.64961 .269 L
.6498 .269 L
.6498 .16187 L
F
.2 .63 .79 r
.64961 .16187 m
.64961 .269 L
.6498 .269 L
.6498 .16187 L
s
.678 .847 .902 r
.6498 .16187 m
.6498 .26904 L
.65007 .26904 L
.65007 .16187 L
F
.2 .63 .79 r
.6498 .16187 m
.6498 .26904 L
.65007 .26904 L
.65007 .16187 L
s
.678 .847 .902 r
.65007 .16187 m
.65007 .26944 L
.65038 .26944 L
.65038 .16187 L
F
.2 .63 .79 r
.65007 .16187 m
.65007 .26944 L
.65038 .26944 L
.65038 .16187 L
s
.678 .847 .902 r
.65038 .16187 m
.65038 .26951 L
.65072 .26951 L
.65072 .16187 L
F
.2 .63 .79 r
.65038 .16187 m
.65038 .26951 L
.65072 .26951 L
.65072 .16187 L
s
.678 .847 .902 r
.65072 .16187 m
.65072 .26995 L
.65098 .26995 L
.65098 .16187 L
F
.2 .63 .79 r
.65072 .16187 m
.65072 .26995 L
.65098 .26995 L
.65098 .16187 L
s
.678 .847 .902 r
.65098 .16187 m
.65098 .27007 L
.65113 .27007 L
.65113 .16187 L
F
.2 .63 .79 r
.65098 .16187 m
.65098 .27007 L
.65113 .27007 L
.65113 .16187 L
s
.678 .847 .902 r
.65113 .16187 m
.65113 .27016 L
.65143 .27016 L
.65143 .16187 L
F
.2 .63 .79 r
.65113 .16187 m
.65113 .27016 L
.65143 .27016 L
.65143 .16187 L
s
.678 .847 .902 r
.65143 .16187 m
.65143 .27034 L
.65161 .27034 L
.65161 .16187 L
F
.2 .63 .79 r
.65143 .16187 m
.65143 .27034 L
.65161 .27034 L
.65161 .16187 L
s
.678 .847 .902 r
.65161 .16187 m
.65161 .27052 L
.65191 .27052 L
.65191 .16187 L
F
.2 .63 .79 r
.65161 .16187 m
.65161 .27052 L
.65191 .27052 L
.65191 .16187 L
s
.678 .847 .902 r
.65191 .16187 m
.65191 .27084 L
.65212 .27084 L
.65212 .16187 L
F
.2 .63 .79 r
.65191 .16187 m
.65191 .27084 L
.65212 .27084 L
.65212 .16187 L
s
.678 .847 .902 r
.65212 .16187 m
.65212 .27097 L
.65257 .27097 L
.65257 .16187 L
F
.2 .63 .79 r
.65212 .16187 m
.65212 .27097 L
.65257 .27097 L
.65257 .16187 L
s
.678 .847 .902 r
.65257 .16187 m
.65257 .2713 L
.6528 .2713 L
.6528 .16187 L
F
.2 .63 .79 r
.65257 .16187 m
.65257 .2713 L
.6528 .2713 L
.6528 .16187 L
s
.678 .847 .902 r
.6528 .16187 m
.6528 .27154 L
.65303 .27154 L
.65303 .16187 L
F
.2 .63 .79 r
.6528 .16187 m
.6528 .27154 L
.65303 .27154 L
.65303 .16187 L
s
.678 .847 .902 r
.65303 .16187 m
.65303 .27179 L
.65338 .27179 L
.65338 .16187 L
F
.2 .63 .79 r
.65303 .16187 m
.65303 .27179 L
.65338 .27179 L
.65338 .16187 L
s
.678 .847 .902 r
.65338 .16187 m
.65338 .27203 L
.65372 .27203 L
.65372 .16187 L
F
.2 .63 .79 r
.65338 .16187 m
.65338 .27203 L
.65372 .27203 L
.65372 .16187 L
s
.678 .847 .902 r
.65372 .16187 m
.65372 .27233 L
.65394 .27233 L
.65394 .16187 L
F
.2 .63 .79 r
.65372 .16187 m
.65372 .27233 L
.65394 .27233 L
.65394 .16187 L
s
.678 .847 .902 r
.65394 .16187 m
.65394 .27255 L
.65433 .27255 L
.65433 .16187 L
F
.2 .63 .79 r
.65394 .16187 m
.65394 .27255 L
.65433 .27255 L
.65433 .16187 L
s
.678 .847 .902 r
.65433 .16187 m
.65433 .27282 L
.65466 .27282 L
.65466 .16187 L
F
.2 .63 .79 r
.65433 .16187 m
.65433 .27282 L
.65466 .27282 L
.65466 .16187 L
s
.678 .847 .902 r
.65466 .16187 m
.65466 .27305 L
.65501 .27305 L
.65501 .16187 L
F
.2 .63 .79 r
.65466 .16187 m
.65466 .27305 L
.65501 .27305 L
.65501 .16187 L
s
.678 .847 .902 r
.65501 .16187 m
.65501 .27333 L
.6553 .27333 L
.6553 .16187 L
F
.2 .63 .79 r
.65501 .16187 m
.65501 .27333 L
.6553 .27333 L
.6553 .16187 L
s
.678 .847 .902 r
.6553 .16187 m
.6553 .27359 L
.65548 .27359 L
.65548 .16187 L
F
.2 .63 .79 r
.6553 .16187 m
.6553 .27359 L
.65548 .27359 L
.65548 .16187 L
s
.678 .847 .902 r
.65548 .16187 m
.65548 .2738 L
.65586 .2738 L
.65586 .16187 L
F
.2 .63 .79 r
.65548 .16187 m
.65548 .2738 L
.65586 .2738 L
.65586 .16187 L
s
.678 .847 .902 r
.65586 .16187 m
.65586 .27428 L
.65628 .27428 L
.65628 .16187 L
F
.2 .63 .79 r
.65586 .16187 m
.65586 .27428 L
.65628 .27428 L
.65628 .16187 L
s
.678 .847 .902 r
.65628 .16187 m
.65628 .27432 L
.65653 .27432 L
.65653 .16187 L
F
.2 .63 .79 r
.65628 .16187 m
.65628 .27432 L
.65653 .27432 L
.65653 .16187 L
s
.678 .847 .902 r
.65653 .16187 m
.65653 .27478 L
.65702 .27478 L
.65702 .16187 L
F
.2 .63 .79 r
.65653 .16187 m
.65653 .27478 L
.65702 .27478 L
.65702 .16187 L
s
.678 .847 .902 r
.65702 .16187 m
.65702 .27498 L
.65727 .27498 L
.65727 .16187 L
F
.2 .63 .79 r
.65702 .16187 m
.65702 .27498 L
.65727 .27498 L
.65727 .16187 L
s
.678 .847 .902 r
.65727 .16187 m
.65727 .27515 L
.65752 .27515 L
.65752 .16187 L
F
.2 .63 .79 r
.65727 .16187 m
.65727 .27515 L
.65752 .27515 L
.65752 .16187 L
s
.678 .847 .902 r
.65752 .16187 m
.65752 .27533 L
.65792 .27533 L
.65792 .16187 L
F
.2 .63 .79 r
.65752 .16187 m
.65752 .27533 L
.65792 .27533 L
.65792 .16187 L
s
.678 .847 .902 r
.65792 .16187 m
.65792 .2759 L
.6583 .2759 L
.6583 .16187 L
F
.2 .63 .79 r
.65792 .16187 m
.65792 .2759 L
.6583 .2759 L
.6583 .16187 L
s
.678 .847 .902 r
.6583 .16187 m
.6583 .27608 L
.65855 .27608 L
.65855 .16187 L
F
.2 .63 .79 r
.6583 .16187 m
.6583 .27608 L
.65855 .27608 L
.65855 .16187 L
s
.678 .847 .902 r
.65855 .16187 m
.65855 .2765 L
.659 .2765 L
.659 .16187 L
F
.2 .63 .79 r
.65855 .16187 m
.65855 .2765 L
.659 .2765 L
.659 .16187 L
s
.678 .847 .902 r
.659 .16187 m
.659 .27683 L
.65937 .27683 L
.65937 .16187 L
F
.2 .63 .79 r
.659 .16187 m
.659 .27683 L
.65937 .27683 L
.65937 .16187 L
s
.678 .847 .902 r
.65937 .16187 m
.65937 .27696 L
.65959 .27696 L
.65959 .16187 L
F
.2 .63 .79 r
.65937 .16187 m
.65937 .27696 L
.65959 .27696 L
.65959 .16187 L
s
.678 .847 .902 r
.65959 .16187 m
.65959 .27717 L
.65979 .27717 L
.65979 .16187 L
F
.2 .63 .79 r
.65959 .16187 m
.65959 .27717 L
.65979 .27717 L
.65979 .16187 L
s
.678 .847 .902 r
.65979 .16187 m
.65979 .27746 L
.66027 .27746 L
.66027 .16187 L
F
.2 .63 .79 r
.65979 .16187 m
.65979 .27746 L
.66027 .27746 L
.66027 .16187 L
s
.678 .847 .902 r
.66027 .16187 m
.66027 .27778 L
.66056 .27778 L
.66056 .16187 L
F
.2 .63 .79 r
.66027 .16187 m
.66027 .27778 L
.66056 .27778 L
.66056 .16187 L
s
.678 .847 .902 r
.66056 .16187 m
.66056 .2779 L
.66104 .2779 L
.66104 .16187 L
F
.2 .63 .79 r
.66056 .16187 m
.66056 .2779 L
.66104 .2779 L
.66104 .16187 L
s
.678 .847 .902 r
.66104 .16187 m
.66104 .27833 L
.66138 .27833 L
.66138 .16187 L
F
.2 .63 .79 r
.66104 .16187 m
.66104 .27833 L
.66138 .27833 L
.66138 .16187 L
s
.678 .847 .902 r
.66138 .16187 m
.66138 .27858 L
.66167 .27858 L
.66167 .16187 L
F
.2 .63 .79 r
.66138 .16187 m
.66138 .27858 L
.66167 .27858 L
.66167 .16187 L
s
.678 .847 .902 r
.66167 .16187 m
.66167 .27876 L
.66189 .27876 L
.66189 .16187 L
F
.2 .63 .79 r
.66167 .16187 m
.66167 .27876 L
.66189 .27876 L
.66189 .16187 L
s
.678 .847 .902 r
.66189 .16187 m
.66189 .27906 L
.66213 .27906 L
.66213 .16187 L
F
.2 .63 .79 r
.66189 .16187 m
.66189 .27906 L
.66213 .27906 L
.66213 .16187 L
s
.678 .847 .902 r
.66213 .16187 m
.66213 .27925 L
.66229 .27925 L
.66229 .16187 L
F
.2 .63 .79 r
.66213 .16187 m
.66213 .27925 L
.66229 .27925 L
.66229 .16187 L
s
.678 .847 .902 r
.66229 .16187 m
.66229 .27928 L
.66271 .27928 L
.66271 .16187 L
F
.2 .63 .79 r
.66229 .16187 m
.66229 .27928 L
.66271 .27928 L
.66271 .16187 L
s
.678 .847 .902 r
.66271 .16187 m
.66271 .27989 L
.66314 .27989 L
.66314 .16187 L
F
.2 .63 .79 r
.66271 .16187 m
.66271 .27989 L
.66314 .27989 L
.66314 .16187 L
s
.678 .847 .902 r
.66314 .16187 m
.66314 .27997 L
.66334 .27997 L
.66334 .16187 L
F
.2 .63 .79 r
.66314 .16187 m
.66314 .27997 L
.66334 .27997 L
.66334 .16187 L
s
.678 .847 .902 r
.66334 .16187 m
.66334 .28023 L
.66362 .28023 L
.66362 .16187 L
F
.2 .63 .79 r
.66334 .16187 m
.66334 .28023 L
.66362 .28023 L
.66362 .16187 L
s
.678 .847 .902 r
.66362 .16187 m
.66362 .28037 L
.66377 .28037 L
.66377 .16187 L
F
.2 .63 .79 r
.66362 .16187 m
.66362 .28037 L
.66377 .28037 L
.66377 .16187 L
s
.678 .847 .902 r
.66377 .16187 m
.66377 .28067 L
.66409 .28067 L
.66409 .16187 L
F
.2 .63 .79 r
.66377 .16187 m
.66377 .28067 L
.66409 .28067 L
.66409 .16187 L
s
.678 .847 .902 r
.66409 .16187 m
.66409 .28082 L
.6643 .28082 L
.6643 .16187 L
F
.2 .63 .79 r
.66409 .16187 m
.66409 .28082 L
.6643 .28082 L
.6643 .16187 L
s
.678 .847 .902 r
.6643 .16187 m
.6643 .28094 L
.66447 .28094 L
.66447 .16187 L
F
.2 .63 .79 r
.6643 .16187 m
.6643 .28094 L
.66447 .28094 L
.66447 .16187 L
s
.678 .847 .902 r
.66447 .16187 m
.66447 .28138 L
.66487 .28138 L
.66487 .16187 L
F
.2 .63 .79 r
.66447 .16187 m
.66447 .28138 L
.66487 .28138 L
.66487 .16187 L
s
.678 .847 .902 r
.66487 .16187 m
.66487 .28163 L
.66528 .28163 L
.66528 .16187 L
F
.2 .63 .79 r
.66487 .16187 m
.66487 .28163 L
.66528 .28163 L
.66528 .16187 L
s
.678 .847 .902 r
.66528 .16187 m
.66528 .28189 L
.6656 .28189 L
.6656 .16187 L
F
.2 .63 .79 r
.66528 .16187 m
.66528 .28189 L
.6656 .28189 L
.6656 .16187 L
s
.678 .847 .902 r
.6656 .16187 m
.6656 .2822 L
.66601 .2822 L
.66601 .16187 L
F
.2 .63 .79 r
.6656 .16187 m
.6656 .2822 L
.66601 .2822 L
.66601 .16187 L
s
.678 .847 .902 r
.66601 .16187 m
.66601 .28237 L
.66646 .28237 L
.66646 .16187 L
F
.2 .63 .79 r
.66601 .16187 m
.66601 .28237 L
.66646 .28237 L
.66646 .16187 L
s
.678 .847 .902 r
.66646 .16187 m
.66646 .28284 L
.66665 .28284 L
.66665 .16187 L
F
.2 .63 .79 r
.66646 .16187 m
.66646 .28284 L
.66665 .28284 L
.66665 .16187 L
s
.678 .847 .902 r
.66665 .16187 m
.66665 .28307 L
.66689 .28307 L
.66689 .16187 L
F
.2 .63 .79 r
.66665 .16187 m
.66665 .28307 L
.66689 .28307 L
.66689 .16187 L
s
.678 .847 .902 r
.66689 .16187 m
.66689 .28328 L
.66725 .28328 L
.66725 .16187 L
F
.2 .63 .79 r
.66689 .16187 m
.66689 .28328 L
.66725 .28328 L
.66725 .16187 L
s
.678 .847 .902 r
.66725 .16187 m
.66725 .28353 L
.66771 .28353 L
.66771 .16187 L
F
.2 .63 .79 r
.66725 .16187 m
.66725 .28353 L
.66771 .28353 L
.66771 .16187 L
s
.678 .847 .902 r
.66771 .16187 m
.66771 .28407 L
.6681 .28407 L
.6681 .16187 L
F
.2 .63 .79 r
.66771 .16187 m
.66771 .28407 L
.6681 .28407 L
.6681 .16187 L
s
.678 .847 .902 r
.6681 .16187 m
.6681 .28425 L
.66835 .28425 L
.66835 .16187 L
F
.2 .63 .79 r
.6681 .16187 m
.6681 .28425 L
.66835 .28425 L
.66835 .16187 L
s
.678 .847 .902 r
.66835 .16187 m
.66835 .28435 L
.66852 .28435 L
.66852 .16187 L
F
.2 .63 .79 r
.66835 .16187 m
.66835 .28435 L
.66852 .28435 L
.66852 .16187 L
s
.678 .847 .902 r
.66852 .16187 m
.66852 .28446 L
.66884 .28446 L
.66884 .16187 L
F
.2 .63 .79 r
.66852 .16187 m
.66852 .28446 L
.66884 .28446 L
.66884 .16187 L
s
.678 .847 .902 r
.66884 .16187 m
.66884 .28494 L
.66916 .28494 L
.66916 .16187 L
F
.2 .63 .79 r
.66884 .16187 m
.66884 .28494 L
.66916 .28494 L
.66916 .16187 L
s
.678 .847 .902 r
.66916 .16187 m
.66916 .28499 L
.66932 .28499 L
.66932 .16187 L
F
.2 .63 .79 r
.66916 .16187 m
.66916 .28499 L
.66932 .28499 L
.66932 .16187 L
s
.678 .847 .902 r
.66932 .16187 m
.66932 .28516 L
.66947 .28516 L
.66947 .16187 L
F
.2 .63 .79 r
.66932 .16187 m
.66932 .28516 L
.66947 .28516 L
.66947 .16187 L
s
.678 .847 .902 r
.66947 .16187 m
.66947 .28525 L
.66987 .28525 L
.66987 .16187 L
F
.2 .63 .79 r
.66947 .16187 m
.66947 .28525 L
.66987 .28525 L
.66987 .16187 L
s
.678 .847 .902 r
.66987 .16187 m
.66987 .28559 L
.67025 .28559 L
.67025 .16187 L
F
.2 .63 .79 r
.66987 .16187 m
.66987 .28559 L
.67025 .28559 L
.67025 .16187 L
s
.678 .847 .902 r
.67025 .16187 m
.67025 .28591 L
.6707 .28591 L
.6707 .16187 L
F
.2 .63 .79 r
.67025 .16187 m
.67025 .28591 L
.6707 .28591 L
.6707 .16187 L
s
.678 .847 .902 r
.6707 .16187 m
.6707 .28655 L
.67107 .28655 L
.67107 .16187 L
F
.2 .63 .79 r
.6707 .16187 m
.6707 .28655 L
.67107 .28655 L
.67107 .16187 L
s
.678 .847 .902 r
.67107 .16187 m
.67107 .28688 L
.67145 .28688 L
.67145 .16187 L
F
.2 .63 .79 r
.67107 .16187 m
.67107 .28688 L
.67145 .28688 L
.67145 .16187 L
s
.678 .847 .902 r
.67145 .16187 m
.67145 .28697 L
.67167 .28697 L
.67167 .16187 L
F
.2 .63 .79 r
.67145 .16187 m
.67145 .28697 L
.67167 .28697 L
.67167 .16187 L
s
.678 .847 .902 r
.67167 .16187 m
.67167 .2873 L
.67206 .2873 L
.67206 .16187 L
F
.2 .63 .79 r
.67167 .16187 m
.67167 .2873 L
.67206 .2873 L
.67206 .16187 L
s
.678 .847 .902 r
.67206 .16187 m
.67206 .28764 L
.6724 .28764 L
.6724 .16187 L
F
.2 .63 .79 r
.67206 .16187 m
.67206 .28764 L
.6724 .28764 L
.6724 .16187 L
s
.678 .847 .902 r
.6724 .16187 m
.6724 .28809 L
.67288 .28809 L
.67288 .16187 L
F
.2 .63 .79 r
.6724 .16187 m
.6724 .28809 L
.67288 .28809 L
.67288 .16187 L
s
.678 .847 .902 r
.67288 .16187 m
.67288 .28828 L
.67317 .28828 L
.67317 .16187 L
F
.2 .63 .79 r
.67288 .16187 m
.67288 .28828 L
.67317 .28828 L
.67317 .16187 L
s
.678 .847 .902 r
.67317 .16187 m
.67317 .28837 L
.67339 .28837 L
.67339 .16187 L
F
.2 .63 .79 r
.67317 .16187 m
.67317 .28837 L
.67339 .28837 L
.67339 .16187 L
s
.678 .847 .902 r
.67339 .16187 m
.67339 .28862 L
.67381 .28862 L
.67381 .16187 L
F
.2 .63 .79 r
.67339 .16187 m
.67339 .28862 L
.67381 .28862 L
.67381 .16187 L
s
.678 .847 .902 r
.67381 .16187 m
.67381 .28903 L
.674 .28903 L
.674 .16187 L
F
.2 .63 .79 r
.67381 .16187 m
.67381 .28903 L
.674 .28903 L
.674 .16187 L
s
.678 .847 .902 r
.674 .16187 m
.674 .28926 L
.67425 .28926 L
.67425 .16187 L
F
.2 .63 .79 r
.674 .16187 m
.674 .28926 L
.67425 .28926 L
.67425 .16187 L
s
.678 .847 .902 r
.67425 .16187 m
.67425 .28933 L
.67472 .28933 L
.67472 .16187 L
F
.2 .63 .79 r
.67425 .16187 m
.67425 .28933 L
.67472 .28933 L
.67472 .16187 L
s
.678 .847 .902 r
.67472 .16187 m
.67472 .28976 L
.67493 .28976 L
.67493 .16187 L
F
.2 .63 .79 r
.67472 .16187 m
.67472 .28976 L
.67493 .28976 L
.67493 .16187 L
s
.678 .847 .902 r
.67493 .16187 m
.67493 .28993 L
.67514 .28993 L
.67514 .16187 L
F
.2 .63 .79 r
.67493 .16187 m
.67493 .28993 L
.67514 .28993 L
.67514 .16187 L
s
.678 .847 .902 r
.67514 .16187 m
.67514 .29004 L
.67549 .29004 L
.67549 .16187 L
F
.2 .63 .79 r
.67514 .16187 m
.67514 .29004 L
.67549 .29004 L
.67549 .16187 L
s
.678 .847 .902 r
.67549 .16187 m
.67549 .29045 L
.67586 .29045 L
.67586 .16187 L
F
.2 .63 .79 r
.67549 .16187 m
.67549 .29045 L
.67586 .29045 L
.67586 .16187 L
s
.678 .847 .902 r
.67586 .16187 m
.67586 .29067 L
.67605 .29067 L
.67605 .16187 L
F
.2 .63 .79 r
.67586 .16187 m
.67586 .29067 L
.67605 .29067 L
.67605 .16187 L
s
.678 .847 .902 r
.67605 .16187 m
.67605 .29094 L
.67643 .29094 L
.67643 .16187 L
F
.2 .63 .79 r
.67605 .16187 m
.67605 .29094 L
.67643 .29094 L
.67643 .16187 L
s
.678 .847 .902 r
.67643 .16187 m
.67643 .29114 L
.67661 .29114 L
.67661 .16187 L
F
.2 .63 .79 r
.67643 .16187 m
.67643 .29114 L
.67661 .29114 L
.67661 .16187 L
s
.678 .847 .902 r
.67661 .16187 m
.67661 .29137 L
.67696 .29137 L
.67696 .16187 L
F
.2 .63 .79 r
.67661 .16187 m
.67661 .29137 L
.67696 .29137 L
.67696 .16187 L
s
.678 .847 .902 r
.67696 .16187 m
.67696 .2917 L
.67715 .2917 L
.67715 .16187 L
F
.2 .63 .79 r
.67696 .16187 m
.67696 .2917 L
.67715 .2917 L
.67715 .16187 L
s
.678 .847 .902 r
.67715 .16187 m
.67715 .29191 L
.67764 .29191 L
.67764 .16187 L
F
.2 .63 .79 r
.67715 .16187 m
.67715 .29191 L
.67764 .29191 L
.67764 .16187 L
s
.678 .847 .902 r
.67764 .16187 m
.67764 .29217 L
.67792 .29217 L
.67792 .16187 L
F
.2 .63 .79 r
.67764 .16187 m
.67764 .29217 L
.67792 .29217 L
.67792 .16187 L
s
.678 .847 .902 r
.67792 .16187 m
.67792 .29249 L
.67831 .29249 L
.67831 .16187 L
F
.2 .63 .79 r
.67792 .16187 m
.67792 .29249 L
.67831 .29249 L
.67831 .16187 L
s
.678 .847 .902 r
.67831 .16187 m
.67831 .29271 L
.67863 .29271 L
.67863 .16187 L
F
.2 .63 .79 r
.67831 .16187 m
.67831 .29271 L
.67863 .29271 L
.67863 .16187 L
s
.678 .847 .902 r
.67863 .16187 m
.67863 .29309 L
.67888 .29309 L
.67888 .16187 L
F
.2 .63 .79 r
.67863 .16187 m
.67863 .29309 L
.67888 .29309 L
.67888 .16187 L
s
.678 .847 .902 r
.67888 .16187 m
.67888 .29333 L
.67909 .29333 L
.67909 .16187 L
F
.2 .63 .79 r
.67888 .16187 m
.67888 .29333 L
.67909 .29333 L
.67909 .16187 L
s
.678 .847 .902 r
.67909 .16187 m
.67909 .29346 L
.67925 .29346 L
.67925 .16187 L
F
.2 .63 .79 r
.67909 .16187 m
.67909 .29346 L
.67925 .29346 L
.67925 .16187 L
s
.678 .847 .902 r
.67925 .16187 m
.67925 .29359 L
.67971 .29359 L
.67971 .16187 L
F
.2 .63 .79 r
.67925 .16187 m
.67925 .29359 L
.67971 .29359 L
.67971 .16187 L
s
.678 .847 .902 r
.67971 .16187 m
.67971 .29402 L
.67997 .29402 L
.67997 .16187 L
F
.2 .63 .79 r
.67971 .16187 m
.67971 .29402 L
.67997 .29402 L
.67997 .16187 L
s
.678 .847 .902 r
.67997 .16187 m
.67997 .29416 L
.68039 .29416 L
.68039 .16187 L
F
.2 .63 .79 r
.67997 .16187 m
.67997 .29416 L
.68039 .29416 L
.68039 .16187 L
s
.678 .847 .902 r
.68039 .16187 m
.68039 .29469 L
.68081 .29469 L
.68081 .16187 L
F
.2 .63 .79 r
.68039 .16187 m
.68039 .29469 L
.68081 .29469 L
.68081 .16187 L
s
.678 .847 .902 r
.68081 .16187 m
.68081 .29483 L
.681 .29483 L
.681 .16187 L
F
.2 .63 .79 r
.68081 .16187 m
.68081 .29483 L
.681 .29483 L
.681 .16187 L
s
.678 .847 .902 r
.681 .16187 m
.681 .29512 L
.68122 .29512 L
.68122 .16187 L
F
.2 .63 .79 r
.681 .16187 m
.681 .29512 L
.68122 .29512 L
.68122 .16187 L
s
.678 .847 .902 r
.68122 .16187 m
.68122 .29522 L
.68154 .29522 L
.68154 .16187 L
F
.2 .63 .79 r
.68122 .16187 m
.68122 .29522 L
.68154 .29522 L
.68154 .16187 L
s
.678 .847 .902 r
.68154 .16187 m
.68154 .29562 L
.68199 .29562 L
.68199 .16187 L
F
.2 .63 .79 r
.68154 .16187 m
.68154 .29562 L
.68199 .29562 L
.68199 .16187 L
s
.678 .847 .902 r
.68199 .16187 m
.68199 .29602 L
.68246 .29602 L
.68246 .16187 L
F
.2 .63 .79 r
.68199 .16187 m
.68199 .29602 L
.68246 .29602 L
.68246 .16187 L
s
.678 .847 .902 r
.68246 .16187 m
.68246 .29626 L
.68261 .29626 L
.68261 .16187 L
F
.2 .63 .79 r
.68246 .16187 m
.68246 .29626 L
.68261 .29626 L
.68261 .16187 L
s
.678 .847 .902 r
.68261 .16187 m
.68261 .2964 L
.68307 .2964 L
.68307 .16187 L
F
.2 .63 .79 r
.68261 .16187 m
.68261 .2964 L
.68307 .2964 L
.68307 .16187 L
s
.678 .847 .902 r
.68307 .16187 m
.68307 .29676 L
.6833 .29676 L
.6833 .16187 L
F
.2 .63 .79 r
.68307 .16187 m
.68307 .29676 L
.6833 .29676 L
.6833 .16187 L
s
.678 .847 .902 r
.6833 .16187 m
.6833 .29702 L
.68373 .29702 L
.68373 .16187 L
F
.2 .63 .79 r
.6833 .16187 m
.6833 .29702 L
.68373 .29702 L
.68373 .16187 L
s
.678 .847 .902 r
.68373 .16187 m
.68373 .29748 L
.68399 .29748 L
.68399 .16187 L
F
.2 .63 .79 r
.68373 .16187 m
.68373 .29748 L
.68399 .29748 L
.68399 .16187 L
s
.678 .847 .902 r
.68399 .16187 m
.68399 .29785 L
.68441 .29785 L
.68441 .16187 L
F
.2 .63 .79 r
.68399 .16187 m
.68399 .29785 L
.68441 .29785 L
.68441 .16187 L
s
.678 .847 .902 r
.68441 .16187 m
.68441 .29812 L
.68479 .29812 L
.68479 .16187 L
F
.2 .63 .79 r
.68441 .16187 m
.68441 .29812 L
.68479 .29812 L
.68479 .16187 L
s
.678 .847 .902 r
.68479 .16187 m
.68479 .29831 L
.68518 .29831 L
.68518 .16187 L
F
.2 .63 .79 r
.68479 .16187 m
.68479 .29831 L
.68518 .29831 L
.68518 .16187 L
s
.678 .847 .902 r
.68518 .16187 m
.68518 .29862 L
.68545 .29862 L
.68545 .16187 L
F
.2 .63 .79 r
.68518 .16187 m
.68518 .29862 L
.68545 .29862 L
.68545 .16187 L
s
.678 .847 .902 r
.68545 .16187 m
.68545 .29896 L
.68573 .29896 L
.68573 .16187 L
F
.2 .63 .79 r
.68545 .16187 m
.68545 .29896 L
.68573 .29896 L
.68573 .16187 L
s
.678 .847 .902 r
.68573 .16187 m
.68573 .29916 L
.68621 .29916 L
.68621 .16187 L
F
.2 .63 .79 r
.68573 .16187 m
.68573 .29916 L
.68621 .29916 L
.68621 .16187 L
s
.678 .847 .902 r
.68621 .16187 m
.68621 .29949 L
.68644 .29949 L
.68644 .16187 L
F
.2 .63 .79 r
.68621 .16187 m
.68621 .29949 L
.68644 .29949 L
.68644 .16187 L
s
.678 .847 .902 r
.68644 .16187 m
.68644 .29974 L
.6866 .29974 L
.6866 .16187 L
F
.2 .63 .79 r
.68644 .16187 m
.68644 .29974 L
.6866 .29974 L
.6866 .16187 L
s
.678 .847 .902 r
.6866 .16187 m
.6866 .29994 L
.68681 .29994 L
.68681 .16187 L
F
.2 .63 .79 r
.6866 .16187 m
.6866 .29994 L
.68681 .29994 L
.68681 .16187 L
s
.678 .847 .902 r
.68681 .16187 m
.68681 .30021 L
.68729 .30021 L
.68729 .16187 L
F
.2 .63 .79 r
.68681 .16187 m
.68681 .30021 L
.68729 .30021 L
.68729 .16187 L
s
.678 .847 .902 r
.68729 .16187 m
.68729 .30059 L
.68754 .30059 L
.68754 .16187 L
F
.2 .63 .79 r
.68729 .16187 m
.68729 .30059 L
.68754 .30059 L
.68754 .16187 L
s
.678 .847 .902 r
.68754 .16187 m
.68754 .30062 L
.68794 .30062 L
.68794 .16187 L
F
.2 .63 .79 r
.68754 .16187 m
.68754 .30062 L
.68794 .30062 L
.68794 .16187 L
s
.678 .847 .902 r
.68794 .16187 m
.68794 .30112 L
.68823 .30112 L
.68823 .16187 L
F
.2 .63 .79 r
.68794 .16187 m
.68794 .30112 L
.68823 .30112 L
.68823 .16187 L
s
.678 .847 .902 r
.68823 .16187 m
.68823 .30135 L
.68842 .30135 L
.68842 .16187 L
F
.2 .63 .79 r
.68823 .16187 m
.68823 .30135 L
.68842 .30135 L
.68842 .16187 L
s
.678 .847 .902 r
.68842 .16187 m
.68842 .30153 L
.68864 .30153 L
.68864 .16187 L
F
.2 .63 .79 r
.68842 .16187 m
.68842 .30153 L
.68864 .30153 L
.68864 .16187 L
s
.678 .847 .902 r
.68864 .16187 m
.68864 .30164 L
.68895 .30164 L
.68895 .16187 L
F
.2 .63 .79 r
.68864 .16187 m
.68864 .30164 L
.68895 .30164 L
.68895 .16187 L
s
.678 .847 .902 r
.68895 .16187 m
.68895 .30205 L
.68942 .30205 L
.68942 .16187 L
F
.2 .63 .79 r
.68895 .16187 m
.68895 .30205 L
.68942 .30205 L
.68942 .16187 L
s
.678 .847 .902 r
.68942 .16187 m
.68942 .30233 L
.68966 .30233 L
.68966 .16187 L
F
.2 .63 .79 r
.68942 .16187 m
.68942 .30233 L
.68966 .30233 L
.68966 .16187 L
s
.678 .847 .902 r
.68966 .16187 m
.68966 .30252 L
.68989 .30252 L
.68989 .16187 L
F
.2 .63 .79 r
.68966 .16187 m
.68966 .30252 L
.68989 .30252 L
.68989 .16187 L
s
.678 .847 .902 r
.68989 .16187 m
.68989 .30268 L
.69021 .30268 L
.69021 .16187 L
F
.2 .63 .79 r
.68989 .16187 m
.68989 .30268 L
.69021 .30268 L
.69021 .16187 L
s
.678 .847 .902 r
.69021 .16187 m
.69021 .30297 L
.69037 .30297 L
.69037 .16187 L
F
.2 .63 .79 r
.69021 .16187 m
.69021 .30297 L
.69037 .30297 L
.69037 .16187 L
s
.678 .847 .902 r
.69037 .16187 m
.69037 .3031 L
.69052 .3031 L
.69052 .16187 L
F
.2 .63 .79 r
.69037 .16187 m
.69037 .3031 L
.69052 .3031 L
.69052 .16187 L
s
.678 .847 .902 r
.69052 .16187 m
.69052 .30324 L
.69081 .30324 L
.69081 .16187 L
F
.2 .63 .79 r
.69052 .16187 m
.69052 .30324 L
.69081 .30324 L
.69081 .16187 L
s
.678 .847 .902 r
.69081 .16187 m
.69081 .30351 L
.69102 .30351 L
.69102 .16187 L
F
.2 .63 .79 r
.69081 .16187 m
.69081 .30351 L
.69102 .30351 L
.69102 .16187 L
s
.678 .847 .902 r
.69102 .16187 m
.69102 .30373 L
.69125 .30373 L
.69125 .16187 L
F
.2 .63 .79 r
.69102 .16187 m
.69102 .30373 L
.69125 .30373 L
.69125 .16187 L
s
.678 .847 .902 r
.69125 .16187 m
.69125 .30399 L
.69151 .30399 L
.69151 .16187 L
F
.2 .63 .79 r
.69125 .16187 m
.69125 .30399 L
.69151 .30399 L
.69151 .16187 L
s
.678 .847 .902 r
.69151 .16187 m
.69151 .30405 L
.69191 .30405 L
.69191 .16187 L
F
.2 .63 .79 r
.69151 .16187 m
.69151 .30405 L
.69191 .30405 L
.69191 .16187 L
s
.678 .847 .902 r
.69191 .16187 m
.69191 .30447 L
.69234 .30447 L
.69234 .16187 L
F
.2 .63 .79 r
.69191 .16187 m
.69191 .30447 L
.69234 .30447 L
.69234 .16187 L
s
.678 .847 .902 r
.69234 .16187 m
.69234 .30512 L
.69278 .30512 L
.69278 .16187 L
F
.2 .63 .79 r
.69234 .16187 m
.69234 .30512 L
.69278 .30512 L
.69278 .16187 L
s
.678 .847 .902 r
.69278 .16187 m
.69278 .30526 L
.69305 .30526 L
.69305 .16187 L
F
.2 .63 .79 r
.69278 .16187 m
.69278 .30526 L
.69305 .30526 L
.69305 .16187 L
s
.678 .847 .902 r
.69305 .16187 m
.69305 .30561 L
.69337 .30561 L
.69337 .16187 L
F
.2 .63 .79 r
.69305 .16187 m
.69305 .30561 L
.69337 .30561 L
.69337 .16187 L
s
.678 .847 .902 r
.69337 .16187 m
.69337 .30586 L
.69379 .30586 L
.69379 .16187 L
F
.2 .63 .79 r
.69337 .16187 m
.69337 .30586 L
.69379 .30586 L
.69379 .16187 L
s
.678 .847 .902 r
.69379 .16187 m
.69379 .30605 L
.69416 .30605 L
.69416 .16187 L
F
.2 .63 .79 r
.69379 .16187 m
.69379 .30605 L
.69416 .30605 L
.69416 .16187 L
s
.678 .847 .902 r
.69416 .16187 m
.69416 .30658 L
.69445 .30658 L
.69445 .16187 L
F
.2 .63 .79 r
.69416 .16187 m
.69416 .30658 L
.69445 .30658 L
.69445 .16187 L
s
.678 .847 .902 r
.69445 .16187 m
.69445 .30676 L
.69467 .30676 L
.69467 .16187 L
F
.2 .63 .79 r
.69445 .16187 m
.69445 .30676 L
.69467 .30676 L
.69467 .16187 L
s
.678 .847 .902 r
.69467 .16187 m
.69467 .30685 L
.69484 .30685 L
.69484 .16187 L
F
.2 .63 .79 r
.69467 .16187 m
.69467 .30685 L
.69484 .30685 L
.69484 .16187 L
s
.678 .847 .902 r
.69484 .16187 m
.69484 .30701 L
.69507 .30701 L
.69507 .16187 L
F
.2 .63 .79 r
.69484 .16187 m
.69484 .30701 L
.69507 .30701 L
.69507 .16187 L
s
.678 .847 .902 r
.69507 .16187 m
.69507 .30712 L
.69531 .30712 L
.69531 .16187 L
F
.2 .63 .79 r
.69507 .16187 m
.69507 .30712 L
.69531 .30712 L
.69531 .16187 L
s
.678 .847 .902 r
.69531 .16187 m
.69531 .30746 L
.69546 .30746 L
.69546 .16187 L
F
.2 .63 .79 r
.69531 .16187 m
.69531 .30746 L
.69546 .30746 L
.69546 .16187 L
s
.678 .847 .902 r
.69546 .16187 m
.69546 .30752 L
.69581 .30752 L
.69581 .16187 L
F
.2 .63 .79 r
.69546 .16187 m
.69546 .30752 L
.69581 .30752 L
.69581 .16187 L
s
.678 .847 .902 r
.69581 .16187 m
.69581 .30795 L
.69606 .30795 L
.69606 .16187 L
F
.2 .63 .79 r
.69581 .16187 m
.69581 .30795 L
.69606 .30795 L
.69606 .16187 L
s
.678 .847 .902 r
.69606 .16187 m
.69606 .30805 L
.69621 .30805 L
.69621 .16187 L
F
.2 .63 .79 r
.69606 .16187 m
.69606 .30805 L
.69621 .30805 L
.69621 .16187 L
s
.678 .847 .902 r
.69621 .16187 m
.69621 .3083 L
.69662 .3083 L
.69662 .16187 L
F
.2 .63 .79 r
.69621 .16187 m
.69621 .3083 L
.69662 .3083 L
.69662 .16187 L
s
.678 .847 .902 r
.69662 .16187 m
.69662 .30847 L
.6968 .30847 L
.6968 .16187 L
F
.2 .63 .79 r
.69662 .16187 m
.69662 .30847 L
.6968 .30847 L
.6968 .16187 L
s
.678 .847 .902 r
.6968 .16187 m
.6968 .30871 L
.69704 .30871 L
.69704 .16187 L
F
.2 .63 .79 r
.6968 .16187 m
.6968 .30871 L
.69704 .30871 L
.69704 .16187 L
s
.678 .847 .902 r
.69704 .16187 m
.69704 .30897 L
.69719 .30897 L
.69719 .16187 L
F
.2 .63 .79 r
.69704 .16187 m
.69704 .30897 L
.69719 .30897 L
.69719 .16187 L
s
.678 .847 .902 r
.69719 .16187 m
.69719 .30902 L
.69745 .30902 L
.69745 .16187 L
F
.2 .63 .79 r
.69719 .16187 m
.69719 .30902 L
.69745 .30902 L
.69745 .16187 L
s
.678 .847 .902 r
.69745 .16187 m
.69745 .30941 L
.69792 .30941 L
.69792 .16187 L
F
.2 .63 .79 r
.69745 .16187 m
.69745 .30941 L
.69792 .30941 L
.69792 .16187 L
s
.678 .847 .902 r
.69792 .16187 m
.69792 .3097 L
.69807 .3097 L
.69807 .16187 L
F
.2 .63 .79 r
.69792 .16187 m
.69792 .3097 L
.69807 .3097 L
.69807 .16187 L
s
.678 .847 .902 r
.69807 .16187 m
.69807 .30978 L
.69845 .30978 L
.69845 .16187 L
F
.2 .63 .79 r
.69807 .16187 m
.69807 .30978 L
.69845 .30978 L
.69845 .16187 L
s
.678 .847 .902 r
.69845 .16187 m
.69845 .31012 L
.69881 .31012 L
.69881 .16187 L
F
.2 .63 .79 r
.69845 .16187 m
.69845 .31012 L
.69881 .31012 L
.69881 .16187 L
s
.678 .847 .902 r
.69881 .16187 m
.69881 .31043 L
.699 .31043 L
.699 .16187 L
F
.2 .63 .79 r
.69881 .16187 m
.69881 .31043 L
.699 .31043 L
.699 .16187 L
s
.678 .847 .902 r
.699 .16187 m
.699 .31068 L
.6992 .31068 L
.6992 .16187 L
F
.2 .63 .79 r
.699 .16187 m
.699 .31068 L
.6992 .31068 L
.6992 .16187 L
s
.678 .847 .902 r
.6992 .16187 m
.6992 .31085 L
.69946 .31085 L
.69946 .16187 L
F
.2 .63 .79 r
.6992 .16187 m
.6992 .31085 L
.69946 .31085 L
.69946 .16187 L
s
.678 .847 .902 r
.69946 .16187 m
.69946 .311 L
.69964 .311 L
.69964 .16187 L
F
.2 .63 .79 r
.69946 .16187 m
.69946 .311 L
.69964 .311 L
.69964 .16187 L
s
.678 .847 .902 r
.69964 .16187 m
.69964 .31126 L
.6999 .31126 L
.6999 .16187 L
F
.2 .63 .79 r
.69964 .16187 m
.69964 .31126 L
.6999 .31126 L
.6999 .16187 L
s
.678 .847 .902 r
.6999 .16187 m
.6999 .31151 L
.70022 .31151 L
.70022 .16187 L
F
.2 .63 .79 r
.6999 .16187 m
.6999 .31151 L
.70022 .31151 L
.70022 .16187 L
s
.678 .847 .902 r
.70022 .16187 m
.70022 .31185 L
.70068 .31185 L
.70068 .16187 L
F
.2 .63 .79 r
.70022 .16187 m
.70022 .31185 L
.70068 .31185 L
.70068 .16187 L
s
.678 .847 .902 r
.70068 .16187 m
.70068 .31218 L
.70114 .31218 L
.70114 .16187 L
F
.2 .63 .79 r
.70068 .16187 m
.70068 .31218 L
.70114 .31218 L
.70114 .16187 L
s
.678 .847 .902 r
.70114 .16187 m
.70114 .31245 L
.70138 .31245 L
.70138 .16187 L
F
.2 .63 .79 r
.70114 .16187 m
.70114 .31245 L
.70138 .31245 L
.70138 .16187 L
s
.678 .847 .902 r
.70138 .16187 m
.70138 .31268 L
.70162 .31268 L
.70162 .16187 L
F
.2 .63 .79 r
.70138 .16187 m
.70138 .31268 L
.70162 .31268 L
.70162 .16187 L
s
.678 .847 .902 r
.70162 .16187 m
.70162 .31303 L
.70199 .31303 L
.70199 .16187 L
F
.2 .63 .79 r
.70162 .16187 m
.70162 .31303 L
.70199 .31303 L
.70199 .16187 L
s
.678 .847 .902 r
.70199 .16187 m
.70199 .31333 L
.70244 .31333 L
.70244 .16187 L
F
.2 .63 .79 r
.70199 .16187 m
.70199 .31333 L
.70244 .31333 L
.70244 .16187 L
s
.678 .847 .902 r
.70244 .16187 m
.70244 .31388 L
.70283 .31388 L
.70283 .16187 L
F
.2 .63 .79 r
.70244 .16187 m
.70244 .31388 L
.70283 .31388 L
.70283 .16187 L
s
.678 .847 .902 r
.70283 .16187 m
.70283 .31405 L
.70331 .31405 L
.70331 .16187 L
F
.2 .63 .79 r
.70283 .16187 m
.70283 .31405 L
.70331 .31405 L
.70331 .16187 L
s
.678 .847 .902 r
.70331 .16187 m
.70331 .31435 L
.70367 .31435 L
.70367 .16187 L
F
.2 .63 .79 r
.70331 .16187 m
.70331 .31435 L
.70367 .31435 L
.70367 .16187 L
s
.678 .847 .902 r
.70367 .16187 m
.70367 .3148 L
.70386 .3148 L
.70386 .16187 L
F
.2 .63 .79 r
.70367 .16187 m
.70367 .3148 L
.70386 .3148 L
.70386 .16187 L
s
.678 .847 .902 r
.70386 .16187 m
.70386 .31511 L
.70422 .31511 L
.70422 .16187 L
F
.2 .63 .79 r
.70386 .16187 m
.70386 .31511 L
.70422 .31511 L
.70422 .16187 L
s
.678 .847 .902 r
.70422 .16187 m
.70422 .31546 L
.70461 .31546 L
.70461 .16187 L
F
.2 .63 .79 r
.70422 .16187 m
.70422 .31546 L
.70461 .31546 L
.70461 .16187 L
s
.678 .847 .902 r
.70461 .16187 m
.70461 .3155 L
.70497 .3155 L
.70497 .16187 L
F
.2 .63 .79 r
.70461 .16187 m
.70461 .3155 L
.70497 .3155 L
.70497 .16187 L
s
.678 .847 .902 r
.70497 .16187 m
.70497 .31604 L
.70539 .31604 L
.70539 .16187 L
F
.2 .63 .79 r
.70497 .16187 m
.70497 .31604 L
.70539 .31604 L
.70539 .16187 L
s
.678 .847 .902 r
.70539 .16187 m
.70539 .3163 L
.70577 .3163 L
.70577 .16187 L
F
.2 .63 .79 r
.70539 .16187 m
.70539 .3163 L
.70577 .3163 L
.70577 .16187 L
s
.678 .847 .902 r
.70577 .16187 m
.70577 .31658 L
.70616 .31658 L
.70616 .16187 L
F
.2 .63 .79 r
.70577 .16187 m
.70577 .31658 L
.70616 .31658 L
.70616 .16187 L
s
.678 .847 .902 r
.70616 .16187 m
.70616 .31724 L
.70663 .31724 L
.70663 .16187 L
F
.2 .63 .79 r
.70616 .16187 m
.70616 .31724 L
.70663 .31724 L
.70663 .16187 L
s
.678 .847 .902 r
.70663 .16187 m
.70663 .31736 L
.70684 .31736 L
.70684 .16187 L
F
.2 .63 .79 r
.70663 .16187 m
.70663 .31736 L
.70684 .31736 L
.70684 .16187 L
s
.678 .847 .902 r
.70684 .16187 m
.70684 .31749 L
.70717 .31749 L
.70717 .16187 L
F
.2 .63 .79 r
.70684 .16187 m
.70684 .31749 L
.70717 .31749 L
.70717 .16187 L
s
.678 .847 .902 r
.70717 .16187 m
.70717 .3179 L
.70751 .3179 L
.70751 .16187 L
F
.2 .63 .79 r
.70717 .16187 m
.70717 .3179 L
.70751 .3179 L
.70751 .16187 L
s
.678 .847 .902 r
.70751 .16187 m
.70751 .31817 L
.70787 .31817 L
.70787 .16187 L
F
.2 .63 .79 r
.70751 .16187 m
.70751 .31817 L
.70787 .31817 L
.70787 .16187 L
s
.678 .847 .902 r
.70787 .16187 m
.70787 .31841 L
.70804 .31841 L
.70804 .16187 L
F
.2 .63 .79 r
.70787 .16187 m
.70787 .31841 L
.70804 .31841 L
.70804 .16187 L
s
.678 .847 .902 r
.70804 .16187 m
.70804 .31862 L
.70826 .31862 L
.70826 .16187 L
F
.2 .63 .79 r
.70804 .16187 m
.70804 .31862 L
.70826 .31862 L
.70826 .16187 L
s
.678 .847 .902 r
.70826 .16187 m
.70826 .31886 L
.70843 .31886 L
.70843 .16187 L
F
.2 .63 .79 r
.70826 .16187 m
.70826 .31886 L
.70843 .31886 L
.70843 .16187 L
s
.678 .847 .902 r
.70843 .16187 m
.70843 .31915 L
.70882 .31915 L
.70882 .16187 L
F
.2 .63 .79 r
.70843 .16187 m
.70843 .31915 L
.70882 .31915 L
.70882 .16187 L
s
.678 .847 .902 r
.70882 .16187 m
.70882 .31938 L
.70903 .31938 L
.70903 .16187 L
F
.2 .63 .79 r
.70882 .16187 m
.70882 .31938 L
.70903 .31938 L
.70903 .16187 L
s
.678 .847 .902 r
.70903 .16187 m
.70903 .31957 L
.7095 .31957 L
.7095 .16187 L
F
.2 .63 .79 r
.70903 .16187 m
.70903 .31957 L
.7095 .31957 L
.7095 .16187 L
s
.678 .847 .902 r
.7095 .16187 m
.7095 .32009 L
.70992 .32009 L
.70992 .16187 L
F
.2 .63 .79 r
.7095 .16187 m
.7095 .32009 L
.70992 .32009 L
.70992 .16187 L
s
.678 .847 .902 r
.70992 .16187 m
.70992 .32024 L
.71009 .32024 L
.71009 .16187 L
F
.2 .63 .79 r
.70992 .16187 m
.70992 .32024 L
.71009 .32024 L
.71009 .16187 L
s
.678 .847 .902 r
.71009 .16187 m
.71009 .32045 L
.71034 .32045 L
.71034 .16187 L
F
.2 .63 .79 r
.71009 .16187 m
.71009 .32045 L
.71034 .32045 L
.71034 .16187 L
s
.678 .847 .902 r
.71034 .16187 m
.71034 .32067 L
.71057 .32067 L
.71057 .16187 L
F
.2 .63 .79 r
.71034 .16187 m
.71034 .32067 L
.71057 .32067 L
.71057 .16187 L
s
.678 .847 .902 r
.71057 .16187 m
.71057 .32093 L
.71101 .32093 L
.71101 .16187 L
F
.2 .63 .79 r
.71057 .16187 m
.71057 .32093 L
.71101 .32093 L
.71101 .16187 L
s
.678 .847 .902 r
.71101 .16187 m
.71101 .32123 L
.71131 .32123 L
.71131 .16187 L
F
.2 .63 .79 r
.71101 .16187 m
.71101 .32123 L
.71131 .32123 L
.71131 .16187 L
s
.678 .847 .902 r
.71131 .16187 m
.71131 .32154 L
.71152 .32154 L
.71152 .16187 L
F
.2 .63 .79 r
.71131 .16187 m
.71131 .32154 L
.71152 .32154 L
.71152 .16187 L
s
.678 .847 .902 r
.71152 .16187 m
.71152 .32181 L
.71187 .32181 L
.71187 .16187 L
F
.2 .63 .79 r
.71152 .16187 m
.71152 .32181 L
.71187 .32181 L
.71187 .16187 L
s
.678 .847 .902 r
.71187 .16187 m
.71187 .32203 L
.71207 .32203 L
.71207 .16187 L
F
.2 .63 .79 r
.71187 .16187 m
.71187 .32203 L
.71207 .32203 L
.71207 .16187 L
s
.678 .847 .902 r
.71207 .16187 m
.71207 .32219 L
.7125 .32219 L
.7125 .16187 L
F
.2 .63 .79 r
.71207 .16187 m
.71207 .32219 L
.7125 .32219 L
.7125 .16187 L
s
.678 .847 .902 r
.7125 .16187 m
.7125 .32274 L
.71278 .32274 L
.71278 .16187 L
F
.2 .63 .79 r
.7125 .16187 m
.7125 .32274 L
.71278 .32274 L
.71278 .16187 L
s
.678 .847 .902 r
.71278 .16187 m
.71278 .32285 L
.71326 .32285 L
.71326 .16187 L
F
.2 .63 .79 r
.71278 .16187 m
.71278 .32285 L
.71326 .32285 L
.71326 .16187 L
s
.678 .847 .902 r
.71326 .16187 m
.71326 .32325 L
.71355 .32325 L
.71355 .16187 L
F
.2 .63 .79 r
.71326 .16187 m
.71326 .32325 L
.71355 .32325 L
.71355 .16187 L
s
.678 .847 .902 r
.71355 .16187 m
.71355 .32355 L
.714 .32355 L
.714 .16187 L
F
.2 .63 .79 r
.71355 .16187 m
.71355 .32355 L
.714 .32355 L
.714 .16187 L
s
.678 .847 .902 r
.714 .16187 m
.714 .32394 L
.71423 .32394 L
.71423 .16187 L
F
.2 .63 .79 r
.714 .16187 m
.714 .32394 L
.71423 .32394 L
.71423 .16187 L
s
.678 .847 .902 r
.71423 .16187 m
.71423 .32408 L
.71451 .32408 L
.71451 .16187 L
F
.2 .63 .79 r
.71423 .16187 m
.71423 .32408 L
.71451 .32408 L
.71451 .16187 L
s
.678 .847 .902 r
.71451 .16187 m
.71451 .32463 L
.71496 .32463 L
.71496 .16187 L
F
.2 .63 .79 r
.71451 .16187 m
.71451 .32463 L
.71496 .32463 L
.71496 .16187 L
s
.678 .847 .902 r
.71496 .16187 m
.71496 .3249 L
.7152 .3249 L
.7152 .16187 L
F
.2 .63 .79 r
.71496 .16187 m
.71496 .3249 L
.7152 .3249 L
.7152 .16187 L
s
.678 .847 .902 r
.7152 .16187 m
.7152 .32497 L
.7154 .32497 L
.7154 .16187 L
F
.2 .63 .79 r
.7152 .16187 m
.7152 .32497 L
.7154 .32497 L
.7154 .16187 L
s
.678 .847 .902 r
.7154 .16187 m
.7154 .32522 L
.71561 .32522 L
.71561 .16187 L
F
.2 .63 .79 r
.7154 .16187 m
.7154 .32522 L
.71561 .32522 L
.71561 .16187 L
s
.678 .847 .902 r
.71561 .16187 m
.71561 .32566 L
.71604 .32566 L
.71604 .16187 L
F
.2 .63 .79 r
.71561 .16187 m
.71561 .32566 L
.71604 .32566 L
.71604 .16187 L
s
.678 .847 .902 r
.71604 .16187 m
.71604 .32571 L
.71638 .32571 L
.71638 .16187 L
F
.2 .63 .79 r
.71604 .16187 m
.71604 .32571 L
.71638 .32571 L
.71638 .16187 L
s
.678 .847 .902 r
.71638 .16187 m
.71638 .32618 L
.71686 .32618 L
.71686 .16187 L
F
.2 .63 .79 r
.71638 .16187 m
.71638 .32618 L
.71686 .32618 L
.71686 .16187 L
s
.678 .847 .902 r
.71686 .16187 m
.71686 .32647 L
.71709 .32647 L
.71709 .16187 L
F
.2 .63 .79 r
.71686 .16187 m
.71686 .32647 L
.71709 .32647 L
.71709 .16187 L
s
.678 .847 .902 r
.71709 .16187 m
.71709 .32666 L
.71725 .32666 L
.71725 .16187 L
F
.2 .63 .79 r
.71709 .16187 m
.71709 .32666 L
.71725 .32666 L
.71725 .16187 L
s
.678 .847 .902 r
.71725 .16187 m
.71725 .32701 L
.71757 .32701 L
.71757 .16187 L
F
.2 .63 .79 r
.71725 .16187 m
.71725 .32701 L
.71757 .32701 L
.71757 .16187 L
s
.678 .847 .902 r
.71757 .16187 m
.71757 .32706 L
.71794 .32706 L
.71794 .16187 L
F
.2 .63 .79 r
.71757 .16187 m
.71757 .32706 L
.71794 .32706 L
.71794 .16187 L
s
.678 .847 .902 r
.71794 .16187 m
.71794 .3275 L
.7181 .3275 L
.7181 .16187 L
F
.2 .63 .79 r
.71794 .16187 m
.71794 .3275 L
.7181 .3275 L
.7181 .16187 L
s
.678 .847 .902 r
.7181 .16187 m
.7181 .32769 L
.71831 .32769 L
.71831 .16187 L
F
.2 .63 .79 r
.7181 .16187 m
.7181 .32769 L
.71831 .32769 L
.71831 .16187 L
s
.678 .847 .902 r
.71831 .16187 m
.71831 .32782 L
.71848 .32782 L
.71848 .16187 L
F
.2 .63 .79 r
.71831 .16187 m
.71831 .32782 L
.71848 .32782 L
.71848 .16187 L
s
.678 .847 .902 r
.71848 .16187 m
.71848 .328 L
.71879 .328 L
.71879 .16187 L
F
.2 .63 .79 r
.71848 .16187 m
.71848 .328 L
.71879 .328 L
.71879 .16187 L
s
.678 .847 .902 r
.71879 .16187 m
.71879 .32821 L
.71908 .32821 L
.71908 .16187 L
F
.2 .63 .79 r
.71879 .16187 m
.71879 .32821 L
.71908 .32821 L
.71908 .16187 L
s
.678 .847 .902 r
.71908 .16187 m
.71908 .32847 L
.71925 .32847 L
.71925 .16187 L
F
.2 .63 .79 r
.71908 .16187 m
.71908 .32847 L
.71925 .32847 L
.71925 .16187 L
s
.678 .847 .902 r
.71925 .16187 m
.71925 .32866 L
.71948 .32866 L
.71948 .16187 L
F
.2 .63 .79 r
.71925 .16187 m
.71925 .32866 L
.71948 .32866 L
.71948 .16187 L
s
.678 .847 .902 r
.71948 .16187 m
.71948 .32885 L
.71966 .32885 L
.71966 .16187 L
F
.2 .63 .79 r
.71948 .16187 m
.71948 .32885 L
.71966 .32885 L
.71966 .16187 L
s
.678 .847 .902 r
.71966 .16187 m
.71966 .32921 L
.71996 .32921 L
.71996 .16187 L
F
.2 .63 .79 r
.71966 .16187 m
.71966 .32921 L
.71996 .32921 L
.71996 .16187 L
s
.678 .847 .902 r
.71996 .16187 m
.71996 .32925 L
.72032 .32925 L
.72032 .16187 L
F
.2 .63 .79 r
.71996 .16187 m
.71996 .32925 L
.72032 .32925 L
.72032 .16187 L
s
.678 .847 .902 r
.72032 .16187 m
.72032 .32958 L
.7206 .32958 L
.7206 .16187 L
F
.2 .63 .79 r
.72032 .16187 m
.72032 .32958 L
.7206 .32958 L
.7206 .16187 L
s
.678 .847 .902 r
.7206 .16187 m
.7206 .3298 L
.72104 .3298 L
.72104 .16187 L
F
.2 .63 .79 r
.7206 .16187 m
.7206 .3298 L
.72104 .3298 L
.72104 .16187 L
s
.678 .847 .902 r
.72104 .16187 m
.72104 .33032 L
.72122 .33032 L
.72122 .16187 L
F
.2 .63 .79 r
.72104 .16187 m
.72104 .33032 L
.72122 .33032 L
.72122 .16187 L
s
.678 .847 .902 r
.72122 .16187 m
.72122 .33045 L
.72161 .33045 L
.72161 .16187 L
F
.2 .63 .79 r
.72122 .16187 m
.72122 .33045 L
.72161 .33045 L
.72161 .16187 L
s
.678 .847 .902 r
.72161 .16187 m
.72161 .33075 L
.7218 .33075 L
.7218 .16187 L
F
.2 .63 .79 r
.72161 .16187 m
.72161 .33075 L
.7218 .33075 L
.7218 .16187 L
s
.678 .847 .902 r
.7218 .16187 m
.7218 .33114 L
.72219 .33114 L
.72219 .16187 L
F
.2 .63 .79 r
.7218 .16187 m
.7218 .33114 L
.72219 .33114 L
.72219 .16187 L
s
.678 .847 .902 r
.72219 .16187 m
.72219 .33131 L
.72265 .33131 L
.72265 .16187 L
F
.2 .63 .79 r
.72219 .16187 m
.72219 .33131 L
.72265 .33131 L
.72265 .16187 L
s
.678 .847 .902 r
.72265 .16187 m
.72265 .33179 L
.7231 .33179 L
.7231 .16187 L
F
.2 .63 .79 r
.72265 .16187 m
.72265 .33179 L
.7231 .33179 L
.7231 .16187 L
s
.678 .847 .902 r
.7231 .16187 m
.7231 .3321 L
.72344 .3321 L
.72344 .16187 L
F
.2 .63 .79 r
.7231 .16187 m
.7231 .3321 L
.72344 .3321 L
.72344 .16187 L
s
.678 .847 .902 r
.72344 .16187 m
.72344 .33247 L
.72385 .33247 L
.72385 .16187 L
F
.2 .63 .79 r
.72344 .16187 m
.72344 .33247 L
.72385 .33247 L
.72385 .16187 L
s
.678 .847 .902 r
.72385 .16187 m
.72385 .33304 L
.72422 .33304 L
.72422 .16187 L
F
.2 .63 .79 r
.72385 .16187 m
.72385 .33304 L
.72422 .33304 L
.72422 .16187 L
s
.678 .847 .902 r
.72422 .16187 m
.72422 .33311 L
.72466 .33311 L
.72466 .16187 L
F
.2 .63 .79 r
.72422 .16187 m
.72422 .33311 L
.72466 .33311 L
.72466 .16187 L
s
.678 .847 .902 r
.72466 .16187 m
.72466 .33352 L
.72483 .33352 L
.72483 .16187 L
F
.2 .63 .79 r
.72466 .16187 m
.72466 .33352 L
.72483 .33352 L
.72483 .16187 L
s
.678 .847 .902 r
.72483 .16187 m
.72483 .33367 L
.72502 .33367 L
.72502 .16187 L
F
.2 .63 .79 r
.72483 .16187 m
.72483 .33367 L
.72502 .33367 L
.72502 .16187 L
s
.678 .847 .902 r
.72502 .16187 m
.72502 .33383 L
.72537 .33383 L
.72537 .16187 L
F
.2 .63 .79 r
.72502 .16187 m
.72502 .33383 L
.72537 .33383 L
.72537 .16187 L
s
.678 .847 .902 r
.72537 .16187 m
.72537 .3342 L
.72575 .3342 L
.72575 .16187 L
F
.2 .63 .79 r
.72537 .16187 m
.72537 .3342 L
.72575 .3342 L
.72575 .16187 L
s
.678 .847 .902 r
.72575 .16187 m
.72575 .33477 L
.72624 .33477 L
.72624 .16187 L
F
.2 .63 .79 r
.72575 .16187 m
.72575 .33477 L
.72624 .33477 L
.72624 .16187 L
s
.678 .847 .902 r
.72624 .16187 m
.72624 .33519 L
.72661 .33519 L
.72661 .16187 L
F
.2 .63 .79 r
.72624 .16187 m
.72624 .33519 L
.72661 .33519 L
.72661 .16187 L
s
.678 .847 .902 r
.72661 .16187 m
.72661 .33542 L
.72682 .33542 L
.72682 .16187 L
F
.2 .63 .79 r
.72661 .16187 m
.72661 .33542 L
.72682 .33542 L
.72682 .16187 L
s
.678 .847 .902 r
.72682 .16187 m
.72682 .33573 L
.72719 .33573 L
.72719 .16187 L
F
.2 .63 .79 r
.72682 .16187 m
.72682 .33573 L
.72719 .33573 L
.72719 .16187 L
s
.678 .847 .902 r
.72719 .16187 m
.72719 .33586 L
.72759 .33586 L
.72759 .16187 L
F
.2 .63 .79 r
.72719 .16187 m
.72719 .33586 L
.72759 .33586 L
.72759 .16187 L
s
.678 .847 .902 r
.72759 .16187 m
.72759 .33624 L
.72793 .33624 L
.72793 .16187 L
F
.2 .63 .79 r
.72759 .16187 m
.72759 .33624 L
.72793 .33624 L
.72793 .16187 L
s
.678 .847 .902 r
.72793 .16187 m
.72793 .33678 L
.72833 .33678 L
.72833 .16187 L
F
.2 .63 .79 r
.72793 .16187 m
.72793 .33678 L
.72833 .33678 L
.72833 .16187 L
s
.678 .847 .902 r
.72833 .16187 m
.72833 .33692 L
.72848 .33692 L
.72848 .16187 L
F
.2 .63 .79 r
.72833 .16187 m
.72833 .33692 L
.72848 .33692 L
.72848 .16187 L
s
.678 .847 .902 r
.72848 .16187 m
.72848 .33697 L
.72876 .33697 L
.72876 .16187 L
F
.2 .63 .79 r
.72848 .16187 m
.72848 .33697 L
.72876 .33697 L
.72876 .16187 L
s
.678 .847 .902 r
.72876 .16187 m
.72876 .3373 L
.72915 .3373 L
.72915 .16187 L
F
.2 .63 .79 r
.72876 .16187 m
.72876 .3373 L
.72915 .3373 L
.72915 .16187 L
s
.678 .847 .902 r
.72915 .16187 m
.72915 .33758 L
.72952 .33758 L
.72952 .16187 L
F
.2 .63 .79 r
.72915 .16187 m
.72915 .33758 L
.72952 .33758 L
.72952 .16187 L
s
.678 .847 .902 r
.72952 .16187 m
.72952 .33801 L
.72977 .33801 L
.72977 .16187 L
F
.2 .63 .79 r
.72952 .16187 m
.72952 .33801 L
.72977 .33801 L
.72977 .16187 L
s
.678 .847 .902 r
.72977 .16187 m
.72977 .3383 L
.73001 .3383 L
.73001 .16187 L
F
.2 .63 .79 r
.72977 .16187 m
.72977 .3383 L
.73001 .3383 L
.73001 .16187 L
s
.678 .847 .902 r
.73001 .16187 m
.73001 .33858 L
.73049 .33858 L
.73049 .16187 L
F
.2 .63 .79 r
.73001 .16187 m
.73001 .33858 L
.73049 .33858 L
.73049 .16187 L
s
.678 .847 .902 r
.73049 .16187 m
.73049 .33912 L
.7309 .33912 L
.7309 .16187 L
F
.2 .63 .79 r
.73049 .16187 m
.73049 .33912 L
.7309 .33912 L
.7309 .16187 L
s
.678 .847 .902 r
.7309 .16187 m
.7309 .33919 L
.73119 .33919 L
.73119 .16187 L
F
.2 .63 .79 r
.7309 .16187 m
.7309 .33919 L
.73119 .33919 L
.73119 .16187 L
s
.678 .847 .902 r
.73119 .16187 m
.73119 .33966 L
.73158 .33966 L
.73158 .16187 L
F
.2 .63 .79 r
.73119 .16187 m
.73119 .33966 L
.73158 .33966 L
.73158 .16187 L
s
.678 .847 .902 r
.73158 .16187 m
.73158 .33983 L
.7318 .33983 L
.7318 .16187 L
F
.2 .63 .79 r
.73158 .16187 m
.73158 .33983 L
.7318 .33983 L
.7318 .16187 L
s
.678 .847 .902 r
.7318 .16187 m
.7318 .34016 L
.73199 .34016 L
.73199 .16187 L
F
.2 .63 .79 r
.7318 .16187 m
.7318 .34016 L
.73199 .34016 L
.73199 .16187 L
s
.678 .847 .902 r
.73199 .16187 m
.73199 .34048 L
.73233 .34048 L
.73233 .16187 L
F
.2 .63 .79 r
.73199 .16187 m
.73199 .34048 L
.73233 .34048 L
.73233 .16187 L
s
.678 .847 .902 r
.73233 .16187 m
.73233 .34059 L
.7327 .34059 L
.7327 .16187 L
F
.2 .63 .79 r
.73233 .16187 m
.73233 .34059 L
.7327 .34059 L
.7327 .16187 L
s
.678 .847 .902 r
.7327 .16187 m
.7327 .34098 L
.73288 .34098 L
.73288 .16187 L
F
.2 .63 .79 r
.7327 .16187 m
.7327 .34098 L
.73288 .34098 L
.73288 .16187 L
s
.678 .847 .902 r
.73288 .16187 m
.73288 .34124 L
.73321 .34124 L
.73321 .16187 L
F
.2 .63 .79 r
.73288 .16187 m
.73288 .34124 L
.73321 .34124 L
.73321 .16187 L
s
.678 .847 .902 r
.73321 .16187 m
.73321 .34159 L
.73366 .34159 L
.73366 .16187 L
F
.2 .63 .79 r
.73321 .16187 m
.73321 .34159 L
.73366 .34159 L
.73366 .16187 L
s
.678 .847 .902 r
.73366 .16187 m
.73366 .34192 L
.73403 .34192 L
.73403 .16187 L
F
.2 .63 .79 r
.73366 .16187 m
.73366 .34192 L
.73403 .34192 L
.73403 .16187 L
s
.678 .847 .902 r
.73403 .16187 m
.73403 .34208 L
.73434 .34208 L
.73434 .16187 L
F
.2 .63 .79 r
.73403 .16187 m
.73403 .34208 L
.73434 .34208 L
.73434 .16187 L
s
.678 .847 .902 r
.73434 .16187 m
.73434 .34256 L
.7346 .34256 L
.7346 .16187 L
F
.2 .63 .79 r
.73434 .16187 m
.73434 .34256 L
.7346 .34256 L
.7346 .16187 L
s
.678 .847 .902 r
.7346 .16187 m
.7346 .34276 L
.73483 .34276 L
.73483 .16187 L
F
.2 .63 .79 r
.7346 .16187 m
.7346 .34276 L
.73483 .34276 L
.73483 .16187 L
s
.678 .847 .902 r
.73483 .16187 m
.73483 .34295 L
.7353 .34295 L
.7353 .16187 L
F
.2 .63 .79 r
.73483 .16187 m
.73483 .34295 L
.7353 .34295 L
.7353 .16187 L
s
.678 .847 .902 r
.7353 .16187 m
.7353 .34354 L
.73575 .34354 L
.73575 .16187 L
F
.2 .63 .79 r
.7353 .16187 m
.7353 .34354 L
.73575 .34354 L
.73575 .16187 L
s
.678 .847 .902 r
.73575 .16187 m
.73575 .34364 L
.73611 .34364 L
.73611 .16187 L
F
.2 .63 .79 r
.73575 .16187 m
.73575 .34364 L
.73611 .34364 L
.73611 .16187 L
s
.678 .847 .902 r
.73611 .16187 m
.73611 .34398 L
.73634 .34398 L
.73634 .16187 L
F
.2 .63 .79 r
.73611 .16187 m
.73611 .34398 L
.73634 .34398 L
.73634 .16187 L
s
.678 .847 .902 r
.73634 .16187 m
.73634 .34427 L
.73667 .34427 L
.73667 .16187 L
F
.2 .63 .79 r
.73634 .16187 m
.73634 .34427 L
.73667 .34427 L
.73667 .16187 L
s
.678 .847 .902 r
.73667 .16187 m
.73667 .34458 L
.73688 .34458 L
.73688 .16187 L
F
.2 .63 .79 r
.73667 .16187 m
.73667 .34458 L
.73688 .34458 L
.73688 .16187 L
s
.678 .847 .902 r
.73688 .16187 m
.73688 .34512 L
.73736 .34512 L
.73736 .16187 L
F
.2 .63 .79 r
.73688 .16187 m
.73688 .34512 L
.73736 .34512 L
.73736 .16187 L
s
.678 .847 .902 r
.73736 .16187 m
.73736 .34541 L
.73783 .34541 L
.73783 .16187 L
F
.2 .63 .79 r
.73736 .16187 m
.73736 .34541 L
.73783 .34541 L
.73783 .16187 L
s
.678 .847 .902 r
.73783 .16187 m
.73783 .34568 L
.73808 .34568 L
.73808 .16187 L
F
.2 .63 .79 r
.73783 .16187 m
.73783 .34568 L
.73808 .34568 L
.73808 .16187 L
s
.678 .847 .902 r
.73808 .16187 m
.73808 .34599 L
.73829 .34599 L
.73829 .16187 L
F
.2 .63 .79 r
.73808 .16187 m
.73808 .34599 L
.73829 .34599 L
.73829 .16187 L
s
.678 .847 .902 r
.73829 .16187 m
.73829 .34601 L
.73851 .34601 L
.73851 .16187 L
F
.2 .63 .79 r
.73829 .16187 m
.73829 .34601 L
.73851 .34601 L
.73851 .16187 L
s
.678 .847 .902 r
.73851 .16187 m
.73851 .34636 L
.73884 .34636 L
.73884 .16187 L
F
.2 .63 .79 r
.73851 .16187 m
.73851 .34636 L
.73884 .34636 L
.73884 .16187 L
s
.678 .847 .902 r
.73884 .16187 m
.73884 .34679 L
.73919 .34679 L
.73919 .16187 L
F
.2 .63 .79 r
.73884 .16187 m
.73884 .34679 L
.73919 .34679 L
.73919 .16187 L
s
.678 .847 .902 r
.73919 .16187 m
.73919 .34718 L
.73967 .34718 L
.73967 .16187 L
F
.2 .63 .79 r
.73919 .16187 m
.73919 .34718 L
.73967 .34718 L
.73967 .16187 L
s
.678 .847 .902 r
.73967 .16187 m
.73967 .3473 L
.73985 .3473 L
.73985 .16187 L
F
.2 .63 .79 r
.73967 .16187 m
.73967 .3473 L
.73985 .3473 L
.73985 .16187 L
s
.678 .847 .902 r
.73985 .16187 m
.73985 .3477 L
.74033 .3477 L
.74033 .16187 L
F
.2 .63 .79 r
.73985 .16187 m
.73985 .3477 L
.74033 .3477 L
.74033 .16187 L
s
.678 .847 .902 r
.74033 .16187 m
.74033 .34814 L
.74081 .34814 L
.74081 .16187 L
F
.2 .63 .79 r
.74033 .16187 m
.74033 .34814 L
.74081 .34814 L
.74081 .16187 L
s
.678 .847 .902 r
.74081 .16187 m
.74081 .34869 L
.74126 .34869 L
.74126 .16187 L
F
.2 .63 .79 r
.74081 .16187 m
.74081 .34869 L
.74126 .34869 L
.74126 .16187 L
s
.678 .847 .902 r
.74126 .16187 m
.74126 .34885 L
.74159 .34885 L
.74159 .16187 L
F
.2 .63 .79 r
.74126 .16187 m
.74126 .34885 L
.74159 .34885 L
.74159 .16187 L
s
.678 .847 .902 r
.74159 .16187 m
.74159 .3492 L
.74178 .3492 L
.74178 .16187 L
F
.2 .63 .79 r
.74159 .16187 m
.74159 .3492 L
.74178 .3492 L
.74178 .16187 L
s
.678 .847 .902 r
.74178 .16187 m
.74178 .34945 L
.74203 .34945 L
.74203 .16187 L
F
.2 .63 .79 r
.74178 .16187 m
.74178 .34945 L
.74203 .34945 L
.74203 .16187 L
s
.678 .847 .902 r
.74203 .16187 m
.74203 .34967 L
.74232 .34967 L
.74232 .16187 L
F
.2 .63 .79 r
.74203 .16187 m
.74203 .34967 L
.74232 .34967 L
.74232 .16187 L
s
.678 .847 .902 r
.74232 .16187 m
.74232 .34982 L
.74254 .34982 L
.74254 .16187 L
F
.2 .63 .79 r
.74232 .16187 m
.74232 .34982 L
.74254 .34982 L
.74254 .16187 L
s
.678 .847 .902 r
.74254 .16187 m
.74254 .34995 L
.74298 .34995 L
.74298 .16187 L
F
.2 .63 .79 r
.74254 .16187 m
.74254 .34995 L
.74298 .34995 L
.74298 .16187 L
s
.678 .847 .902 r
.74298 .16187 m
.74298 .35051 L
.74326 .35051 L
.74326 .16187 L
F
.2 .63 .79 r
.74298 .16187 m
.74298 .35051 L
.74326 .35051 L
.74326 .16187 L
s
.678 .847 .902 r
.74326 .16187 m
.74326 .35092 L
.7436 .35092 L
.7436 .16187 L
F
.2 .63 .79 r
.74326 .16187 m
.74326 .35092 L
.7436 .35092 L
.7436 .16187 L
s
.678 .847 .902 r
.7436 .16187 m
.7436 .35105 L
.74395 .35105 L
.74395 .16187 L
F
.2 .63 .79 r
.7436 .16187 m
.7436 .35105 L
.74395 .35105 L
.74395 .16187 L
s
.678 .847 .902 r
.74395 .16187 m
.74395 .35156 L
.74431 .35156 L
.74431 .16187 L
F
.2 .63 .79 r
.74395 .16187 m
.74395 .35156 L
.74431 .35156 L
.74431 .16187 L
s
.678 .847 .902 r
.74431 .16187 m
.74431 .35172 L
.74474 .35172 L
.74474 .16187 L
F
.2 .63 .79 r
.74431 .16187 m
.74431 .35172 L
.74474 .35172 L
.74474 .16187 L
s
.678 .847 .902 r
.74474 .16187 m
.74474 .35212 L
.74502 .35212 L
.74502 .16187 L
F
.2 .63 .79 r
.74474 .16187 m
.74474 .35212 L
.74502 .35212 L
.74502 .16187 L
s
.678 .847 .902 r
.74502 .16187 m
.74502 .35239 L
.74539 .35239 L
.74539 .16187 L
F
.2 .63 .79 r
.74502 .16187 m
.74502 .35239 L
.74539 .35239 L
.74539 .16187 L
s
.678 .847 .902 r
.74539 .16187 m
.74539 .35269 L
.74577 .35269 L
.74577 .16187 L
F
.2 .63 .79 r
.74539 .16187 m
.74539 .35269 L
.74577 .35269 L
.74577 .16187 L
s
.678 .847 .902 r
.74577 .16187 m
.74577 .3532 L
.7461 .3532 L
.7461 .16187 L
F
.2 .63 .79 r
.74577 .16187 m
.74577 .3532 L
.7461 .3532 L
.7461 .16187 L
s
.678 .847 .902 r
.7461 .16187 m
.7461 .35337 L
.74631 .35337 L
.74631 .16187 L
F
.2 .63 .79 r
.7461 .16187 m
.7461 .35337 L
.74631 .35337 L
.74631 .16187 L
s
.678 .847 .902 r
.74631 .16187 m
.74631 .35354 L
.74661 .35354 L
.74661 .16187 L
F
.2 .63 .79 r
.74631 .16187 m
.74631 .35354 L
.74661 .35354 L
.74661 .16187 L
s
.678 .847 .902 r
.74661 .16187 m
.74661 .35387 L
.74681 .35387 L
.74681 .16187 L
F
.2 .63 .79 r
.74661 .16187 m
.74661 .35387 L
.74681 .35387 L
.74681 .16187 L
s
.678 .847 .902 r
.74681 .16187 m
.74681 .35433 L
.74728 .35433 L
.74728 .16187 L
F
.2 .63 .79 r
.74681 .16187 m
.74681 .35433 L
.74728 .35433 L
.74728 .16187 L
s
.678 .847 .902 r
.74728 .16187 m
.74728 .35452 L
.7475 .35452 L
.7475 .16187 L
F
.2 .63 .79 r
.74728 .16187 m
.74728 .35452 L
.7475 .35452 L
.7475 .16187 L
s
.678 .847 .902 r
.7475 .16187 m
.7475 .3546 L
.74778 .3546 L
.74778 .16187 L
F
.2 .63 .79 r
.7475 .16187 m
.7475 .3546 L
.74778 .3546 L
.74778 .16187 L
s
.678 .847 .902 r
.74778 .16187 m
.74778 .35486 L
.74798 .35486 L
.74798 .16187 L
F
.2 .63 .79 r
.74778 .16187 m
.74778 .35486 L
.74798 .35486 L
.74798 .16187 L
s
.678 .847 .902 r
.74798 .16187 m
.74798 .35517 L
.74847 .35517 L
.74847 .16187 L
F
.2 .63 .79 r
.74798 .16187 m
.74798 .35517 L
.74847 .35517 L
.74847 .16187 L
s
.678 .847 .902 r
.74847 .16187 m
.74847 .3557 L
.74873 .3557 L
.74873 .16187 L
F
.2 .63 .79 r
.74847 .16187 m
.74847 .3557 L
.74873 .3557 L
.74873 .16187 L
s
.678 .847 .902 r
.74873 .16187 m
.74873 .35603 L
.74916 .35603 L
.74916 .16187 L
F
.2 .63 .79 r
.74873 .16187 m
.74873 .35603 L
.74916 .35603 L
.74916 .16187 L
s
.678 .847 .902 r
.74916 .16187 m
.74916 .35618 L
.74933 .35618 L
.74933 .16187 L
F
.2 .63 .79 r
.74916 .16187 m
.74916 .35618 L
.74933 .35618 L
.74933 .16187 L
s
.678 .847 .902 r
.74933 .16187 m
.74933 .35642 L
.74972 .35642 L
.74972 .16187 L
F
.2 .63 .79 r
.74933 .16187 m
.74933 .35642 L
.74972 .35642 L
.74972 .16187 L
s
.678 .847 .902 r
.74972 .16187 m
.74972 .3567 L
.75018 .3567 L
.75018 .16187 L
F
.2 .63 .79 r
.74972 .16187 m
.74972 .3567 L
.75018 .3567 L
.75018 .16187 L
s
.678 .847 .902 r
.75018 .16187 m
.75018 .3572 L
.75053 .3572 L
.75053 .16187 L
F
.2 .63 .79 r
.75018 .16187 m
.75018 .3572 L
.75053 .3572 L
.75053 .16187 L
s
.678 .847 .902 r
.75053 .16187 m
.75053 .35748 L
.75076 .35748 L
.75076 .16187 L
F
.2 .63 .79 r
.75053 .16187 m
.75053 .35748 L
.75076 .35748 L
.75076 .16187 L
s
.678 .847 .902 r
.75076 .16187 m
.75076 .35782 L
.75102 .35782 L
.75102 .16187 L
F
.2 .63 .79 r
.75076 .16187 m
.75076 .35782 L
.75102 .35782 L
.75102 .16187 L
s
.678 .847 .902 r
.75102 .16187 m
.75102 .35791 L
.75128 .35791 L
.75128 .16187 L
F
.2 .63 .79 r
.75102 .16187 m
.75102 .35791 L
.75128 .35791 L
.75128 .16187 L
s
.678 .847 .902 r
.75128 .16187 m
.75128 .35858 L
.75178 .35858 L
.75178 .16187 L
F
.2 .63 .79 r
.75128 .16187 m
.75128 .35858 L
.75178 .35858 L
.75178 .16187 L
s
.678 .847 .902 r
.75178 .16187 m
.75178 .35871 L
.75214 .35871 L
.75214 .16187 L
F
.2 .63 .79 r
.75178 .16187 m
.75178 .35871 L
.75214 .35871 L
.75214 .16187 L
s
.678 .847 .902 r
.75214 .16187 m
.75214 .35907 L
.75245 .35907 L
.75245 .16187 L
F
.2 .63 .79 r
.75214 .16187 m
.75214 .35907 L
.75245 .35907 L
.75245 .16187 L
s
.678 .847 .902 r
.75245 .16187 m
.75245 .35952 L
.75293 .35952 L
.75293 .16187 L
F
.2 .63 .79 r
.75245 .16187 m
.75245 .35952 L
.75293 .35952 L
.75293 .16187 L
s
.678 .847 .902 r
.75293 .16187 m
.75293 .35984 L
.7532 .35984 L
.7532 .16187 L
F
.2 .63 .79 r
.75293 .16187 m
.75293 .35984 L
.7532 .35984 L
.7532 .16187 L
s
.678 .847 .902 r
.7532 .16187 m
.7532 .35997 L
.75368 .35997 L
.75368 .16187 L
F
.2 .63 .79 r
.7532 .16187 m
.7532 .35997 L
.75368 .35997 L
.75368 .16187 L
s
.678 .847 .902 r
.75368 .16187 m
.75368 .36068 L
.75415 .36068 L
.75415 .16187 L
F
.2 .63 .79 r
.75368 .16187 m
.75368 .36068 L
.75415 .36068 L
.75415 .16187 L
s
.678 .847 .902 r
.75415 .16187 m
.75415 .3609 L
.75457 .3609 L
.75457 .16187 L
F
.2 .63 .79 r
.75415 .16187 m
.75415 .3609 L
.75457 .3609 L
.75457 .16187 L
s
.678 .847 .902 r
.75457 .16187 m
.75457 .36138 L
.75503 .36138 L
.75503 .16187 L
F
.2 .63 .79 r
.75457 .16187 m
.75457 .36138 L
.75503 .36138 L
.75503 .16187 L
s
.678 .847 .902 r
.75503 .16187 m
.75503 .36183 L
.75546 .36183 L
.75546 .16187 L
F
.2 .63 .79 r
.75503 .16187 m
.75503 .36183 L
.75546 .36183 L
.75546 .16187 L
s
.678 .847 .902 r
.75546 .16187 m
.75546 .36243 L
.75595 .36243 L
.75595 .16187 L
F
.2 .63 .79 r
.75546 .16187 m
.75546 .36243 L
.75595 .36243 L
.75595 .16187 L
s
.678 .847 .902 r
.75595 .16187 m
.75595 .3627 L
.7563 .3627 L
.7563 .16187 L
F
.2 .63 .79 r
.75595 .16187 m
.75595 .3627 L
.7563 .3627 L
.7563 .16187 L
s
.678 .847 .902 r
.7563 .16187 m
.7563 .36297 L
.75663 .36297 L
.75663 .16187 L
F
.2 .63 .79 r
.7563 .16187 m
.7563 .36297 L
.75663 .36297 L
.75663 .16187 L
s
.678 .847 .902 r
.75663 .16187 m
.75663 .3633 L
.75701 .3633 L
.75701 .16187 L
F
.2 .63 .79 r
.75663 .16187 m
.75663 .3633 L
.75701 .3633 L
.75701 .16187 L
s
.678 .847 .902 r
.75701 .16187 m
.75701 .36363 L
.75716 .36363 L
.75716 .16187 L
F
.2 .63 .79 r
.75701 .16187 m
.75701 .36363 L
.75716 .36363 L
.75716 .16187 L
s
.678 .847 .902 r
.75716 .16187 m
.75716 .36384 L
.75739 .36384 L
.75739 .16187 L
F
.2 .63 .79 r
.75716 .16187 m
.75716 .36384 L
.75739 .36384 L
.75739 .16187 L
s
.678 .847 .902 r
.75739 .16187 m
.75739 .36413 L
.75778 .36413 L
.75778 .16187 L
F
.2 .63 .79 r
.75739 .16187 m
.75739 .36413 L
.75778 .36413 L
.75778 .16187 L
s
.678 .847 .902 r
.75778 .16187 m
.75778 .36432 L
.75814 .36432 L
.75814 .16187 L
F
.2 .63 .79 r
.75778 .16187 m
.75778 .36432 L
.75814 .36432 L
.75814 .16187 L
s
.678 .847 .902 r
.75814 .16187 m
.75814 .36467 L
.75839 .36467 L
.75839 .16187 L
F
.2 .63 .79 r
.75814 .16187 m
.75814 .36467 L
.75839 .36467 L
.75839 .16187 L
s
.678 .847 .902 r
.75839 .16187 m
.75839 .36502 L
.75865 .36502 L
.75865 .16187 L
F
.2 .63 .79 r
.75839 .16187 m
.75839 .36502 L
.75865 .36502 L
.75865 .16187 L
s
.678 .847 .902 r
.75865 .16187 m
.75865 .36518 L
.75884 .36518 L
.75884 .16187 L
F
.2 .63 .79 r
.75865 .16187 m
.75865 .36518 L
.75884 .36518 L
.75884 .16187 L
s
.678 .847 .902 r
.75884 .16187 m
.75884 .36554 L
.75912 .36554 L
.75912 .16187 L
F
.2 .63 .79 r
.75884 .16187 m
.75884 .36554 L
.75912 .36554 L
.75912 .16187 L
s
.678 .847 .902 r
.75912 .16187 m
.75912 .36576 L
.75961 .36576 L
.75961 .16187 L
F
.2 .63 .79 r
.75912 .16187 m
.75912 .36576 L
.75961 .36576 L
.75961 .16187 L
s
.678 .847 .902 r
.75961 .16187 m
.75961 .36625 L
.76009 .36625 L
.76009 .16187 L
F
.2 .63 .79 r
.75961 .16187 m
.75961 .36625 L
.76009 .36625 L
.76009 .16187 L
s
.678 .847 .902 r
.76009 .16187 m
.76009 .36657 L
.76028 .36657 L
.76028 .16187 L
F
.2 .63 .79 r
.76009 .16187 m
.76009 .36657 L
.76028 .36657 L
.76028 .16187 L
s
.678 .847 .902 r
.76028 .16187 m
.76028 .3669 L
.76069 .3669 L
.76069 .16187 L
F
.2 .63 .79 r
.76028 .16187 m
.76028 .3669 L
.76069 .3669 L
.76069 .16187 L
s
.678 .847 .902 r
.76069 .16187 m
.76069 .36739 L
.76101 .36739 L
.76101 .16187 L
F
.2 .63 .79 r
.76069 .16187 m
.76069 .36739 L
.76101 .36739 L
.76101 .16187 L
s
.678 .847 .902 r
.76101 .16187 m
.76101 .36751 L
.76117 .36751 L
.76117 .16187 L
F
.2 .63 .79 r
.76101 .16187 m
.76101 .36751 L
.76117 .36751 L
.76117 .16187 L
s
.678 .847 .902 r
.76117 .16187 m
.76117 .36783 L
.76158 .36783 L
.76158 .16187 L
F
.2 .63 .79 r
.76117 .16187 m
.76117 .36783 L
.76158 .36783 L
.76158 .16187 L
s
.678 .847 .902 r
.76158 .16187 m
.76158 .36814 L
.76201 .36814 L
.76201 .16187 L
F
.2 .63 .79 r
.76158 .16187 m
.76158 .36814 L
.76201 .36814 L
.76201 .16187 L
s
.678 .847 .902 r
.76201 .16187 m
.76201 .36846 L
.76234 .36846 L
.76234 .16187 L
F
.2 .63 .79 r
.76201 .16187 m
.76201 .36846 L
.76234 .36846 L
.76234 .16187 L
s
.678 .847 .902 r
.76234 .16187 m
.76234 .36883 L
.76257 .36883 L
.76257 .16187 L
F
.2 .63 .79 r
.76234 .16187 m
.76234 .36883 L
.76257 .36883 L
.76257 .16187 L
s
.678 .847 .902 r
.76257 .16187 m
.76257 .36907 L
.76301 .36907 L
.76301 .16187 L
F
.2 .63 .79 r
.76257 .16187 m
.76257 .36907 L
.76301 .36907 L
.76301 .16187 L
s
.678 .847 .902 r
.76301 .16187 m
.76301 .36938 L
.7635 .36938 L
.7635 .16187 L
F
.2 .63 .79 r
.76301 .16187 m
.76301 .36938 L
.7635 .36938 L
.7635 .16187 L
s
.678 .847 .902 r
.7635 .16187 m
.7635 .36999 L
.76384 .36999 L
.76384 .16187 L
F
.2 .63 .79 r
.7635 .16187 m
.7635 .36999 L
.76384 .36999 L
.76384 .16187 L
s
.678 .847 .902 r
.76384 .16187 m
.76384 .37022 L
.76421 .37022 L
.76421 .16187 L
F
.2 .63 .79 r
.76384 .16187 m
.76384 .37022 L
.76421 .37022 L
.76421 .16187 L
s
.678 .847 .902 r
.76421 .16187 m
.76421 .37051 L
.76447 .37051 L
.76447 .16187 L
F
.2 .63 .79 r
.76421 .16187 m
.76421 .37051 L
.76447 .37051 L
.76447 .16187 L
s
.678 .847 .902 r
.76447 .16187 m
.76447 .37093 L
.76473 .37093 L
.76473 .16187 L
F
.2 .63 .79 r
.76447 .16187 m
.76447 .37093 L
.76473 .37093 L
.76473 .16187 L
s
.678 .847 .902 r
.76473 .16187 m
.76473 .37104 L
.76507 .37104 L
.76507 .16187 L
F
.2 .63 .79 r
.76473 .16187 m
.76473 .37104 L
.76507 .37104 L
.76507 .16187 L
s
.678 .847 .902 r
.76507 .16187 m
.76507 .37149 L
.76536 .37149 L
.76536 .16187 L
F
.2 .63 .79 r
.76507 .16187 m
.76507 .37149 L
.76536 .37149 L
.76536 .16187 L
s
.678 .847 .902 r
.76536 .16187 m
.76536 .3718 L
.76571 .3718 L
.76571 .16187 L
F
.2 .63 .79 r
.76536 .16187 m
.76536 .3718 L
.76571 .3718 L
.76571 .16187 L
s
.678 .847 .902 r
.76571 .16187 m
.76571 .37224 L
.76611 .37224 L
.76611 .16187 L
F
.2 .63 .79 r
.76571 .16187 m
.76571 .37224 L
.76611 .37224 L
.76611 .16187 L
s
.678 .847 .902 r
.76611 .16187 m
.76611 .37233 L
.76635 .37233 L
.76635 .16187 L
F
.2 .63 .79 r
.76611 .16187 m
.76611 .37233 L
.76635 .37233 L
.76635 .16187 L
s
.678 .847 .902 r
.76635 .16187 m
.76635 .37255 L
.76652 .37255 L
.76652 .16187 L
F
.2 .63 .79 r
.76635 .16187 m
.76635 .37255 L
.76652 .37255 L
.76652 .16187 L
s
.678 .847 .902 r
.76652 .16187 m
.76652 .37282 L
.76683 .37282 L
.76683 .16187 L
F
.2 .63 .79 r
.76652 .16187 m
.76652 .37282 L
.76683 .37282 L
.76683 .16187 L
s
.678 .847 .902 r
.76683 .16187 m
.76683 .37299 L
.7671 .37299 L
.7671 .16187 L
F
.2 .63 .79 r
.76683 .16187 m
.76683 .37299 L
.7671 .37299 L
.7671 .16187 L
s
.678 .847 .902 r
.7671 .16187 m
.7671 .37342 L
.76734 .37342 L
.76734 .16187 L
F
.2 .63 .79 r
.7671 .16187 m
.7671 .37342 L
.76734 .37342 L
.76734 .16187 L
s
.678 .847 .902 r
.76734 .16187 m
.76734 .37361 L
.76752 .37361 L
.76752 .16187 L
F
.2 .63 .79 r
.76734 .16187 m
.76734 .37361 L
.76752 .37361 L
.76752 .16187 L
s
.678 .847 .902 r
.76752 .16187 m
.76752 .37369 L
.76779 .37369 L
.76779 .16187 L
F
.2 .63 .79 r
.76752 .16187 m
.76752 .37369 L
.76779 .37369 L
.76779 .16187 L
s
.678 .847 .902 r
.76779 .16187 m
.76779 .37408 L
.76814 .37408 L
.76814 .16187 L
F
.2 .63 .79 r
.76779 .16187 m
.76779 .37408 L
.76814 .37408 L
.76814 .16187 L
s
.678 .847 .902 r
.76814 .16187 m
.76814 .37457 L
.76856 .37457 L
.76856 .16187 L
F
.2 .63 .79 r
.76814 .16187 m
.76814 .37457 L
.76856 .37457 L
.76856 .16187 L
s
.678 .847 .902 r
.76856 .16187 m
.76856 .3748 L
.76873 .3748 L
.76873 .16187 L
F
.2 .63 .79 r
.76856 .16187 m
.76856 .3748 L
.76873 .3748 L
.76873 .16187 L
s
.678 .847 .902 r
.76873 .16187 m
.76873 .37495 L
.76908 .37495 L
.76908 .16187 L
F
.2 .63 .79 r
.76873 .16187 m
.76873 .37495 L
.76908 .37495 L
.76908 .16187 L
s
.678 .847 .902 r
.76908 .16187 m
.76908 .37516 L
.76949 .37516 L
.76949 .16187 L
F
.2 .63 .79 r
.76908 .16187 m
.76908 .37516 L
.76949 .37516 L
.76949 .16187 L
s
.678 .847 .902 r
.76949 .16187 m
.76949 .37564 L
.76972 .37564 L
.76972 .16187 L
F
.2 .63 .79 r
.76949 .16187 m
.76949 .37564 L
.76972 .37564 L
.76972 .16187 L
s
.678 .847 .902 r
.76972 .16187 m
.76972 .37586 L
.77016 .37586 L
.77016 .16187 L
F
.2 .63 .79 r
.76972 .16187 m
.76972 .37586 L
.77016 .37586 L
.77016 .16187 L
s
.678 .847 .902 r
.77016 .16187 m
.77016 .37657 L
.77056 .37657 L
.77056 .16187 L
F
.2 .63 .79 r
.77016 .16187 m
.77016 .37657 L
.77056 .37657 L
.77056 .16187 L
s
.678 .847 .902 r
.77056 .16187 m
.77056 .37693 L
.77097 .37693 L
.77097 .16187 L
F
.2 .63 .79 r
.77056 .16187 m
.77056 .37693 L
.77097 .37693 L
.77097 .16187 L
s
.678 .847 .902 r
.77097 .16187 m
.77097 .37727 L
.77135 .37727 L
.77135 .16187 L
F
.2 .63 .79 r
.77097 .16187 m
.77097 .37727 L
.77135 .37727 L
.77135 .16187 L
s
.678 .847 .902 r
.77135 .16187 m
.77135 .37753 L
.77156 .37753 L
.77156 .16187 L
F
.2 .63 .79 r
.77135 .16187 m
.77135 .37753 L
.77156 .37753 L
.77156 .16187 L
s
.678 .847 .902 r
.77156 .16187 m
.77156 .37777 L
.77186 .37777 L
.77186 .16187 L
F
.2 .63 .79 r
.77156 .16187 m
.77156 .37777 L
.77186 .37777 L
.77186 .16187 L
s
.678 .847 .902 r
.77186 .16187 m
.77186 .37812 L
.77215 .37812 L
.77215 .16187 L
F
.2 .63 .79 r
.77186 .16187 m
.77186 .37812 L
.77215 .37812 L
.77215 .16187 L
s
.678 .847 .902 r
.77215 .16187 m
.77215 .37823 L
.77234 .37823 L
.77234 .16187 L
F
.2 .63 .79 r
.77215 .16187 m
.77215 .37823 L
.77234 .37823 L
.77234 .16187 L
s
.678 .847 .902 r
.77234 .16187 m
.77234 .37837 L
.77276 .37837 L
.77276 .16187 L
F
.2 .63 .79 r
.77234 .16187 m
.77234 .37837 L
.77276 .37837 L
.77276 .16187 L
s
.678 .847 .902 r
.77276 .16187 m
.77276 .37875 L
.77319 .37875 L
.77319 .16187 L
F
.2 .63 .79 r
.77276 .16187 m
.77276 .37875 L
.77319 .37875 L
.77319 .16187 L
s
.678 .847 .902 r
.77319 .16187 m
.77319 .37918 L
.77358 .37918 L
.77358 .16187 L
F
.2 .63 .79 r
.77319 .16187 m
.77319 .37918 L
.77358 .37918 L
.77358 .16187 L
s
.678 .847 .902 r
.77358 .16187 m
.77358 .37968 L
.77402 .37968 L
.77402 .16187 L
F
.2 .63 .79 r
.77358 .16187 m
.77358 .37968 L
.77402 .37968 L
.77402 .16187 L
s
.678 .847 .902 r
.77402 .16187 m
.77402 .3803 L
.77442 .3803 L
.77442 .16187 L
F
.2 .63 .79 r
.77402 .16187 m
.77402 .3803 L
.77442 .3803 L
.77442 .16187 L
s
.678 .847 .902 r
.77442 .16187 m
.77442 .38049 L
.77468 .38049 L
.77468 .16187 L
F
.2 .63 .79 r
.77442 .16187 m
.77442 .38049 L
.77468 .38049 L
.77468 .16187 L
s
.678 .847 .902 r
.77468 .16187 m
.77468 .38061 L
.77495 .38061 L
.77495 .16187 L
F
.2 .63 .79 r
.77468 .16187 m
.77468 .38061 L
.77495 .38061 L
.77495 .16187 L
s
.678 .847 .902 r
.77495 .16187 m
.77495 .38106 L
.7753 .38106 L
.7753 .16187 L
F
.2 .63 .79 r
.77495 .16187 m
.77495 .38106 L
.7753 .38106 L
.7753 .16187 L
s
.678 .847 .902 r
.7753 .16187 m
.7753 .38124 L
.77567 .38124 L
.77567 .16187 L
F
.2 .63 .79 r
.7753 .16187 m
.7753 .38124 L
.77567 .38124 L
.77567 .16187 L
s
.678 .847 .902 r
.77567 .16187 m
.77567 .38177 L
.77616 .38177 L
.77616 .16187 L
F
.2 .63 .79 r
.77567 .16187 m
.77567 .38177 L
.77616 .38177 L
.77616 .16187 L
s
.678 .847 .902 r
.77616 .16187 m
.77616 .38225 L
.77657 .38225 L
.77657 .16187 L
F
.2 .63 .79 r
.77616 .16187 m
.77616 .38225 L
.77657 .38225 L
.77657 .16187 L
s
.678 .847 .902 r
.77657 .16187 m
.77657 .38276 L
.77699 .38276 L
.77699 .16187 L
F
.2 .63 .79 r
.77657 .16187 m
.77657 .38276 L
.77699 .38276 L
.77699 .16187 L
s
.678 .847 .902 r
.77699 .16187 m
.77699 .38291 L
.77734 .38291 L
.77734 .16187 L
F
.2 .63 .79 r
.77699 .16187 m
.77699 .38291 L
.77734 .38291 L
.77734 .16187 L
s
.678 .847 .902 r
.77734 .16187 m
.77734 .38319 L
.77762 .38319 L
.77762 .16187 L
F
.2 .63 .79 r
.77734 .16187 m
.77734 .38319 L
.77762 .38319 L
.77762 .16187 L
s
.678 .847 .902 r
.77762 .16187 m
.77762 .38354 L
.77777 .38354 L
.77777 .16187 L
F
.2 .63 .79 r
.77762 .16187 m
.77762 .38354 L
.77777 .38354 L
.77777 .16187 L
s
.678 .847 .902 r
.77777 .16187 m
.77777 .38373 L
.77811 .38373 L
.77811 .16187 L
F
.2 .63 .79 r
.77777 .16187 m
.77777 .38373 L
.77811 .38373 L
.77811 .16187 L
s
.678 .847 .902 r
.77811 .16187 m
.77811 .38433 L
.77851 .38433 L
.77851 .16187 L
F
.2 .63 .79 r
.77811 .16187 m
.77811 .38433 L
.77851 .38433 L
.77851 .16187 L
s
.678 .847 .902 r
.77851 .16187 m
.77851 .38435 L
.77888 .38435 L
.77888 .16187 L
F
.2 .63 .79 r
.77851 .16187 m
.77851 .38435 L
.77888 .38435 L
.77888 .16187 L
s
.678 .847 .902 r
.77888 .16187 m
.77888 .38485 L
.77911 .38485 L
.77911 .16187 L
F
.2 .63 .79 r
.77888 .16187 m
.77888 .38485 L
.77911 .38485 L
.77911 .16187 L
s
.678 .847 .902 r
.77911 .16187 m
.77911 .38519 L
.77957 .38519 L
.77957 .16187 L
F
.2 .63 .79 r
.77911 .16187 m
.77911 .38519 L
.77957 .38519 L
.77957 .16187 L
s
.678 .847 .902 r
.77957 .16187 m
.77957 .38541 L
.7799 .38541 L
.7799 .16187 L
F
.2 .63 .79 r
.77957 .16187 m
.77957 .38541 L
.7799 .38541 L
.7799 .16187 L
s
.678 .847 .902 r
.7799 .16187 m
.7799 .38577 L
.78013 .38577 L
.78013 .16187 L
F
.2 .63 .79 r
.7799 .16187 m
.7799 .38577 L
.78013 .38577 L
.78013 .16187 L
s
.678 .847 .902 r
.78013 .16187 m
.78013 .38621 L
.78055 .38621 L
.78055 .16187 L
F
.2 .63 .79 r
.78013 .16187 m
.78013 .38621 L
.78055 .38621 L
.78055 .16187 L
s
.678 .847 .902 r
.78055 .16187 m
.78055 .38636 L
.78098 .38636 L
.78098 .16187 L
F
.2 .63 .79 r
.78055 .16187 m
.78055 .38636 L
.78098 .38636 L
.78098 .16187 L
s
.678 .847 .902 r
.78098 .16187 m
.78098 .38713 L
.78138 .38713 L
.78138 .16187 L
F
.2 .63 .79 r
.78098 .16187 m
.78098 .38713 L
.78138 .38713 L
.78138 .16187 L
s
.678 .847 .902 r
.78138 .16187 m
.78138 .38721 L
.78167 .38721 L
.78167 .16187 L
F
.2 .63 .79 r
.78138 .16187 m
.78138 .38721 L
.78167 .38721 L
.78167 .16187 L
s
.678 .847 .902 r
.78167 .16187 m
.78167 .38754 L
.78185 .38754 L
.78185 .16187 L
F
.2 .63 .79 r
.78167 .16187 m
.78167 .38754 L
.78185 .38754 L
.78185 .16187 L
s
.678 .847 .902 r
.78185 .16187 m
.78185 .38793 L
.78232 .38793 L
.78232 .16187 L
F
.2 .63 .79 r
.78185 .16187 m
.78185 .38793 L
.78232 .38793 L
.78232 .16187 L
s
.678 .847 .902 r
.78232 .16187 m
.78232 .38808 L
.78248 .38808 L
.78248 .16187 L
F
.2 .63 .79 r
.78232 .16187 m
.78232 .38808 L
.78248 .38808 L
.78248 .16187 L
s
.678 .847 .902 r
.78248 .16187 m
.78248 .38833 L
.78264 .38833 L
.78264 .16187 L
F
.2 .63 .79 r
.78248 .16187 m
.78248 .38833 L
.78264 .38833 L
.78264 .16187 L
s
.678 .847 .902 r
.78264 .16187 m
.78264 .38861 L
.78305 .38861 L
.78305 .16187 L
F
.2 .63 .79 r
.78264 .16187 m
.78264 .38861 L
.78305 .38861 L
.78305 .16187 L
s
.678 .847 .902 r
.78305 .16187 m
.78305 .38882 L
.78332 .38882 L
.78332 .16187 L
F
.2 .63 .79 r
.78305 .16187 m
.78305 .38882 L
.78332 .38882 L
.78332 .16187 L
s
.678 .847 .902 r
.78332 .16187 m
.78332 .38931 L
.7836 .38931 L
.7836 .16187 L
F
.2 .63 .79 r
.78332 .16187 m
.78332 .38931 L
.7836 .38931 L
.7836 .16187 L
s
.678 .847 .902 r
.7836 .16187 m
.7836 .38937 L
.78378 .38937 L
.78378 .16187 L
F
.2 .63 .79 r
.7836 .16187 m
.7836 .38937 L
.78378 .38937 L
.78378 .16187 L
s
.678 .847 .902 r
.78378 .16187 m
.78378 .38998 L
.78426 .38998 L
.78426 .16187 L
F
.2 .63 .79 r
.78378 .16187 m
.78378 .38998 L
.78426 .38998 L
.78426 .16187 L
s
.678 .847 .902 r
.78426 .16187 m
.78426 .39009 L
.7846 .39009 L
.7846 .16187 L
F
.2 .63 .79 r
.78426 .16187 m
.78426 .39009 L
.7846 .39009 L
.7846 .16187 L
s
.678 .847 .902 r
.7846 .16187 m
.7846 .39063 L
.78503 .39063 L
.78503 .16187 L
F
.2 .63 .79 r
.7846 .16187 m
.7846 .39063 L
.78503 .39063 L
.78503 .16187 L
s
.678 .847 .902 r
.78503 .16187 m
.78503 .3908 L
.78541 .3908 L
.78541 .16187 L
F
.2 .63 .79 r
.78503 .16187 m
.78503 .3908 L
.78541 .3908 L
.78541 .16187 L
s
.678 .847 .902 r
.78541 .16187 m
.78541 .39134 L
.7859 .39134 L
.7859 .16187 L
F
.2 .63 .79 r
.78541 .16187 m
.78541 .39134 L
.7859 .39134 L
.7859 .16187 L
s
.678 .847 .902 r
.7859 .16187 m
.7859 .39205 L
.78638 .39205 L
.78638 .16187 L
F
.2 .63 .79 r
.7859 .16187 m
.7859 .39205 L
.78638 .39205 L
.78638 .16187 L
s
.678 .847 .902 r
.78638 .16187 m
.78638 .39221 L
.78656 .39221 L
.78656 .16187 L
F
.2 .63 .79 r
.78638 .16187 m
.78638 .39221 L
.78656 .39221 L
.78656 .16187 L
s
.678 .847 .902 r
.78656 .16187 m
.78656 .39227 L
.78672 .39227 L
.78672 .16187 L
F
.2 .63 .79 r
.78656 .16187 m
.78656 .39227 L
.78672 .39227 L
.78672 .16187 L
s
.678 .847 .902 r
.78672 .16187 m
.78672 .39273 L
.78713 .39273 L
.78713 .16187 L
F
.2 .63 .79 r
.78672 .16187 m
.78672 .39273 L
.78713 .39273 L
.78713 .16187 L
s
.678 .847 .902 r
.78713 .16187 m
.78713 .39288 L
.78729 .39288 L
.78729 .16187 L
F
.2 .63 .79 r
.78713 .16187 m
.78713 .39288 L
.78729 .39288 L
.78729 .16187 L
s
.678 .847 .902 r
.78729 .16187 m
.78729 .3932 L
.78763 .3932 L
.78763 .16187 L
F
.2 .63 .79 r
.78729 .16187 m
.78729 .3932 L
.78763 .3932 L
.78763 .16187 L
s
.678 .847 .902 r
.78763 .16187 m
.78763 .39365 L
.78806 .39365 L
.78806 .16187 L
F
.2 .63 .79 r
.78763 .16187 m
.78763 .39365 L
.78806 .39365 L
.78806 .16187 L
s
.678 .847 .902 r
.78806 .16187 m
.78806 .39379 L
.78854 .39379 L
.78854 .16187 L
F
.2 .63 .79 r
.78806 .16187 m
.78806 .39379 L
.78854 .39379 L
.78854 .16187 L
s
.678 .847 .902 r
.78854 .16187 m
.78854 .39428 L
.78877 .39428 L
.78877 .16187 L
F
.2 .63 .79 r
.78854 .16187 m
.78854 .39428 L
.78877 .39428 L
.78877 .16187 L
s
.678 .847 .902 r
.78877 .16187 m
.78877 .39474 L
.7892 .39474 L
.7892 .16187 L
F
.2 .63 .79 r
.78877 .16187 m
.78877 .39474 L
.7892 .39474 L
.7892 .16187 L
s
.678 .847 .902 r
.7892 .16187 m
.7892 .39503 L
.78949 .39503 L
.78949 .16187 L
F
.2 .63 .79 r
.7892 .16187 m
.7892 .39503 L
.78949 .39503 L
.78949 .16187 L
s
.678 .847 .902 r
.78949 .16187 m
.78949 .39538 L
.78993 .39538 L
.78993 .16187 L
F
.2 .63 .79 r
.78949 .16187 m
.78949 .39538 L
.78993 .39538 L
.78993 .16187 L
s
.678 .847 .902 r
.78993 .16187 m
.78993 .39575 L
.79018 .39575 L
.79018 .16187 L
F
.2 .63 .79 r
.78993 .16187 m
.78993 .39575 L
.79018 .39575 L
.79018 .16187 L
s
.678 .847 .902 r
.79018 .16187 m
.79018 .39612 L
.7906 .39612 L
.7906 .16187 L
F
.2 .63 .79 r
.79018 .16187 m
.79018 .39612 L
.7906 .39612 L
.7906 .16187 L
s
.678 .847 .902 r
.7906 .16187 m
.7906 .39652 L
.79087 .39652 L
.79087 .16187 L
F
.2 .63 .79 r
.7906 .16187 m
.7906 .39652 L
.79087 .39652 L
.79087 .16187 L
s
.678 .847 .902 r
.79087 .16187 m
.79087 .39671 L
.79106 .39671 L
.79106 .16187 L
F
.2 .63 .79 r
.79087 .16187 m
.79087 .39671 L
.79106 .39671 L
.79106 .16187 L
s
.678 .847 .902 r
.79106 .16187 m
.79106 .39697 L
.79153 .39697 L
.79153 .16187 L
F
.2 .63 .79 r
.79106 .16187 m
.79106 .39697 L
.79153 .39697 L
.79153 .16187 L
s
.678 .847 .902 r
.79153 .16187 m
.79153 .3974 L
.79182 .3974 L
.79182 .16187 L
F
.2 .63 .79 r
.79153 .16187 m
.79153 .3974 L
.79182 .3974 L
.79182 .16187 L
s
.678 .847 .902 r
.79182 .16187 m
.79182 .39767 L
.79206 .39767 L
.79206 .16187 L
F
.2 .63 .79 r
.79182 .16187 m
.79182 .39767 L
.79206 .39767 L
.79206 .16187 L
s
.678 .847 .902 r
.79206 .16187 m
.79206 .39791 L
.79225 .39791 L
.79225 .16187 L
F
.2 .63 .79 r
.79206 .16187 m
.79206 .39791 L
.79225 .39791 L
.79225 .16187 L
s
.678 .847 .902 r
.79225 .16187 m
.79225 .39798 L
.79254 .39798 L
.79254 .16187 L
F
.2 .63 .79 r
.79225 .16187 m
.79225 .39798 L
.79254 .39798 L
.79254 .16187 L
s
.678 .847 .902 r
.79254 .16187 m
.79254 .3982 L
.79288 .3982 L
.79288 .16187 L
F
.2 .63 .79 r
.79254 .16187 m
.79254 .3982 L
.79288 .3982 L
.79288 .16187 L
s
.678 .847 .902 r
.79288 .16187 m
.79288 .39877 L
.79324 .39877 L
.79324 .16187 L
F
.2 .63 .79 r
.79288 .16187 m
.79288 .39877 L
.79324 .39877 L
.79324 .16187 L
s
.678 .847 .902 r
.79324 .16187 m
.79324 .399 L
.79343 .399 L
.79343 .16187 L
F
.2 .63 .79 r
.79324 .16187 m
.79324 .399 L
.79343 .399 L
.79343 .16187 L
s
.678 .847 .902 r
.79343 .16187 m
.79343 .39918 L
.79373 .39918 L
.79373 .16187 L
F
.2 .63 .79 r
.79343 .16187 m
.79343 .39918 L
.79373 .39918 L
.79373 .16187 L
s
.678 .847 .902 r
.79373 .16187 m
.79373 .39947 L
.79404 .39947 L
.79404 .16187 L
F
.2 .63 .79 r
.79373 .16187 m
.79373 .39947 L
.79404 .39947 L
.79404 .16187 L
s
.678 .847 .902 r
.79404 .16187 m
.79404 .39989 L
.79439 .39989 L
.79439 .16187 L
F
.2 .63 .79 r
.79404 .16187 m
.79404 .39989 L
.79439 .39989 L
.79439 .16187 L
s
.678 .847 .902 r
.79439 .16187 m
.79439 .40025 L
.79467 .40025 L
.79467 .16187 L
F
.2 .63 .79 r
.79439 .16187 m
.79439 .40025 L
.79467 .40025 L
.79467 .16187 L
s
.678 .847 .902 r
.79467 .16187 m
.79467 .40059 L
.79494 .40059 L
.79494 .16187 L
F
.2 .63 .79 r
.79467 .16187 m
.79467 .40059 L
.79494 .40059 L
.79494 .16187 L
s
.678 .847 .902 r
.79494 .16187 m
.79494 .40089 L
.79541 .40089 L
.79541 .16187 L
F
.2 .63 .79 r
.79494 .16187 m
.79494 .40089 L
.79541 .40089 L
.79541 .16187 L
s
.678 .847 .902 r
.79541 .16187 m
.79541 .40139 L
.79582 .40139 L
.79582 .16187 L
F
.2 .63 .79 r
.79541 .16187 m
.79541 .40139 L
.79582 .40139 L
.79582 .16187 L
s
.678 .847 .902 r
.79582 .16187 m
.79582 .40167 L
.79612 .40167 L
.79612 .16187 L
F
.2 .63 .79 r
.79582 .16187 m
.79582 .40167 L
.79612 .40167 L
.79612 .16187 L
s
.678 .847 .902 r
.79612 .16187 m
.79612 .4019 L
.79631 .4019 L
.79631 .16187 L
F
.2 .63 .79 r
.79612 .16187 m
.79612 .4019 L
.79631 .4019 L
.79631 .16187 L
s
.678 .847 .902 r
.79631 .16187 m
.79631 .40214 L
.79649 .40214 L
.79649 .16187 L
F
.2 .63 .79 r
.79631 .16187 m
.79631 .40214 L
.79649 .40214 L
.79649 .16187 L
s
.678 .847 .902 r
.79649 .16187 m
.79649 .40221 L
.79676 .40221 L
.79676 .16187 L
F
.2 .63 .79 r
.79649 .16187 m
.79649 .40221 L
.79676 .40221 L
.79676 .16187 L
s
.678 .847 .902 r
.79676 .16187 m
.79676 .40248 L
.79711 .40248 L
.79711 .16187 L
F
.2 .63 .79 r
.79676 .16187 m
.79676 .40248 L
.79711 .40248 L
.79711 .16187 L
s
.678 .847 .902 r
.79711 .16187 m
.79711 .40279 L
.79754 .40279 L
.79754 .16187 L
F
.2 .63 .79 r
.79711 .16187 m
.79711 .40279 L
.79754 .40279 L
.79754 .16187 L
s
.678 .847 .902 r
.79754 .16187 m
.79754 .40327 L
.79779 .40327 L
.79779 .16187 L
F
.2 .63 .79 r
.79754 .16187 m
.79754 .40327 L
.79779 .40327 L
.79779 .16187 L
s
.678 .847 .902 r
.79779 .16187 m
.79779 .4035 L
.79794 .4035 L
.79794 .16187 L
F
.2 .63 .79 r
.79779 .16187 m
.79779 .4035 L
.79794 .4035 L
.79794 .16187 L
s
.678 .847 .902 r
.79794 .16187 m
.79794 .40367 L
.79825 .40367 L
.79825 .16187 L
F
.2 .63 .79 r
.79794 .16187 m
.79794 .40367 L
.79825 .40367 L
.79825 .16187 L
s
.678 .847 .902 r
.79825 .16187 m
.79825 .40416 L
.7987 .40416 L
.7987 .16187 L
F
.2 .63 .79 r
.79825 .16187 m
.79825 .40416 L
.7987 .40416 L
.7987 .16187 L
s
.678 .847 .902 r
.7987 .16187 m
.7987 .40462 L
.79916 .40462 L
.79916 .16187 L
F
.2 .63 .79 r
.7987 .16187 m
.7987 .40462 L
.79916 .40462 L
.79916 .16187 L
s
.678 .847 .902 r
.79916 .16187 m
.79916 .40504 L
.79956 .40504 L
.79956 .16187 L
F
.2 .63 .79 r
.79916 .16187 m
.79916 .40504 L
.79956 .40504 L
.79956 .16187 L
s
.678 .847 .902 r
.79956 .16187 m
.79956 .40529 L
.79983 .40529 L
.79983 .16187 L
F
.2 .63 .79 r
.79956 .16187 m
.79956 .40529 L
.79983 .40529 L
.79983 .16187 L
s
.678 .847 .902 r
.79983 .16187 m
.79983 .4056 L
.80013 .4056 L
.80013 .16187 L
F
.2 .63 .79 r
.79983 .16187 m
.79983 .4056 L
.80013 .4056 L
.80013 .16187 L
s
.678 .847 .902 r
.80013 .16187 m
.80013 .40596 L
.8004 .40596 L
.8004 .16187 L
F
.2 .63 .79 r
.80013 .16187 m
.80013 .40596 L
.8004 .40596 L
.8004 .16187 L
s
.678 .847 .902 r
.8004 .16187 m
.8004 .40625 L
.80059 .40625 L
.80059 .16187 L
F
.2 .63 .79 r
.8004 .16187 m
.8004 .40625 L
.80059 .40625 L
.80059 .16187 L
s
.678 .847 .902 r
.80059 .16187 m
.80059 .40643 L
.80081 .40643 L
.80081 .16187 L
F
.2 .63 .79 r
.80059 .16187 m
.80059 .40643 L
.80081 .40643 L
.80081 .16187 L
s
.678 .847 .902 r
.80081 .16187 m
.80081 .4065 L
.80096 .4065 L
.80096 .16187 L
F
.2 .63 .79 r
.80081 .16187 m
.80081 .4065 L
.80096 .4065 L
.80096 .16187 L
s
.678 .847 .902 r
.80096 .16187 m
.80096 .40679 L
.80141 .40679 L
.80141 .16187 L
F
.2 .63 .79 r
.80096 .16187 m
.80096 .40679 L
.80141 .40679 L
.80141 .16187 L
s
.678 .847 .902 r
.80141 .16187 m
.80141 .40722 L
.80174 .40722 L
.80174 .16187 L
F
.2 .63 .79 r
.80141 .16187 m
.80141 .40722 L
.80174 .40722 L
.80174 .16187 L
s
.678 .847 .902 r
.80174 .16187 m
.80174 .40787 L
.80218 .40787 L
.80218 .16187 L
F
.2 .63 .79 r
.80174 .16187 m
.80174 .40787 L
.80218 .40787 L
.80218 .16187 L
s
.678 .847 .902 r
.80218 .16187 m
.80218 .40791 L
.80255 .40791 L
.80255 .16187 L
F
.2 .63 .79 r
.80218 .16187 m
.80218 .40791 L
.80255 .40791 L
.80255 .16187 L
s
.678 .847 .902 r
.80255 .16187 m
.80255 .40858 L
.80303 .40858 L
.80303 .16187 L
F
.2 .63 .79 r
.80255 .16187 m
.80255 .40858 L
.80303 .40858 L
.80303 .16187 L
s
.678 .847 .902 r
.80303 .16187 m
.80303 .40897 L
.80344 .40897 L
.80344 .16187 L
F
.2 .63 .79 r
.80303 .16187 m
.80303 .40897 L
.80344 .40897 L
.80344 .16187 L
s
.678 .847 .902 r
.80344 .16187 m
.80344 .40925 L
.80373 .40925 L
.80373 .16187 L
F
.2 .63 .79 r
.80344 .16187 m
.80344 .40925 L
.80373 .40925 L
.80373 .16187 L
s
.678 .847 .902 r
.80373 .16187 m
.80373 .40958 L
.80406 .40958 L
.80406 .16187 L
F
.2 .63 .79 r
.80373 .16187 m
.80373 .40958 L
.80406 .40958 L
.80406 .16187 L
s
.678 .847 .902 r
.80406 .16187 m
.80406 .41012 L
.8045 .41012 L
.8045 .16187 L
F
.2 .63 .79 r
.80406 .16187 m
.80406 .41012 L
.8045 .41012 L
.8045 .16187 L
s
.678 .847 .902 r
.8045 .16187 m
.8045 .41032 L
.80478 .41032 L
.80478 .16187 L
F
.2 .63 .79 r
.8045 .16187 m
.8045 .41032 L
.80478 .41032 L
.80478 .16187 L
s
.678 .847 .902 r
.80478 .16187 m
.80478 .41061 L
.80522 .41061 L
.80522 .16187 L
F
.2 .63 .79 r
.80478 .16187 m
.80478 .41061 L
.80522 .41061 L
.80522 .16187 L
s
.678 .847 .902 r
.80522 .16187 m
.80522 .4111 L
.80561 .4111 L
.80561 .16187 L
F
.2 .63 .79 r
.80522 .16187 m
.80522 .4111 L
.80561 .4111 L
.80561 .16187 L
s
.678 .847 .902 r
.80561 .16187 m
.80561 .41152 L
.80595 .41152 L
.80595 .16187 L
F
.2 .63 .79 r
.80561 .16187 m
.80561 .41152 L
.80595 .41152 L
.80595 .16187 L
s
.678 .847 .902 r
.80595 .16187 m
.80595 .41171 L
.80622 .41171 L
.80622 .16187 L
F
.2 .63 .79 r
.80595 .16187 m
.80595 .41171 L
.80622 .41171 L
.80622 .16187 L
s
.678 .847 .902 r
.80622 .16187 m
.80622 .41198 L
.8065 .41198 L
.8065 .16187 L
F
.2 .63 .79 r
.80622 .16187 m
.80622 .41198 L
.8065 .41198 L
.8065 .16187 L
s
.678 .847 .902 r
.8065 .16187 m
.8065 .41263 L
.80694 .41263 L
.80694 .16187 L
F
.2 .63 .79 r
.8065 .16187 m
.8065 .41263 L
.80694 .41263 L
.80694 .16187 L
s
.678 .847 .902 r
.80694 .16187 m
.80694 .41305 L
.80731 .41305 L
.80731 .16187 L
F
.2 .63 .79 r
.80694 .16187 m
.80694 .41305 L
.80731 .41305 L
.80731 .16187 L
s
.678 .847 .902 r
.80731 .16187 m
.80731 .41327 L
.80767 .41327 L
.80767 .16187 L
F
.2 .63 .79 r
.80731 .16187 m
.80731 .41327 L
.80767 .41327 L
.80767 .16187 L
s
.678 .847 .902 r
.80767 .16187 m
.80767 .41358 L
.80783 .41358 L
.80783 .16187 L
F
.2 .63 .79 r
.80767 .16187 m
.80767 .41358 L
.80783 .41358 L
.80783 .16187 L
s
.678 .847 .902 r
.80783 .16187 m
.80783 .41376 L
.80812 .41376 L
.80812 .16187 L
F
.2 .63 .79 r
.80783 .16187 m
.80783 .41376 L
.80812 .41376 L
.80812 .16187 L
s
.678 .847 .902 r
.80812 .16187 m
.80812 .414 L
.80837 .414 L
.80837 .16187 L
F
.2 .63 .79 r
.80812 .16187 m
.80812 .414 L
.80837 .414 L
.80837 .16187 L
s
.678 .847 .902 r
.80837 .16187 m
.80837 .41436 L
.80869 .41436 L
.80869 .16187 L
F
.2 .63 .79 r
.80837 .16187 m
.80837 .41436 L
.80869 .41436 L
.80869 .16187 L
s
.678 .847 .902 r
.80869 .16187 m
.80869 .41453 L
.80912 .41453 L
.80912 .16187 L
F
.2 .63 .79 r
.80869 .16187 m
.80869 .41453 L
.80912 .41453 L
.80912 .16187 L
s
.678 .847 .902 r
.80912 .16187 m
.80912 .41506 L
.80939 .41506 L
.80939 .16187 L
F
.2 .63 .79 r
.80912 .16187 m
.80912 .41506 L
.80939 .41506 L
.80939 .16187 L
s
.678 .847 .902 r
.80939 .16187 m
.80939 .41523 L
.80969 .41523 L
.80969 .16187 L
F
.2 .63 .79 r
.80939 .16187 m
.80939 .41523 L
.80969 .41523 L
.80969 .16187 L
s
.678 .847 .902 r
.80969 .16187 m
.80969 .41564 L
.81017 .41564 L
.81017 .16187 L
F
.2 .63 .79 r
.80969 .16187 m
.80969 .41564 L
.81017 .41564 L
.81017 .16187 L
s
.678 .847 .902 r
.81017 .16187 m
.81017 .41605 L
.81065 .41605 L
.81065 .16187 L
F
.2 .63 .79 r
.81017 .16187 m
.81017 .41605 L
.81065 .41605 L
.81065 .16187 L
s
.678 .847 .902 r
.81065 .16187 m
.81065 .41667 L
.81105 .41667 L
.81105 .16187 L
F
.2 .63 .79 r
.81065 .16187 m
.81065 .41667 L
.81105 .41667 L
.81105 .16187 L
s
.678 .847 .902 r
.81105 .16187 m
.81105 .41702 L
.81137 .41702 L
.81137 .16187 L
F
.2 .63 .79 r
.81105 .16187 m
.81105 .41702 L
.81137 .41702 L
.81137 .16187 L
s
.678 .847 .902 r
.81137 .16187 m
.81137 .41737 L
.81158 .41737 L
.81158 .16187 L
F
.2 .63 .79 r
.81137 .16187 m
.81137 .41737 L
.81158 .41737 L
.81158 .16187 L
s
.678 .847 .902 r
.81158 .16187 m
.81158 .4177 L
.81192 .4177 L
.81192 .16187 L
F
.2 .63 .79 r
.81158 .16187 m
.81158 .4177 L
.81192 .4177 L
.81192 .16187 L
s
.678 .847 .902 r
.81192 .16187 m
.81192 .41779 L
.81214 .41779 L
.81214 .16187 L
F
.2 .63 .79 r
.81192 .16187 m
.81192 .41779 L
.81214 .41779 L
.81214 .16187 L
s
.678 .847 .902 r
.81214 .16187 m
.81214 .41825 L
.81251 .41825 L
.81251 .16187 L
F
.2 .63 .79 r
.81214 .16187 m
.81214 .41825 L
.81251 .41825 L
.81251 .16187 L
s
.678 .847 .902 r
.81251 .16187 m
.81251 .41854 L
.81293 .41854 L
.81293 .16187 L
F
.2 .63 .79 r
.81251 .16187 m
.81251 .41854 L
.81293 .41854 L
.81293 .16187 L
s
.678 .847 .902 r
.81293 .16187 m
.81293 .41904 L
.81333 .41904 L
.81333 .16187 L
F
.2 .63 .79 r
.81293 .16187 m
.81293 .41904 L
.81333 .41904 L
.81333 .16187 L
s
.678 .847 .902 r
.81333 .16187 m
.81333 .41943 L
.81364 .41943 L
.81364 .16187 L
F
.2 .63 .79 r
.81333 .16187 m
.81333 .41943 L
.81364 .41943 L
.81364 .16187 L
s
.678 .847 .902 r
.81364 .16187 m
.81364 .41957 L
.81382 .41957 L
.81382 .16187 L
F
.2 .63 .79 r
.81364 .16187 m
.81364 .41957 L
.81382 .41957 L
.81382 .16187 L
s
.678 .847 .902 r
.81382 .16187 m
.81382 .41982 L
.81412 .41982 L
.81412 .16187 L
F
.2 .63 .79 r
.81382 .16187 m
.81382 .41982 L
.81412 .41982 L
.81412 .16187 L
s
.678 .847 .902 r
.81412 .16187 m
.81412 .42018 L
.81439 .42018 L
.81439 .16187 L
F
.2 .63 .79 r
.81412 .16187 m
.81412 .42018 L
.81439 .42018 L
.81439 .16187 L
s
.678 .847 .902 r
.81439 .16187 m
.81439 .42061 L
.81475 .42061 L
.81475 .16187 L
F
.2 .63 .79 r
.81439 .16187 m
.81439 .42061 L
.81475 .42061 L
.81475 .16187 L
s
.678 .847 .902 r
.81475 .16187 m
.81475 .42075 L
.81506 .42075 L
.81506 .16187 L
F
.2 .63 .79 r
.81475 .16187 m
.81475 .42075 L
.81506 .42075 L
.81506 .16187 L
s
.678 .847 .902 r
.81506 .16187 m
.81506 .42134 L
.81548 .42134 L
.81548 .16187 L
F
.2 .63 .79 r
.81506 .16187 m
.81506 .42134 L
.81548 .42134 L
.81548 .16187 L
s
.678 .847 .902 r
.81548 .16187 m
.81548 .42162 L
.81574 .42162 L
.81574 .16187 L
F
.2 .63 .79 r
.81548 .16187 m
.81548 .42162 L
.81574 .42162 L
.81574 .16187 L
s
.678 .847 .902 r
.81574 .16187 m
.81574 .42176 L
.81596 .42176 L
.81596 .16187 L
F
.2 .63 .79 r
.81574 .16187 m
.81574 .42176 L
.81596 .42176 L
.81596 .16187 L
s
.678 .847 .902 r
.81596 .16187 m
.81596 .4221 L
.81617 .4221 L
.81617 .16187 L
F
.2 .63 .79 r
.81596 .16187 m
.81596 .4221 L
.81617 .4221 L
.81617 .16187 L
s
.678 .847 .902 r
.81617 .16187 m
.81617 .42217 L
.81642 .42217 L
.81642 .16187 L
F
.2 .63 .79 r
.81617 .16187 m
.81617 .42217 L
.81642 .42217 L
.81642 .16187 L
s
.678 .847 .902 r
.81642 .16187 m
.81642 .42259 L
.81674 .42259 L
.81674 .16187 L
F
.2 .63 .79 r
.81642 .16187 m
.81642 .42259 L
.81674 .42259 L
.81674 .16187 L
s
.678 .847 .902 r
.81674 .16187 m
.81674 .42307 L
.81718 .42307 L
.81718 .16187 L
F
.2 .63 .79 r
.81674 .16187 m
.81674 .42307 L
.81718 .42307 L
.81718 .16187 L
s
.678 .847 .902 r
.81718 .16187 m
.81718 .42349 L
.81758 .42349 L
.81758 .16187 L
F
.2 .63 .79 r
.81718 .16187 m
.81718 .42349 L
.81758 .42349 L
.81758 .16187 L
s
.678 .847 .902 r
.81758 .16187 m
.81758 .42382 L
.81784 .42382 L
.81784 .16187 L
F
.2 .63 .79 r
.81758 .16187 m
.81758 .42382 L
.81784 .42382 L
.81784 .16187 L
s
.678 .847 .902 r
.81784 .16187 m
.81784 .42402 L
.81817 .42402 L
.81817 .16187 L
F
.2 .63 .79 r
.81784 .16187 m
.81784 .42402 L
.81817 .42402 L
.81817 .16187 L
s
.678 .847 .902 r
.81817 .16187 m
.81817 .42426 L
.81836 .42426 L
.81836 .16187 L
F
.2 .63 .79 r
.81817 .16187 m
.81817 .42426 L
.81836 .42426 L
.81836 .16187 L
s
.678 .847 .902 r
.81836 .16187 m
.81836 .42448 L
.81859 .42448 L
.81859 .16187 L
F
.2 .63 .79 r
.81836 .16187 m
.81836 .42448 L
.81859 .42448 L
.81859 .16187 L
s
.678 .847 .902 r
.81859 .16187 m
.81859 .42467 L
.81878 .42467 L
.81878 .16187 L
F
.2 .63 .79 r
.81859 .16187 m
.81859 .42467 L
.81878 .42467 L
.81878 .16187 L
s
.678 .847 .902 r
.81878 .16187 m
.81878 .42519 L
.81927 .42519 L
.81927 .16187 L
F
.2 .63 .79 r
.81878 .16187 m
.81878 .42519 L
.81927 .42519 L
.81927 .16187 L
s
.678 .847 .902 r
.81927 .16187 m
.81927 .42548 L
.81973 .42548 L
.81973 .16187 L
F
.2 .63 .79 r
.81927 .16187 m
.81927 .42548 L
.81973 .42548 L
.81973 .16187 L
s
.678 .847 .902 r
.81973 .16187 m
.81973 .42608 L
.82009 .42608 L
.82009 .16187 L
F
.2 .63 .79 r
.81973 .16187 m
.81973 .42608 L
.82009 .42608 L
.82009 .16187 L
s
.678 .847 .902 r
.82009 .16187 m
.82009 .42639 L
.82035 .42639 L
.82035 .16187 L
F
.2 .63 .79 r
.82009 .16187 m
.82009 .42639 L
.82035 .42639 L
.82035 .16187 L
s
.678 .847 .902 r
.82035 .16187 m
.82035 .42649 L
.82058 .42649 L
.82058 .16187 L
F
.2 .63 .79 r
.82035 .16187 m
.82035 .42649 L
.82058 .42649 L
.82058 .16187 L
s
.678 .847 .902 r
.82058 .16187 m
.82058 .42689 L
.82088 .42689 L
.82088 .16187 L
F
.2 .63 .79 r
.82058 .16187 m
.82058 .42689 L
.82088 .42689 L
.82088 .16187 L
s
.678 .847 .902 r
.82088 .16187 m
.82088 .42719 L
.82121 .42719 L
.82121 .16187 L
F
.2 .63 .79 r
.82088 .16187 m
.82088 .42719 L
.82121 .42719 L
.82121 .16187 L
s
.678 .847 .902 r
.82121 .16187 m
.82121 .42757 L
.82166 .42757 L
.82166 .16187 L
F
.2 .63 .79 r
.82121 .16187 m
.82121 .42757 L
.82166 .42757 L
.82166 .16187 L
s
.678 .847 .902 r
.82166 .16187 m
.82166 .42811 L
.82212 .42811 L
.82212 .16187 L
F
.2 .63 .79 r
.82166 .16187 m
.82166 .42811 L
.82212 .42811 L
.82212 .16187 L
s
.678 .847 .902 r
.82212 .16187 m
.82212 .42865 L
.82254 .42865 L
.82254 .16187 L
F
.2 .63 .79 r
.82212 .16187 m
.82212 .42865 L
.82254 .42865 L
.82254 .16187 L
s
.678 .847 .902 r
.82254 .16187 m
.82254 .42878 L
.82272 .42878 L
.82272 .16187 L
F
.2 .63 .79 r
.82254 .16187 m
.82254 .42878 L
.82272 .42878 L
.82272 .16187 L
s
.678 .847 .902 r
.82272 .16187 m
.82272 .42903 L
.82289 .42903 L
.82289 .16187 L
F
.2 .63 .79 r
.82272 .16187 m
.82272 .42903 L
.82289 .42903 L
.82289 .16187 L
s
.678 .847 .902 r
.82289 .16187 m
.82289 .42943 L
.82324 .42943 L
.82324 .16187 L
F
.2 .63 .79 r
.82289 .16187 m
.82289 .42943 L
.82324 .42943 L
.82324 .16187 L
s
.678 .847 .902 r
.82324 .16187 m
.82324 .42965 L
.82359 .42965 L
.82359 .16187 L
F
.2 .63 .79 r
.82324 .16187 m
.82324 .42965 L
.82359 .42965 L
.82359 .16187 L
s
.678 .847 .902 r
.82359 .16187 m
.82359 .43005 L
.82405 .43005 L
.82405 .16187 L
F
.2 .63 .79 r
.82359 .16187 m
.82359 .43005 L
.82405 .43005 L
.82405 .16187 L
s
.678 .847 .902 r
.82405 .16187 m
.82405 .43052 L
.82446 .43052 L
.82446 .16187 L
F
.2 .63 .79 r
.82405 .16187 m
.82405 .43052 L
.82446 .43052 L
.82446 .16187 L
s
.678 .847 .902 r
.82446 .16187 m
.82446 .43078 L
.82465 .43078 L
.82465 .16187 L
F
.2 .63 .79 r
.82446 .16187 m
.82446 .43078 L
.82465 .43078 L
.82465 .16187 L
s
.678 .847 .902 r
.82465 .16187 m
.82465 .43123 L
.82505 .43123 L
.82505 .16187 L
F
.2 .63 .79 r
.82465 .16187 m
.82465 .43123 L
.82505 .43123 L
.82505 .16187 L
s
.678 .847 .902 r
.82505 .16187 m
.82505 .43148 L
.82525 .43148 L
.82525 .16187 L
F
.2 .63 .79 r
.82505 .16187 m
.82505 .43148 L
.82525 .43148 L
.82525 .16187 L
s
.678 .847 .902 r
.82525 .16187 m
.82525 .43175 L
.82555 .43175 L
.82555 .16187 L
F
.2 .63 .79 r
.82525 .16187 m
.82525 .43175 L
.82555 .43175 L
.82555 .16187 L
s
.678 .847 .902 r
.82555 .16187 m
.82555 .43216 L
.82589 .43216 L
.82589 .16187 L
F
.2 .63 .79 r
.82555 .16187 m
.82555 .43216 L
.82589 .43216 L
.82589 .16187 L
s
.678 .847 .902 r
.82589 .16187 m
.82589 .43238 L
.82625 .43238 L
.82625 .16187 L
F
.2 .63 .79 r
.82589 .16187 m
.82589 .43238 L
.82625 .43238 L
.82625 .16187 L
s
.678 .847 .902 r
.82625 .16187 m
.82625 .43276 L
.82672 .43276 L
.82672 .16187 L
F
.2 .63 .79 r
.82625 .16187 m
.82625 .43276 L
.82672 .43276 L
.82672 .16187 L
s
.678 .847 .902 r
.82672 .16187 m
.82672 .4332 L
.82698 .4332 L
.82698 .16187 L
F
.2 .63 .79 r
.82672 .16187 m
.82672 .4332 L
.82698 .4332 L
.82698 .16187 L
s
.678 .847 .902 r
.82698 .16187 m
.82698 .43339 L
.82732 .43339 L
.82732 .16187 L
F
.2 .63 .79 r
.82698 .16187 m
.82698 .43339 L
.82732 .43339 L
.82732 .16187 L
s
.678 .847 .902 r
.82732 .16187 m
.82732 .43376 L
.82772 .43376 L
.82772 .16187 L
F
.2 .63 .79 r
.82732 .16187 m
.82732 .43376 L
.82772 .43376 L
.82772 .16187 L
s
.678 .847 .902 r
.82772 .16187 m
.82772 .43427 L
.82797 .43427 L
.82797 .16187 L
F
.2 .63 .79 r
.82772 .16187 m
.82772 .43427 L
.82797 .43427 L
.82797 .16187 L
s
.678 .847 .902 r
.82797 .16187 m
.82797 .43448 L
.82812 .43448 L
.82812 .16187 L
F
.2 .63 .79 r
.82797 .16187 m
.82797 .43448 L
.82812 .43448 L
.82812 .16187 L
s
.678 .847 .902 r
.82812 .16187 m
.82812 .43452 L
.82837 .43452 L
.82837 .16187 L
F
.2 .63 .79 r
.82812 .16187 m
.82812 .43452 L
.82837 .43452 L
.82837 .16187 L
s
.678 .847 .902 r
.82837 .16187 m
.82837 .43492 L
.82862 .43492 L
.82862 .16187 L
F
.2 .63 .79 r
.82837 .16187 m
.82837 .43492 L
.82862 .43492 L
.82862 .16187 L
s
.678 .847 .902 r
.82862 .16187 m
.82862 .43507 L
.82903 .43507 L
.82903 .16187 L
F
.2 .63 .79 r
.82862 .16187 m
.82862 .43507 L
.82903 .43507 L
.82903 .16187 L
s
.678 .847 .902 r
.82903 .16187 m
.82903 .43552 L
.82923 .43552 L
.82923 .16187 L
F
.2 .63 .79 r
.82903 .16187 m
.82903 .43552 L
.82923 .43552 L
.82923 .16187 L
s
.678 .847 .902 r
.82923 .16187 m
.82923 .43578 L
.82951 .43578 L
.82951 .16187 L
F
.2 .63 .79 r
.82923 .16187 m
.82923 .43578 L
.82951 .43578 L
.82951 .16187 L
s
.678 .847 .902 r
.82951 .16187 m
.82951 .4362 L
.82983 .4362 L
.82983 .16187 L
F
.2 .63 .79 r
.82951 .16187 m
.82951 .4362 L
.82983 .4362 L
.82983 .16187 L
s
.678 .847 .902 r
.82983 .16187 m
.82983 .4366 L
.83022 .4366 L
.83022 .16187 L
F
.2 .63 .79 r
.82983 .16187 m
.82983 .4366 L
.83022 .4366 L
.83022 .16187 L
s
.678 .847 .902 r
.83022 .16187 m
.83022 .4368 L
.83038 .4368 L
.83038 .16187 L
F
.2 .63 .79 r
.83022 .16187 m
.83022 .4368 L
.83038 .4368 L
.83038 .16187 L
s
.678 .847 .902 r
.83038 .16187 m
.83038 .43707 L
.8308 .43707 L
.8308 .16187 L
F
.2 .63 .79 r
.83038 .16187 m
.83038 .43707 L
.8308 .43707 L
.8308 .16187 L
s
.678 .847 .902 r
.8308 .16187 m
.8308 .43738 L
.83127 .43738 L
.83127 .16187 L
F
.2 .63 .79 r
.8308 .16187 m
.8308 .43738 L
.83127 .43738 L
.83127 .16187 L
s
.678 .847 .902 r
.83127 .16187 m
.83127 .43791 L
.83169 .43791 L
.83169 .16187 L
F
.2 .63 .79 r
.83127 .16187 m
.83127 .43791 L
.83169 .43791 L
.83169 .16187 L
s
.678 .847 .902 r
.83169 .16187 m
.83169 .4385 L
.83193 .4385 L
.83193 .16187 L
F
.2 .63 .79 r
.83169 .16187 m
.83169 .4385 L
.83193 .4385 L
.83193 .16187 L
s
.678 .847 .902 r
.83193 .16187 m
.83193 .43854 L
.83232 .43854 L
.83232 .16187 L
F
.2 .63 .79 r
.83193 .16187 m
.83193 .43854 L
.83232 .43854 L
.83232 .16187 L
s
.678 .847 .902 r
.83232 .16187 m
.83232 .43899 L
.83253 .43899 L
.83253 .16187 L
F
.2 .63 .79 r
.83232 .16187 m
.83232 .43899 L
.83253 .43899 L
.83253 .16187 L
s
.678 .847 .902 r
.83253 .16187 m
.83253 .43932 L
.83289 .43932 L
.83289 .16187 L
F
.2 .63 .79 r
.83253 .16187 m
.83253 .43932 L
.83289 .43932 L
.83289 .16187 L
s
.678 .847 .902 r
.83289 .16187 m
.83289 .43965 L
.83333 .43965 L
.83333 .16187 L
F
.2 .63 .79 r
.83289 .16187 m
.83289 .43965 L
.83333 .43965 L
.83333 .16187 L
s
.678 .847 .902 r
.83333 .16187 m
.83333 .44002 L
.83353 .44002 L
.83353 .16187 L
F
.2 .63 .79 r
.83333 .16187 m
.83333 .44002 L
.83353 .44002 L
.83353 .16187 L
s
.678 .847 .902 r
.83353 .16187 m
.83353 .44049 L
.83387 .44049 L
.83387 .16187 L
F
.2 .63 .79 r
.83353 .16187 m
.83353 .44049 L
.83387 .44049 L
.83387 .16187 L
s
.678 .847 .902 r
.83387 .16187 m
.83387 .44058 L
.83426 .44058 L
.83426 .16187 L
F
.2 .63 .79 r
.83387 .16187 m
.83387 .44058 L
.83426 .44058 L
.83426 .16187 L
s
.678 .847 .902 r
.83426 .16187 m
.83426 .44121 L
.83458 .44121 L
.83458 .16187 L
F
.2 .63 .79 r
.83426 .16187 m
.83426 .44121 L
.83458 .44121 L
.83458 .16187 L
s
.678 .847 .902 r
.83458 .16187 m
.83458 .4413 L
.83492 .4413 L
.83492 .16187 L
F
.2 .63 .79 r
.83458 .16187 m
.83458 .4413 L
.83492 .4413 L
.83492 .16187 L
s
.678 .847 .902 r
.83492 .16187 m
.83492 .44197 L
.83536 .44197 L
.83536 .16187 L
F
.2 .63 .79 r
.83492 .16187 m
.83492 .44197 L
.83536 .44197 L
.83536 .16187 L
s
.678 .847 .902 r
.83536 .16187 m
.83536 .44226 L
.83565 .44226 L
.83565 .16187 L
F
.2 .63 .79 r
.83536 .16187 m
.83536 .44226 L
.83565 .44226 L
.83565 .16187 L
s
.678 .847 .902 r
.83565 .16187 m
.83565 .44242 L
.83598 .44242 L
.83598 .16187 L
F
.2 .63 .79 r
.83565 .16187 m
.83565 .44242 L
.83598 .44242 L
.83598 .16187 L
s
.678 .847 .902 r
.83598 .16187 m
.83598 .44276 L
.8362 .44276 L
.8362 .16187 L
F
.2 .63 .79 r
.83598 .16187 m
.83598 .44276 L
.8362 .44276 L
.8362 .16187 L
s
.678 .847 .902 r
.8362 .16187 m
.8362 .44306 L
.83655 .44306 L
.83655 .16187 L
F
.2 .63 .79 r
.8362 .16187 m
.8362 .44306 L
.83655 .44306 L
.83655 .16187 L
s
.678 .847 .902 r
.83655 .16187 m
.83655 .44352 L
.83691 .44352 L
.83691 .16187 L
F
.2 .63 .79 r
.83655 .16187 m
.83655 .44352 L
.83691 .44352 L
.83691 .16187 L
s
.678 .847 .902 r
.83691 .16187 m
.83691 .44398 L
.8372 .44398 L
.8372 .16187 L
F
.2 .63 .79 r
.83691 .16187 m
.83691 .44398 L
.8372 .44398 L
.8372 .16187 L
s
.678 .847 .902 r
.8372 .16187 m
.8372 .44434 L
.83763 .44434 L
.83763 .16187 L
F
.2 .63 .79 r
.8372 .16187 m
.8372 .44434 L
.83763 .44434 L
.83763 .16187 L
s
.678 .847 .902 r
.83763 .16187 m
.83763 .4446 L
.83781 .4446 L
.83781 .16187 L
F
.2 .63 .79 r
.83763 .16187 m
.83763 .4446 L
.83781 .4446 L
.83781 .16187 L
s
.678 .847 .902 r
.83781 .16187 m
.83781 .44503 L
.83827 .44503 L
.83827 .16187 L
F
.2 .63 .79 r
.83781 .16187 m
.83781 .44503 L
.83827 .44503 L
.83827 .16187 L
s
.678 .847 .902 r
.83827 .16187 m
.83827 .44526 L
.83854 .44526 L
.83854 .16187 L
F
.2 .63 .79 r
.83827 .16187 m
.83827 .44526 L
.83854 .44526 L
.83854 .16187 L
s
.678 .847 .902 r
.83854 .16187 m
.83854 .4455 L
.8387 .4455 L
.8387 .16187 L
F
.2 .63 .79 r
.83854 .16187 m
.83854 .4455 L
.8387 .4455 L
.8387 .16187 L
s
.678 .847 .902 r
.8387 .16187 m
.8387 .44572 L
.8389 .44572 L
.8389 .16187 L
F
.2 .63 .79 r
.8387 .16187 m
.8387 .44572 L
.8389 .44572 L
.8389 .16187 L
s
.678 .847 .902 r
.8389 .16187 m
.8389 .44595 L
.8391 .44595 L
.8391 .16187 L
F
.2 .63 .79 r
.8389 .16187 m
.8389 .44595 L
.8391 .44595 L
.8391 .16187 L
s
.678 .847 .902 r
.8391 .16187 m
.8391 .44611 L
.83926 .44611 L
.83926 .16187 L
F
.2 .63 .79 r
.8391 .16187 m
.8391 .44611 L
.83926 .44611 L
.83926 .16187 L
s
.678 .847 .902 r
.83926 .16187 m
.83926 .44628 L
.83953 .44628 L
.83953 .16187 L
F
.2 .63 .79 r
.83926 .16187 m
.83926 .44628 L
.83953 .44628 L
.83953 .16187 L
s
.678 .847 .902 r
.83953 .16187 m
.83953 .44652 L
.83967 .44652 L
.83967 .16187 L
F
.2 .63 .79 r
.83953 .16187 m
.83953 .44652 L
.83967 .44652 L
.83967 .16187 L
s
.678 .847 .902 r
.83967 .16187 m
.83967 .447 L
.83999 .447 L
.83999 .16187 L
F
.2 .63 .79 r
.83967 .16187 m
.83967 .447 L
.83999 .447 L
.83999 .16187 L
s
.678 .847 .902 r
.83999 .16187 m
.83999 .44701 L
.84022 .44701 L
.84022 .16187 L
F
.2 .63 .79 r
.83999 .16187 m
.83999 .44701 L
.84022 .44701 L
.84022 .16187 L
s
.678 .847 .902 r
.84022 .16187 m
.84022 .44747 L
.84043 .44747 L
.84043 .16187 L
F
.2 .63 .79 r
.84022 .16187 m
.84022 .44747 L
.84043 .44747 L
.84043 .16187 L
s
.678 .847 .902 r
.84043 .16187 m
.84043 .44754 L
.84073 .44754 L
.84073 .16187 L
F
.2 .63 .79 r
.84043 .16187 m
.84043 .44754 L
.84073 .44754 L
.84073 .16187 L
s
.678 .847 .902 r
.84073 .16187 m
.84073 .44818 L
.84115 .44818 L
.84115 .16187 L
F
.2 .63 .79 r
.84073 .16187 m
.84073 .44818 L
.84115 .44818 L
.84115 .16187 L
s
.678 .847 .902 r
.84115 .16187 m
.84115 .44835 L
.84154 .44835 L
.84154 .16187 L
F
.2 .63 .79 r
.84115 .16187 m
.84115 .44835 L
.84154 .44835 L
.84154 .16187 L
s
.678 .847 .902 r
.84154 .16187 m
.84154 .44903 L
.84191 .44903 L
.84191 .16187 L
F
.2 .63 .79 r
.84154 .16187 m
.84154 .44903 L
.84191 .44903 L
.84191 .16187 L
s
.678 .847 .902 r
.84191 .16187 m
.84191 .44924 L
.84226 .44924 L
.84226 .16187 L
F
.2 .63 .79 r
.84191 .16187 m
.84191 .44924 L
.84226 .44924 L
.84226 .16187 L
s
.678 .847 .902 r
.84226 .16187 m
.84226 .44954 L
.84255 .44954 L
.84255 .16187 L
F
.2 .63 .79 r
.84226 .16187 m
.84226 .44954 L
.84255 .44954 L
.84255 .16187 L
s
.678 .847 .902 r
.84255 .16187 m
.84255 .44977 L
.84275 .44977 L
.84275 .16187 L
F
.2 .63 .79 r
.84255 .16187 m
.84255 .44977 L
.84275 .44977 L
.84275 .16187 L
s
.678 .847 .902 r
.84275 .16187 m
.84275 .45023 L
.84304 .45023 L
.84304 .16187 L
F
.2 .63 .79 r
.84275 .16187 m
.84275 .45023 L
.84304 .45023 L
.84304 .16187 L
s
.678 .847 .902 r
.84304 .16187 m
.84304 .4503 L
.8432 .4503 L
.8432 .16187 L
F
.2 .63 .79 r
.84304 .16187 m
.84304 .4503 L
.8432 .4503 L
.8432 .16187 L
s
.678 .847 .902 r
.8432 .16187 m
.8432 .45041 L
.84361 .45041 L
.84361 .16187 L
F
.2 .63 .79 r
.8432 .16187 m
.8432 .45041 L
.84361 .45041 L
.84361 .16187 L
s
.678 .847 .902 r
.84361 .16187 m
.84361 .45105 L
.84402 .45105 L
.84402 .16187 L
F
.2 .63 .79 r
.84361 .16187 m
.84361 .45105 L
.84402 .45105 L
.84402 .16187 L
s
.678 .847 .902 r
.84402 .16187 m
.84402 .45141 L
.84437 .45141 L
.84437 .16187 L
F
.2 .63 .79 r
.84402 .16187 m
.84402 .45141 L
.84437 .45141 L
.84437 .16187 L
s
.678 .847 .902 r
.84437 .16187 m
.84437 .45209 L
.84484 .45209 L
.84484 .16187 L
F
.2 .63 .79 r
.84437 .16187 m
.84437 .45209 L
.84484 .45209 L
.84484 .16187 L
s
.678 .847 .902 r
.84484 .16187 m
.84484 .45231 L
.84528 .45231 L
.84528 .16187 L
F
.2 .63 .79 r
.84484 .16187 m
.84484 .45231 L
.84528 .45231 L
.84528 .16187 L
s
.678 .847 .902 r
.84528 .16187 m
.84528 .45269 L
.84558 .45269 L
.84558 .16187 L
F
.2 .63 .79 r
.84528 .16187 m
.84528 .45269 L
.84558 .45269 L
.84558 .16187 L
s
.678 .847 .902 r
.84558 .16187 m
.84558 .45298 L
.84591 .45298 L
.84591 .16187 L
F
.2 .63 .79 r
.84558 .16187 m
.84558 .45298 L
.84591 .45298 L
.84591 .16187 L
s
.678 .847 .902 r
.84591 .16187 m
.84591 .45351 L
.84632 .45351 L
.84632 .16187 L
F
.2 .63 .79 r
.84591 .16187 m
.84591 .45351 L
.84632 .45351 L
.84632 .16187 L
s
.678 .847 .902 r
.84632 .16187 m
.84632 .4541 L
.84672 .4541 L
.84672 .16187 L
F
.2 .63 .79 r
.84632 .16187 m
.84632 .4541 L
.84672 .4541 L
.84672 .16187 L
s
.678 .847 .902 r
.84672 .16187 m
.84672 .45443 L
.84699 .45443 L
.84699 .16187 L
F
.2 .63 .79 r
.84672 .16187 m
.84672 .45443 L
.84699 .45443 L
.84699 .16187 L
s
.678 .847 .902 r
.84699 .16187 m
.84699 .45468 L
.84722 .45468 L
.84722 .16187 L
F
.2 .63 .79 r
.84699 .16187 m
.84699 .45468 L
.84722 .45468 L
.84722 .16187 L
s
.678 .847 .902 r
.84722 .16187 m
.84722 .45488 L
.84763 .45488 L
.84763 .16187 L
F
.2 .63 .79 r
.84722 .16187 m
.84722 .45488 L
.84763 .45488 L
.84763 .16187 L
s
.678 .847 .902 r
.84763 .16187 m
.84763 .45534 L
.84785 .45534 L
.84785 .16187 L
F
.2 .63 .79 r
.84763 .16187 m
.84763 .45534 L
.84785 .45534 L
.84785 .16187 L
s
.678 .847 .902 r
.84785 .16187 m
.84785 .45556 L
.84805 .45556 L
.84805 .16187 L
F
.2 .63 .79 r
.84785 .16187 m
.84785 .45556 L
.84805 .45556 L
.84805 .16187 L
s
.678 .847 .902 r
.84805 .16187 m
.84805 .45575 L
.84821 .45575 L
.84821 .16187 L
F
.2 .63 .79 r
.84805 .16187 m
.84805 .45575 L
.84821 .45575 L
.84821 .16187 L
s
.678 .847 .902 r
.84821 .16187 m
.84821 .45581 L
.84846 .45581 L
.84846 .16187 L
F
.2 .63 .79 r
.84821 .16187 m
.84821 .45581 L
.84846 .45581 L
.84846 .16187 L
s
.678 .847 .902 r
.84846 .16187 m
.84846 .45634 L
.84876 .45634 L
.84876 .16187 L
F
.2 .63 .79 r
.84846 .16187 m
.84846 .45634 L
.84876 .45634 L
.84876 .16187 L
s
.678 .847 .902 r
.84876 .16187 m
.84876 .45655 L
.84906 .45655 L
.84906 .16187 L
F
.2 .63 .79 r
.84876 .16187 m
.84876 .45655 L
.84906 .45655 L
.84906 .16187 L
s
.678 .847 .902 r
.84906 .16187 m
.84906 .45697 L
.84934 .45697 L
.84934 .16187 L
F
.2 .63 .79 r
.84906 .16187 m
.84906 .45697 L
.84934 .45697 L
.84934 .16187 L
s
.678 .847 .902 r
.84934 .16187 m
.84934 .45725 L
.84974 .45725 L
.84974 .16187 L
F
.2 .63 .79 r
.84934 .16187 m
.84934 .45725 L
.84974 .45725 L
.84974 .16187 L
s
.678 .847 .902 r
.84974 .16187 m
.84974 .45749 L
.84989 .45749 L
.84989 .16187 L
F
.2 .63 .79 r
.84974 .16187 m
.84974 .45749 L
.84989 .45749 L
.84989 .16187 L
s
.678 .847 .902 r
.84989 .16187 m
.84989 .45766 L
.85015 .45766 L
.85015 .16187 L
F
.2 .63 .79 r
.84989 .16187 m
.84989 .45766 L
.85015 .45766 L
.85015 .16187 L
s
.678 .847 .902 r
.85015 .16187 m
.85015 .45785 L
.85062 .45785 L
.85062 .16187 L
F
.2 .63 .79 r
.85015 .16187 m
.85015 .45785 L
.85062 .45785 L
.85062 .16187 L
s
.678 .847 .902 r
.85062 .16187 m
.85062 .45847 L
.85101 .45847 L
.85101 .16187 L
F
.2 .63 .79 r
.85062 .16187 m
.85062 .45847 L
.85101 .45847 L
.85101 .16187 L
s
.678 .847 .902 r
.85101 .16187 m
.85101 .45891 L
.85125 .45891 L
.85125 .16187 L
F
.2 .63 .79 r
.85101 .16187 m
.85101 .45891 L
.85125 .45891 L
.85125 .16187 L
s
.678 .847 .902 r
.85125 .16187 m
.85125 .45935 L
.85158 .45935 L
.85158 .16187 L
F
.2 .63 .79 r
.85125 .16187 m
.85125 .45935 L
.85158 .45935 L
.85158 .16187 L
s
.678 .847 .902 r
.85158 .16187 m
.85158 .45958 L
.85186 .45958 L
.85186 .16187 L
F
.2 .63 .79 r
.85158 .16187 m
.85158 .45958 L
.85186 .45958 L
.85186 .16187 L
s
.678 .847 .902 r
.85186 .16187 m
.85186 .45986 L
.85227 .45986 L
.85227 .16187 L
F
.2 .63 .79 r
.85186 .16187 m
.85186 .45986 L
.85227 .45986 L
.85227 .16187 L
s
.678 .847 .902 r
.85227 .16187 m
.85227 .46019 L
.85256 .46019 L
.85256 .16187 L
F
.2 .63 .79 r
.85227 .16187 m
.85227 .46019 L
.85256 .46019 L
.85256 .16187 L
s
.678 .847 .902 r
.85256 .16187 m
.85256 .46056 L
.85274 .46056 L
.85274 .16187 L
F
.2 .63 .79 r
.85256 .16187 m
.85256 .46056 L
.85274 .46056 L
.85274 .16187 L
s
.678 .847 .902 r
.85274 .16187 m
.85274 .46089 L
.85317 .46089 L
.85317 .16187 L
F
.2 .63 .79 r
.85274 .16187 m
.85274 .46089 L
.85317 .46089 L
.85317 .16187 L
s
.678 .847 .902 r
.85317 .16187 m
.85317 .46159 L
.85366 .46159 L
.85366 .16187 L
F
.2 .63 .79 r
.85317 .16187 m
.85317 .46159 L
.85366 .46159 L
.85366 .16187 L
s
.678 .847 .902 r
.85366 .16187 m
.85366 .46177 L
.85405 .46177 L
.85405 .16187 L
F
.2 .63 .79 r
.85366 .16187 m
.85366 .46177 L
.85405 .46177 L
.85405 .16187 L
s
.678 .847 .902 r
.85405 .16187 m
.85405 .46238 L
.85445 .46238 L
.85445 .16187 L
F
.2 .63 .79 r
.85405 .16187 m
.85405 .46238 L
.85445 .46238 L
.85445 .16187 L
s
.678 .847 .902 r
.85445 .16187 m
.85445 .46271 L
.85481 .46271 L
.85481 .16187 L
F
.2 .63 .79 r
.85445 .16187 m
.85445 .46271 L
.85481 .46271 L
.85481 .16187 L
s
.678 .847 .902 r
.85481 .16187 m
.85481 .46298 L
.85504 .46298 L
.85504 .16187 L
F
.2 .63 .79 r
.85481 .16187 m
.85481 .46298 L
.85504 .46298 L
.85504 .16187 L
s
.678 .847 .902 r
.85504 .16187 m
.85504 .46326 L
.85535 .46326 L
.85535 .16187 L
F
.2 .63 .79 r
.85504 .16187 m
.85504 .46326 L
.85535 .46326 L
.85535 .16187 L
s
.678 .847 .902 r
.85535 .16187 m
.85535 .46377 L
.8557 .46377 L
.8557 .16187 L
F
.2 .63 .79 r
.85535 .16187 m
.85535 .46377 L
.8557 .46377 L
.8557 .16187 L
s
.678 .847 .902 r
.8557 .16187 m
.8557 .46406 L
.85605 .46406 L
.85605 .16187 L
F
.2 .63 .79 r
.8557 .16187 m
.8557 .46406 L
.85605 .46406 L
.85605 .16187 L
s
.678 .847 .902 r
.85605 .16187 m
.85605 .46436 L
.85651 .46436 L
.85651 .16187 L
F
.2 .63 .79 r
.85605 .16187 m
.85605 .46436 L
.85651 .46436 L
.85651 .16187 L
s
.678 .847 .902 r
.85651 .16187 m
.85651 .46477 L
.85668 .46477 L
.85668 .16187 L
F
.2 .63 .79 r
.85651 .16187 m
.85651 .46477 L
.85668 .46477 L
.85668 .16187 L
s
.678 .847 .902 r
.85668 .16187 m
.85668 .46492 L
.85686 .46492 L
.85686 .16187 L
F
.2 .63 .79 r
.85668 .16187 m
.85668 .46492 L
.85686 .46492 L
.85686 .16187 L
s
.678 .847 .902 r
.85686 .16187 m
.85686 .46522 L
.85708 .46522 L
.85708 .16187 L
F
.2 .63 .79 r
.85686 .16187 m
.85686 .46522 L
.85708 .46522 L
.85708 .16187 L
s
.678 .847 .902 r
.85708 .16187 m
.85708 .46546 L
.8573 .46546 L
.8573 .16187 L
F
.2 .63 .79 r
.85708 .16187 m
.85708 .46546 L
.8573 .46546 L
.8573 .16187 L
s
.678 .847 .902 r
.8573 .16187 m
.8573 .46569 L
.85746 .46569 L
.85746 .16187 L
F
.2 .63 .79 r
.8573 .16187 m
.8573 .46569 L
.85746 .46569 L
.85746 .16187 L
s
.678 .847 .902 r
.85746 .16187 m
.85746 .46612 L
.85788 .46612 L
.85788 .16187 L
F
.2 .63 .79 r
.85746 .16187 m
.85746 .46612 L
.85788 .46612 L
.85788 .16187 L
s
.678 .847 .902 r
.85788 .16187 m
.85788 .46633 L
.85812 .46633 L
.85812 .16187 L
F
.2 .63 .79 r
.85788 .16187 m
.85788 .46633 L
.85812 .46633 L
.85812 .16187 L
s
.678 .847 .902 r
.85812 .16187 m
.85812 .46655 L
.85843 .46655 L
.85843 .16187 L
F
.2 .63 .79 r
.85812 .16187 m
.85812 .46655 L
.85843 .46655 L
.85843 .16187 L
s
.678 .847 .902 r
.85843 .16187 m
.85843 .46692 L
.85885 .46692 L
.85885 .16187 L
F
.2 .63 .79 r
.85843 .16187 m
.85843 .46692 L
.85885 .46692 L
.85885 .16187 L
s
.678 .847 .902 r
.85885 .16187 m
.85885 .46747 L
.85909 .46747 L
.85909 .16187 L
F
.2 .63 .79 r
.85885 .16187 m
.85885 .46747 L
.85909 .46747 L
.85909 .16187 L
s
.678 .847 .902 r
.85909 .16187 m
.85909 .46794 L
.85954 .46794 L
.85954 .16187 L
F
.2 .63 .79 r
.85909 .16187 m
.85909 .46794 L
.85954 .46794 L
.85954 .16187 L
s
.678 .847 .902 r
.85954 .16187 m
.85954 .46836 L
.85994 .46836 L
.85994 .16187 L
F
.2 .63 .79 r
.85954 .16187 m
.85954 .46836 L
.85994 .46836 L
.85994 .16187 L
s
.678 .847 .902 r
.85994 .16187 m
.85994 .46842 L
.86021 .46842 L
.86021 .16187 L
F
.2 .63 .79 r
.85994 .16187 m
.85994 .46842 L
.86021 .46842 L
.86021 .16187 L
s
.678 .847 .902 r
.86021 .16187 m
.86021 .46875 L
.86042 .46875 L
.86042 .16187 L
F
.2 .63 .79 r
.86021 .16187 m
.86021 .46875 L
.86042 .46875 L
.86042 .16187 L
s
.678 .847 .902 r
.86042 .16187 m
.86042 .46898 L
.86059 .46898 L
.86059 .16187 L
F
.2 .63 .79 r
.86042 .16187 m
.86042 .46898 L
.86059 .46898 L
.86059 .16187 L
s
.678 .847 .902 r
.86059 .16187 m
.86059 .46951 L
.86098 .46951 L
.86098 .16187 L
F
.2 .63 .79 r
.86059 .16187 m
.86059 .46951 L
.86098 .46951 L
.86098 .16187 L
s
.678 .847 .902 r
.86098 .16187 m
.86098 .46982 L
.86136 .46982 L
.86136 .16187 L
F
.2 .63 .79 r
.86098 .16187 m
.86098 .46982 L
.86136 .46982 L
.86136 .16187 L
s
.678 .847 .902 r
.86136 .16187 m
.86136 .47008 L
.86166 .47008 L
.86166 .16187 L
F
.2 .63 .79 r
.86136 .16187 m
.86136 .47008 L
.86166 .47008 L
.86166 .16187 L
s
.678 .847 .902 r
.86166 .16187 m
.86166 .4705 L
.86197 .4705 L
.86197 .16187 L
F
.2 .63 .79 r
.86166 .16187 m
.86166 .4705 L
.86197 .4705 L
.86197 .16187 L
s
.678 .847 .902 r
.86197 .16187 m
.86197 .47073 L
.86228 .47073 L
.86228 .16187 L
F
.2 .63 .79 r
.86197 .16187 m
.86197 .47073 L
.86228 .47073 L
.86228 .16187 L
s
.678 .847 .902 r
.86228 .16187 m
.86228 .47099 L
.8625 .47099 L
.8625 .16187 L
F
.2 .63 .79 r
.86228 .16187 m
.86228 .47099 L
.8625 .47099 L
.8625 .16187 L
s
.678 .847 .902 r
.8625 .16187 m
.8625 .47142 L
.86294 .47142 L
.86294 .16187 L
F
.2 .63 .79 r
.8625 .16187 m
.8625 .47142 L
.86294 .47142 L
.86294 .16187 L
s
.678 .847 .902 r
.86294 .16187 m
.86294 .47166 L
.86339 .47166 L
.86339 .16187 L
F
.2 .63 .79 r
.86294 .16187 m
.86294 .47166 L
.86339 .47166 L
.86339 .16187 L
s
.678 .847 .902 r
.86339 .16187 m
.86339 .47216 L
.86373 .47216 L
.86373 .16187 L
F
.2 .63 .79 r
.86339 .16187 m
.86339 .47216 L
.86373 .47216 L
.86373 .16187 L
s
.678 .847 .902 r
.86373 .16187 m
.86373 .47266 L
.86393 .47266 L
.86393 .16187 L
F
.2 .63 .79 r
.86373 .16187 m
.86373 .47266 L
.86393 .47266 L
.86393 .16187 L
s
.678 .847 .902 r
.86393 .16187 m
.86393 .47283 L
.86433 .47283 L
.86433 .16187 L
F
.2 .63 .79 r
.86393 .16187 m
.86393 .47283 L
.86433 .47283 L
.86433 .16187 L
s
.678 .847 .902 r
.86433 .16187 m
.86433 .47331 L
.86471 .47331 L
.86471 .16187 L
F
.2 .63 .79 r
.86433 .16187 m
.86433 .47331 L
.86471 .47331 L
.86471 .16187 L
s
.678 .847 .902 r
.86471 .16187 m
.86471 .47369 L
.86498 .47369 L
.86498 .16187 L
F
.2 .63 .79 r
.86471 .16187 m
.86471 .47369 L
.86498 .47369 L
.86498 .16187 L
s
.678 .847 .902 r
.86498 .16187 m
.86498 .47404 L
.86517 .47404 L
.86517 .16187 L
F
.2 .63 .79 r
.86498 .16187 m
.86498 .47404 L
.86517 .47404 L
.86517 .16187 L
s
.678 .847 .902 r
.86517 .16187 m
.86517 .47425 L
.86563 .47425 L
.86563 .16187 L
F
.2 .63 .79 r
.86517 .16187 m
.86517 .47425 L
.86563 .47425 L
.86563 .16187 L
s
.678 .847 .902 r
.86563 .16187 m
.86563 .47481 L
.86593 .47481 L
.86593 .16187 L
F
.2 .63 .79 r
.86563 .16187 m
.86563 .47481 L
.86593 .47481 L
.86593 .16187 L
s
.678 .847 .902 r
.86593 .16187 m
.86593 .47541 L
.86638 .47541 L
.86638 .16187 L
F
.2 .63 .79 r
.86593 .16187 m
.86593 .47541 L
.86638 .47541 L
.86638 .16187 L
s
.678 .847 .902 r
.86638 .16187 m
.86638 .47553 L
.86664 .47553 L
.86664 .16187 L
F
.2 .63 .79 r
.86638 .16187 m
.86638 .47553 L
.86664 .47553 L
.86664 .16187 L
s
.678 .847 .902 r
.86664 .16187 m
.86664 .47584 L
.86701 .47584 L
.86701 .16187 L
F
.2 .63 .79 r
.86664 .16187 m
.86664 .47584 L
.86701 .47584 L
.86701 .16187 L
s
.678 .847 .902 r
.86701 .16187 m
.86701 .47637 L
.86735 .47637 L
.86735 .16187 L
F
.2 .63 .79 r
.86701 .16187 m
.86701 .47637 L
.86735 .47637 L
.86735 .16187 L
s
.678 .847 .902 r
.86735 .16187 m
.86735 .47648 L
.86755 .47648 L
.86755 .16187 L
F
.2 .63 .79 r
.86735 .16187 m
.86735 .47648 L
.86755 .47648 L
.86755 .16187 L
s
.678 .847 .902 r
.86755 .16187 m
.86755 .47686 L
.86803 .47686 L
.86803 .16187 L
F
.2 .63 .79 r
.86755 .16187 m
.86755 .47686 L
.86803 .47686 L
.86803 .16187 L
s
.678 .847 .902 r
.86803 .16187 m
.86803 .47726 L
.86834 .47726 L
.86834 .16187 L
F
.2 .63 .79 r
.86803 .16187 m
.86803 .47726 L
.86834 .47726 L
.86834 .16187 L
s
.678 .847 .902 r
.86834 .16187 m
.86834 .47769 L
.86866 .47769 L
.86866 .16187 L
F
.2 .63 .79 r
.86834 .16187 m
.86834 .47769 L
.86866 .47769 L
.86866 .16187 L
s
.678 .847 .902 r
.86866 .16187 m
.86866 .47794 L
.86895 .47794 L
.86895 .16187 L
F
.2 .63 .79 r
.86866 .16187 m
.86866 .47794 L
.86895 .47794 L
.86895 .16187 L
s
.678 .847 .902 r
.86895 .16187 m
.86895 .47839 L
.8692 .47839 L
.8692 .16187 L
F
.2 .63 .79 r
.86895 .16187 m
.86895 .47839 L
.8692 .47839 L
.8692 .16187 L
s
.678 .847 .902 r
.8692 .16187 m
.8692 .47862 L
.86936 .47862 L
.86936 .16187 L
F
.2 .63 .79 r
.8692 .16187 m
.8692 .47862 L
.86936 .47862 L
.86936 .16187 L
s
.678 .847 .902 r
.86936 .16187 m
.86936 .4788 L
.86952 .4788 L
.86952 .16187 L
F
.2 .63 .79 r
.86936 .16187 m
.86936 .4788 L
.86952 .4788 L
.86952 .16187 L
s
.678 .847 .902 r
.86952 .16187 m
.86952 .47922 L
.86999 .47922 L
.86999 .16187 L
F
.2 .63 .79 r
.86952 .16187 m
.86952 .47922 L
.86999 .47922 L
.86999 .16187 L
s
.678 .847 .902 r
.86999 .16187 m
.86999 .47945 L
.87017 .47945 L
.87017 .16187 L
F
.2 .63 .79 r
.86999 .16187 m
.86999 .47945 L
.87017 .47945 L
.87017 .16187 L
s
.678 .847 .902 r
.87017 .16187 m
.87017 .47961 L
.87038 .47961 L
.87038 .16187 L
F
.2 .63 .79 r
.87017 .16187 m
.87017 .47961 L
.87038 .47961 L
.87038 .16187 L
s
.678 .847 .902 r
.87038 .16187 m
.87038 .47995 L
.87059 .47995 L
.87059 .16187 L
F
.2 .63 .79 r
.87038 .16187 m
.87038 .47995 L
.87059 .47995 L
.87059 .16187 L
s
.678 .847 .902 r
.87059 .16187 m
.87059 .48023 L
.87087 .48023 L
.87087 .16187 L
F
.2 .63 .79 r
.87059 .16187 m
.87059 .48023 L
.87087 .48023 L
.87087 .16187 L
s
.678 .847 .902 r
.87087 .16187 m
.87087 .48071 L
.87134 .48071 L
.87134 .16187 L
F
.2 .63 .79 r
.87087 .16187 m
.87087 .48071 L
.87134 .48071 L
.87134 .16187 L
s
.678 .847 .902 r
.87134 .16187 m
.87134 .48118 L
.87165 .48118 L
.87165 .16187 L
F
.2 .63 .79 r
.87134 .16187 m
.87134 .48118 L
.87165 .48118 L
.87165 .16187 L
s
.678 .847 .902 r
.87165 .16187 m
.87165 .48131 L
.87197 .48131 L
.87197 .16187 L
F
.2 .63 .79 r
.87165 .16187 m
.87165 .48131 L
.87197 .48131 L
.87197 .16187 L
s
.678 .847 .902 r
.87197 .16187 m
.87197 .4817 L
.87245 .4817 L
.87245 .16187 L
F
.2 .63 .79 r
.87197 .16187 m
.87197 .4817 L
.87245 .4817 L
.87245 .16187 L
s
.678 .847 .902 r
.87245 .16187 m
.87245 .48254 L
.87289 .48254 L
.87289 .16187 L
F
.2 .63 .79 r
.87245 .16187 m
.87245 .48254 L
.87289 .48254 L
.87289 .16187 L
s
.678 .847 .902 r
.87289 .16187 m
.87289 .4828 L
.87323 .4828 L
.87323 .16187 L
F
.2 .63 .79 r
.87289 .16187 m
.87289 .4828 L
.87323 .4828 L
.87323 .16187 L
s
.678 .847 .902 r
.87323 .16187 m
.87323 .48305 L
.8734 .48305 L
.8734 .16187 L
F
.2 .63 .79 r
.87323 .16187 m
.87323 .48305 L
.8734 .48305 L
.8734 .16187 L
s
.678 .847 .902 r
.8734 .16187 m
.8734 .48318 L
.87358 .48318 L
.87358 .16187 L
F
.2 .63 .79 r
.8734 .16187 m
.8734 .48318 L
.87358 .48318 L
.87358 .16187 L
s
.678 .847 .902 r
.87358 .16187 m
.87358 .48352 L
.87391 .48352 L
.87391 .16187 L
F
.2 .63 .79 r
.87358 .16187 m
.87358 .48352 L
.87391 .48352 L
.87391 .16187 L
s
.678 .847 .902 r
.87391 .16187 m
.87391 .48382 L
.87437 .48382 L
.87437 .16187 L
F
.2 .63 .79 r
.87391 .16187 m
.87391 .48382 L
.87437 .48382 L
.87437 .16187 L
s
.678 .847 .902 r
.87437 .16187 m
.87437 .48451 L
.87469 .48451 L
.87469 .16187 L
F
.2 .63 .79 r
.87437 .16187 m
.87437 .48451 L
.87469 .48451 L
.87469 .16187 L
s
.678 .847 .902 r
.87469 .16187 m
.87469 .48466 L
.87517 .48466 L
.87517 .16187 L
F
.2 .63 .79 r
.87469 .16187 m
.87469 .48466 L
.87517 .48466 L
.87517 .16187 L
s
.678 .847 .902 r
.87517 .16187 m
.87517 .48516 L
.8755 .48516 L
.8755 .16187 L
F
.2 .63 .79 r
.87517 .16187 m
.87517 .48516 L
.8755 .48516 L
.8755 .16187 L
s
.678 .847 .902 r
.8755 .16187 m
.8755 .48549 L
.8758 .48549 L
.8758 .16187 L
F
.2 .63 .79 r
.8755 .16187 m
.8755 .48549 L
.8758 .48549 L
.8758 .16187 L
s
.678 .847 .902 r
.8758 .16187 m
.8758 .48586 L
.87596 .48586 L
.87596 .16187 L
F
.2 .63 .79 r
.8758 .16187 m
.8758 .48586 L
.87596 .48586 L
.87596 .16187 L
s
.678 .847 .902 r
.87596 .16187 m
.87596 .48598 L
.87628 .48598 L
.87628 .16187 L
F
.2 .63 .79 r
.87596 .16187 m
.87596 .48598 L
.87628 .48598 L
.87628 .16187 L
s
.678 .847 .902 r
.87628 .16187 m
.87628 .48647 L
.87652 .48647 L
.87652 .16187 L
F
.2 .63 .79 r
.87628 .16187 m
.87628 .48647 L
.87652 .48647 L
.87652 .16187 L
s
.678 .847 .902 r
.87652 .16187 m
.87652 .48671 L
.87681 .48671 L
.87681 .16187 L
F
.2 .63 .79 r
.87652 .16187 m
.87652 .48671 L
.87681 .48671 L
.87681 .16187 L
s
.678 .847 .902 r
.87681 .16187 m
.87681 .48733 L
.87729 .48733 L
.87729 .16187 L
F
.2 .63 .79 r
.87681 .16187 m
.87681 .48733 L
.87729 .48733 L
.87729 .16187 L
s
.678 .847 .902 r
.87729 .16187 m
.87729 .48757 L
.87764 .48757 L
.87764 .16187 L
F
.2 .63 .79 r
.87729 .16187 m
.87729 .48757 L
.87764 .48757 L
.87764 .16187 L
s
.678 .847 .902 r
.87764 .16187 m
.87764 .48785 L
.87784 .48785 L
.87784 .16187 L
F
.2 .63 .79 r
.87764 .16187 m
.87764 .48785 L
.87784 .48785 L
.87784 .16187 L
s
.678 .847 .902 r
.87784 .16187 m
.87784 .48809 L
.87807 .48809 L
.87807 .16187 L
F
.2 .63 .79 r
.87784 .16187 m
.87784 .48809 L
.87807 .48809 L
.87807 .16187 L
s
.678 .847 .902 r
.87807 .16187 m
.87807 .48835 L
.87849 .48835 L
.87849 .16187 L
F
.2 .63 .79 r
.87807 .16187 m
.87807 .48835 L
.87849 .48835 L
.87849 .16187 L
s
.678 .847 .902 r
.87849 .16187 m
.87849 .48892 L
.87871 .48892 L
.87871 .16187 L
F
.2 .63 .79 r
.87849 .16187 m
.87849 .48892 L
.87871 .48892 L
.87871 .16187 L
s
.678 .847 .902 r
.87871 .16187 m
.87871 .48911 L
.87893 .48911 L
.87893 .16187 L
F
.2 .63 .79 r
.87871 .16187 m
.87871 .48911 L
.87893 .48911 L
.87893 .16187 L
s
.678 .847 .902 r
.87893 .16187 m
.87893 .48937 L
.87934 .48937 L
.87934 .16187 L
F
.2 .63 .79 r
.87893 .16187 m
.87893 .48937 L
.87934 .48937 L
.87934 .16187 L
s
.678 .847 .902 r
.87934 .16187 m
.87934 .48992 L
.87959 .48992 L
.87959 .16187 L
F
.2 .63 .79 r
.87934 .16187 m
.87934 .48992 L
.87959 .48992 L
.87959 .16187 L
s
.678 .847 .902 r
.87959 .16187 m
.87959 .49008 L
.87981 .49008 L
.87981 .16187 L
F
.2 .63 .79 r
.87959 .16187 m
.87959 .49008 L
.87981 .49008 L
.87981 .16187 L
s
.678 .847 .902 r
.87981 .16187 m
.87981 .49038 L
.88009 .49038 L
.88009 .16187 L
F
.2 .63 .79 r
.87981 .16187 m
.87981 .49038 L
.88009 .49038 L
.88009 .16187 L
s
.678 .847 .902 r
.88009 .16187 m
.88009 .49069 L
.88031 .49069 L
.88031 .16187 L
F
.2 .63 .79 r
.88009 .16187 m
.88009 .49069 L
.88031 .49069 L
.88031 .16187 L
s
.678 .847 .902 r
.88031 .16187 m
.88031 .49082 L
.88054 .49082 L
.88054 .16187 L
F
.2 .63 .79 r
.88031 .16187 m
.88031 .49082 L
.88054 .49082 L
.88054 .16187 L
s
.678 .847 .902 r
.88054 .16187 m
.88054 .49105 L
.88073 .49105 L
.88073 .16187 L
F
.2 .63 .79 r
.88054 .16187 m
.88054 .49105 L
.88073 .49105 L
.88073 .16187 L
s
.678 .847 .902 r
.88073 .16187 m
.88073 .49171 L
.88117 .49171 L
.88117 .16187 L
F
.2 .63 .79 r
.88073 .16187 m
.88073 .49171 L
.88117 .49171 L
.88117 .16187 L
s
.678 .847 .902 r
.88117 .16187 m
.88117 .49183 L
.88143 .49183 L
.88143 .16187 L
F
.2 .63 .79 r
.88117 .16187 m
.88117 .49183 L
.88143 .49183 L
.88143 .16187 L
s
.678 .847 .902 r
.88143 .16187 m
.88143 .49213 L
.88182 .49213 L
.88182 .16187 L
F
.2 .63 .79 r
.88143 .16187 m
.88143 .49213 L
.88182 .49213 L
.88182 .16187 L
s
.678 .847 .902 r
.88182 .16187 m
.88182 .49266 L
.88202 .49266 L
.88202 .16187 L
F
.2 .63 .79 r
.88182 .16187 m
.88182 .49266 L
.88202 .49266 L
.88202 .16187 L
s
.678 .847 .902 r
.88202 .16187 m
.88202 .49289 L
.88227 .49289 L
.88227 .16187 L
F
.2 .63 .79 r
.88202 .16187 m
.88202 .49289 L
.88227 .49289 L
.88227 .16187 L
s
.678 .847 .902 r
.88227 .16187 m
.88227 .49308 L
.88273 .49308 L
.88273 .16187 L
F
.2 .63 .79 r
.88227 .16187 m
.88227 .49308 L
.88273 .49308 L
.88273 .16187 L
s
.678 .847 .902 r
.88273 .16187 m
.88273 .49379 L
.88312 .49379 L
.88312 .16187 L
F
.2 .63 .79 r
.88273 .16187 m
.88273 .49379 L
.88312 .49379 L
.88312 .16187 L
s
.678 .847 .902 r
.88312 .16187 m
.88312 .49423 L
.88349 .49423 L
.88349 .16187 L
F
.2 .63 .79 r
.88312 .16187 m
.88312 .49423 L
.88349 .49423 L
.88349 .16187 L
s
.678 .847 .902 r
.88349 .16187 m
.88349 .49433 L
.88365 .49433 L
.88365 .16187 L
F
.2 .63 .79 r
.88349 .16187 m
.88349 .49433 L
.88365 .49433 L
.88365 .16187 L
s
.678 .847 .902 r
.88365 .16187 m
.88365 .49476 L
.88396 .49476 L
.88396 .16187 L
F
.2 .63 .79 r
.88365 .16187 m
.88365 .49476 L
.88396 .49476 L
.88396 .16187 L
s
.678 .847 .902 r
.88396 .16187 m
.88396 .49525 L
.88436 .49525 L
.88436 .16187 L
F
.2 .63 .79 r
.88396 .16187 m
.88396 .49525 L
.88436 .49525 L
.88436 .16187 L
s
.678 .847 .902 r
.88436 .16187 m
.88436 .49536 L
.88453 .49536 L
.88453 .16187 L
F
.2 .63 .79 r
.88436 .16187 m
.88436 .49536 L
.88453 .49536 L
.88453 .16187 L
s
.678 .847 .902 r
.88453 .16187 m
.88453 .49593 L
.88498 .49593 L
.88498 .16187 L
F
.2 .63 .79 r
.88453 .16187 m
.88453 .49593 L
.88498 .49593 L
.88498 .16187 L
s
.678 .847 .902 r
.88498 .16187 m
.88498 .49612 L
.88521 .49612 L
.88521 .16187 L
F
.2 .63 .79 r
.88498 .16187 m
.88498 .49612 L
.88521 .49612 L
.88521 .16187 L
s
.678 .847 .902 r
.88521 .16187 m
.88521 .49664 L
.88568 .49664 L
.88568 .16187 L
F
.2 .63 .79 r
.88521 .16187 m
.88521 .49664 L
.88568 .49664 L
.88568 .16187 L
s
.678 .847 .902 r
.88568 .16187 m
.88568 .4971 L
.88613 .4971 L
.88613 .16187 L
F
.2 .63 .79 r
.88568 .16187 m
.88568 .4971 L
.88613 .4971 L
.88613 .16187 L
s
.678 .847 .902 r
.88613 .16187 m
.88613 .49744 L
.8865 .49744 L
.8865 .16187 L
F
.2 .63 .79 r
.88613 .16187 m
.88613 .49744 L
.8865 .49744 L
.8865 .16187 L
s
.678 .847 .902 r
.8865 .16187 m
.8865 .49777 L
.88682 .49777 L
.88682 .16187 L
F
.2 .63 .79 r
.8865 .16187 m
.8865 .49777 L
.88682 .49777 L
.88682 .16187 L
s
.678 .847 .902 r
.88682 .16187 m
.88682 .49842 L
.88718 .49842 L
.88718 .16187 L
F
.2 .63 .79 r
.88682 .16187 m
.88682 .49842 L
.88718 .49842 L
.88718 .16187 L
s
.678 .847 .902 r
.88718 .16187 m
.88718 .49855 L
.88756 .49855 L
.88756 .16187 L
F
.2 .63 .79 r
.88718 .16187 m
.88718 .49855 L
.88756 .49855 L
.88756 .16187 L
s
.678 .847 .902 r
.88756 .16187 m
.88756 .49911 L
.88781 .49911 L
.88781 .16187 L
F
.2 .63 .79 r
.88756 .16187 m
.88756 .49911 L
.88781 .49911 L
.88781 .16187 L
s
.678 .847 .902 r
.88781 .16187 m
.88781 .49929 L
.88804 .49929 L
.88804 .16187 L
F
.2 .63 .79 r
.88781 .16187 m
.88781 .49929 L
.88804 .49929 L
.88804 .16187 L
s
.678 .847 .902 r
.88804 .16187 m
.88804 .49964 L
.88833 .49964 L
.88833 .16187 L
F
.2 .63 .79 r
.88804 .16187 m
.88804 .49964 L
.88833 .49964 L
.88833 .16187 L
s
.678 .847 .902 r
.88833 .16187 m
.88833 .49977 L
.88866 .49977 L
.88866 .16187 L
F
.2 .63 .79 r
.88833 .16187 m
.88833 .49977 L
.88866 .49977 L
.88866 .16187 L
s
.678 .847 .902 r
.88866 .16187 m
.88866 .50041 L
.88896 .50041 L
.88896 .16187 L
F
.2 .63 .79 r
.88866 .16187 m
.88866 .50041 L
.88896 .50041 L
.88896 .16187 L
s
.678 .847 .902 r
.88896 .16187 m
.88896 .50055 L
.88943 .50055 L
.88943 .16187 L
F
.2 .63 .79 r
.88896 .16187 m
.88896 .50055 L
.88943 .50055 L
.88943 .16187 L
s
.678 .847 .902 r
.88943 .16187 m
.88943 .50117 L
.88981 .50117 L
.88981 .16187 L
F
.2 .63 .79 r
.88943 .16187 m
.88943 .50117 L
.88981 .50117 L
.88981 .16187 L
s
.678 .847 .902 r
.88981 .16187 m
.88981 .50145 L
.89009 .50145 L
.89009 .16187 L
F
.2 .63 .79 r
.88981 .16187 m
.88981 .50145 L
.89009 .50145 L
.89009 .16187 L
s
.678 .847 .902 r
.89009 .16187 m
.89009 .50174 L
.89029 .50174 L
.89029 .16187 L
F
.2 .63 .79 r
.89009 .16187 m
.89009 .50174 L
.89029 .50174 L
.89029 .16187 L
s
.678 .847 .902 r
.89029 .16187 m
.89029 .5021 L
.89045 .5021 L
.89045 .16187 L
F
.2 .63 .79 r
.89029 .16187 m
.89029 .5021 L
.89045 .5021 L
.89045 .16187 L
s
.678 .847 .902 r
.89045 .16187 m
.89045 .50251 L
.89094 .50251 L
.89094 .16187 L
F
.2 .63 .79 r
.89045 .16187 m
.89045 .50251 L
.89094 .50251 L
.89094 .16187 L
s
.678 .847 .902 r
.89094 .16187 m
.89094 .50283 L
.89134 .50283 L
.89134 .16187 L
F
.2 .63 .79 r
.89094 .16187 m
.89094 .50283 L
.89134 .50283 L
.89134 .16187 L
s
.678 .847 .902 r
.89134 .16187 m
.89134 .50312 L
.89153 .50312 L
.89153 .16187 L
F
.2 .63 .79 r
.89134 .16187 m
.89134 .50312 L
.89153 .50312 L
.89153 .16187 L
s
.678 .847 .902 r
.89153 .16187 m
.89153 .50338 L
.89186 .50338 L
.89186 .16187 L
F
.2 .63 .79 r
.89153 .16187 m
.89153 .50338 L
.89186 .50338 L
.89186 .16187 L
s
.678 .847 .902 r
.89186 .16187 m
.89186 .50392 L
.8921 .50392 L
.8921 .16187 L
F
.2 .63 .79 r
.89186 .16187 m
.89186 .50392 L
.8921 .50392 L
.8921 .16187 L
s
.678 .847 .902 r
.8921 .16187 m
.8921 .50438 L
.89247 .50438 L
.89247 .16187 L
F
.2 .63 .79 r
.8921 .16187 m
.8921 .50438 L
.89247 .50438 L
.89247 .16187 L
s
.678 .847 .902 r
.89247 .16187 m
.89247 .50442 L
.89271 .50442 L
.89271 .16187 L
F
.2 .63 .79 r
.89247 .16187 m
.89247 .50442 L
.89271 .50442 L
.89271 .16187 L
s
.678 .847 .902 r
.89271 .16187 m
.89271 .50483 L
.89296 .50483 L
.89296 .16187 L
F
.2 .63 .79 r
.89271 .16187 m
.89271 .50483 L
.89296 .50483 L
.89296 .16187 L
s
.678 .847 .902 r
.89296 .16187 m
.89296 .50495 L
.89322 .50495 L
.89322 .16187 L
F
.2 .63 .79 r
.89296 .16187 m
.89296 .50495 L
.89322 .50495 L
.89322 .16187 L
s
.678 .847 .902 r
.89322 .16187 m
.89322 .50536 L
.89364 .50536 L
.89364 .16187 L
F
.2 .63 .79 r
.89322 .16187 m
.89322 .50536 L
.89364 .50536 L
.89364 .16187 L
s
.678 .847 .902 r
.89364 .16187 m
.89364 .50598 L
.89399 .50598 L
.89399 .16187 L
F
.2 .63 .79 r
.89364 .16187 m
.89364 .50598 L
.89399 .50598 L
.89399 .16187 L
s
.678 .847 .902 r
.89399 .16187 m
.89399 .50628 L
.89442 .50628 L
.89442 .16187 L
F
.2 .63 .79 r
.89399 .16187 m
.89399 .50628 L
.89442 .50628 L
.89442 .16187 L
s
.678 .847 .902 r
.89442 .16187 m
.89442 .50663 L
.89481 .50663 L
.89481 .16187 L
F
.2 .63 .79 r
.89442 .16187 m
.89442 .50663 L
.89481 .50663 L
.89481 .16187 L
s
.678 .847 .902 r
.89481 .16187 m
.89481 .50703 L
.895 .50703 L
.895 .16187 L
F
.2 .63 .79 r
.89481 .16187 m
.89481 .50703 L
.895 .50703 L
.895 .16187 L
s
.678 .847 .902 r
.895 .16187 m
.895 .50747 L
.89525 .50747 L
.89525 .16187 L
F
.2 .63 .79 r
.895 .16187 m
.895 .50747 L
.89525 .50747 L
.89525 .16187 L
s
.678 .847 .902 r
.89525 .16187 m
.89525 .50783 L
.8956 .50783 L
.8956 .16187 L
F
.2 .63 .79 r
.89525 .16187 m
.89525 .50783 L
.8956 .50783 L
.8956 .16187 L
s
.678 .847 .902 r
.8956 .16187 m
.8956 .50801 L
.89584 .50801 L
.89584 .16187 L
F
.2 .63 .79 r
.8956 .16187 m
.8956 .50801 L
.89584 .50801 L
.89584 .16187 L
s
.678 .847 .902 r
.89584 .16187 m
.89584 .50856 L
.8962 .50856 L
.8962 .16187 L
F
.2 .63 .79 r
.89584 .16187 m
.89584 .50856 L
.8962 .50856 L
.8962 .16187 L
s
.678 .847 .902 r
.8962 .16187 m
.8962 .50903 L
.89663 .50903 L
.89663 .16187 L
F
.2 .63 .79 r
.8962 .16187 m
.8962 .50903 L
.89663 .50903 L
.89663 .16187 L
s
.678 .847 .902 r
.89663 .16187 m
.89663 .50933 L
.89701 .50933 L
.89701 .16187 L
F
.2 .63 .79 r
.89663 .16187 m
.89663 .50933 L
.89701 .50933 L
.89701 .16187 L
s
.678 .847 .902 r
.89701 .16187 m
.89701 .50985 L
.89736 .50985 L
.89736 .16187 L
F
.2 .63 .79 r
.89701 .16187 m
.89701 .50985 L
.89736 .50985 L
.89736 .16187 L
s
.678 .847 .902 r
.89736 .16187 m
.89736 .51009 L
.89758 .51009 L
.89758 .16187 L
F
.2 .63 .79 r
.89736 .16187 m
.89736 .51009 L
.89758 .51009 L
.89758 .16187 L
s
.678 .847 .902 r
.89758 .16187 m
.89758 .51047 L
.89797 .51047 L
.89797 .16187 L
F
.2 .63 .79 r
.89758 .16187 m
.89758 .51047 L
.89797 .51047 L
.89797 .16187 L
s
.678 .847 .902 r
.89797 .16187 m
.89797 .51085 L
.89834 .51085 L
.89834 .16187 L
F
.2 .63 .79 r
.89797 .16187 m
.89797 .51085 L
.89834 .51085 L
.89834 .16187 L
s
.678 .847 .902 r
.89834 .16187 m
.89834 .51107 L
.89868 .51107 L
.89868 .16187 L
F
.2 .63 .79 r
.89834 .16187 m
.89834 .51107 L
.89868 .51107 L
.89868 .16187 L
s
.678 .847 .902 r
.89868 .16187 m
.89868 .51153 L
.899 .51153 L
.899 .16187 L
F
.2 .63 .79 r
.89868 .16187 m
.89868 .51153 L
.899 .51153 L
.899 .16187 L
s
.678 .847 .902 r
.899 .16187 m
.899 .51203 L
.89935 .51203 L
.89935 .16187 L
F
.2 .63 .79 r
.899 .16187 m
.899 .51203 L
.89935 .51203 L
.89935 .16187 L
s
.678 .847 .902 r
.89935 .16187 m
.89935 .51225 L
.89952 .51225 L
.89952 .16187 L
F
.2 .63 .79 r
.89935 .16187 m
.89935 .51225 L
.89952 .51225 L
.89952 .16187 L
s
.678 .847 .902 r
.89952 .16187 m
.89952 .51246 L
.89978 .51246 L
.89978 .16187 L
F
.2 .63 .79 r
.89952 .16187 m
.89952 .51246 L
.89978 .51246 L
.89978 .16187 L
s
.678 .847 .902 r
.89978 .16187 m
.89978 .51284 L
.90022 .51284 L
.90022 .16187 L
F
.2 .63 .79 r
.89978 .16187 m
.89978 .51284 L
.90022 .51284 L
.90022 .16187 L
s
.678 .847 .902 r
.90022 .16187 m
.90022 .51331 L
.90048 .51331 L
.90048 .16187 L
F
.2 .63 .79 r
.90022 .16187 m
.90022 .51331 L
.90048 .51331 L
.90048 .16187 L
s
.678 .847 .902 r
.90048 .16187 m
.90048 .51384 L
.9009 .51384 L
.9009 .16187 L
F
.2 .63 .79 r
.90048 .16187 m
.90048 .51384 L
.9009 .51384 L
.9009 .16187 L
s
.678 .847 .902 r
.9009 .16187 m
.9009 .51409 L
.90138 .51409 L
.90138 .16187 L
F
.2 .63 .79 r
.9009 .16187 m
.9009 .51409 L
.90138 .51409 L
.90138 .16187 L
s
.678 .847 .902 r
.90138 .16187 m
.90138 .5145 L
.90155 .5145 L
.90155 .16187 L
F
.2 .63 .79 r
.90138 .16187 m
.90138 .5145 L
.90155 .5145 L
.90155 .16187 L
s
.678 .847 .902 r
.90155 .16187 m
.90155 .51505 L
.90195 .51505 L
.90195 .16187 L
F
.2 .63 .79 r
.90155 .16187 m
.90155 .51505 L
.90195 .51505 L
.90195 .16187 L
s
.678 .847 .902 r
.90195 .16187 m
.90195 .51538 L
.90243 .51538 L
.90243 .16187 L
F
.2 .63 .79 r
.90195 .16187 m
.90195 .51538 L
.90243 .51538 L
.90243 .16187 L
s
.678 .847 .902 r
.90243 .16187 m
.90243 .51573 L
.90268 .51573 L
.90268 .16187 L
F
.2 .63 .79 r
.90243 .16187 m
.90243 .51573 L
.90268 .51573 L
.90268 .16187 L
s
.678 .847 .902 r
.90268 .16187 m
.90268 .51599 L
.90315 .51599 L
.90315 .16187 L
F
.2 .63 .79 r
.90268 .16187 m
.90268 .51599 L
.90315 .51599 L
.90315 .16187 L
s
.678 .847 .902 r
.90315 .16187 m
.90315 .51651 L
.90345 .51651 L
.90345 .16187 L
F
.2 .63 .79 r
.90315 .16187 m
.90315 .51651 L
.90345 .51651 L
.90345 .16187 L
s
.678 .847 .902 r
.90345 .16187 m
.90345 .51705 L
.90372 .51705 L
.90372 .16187 L
F
.2 .63 .79 r
.90345 .16187 m
.90345 .51705 L
.90372 .51705 L
.90372 .16187 L
s
.678 .847 .902 r
.90372 .16187 m
.90372 .5173 L
.90388 .5173 L
.90388 .16187 L
F
.2 .63 .79 r
.90372 .16187 m
.90372 .5173 L
.90388 .5173 L
.90388 .16187 L
s
.678 .847 .902 r
.90388 .16187 m
.90388 .51737 L
.90414 .51737 L
.90414 .16187 L
F
.2 .63 .79 r
.90388 .16187 m
.90388 .51737 L
.90414 .51737 L
.90414 .16187 L
s
.678 .847 .902 r
.90414 .16187 m
.90414 .51769 L
.90449 .51769 L
.90449 .16187 L
F
.2 .63 .79 r
.90414 .16187 m
.90414 .51769 L
.90449 .51769 L
.90449 .16187 L
s
.678 .847 .902 r
.90449 .16187 m
.90449 .51809 L
.90488 .51809 L
.90488 .16187 L
F
.2 .63 .79 r
.90449 .16187 m
.90449 .51809 L
.90488 .51809 L
.90488 .16187 L
s
.678 .847 .902 r
.90488 .16187 m
.90488 .51882 L
.90519 .51882 L
.90519 .16187 L
F
.2 .63 .79 r
.90488 .16187 m
.90488 .51882 L
.90519 .51882 L
.90519 .16187 L
s
.678 .847 .902 r
.90519 .16187 m
.90519 .51891 L
.90537 .51891 L
.90537 .16187 L
F
.2 .63 .79 r
.90519 .16187 m
.90519 .51891 L
.90537 .51891 L
.90537 .16187 L
s
.678 .847 .902 r
.90537 .16187 m
.90537 .51927 L
.90583 .51927 L
.90583 .16187 L
F
.2 .63 .79 r
.90537 .16187 m
.90537 .51927 L
.90583 .51927 L
.90583 .16187 L
s
.678 .847 .902 r
.90583 .16187 m
.90583 .51966 L
.90599 .51966 L
.90599 .16187 L
F
.2 .63 .79 r
.90583 .16187 m
.90583 .51966 L
.90599 .51966 L
.90599 .16187 L
s
.678 .847 .902 r
.90599 .16187 m
.90599 .52019 L
.90645 .52019 L
.90645 .16187 L
F
.2 .63 .79 r
.90599 .16187 m
.90599 .52019 L
.90645 .52019 L
.90645 .16187 L
s
.678 .847 .902 r
.90645 .16187 m
.90645 .5203 L
.9068 .5203 L
.9068 .16187 L
F
.2 .63 .79 r
.90645 .16187 m
.90645 .5203 L
.9068 .5203 L
.9068 .16187 L
s
.678 .847 .902 r
.9068 .16187 m
.9068 .52091 L
.90706 .52091 L
.90706 .16187 L
F
.2 .63 .79 r
.9068 .16187 m
.9068 .52091 L
.90706 .52091 L
.90706 .16187 L
s
.678 .847 .902 r
.90706 .16187 m
.90706 .52103 L
.90755 .52103 L
.90755 .16187 L
F
.2 .63 .79 r
.90706 .16187 m
.90706 .52103 L
.90755 .52103 L
.90755 .16187 L
s
.678 .847 .902 r
.90755 .16187 m
.90755 .52173 L
.9079 .52173 L
.9079 .16187 L
F
.2 .63 .79 r
.90755 .16187 m
.90755 .52173 L
.9079 .52173 L
.9079 .16187 L
s
.678 .847 .902 r
.9079 .16187 m
.9079 .52225 L
.9083 .52225 L
.9083 .16187 L
F
.2 .63 .79 r
.9079 .16187 m
.9079 .52225 L
.9083 .52225 L
.9083 .16187 L
s
.678 .847 .902 r
.9083 .16187 m
.9083 .52244 L
.90845 .52244 L
.90845 .16187 L
F
.2 .63 .79 r
.9083 .16187 m
.9083 .52244 L
.90845 .52244 L
.90845 .16187 L
s
.678 .847 .902 r
.90845 .16187 m
.90845 .52263 L
.90866 .52263 L
.90866 .16187 L
F
.2 .63 .79 r
.90845 .16187 m
.90845 .52263 L
.90866 .52263 L
.90866 .16187 L
s
.678 .847 .902 r
.90866 .16187 m
.90866 .52289 L
.90902 .52289 L
.90902 .16187 L
F
.2 .63 .79 r
.90866 .16187 m
.90866 .52289 L
.90902 .52289 L
.90902 .16187 L
s
.678 .847 .902 r
.90902 .16187 m
.90902 .52349 L
.90939 .52349 L
.90939 .16187 L
F
.2 .63 .79 r
.90902 .16187 m
.90902 .52349 L
.90939 .52349 L
.90939 .16187 L
s
.678 .847 .902 r
.90939 .16187 m
.90939 .52377 L
.90964 .52377 L
.90964 .16187 L
F
.2 .63 .79 r
.90939 .16187 m
.90939 .52377 L
.90964 .52377 L
.90964 .16187 L
s
.678 .847 .902 r
.90964 .16187 m
.90964 .52415 L
.90987 .52415 L
.90987 .16187 L
F
.2 .63 .79 r
.90964 .16187 m
.90964 .52415 L
.90987 .52415 L
.90987 .16187 L
s
.678 .847 .902 r
.90987 .16187 m
.90987 .5242 L
.91012 .5242 L
.91012 .16187 L
F
.2 .63 .79 r
.90987 .16187 m
.90987 .5242 L
.91012 .5242 L
.91012 .16187 L
s
.678 .847 .902 r
.91012 .16187 m
.91012 .52475 L
.91052 .52475 L
.91052 .16187 L
F
.2 .63 .79 r
.91012 .16187 m
.91012 .52475 L
.91052 .52475 L
.91052 .16187 L
s
.678 .847 .902 r
.91052 .16187 m
.91052 .52516 L
.91096 .52516 L
.91096 .16187 L
F
.2 .63 .79 r
.91052 .16187 m
.91052 .52516 L
.91096 .52516 L
.91096 .16187 L
s
.678 .847 .902 r
.91096 .16187 m
.91096 .52553 L
.91141 .52553 L
.91141 .16187 L
F
.2 .63 .79 r
.91096 .16187 m
.91096 .52553 L
.91141 .52553 L
.91141 .16187 L
s
.678 .847 .902 r
.91141 .16187 m
.91141 .52602 L
.91165 .52602 L
.91165 .16187 L
F
.2 .63 .79 r
.91141 .16187 m
.91141 .52602 L
.91165 .52602 L
.91165 .16187 L
s
.678 .847 .902 r
.91165 .16187 m
.91165 .52639 L
.91193 .52639 L
.91193 .16187 L
F
.2 .63 .79 r
.91165 .16187 m
.91165 .52639 L
.91193 .52639 L
.91193 .16187 L
s
.678 .847 .902 r
.91193 .16187 m
.91193 .52664 L
.91217 .52664 L
.91217 .16187 L
F
.2 .63 .79 r
.91193 .16187 m
.91193 .52664 L
.91217 .52664 L
.91217 .16187 L
s
.678 .847 .902 r
.91217 .16187 m
.91217 .52685 L
.91238 .52685 L
.91238 .16187 L
F
.2 .63 .79 r
.91217 .16187 m
.91217 .52685 L
.91238 .52685 L
.91238 .16187 L
s
.678 .847 .902 r
.91238 .16187 m
.91238 .52719 L
.9128 .52719 L
.9128 .16187 L
F
.2 .63 .79 r
.91238 .16187 m
.91238 .52719 L
.9128 .52719 L
.9128 .16187 L
s
.678 .847 .902 r
.9128 .16187 m
.9128 .52759 L
.91305 .52759 L
.91305 .16187 L
F
.2 .63 .79 r
.9128 .16187 m
.9128 .52759 L
.91305 .52759 L
.91305 .16187 L
s
.678 .847 .902 r
.91305 .16187 m
.91305 .52812 L
.91332 .52812 L
.91332 .16187 L
F
.2 .63 .79 r
.91305 .16187 m
.91305 .52812 L
.91332 .52812 L
.91332 .16187 L
s
.678 .847 .902 r
.91332 .16187 m
.91332 .52828 L
.91351 .52828 L
.91351 .16187 L
F
.2 .63 .79 r
.91332 .16187 m
.91332 .52828 L
.91351 .52828 L
.91351 .16187 L
s
.678 .847 .902 r
.91351 .16187 m
.91351 .52859 L
.91397 .52859 L
.91397 .16187 L
F
.2 .63 .79 r
.91351 .16187 m
.91351 .52859 L
.91397 .52859 L
.91397 .16187 L
s
.678 .847 .902 r
.91397 .16187 m
.91397 .52937 L
.91436 .52937 L
.91436 .16187 L
F
.2 .63 .79 r
.91397 .16187 m
.91397 .52937 L
.91436 .52937 L
.91436 .16187 L
s
.678 .847 .902 r
.91436 .16187 m
.91436 .52938 L
.91452 .52938 L
.91452 .16187 L
F
.2 .63 .79 r
.91436 .16187 m
.91436 .52938 L
.91452 .52938 L
.91452 .16187 L
s
.678 .847 .902 r
.91452 .16187 m
.91452 .52965 L
.91472 .52965 L
.91472 .16187 L
F
.2 .63 .79 r
.91452 .16187 m
.91452 .52965 L
.91472 .52965 L
.91472 .16187 L
s
.678 .847 .902 r
.91472 .16187 m
.91472 .53005 L
.91498 .53005 L
.91498 .16187 L
F
.2 .63 .79 r
.91472 .16187 m
.91472 .53005 L
.91498 .53005 L
.91498 .16187 L
s
.678 .847 .902 r
.91498 .16187 m
.91498 .53024 L
.91546 .53024 L
.91546 .16187 L
F
.2 .63 .79 r
.91498 .16187 m
.91498 .53024 L
.91546 .53024 L
.91546 .16187 L
s
.678 .847 .902 r
.91546 .16187 m
.91546 .53078 L
.91561 .53078 L
.91561 .16187 L
F
.2 .63 .79 r
.91546 .16187 m
.91546 .53078 L
.91561 .53078 L
.91561 .16187 L
s
.678 .847 .902 r
.91561 .16187 m
.91561 .53088 L
.91609 .53088 L
.91609 .16187 L
F
.2 .63 .79 r
.91561 .16187 m
.91561 .53088 L
.91609 .53088 L
.91609 .16187 L
s
.678 .847 .902 r
.91609 .16187 m
.91609 .53168 L
.91649 .53168 L
.91649 .16187 L
F
.2 .63 .79 r
.91609 .16187 m
.91609 .53168 L
.91649 .53168 L
.91649 .16187 L
s
.678 .847 .902 r
.91649 .16187 m
.91649 .53202 L
.91674 .53202 L
.91674 .16187 L
F
.2 .63 .79 r
.91649 .16187 m
.91649 .53202 L
.91674 .53202 L
.91674 .16187 L
s
.678 .847 .902 r
.91674 .16187 m
.91674 .53227 L
.91714 .53227 L
.91714 .16187 L
F
.2 .63 .79 r
.91674 .16187 m
.91674 .53227 L
.91714 .53227 L
.91714 .16187 L
s
.678 .847 .902 r
.91714 .16187 m
.91714 .53271 L
.91754 .53271 L
.91754 .16187 L
F
.2 .63 .79 r
.91714 .16187 m
.91714 .53271 L
.91754 .53271 L
.91754 .16187 L
s
.678 .847 .902 r
.91754 .16187 m
.91754 .53327 L
.91783 .53327 L
.91783 .16187 L
F
.2 .63 .79 r
.91754 .16187 m
.91754 .53327 L
.91783 .53327 L
.91783 .16187 L
s
.678 .847 .902 r
.91783 .16187 m
.91783 .53341 L
.91818 .53341 L
.91818 .16187 L
F
.2 .63 .79 r
.91783 .16187 m
.91783 .53341 L
.91818 .53341 L
.91818 .16187 L
s
.678 .847 .902 r
.91818 .16187 m
.91818 .53425 L
.91862 .53425 L
.91862 .16187 L
F
.2 .63 .79 r
.91818 .16187 m
.91818 .53425 L
.91862 .53425 L
.91862 .16187 L
s
.678 .847 .902 r
.91862 .16187 m
.91862 .53437 L
.91907 .53437 L
.91907 .16187 L
F
.2 .63 .79 r
.91862 .16187 m
.91862 .53437 L
.91907 .53437 L
.91907 .16187 L
s
.678 .847 .902 r
.91907 .16187 m
.91907 .53493 L
.91926 .53493 L
.91926 .16187 L
F
.2 .63 .79 r
.91907 .16187 m
.91907 .53493 L
.91926 .53493 L
.91926 .16187 L
s
.678 .847 .902 r
.91926 .16187 m
.91926 .53521 L
.91948 .53521 L
.91948 .16187 L
F
.2 .63 .79 r
.91926 .16187 m
.91926 .53521 L
.91948 .53521 L
.91948 .16187 L
s
.678 .847 .902 r
.91948 .16187 m
.91948 .53556 L
.91984 .53556 L
.91984 .16187 L
F
.2 .63 .79 r
.91948 .16187 m
.91948 .53556 L
.91984 .53556 L
.91984 .16187 L
s
.678 .847 .902 r
.91984 .16187 m
.91984 .53576 L
.92022 .53576 L
.92022 .16187 L
F
.2 .63 .79 r
.91984 .16187 m
.91984 .53576 L
.92022 .53576 L
.92022 .16187 L
s
.678 .847 .902 r
.92022 .16187 m
.92022 .53624 L
.92048 .53624 L
.92048 .16187 L
F
.2 .63 .79 r
.92022 .16187 m
.92022 .53624 L
.92048 .53624 L
.92048 .16187 L
s
.678 .847 .902 r
.92048 .16187 m
.92048 .53677 L
.92095 .53677 L
.92095 .16187 L
F
.2 .63 .79 r
.92048 .16187 m
.92048 .53677 L
.92095 .53677 L
.92095 .16187 L
s
.678 .847 .902 r
.92095 .16187 m
.92095 .53723 L
.92118 .53723 L
.92118 .16187 L
F
.2 .63 .79 r
.92095 .16187 m
.92095 .53723 L
.92118 .53723 L
.92118 .16187 L
s
.678 .847 .902 r
.92118 .16187 m
.92118 .53751 L
.92151 .53751 L
.92151 .16187 L
F
.2 .63 .79 r
.92118 .16187 m
.92118 .53751 L
.92151 .53751 L
.92151 .16187 L
s
.678 .847 .902 r
.92151 .16187 m
.92151 .53798 L
.92181 .53798 L
.92181 .16187 L
F
.2 .63 .79 r
.92151 .16187 m
.92151 .53798 L
.92181 .53798 L
.92181 .16187 L
s
.678 .847 .902 r
.92181 .16187 m
.92181 .53817 L
.92203 .53817 L
.92203 .16187 L
F
.2 .63 .79 r
.92181 .16187 m
.92181 .53817 L
.92203 .53817 L
.92203 .16187 L
s
.678 .847 .902 r
.92203 .16187 m
.92203 .53848 L
.92226 .53848 L
.92226 .16187 L
F
.2 .63 .79 r
.92203 .16187 m
.92203 .53848 L
.92226 .53848 L
.92226 .16187 L
s
.678 .847 .902 r
.92226 .16187 m
.92226 .5386 L
.92253 .5386 L
.92253 .16187 L
F
.2 .63 .79 r
.92226 .16187 m
.92226 .5386 L
.92253 .5386 L
.92253 .16187 L
s
.678 .847 .902 r
.92253 .16187 m
.92253 .53887 L
.92272 .53887 L
.92272 .16187 L
F
.2 .63 .79 r
.92253 .16187 m
.92253 .53887 L
.92272 .53887 L
.92272 .16187 L
s
.678 .847 .902 r
.92272 .16187 m
.92272 .53916 L
.92296 .53916 L
.92296 .16187 L
F
.2 .63 .79 r
.92272 .16187 m
.92272 .53916 L
.92296 .53916 L
.92296 .16187 L
s
.678 .847 .902 r
.92296 .16187 m
.92296 .53961 L
.92318 .53961 L
.92318 .16187 L
F
.2 .63 .79 r
.92296 .16187 m
.92296 .53961 L
.92318 .53961 L
.92318 .16187 L
s
.678 .847 .902 r
.92318 .16187 m
.92318 .53964 L
.92347 .53964 L
.92347 .16187 L
F
.2 .63 .79 r
.92318 .16187 m
.92318 .53964 L
.92347 .53964 L
.92347 .16187 L
s
.678 .847 .902 r
.92347 .16187 m
.92347 .54007 L
.92375 .54007 L
.92375 .16187 L
F
.2 .63 .79 r
.92347 .16187 m
.92347 .54007 L
.92375 .54007 L
.92375 .16187 L
s
.678 .847 .902 r
.92375 .16187 m
.92375 .54064 L
.92422 .54064 L
.92422 .16187 L
F
.2 .63 .79 r
.92375 .16187 m
.92375 .54064 L
.92422 .54064 L
.92422 .16187 L
s
.678 .847 .902 r
.92422 .16187 m
.92422 .54108 L
.92455 .54108 L
.92455 .16187 L
F
.2 .63 .79 r
.92422 .16187 m
.92422 .54108 L
.92455 .54108 L
.92455 .16187 L
s
.678 .847 .902 r
.92455 .16187 m
.92455 .54156 L
.92492 .54156 L
.92492 .16187 L
F
.2 .63 .79 r
.92455 .16187 m
.92455 .54156 L
.92492 .54156 L
.92492 .16187 L
s
.678 .847 .902 r
.92492 .16187 m
.92492 .54206 L
.92541 .54206 L
.92541 .16187 L
F
.2 .63 .79 r
.92492 .16187 m
.92492 .54206 L
.92541 .54206 L
.92541 .16187 L
s
.678 .847 .902 r
.92541 .16187 m
.92541 .54241 L
.92567 .54241 L
.92567 .16187 L
F
.2 .63 .79 r
.92541 .16187 m
.92541 .54241 L
.92567 .54241 L
.92567 .16187 L
s
.678 .847 .902 r
.92567 .16187 m
.92567 .54287 L
.92605 .54287 L
.92605 .16187 L
F
.2 .63 .79 r
.92567 .16187 m
.92567 .54287 L
.92605 .54287 L
.92605 .16187 L
s
.678 .847 .902 r
.92605 .16187 m
.92605 .5433 L
.92647 .5433 L
.92647 .16187 L
F
.2 .63 .79 r
.92605 .16187 m
.92605 .5433 L
.92647 .5433 L
.92647 .16187 L
s
.678 .847 .902 r
.92647 .16187 m
.92647 .5436 L
.92691 .5436 L
.92691 .16187 L
F
.2 .63 .79 r
.92647 .16187 m
.92647 .5436 L
.92691 .5436 L
.92691 .16187 L
s
.678 .847 .902 r
.92691 .16187 m
.92691 .54421 L
.9271 .54421 L
.9271 .16187 L
F
.2 .63 .79 r
.92691 .16187 m
.92691 .54421 L
.9271 .54421 L
.9271 .16187 L
s
.678 .847 .902 r
.9271 .16187 m
.9271 .54424 L
.92726 .54424 L
.92726 .16187 L
F
.2 .63 .79 r
.9271 .16187 m
.9271 .54424 L
.92726 .54424 L
.92726 .16187 L
s
.678 .847 .902 r
.92726 .16187 m
.92726 .54453 L
.92746 .54453 L
.92746 .16187 L
F
.2 .63 .79 r
.92726 .16187 m
.92726 .54453 L
.92746 .54453 L
.92746 .16187 L
s
.678 .847 .902 r
.92746 .16187 m
.92746 .54463 L
.92778 .54463 L
.92778 .16187 L
F
.2 .63 .79 r
.92746 .16187 m
.92746 .54463 L
.92778 .54463 L
.92778 .16187 L
s
.678 .847 .902 r
.92778 .16187 m
.92778 .54512 L
.928 .54512 L
.928 .16187 L
F
.2 .63 .79 r
.92778 .16187 m
.92778 .54512 L
.928 .54512 L
.928 .16187 L
s
.678 .847 .902 r
.928 .16187 m
.928 .54546 L
.92842 .54546 L
.92842 .16187 L
F
.2 .63 .79 r
.928 .16187 m
.928 .54546 L
.92842 .54546 L
.92842 .16187 L
s
.678 .847 .902 r
.92842 .16187 m
.92842 .54577 L
.92878 .54577 L
.92878 .16187 L
F
.2 .63 .79 r
.92842 .16187 m
.92842 .54577 L
.92878 .54577 L
.92878 .16187 L
s
.678 .847 .902 r
.92878 .16187 m
.92878 .5462 L
.92895 .5462 L
.92895 .16187 L
F
.2 .63 .79 r
.92878 .16187 m
.92878 .5462 L
.92895 .5462 L
.92895 .16187 L
s
.678 .847 .902 r
.92895 .16187 m
.92895 .54689 L
.92944 .54689 L
.92944 .16187 L
F
.2 .63 .79 r
.92895 .16187 m
.92895 .54689 L
.92944 .54689 L
.92944 .16187 L
s
.678 .847 .902 r
.92944 .16187 m
.92944 .54721 L
.92978 .54721 L
.92978 .16187 L
F
.2 .63 .79 r
.92944 .16187 m
.92944 .54721 L
.92978 .54721 L
.92978 .16187 L
s
.678 .847 .902 r
.92978 .16187 m
.92978 .54759 L
.93001 .54759 L
.93001 .16187 L
F
.2 .63 .79 r
.92978 .16187 m
.92978 .54759 L
.93001 .54759 L
.93001 .16187 L
s
.678 .847 .902 r
.93001 .16187 m
.93001 .54768 L
.93049 .54768 L
.93049 .16187 L
F
.2 .63 .79 r
.93001 .16187 m
.93001 .54768 L
.93049 .54768 L
.93049 .16187 L
s
.678 .847 .902 r
.93049 .16187 m
.93049 .54847 L
.93089 .54847 L
.93089 .16187 L
F
.2 .63 .79 r
.93049 .16187 m
.93049 .54847 L
.93089 .54847 L
.93089 .16187 L
s
.678 .847 .902 r
.93089 .16187 m
.93089 .54887 L
.93115 .54887 L
.93115 .16187 L
F
.2 .63 .79 r
.93089 .16187 m
.93089 .54887 L
.93115 .54887 L
.93115 .16187 L
s
.678 .847 .902 r
.93115 .16187 m
.93115 .54939 L
.93159 .54939 L
.93159 .16187 L
F
.2 .63 .79 r
.93115 .16187 m
.93115 .54939 L
.93159 .54939 L
.93159 .16187 L
s
.678 .847 .902 r
.93159 .16187 m
.93159 .54979 L
.93194 .54979 L
.93194 .16187 L
F
.2 .63 .79 r
.93159 .16187 m
.93159 .54979 L
.93194 .54979 L
.93194 .16187 L
s
.678 .847 .902 r
.93194 .16187 m
.93194 .55035 L
.93236 .55035 L
.93236 .16187 L
F
.2 .63 .79 r
.93194 .16187 m
.93194 .55035 L
.93236 .55035 L
.93236 .16187 L
s
.678 .847 .902 r
.93236 .16187 m
.93236 .5504 L
.93278 .5504 L
.93278 .16187 L
F
.2 .63 .79 r
.93236 .16187 m
.93236 .5504 L
.93278 .5504 L
.93278 .16187 L
s
.678 .847 .902 r
.93278 .16187 m
.93278 .55089 L
.933 .55089 L
.933 .16187 L
F
.2 .63 .79 r
.93278 .16187 m
.93278 .55089 L
.933 .55089 L
.933 .16187 L
s
.678 .847 .902 r
.933 .16187 m
.933 .55115 L
.93335 .55115 L
.93335 .16187 L
F
.2 .63 .79 r
.933 .16187 m
.933 .55115 L
.93335 .55115 L
.93335 .16187 L
s
.678 .847 .902 r
.93335 .16187 m
.93335 .55167 L
.93365 .55167 L
.93365 .16187 L
F
.2 .63 .79 r
.93335 .16187 m
.93335 .55167 L
.93365 .55167 L
.93365 .16187 L
s
.678 .847 .902 r
.93365 .16187 m
.93365 .55197 L
.93385 .55197 L
.93385 .16187 L
F
.2 .63 .79 r
.93365 .16187 m
.93365 .55197 L
.93385 .55197 L
.93385 .16187 L
s
.678 .847 .902 r
.93385 .16187 m
.93385 .55227 L
.93413 .55227 L
.93413 .16187 L
F
.2 .63 .79 r
.93385 .16187 m
.93385 .55227 L
.93413 .55227 L
.93413 .16187 L
s
.678 .847 .902 r
.93413 .16187 m
.93413 .55285 L
.93454 .55285 L
.93454 .16187 L
F
.2 .63 .79 r
.93413 .16187 m
.93413 .55285 L
.93454 .55285 L
.93454 .16187 L
s
.678 .847 .902 r
.93454 .16187 m
.93454 .55306 L
.93479 .55306 L
.93479 .16187 L
F
.2 .63 .79 r
.93454 .16187 m
.93454 .55306 L
.93479 .55306 L
.93479 .16187 L
s
.678 .847 .902 r
.93479 .16187 m
.93479 .55328 L
.93497 .55328 L
.93497 .16187 L
F
.2 .63 .79 r
.93479 .16187 m
.93479 .55328 L
.93497 .55328 L
.93497 .16187 L
s
.678 .847 .902 r
.93497 .16187 m
.93497 .55369 L
.93521 .55369 L
.93521 .16187 L
F
.2 .63 .79 r
.93497 .16187 m
.93497 .55369 L
.93521 .55369 L
.93521 .16187 L
s
.678 .847 .902 r
.93521 .16187 m
.93521 .55397 L
.93544 .55397 L
.93544 .16187 L
F
.2 .63 .79 r
.93521 .16187 m
.93521 .55397 L
.93544 .55397 L
.93544 .16187 L
s
.678 .847 .902 r
.93544 .16187 m
.93544 .55422 L
.93562 .55422 L
.93562 .16187 L
F
.2 .63 .79 r
.93544 .16187 m
.93544 .55422 L
.93562 .55422 L
.93562 .16187 L
s
.678 .847 .902 r
.93562 .16187 m
.93562 .55446 L
.93588 .55446 L
.93588 .16187 L
F
.2 .63 .79 r
.93562 .16187 m
.93562 .55446 L
.93588 .55446 L
.93588 .16187 L
s
.678 .847 .902 r
.93588 .16187 m
.93588 .55487 L
.93625 .55487 L
.93625 .16187 L
F
.2 .63 .79 r
.93588 .16187 m
.93588 .55487 L
.93625 .55487 L
.93625 .16187 L
s
.678 .847 .902 r
.93625 .16187 m
.93625 .55514 L
.93646 .55514 L
.93646 .16187 L
F
.2 .63 .79 r
.93625 .16187 m
.93625 .55514 L
.93646 .55514 L
.93646 .16187 L
s
.678 .847 .902 r
.93646 .16187 m
.93646 .55523 L
.93664 .55523 L
.93664 .16187 L
F
.2 .63 .79 r
.93646 .16187 m
.93646 .55523 L
.93664 .55523 L
.93664 .16187 L
s
.678 .847 .902 r
.93664 .16187 m
.93664 .55547 L
.93705 .55547 L
.93705 .16187 L
F
.2 .63 .79 r
.93664 .16187 m
.93664 .55547 L
.93705 .55547 L
.93705 .16187 L
s
.678 .847 .902 r
.93705 .16187 m
.93705 .55623 L
.93734 .55623 L
.93734 .16187 L
F
.2 .63 .79 r
.93705 .16187 m
.93705 .55623 L
.93734 .55623 L
.93734 .16187 L
s
.678 .847 .902 r
.93734 .16187 m
.93734 .55641 L
.93756 .55641 L
.93756 .16187 L
F
.2 .63 .79 r
.93734 .16187 m
.93734 .55641 L
.93756 .55641 L
.93756 .16187 L
s
.678 .847 .902 r
.93756 .16187 m
.93756 .55667 L
.93783 .55667 L
.93783 .16187 L
F
.2 .63 .79 r
.93756 .16187 m
.93756 .55667 L
.93783 .55667 L
.93783 .16187 L
s
.678 .847 .902 r
.93783 .16187 m
.93783 .55699 L
.93814 .55699 L
.93814 .16187 L
F
.2 .63 .79 r
.93783 .16187 m
.93783 .55699 L
.93814 .55699 L
.93814 .16187 L
s
.678 .847 .902 r
.93814 .16187 m
.93814 .55725 L
.93847 .55725 L
.93847 .16187 L
F
.2 .63 .79 r
.93814 .16187 m
.93814 .55725 L
.93847 .55725 L
.93847 .16187 L
s
.678 .847 .902 r
.93847 .16187 m
.93847 .55796 L
.93883 .55796 L
.93883 .16187 L
F
.2 .63 .79 r
.93847 .16187 m
.93847 .55796 L
.93883 .55796 L
.93883 .16187 L
s
.678 .847 .902 r
.93883 .16187 m
.93883 .55825 L
.93919 .55825 L
.93919 .16187 L
F
.2 .63 .79 r
.93883 .16187 m
.93883 .55825 L
.93919 .55825 L
.93919 .16187 L
s
.678 .847 .902 r
.93919 .16187 m
.93919 .55861 L
.93956 .55861 L
.93956 .16187 L
F
.2 .63 .79 r
.93919 .16187 m
.93919 .55861 L
.93956 .55861 L
.93956 .16187 L
s
.678 .847 .902 r
.93956 .16187 m
.93956 .55892 L
.93982 .55892 L
.93982 .16187 L
F
.2 .63 .79 r
.93956 .16187 m
.93956 .55892 L
.93982 .55892 L
.93982 .16187 L
s
.678 .847 .902 r
.93982 .16187 m
.93982 .55937 L
.93998 .55937 L
.93998 .16187 L
F
.2 .63 .79 r
.93982 .16187 m
.93982 .55937 L
.93998 .55937 L
.93998 .16187 L
s
.678 .847 .902 r
.93998 .16187 m
.93998 .55945 L
.94018 .55945 L
.94018 .16187 L
F
.2 .63 .79 r
.93998 .16187 m
.93998 .55945 L
.94018 .55945 L
.94018 .16187 L
s
.678 .847 .902 r
.94018 .16187 m
.94018 .55967 L
.94051 .55967 L
.94051 .16187 L
F
.2 .63 .79 r
.94018 .16187 m
.94018 .55967 L
.94051 .55967 L
.94051 .16187 L
s
.678 .847 .902 r
.94051 .16187 m
.94051 .56041 L
.94098 .56041 L
.94098 .16187 L
F
.2 .63 .79 r
.94051 .16187 m
.94051 .56041 L
.94098 .56041 L
.94098 .16187 L
s
.678 .847 .902 r
.94098 .16187 m
.94098 .56088 L
.94122 .56088 L
.94122 .16187 L
F
.2 .63 .79 r
.94098 .16187 m
.94098 .56088 L
.94122 .56088 L
.94122 .16187 L
s
.678 .847 .902 r
.94122 .16187 m
.94122 .56131 L
.94166 .56131 L
.94166 .16187 L
F
.2 .63 .79 r
.94122 .16187 m
.94122 .56131 L
.94166 .56131 L
.94166 .16187 L
s
.678 .847 .902 r
.94166 .16187 m
.94166 .56173 L
.94195 .56173 L
.94195 .16187 L
F
.2 .63 .79 r
.94166 .16187 m
.94166 .56173 L
.94195 .56173 L
.94195 .16187 L
s
.678 .847 .902 r
.94195 .16187 m
.94195 .56216 L
.94233 .56216 L
.94233 .16187 L
F
.2 .63 .79 r
.94195 .16187 m
.94195 .56216 L
.94233 .56216 L
.94233 .16187 L
s
.678 .847 .902 r
.94233 .16187 m
.94233 .56225 L
.94249 .56225 L
.94249 .16187 L
F
.2 .63 .79 r
.94233 .16187 m
.94233 .56225 L
.94249 .56225 L
.94249 .16187 L
s
.678 .847 .902 r
.94249 .16187 m
.94249 .56284 L
.9429 .56284 L
.9429 .16187 L
F
.2 .63 .79 r
.94249 .16187 m
.94249 .56284 L
.9429 .56284 L
.9429 .16187 L
s
.678 .847 .902 r
.9429 .16187 m
.9429 .56294 L
.94307 .56294 L
.94307 .16187 L
F
.2 .63 .79 r
.9429 .16187 m
.9429 .56294 L
.94307 .56294 L
.94307 .16187 L
s
.678 .847 .902 r
.94307 .16187 m
.94307 .56312 L
.94324 .56312 L
.94324 .16187 L
F
.2 .63 .79 r
.94307 .16187 m
.94307 .56312 L
.94324 .56312 L
.94324 .16187 L
s
.678 .847 .902 r
.94324 .16187 m
.94324 .56357 L
.94368 .56357 L
.94368 .16187 L
F
.2 .63 .79 r
.94324 .16187 m
.94324 .56357 L
.94368 .56357 L
.94368 .16187 L
s
.678 .847 .902 r
.94368 .16187 m
.94368 .56422 L
.94406 .56422 L
.94406 .16187 L
F
.2 .63 .79 r
.94368 .16187 m
.94368 .56422 L
.94406 .56422 L
.94406 .16187 L
s
.678 .847 .902 r
.94406 .16187 m
.94406 .56432 L
.94431 .56432 L
.94431 .16187 L
F
.2 .63 .79 r
.94406 .16187 m
.94406 .56432 L
.94431 .56432 L
.94431 .16187 L
s
.678 .847 .902 r
.94431 .16187 m
.94431 .56468 L
.94468 .56468 L
.94468 .16187 L
F
.2 .63 .79 r
.94431 .16187 m
.94431 .56468 L
.94468 .56468 L
.94468 .16187 L
s
.678 .847 .902 r
.94468 .16187 m
.94468 .56545 L
.94505 .56545 L
.94505 .16187 L
F
.2 .63 .79 r
.94468 .16187 m
.94468 .56545 L
.94505 .56545 L
.94505 .16187 L
s
.678 .847 .902 r
.94505 .16187 m
.94505 .56559 L
.9453 .56559 L
.9453 .16187 L
F
.2 .63 .79 r
.94505 .16187 m
.94505 .56559 L
.9453 .56559 L
.9453 .16187 L
s
.678 .847 .902 r
.9453 .16187 m
.9453 .56619 L
.94574 .56619 L
.94574 .16187 L
F
.2 .63 .79 r
.9453 .16187 m
.9453 .56619 L
.94574 .56619 L
.94574 .16187 L
s
.678 .847 .902 r
.94574 .16187 m
.94574 .56632 L
.94592 .56632 L
.94592 .16187 L
F
.2 .63 .79 r
.94574 .16187 m
.94574 .56632 L
.94592 .56632 L
.94592 .16187 L
s
.678 .847 .902 r
.94592 .16187 m
.94592 .56654 L
.94607 .56654 L
.94607 .16187 L
F
.2 .63 .79 r
.94592 .16187 m
.94592 .56654 L
.94607 .56654 L
.94607 .16187 L
s
.678 .847 .902 r
.94607 .16187 m
.94607 .56714 L
.94646 .56714 L
.94646 .16187 L
F
.2 .63 .79 r
.94607 .16187 m
.94607 .56714 L
.94646 .56714 L
.94646 .16187 L
s
.678 .847 .902 r
.94646 .16187 m
.94646 .56728 L
.94668 .56728 L
.94668 .16187 L
F
.2 .63 .79 r
.94646 .16187 m
.94646 .56728 L
.94668 .56728 L
.94668 .16187 L
s
.678 .847 .902 r
.94668 .16187 m
.94668 .56748 L
.94709 .56748 L
.94709 .16187 L
F
.2 .63 .79 r
.94668 .16187 m
.94668 .56748 L
.94709 .56748 L
.94709 .16187 L
s
.678 .847 .902 r
.94709 .16187 m
.94709 .56816 L
.94758 .56816 L
.94758 .16187 L
F
.2 .63 .79 r
.94709 .16187 m
.94709 .56816 L
.94758 .56816 L
.94758 .16187 L
s
.678 .847 .902 r
.94758 .16187 m
.94758 .56882 L
.94791 .56882 L
.94791 .16187 L
F
.2 .63 .79 r
.94758 .16187 m
.94758 .56882 L
.94791 .56882 L
.94791 .16187 L
s
.678 .847 .902 r
.94791 .16187 m
.94791 .56911 L
.9483 .56911 L
.9483 .16187 L
F
.2 .63 .79 r
.94791 .16187 m
.94791 .56911 L
.9483 .56911 L
.9483 .16187 L
s
.678 .847 .902 r
.9483 .16187 m
.9483 .5696 L
.94873 .5696 L
.94873 .16187 L
F
.2 .63 .79 r
.9483 .16187 m
.9483 .5696 L
.94873 .5696 L
.94873 .16187 L
s
.678 .847 .902 r
.94873 .16187 m
.94873 .57009 L
.94912 .57009 L
.94912 .16187 L
F
.2 .63 .79 r
.94873 .16187 m
.94873 .57009 L
.94912 .57009 L
.94912 .16187 L
s
.678 .847 .902 r
.94912 .16187 m
.94912 .57036 L
.94951 .57036 L
.94951 .16187 L
F
.2 .63 .79 r
.94912 .16187 m
.94912 .57036 L
.94951 .57036 L
.94951 .16187 L
s
.678 .847 .902 r
.94951 .16187 m
.94951 .57096 L
.94975 .57096 L
.94975 .16187 L
F
.2 .63 .79 r
.94951 .16187 m
.94951 .57096 L
.94975 .57096 L
.94975 .16187 L
s
.678 .847 .902 r
.94975 .16187 m
.94975 .57124 L
.94996 .57124 L
.94996 .16187 L
F
.2 .63 .79 r
.94975 .16187 m
.94975 .57124 L
.94996 .57124 L
.94996 .16187 L
s
.678 .847 .902 r
.94996 .16187 m
.94996 .57147 L
.95033 .57147 L
.95033 .16187 L
F
.2 .63 .79 r
.94996 .16187 m
.94996 .57147 L
.95033 .57147 L
.95033 .16187 L
s
.678 .847 .902 r
.95033 .16187 m
.95033 .57188 L
.9508 .57188 L
.9508 .16187 L
F
.2 .63 .79 r
.95033 .16187 m
.95033 .57188 L
.9508 .57188 L
.9508 .16187 L
s
.678 .847 .902 r
.9508 .16187 m
.9508 .57244 L
.95102 .57244 L
.95102 .16187 L
F
.2 .63 .79 r
.9508 .16187 m
.9508 .57244 L
.95102 .57244 L
.95102 .16187 L
s
.678 .847 .902 r
.95102 .16187 m
.95102 .57272 L
.95121 .57272 L
.95121 .16187 L
F
.2 .63 .79 r
.95102 .16187 m
.95102 .57272 L
.95121 .57272 L
.95121 .16187 L
s
.678 .847 .902 r
.95121 .16187 m
.95121 .57323 L
.95163 .57323 L
.95163 .16187 L
F
.2 .63 .79 r
.95121 .16187 m
.95121 .57323 L
.95163 .57323 L
.95163 .16187 L
s
.678 .847 .902 r
.95163 .16187 m
.95163 .57344 L
.95187 .57344 L
.95187 .16187 L
F
.2 .63 .79 r
.95163 .16187 m
.95163 .57344 L
.95187 .57344 L
.95187 .16187 L
s
.678 .847 .902 r
.95187 .16187 m
.95187 .57371 L
.95233 .57371 L
.95233 .16187 L
F
.2 .63 .79 r
.95187 .16187 m
.95187 .57371 L
.95233 .57371 L
.95233 .16187 L
s
.678 .847 .902 r
.95233 .16187 m
.95233 .57428 L
.95264 .57428 L
.95264 .16187 L
F
.2 .63 .79 r
.95233 .16187 m
.95233 .57428 L
.95264 .57428 L
.95264 .16187 L
s
.678 .847 .902 r
.95264 .16187 m
.95264 .57476 L
.95285 .57476 L
.95285 .16187 L
F
.2 .63 .79 r
.95264 .16187 m
.95264 .57476 L
.95285 .57476 L
.95285 .16187 L
s
.678 .847 .902 r
.95285 .16187 m
.95285 .57528 L
.95333 .57528 L
.95333 .16187 L
F
.2 .63 .79 r
.95285 .16187 m
.95285 .57528 L
.95333 .57528 L
.95333 .16187 L
s
.678 .847 .902 r
.95333 .16187 m
.95333 .57546 L
.9535 .57546 L
.9535 .16187 L
F
.2 .63 .79 r
.95333 .16187 m
.95333 .57546 L
.9535 .57546 L
.9535 .16187 L
s
.678 .847 .902 r
.9535 .16187 m
.9535 .57561 L
.95377 .57561 L
.95377 .16187 L
F
.2 .63 .79 r
.9535 .16187 m
.9535 .57561 L
.95377 .57561 L
.95377 .16187 L
s
.678 .847 .902 r
.95377 .16187 m
.95377 .57606 L
.95397 .57606 L
.95397 .16187 L
F
.2 .63 .79 r
.95377 .16187 m
.95377 .57606 L
.95397 .57606 L
.95397 .16187 L
s
.678 .847 .902 r
.95397 .16187 m
.95397 .57641 L
.95421 .57641 L
.95421 .16187 L
F
.2 .63 .79 r
.95397 .16187 m
.95397 .57641 L
.95421 .57641 L
.95421 .16187 L
s
.678 .847 .902 r
.95421 .16187 m
.95421 .57687 L
.95465 .57687 L
.95465 .16187 L
F
.2 .63 .79 r
.95421 .16187 m
.95421 .57687 L
.95465 .57687 L
.95465 .16187 L
s
.678 .847 .902 r
.95465 .16187 m
.95465 .57737 L
.955 .57737 L
.955 .16187 L
F
.2 .63 .79 r
.95465 .16187 m
.95465 .57737 L
.955 .57737 L
.955 .16187 L
s
.678 .847 .902 r
.955 .16187 m
.955 .57745 L
.95521 .57745 L
.95521 .16187 L
F
.2 .63 .79 r
.955 .16187 m
.955 .57745 L
.95521 .57745 L
.95521 .16187 L
s
.678 .847 .902 r
.95521 .16187 m
.95521 .57813 L
.9556 .57813 L
.9556 .16187 L
F
.2 .63 .79 r
.95521 .16187 m
.95521 .57813 L
.9556 .57813 L
.9556 .16187 L
s
.678 .847 .902 r
.9556 .16187 m
.9556 .57822 L
.95582 .57822 L
.95582 .16187 L
F
.2 .63 .79 r
.9556 .16187 m
.9556 .57822 L
.95582 .57822 L
.95582 .16187 L
s
.678 .847 .902 r
.95582 .16187 m
.95582 .57859 L
.95622 .57859 L
.95622 .16187 L
F
.2 .63 .79 r
.95582 .16187 m
.95582 .57859 L
.95622 .57859 L
.95622 .16187 L
s
.678 .847 .902 r
.95622 .16187 m
.95622 .57913 L
.95653 .57913 L
.95653 .16187 L
F
.2 .63 .79 r
.95622 .16187 m
.95622 .57913 L
.95653 .57913 L
.95653 .16187 L
s
.678 .847 .902 r
.95653 .16187 m
.95653 .57944 L
.95669 .57944 L
.95669 .16187 L
F
.2 .63 .79 r
.95653 .16187 m
.95653 .57944 L
.95669 .57944 L
.95669 .16187 L
s
.678 .847 .902 r
.95669 .16187 m
.95669 .57986 L
.95715 .57986 L
.95715 .16187 L
F
.2 .63 .79 r
.95669 .16187 m
.95669 .57986 L
.95715 .57986 L
.95715 .16187 L
s
.678 .847 .902 r
.95715 .16187 m
.95715 .58034 L
.95749 .58034 L
.95749 .16187 L
F
.2 .63 .79 r
.95715 .16187 m
.95715 .58034 L
.95749 .58034 L
.95749 .16187 L
s
.678 .847 .902 r
.95749 .16187 m
.95749 .58061 L
.95792 .58061 L
.95792 .16187 L
F
.2 .63 .79 r
.95749 .16187 m
.95749 .58061 L
.95792 .58061 L
.95792 .16187 L
s
.678 .847 .902 r
.95792 .16187 m
.95792 .58112 L
.9581 .58112 L
.9581 .16187 L
F
.2 .63 .79 r
.95792 .16187 m
.95792 .58112 L
.9581 .58112 L
.9581 .16187 L
s
.678 .847 .902 r
.9581 .16187 m
.9581 .58137 L
.95849 .58137 L
.95849 .16187 L
F
.2 .63 .79 r
.9581 .16187 m
.9581 .58137 L
.95849 .58137 L
.95849 .16187 L
s
.678 .847 .902 r
.95849 .16187 m
.95849 .58176 L
.95879 .58176 L
.95879 .16187 L
F
.2 .63 .79 r
.95849 .16187 m
.95849 .58176 L
.95879 .58176 L
.95879 .16187 L
s
.678 .847 .902 r
.95879 .16187 m
.95879 .58212 L
.95894 .58212 L
.95894 .16187 L
F
.2 .63 .79 r
.95879 .16187 m
.95879 .58212 L
.95894 .58212 L
.95894 .16187 L
s
.678 .847 .902 r
.95894 .16187 m
.95894 .58245 L
.95938 .58245 L
.95938 .16187 L
F
.2 .63 .79 r
.95894 .16187 m
.95894 .58245 L
.95938 .58245 L
.95938 .16187 L
s
.678 .847 .902 r
.95938 .16187 m
.95938 .58287 L
.9598 .58287 L
.9598 .16187 L
F
.2 .63 .79 r
.95938 .16187 m
.95938 .58287 L
.9598 .58287 L
.9598 .16187 L
s
.678 .847 .902 r
.9598 .16187 m
.9598 .58329 L
.96029 .58329 L
.96029 .16187 L
F
.2 .63 .79 r
.9598 .16187 m
.9598 .58329 L
.96029 .58329 L
.96029 .16187 L
s
.678 .847 .902 r
.96029 .16187 m
.96029 .58427 L
.96072 .58427 L
.96072 .16187 L
F
.2 .63 .79 r
.96029 .16187 m
.96029 .58427 L
.96072 .58427 L
.96072 .16187 L
s
.678 .847 .902 r
.96072 .16187 m
.96072 .58473 L
.96117 .58473 L
.96117 .16187 L
F
.2 .63 .79 r
.96072 .16187 m
.96072 .58473 L
.96117 .58473 L
.96117 .16187 L
s
.678 .847 .902 r
.96117 .16187 m
.96117 .5849 L
.96157 .5849 L
.96157 .16187 L
F
.2 .63 .79 r
.96117 .16187 m
.96117 .5849 L
.96157 .5849 L
.96157 .16187 L
s
.678 .847 .902 r
.96157 .16187 m
.96157 .58542 L
.96193 .58542 L
.96193 .16187 L
F
.2 .63 .79 r
.96157 .16187 m
.96157 .58542 L
.96193 .58542 L
.96193 .16187 L
s
.678 .847 .902 r
.96193 .16187 m
.96193 .58596 L
.96232 .58596 L
.96232 .16187 L
F
.2 .63 .79 r
.96193 .16187 m
.96193 .58596 L
.96232 .58596 L
.96232 .16187 L
s
.678 .847 .902 r
.96232 .16187 m
.96232 .58668 L
.96268 .58668 L
.96268 .16187 L
F
.2 .63 .79 r
.96232 .16187 m
.96232 .58668 L
.96268 .58668 L
.96268 .16187 L
s
.678 .847 .902 r
.96268 .16187 m
.96268 .58687 L
.96312 .58687 L
.96312 .16187 L
F
.2 .63 .79 r
.96268 .16187 m
.96268 .58687 L
.96312 .58687 L
.96312 .16187 L
s
.678 .847 .902 r
.96312 .16187 m
.96312 .58731 L
.96328 .58731 L
.96328 .16187 L
F
.2 .63 .79 r
.96312 .16187 m
.96312 .58731 L
.96328 .58731 L
.96328 .16187 L
s
.678 .847 .902 r
.96328 .16187 m
.96328 .58754 L
.96361 .58754 L
.96361 .16187 L
F
.2 .63 .79 r
.96328 .16187 m
.96328 .58754 L
.96361 .58754 L
.96361 .16187 L
s
.678 .847 .902 r
.96361 .16187 m
.96361 .58837 L
.96406 .58837 L
.96406 .16187 L
F
.2 .63 .79 r
.96361 .16187 m
.96361 .58837 L
.96406 .58837 L
.96406 .16187 L
s
.678 .847 .902 r
.96406 .16187 m
.96406 .58887 L
.96444 .58887 L
.96444 .16187 L
F
.2 .63 .79 r
.96406 .16187 m
.96406 .58887 L
.96444 .58887 L
.96444 .16187 L
s
.678 .847 .902 r
.96444 .16187 m
.96444 .58914 L
.96469 .58914 L
.96469 .16187 L
F
.2 .63 .79 r
.96444 .16187 m
.96444 .58914 L
.96469 .58914 L
.96469 .16187 L
s
.678 .847 .902 r
.96469 .16187 m
.96469 .5893 L
.96486 .5893 L
.96486 .16187 L
F
.2 .63 .79 r
.96469 .16187 m
.96469 .5893 L
.96486 .5893 L
.96486 .16187 L
s
.678 .847 .902 r
.96486 .16187 m
.96486 .58992 L
.9653 .58992 L
.9653 .16187 L
F
.2 .63 .79 r
.96486 .16187 m
.96486 .58992 L
.9653 .58992 L
.9653 .16187 L
s
.678 .847 .902 r
.9653 .16187 m
.9653 .59006 L
.96571 .59006 L
.96571 .16187 L
F
.2 .63 .79 r
.9653 .16187 m
.9653 .59006 L
.96571 .59006 L
.96571 .16187 L
s
.678 .847 .902 r
.96571 .16187 m
.96571 .59046 L
.96611 .59046 L
.96611 .16187 L
F
.2 .63 .79 r
.96571 .16187 m
.96571 .59046 L
.96611 .59046 L
.96611 .16187 L
s
.678 .847 .902 r
.96611 .16187 m
.96611 .59098 L
.96634 .59098 L
.96634 .16187 L
F
.2 .63 .79 r
.96611 .16187 m
.96611 .59098 L
.96634 .59098 L
.96634 .16187 L
s
.678 .847 .902 r
.96634 .16187 m
.96634 .59132 L
.96674 .59132 L
.96674 .16187 L
F
.2 .63 .79 r
.96634 .16187 m
.96634 .59132 L
.96674 .59132 L
.96674 .16187 L
s
.678 .847 .902 r
.96674 .16187 m
.96674 .59188 L
.96692 .59188 L
.96692 .16187 L
F
.2 .63 .79 r
.96674 .16187 m
.96674 .59188 L
.96692 .59188 L
.96692 .16187 L
s
.678 .847 .902 r
.96692 .16187 m
.96692 .59213 L
.96716 .59213 L
.96716 .16187 L
F
.2 .63 .79 r
.96692 .16187 m
.96692 .59213 L
.96716 .59213 L
.96716 .16187 L
s
.678 .847 .902 r
.96716 .16187 m
.96716 .59238 L
.96739 .59238 L
.96739 .16187 L
F
.2 .63 .79 r
.96716 .16187 m
.96716 .59238 L
.96739 .59238 L
.96739 .16187 L
s
.678 .847 .902 r
.96739 .16187 m
.96739 .5929 L
.96785 .5929 L
.96785 .16187 L
F
.2 .63 .79 r
.96739 .16187 m
.96739 .5929 L
.96785 .5929 L
.96785 .16187 L
s
.678 .847 .902 r
.96785 .16187 m
.96785 .59322 L
.96809 .59322 L
.96809 .16187 L
F
.2 .63 .79 r
.96785 .16187 m
.96785 .59322 L
.96809 .59322 L
.96809 .16187 L
s
.678 .847 .902 r
.96809 .16187 m
.96809 .59355 L
.96834 .59355 L
.96834 .16187 L
F
.2 .63 .79 r
.96809 .16187 m
.96809 .59355 L
.96834 .59355 L
.96834 .16187 L
s
.678 .847 .902 r
.96834 .16187 m
.96834 .59393 L
.96863 .59393 L
.96863 .16187 L
F
.2 .63 .79 r
.96834 .16187 m
.96834 .59393 L
.96863 .59393 L
.96863 .16187 L
s
.678 .847 .902 r
.96863 .16187 m
.96863 .59402 L
.96879 .59402 L
.96879 .16187 L
F
.2 .63 .79 r
.96863 .16187 m
.96863 .59402 L
.96879 .59402 L
.96879 .16187 L
s
.678 .847 .902 r
.96879 .16187 m
.96879 .59443 L
.96912 .59443 L
.96912 .16187 L
F
.2 .63 .79 r
.96879 .16187 m
.96879 .59443 L
.96912 .59443 L
.96912 .16187 L
s
.678 .847 .902 r
.96912 .16187 m
.96912 .59489 L
.9695 .59489 L
.9695 .16187 L
F
.2 .63 .79 r
.96912 .16187 m
.96912 .59489 L
.9695 .59489 L
.9695 .16187 L
s
.678 .847 .902 r
.9695 .16187 m
.9695 .59533 L
.96989 .59533 L
.96989 .16187 L
F
.2 .63 .79 r
.9695 .16187 m
.9695 .59533 L
.96989 .59533 L
.96989 .16187 L
s
.678 .847 .902 r
.96989 .16187 m
.96989 .59562 L
.97019 .59562 L
.97019 .16187 L
F
.2 .63 .79 r
.96989 .16187 m
.96989 .59562 L
.97019 .59562 L
.97019 .16187 L
s
.678 .847 .902 r
.97019 .16187 m
.97019 .59607 L
.97057 .59607 L
.97057 .16187 L
F
.2 .63 .79 r
.97019 .16187 m
.97019 .59607 L
.97057 .59607 L
.97057 .16187 L
s
.678 .847 .902 r
.97057 .16187 m
.97057 .59657 L
.97094 .59657 L
.97094 .16187 L
F
.2 .63 .79 r
.97057 .16187 m
.97057 .59657 L
.97094 .59657 L
.97094 .16187 L
s
.678 .847 .902 r
.97094 .16187 m
.97094 .59693 L
.97115 .59693 L
.97115 .16187 L
F
.2 .63 .79 r
.97094 .16187 m
.97094 .59693 L
.97115 .59693 L
.97115 .16187 L
s
.678 .847 .902 r
.97115 .16187 m
.97115 .59721 L
.97148 .59721 L
.97148 .16187 L
F
.2 .63 .79 r
.97115 .16187 m
.97115 .59721 L
.97148 .59721 L
.97148 .16187 L
s
.678 .847 .902 r
.97148 .16187 m
.97148 .59758 L
.97164 .59758 L
.97164 .16187 L
F
.2 .63 .79 r
.97148 .16187 m
.97148 .59758 L
.97164 .59758 L
.97164 .16187 L
s
.678 .847 .902 r
.97164 .16187 m
.97164 .59789 L
.97189 .59789 L
.97189 .16187 L
F
.2 .63 .79 r
.97164 .16187 m
.97164 .59789 L
.97189 .59789 L
.97189 .16187 L
s
.678 .847 .902 r
.97189 .16187 m
.97189 .59822 L
.97209 .59822 L
.97209 .16187 L
F
.2 .63 .79 r
.97189 .16187 m
.97189 .59822 L
.97209 .59822 L
.97209 .16187 L
s
.678 .847 .902 r
.97209 .16187 m
.97209 .5984 L
.97248 .5984 L
.97248 .16187 L
F
.2 .63 .79 r
.97209 .16187 m
.97209 .5984 L
.97248 .5984 L
.97248 .16187 L
s
.678 .847 .902 r
.97248 .16187 m
.97248 .59876 L
.97271 .59876 L
.97271 .16187 L
F
.2 .63 .79 r
.97248 .16187 m
.97248 .59876 L
.97271 .59876 L
.97271 .16187 L
s
.678 .847 .902 r
.97271 .16187 m
.97271 .59926 L
.97306 .59926 L
.97306 .16187 L
F
.2 .63 .79 r
.97271 .16187 m
.97271 .59926 L
.97306 .59926 L
.97306 .16187 L
s
.678 .847 .902 r
.97306 .16187 m
.97306 .5998 L
.97352 .5998 L
.97352 .16187 L
F
.2 .63 .79 r
.97306 .16187 m
.97306 .5998 L
.97352 .5998 L
.97352 .16187 L
s
.678 .847 .902 r
.97352 .16187 m
.97352 .60006 L
.974 .60006 L
.974 .16187 L
F
.2 .63 .79 r
.97352 .16187 m
.97352 .60006 L
.974 .60006 L
.974 .16187 L
s
.678 .847 .902 r
.974 .16187 m
.974 .60067 L
.97421 .60067 L
.97421 .16187 L
F
.2 .63 .79 r
.974 .16187 m
.974 .60067 L
.97421 .60067 L
.97421 .16187 L
s
.678 .847 .902 r
.97421 .16187 m
.97421 .60111 L
.97445 .60111 L
.97445 .16187 L
F
.2 .63 .79 r
.97421 .16187 m
.97421 .60111 L
.97445 .60111 L
.97445 .16187 L
s
.678 .847 .902 r
.97445 .16187 m
.97445 .60164 L
.97483 .60164 L
.97483 .16187 L
F
.2 .63 .79 r
.97445 .16187 m
.97445 .60164 L
.97483 .60164 L
.97483 .16187 L
s
.678 .847 .902 r
.97483 .16187 m
.97483 .60171 L
.975 .60171 L
.975 .16187 L
F
.2 .63 .79 r
.97483 .16187 m
.97483 .60171 L
.975 .60171 L
.975 .16187 L
s
.678 .847 .902 r
.975 .16187 m
.975 .60223 L
.97546 .60223 L
.97546 .16187 L
F
.2 .63 .79 r
.975 .16187 m
.975 .60223 L
.97546 .60223 L
.97546 .16187 L
s
.678 .847 .902 r
.97546 .16187 m
.97546 .6025 L
.97595 .6025 L
.97595 .16187 L
F
.2 .63 .79 r
.97546 .16187 m
.97546 .6025 L
.97595 .6025 L
.97595 .16187 L
s
.678 .847 .902 r
.97595 .16187 m
.97595 .60308 L
.97619 .60308 L
.97619 .16187 L
F
.2 .63 .79 r
.97595 .16187 m
.97595 .60308 L
.97619 .60308 L
.97619 .16187 L
s
0 0 0 r
.02381 .16187 m
.97619 .16187 L
s
4 Mabswid
.02382 .01472 Mdot
.02435 .01472 Mdot
.02477 .01472 Mdot
.02524 .01472 Mdot
.02559 .01472 Mdot
.026 .01472 Mdot
.02629 .01472 Mdot
.02651 .01472 Mdot
.02678 .01472 Mdot
.02732 .01472 Mdot
.02757 .01472 Mdot
.0279 .01473 Mdot
.02827 .01473 Mdot
.02856 .01473 Mdot
.02904 .01473 Mdot
.02925 .01473 Mdot
.02955 .01474 Mdot
.02973 .01474 Mdot
.03025 .01474 Mdot
.03071 .01475 Mdot
.03088 .01475 Mdot
.03114 .01475 Mdot
.03167 .01476 Mdot
.03205 .01476 Mdot
.0324 .01476 Mdot
.03305 .01477 Mdot
.03311 .01477 Mdot
.03345 .01478 Mdot
.03383 .01478 Mdot
.03401 .01478 Mdot
.03423 .01479 Mdot
.03443 .01479 Mdot
.03475 .01479 Mdot
.03508 .0148 Mdot
.03525 .0148 Mdot
.03558 .0148 Mdot
.03604 .01481 Mdot
.03642 .01482 Mdot
.03676 .01482 Mdot
.03714 .01483 Mdot
.03757 .01484 Mdot
.03762 .01484 Mdot
.03834 .01485 Mdot
.03847 .01485 Mdot
.03897 .01486 Mdot
.03948 .01487 Mdot
.03974 .01488 Mdot
.04035 .01489 Mdot
.0405 .0149 Mdot
.0408 .0149 Mdot
.04088 .0149 Mdot
.04154 .01492 Mdot
.0417 .01492 Mdot
.04204 .01493 Mdot
.04248 .01494 Mdot
.04274 .01495 Mdot
.04299 .01495 Mdot
.0432 .01496 Mdot
.04333 .01496 Mdot
.04354 .01497 Mdot
.04388 .01498 Mdot
.04421 .01499 Mdot
.04446 .01499 Mdot
.04489 .015 Mdot
.04521 .01501 Mdot
.04539 .01502 Mdot
.04561 .01502 Mdot
.04593 .01503 Mdot
.04604 .01504 Mdot
.04653 .01505 Mdot
.04659 .01505 Mdot
.04718 .01507 Mdot
.04748 .01508 Mdot
.04771 .01509 Mdot
.04796 .01509 Mdot
.04821 .0151 Mdot
.04845 .01511 Mdot
.04895 .01513 Mdot
.04918 .01513 Mdot
.0495 .01514 Mdot
.0499 .01516 Mdot
.05055 .01518 Mdot
.05102 .0152 Mdot
.05139 .01521 Mdot
.05183 .01522 Mdot
.05196 .01523 Mdot
.05226 .01524 Mdot
.0524 .01525 Mdot
.05263 .01525 Mdot
.05299 .01527 Mdot
.05314 .01527 Mdot
.05357 .01529 Mdot
.05367 .01529 Mdot
.05447 .01533 Mdot
.0546 .01533 Mdot
.05501 .01535 Mdot
.05547 .01537 Mdot
.05608 .01539 Mdot
.05619 .0154 Mdot
.05652 .01541 Mdot
.05667 .01542 Mdot
.05709 .01543 Mdot
.05733 .01544 Mdot
.05791 .01547 Mdot
.0584 .01549 Mdot
.05873 .01551 Mdot
.05894 .01552 Mdot
.05941 .01554 Mdot
.05948 .01554 Mdot
.06007 .01557 Mdot
.06041 .01558 Mdot
.06087 .01561 Mdot
.06126 .01563 Mdot
.0616 .01564 Mdot
.06177 .01565 Mdot
.06242 .01568 Mdot
.06273 .0157 Mdot
.06318 .01572 Mdot
.06322 .01572 Mdot
.06366 .01575 Mdot
.06388 .01576 Mdot
.06397 .01576 Mdot
.06475 .0158 Mdot
.06518 .01583 Mdot
.06527 .01583 Mdot
.06565 .01585 Mdot
.06594 .01587 Mdot
.06613 .01588 Mdot
.06652 .0159 Mdot
.06709 .01593 Mdot
.06731 .01594 Mdot
.06765 .01596 Mdot
.06788 .01598 Mdot
.06816 .01599 Mdot
.06866 .01602 Mdot
.06889 .01603 Mdot
.0691 .01605 Mdot
.06966 .01608 Mdot
.07011 .01611 Mdot
.07057 .01613 Mdot
.07078 .01615 Mdot
.07101 .01616 Mdot
.0713 .01618 Mdot
.07144 .01619 Mdot
.07179 .01621 Mdot
.07193 .01622 Mdot
.07238 .01625 Mdot
.07245 .01625 Mdot
.07302 .01629 Mdot
.07314 .01629 Mdot
.07366 .01633 Mdot
.07399 .01635 Mdot
.07417 .01636 Mdot
.07445 .01638 Mdot
.075 .01642 Mdot
.07524 .01643 Mdot
.07551 .01645 Mdot
.07613 .01649 Mdot
.0767 .01653 Mdot
.07722 .01657 Mdot
.07726 .01657 Mdot
.07743 .01658 Mdot
.07765 .0166 Mdot
.07786 .01661 Mdot
.07837 .01665 Mdot
.07854 .01666 Mdot
.07885 .01668 Mdot
.0791 .0167 Mdot
.07986 .01675 Mdot
.0803 .01679 Mdot
.08067 .01681 Mdot
.08083 .01682 Mdot
.08108 .01684 Mdot
.08141 .01687 Mdot
.08158 .01688 Mdot
.08182 .0169 Mdot
.08227 .01693 Mdot
.08255 .01695 Mdot
.08296 .01699 Mdot
.08341 .01702 Mdot
.08376 .01705 Mdot
.08395 .01706 Mdot
.0844 .0171 Mdot
.08474 .01712 Mdot
.08501 .01715 Mdot
.08551 .01719 Mdot
.08575 .01721 Mdot
.08615 .01724 Mdot
.08661 .01727 Mdot
.08688 .0173 Mdot
.08725 .01733 Mdot
.08737 .01734 Mdot
.08801 .01739 Mdot
.0883 .01741 Mdot
.08847 .01743 Mdot
.08876 .01745 Mdot
.08921 .01749 Mdot
.0896 .01752 Mdot
.09001 .01756 Mdot
.09035 .01759 Mdot
.0905 .0176 Mdot
.09057 .01761 Mdot
.09101 .01765 Mdot
.09152 .01769 Mdot
.09154 .01769 Mdot
.09197 .01773 Mdot
.09211 .01774 Mdot
.09247 .01777 Mdot
.09275 .0178 Mdot
.0929 .01781 Mdot
.09346 .01786 Mdot
.09369 .01788 Mdot
.09405 .01792 Mdot
.09432 .01794 Mdot
.09483 .01799 Mdot
.09502 .01801 Mdot
.09535 .01804 Mdot
.0956 .01806 Mdot
.09599 .0181 Mdot
.09613 .01811 Mdot
.09661 .01815 Mdot
.09691 .01818 Mdot
.09718 .01821 Mdot
.09753 .01824 Mdot
.09767 .01826 Mdot
.09821 .01831 Mdot
.0985 .01834 Mdot
.09893 .01838 Mdot
.0991 .01839 Mdot
.09957 .01844 Mdot
.10001 .01848 Mdot
.10019 .0185 Mdot
.1005 .01853 Mdot
.10075 .01856 Mdot
.10103 .01858 Mdot
.10166 .01865 Mdot
.10182 .01866 Mdot
.102 .01868 Mdot
.10212 .01869 Mdot
.10246 .01873 Mdot
.10274 .01876 Mdot
.103 .01878 Mdot
.10314 .0188 Mdot
.10334 .01882 Mdot
.10373 .01886 Mdot
.10399 .01889 Mdot
.10405 .01889 Mdot
.10458 .01895 Mdot
.10486 .01898 Mdot
.10508 .019 Mdot
.1052 .01901 Mdot
.10549 .01904 Mdot
.10615 .01912 Mdot
.10638 .01914 Mdot
.10681 .01919 Mdot
.10739 .01925 Mdot
.10782 .0193 Mdot
.10814 .01933 Mdot
.10833 .01935 Mdot
.10892 .01942 Mdot
.1091 .01944 Mdot
.10936 .01947 Mdot
.10971 .0195 Mdot
.10999 .01953 Mdot
.11059 .0196 Mdot
.11092 .01964 Mdot
.1112 .01967 Mdot
.11144 .0197 Mdot
.1118 .01974 Mdot
.112 .01976 Mdot
.11227 .01979 Mdot
.11251 .01982 Mdot
.11285 .01986 Mdot
.11307 .01989 Mdot
.11333 .01992 Mdot
.11349 .01993 Mdot
.11405 .02 Mdot
.11415 .02001 Mdot
.11453 .02006 Mdot
.11479 .02009 Mdot
.11527 .02014 Mdot
.1155 .02017 Mdot
.11581 .02021 Mdot
.11633 .02027 Mdot
.11658 .0203 Mdot
.11676 .02032 Mdot
.11693 .02034 Mdot
.11742 .0204 Mdot
.11794 .02046 Mdot
.11821 .0205 Mdot
.1184 .02052 Mdot
.11877 .02057 Mdot
.11887 .02058 Mdot
.11904 .0206 Mdot
.11963 .02067 Mdot
.11988 .0207 Mdot
.12044 .02077 Mdot
.12051 .02078 Mdot
.12083 .02082 Mdot
.12115 .02086 Mdot
.1213 .02088 Mdot
.12185 .02095 Mdot
.12187 .02095 Mdot
.12228 .02101 Mdot
.12239 .02102 Mdot
.12283 .02108 Mdot
.12339 .02115 Mdot
.12378 .0212 Mdot
.12408 .02124 Mdot
.12434 .02127 Mdot
.12486 .02134 Mdot
.12498 .02136 Mdot
.12521 .02139 Mdot
.12537 .02141 Mdot
.12553 .02143 Mdot
.12582 .02147 Mdot
.12609 .0215 Mdot
.1263 .02153 Mdot
.12672 .02159 Mdot
.12727 .02166 Mdot
.12744 .02168 Mdot
.12764 .02171 Mdot
.12796 .02175 Mdot
.12854 .02183 Mdot
.12875 .02186 Mdot
.1289 .02188 Mdot
.12904 .0219 Mdot
.12957 .02197 Mdot
.12969 .02199 Mdot
.13018 .02206 Mdot
.13029 .02207 Mdot
.13053 .02211 Mdot
.13107 .02218 Mdot
.13129 .02221 Mdot
.13166 .02226 Mdot
.13231 .02235 Mdot
.13234 .02236 Mdot
.13251 .02238 Mdot
.13285 .02243 Mdot
.13327 .02249 Mdot
.1335 .02252 Mdot
.13378 .02256 Mdot
.1341 .02261 Mdot
.13432 .02264 Mdot
.13487 .02272 Mdot
.13507 .02275 Mdot
.1356 .02283 Mdot
.13609 .0229 Mdot
.13632 .02293 Mdot
.1366 .02297 Mdot
.13717 .02305 Mdot
.13749 .0231 Mdot
.13759 .02312 Mdot
.13806 .02319 Mdot
.13837 .02323 Mdot
.13871 .02328 Mdot
.13896 .02332 Mdot
.13958 .02341 Mdot
.13959 .02341 Mdot
.14022 .02351 Mdot
.14042 .02354 Mdot
.14094 .02362 Mdot
.14111 .02364 Mdot
.14119 .02366 Mdot
.14156 .02371 Mdot
.14166 .02373 Mdot
.14219 .02381 Mdot
.14243 .02385 Mdot
.14286 .02391 Mdot
.14315 .02396 Mdot
.14331 .02398 Mdot
.14398 .02409 Mdot
.14409 .0241 Mdot
.14447 .02416 Mdot
.14474 .02421 Mdot
.14486 .02422 Mdot
.14517 .02427 Mdot
.14539 .02431 Mdot
.14603 .02441 Mdot
.14624 .02444 Mdot
.14687 .02454 Mdot
.14698 .02456 Mdot
.14772 .02468 Mdot
.14797 .02472 Mdot
.14817 .02475 Mdot
.14833 .02478 Mdot
.14859 .02482 Mdot
.14903 .02489 Mdot
.14948 .02496 Mdot
.1498 .02502 Mdot
.14991 .02503 Mdot
.15064 .02515 Mdot
.15087 .02519 Mdot
.15098 .02521 Mdot
.15132 .02527 Mdot
.15204 .02539 Mdot
.15225 .02542 Mdot
.1528 .02551 Mdot
.15321 .02558 Mdot
.15358 .02564 Mdot
.15362 .02565 Mdot
.15408 .02573 Mdot
.15433 .02577 Mdot
.15453 .0258 Mdot
.15471 .02583 Mdot
.15521 .02592 Mdot
.15561 .02599 Mdot
.15601 .02606 Mdot
.15636 .02612 Mdot
.15655 .02615 Mdot
.15689 .02621 Mdot
.15723 .02627 Mdot
.15782 .02637 Mdot
.15793 .02639 Mdot
.15839 .02647 Mdot
.15863 .02651 Mdot
.15923 .02662 Mdot
.15943 .02665 Mdot
.15948 .02666 Mdot
.15983 .02672 Mdot
.16036 .02682 Mdot
.16064 .02686 Mdot
.16098 .02693 Mdot
.16131 .02698 Mdot
.16162 .02704 Mdot
.1619 .02709 Mdot
.16211 .02713 Mdot
.16216 .02714 Mdot
.16252 .0272 Mdot
.1629 .02727 Mdot
.16322 .02733 Mdot
.16361 .0274 Mdot
.16413 .02749 Mdot
.16437 .02754 Mdot
.16493 .02764 Mdot
.16502 .02765 Mdot
.16525 .0277 Mdot
.16578 .02779 Mdot
.16631 .02789 Mdot
.16652 .02793 Mdot
.1666 .02795 Mdot
.16717 .02805 Mdot
.16753 .02812 Mdot
.16772 .02816 Mdot
.16807 .02822 Mdot
.16833 .02827 Mdot
.16853 .02831 Mdot
.16867 .02833 Mdot
.16904 .0284 Mdot
.16943 .02848 Mdot
.1697 .02853 Mdot
.1702 .02862 Mdot
.17033 .02865 Mdot
.17042 .02866 Mdot
.17067 .02871 Mdot
.17111 .0288 Mdot
.17153 .02888 Mdot
.17182 .02893 Mdot
.17199 .02896 Mdot
.1724 .02904 Mdot
.17288 .02914 Mdot
.1731 .02918 Mdot
.17348 .02925 Mdot
.17369 .02929 Mdot
.17396 .02934 Mdot
.17432 .02941 Mdot
.17473 .0295 Mdot
.17528 .0296 Mdot
.17571 .02969 Mdot
.17579 .0297 Mdot
.17616 .02978 Mdot
.17669 .02988 Mdot
.17692 .02993 Mdot
.17709 .02996 Mdot
.17756 .03006 Mdot
.17782 .03011 Mdot
.17835 .03021 Mdot
.17841 .03023 Mdot
.17874 .03029 Mdot
.17917 .03038 Mdot
.17924 .03039 Mdot
.17969 .03048 Mdot
.18001 .03055 Mdot
.18038 .03062 Mdot
.18062 .03067 Mdot
.18098 .03075 Mdot
.1813 .03081 Mdot
.18183 .03092 Mdot
.18207 .03097 Mdot
.18275 .03111 Mdot
.18312 .03119 Mdot
.18364 .03129 Mdot
.18382 .03133 Mdot
.18434 .03144 Mdot
.18447 .03147 Mdot
.18467 .03151 Mdot
.18518 .03161 Mdot
.18555 .03169 Mdot
.18577 .03174 Mdot
.18626 .03184 Mdot
.18638 .03187 Mdot
.18653 .0319 Mdot
.187 .032 Mdot
.18734 .03207 Mdot
.18751 .03211 Mdot
.18803 .03221 Mdot
.18828 .03227 Mdot
.18863 .03234 Mdot
.18894 .03241 Mdot
.18899 .03242 Mdot
.18932 .03249 Mdot
.18948 .03253 Mdot
.18985 .03261 Mdot
.18999 .03264 Mdot
.19021 .03268 Mdot
.1906 .03277 Mdot
.19084 .03282 Mdot
.19121 .0329 Mdot
.19166 .033 Mdot
.1919 .03305 Mdot
.19252 .03319 Mdot
.19281 .03325 Mdot
.19291 .03327 Mdot
.19313 .03332 Mdot
.1937 .03345 Mdot
.19385 .03348 Mdot
.19424 .03356 Mdot
.19457 .03364 Mdot
.195 .03373 Mdot
.19538 .03382 Mdot
.19559 .03386 Mdot
.19598 .03395 Mdot
.19646 .03406 Mdot
.19672 .03412 Mdot
.19697 .03417 Mdot
.19743 .03428 Mdot
.19788 .03438 Mdot
.19799 .0344 Mdot
.1982 .03445 Mdot
.19889 .03461 Mdot
.19922 .03468 Mdot
.19943 .03473 Mdot
.19986 .03483 Mdot
.20005 .03487 Mdot
.20057 .03499 Mdot
.2007 .03502 Mdot
.20094 .03508 Mdot
.20107 .03511 Mdot
.20136 .03517 Mdot
.20139 .03518 Mdot
.20176 .03526 Mdot
.20204 .03533 Mdot
.20242 .03542 Mdot
.20285 .03552 Mdot
.20351 .03567 Mdot
.20382 .03574 Mdot
.20413 .03581 Mdot
.20442 .03588 Mdot
.20481 .03597 Mdot
.20501 .03602 Mdot
.2053 .03609 Mdot
.20553 .03615 Mdot
.20597 .03625 Mdot
.2062 .0363 Mdot
.20634 .03633 Mdot
.20667 .03641 Mdot
.20704 .0365 Mdot
.20723 .03655 Mdot
.20729 .03656 Mdot
.20774 .03667 Mdot
.2079 .03671 Mdot
.20834 .03681 Mdot
.20847 .03684 Mdot
.20897 .03696 Mdot
.20909 .03699 Mdot
.2096 .03711 Mdot
.21003 .03722 Mdot
.21026 .03728 Mdot
.21058 .03735 Mdot
.2111 .03748 Mdot
.21125 .03751 Mdot
.21181 .03765 Mdot
.21211 .03772 Mdot
.21243 .0378 Mdot
.21271 .03787 Mdot
.21299 .03794 Mdot
.21354 .03808 Mdot
.21394 .03817 Mdot
.21413 .03822 Mdot
.21452 .03832 Mdot
.21476 .03838 Mdot
.21513 .03847 Mdot
.21529 .03851 Mdot
.21563 .03859 Mdot
.21597 .03868 Mdot
.21615 .03872 Mdot
.21674 .03887 Mdot
.21688 .0389 Mdot
.21713 .03897 Mdot
.21748 .03905 Mdot
.21816 .03923 Mdot
.21843 .03929 Mdot
.21856 .03933 Mdot
.21905 .03945 Mdot
.21929 .03951 Mdot
.21946 .03956 Mdot
.21974 .03963 Mdot
.22026 .03976 Mdot
.22053 .03983 Mdot
.22085 .03991 Mdot
.2213 .04003 Mdot
.22177 .04015 Mdot
.22219 .04025 Mdot
.22223 .04026 Mdot
.22269 .04038 Mdot
.22295 .04045 Mdot
.22348 .04059 Mdot
.22375 .04066 Mdot
.22399 .04072 Mdot
.22419 .04077 Mdot
.22457 .04087 Mdot
.22485 .04094 Mdot
.22515 .04102 Mdot
.22538 .04108 Mdot
.22589 .04121 Mdot
.2261 .04127 Mdot
.22666 .04142 Mdot
.22686 .04147 Mdot
.22706 .04152 Mdot
.22742 .04162 Mdot
.228 .04177 Mdot
.22845 .04189 Mdot
.22882 .04199 Mdot
.2289 .04201 Mdot
.22918 .04209 Mdot
.22931 .04212 Mdot
.22962 .0422 Mdot
.22965 .04221 Mdot
.23034 .0424 Mdot
.23056 .04245 Mdot
.2306 .04246 Mdot
.23109 .0426 Mdot
.23139 .04268 Mdot
.23175 .04277 Mdot
.23178 .04278 Mdot
.23218 .04289 Mdot
.23265 .04302 Mdot
.23286 .04308 Mdot
.23296 .0431 Mdot
.2337 .0433 Mdot
.23384 .04334 Mdot
.23421 .04344 Mdot
.23437 .04349 Mdot
.23472 .04358 Mdot
.23485 .04362 Mdot
.23524 .04373 Mdot
.23593 .04391 Mdot
.23614 .04397 Mdot
.23649 .04407 Mdot
.23701 .04421 Mdot
.23705 .04422 Mdot
.23752 .04435 Mdot
.23784 .04444 Mdot
.23792 .04446 Mdot
.23824 .04455 Mdot
.23861 .04466 Mdot
.23903 .04478 Mdot
.23928 .04484 Mdot
.23969 .04496 Mdot
.2401 .04507 Mdot
.24028 .04512 Mdot
.24047 .04518 Mdot
.24087 .04529 Mdot
.24106 .04534 Mdot
.24108 .04535 Mdot
.24183 .04556 Mdot
.24197 .0456 Mdot
.24232 .0457 Mdot
.24249 .04575 Mdot
.24303 .0459 Mdot
.2432 .04595 Mdot
.2436 .04606 Mdot
.24389 .04615 Mdot
.24428 .04626 Mdot
.24476 .04639 Mdot
.24482 .04641 Mdot
.24546 .0466 Mdot
.24578 .04669 Mdot
.2462 .04681 Mdot
.24639 .04686 Mdot
.24657 .04692 Mdot
.24701 .04705 Mdot
.24741 .04716 Mdot
.24763 .04722 Mdot
.24786 .04729 Mdot
.24823 .0474 Mdot
.24825 .04741 Mdot
.24889 .04759 Mdot
.24909 .04765 Mdot
.24939 .04774 Mdot
.24985 .04787 Mdot
.24997 .04791 Mdot
.25015 .04796 Mdot
.2505 .04806 Mdot
.25083 .04816 Mdot
.25086 .04817 Mdot
.25158 .04838 Mdot
.25177 .04844 Mdot
.25206 .04852 Mdot
.2525 .04865 Mdot
.25256 .04867 Mdot
.25277 .04873 Mdot
.25302 .04881 Mdot
.25355 .04897 Mdot
.25407 .04912 Mdot
.25422 .04917 Mdot
.25431 .04919 Mdot
.25472 .04932 Mdot
.25503 .04941 Mdot
.25534 .0495 Mdot
.25541 .04952 Mdot
.25587 .04966 Mdot
.25635 .04981 Mdot
.25659 .04988 Mdot
.25679 .04994 Mdot
.25719 .05006 Mdot
.25735 .05011 Mdot
.25744 .05014 Mdot
.25774 .05023 Mdot
.25816 .05036 Mdot
.25843 .05044 Mdot
.25858 .05048 Mdot
.25885 .05057 Mdot
.25948 .05076 Mdot
.25967 .05082 Mdot
.26018 .05097 Mdot
.26031 .05101 Mdot
.26075 .05115 Mdot
.26091 .0512 Mdot
.26106 .05124 Mdot
.26138 .05134 Mdot
.26166 .05143 Mdot
.26201 .05154 Mdot
.26244 .05167 Mdot
.26266 .05174 Mdot
.26321 .05191 Mdot
.26338 .05196 Mdot
.26413 .05219 Mdot
.26441 .05228 Mdot
.26465 .05235 Mdot
.26492 .05244 Mdot
.26534 .05257 Mdot
.26553 .05263 Mdot
.26566 .05267 Mdot
.26595 .05276 Mdot
.2664 .0529 Mdot
.2666 .05297 Mdot
.26694 .05308 Mdot
.26728 .05318 Mdot
.26764 .0533 Mdot
.2678 .05335 Mdot
.26841 .05354 Mdot
.26853 .05358 Mdot
.26904 .05374 Mdot
.26914 .05377 Mdot
.26947 .05388 Mdot
.26953 .0539 Mdot
.26987 .05401 Mdot
.27017 .0541 Mdot
.27048 .0542 Mdot
.27115 .05442 Mdot
.27134 .05448 Mdot
.27162 .05457 Mdot
.27185 .05464 Mdot
.27224 .05476 Mdot
.27286 .05497 Mdot
.27321 .05508 Mdot
.27372 .05524 Mdot
.27382 .05528 Mdot
.2744 .05546 Mdot
.27449 .0555 Mdot
.275 .05566 Mdot
.27523 .05573 Mdot
.27546 .05581 Mdot
.27612 .05603 Mdot
.2763 .05609 Mdot
.2765 .05615 Mdot
.27695 .0563 Mdot
.27733 .05643 Mdot
.27758 .05651 Mdot
.27766 .05653 Mdot
.27788 .05661 Mdot
.27827 .05673 Mdot
.27866 .05686 Mdot
.27885 .05692 Mdot
.27941 .05711 Mdot
.27955 .05716 Mdot
.28005 .05732 Mdot
.28025 .05739 Mdot
.28074 .05755 Mdot
.28111 .05768 Mdot
.28156 .05783 Mdot
.28165 .05786 Mdot
.28199 .05797 Mdot
.2822 .05804 Mdot
.28246 .05813 Mdot
.28303 .05832 Mdot
.28324 .05839 Mdot
.28367 .05854 Mdot
.28375 .05856 Mdot
.2842 .05872 Mdot
.28464 .05886 Mdot
.2847 .05888 Mdot
.28498 .05898 Mdot
.28524 .05907 Mdot
.28557 .05918 Mdot
.28584 .05927 Mdot
.28621 .0594 Mdot
.28645 .05948 Mdot
.28711 .0597 Mdot
.28725 .05975 Mdot
.28776 .05993 Mdot
.28785 .05996 Mdot
.28839 .06014 Mdot
.28858 .06021 Mdot
.2891 .06039 Mdot
.28942 .0605 Mdot
.28965 .06058 Mdot
.28978 .06062 Mdot
.29005 .06072 Mdot
.29038 .06083 Mdot
.29093 .06102 Mdot
.29137 .06117 Mdot
.29158 .06124 Mdot
.29208 .06142 Mdot
.29247 .06155 Mdot
.29272 .06164 Mdot
.29283 .06168 Mdot
.29313 .06178 Mdot
.29351 .06192 Mdot
.29401 .06209 Mdot
.29456 .06229 Mdot
.29472 .06234 Mdot
.29524 .06252 Mdot
.2954 .06258 Mdot
.2958 .06272 Mdot
.29583 .06273 Mdot
.29601 .0628 Mdot
.29665 .06302 Mdot
.29693 .06312 Mdot
.29697 .06314 Mdot
.29731 .06326 Mdot
.29772 .0634 Mdot
.29801 .06351 Mdot
.29831 .06361 Mdot
.29851 .06368 Mdot
.29892 .06383 Mdot
.29906 .06388 Mdot
.29924 .06395 Mdot
.29956 .06406 Mdot
.29982 .06415 Mdot
.29984 .06416 Mdot
.30025 .06431 Mdot
.30068 .06446 Mdot
.30101 .06458 Mdot
.30115 .06463 Mdot
.3016 .06479 Mdot
.30186 .06488 Mdot
.30204 .06495 Mdot
.30252 .06512 Mdot
.3031 .06534 Mdot
.30339 .06544 Mdot
.30358 .06551 Mdot
.30394 .06564 Mdot
.30425 .06575 Mdot
.30459 .06588 Mdot
.3047 .06592 Mdot
.30516 .06608 Mdot
.30563 .06625 Mdot
.3057 .06628 Mdot
.30587 .06634 Mdot
.30635 .06652 Mdot
.30677 .06667 Mdot
.30715 .06681 Mdot
.3075 .06694 Mdot
.30794 .0671 Mdot
.30818 .06719 Mdot
.30833 .06725 Mdot
.30881 .06742 Mdot
.30897 .06748 Mdot
.30938 .06764 Mdot
.30963 .06773 Mdot
.31015 .06792 Mdot
.31064 .06811 Mdot
.31082 .06817 Mdot
.31099 .06823 Mdot
.31142 .0684 Mdot
.31159 .06846 Mdot
.31199 .06861 Mdot
.31223 .0687 Mdot
.31279 .06891 Mdot
.313 .06899 Mdot
.31339 .06913 Mdot
.3135 .06917 Mdot
.31399 .06936 Mdot
.31444 .06953 Mdot
.31461 .06959 Mdot
.31511 .06978 Mdot
.31532 .06986 Mdot
.31599 .07011 Mdot
.31627 .07022 Mdot
.31664 .07036 Mdot
.31693 .07047 Mdot
.3172 .07057 Mdot
.31745 .07067 Mdot
.31756 .07071 Mdot
.31815 .07094 Mdot
.31846 .07105 Mdot
.31873 .07116 Mdot
.31935 .0714 Mdot
.31984 .07159 Mdot
.31993 .07162 Mdot
.32024 .07174 Mdot
.32061 .07188 Mdot
.32094 .07201 Mdot
.32139 .07218 Mdot
.32161 .07227 Mdot
.3218 .07234 Mdot
.32215 .07248 Mdot
.32232 .07254 Mdot
.3228 .07273 Mdot
.32308 .07283 Mdot
.32335 .07294 Mdot
.32358 .07303 Mdot
.32404 .07321 Mdot
.32444 .07337 Mdot
.3245 .07339 Mdot
.32488 .07354 Mdot
.32516 .07365 Mdot
.32549 .07378 Mdot
.32573 .07387 Mdot
.32605 .07399 Mdot
.32653 .07418 Mdot
.32683 .0743 Mdot
.32704 .07439 Mdot
.32754 .07458 Mdot
.32766 .07463 Mdot
.32812 .07481 Mdot
.32838 .07491 Mdot
.32865 .07502 Mdot
.3292 .07524 Mdot
.32934 .07529 Mdot
.32969 .07543 Mdot
.32971 .07544 Mdot
.33042 .07572 Mdot
.33072 .07584 Mdot
.33111 .076 Mdot
.3314 .07611 Mdot
.33175 .07625 Mdot
.33185 .07629 Mdot
.33215 .07641 Mdot
.33252 .07656 Mdot
.33293 .07672 Mdot
.33333 .07689 Mdot
.33396 .07714 Mdot
.334 .07716 Mdot
.33451 .07736 Mdot
.33488 .07751 Mdot
.3351 .0776 Mdot
.33529 .07768 Mdot
.33572 .07785 Mdot
.33608 .078 Mdot
.33612 .07801 Mdot
.33636 .07811 Mdot
.33662 .07821 Mdot
.33675 .07827 Mdot
.33698 .07836 Mdot
.33737 .07852 Mdot
.33756 .0786 Mdot
.33777 .07868 Mdot
.33834 .07891 Mdot
.33863 .07903 Mdot
.339 .07918 Mdot
.33947 .07938 Mdot
.33968 .07946 Mdot
.34009 .07963 Mdot
.34049 .0798 Mdot
.34083 .07994 Mdot
.34116 .08007 Mdot
.34129 .08012 Mdot
.34177 .08032 Mdot
.34205 .08044 Mdot
.34224 .08052 Mdot
.3426 .08066 Mdot
.34269 .0807 Mdot
.3432 .08091 Mdot
.34362 .08109 Mdot
.34398 .08124 Mdot
.3442 .08133 Mdot
.34445 .08143 Mdot
.34492 .08163 Mdot
.34528 .08178 Mdot
.34559 .08191 Mdot
.34599 .08207 Mdot
.34629 .0822 Mdot
.34635 .08223 Mdot
.34673 .08239 Mdot
.3472 .08258 Mdot
.3475 .08271 Mdot
.348 .08292 Mdot
.34848 .08312 Mdot
.34855 .08315 Mdot
.34873 .08323 Mdot
.34908 .08337 Mdot
.34928 .08346 Mdot
.34953 .08356 Mdot
.34967 .08362 Mdot
.34982 .08368 Mdot
.35021 .08385 Mdot
.35055 .08399 Mdot
.35076 .08408 Mdot
.35102 .0842 Mdot
.35126 .0843 Mdot
.35165 .08446 Mdot
.35187 .08456 Mdot
.35214 .08467 Mdot
.35256 .08485 Mdot
.35263 .08488 Mdot
.35299 .08504 Mdot
.3534 .08521 Mdot
.35359 .08529 Mdot
.35386 .0854 Mdot
.35435 .08562 Mdot
.35486 .08583 Mdot
.35506 .08592 Mdot
.35516 .08596 Mdot
.35563 .08617 Mdot
.35593 .08629 Mdot
.35628 .08645 Mdot
.35675 .08665 Mdot
.35726 .08687 Mdot
.3573 .08689 Mdot
.35799 .08719 Mdot
.35822 .08729 Mdot
.35841 .08737 Mdot
.3587 .08749 Mdot
.35894 .0876 Mdot
.35944 .08781 Mdot
.35947 .08783 Mdot
.35995 .08804 Mdot
.36035 .08821 Mdot
.36065 .08834 Mdot
.36097 .08848 Mdot
.36127 .08862 Mdot
.36177 .08884 Mdot
.36192 .0889 Mdot
.36218 .08901 Mdot
.36259 .08919 Mdot
.363 .08937 Mdot
.36306 .0894 Mdot
.36375 .08971 Mdot
.36385 .08975 Mdot
.36418 .0899 Mdot
.36461 .09008 Mdot
.36475 .09015 Mdot
.36508 .09029 Mdot
.36539 .09043 Mdot
.36547 .09047 Mdot
.36585 .09064 Mdot
.36629 .09083 Mdot
.36638 .09087 Mdot
.36655 .09095 Mdot
.36706 .09117 Mdot
.36727 .09127 Mdot
.36763 .09143 Mdot
.36781 .09151 Mdot
.36843 .09179 Mdot
.36881 .09196 Mdot
.36914 .0921 Mdot
.36921 .09213 Mdot
.36958 .0923 Mdot
.36975 .09238 Mdot
.37041 .09267 Mdot
.37083 .09286 Mdot
.37107 .09297 Mdot
.37138 .09311 Mdot
.37151 .09317 Mdot
.37171 .09326 Mdot
.37195 .09337 Mdot
.37211 .09344 Mdot
.37231 .09353 Mdot
.37243 .09358 Mdot
.37291 .0938 Mdot
.37305 .09387 Mdot
.37327 .09397 Mdot
.37388 .09424 Mdot
.37422 .0944 Mdot
.37426 .09441 Mdot
.37483 .09467 Mdot
.37525 .09487 Mdot
.37546 .09496 Mdot
.37591 .09517 Mdot
.37643 .0954 Mdot
.37668 .09552 Mdot
.37696 .09565 Mdot
.37738 .09584 Mdot
.37761 .09595 Mdot
.37791 .09608 Mdot
.37841 .09631 Mdot
.37856 .09638 Mdot
.37879 .09649 Mdot
.37901 .09659 Mdot
.37937 .09676 Mdot
.38007 .09708 Mdot
.38014 .09711 Mdot
.38036 .09721 Mdot
.38064 .09734 Mdot
.38101 .09751 Mdot
.38138 .09769 Mdot
.38154 .09776 Mdot
.38208 .09801 Mdot
.38241 .09817 Mdot
.3826 .09825 Mdot
.3829 .09839 Mdot
.38306 .09847 Mdot
.38326 .09856 Mdot
.38375 .09879 Mdot
.38402 .09891 Mdot
.38423 .09902 Mdot
.38451 .09914 Mdot
.38514 .09944 Mdot
.38547 .09959 Mdot
.38564 .09967 Mdot
.38582 .09976 Mdot
.38634 .10001 Mdot
.38673 .10019 Mdot
.38703 .10033 Mdot
.38741 .10051 Mdot
.38789 .10073 Mdot
.38817 .10087 Mdot
.38862 .10108 Mdot
.38882 .10118 Mdot
.38898 .10125 Mdot
.38911 .10131 Mdot
.38958 .10154 Mdot
.38979 .10163 Mdot
.38998 .10172 Mdot
.39049 .10197 Mdot
.39076 .1021 Mdot
.39122 .10232 Mdot
.39154 .10247 Mdot
.392 .10269 Mdot
.39242 .10289 Mdot
.39262 .10299 Mdot
.39279 .10306 Mdot
.39296 .10315 Mdot
.39343 .10337 Mdot
.39378 .10354 Mdot
.39389 .10359 Mdot
.39456 .10391 Mdot
.39485 .10406 Mdot
.3953 .10427 Mdot
.39572 .10448 Mdot
.39584 .10453 Mdot
.39612 .10467 Mdot
.39627 .10474 Mdot
.39661 .10491 Mdot
.39688 .10503 Mdot
.39763 .1054 Mdot
.39797 .10556 Mdot
.39826 .10571 Mdot
.39865 .1059 Mdot
.39882 .10598 Mdot
.39909 .10611 Mdot
.39927 .1062 Mdot
.39969 .1064 Mdot
.40039 .10674 Mdot
.40065 .10687 Mdot
.40093 .107 Mdot
.40134 .10721 Mdot
.40151 .10729 Mdot
.40198 .10752 Mdot
.40215 .10761 Mdot
.40245 .10775 Mdot
.40295 .108 Mdot
.40302 .10803 Mdot
.40359 .10832 Mdot
.40378 .10841 Mdot
.40432 .10867 Mdot
.40458 .1088 Mdot
.40492 .10897 Mdot
.40547 .10924 Mdot
.40581 .10941 Mdot
.40616 .10958 Mdot
.40663 .10982 Mdot
.40709 .11005 Mdot
.40743 .11022 Mdot
.40772 .11036 Mdot
.40795 .11048 Mdot
.40845 .11072 Mdot
.40877 .11088 Mdot
.4092 .1111 Mdot
.40968 .11134 Mdot
.40993 .11147 Mdot
.41012 .11156 Mdot
.41035 .11168 Mdot
.41083 .11192 Mdot
.41121 .11211 Mdot
.41147 .11224 Mdot
.41203 .11252 Mdot
.41241 .11271 Mdot
.41256 .11279 Mdot
.41294 .11298 Mdot
.41315 .11309 Mdot
.41344 .11323 Mdot
.41371 .11337 Mdot
.4139 .11346 Mdot
.41423 .11363 Mdot
.41442 .11373 Mdot
.41487 .11396 Mdot
.41518 .11411 Mdot
.41549 .11427 Mdot
.41574 .1144 Mdot
.41631 .11469 Mdot
.4168 .11494 Mdot
.41715 .11512 Mdot
.41743 .11526 Mdot
.41792 .11551 Mdot
.41806 .11558 Mdot
.41832 .11571 Mdot
.41837 .11574 Mdot
.41863 .11587 Mdot
.41914 .11614 Mdot
.41936 .11625 Mdot
.41944 .11629 Mdot
.42003 .11659 Mdot
.42044 .1168 Mdot
.42051 .11684 Mdot
.42098 .11708 Mdot
.42142 .11731 Mdot
.42171 .11746 Mdot
.42207 .11764 Mdot
.42221 .11772 Mdot
.42233 .11778 Mdot
.42267 .11795 Mdot
.42285 .11805 Mdot
.4231 .11818 Mdot
.42319 .11822 Mdot
.42336 .11831 Mdot
.42361 .11844 Mdot
.42398 .11863 Mdot
.42437 .11884 Mdot
.42489 .1191 Mdot
.42518 .11926 Mdot
.42543 .11939 Mdot
.42571 .11953 Mdot
.42613 .11975 Mdot
.42631 .11985 Mdot
.42644 .11992 Mdot
.42703 .12022 Mdot
.42729 .12036 Mdot
.42742 .12043 Mdot
.42783 .12065 Mdot
.42825 .12086 Mdot
.42844 .12096 Mdot
.42894 .12123 Mdot
.42923 .12138 Mdot
.42972 .12164 Mdot
.42995 .12176 Mdot
.43039 .12199 Mdot
.43065 .12213 Mdot
.4309 .12226 Mdot
.43119 .12241 Mdot
.43176 .12271 Mdot
.43194 .12281 Mdot
.43239 .12305 Mdot
.43263 .12318 Mdot
.43289 .12331 Mdot
.43318 .12347 Mdot
.4335 .12364 Mdot
.43388 .12384 Mdot
.43426 .12404 Mdot
.43456 .1242 Mdot
.43466 .12425 Mdot
.43485 .12436 Mdot
.4353 .1246 Mdot
.43558 .12474 Mdot
.43598 .12496 Mdot
.43608 .12501 Mdot
.43665 .12532 Mdot
.43671 .12535 Mdot
.4372 .12561 Mdot
.43743 .12574 Mdot
.43776 .12591 Mdot
.43829 .1262 Mdot
.43843 .12628 Mdot
.43886 .1265 Mdot
.43936 .12678 Mdot
.43966 .12694 Mdot
.43994 .12709 Mdot
.44048 .12738 Mdot
.4408 .12755 Mdot
.44118 .12776 Mdot
.44142 .12789 Mdot
.44186 .12813 Mdot
.4423 .12836 Mdot
.4426 .12853 Mdot
.44288 .12868 Mdot
.44299 .12874 Mdot
.44315 .12883 Mdot
.44334 .12893 Mdot
.44391 .12924 Mdot
.44401 .1293 Mdot
.44444 .12953 Mdot
.44467 .12966 Mdot
.44507 .12988 Mdot
.44521 .12995 Mdot
.44553 .13013 Mdot
.44586 .13031 Mdot
.44611 .13045 Mdot
.44628 .13054 Mdot
.44665 .13074 Mdot
.44692 .13089 Mdot
.44728 .13109 Mdot
.44768 .1313 Mdot
.44812 .13155 Mdot
.44829 .13165 Mdot
.44848 .13175 Mdot
.44912 .1321 Mdot
.44922 .13216 Mdot
.44962 .13238 Mdot
.45012 .13265 Mdot
.45046 .13284 Mdot
.45099 .13313 Mdot
.45127 .13329 Mdot
.45158 .13346 Mdot
.45178 .13357 Mdot
.452 .13369 Mdot
.45239 .13391 Mdot
.45287 .13418 Mdot
.45294 .13422 Mdot
.45377 .13468 Mdot
.45406 .13484 Mdot
.45434 .135 Mdot
.45461 .13515 Mdot
.45506 .1354 Mdot
.45532 .13555 Mdot
.45591 .13588 Mdot
.45608 .13597 Mdot
.45636 .13613 Mdot
.45676 .13636 Mdot
.45696 .13647 Mdot
.45723 .13662 Mdot
.45749 .13677 Mdot
.45806 .13709 Mdot
.45823 .13718 Mdot
.45866 .13743 Mdot
.45902 .13763 Mdot
.45944 .13787 Mdot
.45965 .13799 Mdot
.45992 .13814 Mdot
.46036 .13839 Mdot
.46082 .13865 Mdot
.46118 .13885 Mdot
.4617 .13915 Mdot
.46193 .13928 Mdot
.4623 .13949 Mdot
.46234 .13951 Mdot
.46314 .13996 Mdot
.46323 .14002 Mdot
.46372 .1403 Mdot
.46393 .14042 Mdot
.46417 .14056 Mdot
.46453 .14076 Mdot
.46471 .14087 Mdot
.46502 .14104 Mdot
.46536 .14124 Mdot
.46551 .14132 Mdot
.46587 .14153 Mdot
.46601 .14161 Mdot
.46622 .14173 Mdot
.46663 .14196 Mdot
.46674 .14203 Mdot
.46703 .1422 Mdot
.46737 .14239 Mdot
.46787 .14268 Mdot
.46805 .14278 Mdot
.46851 .14305 Mdot
.46876 .14319 Mdot
.46926 .14348 Mdot
.46964 .1437 Mdot
.46984 .14381 Mdot
.46996 .14388 Mdot
.47022 .14404 Mdot
.47063 .14427 Mdot
.47118 .14459 Mdot
.47146 .14476 Mdot
.47211 .14513 Mdot
.47242 .14531 Mdot
.47306 .14569 Mdot
.47321 .14578 Mdot
.47359 .14599 Mdot
.47391 .14618 Mdot
.47423 .14637 Mdot
.47456 .14656 Mdot
.47485 .14673 Mdot
.47523 .14695 Mdot
.4754 .14706 Mdot
.47556 .14715 Mdot
.47578 .14728 Mdot
.47595 .14738 Mdot
.47647 .14768 Mdot
.47657 .14774 Mdot
.47675 .14785 Mdot
.47727 .14815 Mdot
.47755 .14832 Mdot
.47814 .14867 Mdot
.47846 .14886 Mdot
.47866 .14897 Mdot
.47932 .14936 Mdot
.47983 .14966 Mdot
.48029 .14994 Mdot
.48062 .15013 Mdot
.48118 .15047 Mdot
.48138 .15059 Mdot
.48169 .15077 Mdot
.48188 .15088 Mdot
.48219 .15106 Mdot
.48256 .15129 Mdot
.48286 .15146 Mdot
.48317 .15165 Mdot
.48366 .15194 Mdot
.48376 .152 Mdot
.48397 .15212 Mdot
.48418 .15225 Mdot
.48434 .15235 Mdot
.4846 .1525 Mdot
.48513 .15282 Mdot
.48533 .15294 Mdot
.48598 .15333 Mdot
.48603 .15336 Mdot
.48659 .15369 Mdot
.48689 .15387 Mdot
.48696 .15392 Mdot
.48728 .15411 Mdot
.48789 .15448 Mdot
.48805 .15457 Mdot
.48834 .15475 Mdot
.48874 .15499 Mdot
.4889 .15509 Mdot
.48905 .15518 Mdot
.48921 .15528 Mdot
.48969 .15557 Mdot
.49016 .15585 Mdot
.49041 .156 Mdot
.4905 .15605 Mdot
.49114 .15644 Mdot
.4914 .1566 Mdot
.49176 .15682 Mdot
.49234 .15717 Mdot
.49264 .15735 Mdot
.49279 .15745 Mdot
.49313 .15765 Mdot
.49329 .15775 Mdot
.49383 .15808 Mdot
.49398 .15817 Mdot
.49417 .15829 Mdot
.4948 .15867 Mdot
.49493 .15875 Mdot
.49529 .15897 Mdot
.49573 .15924 Mdot
.49584 .15931 Mdot
.49614 .15949 Mdot
.49639 .15964 Mdot
.49685 .15992 Mdot
.49703 .16003 Mdot
.49729 .16019 Mdot
.49766 .16042 Mdot
.49814 .16072 Mdot
.49824 .16078 Mdot
.49876 .1611 Mdot
.49936 .16147 Mdot
.49958 .16161 Mdot
.49974 .16171 Mdot
.50006 .1619 Mdot
.50032 .16207 Mdot
.50049 .16217 Mdot
.50068 .16229 Mdot
.50107 .16253 Mdot
.5015 .16279 Mdot
.50172 .16293 Mdot
.50212 .16318 Mdot
.50236 .16333 Mdot
.50313 .16381 Mdot
.50339 .16397 Mdot
.50363 .16412 Mdot
.50412 .16443 Mdot
.50439 .16459 Mdot
.50466 .16476 Mdot
.50499 .16497 Mdot
.50514 .16506 Mdot
.50555 .16532 Mdot
.5062 .16572 Mdot
.50633 .1658 Mdot
.50662 .16598 Mdot
.50697 .16621 Mdot
.50726 .16639 Mdot
.50753 .16656 Mdot
.50783 .16674 Mdot
.50811 .16692 Mdot
.50839 .1671 Mdot
.50879 .16735 Mdot
.50888 .16741 Mdot
.50934 .16769 Mdot
.50945 .16776 Mdot
.5099 .16805 Mdot
.5102 .16824 Mdot
.51085 .16865 Mdot
.51117 .16885 Mdot
.51144 .16902 Mdot
.51195 .16935 Mdot
.51211 .16944 Mdot
.51264 .16978 Mdot
.5128 .16989 Mdot
.51298 .16999 Mdot
.51335 .17023 Mdot
.5138 .17052 Mdot
.51389 .17058 Mdot
.51465 .17106 Mdot
.51468 .17108 Mdot
.51493 .17124 Mdot
.51535 .1715 Mdot
.5155 .1716 Mdot
.51585 .17183 Mdot
.51642 .17219 Mdot
.51663 .17233 Mdot
.51674 .1724 Mdot
.51726 .17273 Mdot
.51751 .17289 Mdot
.51774 .17303 Mdot
.51786 .17311 Mdot
.51836 .17343 Mdot
.51874 .17368 Mdot
.51885 .17374 Mdot
.51925 .174 Mdot
.51962 .17424 Mdot
.5198 .17436 Mdot
.52036 .17472 Mdot
.52079 .175 Mdot
.52109 .17519 Mdot
.52119 .17525 Mdot
.52157 .1755 Mdot
.52217 .17588 Mdot
.5224 .17603 Mdot
.5226 .17617 Mdot
.52301 .17643 Mdot
.52333 .17664 Mdot
.52358 .1768 Mdot
.52409 .17713 Mdot
.52449 .17739 Mdot
.52471 .17753 Mdot
.52515 .17782 Mdot
.5254 .17798 Mdot
.52583 .17826 Mdot
.52618 .17849 Mdot
.52675 .17886 Mdot
.5269 .17896 Mdot
.52712 .17911 Mdot
.52766 .17946 Mdot
.52783 .17957 Mdot
.52808 .17973 Mdot
.52853 .18002 Mdot
.52897 .18032 Mdot
.52923 .18049 Mdot
.52977 .18084 Mdot
.52991 .18093 Mdot
.53015 .18109 Mdot
.53039 .18125 Mdot
.53051 .18133 Mdot
.53098 .18164 Mdot
.53113 .18173 Mdot
.53153 .182 Mdot
.53176 .18215 Mdot
.53199 .1823 Mdot
.53224 .18246 Mdot
.53258 .18269 Mdot
.53314 .18306 Mdot
.53343 .18325 Mdot
.53366 .1834 Mdot
.53372 .18344 Mdot
.53436 .18387 Mdot
.53479 .18415 Mdot
.53512 .18437 Mdot
.53533 .18451 Mdot
.5355 .18463 Mdot
.53579 .18482 Mdot
.53601 .18496 Mdot
.53626 .18513 Mdot
.53674 .18545 Mdot
.53719 .18575 Mdot
.53727 .1858 Mdot
.53753 .18597 Mdot
.53779 .18615 Mdot
.5384 .18655 Mdot
.5387 .18676 Mdot
.53905 .18699 Mdot
.53943 .18724 Mdot
.53963 .18738 Mdot
.53978 .18748 Mdot
.54001 .18763 Mdot
.54051 .18797 Mdot
.54059 .18802 Mdot
.54101 .1883 Mdot
.54122 .18844 Mdot
.54155 .18867 Mdot
.54204 .18899 Mdot
.54271 .18945 Mdot
.5429 .18958 Mdot
.54295 .18961 Mdot
.5436 .19005 Mdot
.54389 .19024 Mdot
.54417 .19043 Mdot
.54445 .19062 Mdot
.54459 .19071 Mdot
.54512 .19107 Mdot
.54528 .19118 Mdot
.54559 .19139 Mdot
.54581 .19154 Mdot
.54607 .19171 Mdot
.54636 .19191 Mdot
.54685 .19225 Mdot
.547 .19235 Mdot
.54728 .19254 Mdot
.54749 .19268 Mdot
.54789 .19295 Mdot
.54801 .19304 Mdot
.54851 .19337 Mdot
.54858 .19342 Mdot
.54908 .19376 Mdot
.54961 .19413 Mdot
.54994 .19435 Mdot
.55004 .19442 Mdot
.55047 .19471 Mdot
.55101 .19508 Mdot
.55147 .1954 Mdot
.55158 .19547 Mdot
.55187 .19567 Mdot
.55225 .19593 Mdot
.55279 .1963 Mdot
.55299 .19643 Mdot
.55329 .19664 Mdot
.55374 .19695 Mdot
.5541 .1972 Mdot
.55423 .19729 Mdot
.55463 .19756 Mdot
.55501 .19783 Mdot
.55524 .19799 Mdot
.55558 .19822 Mdot
.55578 .19836 Mdot
.55593 .19846 Mdot
.5565 .19886 Mdot
.55678 .19905 Mdot
.55684 .19909 Mdot
.55727 .19939 Mdot
.55779 .19975 Mdot
.55805 .19993 Mdot
.5584 .20017 Mdot
.55865 .20035 Mdot
.55877 .20043 Mdot
.55923 .20075 Mdot
.55965 .20104 Mdot
.55991 .20122 Mdot
.55998 .20127 Mdot
.56036 .20153 Mdot
.56111 .20206 Mdot
.56131 .2022 Mdot
.56168 .20246 Mdot
.56204 .2027 Mdot
.56236 .20293 Mdot
.56257 .20308 Mdot
.56316 .20349 Mdot
.5632 .20352 Mdot
.56357 .20378 Mdot
.5641 .20415 Mdot
.5642 .20422 Mdot
.56455 .20446 Mdot
.56477 .20462 Mdot
.56518 .2049 Mdot
.56535 .20502 Mdot
.5658 .20534 Mdot
.5661 .20556 Mdot
.56632 .20571 Mdot
.56663 .20593 Mdot
.56693 .20614 Mdot
.56726 .20637 Mdot
.56749 .20653 Mdot
.56795 .20685 Mdot
.56837 .20715 Mdot
.56885 .2075 Mdot
.56936 .20786 Mdot
.56945 .20792 Mdot
.5699 .20823 Mdot
.57003 .20833 Mdot
.57064 .20876 Mdot
.57071 .20881 Mdot
.57108 .20908 Mdot
.5715 .20937 Mdot
.57165 .20948 Mdot
.57196 .2097 Mdot
.57206 .20977 Mdot
.57264 .21018 Mdot
.57279 .21029 Mdot
.57325 .21062 Mdot
.57355 .21083 Mdot
.57383 .21104 Mdot
.57397 .21113 Mdot
.57444 .21147 Mdot
.57465 .21162 Mdot
.57488 .21178 Mdot
.57534 .21212 Mdot
.57555 .21226 Mdot
.57582 .21245 Mdot
.57639 .21286 Mdot
.5764 .21287 Mdot
.57713 .2134 Mdot
.57754 .21369 Mdot
.57793 .21397 Mdot
.57807 .21407 Mdot
.57857 .21443 Mdot
.57889 .21466 Mdot
.57911 .21482 Mdot
.57962 .21519 Mdot
.57995 .21542 Mdot
.58006 .21551 Mdot
.58031 .21569 Mdot
.58063 .21592 Mdot
.58086 .21608 Mdot
.5811 .21625 Mdot
.58148 .21653 Mdot
.58192 .21685 Mdot
.58227 .2171 Mdot
.58252 .21728 Mdot
.58282 .2175 Mdot
.58315 .21774 Mdot
.58352 .21801 Mdot
.58386 .21826 Mdot
.5841 .21843 Mdot
.5845 .21872 Mdot
.58475 .21891 Mdot
.58522 .21924 Mdot
.5855 .21945 Mdot
.58583 .21969 Mdot
.58647 .22016 Mdot
.58682 .22042 Mdot
.58714 .22065 Mdot
.58745 .22088 Mdot
.58752 .22093 Mdot
.58797 .22126 Mdot
.5883 .2215 Mdot
.58872 .22181 Mdot
.58896 .22198 Mdot
.58914 .22211 Mdot
.58951 .22239 Mdot
.59007 .2228 Mdot
.59016 .22287 Mdot
.59077 .22331 Mdot
.59088 .22339 Mdot
.59111 .22356 Mdot
.5915 .22385 Mdot
.59171 .22401 Mdot
.59217 .22434 Mdot
.59262 .22467 Mdot
.59271 .22474 Mdot
.59313 .22505 Mdot
.59364 .22543 Mdot
.59392 .22563 Mdot
.59409 .22576 Mdot
.59427 .22589 Mdot
.59436 .22596 Mdot
.59497 .22642 Mdot
.5951 .22651 Mdot
.59535 .2267 Mdot
.59572 .22697 Mdot
.59583 .22705 Mdot
.59609 .22725 Mdot
.59648 .22754 Mdot
.59679 .22776 Mdot
.59708 .22798 Mdot
.5974 .22822 Mdot
.59807 .22872 Mdot
.59813 .22876 Mdot
.59855 .22908 Mdot
.59881 .22927 Mdot
.59951 .2298 Mdot
.59983 .23003 Mdot
.59993 .23011 Mdot
.60052 .23055 Mdot
.60065 .23065 Mdot
.60089 .23082 Mdot
.60153 .23131 Mdot
.60188 .23156 Mdot
.60207 .23171 Mdot
.6024 .23196 Mdot
.60272 .2322 Mdot
.60317 .23254 Mdot
.60376 .23298 Mdot
.60402 .23318 Mdot
.60443 .23349 Mdot
.60472 .23371 Mdot
.60479 .23375 Mdot
.60516 .23404 Mdot
.60542 .23423 Mdot
.60549 .23428 Mdot
.60568 .23443 Mdot
.60615 .23478 Mdot
.60652 .23506 Mdot
.60671 .2352 Mdot
.60708 .23549 Mdot
.60747 .23578 Mdot
.60759 .23587 Mdot
.60794 .23614 Mdot
.60839 .23648 Mdot
.6086 .23663 Mdot
.60892 .23688 Mdot
.6094 .23724 Mdot
.60967 .23745 Mdot
.60978 .23753 Mdot
.61016 .23783 Mdot
.61036 .23798 Mdot
.61068 .23822 Mdot
.61102 .23848 Mdot
.61143 .23879 Mdot
.61177 .23905 Mdot
.61213 .23933 Mdot
.61251 .23961 Mdot
.61278 .23982 Mdot
.61295 .23995 Mdot
.61349 .24036 Mdot
.61365 .24049 Mdot
.61391 .24069 Mdot
.61423 .24093 Mdot
.61449 .24113 Mdot
.61473 .24131 Mdot
.61518 .24166 Mdot
.61526 .24172 Mdot
.61574 .24209 Mdot
.61608 .24235 Mdot
.61639 .24259 Mdot
.6167 .24283 Mdot
.61697 .24304 Mdot
.61724 .24325 Mdot
.61752 .24346 Mdot
.61784 .24371 Mdot
.61801 .24383 Mdot
.61885 .24449 Mdot
.61897 .24458 Mdot
.61919 .24475 Mdot
.6194 .24491 Mdot
.61969 .24514 Mdot
.6202 .24553 Mdot
.62042 .2457 Mdot
.62069 .24591 Mdot
.62078 .24598 Mdot
.62137 .24643 Mdot
.62151 .24654 Mdot
.62184 .2468 Mdot
.62243 .24726 Mdot
.62278 .24753 Mdot
.62293 .24765 Mdot
.62312 .24779 Mdot
.6235 .24809 Mdot
.62388 .24839 Mdot
.62435 .24875 Mdot
.62442 .24881 Mdot
.62487 .24916 Mdot
.62501 .24927 Mdot
.62531 .2495 Mdot
.62544 .2496 Mdot
.62598 .25002 Mdot
.62619 .25019 Mdot
.62642 .25037 Mdot
.62671 .2506 Mdot
.627 .25082 Mdot
.62734 .25109 Mdot
.62745 .25118 Mdot
.6281 .25169 Mdot
.6283 .25184 Mdot
.62867 .25213 Mdot
.62893 .25234 Mdot
.62917 .25252 Mdot
.62964 .2529 Mdot
.62987 .25307 Mdot
.63023 .25336 Mdot
.63047 .25354 Mdot
.63069 .25372 Mdot
.63115 .25408 Mdot
.63146 .25433 Mdot
.63221 .25492 Mdot
.63246 .25511 Mdot
.6328 .25539 Mdot
.63329 .25577 Mdot
.63363 .25604 Mdot
.63384 .25621 Mdot
.63415 .25645 Mdot
.63421 .2565 Mdot
.63463 .25683 Mdot
.63505 .25717 Mdot
.63535 .2574 Mdot
.63589 .25783 Mdot
.63601 .25793 Mdot
.63634 .25819 Mdot
.63638 .25822 Mdot
.63667 .25845 Mdot
.63707 .25878 Mdot
.63748 .2591 Mdot
.63768 .25926 Mdot
.63803 .25954 Mdot
.63838 .25982 Mdot
.63868 .26005 Mdot
.63904 .26035 Mdot
.63956 .26076 Mdot
.63966 .26084 Mdot
.64016 .26124 Mdot
.64026 .26132 Mdot
.64048 .26149 Mdot
.64098 .26189 Mdot
.64133 .26217 Mdot
.64144 .26227 Mdot
.64205 .26276 Mdot
.64233 .26298 Mdot
.64251 .26313 Mdot
.64269 .26326 Mdot
.643 .26352 Mdot
.6435 .26392 Mdot
.64376 .26413 Mdot
.64384 .26419 Mdot
.64448 .26471 Mdot
.64465 .26485 Mdot
.64506 .26517 Mdot
.64578 .26575 Mdot
.64596 .2659 Mdot
.64607 .26599 Mdot
.64659 .26641 Mdot
.64671 .2665 Mdot
.64711 .26683 Mdot
.64714 .26686 Mdot
.64736 .26703 Mdot
.64795 .26751 Mdot
.64852 .26797 Mdot
.64898 .26835 Mdot
.64913 .26846 Mdot
.64946 .26874 Mdot
.64979 .269 Mdot
.64984 .26904 Mdot
.65032 .26944 Mdot
.65041 .26951 Mdot
.65095 .26995 Mdot
.6511 .27007 Mdot
.65121 .27016 Mdot
.65144 .27034 Mdot
.65165 .27052 Mdot
.65204 .27084 Mdot
.6522 .27097 Mdot
.65261 .2713 Mdot
.65291 .27154 Mdot
.65322 .27179 Mdot
.65351 .27203 Mdot
.65388 .27233 Mdot
.65415 .27255 Mdot
.65448 .27282 Mdot
.65475 .27305 Mdot
.6551 .27333 Mdot
.65541 .27359 Mdot
.65566 .2738 Mdot
.65626 .27428 Mdot
.6563 .27432 Mdot
.65686 .27478 Mdot
.6571 .27498 Mdot
.65731 .27515 Mdot
.65753 .27533 Mdot
.65822 .2759 Mdot
.65844 .27608 Mdot
.65895 .2765 Mdot
.65935 .27683 Mdot
.65951 .27696 Mdot
.65977 .27717 Mdot
.66012 .27746 Mdot
.6605 .27778 Mdot
.66065 .2779 Mdot
.66117 .27833 Mdot
.66147 .27858 Mdot
.66169 .27876 Mdot
.66205 .27906 Mdot
.66228 .27925 Mdot
.66231 .27928 Mdot
.66305 .27989 Mdot
.66315 .27997 Mdot
.66347 .28023 Mdot
.66363 .28037 Mdot
.66399 .28067 Mdot
.66417 .28082 Mdot
.66432 .28094 Mdot
.66485 .28138 Mdot
.66514 .28163 Mdot
.66546 .28189 Mdot
.66583 .2822 Mdot
.66604 .28237 Mdot
.66659 .28284 Mdot
.66687 .28307 Mdot
.66713 .28328 Mdot
.66742 .28353 Mdot
.66807 .28407 Mdot
.66829 .28425 Mdot
.6684 .28435 Mdot
.66854 .28446 Mdot
.66911 .28494 Mdot
.66917 .28499 Mdot
.66938 .28516 Mdot
.66948 .28525 Mdot
.66988 .28559 Mdot
.67026 .28591 Mdot
.67103 .28655 Mdot
.67142 .28688 Mdot
.67153 .28697 Mdot
.67192 .2873 Mdot
.67233 .28764 Mdot
.67286 .28809 Mdot
.67308 .28828 Mdot
.67319 .28837 Mdot
.67349 .28862 Mdot
.67398 .28903 Mdot
.67425 .28926 Mdot
.67433 .28933 Mdot
.67484 .28976 Mdot
.67504 .28993 Mdot
.67517 .29004 Mdot
.67565 .29045 Mdot
.67591 .29067 Mdot
.67623 .29094 Mdot
.67648 .29114 Mdot
.67674 .29137 Mdot
.67714 .2917 Mdot
.67738 .29191 Mdot
.67769 .29217 Mdot
.67806 .29249 Mdot
.67833 .29271 Mdot
.67877 .29309 Mdot
.67906 .29333 Mdot
.6792 .29346 Mdot
.67936 .29359 Mdot
.67987 .29402 Mdot
.68002 .29416 Mdot
.68065 .29469 Mdot
.68082 .29483 Mdot
.68116 .29512 Mdot
.68127 .29522 Mdot
.68174 .29562 Mdot
.6822 .29602 Mdot
.68249 .29626 Mdot
.68265 .2964 Mdot
.68307 .29676 Mdot
.68338 .29702 Mdot
.68391 .29748 Mdot
.68435 .29785 Mdot
.68466 .29812 Mdot
.68489 .29831 Mdot
.68524 .29862 Mdot
.68564 .29896 Mdot
.68587 .29916 Mdot
.68626 .29949 Mdot
.68654 .29974 Mdot
.68678 .29994 Mdot
.68709 .30021 Mdot
.68753 .30059 Mdot
.68756 .30062 Mdot
.68814 .30112 Mdot
.68842 .30135 Mdot
.68862 .30153 Mdot
.68875 .30164 Mdot
.68922 .30205 Mdot
.68955 .30233 Mdot
.68977 .30252 Mdot
.68995 .30268 Mdot
.69029 .30297 Mdot
.69044 .3031 Mdot
.69061 .30324 Mdot
.69091 .30351 Mdot
.69117 .30373 Mdot
.69147 .30399 Mdot
.69154 .30405 Mdot
.69202 .30447 Mdot
.69277 .30512 Mdot
.69294 .30526 Mdot
.69333 .30561 Mdot
.69363 .30586 Mdot
.69384 .30605 Mdot
.69445 .30658 Mdot
.69465 .30676 Mdot
.69476 .30685 Mdot
.69494 .30701 Mdot
.69507 .30712 Mdot
.69546 .30746 Mdot
.69553 .30752 Mdot
.69602 .30795 Mdot
.69613 .30805 Mdot
.69642 .3083 Mdot
.69662 .30847 Mdot
.69689 .30871 Mdot
.69719 .30897 Mdot
.69725 .30902 Mdot
.6977 .30941 Mdot
.69803 .3097 Mdot
.69812 .30978 Mdot
.69851 .31012 Mdot
.69886 .31043 Mdot
.69915 .31068 Mdot
.69934 .31085 Mdot
.69951 .311 Mdot
.69981 .31126 Mdot
.70009 .31151 Mdot
.70048 .31185 Mdot
.70085 .31218 Mdot
.70116 .31245 Mdot
.70142 .31268 Mdot
.70182 .31303 Mdot
.70216 .31333 Mdot
.70279 .31388 Mdot
.70297 .31405 Mdot
.70332 .31435 Mdot
.70383 .3148 Mdot
.70418 .31511 Mdot
.70458 .31546 Mdot
.70462 .3155 Mdot
.70524 .31604 Mdot
.70552 .3163 Mdot
.70584 .31658 Mdot
.70658 .31724 Mdot
.70673 .31736 Mdot
.70687 .31749 Mdot
.70733 .3179 Mdot
.70764 .31817 Mdot
.7079 .31841 Mdot
.70815 .31862 Mdot
.70841 .31886 Mdot
.70874 .31915 Mdot
.70899 .31938 Mdot
.70921 .31957 Mdot
.7098 .32009 Mdot
.70997 .32024 Mdot
.7102 .32045 Mdot
.71045 .32067 Mdot
.71074 .32093 Mdot
.71107 .32123 Mdot
.71143 .32154 Mdot
.71173 .32181 Mdot
.71197 .32203 Mdot
.71215 .32219 Mdot
.71277 .32274 Mdot
.71289 .32285 Mdot
.71334 .32325 Mdot
.71367 .32355 Mdot
.71411 .32394 Mdot
.71426 .32408 Mdot
.71488 .32463 Mdot
.71518 .3249 Mdot
.71526 .32497 Mdot
.71554 .32522 Mdot
.71602 .32566 Mdot
.71608 .32571 Mdot
.7166 .32618 Mdot
.71693 .32647 Mdot
.71713 .32666 Mdot
.71752 .32701 Mdot
.71758 .32706 Mdot
.71807 .3275 Mdot
.71828 .32769 Mdot
.71842 .32782 Mdot
.71862 .328 Mdot
.71886 .32821 Mdot
.71915 .32847 Mdot
.71935 .32866 Mdot
.71957 .32885 Mdot
.71996 .32921 Mdot
.72001 .32925 Mdot
.72037 .32958 Mdot
.72062 .3298 Mdot
.72119 .33032 Mdot
.72134 .33045 Mdot
.72166 .33075 Mdot
.7221 .33114 Mdot
.72228 .33131 Mdot
.72281 .33179 Mdot
.72316 .3321 Mdot
.72357 .33247 Mdot
.72419 .33304 Mdot
.72427 .33311 Mdot
.72472 .33352 Mdot
.72488 .33367 Mdot
.72505 .33383 Mdot
.72547 .3342 Mdot
.72609 .33477 Mdot
.72655 .33519 Mdot
.7268 .33542 Mdot
.72714 .33573 Mdot
.72729 .33586 Mdot
.7277 .33624 Mdot
.72829 .33678 Mdot
.72845 .33692 Mdot
.7285 .33697 Mdot
.72887 .3373 Mdot
.72917 .33758 Mdot
.72963 .33801 Mdot
.72996 .3383 Mdot
.73025 .33858 Mdot
.73084 .33912 Mdot
.73093 .33919 Mdot
.73143 .33966 Mdot
.73163 .33983 Mdot
.73198 .34016 Mdot
.73232 .34048 Mdot
.73244 .34059 Mdot
.73287 .34098 Mdot
.73316 .34124 Mdot
.73354 .34159 Mdot
.73389 .34192 Mdot
.73406 .34208 Mdot
.73458 .34256 Mdot
.7348 .34276 Mdot
.735 .34295 Mdot
.73565 .34354 Mdot
.73576 .34364 Mdot
.73613 .34398 Mdot
.73644 .34427 Mdot
.73678 .34458 Mdot
.73735 .34512 Mdot
.73767 .34541 Mdot
.73796 .34568 Mdot
.73829 .34599 Mdot
.73832 .34601 Mdot
.7387 .34636 Mdot
.73915 .34679 Mdot
.73957 .34718 Mdot
.73971 .3473 Mdot
.74014 .3477 Mdot
.74061 .34814 Mdot
.7412 .34869 Mdot
.74138 .34885 Mdot
.74175 .3492 Mdot
.74202 .34945 Mdot
.74225 .34967 Mdot
.74241 .34982 Mdot
.74255 .34995 Mdot
.74315 .35051 Mdot
.74359 .35092 Mdot
.74373 .35105 Mdot
.74428 .35156 Mdot
.74444 .35172 Mdot
.74488 .35212 Mdot
.74516 .35239 Mdot
.74549 .35269 Mdot
.74603 .3532 Mdot
.74621 .35337 Mdot
.74639 .35354 Mdot
.74675 .35387 Mdot
.74723 .35433 Mdot
.74744 .35452 Mdot
.74752 .3546 Mdot
.7478 .35486 Mdot
.74813 .35517 Mdot
.74869 .3557 Mdot
.74904 .35603 Mdot
.7492 .35618 Mdot
.74946 .35642 Mdot
.74975 .3567 Mdot
.75029 .3572 Mdot
.75058 .35748 Mdot
.75094 .35782 Mdot
.75104 .35791 Mdot
.75174 .35858 Mdot
.75188 .35871 Mdot
.75226 .35907 Mdot
.75274 .35952 Mdot
.75308 .35984 Mdot
.75322 .35997 Mdot
.75397 .36068 Mdot
.7542 .3609 Mdot
.75471 .36138 Mdot
.75518 .36183 Mdot
.75581 .36243 Mdot
.75609 .3627 Mdot
.75638 .36297 Mdot
.75673 .3633 Mdot
.75707 .36363 Mdot
.75729 .36384 Mdot
.7576 .36413 Mdot
.75779 .36432 Mdot
.75816 .36467 Mdot
.75852 .36502 Mdot
.7587 .36518 Mdot
.75907 .36554 Mdot
.7593 .36576 Mdot
.75982 .36625 Mdot
.76015 .36657 Mdot
.7605 .3669 Mdot
.76101 .36739 Mdot
.76114 .36751 Mdot
.76147 .36783 Mdot
.76179 .36814 Mdot
.76213 .36846 Mdot
.76251 .36883 Mdot
.76277 .36907 Mdot
.76309 .36938 Mdot
.76373 .36999 Mdot
.76396 .37022 Mdot
.76427 .37051 Mdot
.76471 .37093 Mdot
.76482 .37104 Mdot
.76529 .37149 Mdot
.7656 .3718 Mdot
.76606 .37224 Mdot
.76615 .37233 Mdot
.76639 .37255 Mdot
.76666 .37282 Mdot
.76685 .37299 Mdot
.76729 .37342 Mdot
.76748 .37361 Mdot
.76757 .37369 Mdot
.76797 .37408 Mdot
.76847 .37457 Mdot
.76872 .3748 Mdot
.76888 .37495 Mdot
.76909 .37516 Mdot
.76959 .37564 Mdot
.76981 .37586 Mdot
.77055 .37657 Mdot
.77091 .37693 Mdot
.77126 .37727 Mdot
.77154 .37753 Mdot
.77178 .37777 Mdot
.77214 .37812 Mdot
.77225 .37823 Mdot
.7724 .37837 Mdot
.77279 .37875 Mdot
.77323 .37918 Mdot
.77374 .37968 Mdot
.77438 .3803 Mdot
.77458 .38049 Mdot
.7747 .38061 Mdot
.77516 .38106 Mdot
.77535 .38124 Mdot
.77589 .38177 Mdot
.77638 .38225 Mdot
.7769 .38276 Mdot
.77706 .38291 Mdot
.77734 .38319 Mdot
.7777 .38354 Mdot
.77789 .38373 Mdot
.7785 .38433 Mdot
.77853 .38435 Mdot
.77904 .38485 Mdot
.77938 .38519 Mdot
.77961 .38541 Mdot
.77997 .38577 Mdot
.78043 .38621 Mdot
.78058 .38636 Mdot
.78136 .38713 Mdot
.78145 .38721 Mdot
.78178 .38754 Mdot
.78217 .38793 Mdot
.78233 .38808 Mdot
.78258 .38833 Mdot
.78286 .38861 Mdot
.78307 .38882 Mdot
.78358 .38931 Mdot
.78363 .38937 Mdot
.78426 .38998 Mdot
.78436 .39009 Mdot
.78491 .39063 Mdot
.78508 .3908 Mdot
.78563 .39134 Mdot
.78635 .39205 Mdot
.78652 .39221 Mdot
.78657 .39227 Mdot
.78704 .39273 Mdot
.78718 .39288 Mdot
.78751 .3932 Mdot
.78796 .39365 Mdot
.7881 .39379 Mdot
.7886 .39428 Mdot
.78907 .39474 Mdot
.78936 .39503 Mdot
.7897 .39538 Mdot
.79008 .39575 Mdot
.79045 .39612 Mdot
.79085 .39652 Mdot
.79105 .39671 Mdot
.7913 .39697 Mdot
.79174 .3974 Mdot
.792 .39767 Mdot
.79224 .39791 Mdot
.79231 .39798 Mdot
.79254 .3982 Mdot
.79311 .39877 Mdot
.79334 .399 Mdot
.79352 .39918 Mdot
.79381 .39947 Mdot
.79423 .39989 Mdot
.79459 .40025 Mdot
.79493 .40059 Mdot
.79523 .40089 Mdot
.79573 .40139 Mdot
.79601 .40167 Mdot
.79624 .4019 Mdot
.79647 .40214 Mdot
.79655 .40221 Mdot
.79681 .40248 Mdot
.79713 .40279 Mdot
.79761 .40327 Mdot
.79783 .4035 Mdot
.798 .40367 Mdot
.79849 .40416 Mdot
.79895 .40462 Mdot
.79937 .40504 Mdot
.79962 .40529 Mdot
.79992 .4056 Mdot
.80028 .40596 Mdot
.80057 .40625 Mdot
.80074 .40643 Mdot
.80081 .4065 Mdot
.8011 .40679 Mdot
.80153 .40722 Mdot
.80217 .40787 Mdot
.80221 .40791 Mdot
.80288 .40858 Mdot
.80326 .40897 Mdot
.80354 .40925 Mdot
.80386 .40958 Mdot
.80439 .41012 Mdot
.80459 .41032 Mdot
.80487 .41061 Mdot
.80536 .4111 Mdot
.80577 .41152 Mdot
.80596 .41171 Mdot
.80623 .41198 Mdot
.80687 .41263 Mdot
.80728 .41305 Mdot
.8075 .41327 Mdot
.8078 .41358 Mdot
.80798 .41376 Mdot
.80821 .414 Mdot
.80857 .41436 Mdot
.80873 .41453 Mdot
.80926 .41506 Mdot
.80942 .41523 Mdot
.80983 .41564 Mdot
.81023 .41605 Mdot
.81083 .41667 Mdot
.81118 .41702 Mdot
.81152 .41737 Mdot
.81184 .4177 Mdot
.81193 .41779 Mdot
.81237 .41825 Mdot
.81266 .41854 Mdot
.81315 .41904 Mdot
.81353 .41943 Mdot
.81367 .41957 Mdot
.81391 .41982 Mdot
.81426 .42018 Mdot
.81468 .42061 Mdot
.81482 .42075 Mdot
.81539 .42134 Mdot
.81566 .42162 Mdot
.8158 .42176 Mdot
.81614 .4221 Mdot
.8162 .42217 Mdot
.81661 .42259 Mdot
.81707 .42307 Mdot
.81748 .42349 Mdot
.8178 .42382 Mdot
.818 .42402 Mdot
.81823 .42426 Mdot
.81844 .42448 Mdot
.81862 .42467 Mdot
.81913 .42519 Mdot
.81941 .42548 Mdot
.81999 .42608 Mdot
.82029 .42639 Mdot
.82038 .42649 Mdot
.82078 .42689 Mdot
.82107 .42719 Mdot
.82143 .42757 Mdot
.82196 .42811 Mdot
.82248 .42865 Mdot
.8226 .42878 Mdot
.82284 .42903 Mdot
.82323 .42943 Mdot
.82344 .42965 Mdot
.82382 .43005 Mdot
.82428 .43052 Mdot
.82453 .43078 Mdot
.82496 .43123 Mdot
.8252 .43148 Mdot
.82546 .43175 Mdot
.82585 .43216 Mdot
.82606 .43238 Mdot
.82643 .43276 Mdot
.82685 .4332 Mdot
.82704 .43339 Mdot
.82739 .43376 Mdot
.82788 .43427 Mdot
.82808 .43448 Mdot
.82812 .43452 Mdot
.8285 .43492 Mdot
.82865 .43507 Mdot
.82908 .43552 Mdot
.82933 .43578 Mdot
.82972 .4362 Mdot
.83011 .4366 Mdot
.8303 .4368 Mdot
.83056 .43707 Mdot
.83086 .43738 Mdot
.83136 .43791 Mdot
.83193 .4385 Mdot
.83196 .43854 Mdot
.83239 .43899 Mdot
.8327 .43932 Mdot
.83301 .43965 Mdot
.83337 .44002 Mdot
.83381 .44049 Mdot
.83391 .44058 Mdot
.8345 .44121 Mdot
.83459 .4413 Mdot
.83522 .44197 Mdot
.8355 .44226 Mdot
.83566 .44242 Mdot
.83598 .44276 Mdot
.83626 .44306 Mdot
.83669 .44352 Mdot
.83713 .44398 Mdot
.83747 .44434 Mdot
.83772 .4446 Mdot
.83812 .44503 Mdot
.83834 .44526 Mdot
.83857 .4455 Mdot
.83878 .44572 Mdot
.83899 .44595 Mdot
.83914 .44611 Mdot
.83931 .44628 Mdot
.83954 .44652 Mdot
.83999 .447 Mdot
.84 .44701 Mdot
.84043 .44747 Mdot
.8405 .44754 Mdot
.8411 .44818 Mdot
.84126 .44835 Mdot
.8419 .44903 Mdot
.8421 .44924 Mdot
.84238 .44954 Mdot
.8426 .44977 Mdot
.84303 .45023 Mdot
.8431 .4503 Mdot
.8432 .45041 Mdot
.8438 .45105 Mdot
.84414 .45141 Mdot
.84478 .45209 Mdot
.84499 .45231 Mdot
.84534 .45269 Mdot
.84561 .45298 Mdot
.84611 .45351 Mdot
.84666 .4541 Mdot
.84697 .45443 Mdot
.84721 .45468 Mdot
.84739 .45488 Mdot
.84782 .45534 Mdot
.84803 .45556 Mdot
.8482 .45575 Mdot
.84826 .45581 Mdot
.84876 .45634 Mdot
.84895 .45655 Mdot
.84934 .45697 Mdot
.84961 .45725 Mdot
.84983 .45749 Mdot
.84999 .45766 Mdot
.85016 .45785 Mdot
.85075 .45847 Mdot
.85115 .45891 Mdot
.85156 .45935 Mdot
.85178 .45958 Mdot
.85204 .45986 Mdot
.85234 .46019 Mdot
.85269 .46056 Mdot
.853 .46089 Mdot
.85365 .46159 Mdot
.85381 .46177 Mdot
.85438 .46238 Mdot
.85468 .46271 Mdot
.85493 .46298 Mdot
.8552 .46326 Mdot
.85567 .46377 Mdot
.85593 .46406 Mdot
.85621 .46436 Mdot
.8566 .46477 Mdot
.85673 .46492 Mdot
.85701 .46522 Mdot
.85723 .46546 Mdot
.85744 .46569 Mdot
.85784 .46612 Mdot
.85804 .46633 Mdot
.85823 .46655 Mdot
.85858 .46692 Mdot
.85908 .46747 Mdot
.85952 .46794 Mdot
.85991 .46836 Mdot
.85997 .46842 Mdot
.86026 .46875 Mdot
.86048 .46898 Mdot
.86097 .46951 Mdot
.86125 .46982 Mdot
.86149 .47008 Mdot
.86187 .4705 Mdot
.86209 .47073 Mdot
.86232 .47099 Mdot
.86272 .47142 Mdot
.86295 .47166 Mdot
.8634 .47216 Mdot
.86387 .47266 Mdot
.86402 .47283 Mdot
.86445 .47331 Mdot
.86481 .47369 Mdot
.86512 .47404 Mdot
.86532 .47425 Mdot
.86583 .47481 Mdot
.86638 .47541 Mdot
.86649 .47553 Mdot
.86677 .47584 Mdot
.86726 .47637 Mdot
.86736 .47648 Mdot
.8677 .47686 Mdot
.86807 .47726 Mdot
.86846 .47769 Mdot
.86869 .47794 Mdot
.8691 .47839 Mdot
.86931 .47862 Mdot
.86947 .4788 Mdot
.86986 .47922 Mdot
.87007 .47945 Mdot
.87021 .47961 Mdot
.87052 .47995 Mdot
.87077 .48023 Mdot
.87121 .48071 Mdot
.87164 .48118 Mdot
.87175 .48131 Mdot
.87211 .4817 Mdot
.87288 .48254 Mdot
.87311 .4828 Mdot
.87334 .48305 Mdot
.87345 .48318 Mdot
.87376 .48352 Mdot
.87403 .48382 Mdot
.87466 .48451 Mdot
.8748 .48466 Mdot
.87524 .48516 Mdot
.87555 .48549 Mdot
.87588 .48586 Mdot
.87599 .48598 Mdot
.87643 .48647 Mdot
.87665 .48671 Mdot
.87721 .48733 Mdot
.87743 .48757 Mdot
.87768 .48785 Mdot
.8779 .48809 Mdot
.87813 .48835 Mdot
.87865 .48892 Mdot
.87881 .48911 Mdot
.87905 .48937 Mdot
.87955 .48992 Mdot
.87969 .49008 Mdot
.87996 .49038 Mdot
.88024 .49069 Mdot
.88035 .49082 Mdot
.88057 .49105 Mdot
.88116 .49171 Mdot
.88127 .49183 Mdot
.88153 .49213 Mdot
.88201 .49266 Mdot
.88221 .49289 Mdot
.88238 .49308 Mdot
.88302 .49379 Mdot
.88342 .49423 Mdot
.88351 .49433 Mdot
.8839 .49476 Mdot
.88433 .49525 Mdot
.88443 .49536 Mdot
.88494 .49593 Mdot
.88511 .49612 Mdot
.88557 .49664 Mdot
.88599 .4971 Mdot
.88629 .49744 Mdot
.88658 .49777 Mdot
.88716 .49842 Mdot
.88728 .49855 Mdot
.88778 .49911 Mdot
.88794 .49929 Mdot
.88826 .49964 Mdot
.88836 .49977 Mdot
.88894 .50041 Mdot
.88906 .50055 Mdot
.88961 .50117 Mdot
.88987 .50145 Mdot
.89012 .50174 Mdot
.89044 .5021 Mdot
.89081 .50251 Mdot
.89109 .50283 Mdot
.89135 .50312 Mdot
.89158 .50338 Mdot
.89206 .50392 Mdot
.89246 .50438 Mdot
.8925 .50442 Mdot
.89286 .50483 Mdot
.89297 .50495 Mdot
.89334 .50536 Mdot
.89389 .50598 Mdot
.89415 .50628 Mdot
.89446 .50663 Mdot
.89481 .50703 Mdot
.8952 .50747 Mdot
.89552 .50783 Mdot
.89568 .50801 Mdot
.89617 .50856 Mdot
.89658 .50903 Mdot
.89684 .50933 Mdot
.89731 .50985 Mdot
.89752 .51009 Mdot
.89785 .51047 Mdot
.89819 .51085 Mdot
.89838 .51107 Mdot
.89879 .51153 Mdot
.89923 .51203 Mdot
.89942 .51225 Mdot
.89961 .51246 Mdot
.89994 .51284 Mdot
.90036 .51331 Mdot
.90082 .51384 Mdot
.90104 .51409 Mdot
.9014 .5145 Mdot
.90188 .51505 Mdot
.90217 .51538 Mdot
.90248 .51573 Mdot
.9027 .51599 Mdot
.90316 .51651 Mdot
.90363 .51705 Mdot
.90385 .5173 Mdot
.90391 .51737 Mdot
.90419 .51769 Mdot
.90454 .51809 Mdot
.90518 .51882 Mdot
.90526 .51891 Mdot
.90558 .51927 Mdot
.90592 .51966 Mdot
.90638 .52019 Mdot
.90648 .5203 Mdot
.90701 .52091 Mdot
.90711 .52103 Mdot
.90772 .52173 Mdot
.90818 .52225 Mdot
.90834 .52244 Mdot
.90851 .52263 Mdot
.90874 .52289 Mdot
.90925 .52349 Mdot
.9095 .52377 Mdot
.90983 .52415 Mdot
.90987 .5242 Mdot
.91035 .52475 Mdot
.91071 .52516 Mdot
.91103 .52553 Mdot
.91145 .52602 Mdot
.91178 .52639 Mdot
.912 .52664 Mdot
.91217 .52685 Mdot
.91247 .52719 Mdot
.91282 .52759 Mdot
.91327 .52812 Mdot
.91342 .52828 Mdot
.91368 .52859 Mdot
.91435 .52937 Mdot
.91437 .52938 Mdot
.9146 .52965 Mdot
.91494 .53005 Mdot
.91511 .53024 Mdot
.91557 .53078 Mdot
.91566 .53088 Mdot
.91635 .53168 Mdot
.91665 .53202 Mdot
.91687 .53227 Mdot
.91724 .53271 Mdot
.91772 .53327 Mdot
.91785 .53341 Mdot
.91857 .53425 Mdot
.91867 .53437 Mdot
.91916 .53493 Mdot
.91939 .53521 Mdot
.9197 .53556 Mdot
.91987 .53576 Mdot
.92028 .53624 Mdot
.92073 .53677 Mdot
.92113 .53723 Mdot
.92137 .53751 Mdot
.92177 .53798 Mdot
.92193 .53817 Mdot
.9222 .53848 Mdot
.92231 .5386 Mdot
.92254 .53887 Mdot
.92279 .53916 Mdot
.92318 .53961 Mdot
.9232 .53964 Mdot
.92357 .54007 Mdot
.92406 .54064 Mdot
.92443 .54108 Mdot
.92484 .54156 Mdot
.92527 .54206 Mdot
.92557 .54241 Mdot
.92596 .54287 Mdot
.92633 .5433 Mdot
.92658 .5436 Mdot
.9271 .54421 Mdot
.92713 .54424 Mdot
.92738 .54453 Mdot
.92746 .54463 Mdot
.92788 .54512 Mdot
.92817 .54546 Mdot
.92843 .54577 Mdot
.9288 .5462 Mdot
.92939 .54689 Mdot
.92966 .54721 Mdot
.92998 .54759 Mdot
.93006 .54768 Mdot
.93073 .54847 Mdot
.93107 .54887 Mdot
.93151 .54939 Mdot
.93185 .54979 Mdot
.93233 .55035 Mdot
.93237 .5504 Mdot
.93279 .55089 Mdot
.93301 .55115 Mdot
.93345 .55167 Mdot
.9337 .55197 Mdot
.93395 .55227 Mdot
.93445 .55285 Mdot
.93462 .55306 Mdot
.93481 .55328 Mdot
.93516 .55369 Mdot
.93539 .55397 Mdot
.9356 .55422 Mdot
.9358 .55446 Mdot
.93616 .55487 Mdot
.93638 .55514 Mdot
.93646 .55523 Mdot
.93666 .55547 Mdot
.9373 .55623 Mdot
.93746 .55641 Mdot
.93767 .55667 Mdot
.93794 .55699 Mdot
.93816 .55725 Mdot
.93876 .55796 Mdot
.939 .55825 Mdot
.9393 .55861 Mdot
.93957 .55892 Mdot
.93994 .55937 Mdot
.94001 .55945 Mdot
.9402 .55967 Mdot
.94082 .56041 Mdot
.94121 .56088 Mdot
.94157 .56131 Mdot
.94193 .56173 Mdot
.94229 .56216 Mdot
.94236 .56225 Mdot
.94286 .56284 Mdot
.94294 .56294 Mdot
.9431 .56312 Mdot
.94347 .56357 Mdot
.94401 .56422 Mdot
.9441 .56432 Mdot
.9444 .56468 Mdot
.94505 .56545 Mdot
.94516 .56559 Mdot
.94566 .56619 Mdot
.94577 .56632 Mdot
.94595 .56654 Mdot
.94646 .56714 Mdot
.94658 .56728 Mdot
.94674 .56748 Mdot
.94731 .56816 Mdot
.94786 .56882 Mdot
.9481 .56911 Mdot
.94851 .5696 Mdot
.94892 .57009 Mdot
.94914 .57036 Mdot
.94964 .57096 Mdot
.94988 .57124 Mdot
.95007 .57147 Mdot
.95041 .57188 Mdot
.95087 .57244 Mdot
.95111 .57272 Mdot
.95153 .57323 Mdot
.9517 .57344 Mdot
.95193 .57371 Mdot
.9524 .57428 Mdot
.9528 .57476 Mdot
.95323 .57528 Mdot
.95338 .57546 Mdot
.9535 .57561 Mdot
.95388 .57606 Mdot
.95416 .57641 Mdot
.95455 .57687 Mdot
.95496 .57737 Mdot
.95502 .57745 Mdot
.95559 .57813 Mdot
.95566 .57822 Mdot
.95597 .57859 Mdot
.95641 .57913 Mdot
.95667 .57944 Mdot
.95702 .57986 Mdot
.95741 .58034 Mdot
.95764 .58061 Mdot
.95806 .58112 Mdot
.95826 .58137 Mdot
.95858 .58176 Mdot
.95888 .58212 Mdot
.95916 .58245 Mdot
.9595 .58287 Mdot
.95984 .58329 Mdot
.96065 .58427 Mdot
.96103 .58473 Mdot
.96117 .5849 Mdot
.96159 .58542 Mdot
.96204 .58596 Mdot
.96263 .58668 Mdot
.96278 .58687 Mdot
.96315 .58731 Mdot
.96334 .58754 Mdot
.96402 .58837 Mdot
.96443 .58887 Mdot
.96465 .58914 Mdot
.96478 .5893 Mdot
.96529 .58992 Mdot
.9654 .59006 Mdot
.96573 .59046 Mdot
.96616 .59098 Mdot
.96643 .59132 Mdot
.96689 .59188 Mdot
.9671 .59213 Mdot
.9673 .59238 Mdot
.96772 .5929 Mdot
.96798 .59322 Mdot
.96826 .59355 Mdot
.96857 .59393 Mdot
.96863 .59402 Mdot
.96897 .59443 Mdot
.96934 .59489 Mdot
.9697 .59533 Mdot
.96994 .59562 Mdot
.97031 .59607 Mdot
.97072 .59657 Mdot
.97101 .59693 Mdot
.97124 .59721 Mdot
.97154 .59758 Mdot
.97179 .59789 Mdot
.97205 .59822 Mdot
.9722 .5984 Mdot
.9725 .59876 Mdot
.9729 .59926 Mdot
.97334 .5998 Mdot
.97355 .60006 Mdot
.97404 .60067 Mdot
.9744 .60111 Mdot
.97483 .60164 Mdot
.97489 .60171 Mdot
.97531 .60223 Mdot
.97553 .6025 Mdot
.97599 .60308 Mdot
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01474 L
.03279 .01477 L
.03527 .0148 L
.0379 .01484 L
.04262 .01494 L
.04749 .01508 L
.05205 .01523 L
.06244 .01568 L
.07305 .01629 L
.08274 .01697 L
.10458 .01895 L
.12357 .02117 L
.14429 .02413 L
.18493 .03156 L
.22406 .04074 L
.26565 .05267 L
.30571 .06629 L
.34426 .08135 L
.38527 .0995 L
.42475 .11904 L
.46273 .13973 L
.50315 .16382 L
.54206 .18901 L
.58342 .21794 L
.62326 .24791 L
.66159 .27868 L
.70238 .31352 L
.74164 .3491 L
.77939 .3852 L
.8196 .42567 L
.85828 .4666 L
.89942 .51225 L
.93905 .5583 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -141.094 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
186.313 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
196.375 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
206.438 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
213.625 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2980) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0010336) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666667) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.666645) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  AnimationDisplayTime->0.627485,
  AnimationCycleOffset->-28,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP@0
00000`3jl>H300000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP030000003j
l>H0n_3V00800000o`3jl>JL0?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2
000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000040?[`iP00000000000?[`iPH00000
1@3jl>H200000?l0n_3VW03jl>H10?ooo`00803jl>H5000000@0n_3V0P0000030?[`iPH0000000H0
n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H200000004
0?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H20000
00030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001@3jl>H000000000003jl>H0
00000080n_3V0P0000060?[`iP800000o`3jl>JL0?[`iP40oooo000P0?[`iP8000000P3jl>H20000
00<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P00
00040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H0
0P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H4000000<0n_3V100000030?[`iP@00000
0`3jl>H4000000<0n_3V00@000000?[`iP00000000000`3jl>H00`000000n_3V0?[`iP0200000?l0
n_3VW03jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V
100000000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V
0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`iP80000000<0n_3V000000000000
2@3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V00@000000?[`iP000000
00000`3jl>H400000?l0n_3VW@3jl>H10?ooo`00803jl>H200000080n_3V0P00000c0?[`iP800000
0`3jl>H00`000000n_3V0?[`iP0U0?[`iP80000000<0n_3V0000000000002P3jl>H2000000D0n_3V
0P0000050?[`iP8000001@3jl>H2000000D0n_3V0`0000030?[`iP800000o`3jl>JO0?[`iP40oooo
000O0?[`iPH00000103jl>H2000002l0n_3V1@00000X0?[`iP<00000303jl>H3000000@0n_3V0`00
00040?[`iP<00000103jl>H3000000@0n_3V0P0000030?[`iPD00000o`3jl>JL0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool003d0n_3V
1000003o0?[`i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3Vo`3jl>HG0?[`iP40oooo000P
0?[`iPH0000000D0n_3V00000000000000000?[`iP0300000080n_3V0`0000030?[`iP@000000`3j
l>H2000000040?[`iP00000000000?[`iPD000000`3jl>H<000002l0n_3V0`0000040?[`iP800000
1@3jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP800000
o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P00
00020?[`iP040000003jl>H00000000000<0n_3V00D000000?[`iP00000000000?[`iP0300000080
n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`iPD000002@3jl>H200000003
0?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`iYh0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000050?[`iP800000
0P3jl>H200000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000`0?[`iP800000
00<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103j
l>H2000000030?[`iP00000000000080n_3V0P0000040?[`iPH0000000<0n_3V0000000000000P3j
l>H200000080n_3V0P0000050?[`iPD000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000040?[`iP800000o`3jl>JN0?[`iP40oooo000R0?[`iP800000103jl>H2
000000030?[`iP00000000000080n_3V0P0000040?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP<000000P3jl>H3000000030?[`iP000000n_3V00@0n_3V0P0000030?[`iP800000<03j
l>H2000000030?[`iP000000000000T0n_3V100000030?[`iP@000000`3jl>H4000000<0n_3V1000
00030?[`iP@000001P3jl>H200000?l0n_3VW@3jl>H10?ooo`008P3jl>H2000000<0n_3V1@000002
0?[`iPD000000`3jl>H4000000<0n_3V0P0000000`3jl>H0000000000004000000030?[`iP000000
00000080n_3V100000040?[`iP800000<03jl>H2000000030?[`iP000000000000T0n_3V0P000005
0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000203jl>H200000?l0n_3VW@3jl>H1
0?ooo`008P3jl>H2000000/0n_3V0P00000R0?[`iP800000<03jl>H2000000030?[`iP0000000000
00X0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000103jl>H00`00
0000n_3V0?[`iP0200000?l0n_3VW@3jl>H10?ooo`00803jl>H6000000T0n_3V0P00000P0?[`iP@0
0000<@3jl>H3000000`0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<0
00000P3jl>H500000?l0n_3VW@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003j
l>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H010000000n_3V
0000003jl>H200000080n_3V00<000000?[`iP3jl>H00`00003o0?[`i_l0n_3V903jl>H10?ooo`00
803jl>H3000000030?[`iP00000000000080000000D0n_3V0000003jl>H000000?[`iP0300000080
n_3V00<000000?[`iP000000603jl>H500000=/0n_3V100000040?[`iP/00000103jl>H300000080
n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000@0n_3V00000000
00000000203jl>H4000000030?[`iP00000000000080n_3V100000020?[`iPD0000000L0n_3V0000
0000000000000?[`iP000000n_3V00<00000603jl>H3000000@0n_3V0P0000050?[`iP<00000103j
l>H3000000<0n_3V1P0000020?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000LP3j
l>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000@0n_3V00000000000000000P3j
l>H2000000030?[`iP000000000000T0n_3V1@0000090?[`iP800000g`3jl>H2000000@0n_3V0P00
00020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000
103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P0000000`3jl>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0
n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000030?[`iP00000000000080
n_3V00<000000?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V008000000P3jl>H200000003
0?[`iP00000000000740n_3V0@3oool00280n_3V0`00000Y0?[`iP800000gP3jl>H2000000@0n_3V
0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V
0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP800000
00D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H200000003
0?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P0000000`3jl>H0
0000000000050?[`iP8000001@3jl>H200000080n_3V0P0000000`3jl>H000000000001a0?[`iP40
oooo000R0?[`iP<000006P3jl>H5000000/0n_3V0P00003M0?[`iP@000000`3jl>H500000080n_3V
0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V
0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003j
l>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000030?[`iP000000000000D0
n_3V0P0000050?[`iP8000000P3jl>H2000000030?[`iP00000000000740n_3V0@3oool00240n_3V
0P0000000`3jl>H000000000000Z0?[`iP800000g03jl>H2000000030?[`iP000000000000D0n_3V
0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP<0
000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V
0080000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H20000
00030?[`iP000000000000<0n_3V0`0000040?[`iP<000000`3jl>H400000780n_3V0@3oool00200
n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H20000
00030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@000002
0?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`000000
0`3jl>H00000000000020?[`iP@000000P3jl>H3000000030?[`iP000000000000L000006@3jl>H2
000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
000000000000103jl>H2000000<0n_3V0P0000000`3jl>H00000000000050?[`iP8000001@3jl>H2
00000080n_3V0P00001d0?[`iP40oooo001=0?[`iP80000000<0n_3V000000000000g03jl>H20000
00030?[`iP00000000000100n_3V0P00000<0?[`iP8000008P3jl>H200000080n_3V0P00000^0?[`
iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP@000000`3jl>H2000000030?[`iP00000000000080n_3V00<000000?[`
iP3jl>H00P0000020?[`iP030000003jl>H0n_3V008000000`3jl>H2000007<0n_3V0@3oool004h0
n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000001T0
n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000;0?[`iP<00000103jl>H3000000D0
n_3V0P0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP<00000L@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`
iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?oo
o`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H000000P3jl>H0
0`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`iP0000000000
0080000000@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003j
l>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3j
l>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000H000006P3j
l>H500000080n_3V0`0000050?[`iP<00000103jl>H300000;<0n_3V0@3oool00240n_3V0P000000
0`3jl>H0000000000005000000050?[`iP00000000000000003jl>H01000000;0?[`iPD000002@3j
l>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P00
00050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000
003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V00000000
0000n_3V0P0000020?[`iP8000002`3jl>H5000000T0n_3V0P0000070?[`iP8000000`3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000002b0?[`iP40oooo000R0?[`iP<0
0000:03jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080
n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H4000001X0n_3V0P0000070?[`iP80
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000002b0?[`iP40
oooo000R0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`
iP00000000000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000
103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H00000
0000003jl>H4000000d0n_3V1@00000;0?[`iP800000103jl>H400000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000/P3jl>H10?ooo`008@3jl>H2000000030?[`
iP000000000002L0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000
1@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`
iP8000000P3jl>H2000001`0n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H30000
00<0n_3V0P0000000`3jl>H000000000002b0?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000
000000009P3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`
iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@000002
0?[`iP@00000103jl>H400000080n_3V1@0000030?[`iPD000006@3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000;80n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`
iP80000000<0n_3V000000000000403jl>H2000000`0n_3V0P00000h0?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V000000000000/P3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP80
00001P3jl>H2000000@0n_3V0P0000060?[`iP800000<@3jl>H3000000@0n_3V0`0000040?[`iP<0
0000103jl>H300000;<0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo000M0?[`iRH0oooP0P00001/0?ooh0800000103oon02000000@0oooP0P00001[0?oo
h0D00000J@3oon0500000080oooP0P0000040?ooh0800000J`3oon04000002<0oooP7P3jl>H10?oo
o`007@3jl>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon000000203oon00
10000000oooP0?ooh000001/0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon001`3o
on0010000000oooP0?ooh000001Z0?ooh0030000003oon00oooP02@0oooP7P3jl>H10?ooo`007@3j
l>HU0?ooh0040000003oon00oooP000006X0oooP00@000000?ooh03oon0000002`3oon000`000000
oooP0?ooh01Z0?ooh0030000003oon00oooP06/0oooP00<000000?ooh03oon002P3oon000`000000
oooP0?ooh01Y0?ooh0030000003oon00oooP02<0oooP7P3jl>H10?ooo`007@3jl>HU0?ooh0040000
003oon00oooP000006X0oooP00@000000?ooh03oon0000002@3oon02000006d0oooP00<000000?oo
h03oon00J`3oon000`000000oooP0?ooh0080?ooh0800000K@3oon000`000000oooP0?ooh00R0?oo
h1h0n_3V0@3oool001d0n_3V9@3oon0010000000oooP0?ooh000001Z0?ooh0040000003oon00oooP
000000T0oooP00<000000?ooh03oon00K03oon000`000000oooP0?ooh01[0?ooh0030000003oon00
oooP00P0oooP00<000000?ooh03oon00JP3oon0010000000oooP0?ooh000000S0?ooh1h0n_3V0@3o
ool001d0n_3V9P3oon02000006`0oooP0P00000:0?ooh0<00000J`3oon02000006`0oooP0P00000:
0?ooh0<00000J`3oon02000002@0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on3o00000>X00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon00
0`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`000000oooP0?ooh00D0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh00E0?oo
h0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003oon00oooP0740
oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP1@0000060?ooh0030000003oon00
oooP00P0oooP5000003o0?ooh<X0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ80oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0070?ooh2@00000o`3oon2k0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HB0?ooh0030000003oon00oooP00H0
oooP100000060?ooh08000006P000?lB00000?l0oooP[P3oon04000001P0oooP7P3jl>H10?ooo`00
7@3jl>H:0?ooh0@00000103oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP00P0oooP
6`0000080000oa800000o`3oon2Y0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HB0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon0A0<f5?a4000002P00
0?l?00000?l0oooPXP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4@3oon02
000000P0oooP00<000000?ooh03oon002@3oon0P0<f5?``000002@000?l<00000?l0oooPW03oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h2X0cHDo2`0000080000o`X00000o`3oon2F0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP<P3=QCl;000000D0003o2P00003o0?ooh940
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon0i0<f5?`T000001@000?l:00000?l0oooPS03oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh3l0cHDo200000050000o`T00000o`3o
on280?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPA@3=QCl7000000D0003o2@00003o0?ooh8<0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1:0<f5?`L000001@000?l80000
0?l0oooPO`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh4l0cHDo1`0000040000o`P00000o`3oon1k0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPD`3=QCl7000000D0003o
1`00003o0?ooh7L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon1H0<f5?`L0000010000?l600000?l0oooPM03oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh5`0cHDo1`000004
0000o`H00000o`3oon1`0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0<000002@3oon1P0<f5?`L000000`000?l600000?l0oooPJ`3oon03000001P0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPI03=QCl6000000@0003o1P00003o0?ooh6T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon1W0<f5?`L000000`000?l600000?l0oooPIP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh6/0cHDo1P0000040000o`D00000o`3o
on1S0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPKP3=QCl7000000<0003o1@00003o0?ooh600oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon1b0<f5?`H000000`000?l50000
0?l0oooPG@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh7D0cHDo1P0000020000o`H00000o`3oon1J0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPN03=QCl5000000<0003o
1P00003o0?ooh5L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon1k0<f5?`D000000`000?l600000?l0oooPE03oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh7h0cHDo1@000002
0000o`H00000o`3oon1B0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooPP@3=QCl4000000<0003o1P00003o0?ooh4l0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon240<f5?`@0
00000`000?l600000?l0oooPC03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh8L0cHDo100000030000o`D00000o`3oon1:0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPRP3=
QCl400000080003o1P00003o0?ooh4L0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP0`0000090?ooh8`0cHDo100000030000o`D00000o`3oon130?ooh0<00000603oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2?0<f5?`@000000`000?l50000
0?l0oooP@P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh0090?ooh980cHDo100000020000o`D00000o`3oon100?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPU03=QCl4000000<0003o
1@00003o0?ooh3d0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon002@3oon2F0<f5?`D000000`000?l400000?l0oooP>`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh9T0cHDo1@000002
0000o`@00000o`3oon0i0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooPV`3=QCl500000080003o1@00003o0?ooh3H0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2N0<f5?`@0
00000P000?l500000?l0oooP=03oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh:00cHDo100000020000o`D00000o`3oon0b0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPXP3=
QCl4000000<0003o1000003o0?ooh300oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon2U0<f5?`@000000P000?l400000?l0oooP;P3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h:L0cHDo100000020000o`D00000o`3oon0[0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooPZ@3=QCl400000080003o1@00003o0?ooh2T0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon2[0<f5?`@000000`000?l400000?l0oooP9`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh:h0cHDo100000020000o`@00000o`3o
on0U0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<000002@3oon2`
0<f5?`@000000P000?l400000?l0oooP8@3oon03000001P0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooP/P3=QCl400000080003o1000003o0?ooh240oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon2d0<f5?`@0
00000P000?l400000?l0oooP7`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh;H0cHDo100000020000o`@00000o`3oon0M0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP^03=
QCl400000080003o1000003o0?ooh1/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon002@3oon2j0<f5?`@000000P000?l400000?l0oooP6@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h;`0cHDo100000020000o`@00000o`3oon0G0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?oo
o`007@3jl>HK0?ooh0030000003oon00oooP00T0oooP_P3=QCl400000080003o1000003o0?ooh1D0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon300<f5?`@000000P000?l400000?l0oooP4`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh<80cHDo100000020000o`<00000o`3o
on0B0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP00T0oooPa03=QCl400000080003o0`00003o0?ooh100oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon360<f5?`@0000000<0003o0000
000000000P00003o0?ooh0h0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon002@3oon380<f5?`<000000P000?l400000?l0oooP303oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh<X0cHDo
0`0000020000o`<00000o`3oon0;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0<000002@3oon3;0<f5?`@0000000<0003o0000000000000`00003o0?ooh0H0oooP0`00
000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh<d0cHDo0`000002
0000o`@00000o`3oon070?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP00T0oooPc`3=QCl300000080003o1000003o0?ooh0D0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon3A0<f5?`<0
00000P000?l400000?l0oooP0`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh0090?ooh=<0cHDo0`0000000`000?l000000000000200000?l0oooP
0P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h0090?ooh=@0cHDo0`0000020000o`@00000o`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V6`3oon000`000000oooP0?ooh0090?ooh=H0cHDo0`0000020000o`@00000o@3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh0090?oo
h=P0cHDo0`0000020000o`@00000n`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh0090?ooh=X0cHDo0`0000000`000?l000000000000200000?X0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
2@3oon3K0<f5?`<000000P000?l400000?P0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon3M0<f5?`<000000P000?l300000?L0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon3O
0<f5?`<0000000<0003o0000000000000P00003e0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh0090?ooh>40cHDo0P0000020000
o`@00000l`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon0010000000
oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooPhP3=QCl300000080003o0`00003b0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0040000003oon00oooP0000
00L0oooP100000080?ooh>L000000P000?oX000000P0oooP1000000H0?ooh1h0n_3V0@3oool001d0
n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0>h0oooP100000000`00
0?l000000000000200000><0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?00oooP0`0000020000
o`<00000hP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HA0?ooh080
0000203oon000`000000oooP0?ooh03b0?ooh0<0000000<0003o0000000000000P00003P03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
l`3oon0300000080003o0`00003O03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00m@3oon03000000030000o`000000000000800000g@0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?L0oooP0P0000020000o`<00000g00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?P0oooP0`0000000`000?l00000000000020000
0=X0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03i0?ooh0<0000000<0003o0000000000000`00003H03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00n`3oon0200000080003o
1000003G03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o@3oon02000000030000o`000000000000<00000e@0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?h0oooP0P000002
0000o`@00000e00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP0@3oon02000000030000o`000000000000800000d`0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP0P3oon0200000080003o1000003A03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon040?ooh080000000<0003o000000000000
0P00003@03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00
003o0?ooh0D0oooP0P0000020000o`@00000cP0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon070?ooh080000000<0003o0000000000000P00003=
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon080?ooh08000000P000?l400000</0<j7:2`3oon000`000000oooP0?ooh00F0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh0X0oooP0P0000000`000?l0
00000000000200000<X0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh0/0oooP0P0000020000o`@00000b00cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP303o
on03000000030000o`000000000000800000a`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP3P3oon0200000080003o0`000036
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0?0?ooh0<0000000<0003o0000000000000P00003403>QbP/0oooP00<000000?oo
h03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0A0?ooh080
00000P000?l300000<<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh180oooP0`0000000`000?l000000000000200000<40<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh1@0oooP0P0000020000o`<00000`00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP5@3oon03000000040000o`000000
000000000;l0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh1L0oooP0P0000020000o`<00000_@0cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP603oon030000
00040000o`000000000000000;`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon0300000?l0oooP6@3oon0300000080003o0`00002j03>QbPT0oooP0`00000H0?oo
h1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh1/0oooP0`00000010000?l0
000000000000002i03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0L0?ooh0<0000000@0003o0000000000000000^00cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP7@3oon0300000080003o0`00002f03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0O0?ooh0<0000000@0003o000000000000
0000]@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000
003oon00oooP0?l0oooP803oon03000000040000o`000000000000000;@0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh240oooP
0`0000020000o`800000/`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP8`3oon03000000040000o`000000000000000;40<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh2@0oooP0`00000010000?l0000000000000002`03>QbP/0oooP00<000000?ooh03oon00
5P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0U0?ooh0<000000P00
0?l300000:h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh2L0oooP0`00000010000?l0000000000000002]03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0X
0?ooh0<0000000@0003o0000000000000000[00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3j
l>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP:@3oon0300000080003o0P00002[
03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?oo
h03oon00o`3oon0[0?ooh0<0000000<0003o000000000000ZP0cXLX;0?ooh0030000003oon00oooP
01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon0/0?ooh0<0000000@0003o00000000
00000000Z00cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon0]0?ooh0<000000P000?l200000:L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh2h0oooP100000000`000?l00000
0000002V03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon0`0?ooh0<0000000@0003o0000000000000000Y00cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP<@3o
on03000000040000o`000000000000000:<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh380oooP0`0000020000o`800000XP0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP=03oon03000000030000o`00000000000:40<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3D0oooP0`0000000`00
0?l000000000002P03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP00<000000?ooh03oon00o`3oon0f0?ooh0<000000P000?l2000009h0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3L0oooP
100000000`000?l000000000002M03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon0i0?ooh0<0000000<0003o000000000000W00c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP>P3oon03000000040000o`0000000000000009X0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3/0oooP0`000002
0000o`800000V@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooP?03oon04000000030000o`000000000009P0<j7:2`3oon000`00
0000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh3h0
oooP0`0000000`000?l000000000002G03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40
oooo000M0?[`iQ/0oooP0`00003o0?ooh3l0oooP0`0000000`000?l000000000002F03>QbPT0oooP
0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh400oooP0`00
00000`000?l000000000002E03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon110?ooh0<0000000@0003o0000000000000000T`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooP@P3oon0300000080003o0P00002B03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon140?ooh0<0000000<0003o0000
00000000T@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPA@3oon03000000030000o`00000000000900<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4H0oooP
0`0000000`000?l000000000002?03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon170?ooh0<0000000@0003o0000000000000000
S@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPB03oon03000000040000o`0000000000000008`0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh4T0oooP0`00
000010000?l0000000000000002;03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1;0?ooh080000000@0003o0000000000000000
RP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPC03oon02000000040000o`0000000000000008T0<j7:2`3oon000`000000oooP
0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V403oon05000000H0oooP00<000000?ooh03oon00o`3o
on1=0?ooh08000000P000?l2000008P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP0?l0oooPCP3oon03
000000040000o`0000000000000008H0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3o
ool001d0n_3V4P3oon000`000000oooP0?ooh0060?ooh0@00000o`3oon1>0?ooh0<0000000@0003o
0000000000000000Q@0cXLX80?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ80oooP00<00000
0?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh500oooP0`00000010000?l0000000000000
002403>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ80oooP00<00000
0?ooh03oon001P3oon000`000000oooP0?ooh03o0?ooh540oooP0`00000010000?l0000000000000
002303>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P000008
0?ooh0030000003oon00oooP0?l0oooPD`3oon02000000040000o`000000000000000880<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh5@0oooP0P00000010000?l0000000000000002103>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1E0?ooh080000000@0003o
0000000000000000P00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPEP3oon02000000040000o`0000000000000007l0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh5L0oooP0P0000020000o`800000OP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPF03oon03000000040000o`0000000000
000007`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh5T0oooP0`00000010000?l0000000000000001k03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1K0?oo
h080000000@0003o0000000000000000NP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPG03oon02000000040000o`0000000000
000007T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh5d0oooP0P00000010000?l0000000000000001h03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1N0?oo
h080000000@0003o0000000000000000M`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon1O0?ooh080000000@0003o0000000000000000MP0cXLX9
0?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1P0?oo
h080000000@0003o0000000000000000M@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH@3oon0200000080003o0P00001d03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1R0?ooh0<0000000<0003o000000000000L`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPH`3oon03000000040000
o`000000000000000740<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6@0oooP0`00000010000?l0000000000000001`03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1U0?ooh0<0000000@0003o0000000000000000K`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPI`3oon02000000040000
o`0000000000000006h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6P0oooP0P00000010000?l0000000000000001]03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1Y0?ooh080000000@0003o0000000000000000K00cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPJP3oon02000000040000
o`0000000000000006/0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6/0oooP0P00000010000?l0000000000000001Z03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon1/0?ooh080000000@0003o0000000000000000J@0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPK@3oon02000000040000
o`0000000000000006P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh6h0oooP0P00000010000?l0000000000000001W03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh6l0oooP
0P0000020000o`800000IP0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon1`0?ooh0<0000000<0003o000000000000I@0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPL@3oon03
000000030000o`000000000006@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh780oooP0`0000000`000?l000000000001S03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon1c0?ooh0<0000000<0003o000000000000HP0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPM03oon03000000030000
o`00000000000640<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh7D0oooP0`0000000`000?l000000000001P03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1f
0?ooh0<0000000<0003o000000000000G`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPM`3oon03000000030000o`0000000000
05h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh7P0oooP0`0000000`000?l000000000001M03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1i0?ooh0<00000
00<0003o000000000000G00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooPNP3oon03000000030000o`000000000005/0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh7`0oooP0P0000000`000?l000000000001J03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1l0?ooh0<0000000<0003o0000
00000000F@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<0
0000o`3oon1m0?ooh0<0000000<0003o000000000000F00cXLX90?ooh0<00000603oon0N0?[`iP40
oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon1o0?ooh080000000<0003o000000000000
E`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooPP03oon02000000030000o`000000000005H0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh800oooP0`000000
0`000?l000000000001E03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon210?ooh0<0000000<0003o000000000000E00cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooPP`3oon02000000030000o`000000000005<0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8@0oooP0P0000000`000?l00000
0000001B03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon240?ooh0<0000000<0003o000000000000D@0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPQ@3oon03
000000030000o`00000000000500<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh8H0oooP0`0000000`000?l000000000001?03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon270?ooh0<0000000<0003o000000000000CP0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPR03oon03000000030000
o`000000000004d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh8T0oooP0`0000000`000?l000000000001<03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2:
0?ooh0<0000000<0003o000000000000B`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon2;0?ooh0<0000000<0003o000000000000BP0cXLX90?oo
h0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2<0?ooh0<0
000000<0003o000000000000B@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPS@3oon03000000030000o`000000000004P0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh8h0oooP0`0000000`000?l000000000001703>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2?0?ooh0<0000000<0003o
000000000000AP0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPT03oon02000000040000o`0000000000000004D0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h940oooP0P00000010000?l0000000000000001403>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2B0?ooh080000000@0003o0000
000000000000@`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPT`3oon02000000040000o`000000000000000480<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h9@0oooP0P00000010000?l0000000000000001103>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2E0?ooh080000000@0003o0000
000000000000@00cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?oo
h0030000003oon00oooP0?l0oooPUP3oon02000000040000o`0000000000000003l0<j7:2`3oon00
0`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?oo
h9L0oooP0P00000010000?l0000000000000000n03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ00oooP100000070?ooh0030000003oon00oooP0?l0oooPV03oon020000
00030000o`000000000003h0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V403oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP0?l0oooPV@3oon0200000003
0000o`000000000003d0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
4@3oon000`000000oooP0?ooh0070?ooh0@00000o`3oon2I0?ooh003000000000?l0000000800000
?00cXLX80?ooh0@00000603oon0N0?[`iP40oooo000M0?[`iQ80oooP00<000000?ooh03oon001P3o
on000`000000oooP0?ooh03o0?ooh9/0oooP00<000000000o`0000000P00000k03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ00oooP00@000000?ooh03oon0000001`3o
on000`000000oooP0?ooh03o0?ooh9`0oooP00<000000000o`0000000P00000j03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh0030000003oon00
oooP0?l0oooPW03oon02000000040000o`0000000000000003T0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh9d0oooP0P000000
10000?l0000000000000000h03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2N0?ooh080000000@0003o0000000000000000=`0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPW`3oon02000000040000o`0000000000000003H0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:00oooP0P000000
10000?l0000000000000000e03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2Q0?ooh080000000@0003o0000000000000000=00c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPXP3oon02000000040000o`0000000000000003<0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:<0oooP0P000000
10000?l0000000000000000b03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M
0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2T0?ooh080000000@0003o0000000000000000<@0c
XLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00
oooP0?l0oooPY@3oon02000000030000o`00000000000340<j7:2`3oon000`000000oooP0?ooh00F
0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:H0oooP0P0000000`00
0?l000000000000`03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0
oooP0`00003o0?ooh:L0oooP0P0000000`000?l000000000000_03>QbPT0oooP0`00000H0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:L0oooP0`0000000`000?l00000
0000000^03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2X0?ooh080000000@0003o0000000000000000;@0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPZ@3o
on02000000040000o`0000000000000002`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:X0oooP0P00000010000?l000000000
0000000[03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2[0?ooh080000000@0003o0000000000000000:P0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[03o
on02000000040000o`0000000000000002T0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V
0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh:d0oooP0P0000000`000?l000000000
000Y03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon00o`3oon2^0?ooh080000000<0003o000000000000:00cXLX;0?ooh0030000003oon00
oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP[`3oon020000
00030000o`000000000002L0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V6`3oon000`000000oooP0?ooh03o0?ooh:l0oooP0`0000000`000?l000000000000V03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon2`0?ooh0<0000000<0003o0000000000009@0cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP/@3oon03000000030000o`00
0000000002@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon00
0`000000oooP0?ooh03o0?ooh;80oooP0`0000000`000?l000000000000S03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP0`00003o0?ooh;<0oooP0`0000000`00
0?l000000000000R03>QbPT0oooP0`00000H0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000
oooP0?ooh03o0?ooh;@0oooP0`0000000`000?l000000000000Q03>QbP/0oooP00<000000?ooh03o
on005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2e0?ooh0800000
00<0003o0000000000008@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3j
l>HK0?ooh0030000003oon00oooP0?l0oooP]P3oon02000000030000o`00000000000200<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh;L0oooP0P0000000`000?l000000000000O03>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2g0?ooh0<0000000<0003o0000
000000007P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooP^03oon03000000030000o`000000000001d0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;T0oooP
0`0000000`000?l000000000000L03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon2j0?ooh080000000@0003o0000000000000000
6`0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003o
on00oooP0?l0oooP^`3oon02000000030000o`000000000001/0<j7:2`3oon000`000000oooP0?oo
h00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;`0oooP0P000000
0`000?l000000000000J03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`
iQ/0oooP00<000000?ooh03oon00o`3oon2m0?ooh080000000<0003o0000000000006@0cXLX;0?oo
h0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0
oooP_@3oon03000000030000o`000000000001P0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0
n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh;h0oooP0`0000000`000?l00000
0000000G03>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon2o0?ooh080000000@0003o00000000000000005P0cXLX;0?ooh0030000
003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0<00000o`3oon300?ooh080000000@0
003o00000000000000005@0cXLX90?ooh0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<0
00000?ooh03oon00o`3oon310?ooh080000000<0003o0000000000005@0cXLX;0?ooh0030000003o
on00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooP`P3oon02
000000030000o`000000000001@0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool0
01d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh<<0oooP0P0000000`000?l000000000000C03>Q
bP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03o
on00o`3oon330?ooh0<0000000<0003o0000000000004P0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa03oon02000000040000
o`000000000000000140<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh<D0oooP0P00000010000?l0000000000000000@03>QbP/0
oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00
o`3oon360?ooh080000000@0003o00000000000000003`0cXLX;0?ooh0030000003oon00oooP01H0
oooP7P3jl>H10?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPa`3oon02000000030000
o`000000000000l0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3o
on000`000000oooP0?ooh03o0?ooh<P0oooP0P0000000`000?l000000000000>03>QbP/0oooP00<0
00000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon39
0?ooh080000000<0003o0000000000003@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0030000003oon00oooP0?l0oooPb@3oon02000000040000o`0000000000
000000`0<j7:2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh03o0?ooh<X0oooP0P00000010000?l0000000000000000;03>QbP/0oooP00<00000
0?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3;0?oo
h080000000@0003o00000000000000002P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H1
0?ooo`007@3jl>HK0?ooh0<00000o`3oon3<0?ooh080000000<0003o0000000000002P0cXLX90?oo
h0<00000603oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3=0?ooh080
000000<0003o0000000000002@0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`00
7@3jl>HK0?ooh0030000003oon00oooP0?l0oooPcP3oon02000000030000o`000000000000P0<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh<h0oooP0`0000000`000?l000000000000703>QbP/0oooP00<000000?ooh03oon005P3o
on0N0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3?0?ooh080000000@0003o
00000000000000001P0cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK
0?ooh0030000003oon00oooP0?l0oooPd03oon02000000040000o`0000000000000000D0<j7:2`3o
on000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o
0?ooh=40oooP0P0000000`000?l000000000000503>QbP/0oooP00<000000?ooh03oon005P3oon0N
0?[`iP40oooo000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3B0?ooh080000000<0003o0000
00000000100cXLX;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh003
0000003oon00oooP0?l0oooPd`3oon02000000030000o`000000000000<0<j7:2`3oon000`000000
oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?ooh03o0?ooh=<0oooP
0`0000000`000?l000000000000203>QbP/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon00o`3oon3D0?ooh0<0000000@0003o000000000000<j7:
2`3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`000000oooP0?oo
h03o0?ooh=D0oooP0P00000010000?l000000000000cXLX;0?ooh0030000003oon00oooP01H0oooP
7P3jl>H10?ooo`007@3jl>HA0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh=H0oooP0P00
00000`000?l000000000000;0?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>H@
0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3G0?ooh080000000<0
003o0000000000002P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V4P3oon00
0`000000oooP0?ooh0060?ooh0@00000o`3oon3F0?ooh0<0000000<0003o0000003oon001P3oon04
000001P0oooP7P3jl>H10?ooo`007@3jl>HC0?ooh0030000003oon00oooP00D0oooP00<000000?oo
h03oon00o`3oon3H0?ooh0@000002P3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0
n_3V403oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPf@3oon020000
00/0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ40oooP0P0000080?ooh003
0000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V
6`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo
000M0?[`iQ/0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01a0?ooh0030000003o
on00oooP0740oooP00<000000?ooh03oon00L@3oon000`000000oooP0?ooh01a0?ooh0030000003o
on00oooP00T0oooP00<000000?ooh03oon005P3oon0N0?[`iP40oooo000M0?[`iQ/0oooP00<00000
0?ooh03oon002@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<00000
0?ooh03oon00503oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon005@3oon000`000000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<00000
0?ooh03oon002@3oon000`000000oooP0?ooh00F0?ooh1h0n_3V0@3oool001d0n_3V6`3oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01D0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon005@3oon000`00
0000oooP0?ooh00D0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh00E0?ooh0030000003oon00oooP01@0oooP00<000000?ooh03oon00503oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP01H0oooP7P3jl>H10?ooo`007@3jl>HK0?ooh?l0
0000jP00000H0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00g03jl>H400000080n_3V200000020?[`iP@0000000L0n_3V00000000000000000?[`iP000000
n_3V00`0000000<0n_3V00000000000010000000103jl>H000000000000000080?[`iPD00000103j
l>H7000000030?[`iP000000n_3V00<000002@3jl>H500000080n_3V100000020?[`iPD000004P3j
l>H6000000H0n_3V00<000000?[`iP3jl>H0103jl>H3000000040?[`iP000000000000000>@0n_3V
0@3oool00=d0n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000030?[`iP070000003j
l>H000000000003jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V00000000
00000P3jl>H2000000030?[`iP000000000000T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`
iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP05
0?[`iP80000000<0n_3V000000000000i@3jl>H10?ooo`00g@3jl>H2000000030?[`iP0000000000
00@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H20000
0080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2
000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000`0n_3V1@0000050?[`iP8000001P3jl>H5
000000H0n_3V0`00003V0?[`iP40oooo003M0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3j
l>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0
n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000/0n_3V0P0000030?[`iP800000
0P3jl>H200000080n_3V0P00000F0?[`iP800000203jl>H00`000000n_3V0?[`iP060?[`iP<00000
iP3jl>H10?ooo`00g@3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P00
00001P3jl>H000000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000103jl>H0
00000000003jl>H2000000030?[`iP000000n_3V008000002`3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H3000000030?[`iP000000n_3V0180n_3V0P0000080?[`iP030000003jl>H0n_3V
00D0n_3V0P0000000`3jl>H000000000003U0?[`iP40oooo003M0?[`iP8000000P3jl>H200000003
0?[`iP000000000000800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080
n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000000/0
n_3V1@0000020?[`iP@000000P3jl>H3000000030?[`iP000000000001<0n_3V0P00000?0?[`iP<0
000000D0n_3V00000000000000000?[`iP0400000=l0n_3V0@3oool00=d0n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H0603jl>H200000240n_3V1000000H0?[`iP03
0000003jl>H0n_3V0=l0n_3V0@3oool00=`0n_3V1P0000040?[`iP800000;`3jl>H5000001/0n_3V
0`00000Q0?[`iP8000006@3jl>H00`000000n_3V0?[`iP3N0?[`iP40oooo003o0?[`iWP0n_3V00<0
00000?[`iP3jl>H0g@3jl>H10?ooo`00o`3jl>Ie0?[`iP040000003jl>H0n_3V00000=l0n_3V0@3o
ool00?l0n_3VMP3jl>H200000>00n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.294164, \
-2.98104, 0.00430873, 0.0139433}}]
}, Closed]]
}, Open  ]],

Cell["\<\
This is a method for obtaining a series of \"nice\" values for the number of \
intervals.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Flatten[
      Table[{2, 3, 5, 7, 10} 10\^i, {i, 0, 3}]]\), "\[IndentingNewLine]", 
    \(Drop[%, \(-3\)]\), "\[IndentingNewLine]", 
    \(\(\(RiemannSumPlot[#\^2 - 6  # + 8 &, {0, 
              3}, #] &\) /@ %;\)\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, 
      GeneratedCell]\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\[IndentingNewLine]", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[BoxData[
    \({2, 3, 5, 7, 10, 20, 30, 50, 70, 100, 200, 300, 500, 700, 1000, 2000, 
      3000, 5000, 7000, 10000}\)], "Output"],

Cell[BoxData[
    \({2, 3, 5, 7, 10, 20, 30, 50, 70, 100, 200, 300, 500, 700, 1000, 2000, 
      3000}\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .28513 L
.56682 .28513 L
.56682 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .28513 L
.56682 .28513 L
.56682 .08012 L
s
1 .894 .882 r
.56682 .08012 m
.56682 .02609 L
.97619 .02609 L
.97619 .08012 L
F
.804 .522 .247 r
.56682 .08012 m
.56682 .02609 L
.97619 .02609 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.33066 .28513 Mdot
.84381 .02609 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.71047) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.29664) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP@0
00000`3jl>H2000000@0n_3V1@0000020?[`iP<000001@3jl>H3000000@0n_3V0`0000040?[`iP@0
0000o`3jl>JS0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD00000303jl>H2000000@0n_3V0P0000040?[`iP8000001`3jl>H2000000<0n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VY03j
l>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2
000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000005`3jl>H6000000X0n_3V0P0000070?[`iP8000000P3j
l>H2000000030?[`iP00000000000080n_3V0P000000103jl>H000000000003jl>H600000?l0n_3V
X`3jl>H10?ooo`00803jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V
0000003jl>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`
iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002@3jl>H00`000000n_3V0?[`iP020000
00`0n_3V0P0000040?[`iP@000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000001@3j
l>H000000000003jl>H000000080n_3V0P00003o0?[`iZ@0n_3V0@3oool00200n_3V0P0000020?[`
iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003j
l>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
0000000000X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H00000
0?[`iP02000001P0n_3V00@000000?[`iP00000000003@3jl>H200000080n_3V0P0000000`3jl>H0
0000000000020?[`iP@000000`3jl>H4000000<0n_3V00@000000?[`iP0000000000o`3jl>JT0?[`
iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H400000003
0?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0
n_3V0`0000000`3jl>H0000000000007000001T0n_3V00@000000?[`iP00000000002P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP8000001@3jl>H20000
00D0n_3V00@000000?[`iP0000000000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H20000
03<0n_3V0P0000030?[`iP030000003jl>H0n_3V02H0n_3V0`00000:0?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000050?[`iP8000001@3jl>H30000
0?l0n_3VY03jl>H10?ooo`007`3jl>H6000000@0n_3V0P00000_0?[`iPD00000:@3jl>H2000000/0
n_3V0`0000040?[`iP<000001@3jl>H3000000@0n_3V0`0000040?[`iP800000o`3jl>JT0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
03d0n_3V1000003o0?[`i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3Vo`3jl>HG0?[`iP40
oooo000P0?[`iPH0000000D0n_3V00000000000000000?[`iP0300000080n_3V0`0000030?[`iP@0
00000`3jl>H2000000040?[`iP00000000000?[`iPD000000`3jl>H<000002l0n_3V0`0000040?[`
iP800000o`3jl>K90?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080
n_3V0P0000020?[`iP040000003jl>H00000000000<0n_3V00D000000?[`iP00000000000?[`iP03
00000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`iPD000002@3jl>H2
000000030?[`iP000000000000<0n_3V0P00003o0?[`i/T0n_3V0@3oool00280n_3V0P0000040?[`
iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000050?[`iP8000000P3jl>H20000
0080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000`0?[`iP80000000<0n_3V0000
00000000o`3jl>K>0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080
n_3V0P0000040?[`iPH0000000<0n_3V0000000000000P3jl>H200000080n_3V0P0000050?[`iPD0
00000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V000000000000o`3jl>K>0?[`iP40
oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP<000000P3jl>H3000000030?[`iP000000n_3V00@0
n_3V0P0000030?[`iP800000<03jl>H400000?l0n_3Vc`3jl>H10?ooo`008P3jl>H2000000<0n_3V
1@0000020?[`iPD000000`3jl>H4000000<0n_3V0P0000000`3jl>H0000000000004000000030?[`
iP00000000000080n_3V100000040?[`iP800000<03jl>H200000?l0n_3Vd@3jl>H10?ooo`008P3j
l>H2000000/0n_3V0P00000R0?[`iP800000<@3jl>H200000?l0n_3Vd03jl>H10?ooo`00803jl>H6
000000T0n_3V0P00000P0?[`iP@00000<P3jl>H300000?l0n_3VcP3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V
0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H1
0?ooo`009`3jl>H010000000n_3V0000003jl>H200000080n_3V00<000000?[`iP3jl>H00`00003o
0?[`i_l0n_3V903jl>H10?ooo`00803jl>H3000000030?[`iP00000000000080000000D0n_3V0000
003jl>H000000?[`iP0300000080n_3V00<000000?[`iP0000006@3jl>H300000=`0n_3V10000004
0?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V10000002
0?[`iP<0000000@0n_3V0000000000000000203jl>H4000000030?[`iP00000000000080n_3V1000
00020?[`iPD0000000L0n_3V00000000000000000?[`iP000000n_3V00<000005`3jl>H600000080
n_3V0P0000060?[`iP8000000`3jl>H600000080n_3V0`0000040?[`iP@00000103jl>H200000800
n_3V0@3oool00240n_3V0P0000000`3jl>H0000000000005000000040?[`iP000000000000000080
n_3V0P0000000`3jl>H00000000000090?[`iPD000002@3jl>H00`000000n_3V0?[`iP0200000=`0
n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000
n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02
000000T0n_3V1@00000<0?[`iP800000103jl>H2000000H0n_3V0P0000050?[`iP8000000`3jl>H2
000000030?[`iP000000000000@0n_3V0P0000050?[`iP800000P03jl>H10?ooo`008P3jl>H30000
02/0n_3V0P00003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00030?[`iP000000000000X0n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H2
00000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P00000J0?[`iP800000303jl>H2
000000D0n_3V0P0000030?[`iP80000000@0n_3V000000000000n_3V1P0000040?[`iP800000P03j
l>H10?ooo`008P3jl>H3000001X0n_3V1@00000<0?[`iP800000g03jl>H4000000<0n_3V1@000002
0?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P000002
0?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H0000000000000
0000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD00000303jl>H2000000`0n_3V0P0000050?[`iP8000000`3jl>H2000000050?[`iP00
000000000?[`iP0000000P3jl>H2000000D0n_3V0P0000200?[`iP40oooo000Q0?[`iP80000000<0
n_3V000000000000:03jl>H300000=d0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3j
l>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000
0`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000040?[`
iP00000000000?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP0200000003
0?[`iP000000n_3V008000006P3jl>H2000000d0n_3V0P0000040?[`iP8000000`3jl>H200000003
0?[`iP00000000000080n_3V00@000000?[`iP00000000001P3jl>H2000007l0n_3V0@3oool00200
n_3V0`000000103jl>H0000000000000000Y0?[`iP800000g03jl>H2000000030?[`iP0000000000
0080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H5
00000080n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`0000000`3jl>H0000000000002
0?[`iP@000000P3jl>H3000000030?[`iP000000000000L000006`3jl>H2000000d0n_3V0P000004
0?[`iP8000000`3jl>H2000000030?[`iP00000000000080n_3V00@000000?[`iP00000000001P3j
l>H2000007l0n_3V0@3oool004d0n_3V00<000000?[`iP3jl>H00P00003L0?[`iP80000000<0n_3V
000000000000403jl>H2000000`0n_3V0P00000R0?[`iP8000000P3jl>H2000002h0n_3V1000000:
0?[`iP030000003jl>H0n_3V008000000P3jl>H4000000<0n_3V0P0000000`3jl>H0000000000003
0?[`iP<000000`3jl>H00`000000n_3V0?[`iP02000007l0n_3V0@3oool004h0n_3V0`00003L0?[`
iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000001T0n_3V0`0000000`3j
l>H0000000000002000002l0n_3V0P00000:0?[`iPD00000103jl>H2000000@0n_3V0`0000050?[`
iP8000000`3jl>H5000007l0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V
000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00D000000?[`iP000000n_3V00000002
0?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H0o`3jl>Ko0?[`iR80n_3V0@3o
ool00200n_3V0`0000000`3jl>H0000000000002000000040?[`iP000000n_3V00000080n_3V00@0
00000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP0G0?[`iP<00000g03jl>H4000000@0n_3V
2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V
0`0000000`3jl>H0000000000006000001X0n_3V1@0000370?[`iP40oooo000Q0?[`iP80000000<0
n_3V0000000000001@0000001@3jl>H00000000000000000n_3V00@000002`3jl>H5000000T0n_3V
0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP800000
1@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000
n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP0000000000
0?[`iP8000000P3jl>H2000000/0n_3V1@0000090?[`iP800000bP3jl>H10?ooo`008P3jl>H30000
02P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`
iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000J0?[`iP800000b@3jl>H10?oo
o`008P3jl>H3000000T0n_3V00<000000?[`iP3jl>H03P3jl>H5000000T0n_3V0P0000000`3jl>H0
00000000003L0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0
n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V00000000
0000n_3V1000000=0?[`iPD000002`3jl>H200000<P0n_3V0@3oool00240n_3V0P0000000`3jl>H0
00000000000W0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP000000000000D0
n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H20000
00H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2
00000080n_3V0P00000L0?[`iP800000a`3jl>H10?ooo`00803jl>H3000000040?[`iP0000000000
000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H4
00000080n_3V0`000000103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3j
l>H4000000@0n_3V100000020?[`iPD000000`3jl>H5000001T0n_3V0P0000000`3jl>H000000000
00370?[`iP40oooo001=0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP000000
00000100n_3V0P00000<0?[`iP800000>03jl>H2000000030?[`iP00000000000<L0n_3V0@3oool0
04h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
0340n_3V0`0000380?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`007@3jl>HS0?ooh0800000A@3oon02000000@0oooP0P0000040?ooh0800000A03oon05
000004<0oooP1@0000020?ooh0800000103oon02000004@0oooP100000140?ooh0@000000`3oon02
000000@0oooP0P0000150?ooh08000009`3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?oo
h03oon000000@`3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP000004D0oooP
00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0070?ooh0040000003oon00oooP000004<0
oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0090?ooh0040000003oon00oooP0000
04<0oooP00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?oo
h03oon000000@`3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP04<0oooP00<0
00000?ooh03oon00A@3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP0480oooP00<0
00000?ooh03oon00A@3oon000`000000oooP0?ooh00;0?ooh0030000003oon00oooP04<0oooP00<0
00000?ooh03oon009@3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3o
on0010000000oooP0?ooh00000090?ooh0800000AP3oon000`000000oooP0?ooh0150?ooh0030000
003oon00oooP00P0oooP0P0000160?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00
203oon02000004L0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iR80oooP00@0
00000?ooh03oon000000@`3oon0010000000oooP0?ooh00000090?ooh0030000003oon00oooP04D0
oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP04<0
oooP00@000000?ooh03oon000000A03oon0010000000oooP0?ooh00000090?ooh0030000003oon00
oooP04<0oooP00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR<0oooP0P000015
0?ooh08000002P3oon03000004@0oooP0P0000160?ooh08000002P3oon03000004@0oooP0P000016
0?ooh08000002P3oon03000004@0oooP0P00000W0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`iQP0oooPo`00003Z000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh01:0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000
oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon0300000?l0oooP`@3oon0J0000o`T0oooP0`00000K0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh;T0oooP20000?lU0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP/03o
on090000obd0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon00o`3oon2V0?ooh0X0003o=P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh03o0?ooh9T0oooP0P0000030?ooh0P0003o@03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh180
oooPQP3=QCl60000ocd0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh180oooP00<0cHDo0?oTh@3oi>40O03oi>470000o`@00000
?P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP0?l0oooP4P3oon000`3=QCl0onCQ0?oTh@1g0?oTh@D0003o203o
i>42000003l0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh180oooP00<0cHDo0?oTh@3oi>40L`3oi>44
0000odh0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh03o0?ooh180oooP00<0cHDo0?oTh@3oi>40K`3oi>440000
oe80onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh03o0?ooh180oooP00<0cHDo0?oTh@3oi>40J`3oi>440000oeH0
onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh180oooP00<0cHDo0?oTh@3oi>40I`3oi>440000oeX0onCQ
00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh180oooP00<0cHDo0?oTh@3oi>40H`3oi>440000oeh0onCQ00<0
cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh03o0?ooh180oooP00<0cHDo0?oTh@3oi>40G`3oi>440000of80onCQ00<0cHDo
0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh180oooP00<0cHDo0?oTh@3oi>40F`3oi>440000ofH0onCQ00<0cHDo0?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh180oooP00<0cHDo0?oTh@3oi>40E`3oi>440000ofX0onCQ00<0cHDo0?ooh03o
on002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon0300000?l0oooP
4P3oon000`3=QCl0onCQ0?oTh@1C0?oTh@@0003oKP3oi>400`3=QCl0oooP0?ooh0070?ooh0<00000
6`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3o
i>40onCQ0500onCQ0`000?mb0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40
onCQ04d0onCQ0`000?me0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ
04X0onCQ0`000?mh0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ04P0
onCQ0P000?mk0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ04D0onCQ
0`000?mm0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ0480onCQ0`00
0?n00?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ03l0onCQ0`000?n3
0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ03`0onCQ0`000?n60?oT
h@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ03X0onCQ0P000?n90?oTh@03
0<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ03L0onCQ0`000?n;0?oTh@030<f5
?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ03D0onCQ0P000?n>0?oTh@030<f5?`3o
on00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ0380onCQ0`000?n@0?oTh@030<f5?`3oon00
oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?oo
h0030000003oon00oooP0?l0oooP4P3oon000`3=QCl0onCQ0?oTh@0_0?oTh@<0003oT`3oi>400`3=
QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh004
0000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon0B0?ooh0030<f5?`3oi>40onCQ
02d0onCQ0P000?nF0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon04000000P0oooPo`00000f0000
00<0003oV@0000080?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03o
on0000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?l0[MSV1P2]f>H00`0c
XLX0oooP0?ooh00X0?ooh080003oY`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0o`2]f>H60:gHiP0303>QbP3oon00oooP02H0oooP0P000?nY0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV0?l0[MSV1P2]f>H00`0cXLX0oooP0?ooh00T0?ooh080003oZ`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV0?l0[MSV1P2]f>H00`0cXLX0oooP0?ooh00R0?ooh080003o[@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV0?l0[MSV1P2]f>H00`0cXLX0oooP0?ooh00O0?ooh0<0003o[`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV0?l0[MSV1P2]f>H00`0cXLX0oooP0?ooh00M0?ooh080003o/P3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
0?l0[MSV1P2]f>H00`0cXLX0oooP0?ooh00K0?ooh080003o]03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?l0
[MSV1P2]f>H00`0cXLX0oooP0?ooh00I0?ooh080003o]P3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?l0[MSV
1P2]f>H00`0cXLX0oooP0?ooh00G0?ooh080003o^03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?l0[MSV1P2]
f>H00`0cXLX0oooP0?ooh00E0?ooh080003o^P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?l0[MSV1P2]f>H0
0`0cXLX0oooP0?ooh00C0?ooh080003o_03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?l0[MSV1P2]f>H00`0c
XLX0oooP0?ooh00A0?ooh080003o_P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?l0[MSV1P2]f>H00`0cXLX0
oooP0?ooh00?0?ooh080003o`03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?l0[MSV1P2]f>H00`0cXLX0oooP
0?ooh00=0?ooh080003o`P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?l0[MSV1P2]f>H00`0cXLX0oooP0?oo
h00;0?ooh080003oa03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03
000000T0oooP00<0<j7:0:gHiP2]f>H0o`2]f>H60:gHiP0303>QbP3oon00oooP00T0oooP0P000?o4
0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP3o0:gHiPH0[MSV00<0<j7:0?ooh03oon001`3oon020000olP0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP3o0:gHiPH0[MSV00<0<j7:0?ooh03oon001@3oon020000olX0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP3o0:gHiPH0[MSV00<0<j7:0?ooh03oon000`3oon020000ol`0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP3o0:gHiPH0[MSV00@0<j7:0?ooh03oon00oooP0P000?o>0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0o`2]
f>H60:gHiP0403>QbP3oon00003o0000om00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP3o0:gHiPH0[MSV0P00
0?oB0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0o`2]f>H40:gHiP80003o00<0<j7:0?ooh03oon00d@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV0?l0[MSV0P2]f>H20000o`80[MSV00<0<j7:0?ooh03oon00d@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV0?l0[MSV0P000?l40:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP3m0:gHiP80003o1P2]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0n`2]
f>H20000o`P0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?T0[MSV0P000?l:
0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP3h0:gHiP030000o`2]f>H0[MSV
00X0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0?H0[MSV0P000?l=0:gHiP03
03>QbP3oon00oooP0=40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP3d0:gHiP80003o3`2]f>H00`0cXLX0oooP
0?ooh03A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3o
on000`0cXLX0[MSV0:gHiP3b0:gHiP80003o4@2]f>H00`0cXLX0oooP0?ooh03?0?ooh0<000006`3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP3a
0:gHiP030000o`2]f>H0[MSV0140[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
0>l0[MSV0P000?lD0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP3]0:gHiP80
003o5P2]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0k02]f>H00`000?l0[MSV
0:gHiP0F0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP3Z0:gHiP80003o6@2]
f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0j02]f>H20000oa/0[MSV00<0<j7:
0?ooh03oon00d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0>H0[MSV0P000?lM0:gHiP0303>QbP3oon00oooP
0=40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP3U0:gHiP030000o`2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03o
on00d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV0><0[MSV0P000?lP0:gHiP0303>QbP3oon00oooP0=40oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP3R0:gHiP030000o`2]f>H0[MSV0200[MSV00<0<j7:0?ooh03oon00d@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV0>00[MSV0P000?lS0:gHiP0303>QbP3oon00oooP0=40oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP3N0:gHiP80003o9@2]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0g@2]f>H00`000?l0[MSV0:gHiP0U0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP3K0:gHiP80003o:02]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0fP2]
f>H00`000?l0[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV0=P0[MSV0P000?l[
0:gHiP0303>QbP3oon00oooP0<l0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0=H0[MSV0P000?l]0:gHiP0303>QbP3oon00oooP
0=40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP3E0:gHiP030000o`2]f>H0[MSV02d0[MSV00<0<j7:0?ooh03o
on00d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV0=<0[MSV0P000?l`0:gHiP0303>QbP3oon00oooP0=40oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP3B0:gHiP030000o`2]f>H0[MSV0300[MSV00<0<j7:0?ooh03oon00d@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV0=00[MSV0P000?lc0:gHiP0303>QbP3oon00oooP0=40oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP3?0:gHiP030000o`2]f>H0[MSV03<0[MSV00<0<j7:0?ooh03oon00d@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV0<h0[MSV00<0003o0:gHiP2]f>H0=02]f>H00`0cXLX0oooP0?ooh03A0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0c02]f>H20000ocL0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV0</0[MSV00<0003o0:gHiP2]f>H0=`2]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0bP2]f>H00`000?l0[MSV0:gHiP0h0:gHiP0303>QbP3oon00oooP0=40oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP380:gHiP80003o>`2]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0a`2]f>H00`000?l0[MSV0:gHiP0k0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP360:gHiP030000o`2]f>H0[MSV03`0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon04000000L0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP340:gHiP80003o?`2]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0030000003oon00oooP00P0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP330:gHiP030000o`2]f>H0[MSV03l0[MSV00<0<j7:
0?ooh03oon00d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon000`00
0000oooP0?ooh0070?ooh0@00000203oon000`0cXLX0[MSV0:gHiP320:gHiP030000o`2]f>H0[MSV
0400[MSV00<0<j7:0?ooh03oon00cP3oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh003
0000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP300:gHiP80
003o@`2]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP2o0:gHiP030000o`2]f>H0[MSV04<0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP2m0:gHiP80003oAP2]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0_02]f>H00`000?l0[MSV0:gHiP160:gHiP0303>QbP3oon00oooP0=40oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP2k0:gHiP030000o`2]f>H0[MSV04L0[MSV00<0<j7:0?ooh03oon00d@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV0;T0[MSV0P000?m:0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP2h0:gHiP030000o`2]f>H0[MSV04X0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV0;H0[MSV0P000?m=0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP2e0:gHiP030000o`2]f>H0[MSV04d0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV0;<0[MSV0P000?m@0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP2b0:gH
iP030000o`2]f>H0[MSV0500[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0;40
[MSV00<0003o0:gHiP2]f>H0D@2]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
[`2]f>H20000oe@0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0:h0[MSV00<0
003o0:gHiP2]f>H0E02]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0[02]f>H2
0000oeL0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0Z`2]f>H00`000?l0[MSV0:gHiP1G0:gH
iP0303>QbP3oon00oooP0<l0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0:X0[MSV00<0003o0:gHiP2]f>H0F02]f>H00`0cXLX0
oooP0?ooh03A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0Z02]f>H20000oe/0[MSV00<0<j7:0?ooh03oon00
d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV0:L0[MSV00<0003o0:gHiP2]f>H0F`2]f>H00`0cXLX0oooP0?oo
h03A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0YP2]f>H00`000?l0[MSV0:gHiP1L0:gHiP0303>QbP3oon00
oooP0=40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP2U0:gHiP030000o`2]f>H0[MSV05d0[MSV00<0<j7:0?oo
h03oon00d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0:<0[MSV0P000?mP0:gHiP0303>QbP3oon00oooP0=40
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP2R0:gHiP030000o`2]f>H0[MSV0600[MSV00<0<j7:0?ooh03oon00
d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV0:40[MSV00<0003o0:gHiP2]f>H0H@2]f>H00`0cXLX0oooP0?oo
h03A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0W`2]f>H20000of@0[MSV00<0<j7:0?ooh03oon00d@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV09h0[MSV00<0003o0:gHiP2]f>H0I02]f>H00`0cXLX0oooP0?ooh03A0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0W@2]f>H00`000?l0[MSV0:gHiP1U0:gHiP0303>QbP3oon00oooP0=40
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP2L0:gHiP030000o`2]f>H0[MSV06H0[MSV00<0<j7:0?ooh03oon00
d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV09X0[MSV0P000?mY0:gHiP0303>QbP3oon00oooP0=40oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP2I0:gHiP030000o`2]f>H0[MSV06T0[MSV00<0<j7:0?ooh03oon00d@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV09P0[MSV00<0003o0:gHiP2]f>H0JP2]f>H00`0cXLX0oooP0?ooh03A0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0
[MSV0:gHiP2G0:gHiP030000o`2]f>H0[MSV06/0[MSV00<0<j7:0?ooh03oon00c`3oon03000001/0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
UP2]f>H00`000?l0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP0=40oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP2E0:gHiP030000o`2]f>H0[MSV06d0[MSV00<0<j7:0?ooh03oon00d@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV0980[MSV00<000000000o`000?l0L02]f>H00`0cXLX0oooP0?ooh03A0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPU00cXLX01000
0000003o00000000001a03>Qb]<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00W@3oon0010000?l0000000000000003o0?ooh4D0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00W03oon001000
0?l0oooP00000000003o0?ooh4H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00V`3oon000`000?l0oooP0?ooh03o0?ooh4P0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00VP3oon000`000?l0
oooP0?ooh03o0?ooh4T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00V@3oon000`000?l0oooP0?ooh03o0?ooh4X0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00V03oon000`000?l0oooP0?oo
h03o0?ooh4/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon00U`3oon000`000?l0oooP0?ooh03o0?ooh4`0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00U@3oon020000ool0oooPC`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh02D0?ooh003
0000o`3oon00oooP0?l0oooPC`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh02C0?ooh0030000o`3oon00oooP0?l0oooPD03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh02B0?ooh0030000o`3o
on00oooP0?l0oooPD@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03
00000940oooP00<0003o0?ooh03oon00o`3oon1@0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00T03oon000`000?l0oooP0?ooh03o0?ooh5<0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00S`3oon000`000?l0
oooP0?ooh03o0?ooh5@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00SP3oon000`000?l0oooP0?ooh03o0?ooh5D0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00S@3oon000`000?l0oooP0?oo
h03o0?ooh5H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon00R`3oon020000ool0oooPF@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh02:0?ooh0030000o`3oon00oooP0?l0oooPF@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0290?ooh003
0000o`3oon00oooP0?l0oooPFP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0280?ooh0030000o`3oon00oooP0?l0oooPF`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0270?ooh0030000o`3o
on00oooP0?l0oooPG03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0260?ooh0030000o`3oon00oooP0?l0oooPG@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0250?ooh0030000o`3oon00oooP
0?l0oooPGP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0240?ooh0030000o`3oon00oooP0?l0oooPG`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0230?ooh0030000o`3oon00oooP0?l0oooP
H03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3`3oon03000000H0oooP00<0
00000?ooh03oon00P@3oon020000ool0oooPH`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V403oon000`000000oooP0?ooh0050?ooh0030000003oon00oooP0800oooP00<0003o
0?ooh03oon00o`3oon1S0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?oo
h0D000001P3oon04000007h0oooP00<0003o0?ooh03oon00o`3oon1Q0?ooh0@000006`3oon0N0?[`
iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh01n0?oo
h0030000o`3oon00oooP0?l0oooPI@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V3P3oon000`000000oooP000000070?ooh0030000003oon00oooP07d0oooP00<0003o0?ooh03o
on00o`3oon1V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh0800000
1`3oon000`000000oooP0?ooh01l0?ooh0030000o`3oon00oooP0?l0oooPI`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01k0?ooh0030000o`3o
on00oooP0?l0oooPJ03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh01j0?ooh0030000o`3oon00oooP0?l0oooPJ@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01i0?ooh0030000o`3oon00oooP
0?l0oooPJP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh01h0?ooh0030000o`3oon00oooP0?l0oooPJ`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01g0?ooh0030000o`3oon00oooP0?l0oooP
K03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h01f0?ooh0030000o`3oon00oooP0?l0oooPK@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh01e0?ooh0030000o`3oon00oooP0?l0oooPKP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01c0?oo
h080003oo`3oon1a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP0780oooP00<0003o0?ooh03oon00o`3oon1a0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0740oooP00<0003o0?ooh03oon00
o`3oon1b0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP0700oooP00<0003o0?ooh03oon00o`3oon1c0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP06l0oooP00<0003o0?ooh03oon00o`3oon1d
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000KP3oon000`00
0?l0oooP0?ooh03o0?ooh7<0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh01]0?ooh0030000o`3oon00oooP0?l0oooPMP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01/0?ooh0030000o`3oon00oooP0?l0oooP
M`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h01[0?ooh0030000o`3oon00oooP0?l0oooPN03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh01Z0?ooh0030000o`3oon00oooP0?l0oooPN@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01Y0?oo
h0030000o`3oon00oooP0?l0oooPNP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh01X0?ooh0030000o`3oon00oooP0?l0oooPN`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01W0?ooh0030000
o`3oon00oooP0?l0oooPO03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh01V0?ooh0030000o`3oon00oooP0?l0oooPO@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01U0?ooh0030000o`3oon00
oooP0?l0oooPOP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh01T0?ooh0030000o`3oon00oooP0?l0oooPO`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01S0?ooh0030000o`3oon00oooP0?l0
oooPP03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh01R0?ooh0030000o`3oon00oooP0?l0oooPP@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh01Q0?ooh0030000o`3oon00oooP0?l0oooPPP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01P
0?ooh0030000o`3oon00oooP0?l0oooPP`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh01O0?ooh0030000o`3oon00oooP0?l0oooPQ03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000005h0oooP00<0003o0?ooh03o
on00o`3oon230?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
G@3oon000`000?l0oooP0?ooh03o0?ooh8H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00G03oon000`000?l0oooP0?ooh03o0?ooh8L0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00F`3oon00
0`000?l0oooP0?ooh03o0?ooh8P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00FP3oon000`000?l0oooP0?ooh03o0?ooh8T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00F@3oon000`000?l0
oooP0?ooh03o0?ooh8X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00F03oon000`000?l0oooP0?ooh03o0?ooh8/0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00E`3oon000`000?l0oooP0?oo
h03o0?ooh8`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon00EP3oon000`000?l0oooP0?ooh03o0?ooh8d0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00E@3oon000`000?l0oooP0?ooh03o0?oo
h8h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on00E03oon000`000?l0oooP0?ooh03o0?ooh8l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00D`3oon000`000?l0oooP0?ooh03o0?ooh900oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00DP3o
on000`000?l0oooP0?ooh03o0?ooh940oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00D@3oon000`000?l0oooP0?ooh03o0?ooh980oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00D03oon000`00
0?l0oooP0?ooh03o0?ooh9<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00C`3oon000`000?l0oooP0?ooh03o0?ooh9@0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`00001>0?ooh0030000o`3oon00oooP0?l0oooP
T`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP04d0oooP00<0
003o0?ooh03oon00o`3oon2F0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP04`0oooP00<0003o0?ooh03oon00o`3oon2G0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP04`0oooP00<0003o0?oo
h03oon00o`3oon2G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP04/0oooP00<0003o0?ooh03oon00o`3oon2H0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP04X0oooP00<0003o0?ooh03oon00
o`3oon2I0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP04T0oooP00<0003o0?ooh03oon00o`3oon2J0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP04P0oooP00<0003o0?ooh03oon00o`3oon2K
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
04L0oooP00<0003o0?ooh03oon00o`3oon2L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP04H0oooP00<0003o0?ooh03oon00o`3oon2M0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP04D0oooP
00<0003o0?ooh03oon00o`3oon2N0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP04@0oooP00<0003o0?ooh03oon00o`3oon2O0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP04<0oooP00<0003o
0?ooh03oon00o`3oon2P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0480oooP00<0003o0?ooh03oon00o`3oon2Q0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0<00000203oon000`000000oooP0?ooh0110?ooh003
0000o`3oon00oooP0?l0oooPXP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0400oooP00<0003o0?ooh03o
on00o`3oon2S0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000
003oon00oooP000000L0oooP1000000n0?ooh0030000o`3oon00oooP0?l0oooPX@3oon04000001/0
oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0<00000203oon000`000000oooP0?ooh00n0?ooh0030000
o`3oon00oooP0?l0oooPY@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3o
on000`000000oooP0?ooh0070?ooh0030000003oon00oooP03h0oooP00<0003o0?ooh03oon00o`3o
on2U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0<000001`3oon00
0`000000oooP0?ooh00m0?ooh0030000o`3oon00oooP0?l0oooPYP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00l0?ooh0030000o`3oon00oooP
0?l0oooPY`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh00k0?ooh0030000o`3oon00oooP0?l0oooPZ03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00j0?ooh0030000o`3oon00oooP0?l0oooP
Z@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h00i0?ooh0030000o`3oon00oooP0?l0oooPZP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh00h0?ooh0030000o`3oon00oooP0?l0oooPZ`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00g0?oo
h0030000o`3oon00oooP0?l0oooP[03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh00f0?ooh0030000o`3oon00oooP0?l0oooP[@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00e0?ooh0030000
o`3oon00oooP0?l0oooP[P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh00e0?ooh0030000o`3oon00oooP0?l0oooP[P3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00d0?ooh0030000o`3oon00
oooP0?l0oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh00c0?ooh0030000o`3oon00oooP0?l0oooP/03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00b0?ooh0030000o`3oon00oooP0?l0
oooP/@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon0300000340oooP
00<0003o0?ooh03oon00o`3oon2`0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00<03oon000`000?l0oooP0?ooh03o0?ooh;<0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00;`3oon000`000?l0oooP0?ooh03o
0?ooh;@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00;P3oon000`000?l0oooP0?ooh03o0?ooh;D0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00;@3oon000`000?l0oooP0?ooh03o0?ooh;H0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
;@3oon000`000?l0oooP0?ooh03o0?ooh;H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00;03oon000`000?l0oooP0?ooh03o0?ooh;L0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00:`3oon00
0`000?l0oooP0?ooh03o0?ooh;P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00:P3oon000`000?l0oooP0?ooh03o0?ooh;T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00:@3oon000`000?l0
oooP0?ooh03o0?ooh;X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00:03oon000`000?l0oooP0?ooh03o0?ooh;/0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00:03oon000`000?l0oooP0?oo
h03o0?ooh;/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon009`3oon000`000?l0oooP0?ooh03o0?ooh;`0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon009P3oon000`000?l0oooP0?ooh03o0?oo
h;d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on009@3oon000`000?l0oooP0?ooh03o0?ooh;h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00903oon000`000?l0oooP0?ooh03o0?ooh;l0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`00000S0?ooh0030000o`3o
on00oooP0?l0oooP_P3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP02<0oooP00<0003o0?ooh03oon00o`3oon300?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0280oooP00<0003o0?ooh03oon00o`3oon310?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0240
oooP00<0003o0?ooh03oon00o`3oon320?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP0200oooP00<0003o0?ooh03oon00o`3oon330?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP01l0oooP00<0
003o0?ooh03oon00o`3oon340?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP01h0oooP00<0003o0?ooh03oon00o`3oon350?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP01h0oooP00<0003o0?oo
h03oon00o`3oon350?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP01d0oooP00<0003o0?ooh03oon00o`3oon360?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP01`0oooP00<0003o0?ooh03oon00
o`3oon370?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP01/0oooP00<0003o0?ooh03oon00o`3oon380?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP01X0oooP00<0003o0?ooh03oon00o`3oon39
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
01T0oooP00<0003o0?ooh03oon00o`3oon3:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP01T0oooP00<0003o0?ooh03oon00o`3oon3:0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP01P0oooP
00<0003o0?ooh03oon00o`3oon3;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP01L0oooP00<0003o0?ooh03oon00o`3oon3<0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000005P3oon000`000?l0oooP0?ooh03o
0?ooh</0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00E0?oo
h0030000o`3oon00oooP0?l0oooPcP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh00D0?ooh0030000o`3oon00oooP0?l0oooPc`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00C0?ooh0030000
o`3oon00oooP0?l0oooPd03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh00B0?ooh0030000o`3oon00oooP0?l0oooPd@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00B0?ooh0030000o`3oon00
oooP0?l0oooPd@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh00A0?ooh0030000o`3oon00oooP0?l0oooPdP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00@0?ooh0030000o`3oon00oooP0?l0
oooPd`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh00?0?ooh0030000o`3oon00oooP0?l0oooPe03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh00>0?ooh0030000o`3oon00oooP0?l0oooPe@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00=
0?ooh0030000o`3oon00oooP0?l0oooPeP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh00<0?ooh0030000o`3oon00oooP0?l0oooPe`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00<0?ooh003
0000o`3oon00oooP0?l0oooPe`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
3P3oon02000000P0oooP00<000000?ooh03oon002`3oon000`000?l0oooP0?ooh03o0?ooh=P0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon000000
1`3oon000`000000oooP0?ooh00:0?ooh0030000o`3oon00oooP0?l0oooPf@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0@00000
203oon000`000?l0oooP0?ooh03o0?ooh=L0oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3P3o
on02000000P0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3o
on3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon00
0`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00BP3oon000`000000
oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000
oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh?l00000jP00000K0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00d@3jl>H400000080n_3V200000020?[`iP@0000000L0n_3V
00000000000000000?[`iP000000n_3V00`0000000<0n_3V00000000000010000000103jl>H00000
0000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V00<00000203jl>H500000080
n_3V100000020?[`iPD00000303jl>H300000140n_3V0`0000060?[`iP<0000000@0n_3V00000000
000000001P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V0000000000000000f03jl>H1
0?ooo`00dP3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H2000000<0n_3V00L000000?[`
iP00000000000?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000002@3jl>H010000000n_3V0?[`iP3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V0P0000000`3jl>H000000000000?0?[`iP80
000000<0n_3V0000000000001P3jl>H2000000030?[`iP000000000000L0n_3V00<000000?[`iP3j
l>H01@3jl>H2000000030?[`iP00000000000=T0n_3V0@3oool00=80n_3V0P0000000`3jl>H00000
000000040?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V
0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000d0n_3V
0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80000000<0n_3V00000000
00001@3jl>H5000000D0n_3V0P0000000`3jl>H00000000000070?[`iP<000001P3jl>H5000000H0
n_3V0`00003J0?[`iP40oooo003B0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H00000
0000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V0000
00000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V0P00000=0?[`iP80000000<0n_3V0000000000003`3jl>H2000000030?[`iP000000
000000L0n_3V0`0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00003J0?[`iP40oooo003B0?[`
iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP0000000000
0?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP800000
00<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP<00000
00<0n_3V0000003jl>H02P3jl>H300000100n_3V100000070?[`iP80000000<0n_3V000000000000
1`3jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000f@3jl>H10?ooo`00dP3j
l>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H000000000
000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0
n_3V0000000000001`00000:0?[`iPD000000P3jl>H400000080n_3V0`0000000`3jl>H000000000
000:0?[`iP80000000<0n_3V0000000000003`3jl>H2000000P0n_3V0`000000103jl>H000000000
0000000=0?[`iP<0000000<0n_3V0000000000001@00003D0?[`iP40oooo003B0?[`iP8000000P3j
l>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V01L0n_3V0P00000J0?[`iP80000000<0
n_3V000000000000403jl>H2000002<0n_3V00<000000?[`iP3jl>H0e03jl>H10?ooo`00d@3jl>H6
000000@0n_3V0P00000_0?[`iPD000006P3jl>H3000001T0n_3V0`00000B0?[`iP<000008P3jl>H0
0`000000n_3V0?[`iP3C0?[`iP40oooo003o0?[`iX<0n_3V00<000000?[`iP3jl>H0dP3jl>H10?oo
o`00o`3jl>J00?[`iP040000003jl>H0n_3V00000=@0n_3V0@3oool00?l0n_3VP@3jl>H200000=D0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .51801 L
.24369 .51801 L
.24369 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .51801 L
.24369 .51801 L
.24369 .08012 L
s
1 .894 .882 r
.24369 .08012 m
.24369 .07834 L
.73675 .07834 L
.73675 .08012 L
F
.804 .522 .247 r
.24369 .08012 m
.24369 .07834 L
.73675 .07834 L
.73675 .08012 L
s
1 .894 .882 r
.73675 .08012 m
.73675 .02502 L
.97619 .02502 L
.97619 .08012 L
F
.804 .522 .247 r
.73675 .08012 m
.73675 .02502 L
.97619 .02502 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.09552 .51801 Mdot
.66306 .07834 Mdot
.85018 .02502 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55314) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.96012) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000@0n_3V0`0000050?[`iP<00000103jl>H3000000<0n_3V1P0000000`3jl>H0
00000000000300000?l0n_3VX`3jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V00<000000?[`iP3jl>H00P0000030?[`iP8000001P3j
l>H2000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103j
l>H2000000<0n_3V0P00003o0?[`iZH0n_3V0@3oool00200n_3V0P0000000`3jl>H0000000000004
0?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000d0n_3V0P000002
0?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000001/0n_3V0P00
000<0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00040?[`iP800000103jl>H200000?l0n_3VY@3jl>H10?ooo`00803jl>H5000000@0n_3V0P000003
0?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<00000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<00000
0`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD0
00003@3jl>H2000000X0n_3V100000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000@0n_3V0P0000050?[`iP800000o`3jl>JT0?[`iP40oooo000P0?[`iP800000
0P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP00
0000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000I0?[`iP<000002P3jl>H2000000030?[`iP00000000000080n_3V10000003
0?[`iP80000000<0n_3V000000000000103jl>H2000000H0n_3V0P00003o0?[`iZ<0n_3V0@3oool0
0200n_3V0P0000020?[`iP80000000<0n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000
000000001@0000020?[`iP@000000P3jl>H500000080n_3V1@00000:0?[`iP8000001@3jl>H30000
00030?[`iP000000000000L00000703jl>H2000000T0n_3V0P0000000`3jl>H00000000000020?[`
iP8000001@3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0n_3V0000
00000000o`3jl>JS0?[`iP40oooo000P0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP03
0000003jl>H0n_3V02D0n_3V00<000000?[`iP3jl>H00P0000090?[`iP80000000<0n_3V00000000
00000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP@000000`3jl>H200000003
0?[`iP00000000000?l0n_3VX`3jl>H10?ooo`007`3jl>H6000000@0n_3V0P00000_0?[`iPD00000
:03jl>H3000000/0n_3V0`0000050?[`iP<000000`3jl>H3000000D0n_3V0P0000040?[`iP<00000
o`3jl>JT0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool003d0n_3V1000003o0?[`i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3V
o`3jl>HG0?[`iP40oooo000P0?[`iPH0000000D0n_3V00000000000000000?[`iP0300000080n_3V
0`0000030?[`iP@000000`3jl>H2000000040?[`iP00000000000?[`iPD000000`3jl>H<000002l0
n_3V0`0000040?[`iP800000o`3jl>K90?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`
iP00000000000080n_3V0P0000020?[`iP040000003jl>H00000000000<0n_3V00D000000?[`iP00
000000000?[`iP0300000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`
iPD000002@3jl>H2000000030?[`iP000000000000<0n_3V0P00003o0?[`i/T0n_3V0@3oool00280
n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000050?[`iP80
00000P3jl>H200000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000`0?[`iP80
000000<0n_3V000000000000o`3jl>K>0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`
iP00000000000080n_3V0P0000040?[`iPH0000000<0n_3V0000000000000P3jl>H200000080n_3V
0P0000050?[`iPD000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V000000000000
o`3jl>K>0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P00
00040?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP<000000P3jl>H3000000030?[`
iP000000n_3V00@0n_3V0P0000030?[`iP800000<03jl>H400000?l0n_3Vc`3jl>H10?ooo`008P3j
l>H2000000<0n_3V1@0000020?[`iPD000000`3jl>H4000000<0n_3V0P0000000`3jl>H000000000
0004000000030?[`iP00000000000080n_3V100000040?[`iP800000<03jl>H200000?l0n_3Vd@3j
l>H10?ooo`008P3jl>H2000000/0n_3V0P00000R0?[`iP800000<@3jl>H200000?l0n_3Vd03jl>H1
0?ooo`00803jl>H6000000T0n_3V0P00000P0?[`iP@00000<P3jl>H300000?l0n_3VcP3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`
i_l0n_3V8`3jl>H10?ooo`009`3jl>H010000000n_3V0000003jl>H200000080n_3V00<000000?[`
iP3jl>H00`00003o0?[`i_l0n_3V903jl>H10?ooo`00803jl>H3000000030?[`iP00000000000080
000000D0n_3V0000003jl>H000000?[`iP0300000080n_3V00<000000?[`iP0000006@3jl>H30000
0=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H60000
0080n_3V100000020?[`iP<0000000@0n_3V0000000000000000203jl>H4000000030?[`iP000000
00000080n_3V100000020?[`iPD0000000L0n_3V00000000000000000?[`iP000000n_3V00<00000
5`3jl>H600000080n_3V0P0000050?[`iP<00000103jl>H3000000@0n_3V0`0000030?[`iPH00000
0P3jl>H4000007l0n_3V0@3oool00240n_3V0P0000000`3jl>H0000000000005000000040?[`iP00
0000000000000080n_3V0P0000000`3jl>H00000000000090?[`iPD000002@3jl>H00`000000n_3V
0?[`iP0200000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP800000
0P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3j
l>H000000?[`iP02000000T0n_3V1@00000<0?[`iP800000103jl>H2000000@0n_3V00<000000?[`
iP3jl>H00P0000020?[`iP030000003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`iP020000
00@0n_3V0P0000050?[`iP800000P03jl>H10?ooo`008P3jl>H3000002/0n_3V0P00003L0?[`iP80
0000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0
n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`
iP80000000<0n_3V0000003jl>H00P00000J0?[`iP8000003@3jl>H2000000D0n_3V0P0000050?[`
iP800000103jl>H200000080n_3V1P00001o0?[`iP40oooo000R0?[`iP<000006P3jl>H5000000`0
n_3V0P00003L0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0
n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V00000000
00002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H20000
00@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000<0?[`iP8000003@3jl>H20000
00D0n_3V0P0000050?[`iP800000103jl>H200000080n_3V00<000000?[`iP3jl>H00P0000200?[`
iP40oooo000Q0?[`iP80000000<0n_3V000000000000:03jl>H300000=d0n_3V0P0000000`3jl>H0
0000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H20000
00@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000
000000002P3jl>H3000000040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V0`000000
0`3jl>H000000?[`iP02000000030?[`iP000000n_3V008000006P3jl>H2000000X0n_3V00<00000
0?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V008000000`3jl>H3000000D0n_3V0P000003
0?[`iP040000003jl>H0000000000800n_3V0@3oool00200n_3V0`000000103jl>H0000000000000
000Y0?[`iP800000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0
n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@00000
0P3jl>H5000000/0n_3V0`0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000030?[`
iP000000000000L000006`3jl>H2000000X0n_3V100000030?[`iP@000001P3jl>H2000000@0n_3V
0P0000030?[`iP040000003jl>H0000000000800n_3V0@3oool004d0n_3V00<000000?[`iP3jl>H0
0P00003L0?[`iP80000000<0n_3V000000000000403jl>H2000000`0n_3V0P00000R0?[`iP800000
0P3jl>H2000002h0n_3V1000000:0?[`iP8000001@3jl>H2000000D0n_3V00<000000?[`iP3jl>H0
0P0000020?[`iP@00000103jl>H300000800n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3j
l>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000001T0n_3V0`0000000`3jl>H000000000
0002000002l0n_3V0P00000:0?[`iPD000000P3jl>H5000000<0n_3V0`0000050?[`iP8000001@3j
l>H200000800n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V000000000000
o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00D000000?[`iP000000n_3V000000020?[`iP040000
003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H0o`3jl>Ko0?[`iR80n_3V0@3oool00200n_3V
0`0000000`3jl>H0000000000002000000040?[`iP000000n_3V00000080n_3V00@000000?[`iP3j
l>H000000P3jl>H00`000000n_3V0?[`iP0G0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`
iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`0000000`3j
l>H0000000000006000001/0n_3V0`0000380?[`iP40oooo000Q0?[`iP80000000<0n_3V00000000
00001@0000001@3jl>H00000000000000000n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3j
l>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H20000
0080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP800000
0P3jl>H2000000/0n_3V1@0000090?[`iP030000003jl>H0n_3V00800000a`3jl>H10?ooo`008P3j
l>H3000002P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P00
00020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P00
00020?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000L0?[`iP800000a`3j
l>H10?ooo`008P3jl>H3000000T0n_3V00<000000?[`iP3jl>H03P3jl>H5000000T0n_3V0P000000
0`3jl>H000000000003L0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2
000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V
000000000000n_3V1000000=0?[`iPD00000303jl>H200000<L0n_3V0@3oool00240n_3V0P000000
0`3jl>H000000000000W0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP000000
000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103j
l>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000
003jl>H200000080n_3V0P00000J0?[`iP<00000b03jl>H10?ooo`00803jl>H3000000040?[`iP00
00000000000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000
0P3jl>H400000080n_3V0`000000103jl>H000000000003jl>H500000080n_3V100000030?[`iPD0
00000P3jl>H4000000@0n_3V100000020?[`iPD000000`3jl>H5000001`0n_3V0P0000370?[`iP40
oooo001=0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100n_3V
0P00000<0?[`iP800000>03jl>H00`000000n_3V0?[`iP0200000<L0n_3V0@3oool004h0n_3V0`00
003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H200000340n_3V0`00
00380?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
7@3jl>HS0?ooh0800000A@3oon02000000@0oooP0P0000040?ooh0800000A03oon05000004<0oooP
1@0000020?ooh0800000103oon02000004@0oooP100000140?ooh0@000000`3oon02000000@0oooP
0P0000150?ooh08000009`3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000
@`3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP000004D0oooP00<000000?oo
h03oon00A@3oon000`000000oooP0?ooh0070?ooh0040000003oon00oooP000004<0oooP00<00000
0?ooh03oon00A@3oon000`000000oooP0?ooh0090?ooh0040000003oon00oooP000004<0oooP00@0
00000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000
@`3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP04<0oooP00<000000?ooh03o
on00A@3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP0480oooP00<000000?ooh03o
on00A@3oon000`000000oooP0?ooh00;0?ooh0030000003oon00oooP04<0oooP00<000000?ooh03o
on009@3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000
oooP0?ooh00000090?ooh0800000AP3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP
00P0oooP0P0000160?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00203oon020000
04L0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03o
on000000@`3oon0010000000oooP0?ooh00000090?ooh0030000003oon00oooP04D0oooP00<00000
0?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP04<0oooP00@00000
0?ooh03oon000000A03oon0010000000oooP0?ooh00000090?ooh0030000003oon00oooP04<0oooP
00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR<0oooP0P0000150?ooh0800000
2P3oon03000004@0oooP0P0000160?ooh08000002P3oon03000004@0oooP0P0000160?ooh0800000
2P3oon03000004@0oooP0P00000W0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`iQP0
oooPo`00003Z000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01:
0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?ooh01:
0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh009
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon0300000?l0oooP`@3oon0J0000o`T0oooP0`00000K0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh03o0?ooh;T0oooP20000?lU0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP/03oon090000obd0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon2L0?ooh0800000203oon0:0000ocH0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2K0?ooh0<0000020000?m00?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPI@3oon0c
0<f5?`H0003o00<000000<f5?`3=QCl0>P3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPI@3oon000`3=QCl0onCQ0?oTh@0Y0?oT
h@L0003o103oi>42000003`0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0cHDo0?oTh@3o
i>40903oi>450000odT0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0cHDo0?oTh@3oi>40
803oi>440000odh0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0cHDo0?oTh@3oi>40703o
i>440000oe80onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0cHDo0?oTh@3oi>40603oi>44
0000oeH0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0cHDo0?oTh@3oi>40503oi>440000
oeX0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0cHDo0?oTh@3oi>40403oi>440000oeh0
onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh6D0oooP00<0cHDo0?oTh@3oi>40303oi>440000of80onCQ
00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh6D0oooP00<0cHDo0?oTh@3oi>40203oi>440000ofH0onCQ00<0
cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh03o0?ooh6D0oooP00<0cHDo0?oTh@3oi>40103oi>440000ofX0onCQ00<0cHDo
0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon030000
0?l0oooPI@3oon000`3=QCl0onCQ0?oTh@040000ofh0onCQ00<0cHDo0?ooh03oon001`3oon030000
01/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPI@3oon030000og80
onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh680oooP0`000?l00`3=QCl0onCQ0?oTh@1b0?oTh@030<f5
?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00o`3oon1O0?ooh0<0003o0`3oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3o
on00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon00o`3oon1M0?ooh080003o1P3oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3oon00
oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00o`3oon1J0?ooh0<0003o203oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3oon00oooP
00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on00o`3oon1G0?ooh0<0003o2`3oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3oon00oooP00T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon1D0?ooh0<0003o3P3oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3oon00oooP00T0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3o
on1A0?ooh0<0003o4@3oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1?
0?ooh080003o503oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3oon00oooP00T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1<0?oo
h0<0003o5P3oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1:0?ooh080
003o6@3oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon170?ooh0<0003o
6`3oon000`3=QCl0onCQ0?oTh@1b0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP0?l0oooP@@3o
on02000000040?ooh0000?l0003o0000oah0oooP00<0cHDo0?oTh@3oi>40LP3oi>400`3=QCl0oooP
0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003o
on00oooP000000L0oooP00<000000?ooh03oon00o`3oon100?ooh08000000P000?lQ0?ooh0030<f5
?`3oi>40onCQ0780onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0@00000203oon3o000003H00000
0`000?nI000000P0oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?oo
h00000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP
0?ooh0350?ooh080003o0P3oon0200000:<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00``3oon020000ojT0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh0310?ooh080003oZ`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV06P0[MSV00<0<j7:0?ooh03oon00_`3oon020000ojd0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gH
iP0303>QbP3oon00oooP0;`0oooP0`000?n_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0
oooP0?ooh02j0?ooh080003o/P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00
^03oon020000ok@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP0;H0oooP0P00
0?nf0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh02d0?ooh080003o^03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00/P3oon020000okX0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP0;00oooP0P000?nl0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
J02]f>H00`0cXLX0oooP0?ooh02^0?ooh080003o_P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0
<j7:0?ooh03oon00[03oon020000ol00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00
oooP0:X0oooP0P000?o20?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh02X0?oo
h080003oa03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0
oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh02V0?ooh080003oa03oon03000001/0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
J02]f>H00`0cXLX0oooP0?ooh02T0?ooh080003ob03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0
<j7:0?ooh03oon00XP3oon020000olX0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00
oooP0:00oooP0P000?o<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh02N0?oo
h080003ocP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00W03oon020000om00
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP09X0oooP0P000?oB0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh02H0?ooh080003oe03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV06P0[MSV00<0<j7:0?ooh03oon00UP3oon020000omH0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gH
iP0303>QbP3oon00oooP09@0oooP0P000?oH0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0
oooP0?ooh02B0?ooh080003ofP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00
T03oon020000om`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP08h0oooP0P00
0?oN0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh02=0?ooh0030000o`3oon00
oooP0=h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP08/0oooP0P000?oQ0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh0290?ooh080003oh`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0
J02]f>H00`0cXLX0oooP0?ooh0270?ooh080003oh`3oon03000001/0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?oo
h0260?ooh0030000o`3oon00oooP0>D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00
oooP08@0oooP0P000?oX0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh0220?oo
h080003ojP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00P@3oon000`000?l0
oooP0?ooh03Z0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh01o0?ooh080003o
k@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00O@3oon020000onl0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP07/0oooP0P000?oa0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0J02]f>H00`0cXLX0oooP0?ooh01j0?ooh0030000o`3oon00oooP0?40oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP07P0oooP0P000?od0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
J02]f>H00`0cXLX0oooP0?ooh01g0?ooh0030000o`3oon00oooP0?@0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP1X0:gHiP0303>QbP3oon00oooP07D0oooP0P000?og0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H0
0`0cXLX0oooP0?ooh01c0?ooh080003on@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?oo
h03oon00LP3oon000`000?l0oooP0?ooh03i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0
oooP0?ooh01`0?ooh080003oo03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00
K`3oon000`000?l0oooP0?ooh03l0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP06d0oooP0P00
0?om0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP06/0oooP0P000?oo0?ooh080oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP06X0oooP00<0003o0?ooh03oon00o`3oon020?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh01X0?ooh080003oo`3oon050?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh01W0?ooh0030000o`3oon00oooP0?l0oooP
1@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00I@3oon020000ool0oooP203o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00I03oon000`000?l0oooP0?ooh03o
0?ooh0P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP06<0oooP00<0003o0?oo
h03oon00o`3oon090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh01Q0?ooh080
003oo`3oon0<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh01P0?ooh0030000
o`3oon00oooP0?l0oooP303oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00G`3o
on000`000?l0oooP0?ooh03o0?ooh0d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00
oooP05d0oooP0P000?oo0?ooh100oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP
05`0oooP00<0003o0?ooh03oon00o`3oon0@0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0
oooP0?ooh01K0?ooh0030000o`3oon00oooP0?l0oooP4@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V3@3oon04000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP1X0:gHiP0303>QbP3oon00oooP05T0oooP0P000?oo0?ooh1@0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00<000000?ooh03oon00203oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00F03oon000`000?l0oooP0?oo
h03o0?ooh1@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<00000
0?ooh03oon001`3oon04000000P0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh01G
0?ooh0030000o`3oon00oooP0?l0oooP4P3oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H?0?oo
h0030000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gH
iP0303>QbP3oon00oooP05D0oooP0P000?oo0?ooh1P0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00E03oon000`000?l0oooP0?ooh03o0?oo
h1P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh01B0?ooh080
003oo`3oon0K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh01A0?ooh0030000
o`3oon00oooP0?l0oooP6`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00D03o
on000`000?l0oooP0?ooh03o0?ooh1`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00
oooP04h0oooP0P000?oo0?ooh1l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP
04d0oooP00<0003o0?ooh03oon00o`3oon0O0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0
oooP0?ooh01;0?ooh080003oo`3oon0R0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP
0?ooh01:0?ooh0030000o`3oon00oooP0?l0oooP8P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0
<j7:0?ooh03oon00B03oon020000ool0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:
0?ooh03oon00A`3oon000`000?l0oooP0?ooh03o0?ooh2D0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gH
iP0303>QbP3oon00oooP04H0oooP00<0003o0?ooh03oon00o`3oon0V0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0J02]f>H00`0cXLX0oooP0?ooh0140?ooh080003oo`3oon0Y0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
J02]f>H00`0cXLX0oooP0?ooh0130?ooh0030000o`3oon00oooP0?l0oooP:@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00@@3oon020000ool0oooP;03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H0
0`0cXLX0oooP0?ooh0100?ooh0030000o`3oon00oooP0?l0oooP:P3oon03000001/0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0c
XLX0oooP0?ooh00o0?ooh0030000o`3oon00oooP0?l0oooP;@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0
[MSV00<0<j7:0?ooh03oon00?@3oon020000ool0oooP<03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV
00<0<j7:0?ooh03oon00?03oon000`000?l0oooP0?ooh03o0?ooh300oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP1X0:gHiP0303>QbP3oon00oooP03/0oooP00<0003o0?ooh03oon00o`3oon0a0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh00j0?ooh0030000o`3oon00oooP0?l0oooP<P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00>03oon020000ool0oooP=@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00=`3oon000`000?l0oooP0?ooh03o0?ooh3D0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP03H0oooP00<0003o0?ooh03oon00
o`3oon0f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh00d0?ooh080003oo`3o
on0i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh00c0?ooh0030000o`3oon00
oooP0?l0oooP>@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon00<P3oon000`00
0?l0oooP0?ooh03o0?ooh3X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP0340
oooP00<0003o0?ooh03oon00o`3oon0k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP
0?ooh00_0?ooh080003oo`3oon0n0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?oo
h00^0?ooh0030000o`3oon00oooP0?l0oooP?P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:
0?ooh03oon00;@3oon000`000?l0oooP0?ooh03o0?ooh3l0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?oo
h03oon00;03oon000`000?l0oooP0?ooh03o0?ooh3h0oooP0`00000K0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03o
on00:`3oon000`000?l0oooP0?ooh03o0?ooh440oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>Q
bP3oon00oooP02X0oooP00<0003o0?ooh03oon00o`3oon120?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]
f>H00`0cXLX0oooP0?ooh00X0?ooh080003oo`3oon150?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H0
0`0cXLX0oooP0?ooh00W0?ooh0030000o`3oon00oooP0?l0oooPA@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
06P0[MSV00<0<j7:0?ooh03oon009P3oon000`000?l0oooP0?ooh03o0?ooh4H0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP02D0oooP00<0003o0?ooh03oon00o`3oon170?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh00T0?ooh0030000o`3oon00oooP0?l0oooP
B03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon008`3oon000`000?l0oooP0?oo
h03o0?ooh4T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP0280oooP00<0003o
0?ooh03oon00o`3oon1:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh00Q0?oo
h0030000o`3oon00oooP0?l0oooPB`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03o
on00803oon000`000?l0oooP0?ooh03o0?ooh4`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>Q
bP3oon00oooP01h0oooP0P000?oo0?ooh4l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3o
on00oooP01d0oooP00<0003o0?ooh03oon00o`3oon1?0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H0
0`0cXLX0oooP0?ooh00L0?ooh0030000o`3oon00oooP0?l0oooPD03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
06P0[MSV00<0<j7:0?ooh03oon006`3oon000`000?l0oooP0?ooh03o0?ooh540oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV06P0
[MSV00<0<j7:0?ooh03oon006P3oon000`000?l0oooP0?ooh03o0?ooh500oooP0`00000K0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV
00<0<j7:0?ooh03oon006@3oon000`000?l0oooP0?ooh03o0?ooh5<0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP1X0:gHiP0303>QbP3oon00oooP01P0oooP00<0003o0?ooh03oon00o`3oon1D0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh00G0?ooh0030000o`3oon00oooP0?l0oooPE@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon005P3oon000`000?l0oooP0?ooh03o0?oo
h5H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP01@0oooP0P000?oo0?ooh5T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP01<0oooP00<0003o0?ooh03oon00
o`3oon1I0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh00B0?ooh0030000o`3o
on00oooP0?l0oooPFP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon004@3oon00
0`000?l0oooP0?ooh03o0?ooh5/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP
0100oooP00<0003o0?ooh03oon00o`3oon1L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0
oooP0?ooh00?0?ooh0030000o`3oon00oooP0?l0oooPG@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV
00<0<j7:0?ooh03oon003P3oon000`000?l0oooP0?ooh03o0?ooh5h0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP1X0:gHiP0303>QbP3oon00oooP00d0oooP00<0003o0?ooh03oon00o`3oon1O0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh00<0?ooh0030000o`3oon00oooP0?l0oooPH03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3`3oon03000000H0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP00X0oooP0P000?oo0?oo
h6<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQ00oooP00<000000?ooh03o
on001@3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03o
on002@3oon000`000?l0oooP0?ooh03o0?ooh6<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iPd0oooP1@0000060?ooh0@00000203oon000`0cXLX0[MSV0:gHiP1X0:gHiP0303>Q
bP3oon00oooP00P0oooP00<0003o0?ooh03oon00o`3oon1Q0?ooh0@000006`3oon0N0?[`iP40oooo
000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon001`3oon000`000?l0oooP0?ooh03o0?ooh6D0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<000000?ooh00000001`3o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00<0<j7:0?ooh03oon001P3o
on000`000?l0oooP0?ooh03o0?ooh6H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iPl0oooP0P0000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H0
0`0cXLX0oooP0?ooh0050?ooh0030000o`3oon00oooP0?l0oooPI`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
06P0[MSV00<0<j7:0?ooh03oon00103oon000`000?l0oooP0?ooh03o0?ooh6P0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP1X0:gHiP0303>QbP3oon00oooP00<0oooP00<0003o0?ooh03oon00o`3oon1Y0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0J02]f>H00`0cXLX0oooP0?ooh0020?ooh0030000o`3oon00oooP0?l0oooP
JP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV06P0[MSV00D0<j7:0?ooh03oon00oooP0000o`3o0?ooh6d0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP1X0:gHiP0403>QbP3oon00oooP0000ool0oooPKP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV06P0[MSV00<0<j7:0?ooh0000?l0o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0J02]f>H0
0`0cXLX0003o0?ooh03o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1W0:gHiP80003oo`3oon1a0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0IP2]f>H00`000?l0[MSV03>QbP3o0?ooh740oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP1U0:gHiP040000o`2]f>H0[MSV03>Qb_l0oooPL@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06@0[MSV
00D0003o0:gHiP2]f>H0[MSV03>QbP3o0?ooh740oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1S0:gHiP030000
o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP1R0:gHiP030000o`2]
f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00o`3oon1]0?ooh0<000006`3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1Q0:gHiP030000o`2]f>H0
[MSV00@0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0H02]f>H00`00
0?l0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV05l0
[MSV00<0003o0:gHiP2]f>H01P2]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP1N0:gHiP030000o`2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0G@2]f>H00`000?l0[MSV0:gHiP080:gHiP0303>QbP3oon00oooP0?l0oooPK`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV05`0[MSV00<0003o0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh03o
0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP1K0:gHiP030000o`2]f>H0[MSV00X0[MSV00<0<j7:0?oo
h03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0FP2]f>H00`000?l0[MSV0:gHiP0;0:gHiP03
03>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV05T0[MSV00<0003o0:gHiP2]f>H0
302]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1H0:gHiP030000o`2]
f>H0[MSV00d0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0E`2]f>H0
0`000?l0[MSV0:gHiP0>0:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
05H0[MSV00<0003o0:gHiP2]f>H03`2]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP1E0:gHiP030000o`2]f>H0[MSV0100[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0E02]f>H00`000?l0[MSV0:gHiP0A0:gHiP0303>QbP3oon00oooP0?l0oooP
K`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV05<0[MSV00<0003o0:gHiP2]f>H04P2]f>H00`0cXLX0oooP0?oo
h03o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`000009
0?ooh00303>QbP2]f>H0[MSV0580[MSV00<0003o0:gHiP2]f>H04`2]f>H00`0cXLX0oooP0?ooh03o
0?ooh6d0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV0540[MSV00<0003o0:gHiP2]f>H0502]f>H00`0cXLX0oooP0?ooh03o0?oo
h6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP1@0:gHiP030000o`2]f>H0[MSV01D0[MSV00<0<j7:0?ooh03o
on00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0C`2]f>H00`000?l0[MSV0:gHiP0F0:gHiP0303>Q
bP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV04h0[MSV00<0003o0:gHiP2]f>H05`2]
f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1=0:gHiP030000o`2]f>H0
[MSV01P0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0C02]f>H00`00
0?l0[MSV0:gHiP0I0:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV04/0
[MSV00<0003o0:gHiP2]f>H06P2]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP1:0:gHiP030000o`2]f>H0[MSV01/0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0B@2]f>H00`000?l0[MSV0:gHiP0L0:gHiP0303>QbP3oon00oooP0?l0oooPK`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV04P0[MSV00<0003o0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh03o
0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP170:gHiP030000o`2]f>H0[MSV01h0[MSV00<0<j7:0?oo
h03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0AP2]f>H00`000?l0[MSV0:gHiP0O0:gHiP03
03>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV04D0[MSV00<0003o0:gHiP2]f>H0
802]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP140:gHiP030000o`2]
f>H0[MSV0240[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0@`2]f>H0
0`000?l0[MSV0:gHiP0R0:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0@P2]f>H00`00
0?l0[MSV0:gHiP0S0:gHiP0303>QbP3oon00oooP0?l0oooPK@3oon03000001/0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0@@2]f>H00`000?l0
[MSV0:gHiP0T0:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0400[MSV
00<0003o0:gHiP2]f>H09@2]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP100:gHiP030000o`2]f>H0[MSV02D0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0?`2]f>H00`000?l0[MSV0:gHiP0V0:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV03h0[MSV00<0003o0:gHiP2]f>H09`2]f>H00`0cXLX0oooP0?ooh03o0?oo
h6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0m0:gHiP030000o`2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03o
on00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0?02]f>H00`000?l0[MSV0:gHiP0Y0:gHiP0303>Q
bP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03/0[MSV00<0003o0:gHiP2]f>H0:P2]
f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0j0:gHiP030000o`2]f>H0
[MSV02/0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0>@2]f>H00`00
0?l0[MSV0:gHiP0/0:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03P0
[MSV00<0003o0:gHiP2]f>H0;@2]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0g0:gHiP030000o`2]f>H0[MSV02h0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0=P2]f>H00`000?l0[MSV0:gHiP0_0:gHiP0303>QbP3oon00oooP0?l0oooPK`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon03000000P0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0e0:gHiP030000o`2]f>H0[MSV0300[MSV00<0<j7:
0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?oo
h0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0d
0:gHiP030000o`2]f>H0[MSV0340[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP10000008
0?ooh00303>QbP2]f>H0[MSV03<0[MSV00<0003o0:gHiP2]f>H0<P2]f>H00`0cXLX0oooP0?ooh03o
0?ooh6`0oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3oon03000000P0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0b0:gHiP030000o`2]f>H0[MSV03<0[MSV00<0<j7:0?oo
h03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh003
0000003oon00oooP00L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0b0:gHiP03
0000o`2]f>H0[MSV03<0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0<000001`3oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV0340[MSV00<0003o0:gHiP2]f>H0=02]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0`0:gHiP030000o`2]f>H0[MSV03D0[MSV00<0<j7:0?ooh03oon00o`3o
on1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0;`2]f>H00`000?l0[MSV0:gHiP0f0:gHiP0303>QbP3oon00
oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02h0[MSV00<0003o0:gHiP2]f>H0=`2]f>H00`0c
XLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0]0:gHiP030000o`2]f>H0[MSV03P0
[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0;02]f>H00`000?l0[MSV
0:gHiP0i0:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02/0[MSV00<0
003o0:gHiP2]f>H0>P2]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0Z
0:gHiP030000o`2]f>H0[MSV03/0[MSV00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0:@2]f>H00`000?l0[MSV0:gHiP0l0:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV02T0[MSV00<0003o0:gHiP2]f>H0?02]f>H00`0cXLX0oooP0?ooh03o0?ooh6l0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP030000o`2]f>H0[MSV03d0[MSV00<0<j7:0?ooh03oon00
o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H09`2]f>H00`000?l0[MSV0:gHiP0n0:gHiP0303>QbP3o
on00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02H0[MSV00<0003o0:gHiP2]f>H0?`2]f>H0
0`0cXLX0oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV02D0[MSV00<0003o0:gHiP2]f>H0@02]f>H00`0c
XLX0oooP0?ooh03o0?ooh6d0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02@0[MSV00<0003o0:gHiP2]f>H0@@2]f>H00`0cXLX0
oooP0?ooh03o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0S0:gHiP030000o`2]f>H0[MSV0480[MSV
00<0<j7:0?ooh03oon00o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H08P2]f>H00`000?l0[MSV0:gH
iP130:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01l0[MSV0P000000
0`000?l0[MSV0:gHiP140:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
01h0[MSV0`0000000`000?l0[MSV0:gHiP140:gHiP0303>QbP3oon00oooP0?l0oooPK`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh240
<j7:0P0000000`000?l0000003>QbP1603>Qb_l0oooPL@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00[0?ooh0030000o`000000oooP0?l0oooP
^03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h00Z0?ooh0030000o`3oon00oooP0?l0oooP^@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh00Y0?ooh0030000o`3oon00oooP0?l0oooP^P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00X0?oo
h0030000o`3oon00oooP0?l0oooP^`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh00X0?ooh0030000o`3oon00oooP0?l0oooP^`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00W0?ooh0030000
o`3oon00oooP0?l0oooP_03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh00V0?ooh0030000o`3oon00oooP0?l0oooP_@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00U0?ooh0030000o`3oon00
oooP0?l0oooP_P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh00T0?ooh0030000o`3oon00oooP0?l0oooP_`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon03000002<0oooP00<0003o0?ooh03oon00o`3oon2n0?ooh0<0
00006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon008`3oon000`000?l0oooP
0?ooh03o0?ooh<00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon008P3oon000`000?l0oooP0?ooh03o0?ooh<40oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon008@3oon000`000?l0oooP0?ooh03o
0?ooh<80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00803oon000`000?l0oooP0?ooh03o0?ooh<<0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon007`3oon000`000?l0oooP0?ooh03o0?ooh<@0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
7P3oon000`000?l0oooP0?ooh03o0?ooh<D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon007P3oon000`000?l0oooP0?ooh03o0?ooh<D0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon007@3oon00
0`000?l0oooP0?ooh03o0?ooh<H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00703oon000`000?l0oooP0?ooh03o0?ooh<L0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon006`3oon000`000?l0
oooP0?ooh03o0?ooh<P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon006P3oon000`000?l0oooP0?ooh03o0?ooh<T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon006@3oon000`000?l0oooP0?oo
h03o0?ooh<X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon006@3oon000`000?l0oooP0?ooh03o0?ooh<X0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00603oon000`000?l0oooP0?ooh03o0?oo
h</0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on005`3oon000`000?l0oooP0?ooh03o0?ooh<`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP0`00000F0?ooh0030000o`3oon00oooP0?l0oooPb`3oon03000001/0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP01D0oooP00<0003o0?ooh03oon00o`3o
on3>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP01@0oooP00<0003o0?ooh03oon00o`3oon3?0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP01<0oooP00<0003o0?ooh03oon00o`3oon3@0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0180
oooP00<0003o0?ooh03oon00o`3oon3A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP0180oooP00<0003o0?ooh03oon00o`3oon3A0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0140oooP00<0
003o0?ooh03oon00o`3oon3B0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP0100oooP00<0003o0?ooh03oon00o`3oon3C0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00l0oooP00<0003o0?oo
h03oon00o`3oon3D0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00h0oooP00<0003o0?ooh03oon00o`3oon3E0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00d0oooP00<0003o0?ooh03oon00
o`3oon3F0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00`0oooP00<0003o0?ooh03oon00o`3oon3G0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00`0oooP00<0003o0?ooh03oon00o`3oon3G
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon000`00
0000oooP0?ooh00;0?ooh0030000o`3oon00oooP0?l0oooPf03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP
00X0oooP00<0003o0?ooh03oon00o`3oon3I0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP100000080?ooh0030000o`3oon00oooP
0?l0oooPe`3oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon000`000000
oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP
00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP0?l0oooP
iP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04X0oooP00<00000
0?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<00000
0?ooh03oon00BP3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh003
0000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
o`00003Z000001/0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003A0?[`iP@000000P3jl>H800000080n_3V100000001`3jl>H00000000000000000n_3V0000
003jl>H0300000000`3jl>H0000000000004000000040?[`iP0000000000000000P0n_3V1@000004
0?[`iPL0000000<0n_3V0000003jl>H00`0000080?[`iPD000000P3jl>H400000080n_3V1@00000<
0?[`iP<000004@3jl>H3000000H0n_3V0`000000103jl>H000000000000000060?[`iP030000003j
l>H0n_3V00@0n_3V0`000000103jl>H0000000000000003H0?[`iP40oooo003B0?[`iP8000000P3j
l>H2000000<0n_3V0P0000030?[`iP8000000`3jl>H01`000000n_3V000000000000n_3V0000003j
l>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000090?[`iP040000003jl>H0n_3V0?[`iP8000000P3jl>H2000000040?[`iP0000000000
0?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P000002
0?[`iP8000003@3jl>H2000000030?[`iP000000000000l0n_3V0P0000000`3jl>H0000000000006
0?[`iP80000000<0n_3V0000000000001`3jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V
000000000000f@3jl>H10?ooo`00dP3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`
iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103j
l>H000000000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V0P000002
0?[`iP8000000P3jl>H2000000d0n_3V0P0000000`3jl>H00000000000050?[`iPD000001@3jl>H2
000000030?[`iP000000000000L0n_3V0`0000060?[`iPD000001P3jl>H300000=X0n_3V0@3oool0
0=80n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`iP00000000000?[`iP000000n_3V0P00
00000`3jl>H000000000000300000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000002`3jl>H3000000<0n_3V0P000000103jl>H000000000003jl>H2000000030?[`
iP000000n_3V008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V
0P0000000`3jl>H000000000000?0?[`iP80000000<0n_3V0000000000001`3jl>H3000000P0n_3V
00<000000?[`iP3jl>H01P3jl>H300000=X0n_3V0@3oool00=80n_3V0P0000020?[`iP8000000`3j
l>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0
n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0
n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP020000
00X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP0:0?[`
iP<00000403jl>H4000000L0n_3V0P0000000`3jl>H00000000000070?[`iP030000003jl>H0n_3V
00D0n_3V0P0000000`3jl>H000000000003I0?[`iP40oooo003B0?[`iP8000000P3jl>H200000003
0?[`iP000000000000800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080
n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000000X0
n_3V1@0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000X0n_3V0P0000000`3jl>H0
00000000000?0?[`iP800000203jl>H3000000040?[`iP0000000000000000d0n_3V0`0000000`3j
l>H000000000000500000=@0n_3V0@3oool00=80n_3V0P0000020?[`iP800000<`3jl>H2000000<0
n_3V00<000000?[`iP3jl>H05`3jl>H2000001X0n_3V0P0000000`3jl>H000000000000@0?[`iP80
00008`3jl>H00`000000n_3V0?[`iP3D0?[`iP40oooo003A0?[`iPH00000103jl>H2000002l0n_3V
1@00000J0?[`iP<000006@3jl>H300000180n_3V0`00000R0?[`iP030000003jl>H0n_3V0=<0n_3V
0@3oool00?l0n_3VP`3jl>H00`000000n_3V0?[`iP3B0?[`iP40oooo003o0?[`iX00n_3V00@00000
0?[`iP3jl>H00000e03jl>H10?ooo`00o`3jl>J10?[`iP800000e@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .3741 L
.25149 .3741 L
.25149 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .3741 L
.25149 .3741 L
.25149 .08012 L
s
.678 .847 .902 r
.25149 .08012 m
.25149 .26405 L
.46301 .26405 L
.46301 .08012 L
F
.2 .63 .79 r
.25149 .08012 m
.25149 .26405 L
.46301 .26405 L
.46301 .08012 L
s
.678 .847 .902 r
.46301 .08012 m
.46301 .16212 L
.68446 .16212 L
.68446 .08012 L
F
.2 .63 .79 r
.46301 .08012 m
.46301 .16212 L
.68446 .16212 L
.68446 .08012 L
s
1 .894 .882 r
.68446 .08012 m
.68446 .05378 L
.86895 .05378 L
.86895 .08012 L
F
.804 .522 .247 r
.68446 .08012 m
.68446 .05378 L
.86895 .05378 L
.86895 .08012 L
s
1 .894 .882 r
.86895 .08012 m
.86895 .01475 L
.97619 .01475 L
.97619 .08012 L
F
.804 .522 .247 r
.86895 .08012 m
.86895 .01475 L
.97619 .01475 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.232 .3741 Mdot
.35634 .26405 Mdot
.4996 .16212 Mdot
.73082 .05378 Mdot
.96868 .01475 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.717197) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.40081) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V100000030?[`iP<00000103jl>H3000000@0n_3V0`0000030?[`iPH0
0000o`3jl>JR0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000060?[`iP8000000`3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V000000000000103jl>H200000?l0n_3VY03jl>H10?ooo`00803jl>H2000000030?[`iP000000
000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000006`3j
l>H2000000P0n_3V1P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3jl>JT0?[`iP40oooo000P
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000T0n_3V1@00000=0?[`iP800000203jl>H00`000000n_3V0?[`iP02000000<0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000@0n_3V0P00003o0?[`iZ@0n_3V0@3oool00200n_3V0P0000020?[`iP800000
0`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H20000
00@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02
000001P0n_3V00<000000?[`iP3jl>H00P0000090?[`iP040000003jl>H00000000000<0n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000`3jl>H3000000D0n_3V0P00
003o0?[`iZ@0n_3V0@3oool00200n_3V0P0000020?[`iP80000000<0n_3V0000000000000P000004
0?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3jl>H500000080n_3V1@00000:
0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000006@3jl>H4000000X0n_3V00@00000
0?[`iP00000000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VY03jl>H10?ooo`00803jl>H2
00000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0U0?[`iP8000003@3jl>H3
000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000080n_3V1000003o0?[`iZ@0n_3V0@3oool001l0n_3V1P0000040?[`
iP800000;`3jl>H5000002L0n_3V1@00000;0?[`iP800000103jl>H3000000@0n_3V0`0000040?[`
iP<000001@3jl>H200000?l0n_3VY03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0n_3V0@3oool0
0400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00000000000000
003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H000000000003jl>H5
000000<0n_3V3000000_0?[`iP<00000103jl>H200000?l0n_3Vb@3jl>H10?ooo`008P3jl>H20000
00@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V000000000003
0?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H200000080n_3V0P00
00030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`iP800000o`3j
l>K90?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P000004
0?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P000003
0?[`iP800000<03jl>H2000000030?[`iP00000000000?l0n_3VcP3jl>H10?ooo`008P3jl>H20000
00@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H6000000030?[`iP0000000000
0080n_3V0P0000020?[`iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H20000
00030?[`iP00000000000?l0n_3VcP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H0
0000000000020?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H30000
0080n_3V0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V1000003o0?[`
i/l0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V100000030?[`iP80
000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000103jl>H200000300
n_3V0P00003o0?[`i]40n_3V0@3oool00280n_3V0P00000;0?[`iP8000008P3jl>H200000340n_3V
0P00003o0?[`i]00n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000380n_3V0`00
003o0?[`i/h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0
n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P00
00020?[`iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`000000
0`3jl>H0000000000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003j
l>H0000001T0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3j
l>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V
100000000`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003j
l>H000000?[`iP03000001P0n_3V0`0000040?[`iP8000001P3jl>H2000000<0n_3V1P0000030?[`
iP8000000`3jl>H6000000040?[`iP0000000000000000H0n_3V0P00001i0?[`iP40oooo000Q0?[`
iP80000000<0n_3V0000000000001@000000103jl>H000000000000000020?[`iP80000000<0n_3V
0000000000002@3jl>H5000000T0n_3V00<000000?[`iP3jl>H00P00003L0?[`iP800000103jl>H2
00000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P00
00040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP800000
0P3jl>H2000000030?[`iP000000000000X0n_3V0P0000020?[`iP80000000<0n_3V000000000000
0P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD00000
2P3jl>H2000000030?[`iP000000000000<0n_3V0P0000060?[`iP8000001@3jl>H2000000D0n_3V
0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P00001i0?[`iP40oooo000R0?[`iP<00000:`3j
l>H200000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000001P3j
l>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0
n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`iP800000
0P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H00000
0000000;0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V
0P00001i0?[`iP40oooo000R0?[`iP<000006P3jl>H5000000`0n_3V0P00003L0?[`iP@000000`3j
l>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3j
l>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00
000000000000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H00000
0?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002`3jl>H2000000D0n_3V
0P0000050?[`iP8000001@3jl>H2000000@0n_3V100000040?[`iP800000N@3jl>H10?ooo`008@3j
l>H2000000030?[`iP000000000002P0n_3V0`00003M0?[`iP80000000<0n_3V0000000000001@3j
l>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP800000
1P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V
0`000000103jl>H000000000003jl>H200000080n_3V0P0000020?[`iP<0000000<0n_3V0000003j
l>H00P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H000000000000<0?[`iP80
0000103jl>H2000000H0n_3V0P0000040?[`iP8000000`3jl>H2000000030?[`iP000000000000D0
n_3V0P00001h0?[`iP40oooo000P0?[`iP<0000000@0n_3V0000000000000000:@3jl>H200000=`0
n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`
iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`
iP<0000000<0n_3V0000000000000P3jl>H400000080n_3V0`0000000`3jl>H00000000000070000
01T0n_3V0P0000000`3jl>H000000000000<0?[`iP800000103jl>H2000000H0n_3V0P0000040?[`
iP8000000`3jl>H2000000030?[`iP000000000000D0n_3V0P00001h0?[`iP40oooo001=0?[`iP03
0000003jl>H0n_3V00800000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP80
00008P3jl>H200000080n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H00`000000
n_3V0?[`iP0200000080n_3V100000030?[`iP030000003jl>H0n_3V008000000P3jl>H4000000<0
n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V00800000N03jl>H10?ooo`00
CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000
6@3jl>H3000000030?[`iP000000000000800000;P3jl>H3000000X0n_3V1@0000040?[`iP800000
0`3jl>H5000000@0n_3V0P0000040?[`iP<000000`3jl>H5000007P0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H200000003
0?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V
00D000000?[`iP000000n_3V000000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`
iP3jl>H0o`3jl>Ko0?[`iR80n_3V0@3oool00200n_3V0`0000000`3jl>H000000000000200000004
0?[`iP000000n_3V00000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP0G
0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`000002
0?[`iPH000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000006000001/0n_3V0`000038
0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@0000001@3jl>H00000000000000000
n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H2
00000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P00
00040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP800000
0P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000/0n_3V1@0000090?[`iP03
0000003jl>H0n_3V00800000a`3jl>H10?ooo`008P3jl>H3000002P0n_3V0P0000000`3jl>H00000
0000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V
0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`
iP000000000000<0n_3V1000000L0?[`iP800000a`3jl>H10?ooo`008P3jl>H3000000T0n_3V00<0
00000?[`iP3jl>H03P3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP@000000`3j
l>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3j
l>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V1000000=0?[`iPD00000
303jl>H200000<L0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0
n_3V000000000000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0
n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP800000
0P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000I0?[`iP03
0000003jl>H0n_3V00800000a`3jl>H10?ooo`00803jl>H3000000040?[`iP0000000000000002H0
n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080
n_3V0`000000103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3jl>H40000
00@0n_3V100000020?[`iPD000000`3jl>H5000001T0n_3V100000380?[`iP40oooo001=0?[`iP80
000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP80
0000>03jl>H200000<X0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V
0P0000040?[`iP8000001P3jl>H200000300n_3V1@0000370?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`007@3jl>HS0?ooh0800000A@3oon02000000@0
oooP0P0000040?ooh0800000A03oon05000004<0oooP1@0000020?ooh0800000103oon02000004@0
oooP100000140?ooh0@000000`3oon02000000@0oooP0P0000150?ooh08000009`3oon0N0?[`iP40
oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh00000080?oo
h0040000003oon00oooP000004D0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh007
0?ooh0040000003oon00oooP000004<0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?oo
h0090?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon0000009P3oon0N0?[`iP40
oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh000000;0?oo
h0030000003oon00oooP04<0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh00:0?oo
h0030000003oon00oooP0480oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh00;0?oo
h0030000003oon00oooP04<0oooP00<000000?ooh03oon009@3oon0N0?[`iP40oooo000M0?[`iR80
oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh00000090?ooh0800000AP3oon00
0`000000oooP0?ooh0150?ooh0030000003oon00oooP00P0oooP0P0000160?ooh0030000003oon00
oooP04D0oooP00<000000?ooh03oon00203oon02000004L0oooP00<000000?ooh03oon00903oon0N
0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh000
00090?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?oo
h0080?ooh0030000003oon00oooP04<0oooP00@000000?ooh03oon000000A03oon0010000000oooP
0?ooh00000090?ooh0030000003oon00oooP04<0oooP00@000000?ooh03oon0000009P3oon0N0?[`
iP40oooo000M0?[`iR<0oooP0P0000150?ooh08000002P3oon03000004@0oooP0P0000160?ooh080
00002P3oon03000004@0oooP0P0000160?ooh08000002P3oon03000004@0oooP0P00000W0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`iQP0oooPo`00003Z000001/0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04X0oooP00<0
00000?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<0
00000?ooh03oon00BP3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3F0?ooh080
00003P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh03o0?ooh=D0oooP1000000=0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0<00000o`3oon2V0?ooh1/0cHDo6P000?l90?ooh0<000006`3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00o`3oon2V0?ooh0030<f5?`3oi>40onCQ0100onCQ20000?lE
0?oTh@8000000P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPYP3oon000`3=QCl0onCQ0?oTh@070?oT
h@T0003o8@3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPYP3oon0:0000obX0onCQ00<0cHDo0?ooh03o
on002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh03o0?ooh9h0oooP20000?l00`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3o
on2H0?ooh0H0003o203oon000`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2A
0?ooh0L0003o3P3oon000`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2<0?oo
h0D0003o5@3oon000`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon280?ooh0@0
003o6P3oon000`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon240?ooh0@0003o
7P3oon000`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon200?ooh0@0003o8P3o
on000`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1l0?ooh0@0003o9P3oon00
0`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1h0?ooh0@0003o:P3oon000`3=
QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1d0?ooh0@0003o;P3oon000`3=QCl0
onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1`0?ooh0@0003o<P3oon000`3=QCl0onCQ
0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1/0?ooh0@0003o=P3oon000`3=QCl0onCQ0?oT
h@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP0`00003o0?ooh6P0oooP10000?lj0?ooh0030<f5?`3oi>40onCQ0340onCQ00<0cHDo
0?ooh03oon001`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
0?l0oooPHP3oon02000000040?ooh0000?l0003o0000och0oooP00<0cHDo0?oTh@3oi>40<@3oi>40
0`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0?l0oooPH@3oon0010000000003o0000o`000?m10?ooh0030<f5?`3oi>40
onCQ0340onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh03o0?ooh4`0oooP4`3=QCl30000o`<00000@P3=QClc0?oT
h@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00o`3oon1<0?ooh0030<f5?`3oi>40onCQ00h0onCQ0P000?l30?oTh@80
0000@P3oi>400`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1<0?ooh0030<f5
?`3oi>40onCQ00/0onCQ0`000?m90?oTh@030<f5?`3oi>40onCQ0340onCQ00<0cHDo0?ooh03oon00
2@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh4`0oooP00<0cHDo0?oTh@3oi>40203oi>430000od`0onCQ00<0cHDo0?oTh@3oi>40<@3o
i>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP0?l0oooPC03oon000`3=QCl0onCQ0?oTh@050?oTh@<0003oC`3oi>40
0`3=QCl0onCQ0?oTh@0a0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1<0?ooh0030<f5?`3oi>40onCQ
0080onCQ0`000?mB0?oTh@030<f5?`3oi>40onCQ0340onCQ00<0cHDo0?ooh03oon002@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh4`0
oooP00<0cHDo0?oTh@3oi>400P000?mE0?oTh@030<f5?`3oi>40onCQ0340onCQ00<0cHDo0?ooh03o
on002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh03o0?ooh4`0oooP0`000?mG0?oTh@030<f5?`3oi>40onCQ0340onCQ00<0cHDo0?ooh03oon00
2@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh4X0oooP0P000?l00`3=QCl0onCQ0?oTh@1G0?oTh@030<f5?`3oi>40onCQ0340onCQ00<0
cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh03o0?ooh4L0oooP0`000?l20?ooh0030<f5?`3oi>40onCQ05L0onCQ00<0cHDo
0?oTh@3oi>40<@3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>H>0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh4@0oooP0`000?l50?oo
h0030<f5?`3oi>40onCQ05L0onCQ00<0cHDo0?oTh@3oi>40<@3oi>400`3=QCl0oooP0?ooh0090?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP0000
00L0oooP00<000000?ooh03oon00o`3oon120?ooh080003o203oon000`3=QCl0onCQ0?oTh@1G0?oT
h@030<f5?`3oi>40onCQ0340onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0@00000203oon3o0000
03H000000`000?nI000000P0oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000
oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0c
XLX0[MSV0:gHiP1T0:gHiP0303>QbP2]f>H0[MSV05X0[MSV0P000?l=0:gHiP0303>QbP3oon00oooP
09L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03o
on0000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gH
iP2]f>H0I02]f>H00`0cXLX0[MSV0:gHiP1H0:gHiP80003o3`2]f>H00`0cXLX0oooP0?ooh02G0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0
[MSV0:gHiP1F0:gHiP80003o4@2]f>H00`0cXLX0oooP0?ooh02G0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP2]f>H0[MSV05@0[MSV0P000?lC0:gHiP0303>Q
bP3oon00oooP09L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV06@0[MSV00<0
<j7:0:gHiP2]f>H0D@2]f>H30000oaD0[MSV00<0<j7:0?ooh03oon00U`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0[MSV0:gHiP1?0:gHiP80003o602]f>H0
0`0cXLX0oooP0?ooh02G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gH
iP0303>QbP2]f>H0[MSV04d0[MSV0P000?lJ0:gHiP0303>QbP3oon00oooP09L0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV06@0[MSV00<0<j7:0:gHiP2]f>H0B`2]f>H20000oa`0
[MSV00<0<j7:0?ooh03oon00U`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0
I02]f>H00`0cXLX0[MSV0:gHiP190:gHiP80003o7P2]f>H00`0cXLX0oooP0?ooh02G0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP2]f>H0[MSV04L0[MSV0P00
0?lP0:gHiP0303>QbP3oon00oooP09L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0
[MSV06@0[MSV00<0<j7:0:gHiP2]f>H0A@2]f>H20000ob80[MSV00<0<j7:0?ooh03oon00U`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0[MSV0:gHiP130:gH
iP80003o902]f>H00`0cXLX0oooP0?ooh02G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0
[MSV0:gHiP1T0:gHiP0303>QbP2]f>H0[MSV0440[MSV0P000?lV0:gHiP0303>QbP3oon00oooP09L0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV06@0[MSV00<0<j7:0:gHiP2]f>H0
?`2]f>H20000obP0[MSV00<0<j7:0?ooh03oon00U`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0
<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0[MSV0:gHiP0m0:gHiP80003o:P2]f>H00`0cXLX0oooP0?oo
h02G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon00
0`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV06@0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H2
0000ob`0[MSV00<0<j7:0?ooh03oon00U@3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gH
iP0303>QbP2]f>H0[MSV03T0[MSV0P000?l^0:gHiP0303>QbP3oon00oooP09L0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV06@0[MSV00<0<j7:0:gHiP2]f>H0=`2]f>H20000oc00
[MSV00<0<j7:0?ooh03oon00U`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0
I02]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP80003o<P2]f>H00`0cXLX0oooP0?ooh02G0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP2]f>H0[MSV03<0[MSV0P00
0?ld0:gHiP0303>QbP3oon00oooP09L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0
[MSV06@0[MSV00<0<j7:0:gHiP2]f>H0<@2]f>H20000ocH0[MSV00<0<j7:0?ooh03oon00U`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0[MSV0:gHiP0_0:gH
iP80003o>02]f>H00`0cXLX0oooP0?ooh02G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0
[MSV0:gHiP1T0:gHiP0303>QbP2]f>H0[MSV02d0[MSV0P000?lj0:gHiP0303>QbP3oon00oooP09L0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV06@0[MSV00<0<j7:0:gHiP2]f>H0
:`2]f>H20000oc`0[MSV00<0<j7:0?ooh03oon00U`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0
<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0[MSV0:gHiP0Y0:gHiP80003o?P2]f>H00`0cXLX0oooP0?oo
h02G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP2]f>H0
[MSV02L0[MSV0P000?m00:gHiP0303>QbP3oon00oooP09L0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gH
iP0303>QbP2]f>H0[MSV06@0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H20000od80[MSV00<0<j7:0?oo
h03oon00U`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0
[MSV0:gHiP0S0:gHiP80003oA02]f>H00`0cXLX0oooP0?ooh02G0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0003o0:gHiP2]f>H0
A02]f>H00`0cXLX0oooP0?ooh02G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gH
iP1T0:gHiP0303>QbP2]f>H0[MSV0200[MSV0P000?m70:gHiP0303>QbP3oon00oooP09L0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV06@0[MSV00<0<j7:0:gHiP2]f>H07P2]f>H2
0000odT0[MSV00<0<j7:0?ooh03oon00U`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gH
iP0303>QbP2]f>H0[MSV01`0[MSV0P000?m;0:gHiP0303>QbP3oon00oooP09D0oooP0`00000K0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0
[MSV00<0<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP030000o`2]f>H0[MSV04/0
[MSV00<0<j7:0?ooh03oon00U`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0
I02]f>H00`0cXLX0[MSV0:gHiP0I0:gHiP80003oCP2]f>H00`0cXLX0oooP0?ooh02G0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP2]f>H0[MSV01L0[MSV0P00
0?m@0:gHiP0303>QbP3oon00oooP09L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0
[MSV06@0[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`000?l0[MSV0:gHiP1@0:gHiP0303>QbP3oon00
oooP09L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV06@0[MSV00<0<j7:0:gH
iP2]f>H0502]f>H20000oe<0[MSV00<0<j7:0?ooh03oon00U`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0
[MSV00<0<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0[MSV0:gHiP0B0:gHiP80003oE@2]f>H00`0cXLX0
oooP0?ooh02G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV0P0000020000oeL0[MSV00<0<j7:0?ooh03oon00U`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0I02]f>H@03>QbP80000000<0003o0000000cXLX0F00c
XLZI0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP3oon00
oooP00d0oooP0P000?l200000?80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV
06@0[MSV00<0<j7:0?ooh03oon00303oon0010000?l0oooP00000000003c0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP3oon00oooP00X0oooP0P000?og0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP3oon00oooP00P0
oooP0P000?oi0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>Q
bP3oon00oooP00L0oooP00<0003o0?ooh03oon00n@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0
<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0oooP0?ooh0050?ooh080003oo03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0oooP0?ooh0040?ooh0030000o`3oon00
oooP0?`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?oo
h00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0I02]f>H00`0cXLX0oooP0?ooh0020?oo
h080003oo@3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>QbP3oon00oooP0080
003oo`3oon020?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1T0:gHiP0303>Q
bP3oon00003o0?l0oooP103oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0I02]
f>H20000ool0oooP1@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0H`2]f>H0
0`000?l0<j7:0?ooh03o0?ooh0D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV
0640[MSV0P000?l00`2]f>H0<j7:0?ooh03o0?ooh0D0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP03
03>QbP2]f>H0[MSV0600[MSV00D0003o0:gHiP2]f>H0[MSV03>QbP3o0?ooh0H0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV05l0[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0
oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV05d0[MSV
0P000?l50:gHiP0303>QbP3oon00oooP0?l0oooP103oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0
<j7:0:gHiP2]f>H0G02]f>H00`000?l0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP0?l0oooP103o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0F`2]f>H00`000?l0[MSV0:gHiP06
0:gHiP0303>QbP3oon00oooP0?l0oooP103oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gH
iP2]f>H0F@2]f>H20000o`T0[MSV00<0<j7:0?ooh03oon00o`3oon040?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0K02]f>H00`0cXLX0[MSV0:gHiP1H0:gHiP030000o`2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03o
on00o`3oon040?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1G0:gHiP030000
o`2]f>H0[MSV00X0[MSV00<0<j7:0?ooh03oon00o`3oon040?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>H=0?ooh0@000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0E@2]f>H20000o`d0[MSV00<0<j7:0?ooh03oon00o`3o
on040?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0030000003oon00
oooP00P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0
[MSV05@0[MSV00<0003o0:gHiP2]f>H03@2]f>H00`0cXLX0oooP0?ooh03o0?ooh0@0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<000000?ooh03oon001`3oon040000
00P0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1C0:gHiP030000o`2]f>H0[MSV
00h0[MSV00<0<j7:0?ooh03oon00o`3oon010?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPl0
oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0
[MSV00<0<j7:0:gHiP2]f>H0D@2]f>H20000oa40[MSV00<0<j7:0?ooh03oon00o`3oon040?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV0500
[MSV00<0003o0:gHiP2]f>H04@2]f>H00`0cXLX0oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP1>0:gHiP80003o502]f>H00`0cXLX0oooP
0?ooh03o0?ooh0@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV04d0[MSV00<0
003o0:gHiP2]f>H0502]f>H00`0cXLX0oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/
0:gHiP0303>QbP2]f>H0[MSV04`0[MSV00<0003o0:gHiP2]f>H05@2]f>H00`0cXLX0oooP0?ooh03o
0?ooh0@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV04X0[MSV0P000?lH0:gH
iP0303>QbP3oon00oooP0?l0oooP103oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]
f>H0B@2]f>H00`000?l0[MSV0:gHiP0H0:gHiP0303>QbP3oon00oooP0?l0oooP103oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0A`2]f>H20000oa/0[MSV00<0<j7:0?ooh03oon00
o`3oon040?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP160:gHiP030000o`2]
f>H0[MSV01/0[MSV00<0<j7:0?ooh03oon00o`3oon040?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H0
0`0cXLX0[MSV0:gHiP140:gHiP80003o7P2]f>H00`0cXLX0oooP0?ooh03o0?ooh0@0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV04<0[MSV00<0003o0:gHiP2]f>H07P2]f>H00`0c
XLX0oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV0480
[MSV00<0003o0:gHiP2]f>H07`2]f>H00`0cXLX0oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV0400[MSV0P000?lR0:gHiP0303>QbP3oon00oooP0?l0oooP
103oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0?`2]f>H00`000?l0[MSV0:gH
iP0R0:gHiP0303>QbP3oon00oooP0?l0oooP103oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:
0:gHiP2]f>H0?@2]f>H20000obD0[MSV00<0<j7:0?ooh03oon00o`3oon040?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP1/0:gH
iP0303>QbP2]f>H0[MSV03`0[MSV00<0003o0:gHiP2]f>H09@2]f>H00`0cXLX0oooP0?ooh03o0?oo
h080oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`000?l0[MSV0:gHiP0V0:gHiP03
03>QbP3oon00oooP0?l0oooP103oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0:gHiP2]f>H0
>@2]f>H20000obT0[MSV00<0<j7:0?ooh03oon00o`3oon040?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]
f>H00`0cXLX0[MSV0:gHiP0h0:gHiP030000o`2]f>H0[MSV02T0[MSV00<0<j7:0?ooh03oon00o`3o
on040?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP0g0:gHiP030000o`2]f>H0
[MSV02X0[MSV00<0<j7:0?ooh03oon00o`3oon040?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0c
XLX0[MSV0:gHiP0f0:gHiP030000o`2]f>H0[MSV02/0[MSV00<0<j7:0?ooh03oon00o`3oon040?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0[MSV0:gHiP0d0:gHiP80003o;P2]f>H00`0cXLX0
oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV03<0[MSV
00<0003o0:gHiP2]f>H0;P2]f>H00`0cXLX0oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP1/0:gHiP0303>QbP2]f>H0[MSV0380[MSV00<0003o0:gHiP2]f>H0;`2]f>H00`0cXLX0oooP0?oo
h03o0?ooh0@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP2]f>H0[MSV02l0[MSV00<00000
0000o`000?l0<P2]f>H00`0cXLX0oooP0?ooh03o0?ooh0@0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gH
iS40<j7:00@000000000o`0000000000<`0cXL[o0?ooh0H0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gH
iP0303>QbP3oon00oooP02h0oooP00@0003o0000000000000000o`3oon0i0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0K02]f>H00`0cXLX0oooP0?ooh00]0?ooh0040000o`3oon00000000000?l0oooP>P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon00:`3oon020000ool0oooP?P3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon00:P3oon000`000?l0oooP0?ooh03o0?ooh3h0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP02T0oooP00<0003o0?ooh03oon00
o`3oon0o0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3o
on000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP02P0oooP00<0003o0?ooh03oon00o`3o
on0n0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP02L0oooP00<0003o0?ooh03oon00o`3oon11
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0oooP0?ooh00V0?ooh0030000o`3oon00oooP
0?l0oooP@P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon00903oon020000ool0
oooPA@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon008`3oon000`000?l0oooP
0?ooh03o0?ooh4D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP0280oooP00<0
003o0?ooh03oon00o`3oon160?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0oooP0?ooh00Q
0?ooh0030000o`3oon00oooP0?l0oooPA`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0?oo
h03oon00803oon000`000?l0oooP0?ooh03o0?ooh4P0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP03
03>QbP3oon00oooP01l0oooP00<0003o0?ooh03oon00o`3oon190?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
K02]f>H00`0cXLX0oooP0?ooh00N0?ooh0030000o`3oon00oooP0?l0oooPBP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon007@3oon000`000?l0oooP0?ooh03o0?ooh4/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP01`0oooP00<0003o0?ooh03oon00o`3oon1<
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0oooP0?ooh00J0?ooh080003oo`3oon1?0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0oooP0?ooh00I0?ooh0030000o`3oon00oooP0?l0
oooPC`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon00603oon000`000?l0oooP
0?ooh03o0?ooh500oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP01L0oooP00<0
003o0?ooh03oon00o`3oon1A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP01H0oooP00<0003o
0?ooh03oon00o`3oon1@0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP01D0oooP00<0003o0?oo
h03oon00o`3oon1C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0oooP0?ooh00D0?ooh003
0000o`3oon00oooP0?l0oooPE03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon00
4`3oon000`000?l0oooP0?ooh03o0?ooh5D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3o
on00oooP0180oooP00<0003o0?ooh03oon00o`3oon1F0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H0
0`0cXLX0oooP0?ooh00@0?ooh080003oo`3oon1I0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0c
XLX0oooP0?ooh00?0?ooh0030000o`3oon00oooP0?l0oooPF@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0
[MSV00<0<j7:0?ooh03oon003P3oon000`000?l0oooP0?ooh03o0?ooh5X0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP1/0:gHiP0303>QbP3oon00oooP00d0oooP00<0003o0?ooh03oon00o`3oon1K0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0oooP0?ooh00<0?ooh0030000o`3oon00oooP0?l0oooPG03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon002`3oon000`000?l0oooP0?ooh03o
0?ooh5d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP00X0oooP00<0003o0?oo
h03oon00o`3oon1N0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000o`3oon00oooP0?l0oooPG`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00<0<j7:0?ooh03oon00
203oon000`000?l0oooP0?ooh03o0?ooh600oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iPl0oooP0`0000060?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]
f>H00`0cXLX0oooP0?ooh0060?ooh080003oo`3oon1S0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>H@0?ooh0030000003oon00oooP00D0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP00D0oooP00<0003o0?ooh03oon00o`3oon1S
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0D000001P3oon040000
00P0oooP00<0<j7:0:gHiP2]f>H0K02]f>H00`0cXLX0oooP0?ooh0040?ooh0030000o`3oon00oooP
0?l0oooPH@3oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP0000
00L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP
00<0oooP00<0003o0?ooh03oon00o`3oon1U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H>0?ooh0030000003oon00000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP1/0:gHiP0303>QbP3oon00oooP0080oooP00<0003o0?ooh03oon00o`3oon1V0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh08000001`3oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV06`0[MSV00D0<j7:0?ooh03oon00oooP0000o`3o0?ooh6T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP0403>QbP3oon00oooP0000ool0oooPJP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV06`0[MSV00<0<j7:0?ooh0000?l0o`3oon1[0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0K02]
f>H00`0cXLX0003o0?ooh03o0?ooh6/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1/0:gHiP030000o`3oon00
oooP0?l0oooPJ`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06/0[MSV00<0003o03>QbP3oon00o`3oon1/0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0JP2]f>H00`000?l0[MSV03>QbP3o0?ooh6d0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP1Y0:gHiP040000o`2]f>H0[MSV03>Qb_l0oooPK@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06L0[MSV
0P000?l30:gHiP0303>QbP3oon00oooP0?l0oooPJ`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV06H0[MSV00<0
003o0:gHiP2]f>H00`2]f>H00`0cXLX0oooP0?ooh03o0?ooh6/0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP1U
0:gHiP030000o`2]f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon00o`3oon1[0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0HP2]f>H2000000030000o`2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00o`3oon1[0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0H@2]f>H2000000030000o`000000[MSV00H0[MSV00<0<j7:0?ooh03o
on00o`3oon1[0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000
2@3oon1T03>QbP04000000000?l00000000000P0<j7:o`3oon1[0?ooh0<000006`3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00K@3oon000`000?l000000000003o0?ooh7H0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00K03o
on000`000?l0oooP0?ooh03o0?ooh7L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00J`3oon000`000?l0oooP0?ooh03o0?ooh7P0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00JP3oon000`00
0?l0oooP0?ooh03o0?ooh7T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00J@3oon000`000?l0oooP0?ooh03o0?ooh7X0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00J03oon000`000?l0oooP
0?ooh03o0?ooh7/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00I`3oon000`000?l0oooP0?ooh03o0?ooh7`0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00IP3oon000`000?l0oooP0?ooh03o
0?ooh7d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00I@3oon000`000?l0oooP0?ooh03o0?ooh7h0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00I03oon000`000?l0oooP0?ooh03o0?ooh7l0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
H`3oon000`000?l0oooP0?ooh03o0?ooh800oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00HP3oon000`000?l0oooP0?ooh03o0?ooh840oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00H@3oon00
0`000?l0oooP0?ooh03o0?ooh880oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00H03oon000`000?l0oooP0?ooh03o0?ooh8<0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00G`3oon000`000?l0
oooP0?ooh03o0?ooh8@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
0`00001N0?ooh0030000o`3oon00oooP0?l0oooPP`3oon03000001/0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP05d0oooP00<0003o0?ooh03oon00o`3oon260?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP05`0oooP00<0003o
0?ooh03oon00o`3oon270?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP05/0oooP00<0003o0?ooh03oon00o`3oon280?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP05X0oooP00<0003o0?ooh03o
on00o`3oon290?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP05T0oooP00<0003o0?ooh03oon00o`3oon2:0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP05P0oooP00<0003o0?ooh03oon00o`3o
on2;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP05L0oooP00<0003o0?ooh03oon00o`3oon2<0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP05H0oooP00<0003o0?ooh03oon00o`3oon2=0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP05D0
oooP00<0003o0?ooh03oon00o`3oon2>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP05@0oooP00<0003o0?ooh03oon00o`3oon2?0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP05<0oooP00<0
003o0?ooh03oon00o`3oon2@0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP0580oooP00<0003o0?ooh03oon00o`3oon2A0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0540oooP00<0003o0?oo
h03oon00o`3oon2B0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP0500oooP00<0003o0?ooh03oon00o`3oon2C0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP04l0oooP00<0003o0?ooh03oon00
o`3oon2D0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000CP3o
on000`000?l0oooP0?ooh03o0?ooh9<0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh01=0?ooh0030000o`3oon00oooP0?l0oooPUP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01<0?ooh0030000o`3oon00oooP
0?l0oooPU`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh01<0?ooh0030000o`3oon00oooP0?l0oooPU`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh01;0?ooh0030000o`3oon00oooP0?l0oooP
V03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h01:0?ooh0030000o`3oon00oooP0?l0oooPV@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0190?ooh0030000o`3oon00oooP0?l0oooPVP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0180?oo
h0030000o`3oon00oooP0?l0oooPV`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0170?ooh0030000o`3oon00oooP0?l0oooPW03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0160?ooh0030000
o`3oon00oooP0?l0oooPW@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0150?ooh0030000o`3oon00oooP0?l0oooPWP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0140?ooh0030000o`3oon00
oooP0?l0oooPW`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0130?ooh0030000o`3oon00oooP0?l0oooPX03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0120?ooh0030000o`3oon00oooP0?l0
oooPX@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon03000000P0oooP
00<000000?ooh03oon00@@3oon000`000?l0oooP0?ooh03o0?ooh:80oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP
0?ooh0100?ooh0030000o`3oon00oooP0?l0oooPX`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0@00000?P3oon000`000?l0oooP
0?ooh03o0?ooh:40oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3oon03000000P0oooP00<0
00000?ooh03oon00?P3oon000`000?l0oooP0?ooh03o0?ooh:D0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iPh0oooP00<000000?ooh03oon001`3oon000`000000oooP0?ooh00n
0?ooh0030000o`3oon00oooP0?l0oooPY@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V3P3oon03000000L0oooP00<000000?ooh03oon00?@3oon000`000?l0oooP0?ooh03o0?oo
h:H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on00?03oon000`000?l0oooP0?ooh03o0?ooh:L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00>`3oon000`000?l0oooP0?ooh03o0?ooh:P0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00>P3o
on000`000?l0oooP0?ooh03o0?ooh:T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00>@3oon000`000?l0oooP0?ooh03o0?ooh:X0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00>03oon000`00
0?l0oooP0?ooh03o0?ooh:/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00=`3oon000`000?l0oooP0?ooh03o0?ooh:`0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00=P3oon000`000?l0oooP
0?ooh03o0?ooh:d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00=@3oon000`000?l0oooP0?ooh03o0?ooh:h0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00=@3oon000`000?l0oooP0?ooh03o
0?ooh:h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00=03oon000`000?l0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00<`3oon000`000?l0oooP0?ooh03o0?ooh;00
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
<P3oon000`000?l0oooP0?ooh03o0?ooh;40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP0`00000a0?ooh0030000o`3oon00oooP0?l0oooP/03oon03000001/0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0300oooP00<0003o0?ooh03oon00o`3oon2c
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
02l0oooP00<0003o0?ooh03oon00o`3oon2d0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP02h0oooP00<0003o0?ooh03oon00o`3oon2e0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02d0oooP
00<0003o0?ooh03oon00o`3oon2f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP02d0oooP00<0003o0?ooh03oon00o`3oon2f0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02`0oooP00<0003o
0?ooh03oon00o`3oon2g0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP02/0oooP00<0003o0?ooh03oon00o`3oon2h0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02X0oooP00<0003o0?ooh03o
on00o`3oon2i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP02T0oooP00<0003o0?ooh03oon00o`3oon2j0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02P0oooP00<0003o0?ooh03oon00o`3o
on2k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP02P0oooP00<0003o0?ooh03oon00o`3oon2k0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP02L0oooP00<0003o0?ooh03oon00o`3oon2l0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02H0
oooP00<0003o0?ooh03oon00o`3oon2m0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP02D0oooP00<0003o0?ooh03oon00o`3oon2n0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02@0oooP00<0
003o0?ooh03oon00o`3oon2o0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0<000008`3oon000`000?l0oooP0?ooh03o0?ooh;h0oooP0`00000K0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh00S0?ooh0030000o`3oon00oooP0?l0oooP`03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00R0?ooh003
0000o`3oon00oooP0?l0oooP`@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh00Q0?ooh0030000o`3oon00oooP0?l0oooP`P3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00P0?ooh0030000o`3o
on00oooP0?l0oooP``3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh00O0?ooh0030000o`3oon00oooP0?l0oooPa03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00N0?ooh0030000o`3oon00oooP
0?l0oooPa@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh00N0?ooh0030000o`3oon00oooP0?l0oooPa@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00M0?ooh0030000o`3oon00oooP0?l0oooP
aP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h00L0?ooh0030000o`3oon00oooP0?l0oooPa`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh00K0?ooh0030000o`3oon00oooP0?l0oooPb03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00J0?oo
h0030000o`3oon00oooP0?l0oooPb@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh00I0?ooh0030000o`3oon00oooP0?l0oooPbP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00I0?ooh0030000
o`3oon00oooP0?l0oooPbP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh00H0?ooh0030000o`3oon00oooP0?l0oooPb`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00G0?ooh0030000o`3oon00
oooP0?l0oooPc03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon030000
01H0oooP00<0003o0?ooh03oon00o`3oon3;0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon005@3oon000`000?l0oooP0?ooh03o0?ooh<h0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00503oon000`000?l0oooP
0?ooh03o0?ooh<l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon004`3oon000`000?l0oooP0?ooh03o0?ooh=00oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon004P3oon000`000?l0oooP0?ooh03o
0?ooh=40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon004P3oon000`000?l0oooP0?ooh03o0?ooh=40oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon004@3oon000`000?l0oooP0?ooh03o0?ooh=80
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
403oon000`000?l0oooP0?ooh03o0?ooh=<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon003`3oon000`000?l0oooP0?ooh03o0?ooh=@0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon003P3oon00
0`000?l0oooP0?ooh03o0?ooh=D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon003@3oon000`000?l0oooP0?ooh03o0?ooh=H0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00303oon000`000?l0
oooP0?ooh03o0?ooh=L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00303oon000`000?l0oooP0?ooh03o0?ooh=L0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00/0oooP00<0
003o0?ooh03oon00o`3oon3H0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=
0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002P3oon000`000?l0oooP0?oo
h03o0?ooh=T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@00000
0?ooh03oon0000001`3oon04000000P0oooP00<0003o0?ooh03oon00o`3oon3G0?ooh0@000006`3o
on0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh0000007
0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP04X0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000
003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon3o00000>X000006`3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=40n_3V100000020?[`
iPP000000P3jl>H4000000070?[`iP00000000000000003jl>H000000?[`iP0<000000030?[`iP00
0000000000@0000000@0n_3V0000000000000000203jl>H5000000@0n_3V1`0000000`3jl>H00000
0?[`iP03000000P0n_3V1@0000020?[`iP@000000P3jl>H5000000`0n_3V0`00000A0?[`iP<00000
1P3jl>H3000000040?[`iP0000000000000000H0n_3V00<000000?[`iP3jl>H0103jl>H300000004
0?[`iP000000000000000=P0n_3V0@3oool00=80n_3V0P0000020?[`iP8000000`3jl>H2000000<0
n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP0400000080n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000T0n_3V00@00000
0?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H00000
0?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP800000
00<0n_3V0000000000003`3jl>H2000000030?[`iP000000000000H0n_3V0P0000000`3jl>H00000
000000070?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003I0?[`iP40oooo
003B0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0
n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP800000
00<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP800000
3@3jl>H2000000030?[`iP000000000000D0n_3V1@0000050?[`iP80000000<0n_3V000000000000
1`3jl>H3000000H0n_3V1@0000060?[`iP<00000fP3jl>H10?ooo`00dP3jl>H5000000@0n_3V0P00
00030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<0
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<0
00000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`
iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000003@3jl>H2000000030?[`iP0000000000
00l0n_3V0P0000000`3jl>H00000000000070?[`iP<00000203jl>H00`000000n_3V0?[`iP060?[`
iP<00000fP3jl>H10?ooo`00dP3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080
n_3V0P0000001P3jl>H000000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000
103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V0P00
00020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V00X0n_3V0`00000@0?[`iP@000001`3j
l>H2000000030?[`iP000000000000L0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00
000000000=T0n_3V0@3oool00=80n_3V0P0000020?[`iP80000000<0n_3V0000000000000P000004
0?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3jl>H500000080n_3V1@00000:
0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000002P3jl>H500000080n_3V10000002
0?[`iP<0000000<0n_3V0000000000002P3jl>H2000000030?[`iP000000000000l0n_3V0P000008
0?[`iP<0000000@0n_3V00000000000000003@3jl>H3000000030?[`iP000000000000D00000e03j
l>H10?ooo`00dP3jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0G
0?[`iP8000006P3jl>H2000000030?[`iP00000000000100n_3V0P00000S0?[`iP030000003jl>H0
n_3V0=@0n_3V0@3oool00=40n_3V1P0000040?[`iP800000;`3jl>H5000001X0n_3V0`00000I0?[`
iP<000004P3jl>H300000280n_3V00<000000?[`iP3jl>H0d`3jl>H10?ooo`00o`3jl>J30?[`iP03
0000003jl>H0n_3V0=80n_3V0@3oool00?l0n_3VP03jl>H010000000n_3V0?[`iP00003D0?[`iP40
oooo003o0?[`iX40n_3V0P00003E0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .59679 L
.11324 .59679 L
.11324 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .59679 L
.11324 .59679 L
.11324 .08012 L
s
.678 .847 .902 r
.11324 .08012 m
.11324 .38825 L
.25323 .38825 L
.25323 .08012 L
F
.2 .63 .79 r
.11324 .08012 m
.11324 .38825 L
.25323 .38825 L
.25323 .08012 L
s
.678 .847 .902 r
.25323 .08012 m
.25323 .31218 L
.33361 .31218 L
.33361 .08012 L
F
.2 .63 .79 r
.25323 .08012 m
.25323 .31218 L
.33361 .31218 L
.33361 .08012 L
s
.678 .847 .902 r
.33361 .08012 m
.33361 .23159 L
.51052 .23159 L
.51052 .08012 L
F
.2 .63 .79 r
.33361 .08012 m
.33361 .23159 L
.51052 .23159 L
.51052 .08012 L
s
.678 .847 .902 r
.51052 .08012 m
.51052 .08175 L
.70732 .08175 L
.70732 .08012 L
F
.2 .63 .79 r
.51052 .08012 m
.51052 .08175 L
.70732 .08175 L
.70732 .08012 L
s
1 .894 .882 r
.70732 .08012 m
.70732 .0312 L
.82974 .0312 L
.82974 .08012 L
F
.804 .522 .247 r
.70732 .08012 m
.70732 .0312 L
.82974 .0312 L
.82974 .08012 L
s
1 .894 .882 r
.82974 .08012 m
.82974 .02605 L
.97619 .02605 L
.97619 .08012 L
F
.804 .522 .247 r
.82974 .08012 m
.82974 .02605 L
.97619 .02605 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.0291 .59679 Mdot
.2175 .38825 Mdot
.29915 .31218 Mdot
.39809 .23159 Mdot
.65479 .08175 Mdot
.81679 .0312 Mdot
.84403 .02605 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.619925) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.83801) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000030?[`iPH0
0000o`3jl>JR0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000040?[`iP80000000<0
n_3V0000000000000P3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VY03jl>H10?ooo`00803jl>H2
000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000
n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000006`3jl>H2000000T0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP800000o`3j
l>JT0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003j
l>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000=0?[`iP8000002@3jl>H200000003
0?[`iP000000000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000@0n_3V0P00003o0?[`iZ@0n_3V0@3oool00200n_3V0P0000020?[`iP800000
0`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H20000
00@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02
000001P0n_3V00<000000?[`iP3jl>H00P00000:0?[`iP<00000103jl>H3000000@0n_3V0`000003
0?[`iP80000000<0n_3V000000000000103jl>H200000?l0n_3VY03jl>H10?ooo`00803jl>H20000
0080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H00000000000050000
0080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000
000000001`00000I0?[`iP@000002P3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00003o0?[`
iZ@0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3j
l>H09@3jl>H2000000`0n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V0080
00000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP@0
0000o`3jl>JT0?[`iP40oooo000O0?[`iPH00000103jl>H2000002l0n_3V1@00000W0?[`iPD00000
2P3jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P00003o0?[`iZ@0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V
0@3oool00200n_3V1P0000001@3jl>H00000000000000000n_3V00<000000P3jl>H3000000<0n_3V
100000030?[`iP80000000@0n_3V000000000000n_3V1@0000030?[`iP`00000;`3jl>H3000000@0
n_3V0P00003o0?[`i/T0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V000000000000
0P3jl>H200000080n_3V00@000000?[`iP00000000000`3jl>H01@000000n_3V000000000000n_3V
00<000000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000280n_3V1@0000090?[`
iP80000000<0n_3V0000000000000`3jl>H200000?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0
n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H2000000D0n_3V0P0000020?[`iP80
00000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H0
00000000003o0?[`i/h0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V000000000000
0P3jl>H2000000@0n_3V1P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000D0n_3V
1@0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H000000000003o0?[`i/h0n_3V
0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P00
00020?[`iP80000000@0n_3V000000000000n_3V0`0000020?[`iP<0000000<0n_3V0000003jl>H0
103jl>H2000000<0n_3V0P00000`0?[`iP@00000o`3jl>K?0?[`iP40oooo000R0?[`iP8000000`3j
l>H500000080n_3V1@0000030?[`iP@000000`3jl>H2000000030?[`iP000000000000@0000000<0
n_3V0000000000000P3jl>H4000000@0n_3V0P00000`0?[`iP800000o`3jl>KA0?[`iP40oooo000R
0?[`iP8000002`3jl>H200000280n_3V0P00000a0?[`iP800000o`3jl>K@0?[`iP40oooo000P0?[`
iPH000002@3jl>H200000200n_3V1000000b0?[`iP<00000o`3jl>K>0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
02H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`
iP40oooo000W0?[`iP040000003jl>H000000?[`iP8000000P3jl>H00`000000n_3V0?[`iP030000
0?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P0000001@3jl>H0
00000?[`iP000000n_3V00<000000P3jl>H00`000000n_3V0000000I0?[`iP<00000g03jl>H40000
00@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H40000
0080n_3V0`000000103jl>H000000000000000080?[`iP@0000000<0n_3V0000000000000P3jl>H4
00000080n_3V1@0000001`3jl>H00000000000000000n_3V0000003jl>H00`00000H0?[`iP<00000
103jl>H2000000D0n_3V0`0000030?[`iPH0000000@0n_3V0000000000000000103jl>H3000000@0
n_3V1@0000030?[`iP<00000N@3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D00000
00@0n_3V00000000000000000P3jl>H2000000030?[`iP000000000000T0n_3V1@0000090?[`iP03
0000003jl>H0n_3V00800000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0
n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`
iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`iP800000103jl>H2
000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H0000000000003
0?[`iP800000103jl>H2000000030?[`iP000000000000@0n_3V0P0000050?[`iP8000001@3jl>H2
000000<0n_3V0P0000050?[`iP030000003jl>H0n_3V00800000N03jl>H10?ooo`008P3jl>H30000
02/0n_3V0P00003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00030?[`iP000000000000X0n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H2
00000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V
0000000000002@3jl>H2000000030?[`iP000000000000@0n_3V0P0000060?[`iP8000001@3jl>H2
000000<0n_3V0P0000070?[`iP800000N03jl>H10?ooo`008P3jl>H3000001X0n_3V1@00000<0?[`
iP800000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`
iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP0000000000
00X0n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P000004
0?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000
000000T0n_3V0P0000000`3jl>H00000000000040?[`iP800000103jl>H4000000<0n_3V10000004
0?[`iP8000001P3jl>H2000007P0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000X0?[`
iP<00000g@3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000
003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V0P0000000`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P00
00020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00
000H0?[`iP80000000<0n_3V0000000000002@3jl>H4000000D0n_3V0P0000030?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP030000003j
l>H0n_3V00800000N03jl>H10?ooo`00803jl>H3000000040?[`iP0000000000000002T0n_3V0P00
003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000
003jl>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD00000
2`3jl>H3000000030?[`iP00000000000080n_3V100000020?[`iP<0000000<0n_3V000000000000
1`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H2000000L0n_3V0P0000030?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP@00000N@3jl>H10?ooo`00C@3jl>H00`000000n_3V0?[`iP0200000=`0n_3V0P00
00000`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`iP800000;P3j
l>H2000000030?[`iP000000000000X0n_3V0P0000040?[`iP@000000`3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3j
l>H2000007/0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P000004
0?[`iP8000001P3jl>H2000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000<
0?[`iP<00000103jl>H2000000@0n_3V0`0000040?[`iP<00000103jl>H3000000<0n_3V1@00001h
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3j
l>HS0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`iP0000000P3jl>H010000000n_3V0?[`
iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0
n_3V0000000000000P000000103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V00000080
n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080
n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V00000000
00001P00000L0?[`iP800000b03jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D00000
00D0n_3V00000000000000000?[`iP04000000/0n_3V1@0000090?[`iP80000000<0n_3V00000000
0000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP04
0000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00
000;0?[`iPD000002`3jl>H200000<P0n_3V0@3oool00280n_3V0`00000X0?[`iP80000000<0n_3V
000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P000006
0?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000
0`3jl>H00000000000030?[`iP@000006`3jl>H200000<P0n_3V0@3oool00280n_3V0`0000090?[`
iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H40000
00<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP@000003@3jl>H5
000000/0n_3V0P0000380?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000009`3jl>H20000
00030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H30000
00040?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP800000703j
l>H200000<L0n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0
n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<0000000@0
n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@00000
0P3jl>H5000000<0n_3V1@00000L0?[`iP800000a`3jl>H10?ooo`00C@3jl>H2000000030?[`iP00
000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2000003P0n_3V00<0
00000?[`iP3jl>H00P0000370?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P000006
0?[`iP800000103jl>H2000000H0n_3V0P00000`0?[`iPD00000a`3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0n_3V8`3oon02000004D0oooP0P00
00040?ooh0800000103oon02000004@0oooP1@0000130?ooh0D000000P3oon02000000@0oooP0P00
00140?ooh0@00000A03oon04000000<0oooP0P0000040?ooh0800000A@3oon02000002L0oooP7P3j
l>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon000000
203oon0010000000oooP0?ooh00000150?ooh0030000003oon00oooP04D0oooP00<000000?ooh03o
on001`3oon0010000000oooP0?ooh00000130?ooh0030000003oon00oooP04D0oooP00<000000?oo
h03oon002@3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP000002H0oooP7P3j
l>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon000000
2`3oon000`000000oooP0?ooh0130?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00
2P3oon000`000000oooP0?ooh0120?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00
2`3oon000`000000oooP0?ooh0130?ooh0030000003oon00oooP02D0oooP7P3jl>H10?ooo`007@3j
l>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon0000002@3oon02000004H0
oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0800000AP3oon000`000000
oooP0?ooh0150?ooh0030000003oon00oooP00P0oooP0P0000170?ooh0030000003oon00oooP02@0
oooP7P3jl>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03o
on0000002@3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP04D0oooP00<000000?oo
h03oon00203oon000`000000oooP0?ooh0130?ooh0040000003oon00oooP000004@0oooP00@00000
0?ooh03oon0000002@3oon000`000000oooP0?ooh0130?ooh0040000003oon00oooP000002H0oooP
7P3jl>H10?ooo`007@3jl>HS0?ooh0800000A@3oon02000000X0oooP0`0000140?ooh0800000AP3o
on02000000X0oooP0`0000140?ooh0800000AP3oon02000000X0oooP0`0000140?ooh08000009`3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh?l00000jP00000K0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<0
00000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01:0?oo
h0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01;0?oo
h0030000003oon00oooP04X0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o
0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`00003o0?oo
h<40oooP6P000?l90?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on00o`3oon2i0?ooh0P0003o9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh;00oooP2@000?l]0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPYP3oon0:0000ocH0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2I
0?ooh08000000`3oon080000od00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon2C0?ooh0D0cHDo1P000?lm0<f5?`/0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2<0?ooh080
00000`3oon070000o`@00000?P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPR`3oon000`000000003o
0000o`030000o`80oooP00<0cHDo0?oTh@3oi>400`3oi>42000003l0onCQ00<0cHDo0?ooh03oon00
2@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh5L0oooP<@3=QCl40000o`<000001@3=QCm60?oTh@030<f5?`3oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1G
0?ooh0030<f5?`3oi>40onCQ02X0onCQ10000?l40?oTh@8000001@3oi>400`3=QCl0onCQ0?oTh@14
0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon1G0?ooh0030<f5?`3oi>40onCQ02H0onCQ10000?l?0?oT
h@030<f5?`3oi>40onCQ04@0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5L0oooP00<0cHDo0?oTh@3o
i>408P3oi>440000oa<0onCQ00<0cHDo0?oTh@3oi>40A03oi>400`3=QCl0oooP0?ooh0090?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
E`3oon000`3=QCl0onCQ0?oTh@0N0?oTh@@0003o5`3oi>400`3=QCl0onCQ0?oTh@140?oTh@030<f5
?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00o`3oon1G0?ooh0030<f5?`3oi>40onCQ01X0onCQ10000?lK0?oTh@030<f5?`3o
i>40onCQ04@0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5L0oooP00<0cHDo0?oTh@3oi>405P3oi>44
0000oal0onCQ00<0cHDo0?oTh@3oi>40A03oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPE`3oon000`3=
QCl0onCQ0?oTh@0B0?oTh@@0003o8`3oi>400`3=QCl0onCQ0?oTh@140?oTh@030<f5?`3oon00oooP
00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`00003o0?ooh5L0
oooP00<0cHDo0?oTh@3oi>403P3oi>440000obL0onCQ00<0cHDo0?oTh@3oi>40A03oi>400`3=QCl0
oooP0?ooh0070?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon1G0?ooh0030<f5?`3oi>40onCQ00/0onCQ0`000?l[0?oTh@030<f5?`3oi>40onCQ04@0onCQ
00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh5L0oooP00<0cHDo0?oTh@3oi>40203oi>430000obh0onCQ00<0
cHDo0?oTh@3oi>40A03oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPE`3oon000`3=QCl0onCQ0?oTh@05
0?oTh@<0003o<@3oi>400`3=QCl0onCQ0?oTh@140?oTh@030<f5?`3oon00oooP00T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1G0?oo
h0030<f5?`3oi>40onCQ00<0onCQ0P000?ld0?oTh@030<f5?`3oi>40onCQ04@0onCQ00<0cHDo0?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh5L0oooP00<0cHDo0?oTh@3oi>400`000?lf0?oTh@030<f5?`3oi>40onCQ04@0
onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh5L0oooP0`000?li0?oTh@030<f5?`3oi>40onCQ04@0onCQ
00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh5@0oooP0`000?l00`3=QCl0onCQ0?oTh@0i0?oTh@030<f5?`3o
i>40onCQ04@0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh540oooP0`000?l30?ooh0030<f5?`3oi>40
onCQ03T0onCQ00<0cHDo0?oTh@3oi>40A03oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPC`3oon020000
o`H0oooP00<0cHDo0?oTh@3oi>40>@3oi>400`3=QCl0onCQ0?oTh@140?oTh@030<f5?`3oon00oooP
00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on00o`3oon1<0?ooh0<0003o203oon000`3=QCl0onCQ0?oTh@0i0?oTh@030<f5?`3oi>40onCQ04@0
onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh4X0oooP0P000?l;0?ooh0030<f5?`3oi>40onCQ03T0onCQ
00<0cHDo0?oTh@3oi>40A03oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPA`3oon030000o`d0oooP00<0
cHDo0?oTh@3oi>40>@3oi>400`3=QCl0onCQ0?oTh@140?oTh@030<f5?`3oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00
oooP0?l0oooPA03oon030000oa00oooP00<0cHDo0?oTh@3oi>40>@3oi>400`3=QCl0onCQ0?oTh@14
0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh480oooP0P000?lC
0?ooh0030<f5?`3oi>40onCQ03T0onCQ00<0cHDo0?oTh@3oi>40A03oi>400`3=QCl0oooP0?ooh009
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP
000000L0oooP100000080?ooh?l00000=P0000030000oiT00000203oon04000001/0oooP7P3jl>H1
0?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H0
0`0cXLX0[MSV0:gHiP1C0:gHiTD0<j7:00@000000000o`000?l00000600cXLZ>0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0
<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1C0:gHiP0303>QbP3oon00oooP0440oooP0P00
0?l300000:H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P000008
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP12
0:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP0?ooh00o
0?ooh080003o0P3oon0200000:L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV
0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1C0:gHiP0303>QbP3oon00oooP
03d0oooP0P000?n]0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP03
03>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP0?ooh00j0?ooh0<0
003o[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV
0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05<0[MSV00<0<j7:0?ooh03oon00>03oon020000ok80oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]
f>H00`0cXLX0[MSV0:gHiP1C0:gHiP0303>QbP3oon00oooP03H0oooP0P000?nd0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:
0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP0?ooh00d0?ooh080003o]P3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV
05<0[MSV00<0<j7:0?ooh03oon00<P3oon020000okP0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP03
03>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1C0:gHiP03
03>QbP3oon00oooP0300oooP0P000?nj0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV
0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP
0?ooh00^0?ooh080003o_03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]
f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05<0[MSV00<0<j7:0?ooh03oon00;03o
on020000okh0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:
0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1C0:gHiP0303>QbP3oon00oooP02X0oooP0P000?o0
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV
02@0[MSV00<0<j7:0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP0?ooh00X0?ooh080003o`P3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP03
03>QbP2]f>H0[MSV05<0[MSV00<0<j7:0?ooh03oon009P3oon020000ol@0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV02P0[MSV
00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05<0[MSV
00<0<j7:0?ooh03oon00903oon020000ol@0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]
f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05<0[MSV00<0<j7:0?ooh03oon008P3o
on020000olP0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:
0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1C0:gHiP0303>QbP3oon00oooP0200oooP0P000?o:
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV
02@0[MSV00<0<j7:0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP0?ooh00N0?ooh080003oc03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP03
03>QbP2]f>H0[MSV05<0[MSV00<0<j7:0?ooh03oon00703oon020000olh0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV
0:gHiP1C0:gHiP0303>QbP3oon00oooP01X0oooP0P000?o@0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]
f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0D`2]
f>H00`0cXLX0oooP0?ooh00H0?ooh080003odP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:
0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05<0[MSV00<0<j7:
0?ooh03oon005P3oon020000om@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV
0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1C0:gHiP0303>QbP3oon00oooP
01@0oooP0P000?oF0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP03
03>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP0?ooh00B0?ooh080
003of03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV
0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05<0[MSV00<0<j7:0?ooh03oon00403oon020000omX0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]
f>H00`0cXLX0[MSV0:gHiP1C0:gHiP0303>QbP3oon00oooP00h0oooP0P000?oL0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:
0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP0?ooh00<0?ooh080003ogP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV
05<0[MSV00<0<j7:0?ooh03oon002`3oon000`000?l0oooP0?ooh03N0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]
f>H0D`2]f>H00`0cXLX0oooP0?ooh0090?ooh080003oh@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV
00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05<0[MSV
00<0<j7:0?ooh03oon001`3oon020000on<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]
f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV05<0[MSV00<0<j7:0?ooh03oon001@3o
on020000on<0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T
0:gHiP0303>QbP2]f>H0[MSV05<0[MSV00<0<j7:0?ooh03oon00103oon000`000?l0oooP0?ooh03U
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV
02@0[MSV00<0<j7:0:gHiP2]f>H0D`2]f>H00`0cXLX0oooP0?ooh0020?ooh080003oj03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP03
03>QbP2]f>H0[MSV05<0[MSV00<0<j7:0?ooh03oon000P000?oZ0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0
D`2]f>H00`0cXLX0oooP0000o`3/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gH
iP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0D`2]f>H20000ond0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H0
0`0cXLX0[MSV0:gHiP1A0:gHiP80003o00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV
04l0[MSV0P000?l20:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP03
03>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1>0:gHiP03
0000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV
00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV04`0[MSV
0P000?l50:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]
f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP1;0:gHiP030000o`2]
f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:
0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV04T0[MSV0P000?l8
0:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV
0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP170:gHiP80003o2P2]f>H00`0c
XLX0oooP0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP03
03>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0AP2]f>H00`000?l0[MSV0:gHiP0:0:gHiP03
03>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV
00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP140:gHiP80003o3@2]f>H00`0cXLX0oooP
0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]
f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0@`2]f>H00`000?l0[MSV0:gHiP0=0:gHiP0303>QbP3o
on00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`000009
0?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T
0:gHiP0303>QbP2]f>H0[MSV0440[MSV0P000?l@0:gHiP0303>QbP3oon00oooP0>X0oooP0`00000K
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV
03l0[MSV0P000?lB0:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP03
03>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0n0:gHiP03
0000o`2]f>H0[MSV0180[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV
00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV03`0[MSV
0P000?lE0:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]
f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0k0:gHiP030000o`2]
f>H0[MSV01D0[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:
0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV03T0[MSV0P000?lH
0:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV
0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0h0:gHiP030000o`2]f>H0[MSV
01P0[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]
f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV03L0[MSV00<0003o0:gHiP2]
f>H06@2]f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV
0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H20000oa`0[MSV
00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]
f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV03@0[MSV00<0003o0:gHiP2]f>H0702]
f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP12
0:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`000?l0[MSV0:gHiP0M
0:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV
0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0a0:gHiP80003o802]f>H00`0c
XLX0oooP0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP03
03>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H0<02]f>H00`000?l0[MSV0:gHiP0P0:gHiP03
03>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV
00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0_0:gHiP030000o`2]f>H0[MSV0240[MSV
00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3o
on04000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]
f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0]0:gHiP80003o902]
f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=
0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X
0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0/
0:gHiP030000o`2]f>H0[MSV02@0[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V3P3oon000`000000oooP0?ooh0070?ooh0@00000203oon000`0c
XLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0c
XLX0[MSV0:gHiP0[0:gHiP030000o`2]f>H0[MSV02D0[MSV00<0<j7:0?ooh03oon00j@3oon040000
01/0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]
f>H0902]f>H00`0cXLX0[MSV0:gHiP0Y0:gHiP80003o:02]f>H00`0cXLX0oooP0?ooh03/0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480
[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0X0:gHiP030000o`2]f>H0[MSV02P0
[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
3P3oon02000000P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>Q
bP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0V0:gHiP80003o
:`2]f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gH
iP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0:gHiP2]f>H09@2]f>H00`000?l0[MSV0:gH
iP0[0:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0
[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP030000o`2]f>H0
[MSV02`0[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gH
iP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV0280[MSV0P000?l_0:gH
iP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480
[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP030000o`2]f>H0[MSV02l0
[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0
@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP2]f>H0[MSV01l0[MSV0P000?lb0:gHiP0303>Q
bP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0
<j7:0:gHiP2]f>H0902]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP80000000<0003o0:gHiP2]f>H0<P2]
f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP12
0:gHiP0303>QbP2]f>H0[MSV02@0[MSV7P0cXLX010000000003o0000o`00000e03>Qb^h0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H0
0`0cXLX0oooP0?ooh00K0?ooh0040000o`000000000000000?l0oooP903oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP3oon00
oooP01X0oooP00@0003o0?ooh00000000000o`3oon0U0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H0
0`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0?ooh03oon00603oon02
0000ool0oooP:@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0c
XLX0[MSV0:gHiP0T0:gHiP0303>QbP3oon00oooP01L0oooP00<0003o0?ooh03oon00o`3oon0Y0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0
[MSV00<0<j7:0?ooh03oon005@3oon020000ool0oooP;03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV
0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0?ooh03oon00503oon000`000?l0oooP
0?ooh03o0?ooh2X0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gH
iP0T0:gHiP0303>QbP3oon00oooP01<0oooP00<0003o0?ooh03oon00o`3oon0]0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:
0?ooh03oon004@3oon020000ool0oooP<03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gH
iP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP3oon00oooP0100oooP00<0003o0?oo
h03oon00o`3oon0`0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP03
03>QbP2]f>H0[MSV02@0[MSV00<0<j7:0?ooh03oon003`3oon000`000?l0oooP0?ooh03o0?ooh340
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0
902]f>H00`0cXLX0oooP0?ooh00>0?ooh0030000o`3oon00oooP0?l0oooP<P3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP3o
on00oooP00`0oooP0P000?oo0?ooh3D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0
[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0oooP0?ooh00;0?ooh0030000o`3oon00
oooP0?l0oooP=@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0c
XLX0[MSV0:gHiP0T0:gHiP0303>QbP3oon00oooP00X0oooP00<0003o0?ooh03oon00o`3oon0f0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV02@0
[MSV00<0<j7:0?ooh03oon00203oon020000ool0oooP>@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV
00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP3oon00oooP00L0oooP
00<0003o0?ooh03oon00o`3oon0i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gH
iP120:gHiP0303>QbP2]f>H0[MSV02@0[MSV00<0<j7:0?ooh03oon001P3oon000`000?l0oooP0?oo
h03o0?ooh3X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:
0:gHiP2]f>H0902]f>H00`0cXLX0oooP0?ooh0050?ooh0030000o`3oon00oooP0?l0oooP>`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gH
iP0303>QbP3oon00oooP00<0oooP0P000?oo0?ooh3h0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP03
03>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H00`0cXLX0oooP0?ooh0020?ooh003
0000o`3oon00oooP0?l0oooP?P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0
@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0503>QbP3oon00oooP0?ooh0000?l0o`3oon110?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV
0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H0902]f>H0100cXLX0oooP
0?ooh0000?oo0?ooh400oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV
0:gHiP0T0:gHiP0303>QbP3oon00003o0?l0oooP@`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0
<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0T0:gHiP0303>QbP000?l0oooP0?l0oooP@`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0S
0:gHiP80003oo`3oon150?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gH
iP0303>QbP2]f>H0[MSV0280[MSV00<0003o0:gHiP0cXLX0o`3oon150?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV0240[MSV00@0003o0:gHiP2]
f>H0<j7:o`3oon150?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP03
03>QbP2]f>H0[MSV0200[MSV00D0003o0:gHiP2]f>H0[MSV03>QbP3o0?ooh4D0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`000?l0
[MSV0:gHiP020:gHiP0303>QbP3oon00oooP0?l0oooP@`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV
00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP030000o`2]f>H0[MSV00<0[MSV
00<0<j7:0?ooh03oon00o`3oon130?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gH
iP120:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0003o0:gHiP2]f>H0102]f>H00`0cXLX0oooP0?oo
h03o0?ooh4<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:
0:gHiP2]f>H0702]f>H00`000?l0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP0?l0oooP@`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0[MSV0:gHiP0K0:gH
iP030000o`2]f>H0[MSV00H0[MSV00<0<j7:0?ooh03oon00o`3oon130?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV01T0[MSV0P000?l90:gHiP03
03>QbP3oon00oooP0?l0oooP@`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0
@P2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP030000o`2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon00
o`3oon130?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP2]
f>H0[MSV01L0[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0oooP0?ooh03o0?ooh4<0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0:gHiP2]f>H05P2]f>H0
0`000?l0[MSV0:gHiP0;0:gHiP0303>QbP3oon00oooP0?l0oooP@`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0c
XLX0[MSV0:gHiP120:gHiP0303>QbP2]f>H0[MSV0180[MSV0P0000000`2]f>H0003o0:gHiP0=0:gH
iP0303>QbP3oon00oooP0?l0oooP@@3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP03
03>QbP2]f>H0[MSV0140[MSV0`0000000`000?l0[MSV0:gHiP0=0:gHiP0303>QbP3oon00oooP0?l0
oooP@`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>HD03>QbP800000
00<0003o0000000cXLX03`0cXL[o0?ooh4D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]
f>H0[MSV0480[MSV00<0<j7:0?ooh03oon004P3oon000`000?l000000?ooh03o0?ooh5D0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0480[MSV00<0<j7:0?ooh03oon004@3oon00
0`000?l0oooP0?ooh03o0?ooh5H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV
0480[MSV00<0<j7:0?ooh03oon003`3oon020000ool0oooPF@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0
[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0oooP0?ooh00>0?ooh0030000o`3oon00oooP0?l0
oooPF@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0oooP
0?ooh00=0?ooh0030000o`3oon00oooP0?l0oooPFP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0
<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0oooP0?ooh00<0?ooh0030000o`3oon00oooP0?l0oooPF`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0oooP0?ooh00;
0?ooh0030000o`3oon00oooP0?l0oooPG03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gH
iP2]f>H0@P2]f>H00`0cXLX0oooP0?ooh00:0?ooh0030000o`3oon00oooP0?l0oooPG@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0oooP0?ooh0090?ooh003
0000o`3oon00oooP0?l0oooPGP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0
@P2]f>H00`0cXLX0oooP0?ooh0080?ooh0030000o`3oon00oooP0?l0oooPG`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0oooP0?ooh0070?ooh0030000o`3o
on00oooP0?l0oooPH03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3`3oon03
000000H0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0
[MSV0480[MSV00<0<j7:0?ooh03oon001@3oon020000ool0oooPH`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh0050?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP3oon00oooP
00@0oooP00<0003o0?ooh03oon00o`3oon1S0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H=0?ooh0D000001P3oon04000000P0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0
[MSV0:gHiP120:gHiP0303>QbP3oon00oooP00<0oooP00<0003o0?ooh03oon00o`3oon1Q0?ooh0@0
00006`3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`0cXLX0
oooP0?ooh0020?ooh0030000o`3oon00oooP0?l0oooPI@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V3P3oon000`000000oooP000000070?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP120:gHiP0503>QbP3oon00oooP0?ooh000
0?l0o`3oon1X0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh0800000
1`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0
@P2]f>H0100cXLX0oooP0?ooh0000?oo0?ooh6T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>Q
bP2]f>H0[MSV0480[MSV00<0<j7:0?ooh0000?l0o`3oon1Z0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]
f>H00`0cXLX0[MSV0:gHiP120:gHiP0303>QbP000?l0oooP0?l0oooPJP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0@P2]f>H00`000?l0oooP0?ooh03o0?ooh6X0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV0440[MSV00<0003o03>QbP3oon00o`3oon1[0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV0:gHiP100:gHiP030000o`2]f>H0<j7:0?l0
oooPK03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0?`2]f>H010000?l0[MSV
0:gHiP0cXL[o0?ooh6`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV03h0[MSV
00D0003o0:gHiP2]f>H0[MSV03>QbP3o0?ooh6`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>Q
bP2]f>H0[MSV03`0[MSV0P000?l40:gHiP0303>QbP3oon00oooP0?l0oooPJP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0>`2]f>H00`000?l0[MSV0:gHiP040:gHiP0303>QbP3o
on00oooP0?l0oooPJP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0>P2]f>H0
0`000?l0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP0?l0oooPJP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
02P0[MSV00<0<j7:0:gHiP2]f>H0>@2]f>H00`000?l0[MSV0:gHiP060:gHiP0303>QbP3oon00oooP
0?l0oooPJP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0>02]f>H00`000?l0
[MSV0:gHiP070:gHiP0303>QbP3oon00oooP0?l0oooPJP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0[MSV
0:gHiP0g0:gHiP030000o`2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon00o`3oon1X0?ooh0<00000
6`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0X0:gHiP0303>QbP2]f>H0[MSV03H0[MSV00<0003o0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?oo
h03o0?ooh6X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0003o
0:gHiP2]f>H02P2]f>H00`0cXLX0oooP0?ooh03o0?ooh6X0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gH
iP0303>QbP2]f>H0[MSV03@0[MSV00<0003o0:gHiP2]f>H02`2]f>H00`0cXLX0oooP0?ooh03o0?oo
h6X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0003o0:gHiP2]
f>H0302]f>H00`0cXLX0oooP0?ooh03o0?ooh6X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>Q
bP2]f>H0[MSV0300[MSV0P0000000`000?l0[MSV0:gHiP0=0:gHiP0303>QbP3oon00oooP0?l0oooP
JP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0:gHiP2]f>H0;`2]f>H2000000030000o`00
0000[MSV00h0[MSV00<0<j7:0?ooh03oon00o`3oon1Z0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>Hb
03>QbP04000000000?l0000000000100<j7:o`3oon1/0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H0
0`0cXLX0oooP0?ooh00_0?ooh0030000o`00000000000?l0oooPO@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
02P0[MSV00<0<j7:0?ooh03oon00;P3oon000`000?l0oooP0?ooh03o0?ooh7h0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP02d0oooP00<0003o0?ooh03oon00o`3oon1o0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00/0?ooh0030000o`3oon00oooP0?l0oooP
P03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon00:`3oon000`000?l0oooP0?oo
h03o0?ooh840oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP02X0oooP00<0003o
0?ooh03oon00o`3oon220?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00Y0?oo
h0030000o`3oon00oooP0?l0oooPP`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03o
on00:03oon000`000?l0oooP0?ooh03o0?ooh8@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon00
9`3oon000`000?l0oooP0?ooh03o0?ooh8<0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon009P3o
on000`000?l0oooP0?ooh03o0?ooh8H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3oon00
oooP02D0oooP00<0003o0?ooh03oon00o`3oon270?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0c
XLX0oooP0?ooh00T0?ooh0030000o`3oon00oooP0?l0oooPR03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0
[MSV00<0<j7:0?ooh03oon008`3oon000`000?l0oooP0?ooh03o0?ooh8T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0X0:gHiP0303>QbP3oon00oooP0280oooP00<0003o0?ooh03oon00o`3oon2:0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00Q0?ooh0030000o`3oon00oooP0?l0oooPR`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon00803oon000`000?l0oooP0?ooh03o
0?ooh8`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP01l0oooP00<0003o0?oo
h03oon00o`3oon2=0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00N0?ooh003
0000o`3oon00oooP0?l0oooPSP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon00
7@3oon000`000?l0oooP0?ooh03o0?ooh8l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3o
on00oooP01`0oooP00<0003o0?ooh03oon00o`3oon2@0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H0
0`0cXLX0oooP0?ooh00K0?ooh0030000o`3oon00oooP0?l0oooPT@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
02P0[MSV00<0<j7:0?ooh03oon006P3oon000`000?l0oooP0?ooh03o0?ooh980oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP01T0oooP00<0003o0?ooh03oon00o`3oon2C0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00H0?ooh0030000o`3oon00oooP0?l0oooP
U03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0
<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00G0?ooh0030000o`3oon00oooP0?l0oooPT`3o
on03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00F0?ooh0030000o`3oon00oooP0?l0oooPUP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon005@3oon000`000?l0oooP0?ooh03o0?oo
h9L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP01D0oooP00<0003o0?ooh03o
on00o`3oon2G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00D0?ooh0030000
o`3oon00oooP0?l0oooPV03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon004`3o
on000`000?l0oooP0?ooh03o0?ooh9T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3oon00
oooP0180oooP00<0003o0?ooh03oon00o`3oon2J0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0c
XLX0oooP0?ooh00A0?ooh0030000o`3oon00oooP0?l0oooPV`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0
[MSV00<0<j7:0?ooh03oon00403oon000`000?l0oooP0?ooh03o0?ooh9`0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0X0:gHiP0303>QbP3oon00oooP00l0oooP00<0003o0?ooh03oon00o`3oon2M0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00>0?ooh0030000o`3oon00oooP0?l0oooPWP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon003@3oon000`000?l0oooP0?ooh03o
0?ooh9l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP00`0oooP00<0003o0?oo
h03oon00o`3oon2P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP0?ooh00;0?ooh003
0000o`3oon00oooP0?l0oooPX@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
3@3oon03000000P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>Q
bP3oon00oooP00X0oooP00<0003o0?ooh03oon00o`3oon2R0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP00T0oooP00<0003o0?ooh03oon00
o`3oon2S0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003o
on00oooP000000L0oooP100000080?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon00
203oon000`000?l0oooP0?ooh03o0?ooh:40oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3o
on03000000P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3o
on00oooP00L0oooP00<0003o0?ooh03oon00o`3oon2U0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>H>0?ooh0030000003oon00oooP00L0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP00L0oooP00<0003o0?ooh03oon00o`3oon2U
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0<000001`3oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0?ooh03oon001P3oon000`00
0?l0oooP0?ooh03o0?ooh:H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP3oon00oooP00D0
oooP00<0003o0?ooh03oon00o`3oon2W0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0cXLX0oooP
0?ooh0040?ooh0030000o`3oon00oooP0?l0oooPZ03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0
<j7:0?ooh03oon000`3oon000`000?l0oooP0?ooh03o0?ooh:T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X
0:gHiP0303>QbP3oon00oooP0080oooP00<0003o0?ooh03oon00o`3oon2Z0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0:02]f>H01@0cXLX0oooP0?ooh03oon00003o0?l0oooP[@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
02P0[MSV00@0<j7:0?ooh03oon00003oo`3oon2^0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0:02]f>H00`0c
XLX0oooP0000o`3o0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP0303>QbP000?l0oooP0?l0
oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV02P0[MSV00<0<j7:0000o`3oon00o`3oon2_0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0:02]f>H00`000?l0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0W
0:gHiP030000o`0cXLX0oooP0?l0oooP/03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02H0[MSV00<0003o0:gH
iP0cXLX0o`3oon2a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<0
00002@3oon000`0cXLX0[MSV0:gHiP0U0:gHiP040000o`2]f>H0[MSV03>Qb_l0oooP[`3oon030000
01/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0902]f>H01@000?l0[MSV0:gHiP2]f>H0<j7:0?l0oooP/@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02<0
[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0R0:gHiP030000o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00o`3oon2_0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H08@2]f>H00`000?l0[MSV0:gHiP040:gHiP0303>QbP3oon00oooP0?l0oooP[`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV0240[MSV00<0003o0:gHiP2]f>H0102]f>H00`0cXLX0oooP0?ooh03o
0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0P0:gHiP030000o`2]f>H0[MSV00D0[MSV00<0<j7:0?oo
h03oon00o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H07`2]f>H00`000?l0[MSV0:gHiP060:gHiP03
03>QbP3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01h0[MSV00<0003o0:gHiP2]f>H0
1`2]f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0M0:gHiP030000o`2]
f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon00o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0702]f>H0
0`000?l0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
01`0[MSV00<0003o0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0K0:gHiP030000o`2]f>H0[MSV00X0[MSV00<0<j7:0?ooh03oon00o`3oon2_0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H06P2]f>H00`000?l0[MSV0:gHiP0;0:gHiP0303>QbP3oon00oooP0?l0oooP
[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV01T0[MSV00<0003o0:gHiP2]f>H0302]f>H00`0cXLX0oooP0?oo
h03o0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0H0:gHiP030000o`2]f>H0[MSV00d0[MSV00<0<j7:
0?ooh03oon00o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0<000002@3oon000`0cXLX0[MSV0:gHiP0G0:gHiP030000o`2]f>H0[MSV00h0[MSV00<0<j7:0?oo
h03oon00o`3oon2]0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0G0:gHiP030000o`2]f>H0[MSV00h0[MSV00<0<j7:0?ooh03o
on00o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H05P2]f>H00`000?l0[MSV0:gHiP0?0:gHiP0303>Q
bP3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01D0[MSV00<0003o0:gHiP2]f>H0402]
f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0D0:gHiP030000o`2]f>H0
[MSV0140[MSV00<0<j7:0?ooh03oon00o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`00
0?l0[MSV0:gHiP0B0:gHiP0303>QbP3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0180
[MSV00<0003o0:gHiP2]f>H04`2]f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0B0:gHiP030000o`2]f>H0[MSV01<0[MSV00<0<j7:0?ooh03oon00o`3oon2_0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H04@2]f>H00`000?l0[MSV0:gHiP0D0:gHiP0303>QbP3oon00oooP0?l0oooP[`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV0100[MSV00<0003o0:gHiP2]f>H05@2]f>H00`0cXLX0oooP0?ooh03o
0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0?0:gHiP030000o`2]f>H0[MSV01H0[MSV00<0<j7:0?oo
h03oon00o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03P2]f>H00`000?l0[MSV0:gHiP0G0:gHiP03
03>QbP3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0003o0:gHiP2]f>H0
602]f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP030000o`2]
f>H0[MSV01P0[MSV00<0<j7:0?ooh03oon00o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0302]f>H0
0`000?l0[MSV0:gHiP0I0:gHiP0303>QbP3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00/0[MSV00<0003o0:gHiP2]f>H06P2]f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV00X0
[MSV00<0003o0:gHiP2]f>H06`2]f>H00`0cXLX0oooP0?ooh03o0?ooh:d0oooP0`00000K0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00T0[MSV
00<0003o0:gHiP2]f>H0702]f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP080:gHiP030000o`2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon00o`3oon2_0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H01`2]f>H00`000?l0[MSV0:gHiP0N0:gHiP0303>QbP3oon00oooP0?l0oooP[`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H07`2]f>H00`0cXLX0oooP0?ooh03o0?oo
h:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP060:gHiP030000o`2]f>H0[MSV01l0[MSV00<0<j7:0?ooh03o
on00o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP0P0:gHiP0303>Q
bP3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0003o0:gHiP2]f>H08@2]
f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0
[MSV0280[MSV00<0<j7:0?ooh03oon00o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H00P2]f>H00`00
0?l0[MSV0:gHiP0S0:gHiP0303>QbP3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gH
iP000?l09P2]f>H00`0cXLX0oooP0?ooh03o0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00100cXLX0[MSV000000000?lW0:gH
iP0303>QbP3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP00000000000000o`0000009`0cXL[o0?oo
h;40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh003
0000003oon00oooP00X0oooP00@000000000o`0000000000o`3oon3H0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?oo
h03oon002P3oon000`000?l000000000003o0?ooh=T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon04000000P0oooP00<0003o0?oo
h03oon00o`3oon3G0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh003
0000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00
o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00BP3oon00
0`000000oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon00
0`000000oooP0?ooh01:0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon3o00000>X000006`3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00=40n_3V100000020?[`iPP000000P3jl>H4000000070?[`iP00000000000000003j
l>H000000?[`iP0<000000030?[`iP000000000000@0000000@0n_3V0000000000000000203jl>H5
000000@0n_3V1`0000000`3jl>H000000?[`iP03000000P0n_3V1@0000020?[`iP@000000P3jl>H5
000000`0n_3V0`00000A0?[`iP<000001P3jl>H3000000040?[`iP0000000000000000H0n_3V00<0
00000?[`iP3jl>H0103jl>H3000000040?[`iP000000000000000=P0n_3V0@3oool00=80n_3V0P00
00020?[`iP8000000`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H0
00000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V0000
00000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V0P00000=0?[`iP80000000<0n_3V0000000000003`3jl>H2000000030?[`iP000000
000000H0n_3V0P0000000`3jl>H00000000000070?[`iP030000003jl>H0n_3V00D0n_3V0P000000
0`3jl>H000000000003I0?[`iP40oooo003B0?[`iP80000000<0n_3V000000000000103jl>H20000
00<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP8000003@3jl>H2000000030?[`iP000000000000D0n_3V1@000005
0?[`iP80000000<0n_3V0000000000001`3jl>H3000000H0n_3V1@0000060?[`iP<00000fP3jl>H1
0?ooo`00dP3jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V0000003j
l>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`iP800000
00<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP800000
3@3jl>H2000000030?[`iP000000000000l0n_3V0P0000000`3jl>H00000000000070?[`iP<00000
203jl>H00`000000n_3V0?[`iP060?[`iP<00000fP3jl>H10?ooo`00dP3jl>H200000080n_3V0P00
00030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H000000?[`iP80
0000103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00002P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V
008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V
00X0n_3V0`00000@0?[`iP@000001`3jl>H2000000030?[`iP000000000000L0n_3V00<000000?[`
iP3jl>H01@3jl>H2000000030?[`iP00000000000=T0n_3V0@3oool00=80n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@0
00000P3jl>H500000080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L0
00002P3jl>H500000080n_3V100000020?[`iP<0000000<0n_3V0000000000002P3jl>H200000003
0?[`iP000000000000l0n_3V0P0000080?[`iP<0000000@0n_3V00000000000000003@3jl>H30000
00030?[`iP000000000000D00000e03jl>H10?ooo`00dP3jl>H200000080n_3V0P00000c0?[`iP80
00000`3jl>H00`000000n_3V0?[`iP0G0?[`iP8000006P3jl>H2000000030?[`iP00000000000100
n_3V0P00000S0?[`iP030000003jl>H0n_3V0=@0n_3V0@3oool00=40n_3V1P0000040?[`iP800000
;`3jl>H5000001X0n_3V0`00000I0?[`iP<000004P3jl>H300000280n_3V00<000000?[`iP3jl>H0
d`3jl>H10?ooo`00o`3jl>J30?[`iP030000003jl>H0n_3V0=80n_3V0@3oool00?l0n_3VP03jl>H0
10000000n_3V0?[`iP00003D0?[`iP40oooo003o0?[`iX40n_3V0P00003E0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .50726 L
.14381 .50726 L
.14381 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .50726 L
.14381 .50726 L
.14381 .08012 L
s
.678 .847 .902 r
.14381 .08012 m
.14381 .46136 L
.20805 .46136 L
.20805 .08012 L
F
.2 .63 .79 r
.14381 .08012 m
.14381 .46136 L
.20805 .46136 L
.20805 .08012 L
s
.678 .847 .902 r
.20805 .08012 m
.20805 .37002 L
.28392 .37002 L
.28392 .08012 L
F
.2 .63 .79 r
.20805 .08012 m
.20805 .37002 L
.28392 .37002 L
.28392 .08012 L
s
.678 .847 .902 r
.28392 .08012 m
.28392 .26474 L
.39658 .26474 L
.39658 .08012 L
F
.2 .63 .79 r
.28392 .08012 m
.28392 .26474 L
.39658 .26474 L
.39658 .08012 L
s
.678 .847 .902 r
.39658 .08012 m
.39658 .16836 L
.51148 .16836 L
.51148 .08012 L
F
.2 .63 .79 r
.39658 .08012 m
.39658 .16836 L
.51148 .16836 L
.51148 .08012 L
s
.678 .847 .902 r
.51148 .08012 m
.51148 .12716 L
.58425 .12716 L
.58425 .08012 L
F
.2 .63 .79 r
.51148 .08012 m
.51148 .12716 L
.58425 .12716 L
.58425 .08012 L
s
1 .894 .882 r
.58425 .08012 m
.58425 .06795 L
.71043 .06795 L
.71043 .08012 L
F
.804 .522 .247 r
.58425 .08012 m
.58425 .06795 L
.71043 .06795 L
.71043 .08012 L
s
1 .894 .882 r
.71043 .08012 m
.71043 .04343 L
.80661 .04343 L
.80661 .08012 L
F
.804 .522 .247 r
.71043 .08012 m
.71043 .04343 L
.80661 .04343 L
.80661 .08012 L
s
1 .894 .882 r
.80661 .08012 m
.80661 .03212 L
.89644 .03212 L
.89644 .08012 L
F
.804 .522 .247 r
.80661 .08012 m
.80661 .03212 L
.89644 .03212 L
.89644 .08012 L
s
1 .894 .882 r
.89644 .08012 m
.89644 .0181 L
.97619 .0181 L
.97619 .08012 L
F
.804 .522 .247 r
.89644 .08012 m
.89644 .0181 L
.97619 .0181 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.10498 .50726 Mdot
.14656 .46136 Mdot
.23624 .37002 Mdot
.35548 .26474 Mdot
.48961 .16836 Mdot
.55992 .12716 Mdot
.68977 .06795 Mdot
.76582 .04343 Mdot
.81244 .03212 Mdot
.90397 .0181 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.397469) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.67315) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000050?[`iP800000103jl>H3000000<0n_3V1P0000020?[`iP<0
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000040?[`iP80000000<0
n_3V000000000000103jl>H2000000<0n_3V00<000000?[`iP3jl>H00P0000040?[`iP8000000`3j
l>H00`000000n_3V0?[`iP0200000?l0n_3VX`3jl>H10?ooo`00803jl>H2000000030?[`iP000000
000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000006`3j
l>H2000000T0n_3V0P0000000`3jl>H00000000000040?[`iP8000001P3jl>H2000000@0n_3V0P00
00060?[`iP800000o`3jl>JS0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P000000
1P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP800000
00@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000=0?[`iP80
00002@3jl>H2000000030?[`iP000000000000@0n_3V0P0000060?[`iP800000103jl>H2000000H0
n_3V0P00003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V
0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`
iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V00<00000
0?[`iP3jl>H00P0000090?[`iP@000001P3jl>H2000000<0n_3V0`0000050?[`iP8000000`3jl>H0
0`000000n_3V0?[`iP0200000?l0n_3VX`3jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3j
l>H0000000000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`
iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`
iP@000002P3jl>H2000000P0n_3V0P0000050?[`iP800000103jl>H2000000<0n_3V1000003o0?[`
iZ@0n_3V0@3oool00200n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3j
l>H09@3jl>H2000000d0n_3V0P0000040?[`iP030000003jl>H0n_3V008000000P3jl>H00`000000
n_3V0?[`iP0200000080n_3V100000030?[`iP800000o`3jl>JV0?[`iP40oooo000O0?[`iPH00000
103jl>H2000002l0n_3V1@00000W0?[`iPD000002`3jl>H300000080n_3V1@0000030?[`iP<00000
1@3jl>H2000000<0n_3V1@00003o0?[`iZ<0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40
oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200n_3V1P0000001@3jl>H000000000
00000000n_3V00<000000P3jl>H3000000<0n_3V100000030?[`iP80000000@0n_3V000000000000
n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P00003o0?[`i/T0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V00@000000?[`iP000000
00000`3jl>H01@000000n_3V000000000000n_3V00<000000P3jl>H2000000@0n_3V0P0000020?[`
iP8000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000000000000`3jl>H20000
0?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP80
0000103jl>H2000000D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000020?[`iP80
00000`3jl>H200000300n_3V0P0000000`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V1P0000000`3jl>H00000
000000020?[`iP8000000P3jl>H2000000D0n_3V1@0000030?[`iP8000008P3jl>H5000000T0n_3V
0P0000000`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0
n_3V0000000000000P3jl>H2000000@0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V
0`0000020?[`iP<0000000<0n_3V0000003jl>H0103jl>H2000000<0n_3V0P00000`0?[`iP@00000
o`3jl>K?0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080n_3V1@0000030?[`iP@000000`3j
l>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H4000000@0n_3V0P00
000`0?[`iP800000o`3jl>KA0?[`iP40oooo000R0?[`iP8000002`3jl>H200000280n_3V0P00000a
0?[`iP800000o`3jl>K@0?[`iP40oooo000P0?[`iPH000002@3jl>H200000200n_3V1000000b0?[`
iP<00000o`3jl>K>0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP080000
00030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP040000003jl>H000000?[`
iP8000000P3jl>H00`000000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0
000000<0n_3V0000000000000P0000001@3jl>H000000?[`iP000000n_3V00<000000P3jl>H00`00
0000n_3V0000000I0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H60000
00<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`000000103jl>H00000000000000008
0?[`iP@0000000<0n_3V0000000000000P3jl>H400000080n_3V1@0000001`3jl>H0000000000000
0000n_3V0000003jl>H00`00000H0?[`iP<00000103jl>H2000000D0n_3V0`0000030?[`iP<00000
1P3jl>H2000000@0n_3V100000030?[`iP<000000`3jl>H3000007X0n_3V0@3oool00240n_3V0P00
00000`3jl>H0000000000005000000040?[`iP000000000000000080n_3V0P0000000`3jl>H00000
000000090?[`iPD000002@3jl>H00`000000n_3V0?[`iP0200000=`0n_3V0P0000040?[`iP800000
0P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0
n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000002P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`
iP80000000<0n_3V0000000000000`3jl>H2000000@0n_3V00<000000?[`iP3jl>H00P0000040?[`
iP8000001@3jl>H2000000D0n_3V0P0000030?[`iP80000000<0n_3V000000000000103jl>H20000
07T0n_3V0@3oool00280n_3V0`00000[0?[`iP800000g03jl>H2000000@0n_3V0P0000020?[`iP80
00000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000
000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V
00800000603jl>H2000000030?[`iP000000000000`0n_3V0P0000050?[`iP800000103jl>H20000
0080n_3V1P0000020?[`iP80000000<0n_3V0000000000001@3jl>H2000007P0n_3V0@3oool00280
n_3V0`00000J0?[`iPD00000303jl>H200000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0
n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP020000
0080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H50000
00X0n_3V0P0000000`3jl>H000000000000<0?[`iP8000000`3jl>H4000000@0n_3V0P0000020?[`
iP030000003jl>H0n_3V008000000`3jl>H2000000030?[`iP000000000000<0n_3V1000001h0?[`
iP40oooo000Q0?[`iP80000000<0n_3V000000000000:03jl>H300000=d0n_3V0P0000000`3jl>H0
0000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H20000
00@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000
000000002P3jl>H3000000040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V0`000000
0`3jl>H000000?[`iP02000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000
000000X0n_3V0`0000030?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V00@00000
0?[`iP00000000000`3jl>H4000000<0n_3V0P0000000`3jl>H000000000001h0?[`iP40oooo000P
0?[`iP<0000000@0n_3V0000000000000000:@3jl>H200000=`0n_3V0P0000000`3jl>H000000000
00020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V
1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0n_3V000000000000
0P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H00000
0000000<0?[`iP8000000P3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP040000
003jl>H00000000000<0n_3V0P0000050?[`iP80000000<0n_3V000000000000N03jl>H10?ooo`00
C@3jl>H00`000000n_3V0?[`iP0200000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000
303jl>H200000280n_3V0P0000020?[`iP800000;P3jl>H2000000030?[`iP000000000000T0n_3V
00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H00`000000n_3V
0?[`iP02000000<0n_3V0`0000040?[`iP800000103jl>H2000000030?[`iP000000000007P0n_3V
0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3j
l>H2000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000;0?[`iP<00000103j
l>H3000000<0n_3V1@0000040?[`iP8000001@3jl>H3000000<0n_3V0`00001i0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V
0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo
000W0?[`iP050000003jl>H000000?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP03
0000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V000000000000
0P000000103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`
iP3jl>H05`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`
iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V0000000000001P00000J0?[`
iPH000000P3jl>H300000<40n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000500000005
0?[`iP00000000000000003jl>H01000000;0?[`iPD000002@3jl>H2000000030?[`iP0000000000
0=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H01000
0000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3j
l>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP800000
2`3jl>H5000000/0n_3V0P0000030?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`008P3j
l>H3000002P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P00
00020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P00
00020?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000K0?[`iP8000000`3j
l>H2000000030?[`iP00000000000<00n_3V0@3oool00280n_3V0`0000090?[`iP030000003jl>H0
n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H4000000<0n_3V1@000002
0?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P000002
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP@000003@3jl>H5000000/0n_3V0P00
00030?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`008@3jl>H2000000030?[`iP000000
000002L0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H2
00000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP800000
0P3jl>H2000001/0n_3V0P0000030?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00803j
l>H3000000040?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP800000
00<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003jl>H500000080
n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000000`3jl>H5000001/0
n_3V0P0000030?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00C@3jl>H2000000030?[`
iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2000003P0n_3V
100000030?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00
000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<P3jl>H2000000@0n_3V0`00
00310?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
7@3jl>HS0?ooh0800000A@3oon02000000@0oooP0P0000040?ooh0800000A03oon05000004<0oooP
1@0000020?ooh0800000103oon02000004@0oooP100000140?ooh0@000000`3oon02000000@0oooP
0P0000150?ooh08000009`3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000
@`3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP000004D0oooP00<000000?oo
h03oon00A@3oon000`000000oooP0?ooh0070?ooh0040000003oon00oooP000004<0oooP00<00000
0?ooh03oon00A@3oon000`000000oooP0?ooh0090?ooh0040000003oon00oooP000004<0oooP00@0
00000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000
@`3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP04<0oooP00<000000?ooh03o
on00A@3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP0480oooP00<000000?ooh03o
on00A@3oon000`000000oooP0?ooh00;0?ooh0030000003oon00oooP04<0oooP00<000000?ooh03o
on009@3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000
oooP0?ooh00000090?ooh0800000AP3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP
00P0oooP0P0000160?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00203oon020000
04L0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03o
on000000@`3oon0010000000oooP0?ooh00000090?ooh0030000003oon00oooP04D0oooP00<00000
0?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP04<0oooP00@00000
0?ooh03oon000000A03oon0010000000oooP0?ooh00000090?ooh0030000003oon00oooP04<0oooP
00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR<0oooP0P0000150?ooh0800000
2P3oon03000004@0oooP0P0000160?ooh08000002P3oon03000004@0oooP0P0000160?ooh0800000
2P3oon03000004@0oooP0P00000W0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`iQP0
oooPo`00003Z000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01:
0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?ooh01:
0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh009
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon0300000?l0oooP]P3oon02000000T0oooP6P000?l90?ooh0<000006`3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2c0?ooh080cHDo100000080000
oaX0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh;00oooP2@000?lQ0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2V0?ooh0X0003o
0`3oon000`3=QCl0onCQ0?oTh@0200000280onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh9h0oooP2000
0?l=0?ooh0030<f5?`3oi>40onCQ02@0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh9P0oooP1P000?lE
0?ooh0030<f5?`3oi>40onCQ02@0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh940oooP1`000?lK0?oo
h0030<f5?`3oi>40onCQ02@0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh8X0oooP0P0000050000ob80
oooP00<0cHDo0?oTh@3oi>40903oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPQ`3oon000`3=QCl0003o
0000o`020000o`030000003=QCl0cHDo02D0cHDo9P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPQ03o
on040000o`030?oTh@0000000000008000009P3oi>400`3=QCl0onCQ0?oTh@0T0?oTh@030<f5?`3o
on00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon00o`3oon200?ooh0@0003o0`3oon000`3=QCl0onCQ0?oTh@02000002L0onCQ00<0cHDo
0?oTh@3oi>40903oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPO03oon040000o`L0oooP00<0cHDo0?oT
h@3oi>40:@3oi>400`3=QCl0onCQ0?oTh@0T0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1c0?ooh080
00000`3oon040000o`/0oooP00<0cHDo0?oTh@3oi>40:@3oi>400`3=QCl0onCQ0?oTh@0T0?oTh@03
0<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon1b0?ooh080000010000?l?0?ooh0030<f5?`3oi>40onCQ02T0onCQ
00<0cHDo0?oTh@3oi>40903oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPF03oon0H0<f5?`@0003o0P00
000B0<f5?b/0onCQ00<0cHDo0?oTh@3oi>40903oi>400`3=QCl0oooP0?ooh0090?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPF03oon00
0`3=QCl0onCQ0?oTh@0A0?oTh@@0003o0`3oi>4200000180onCQ00<0cHDo0?oTh@3oi>40:@3oi>40
0`3=QCl0onCQ0?oTh@0T0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP0`00003o0?ooh5P0oooP00<0cHDo0?oTh@3oi>403@3oi>440000
oa/0onCQ00<0cHDo0?oTh@3oi>40:@3oi>400`3=QCl0onCQ0?oTh@0T0?oTh@030<f5?`3oon00oooP
00L0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5P0
oooP00<0cHDo0?oTh@3oi>402P3oi>430000oal0onCQ00<0cHDo0?oTh@3oi>40:@3oi>400`3=QCl0
onCQ0?oTh@0T0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1H0?ooh0030<f5?`3oi>40onCQ00L0onCQ
0`000?lR0?oTh@030<f5?`3oi>40onCQ02T0onCQ00<0cHDo0?oTh@3oi>40903oi>400`3=QCl0oooP
0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP0?l0oooPF03oon000`3=QCl0onCQ0?oTh@040?oTh@<0003o9@3oi>400`3=QCl0onCQ0?oT
h@0Y0?oTh@030<f5?`3oi>40onCQ02@0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5P0oooP00<0cHDo
0?oTh@3oi>400P3oi>420000obP0onCQ00<0cHDo0?oTh@3oi>40:@3oi>400`3=QCl0onCQ0?oTh@0T
0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon1H0?ooh0030<f5?`3oi>40003o0080003o:P3oi>400`3=
QCl0onCQ0?oTh@0Y0?oTh@030<f5?`3oi>40onCQ02@0onCQ00<0cHDo0?ooh03oon002@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5L0
oooP0`000?l]0?oTh@030<f5?`3oi>40onCQ02T0onCQ00<0cHDo0?oTh@3oi>40903oi>400`3=QCl0
oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPE03oon030000o`030?ooh03=QCl0onCQ02d0onCQ00<0cHDo0?oTh@3oi>40
:@3oi>400`3=QCl0onCQ0?oTh@0T0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1>0?ooh080000000@0
oooP0000o`000?l0003o103oon000`3=QCl0onCQ0?oTh@0/0?oTh@030<f5?`3oi>40onCQ02T0onCQ
00<0cHDo0?oTh@3oi>40903oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPC@3oon0200000080003o1`3o
on000`3=QCl0onCQ0?oTh@0/0?oTh@030<f5?`3oi>40onCQ02T0onCQ00<0cHDo0?oTh@3oi>40903o
i>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP0?l0oooP6`3oon0a0<f5?`<0003o0P0000080<f5?bh0onCQ00<0cHDo
0?oTh@3oi>40:@3oi>400`3=QCl0onCQ0?oTh@0T0?oTh@030<f5?`3oon00oooP00T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon0K0?oo
h0030<f5?`3oi>40onCQ02`0onCQ0P000?l20?oTh@800000203oi>400`3=QCl0onCQ0?oTh@0/0?oT
h@030<f5?`3oi>40onCQ02T0onCQ00<0cHDo0?oTh@3oi>40903oi>400`3=QCl0oooP0?ooh0090?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0
oooP6`3oon000`3=QCl0onCQ0?oTh@0Y0?oTh@<0003o3P3oi>400`3=QCl0onCQ0?oTh@0/0?oTh@03
0<f5?`3oi>40onCQ02T0onCQ00<0cHDo0?oTh@3oi>40903oi>400`3=QCl0oooP0?ooh0090?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon000`000000oooP
0?ooh03o0?ooh1/0oooP00<0cHDo0?oTh@3oi>409P3oi>430000oa40onCQ00<0cHDo0?oTh@3oi>40
;03oi>400`3=QCl0onCQ0?oTh@0Y0?oTh@030<f5?`3oi>40onCQ02@0onCQ00<0cHDo0?ooh03oon00
2@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?oo
h00000070?ooh0030000003oon00oooP0?l0oooP6`3oon000`3=QCl0onCQ0?oTh@0T0?oTh@80003o
503oi>400`3=QCl0onCQ0?oTh@0/0?oTh@030<f5?`3oi>40onCQ02T0onCQ00<0cHDo0?oTh@3oi>40
903oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H=0?ooh0040000003oon00oooP000000L0oooP100000080?ooh?l00000=P0000030000oiT00000
203oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV
00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP2]f>H0[MSV03D0[MSV
00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0oooP0?ooh00O0?ooh080003oY`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>Q
bP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>Q
bP2]f>H0[MSV0240[MSV00<0<j7:0?ooh03oon007@3oon020000ojT0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0
<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV0240[MSV00<0
<j7:0?ooh03oon006`3oon020000oj/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0
[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP2]f>H0
[MSV03D0[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0oooP0?ooh00I0?ooh080003o[@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gH
iP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP0Q0:gH
iP0303>QbP3oon00oooP01H0oooP0`000?n_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0
[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0
[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV0240[MSV00<0<j7:0?ooh03oon00503oon020000ok80
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H0
8P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0
8@2]f>H00`0cXLX0oooP0?ooh00B0?ooh080003o]03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0
<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0
<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP0303>QbP3oon00oooP0100oooP0P00
0?nf0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0
[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0
[MSV0240[MSV00<0<j7:0?ooh03oon003P3oon020000okP0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gH
iP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0oooP0?ooh00<0?oo
h080003o^P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0
[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0
[MSV0:gHiP0Q0:gHiP0303>QbP3oon00oooP00X0oooP0P000?nl0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0
<`2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV0240[MSV00<0<j7:0?ooh03oon00
203oon020000okh0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0
<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0
<j7:0:gHiP2]f>H08@2]f>H00`0cXLX0oooP0?ooh0060?ooh080003o`03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0
[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP0303>QbP3oon00
oooP00@0oooP0P000?o20?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gH
iP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0[MSV0:gHiP0e0:gH
iP0303>QbP2]f>H0[MSV0240[MSV00<0<j7:0?ooh03oon000P3oon020000ol@0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV03L0
[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0
[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP0303>QbP3oon00oooP0080
003oa03oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV
00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV0240[MSV
00<0<j7:0000o`000?l0b03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]
f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]
f>H00`0cXLX0[MSV0:gHiP0P0:gHiP80003obP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:
0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:
0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP0N0:gHiP80003o00<0[MSV03>QbP3oon00b@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gH
iP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0[MSV0:gHiP0L0:gH
iP80003o0`2]f>H00`0cXLX0oooP0?ooh0380?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0
[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0
[MSV0:gHiP0e0:gHiP0303>QbP2]f>H0[MSV01X0[MSV0P000?l50:gHiP0303>QbP3oon00oooP0<P0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H0
8P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0:gHiP2]f>H0
5@2]f>H2000000030:gHiP000?l0003o00L0[MSV00<0<j7:0?ooh03oon00b03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]
f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>HG03>QbP8000000P000?l:03>Qb/X0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H0
0`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0?ooh03oon00503oon02
0000o`800000e03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0c
XLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0c
XLX0oooP0?ooh00B0?ooh080003o00<0oooP000000000000e@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0
[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0
[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0oooP0?ooh00@0?ooh080003ofP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>Q
bP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0oooP0?ooh00>0?ooh080003o
g03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gH
iP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0oooP0?oo
h00<0?ooh080003ogP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H0
0`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H0
0`0cXLX0oooP0?ooh00;0?ooh0030000o`3oon00oooP0=h0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gH
iP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0?ooh03oon002@3oon020000on40oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0
[MSV0:gHiP0c0:gHiP0303>QbP2]f>H0[MSV03D0[MSV00<0<j7:0?ooh03oon001`3oon020000on<0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>Q
bP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>Q
bP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H00`0cXLX0oooP0?ooh0050?ooh080003o
h`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0
<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0[MSV0:gHiP0e0:gHiP0303>QbP3oon00oooP00@0oooP00<0
003o0?ooh03oon00i@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H0
0`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0=@2]f>H0
0`0cXLX0oooP0?ooh0020?ooh080003oj03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gH
iP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gH
iP2]f>H0=@2]f>H00`0cXLX0oooP0?ooh0020000onX0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP03
03>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP03
03>QbP2]f>H0[MSV03D0[MSV00<0<j7:0?ooh0000?l0k03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV
00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV
00<0<j7:0:gHiP2]f>H0=@2]f>H20000ond0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]
f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP2]
f>H0[MSV03<0[MSV0P000?l00`0cXLX0oooP0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H0
0`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H0
0`0cXLX0[MSV0:gHiP0a0:gHiP80003o0P2]f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gH
iP2]f>H0<`2]f>H00`0cXLX0[MSV0:gHiP0`0:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?oo
h03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0
[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0;P2]f>H20000o`D0
[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H0
7@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0:gHiP2]f>H0
:P2]f>H2000000030:gHiP000?l0[MSV00H0[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]
f>H0[MSV03<0[MSV;00cXLX200000080003o2@0cXL[^0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H0
0`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H0
0`0cXLX0oooP0?ooh00Y0?ooh080003o0P00003g0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0c
XLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0c
XLX0oooP0?ooh00X0?ooh0040000o`3oon00000000000?P0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gH
iP0303>QbP3oon00oooP02H0oooP0P000?ol0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0
[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0
oooP0?ooh00U0?ooh0030000o`3oon00oooP0?`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H0
7@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0?ooh03oon00
8`3oon020000ood0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gH
iP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0?ooh03oon008@3oon020000ool0oooP0P3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R
0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0?ooh03oon00803oon000`000?l0oooP0?ooh03o
0?ooh080oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gH
iP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP3oon00oooP01h0oooP0P000?oo0?oo
h0D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]
f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP3oon00oooP01d0oooP00<0003o0?ooh03o
on00o`3oon050?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>Q
bP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0oooP0?ooh00K0?ooh080003o
o`3oon080?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]
f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0oooP0?ooh00J0?ooh0030000o`3o
on00oooP0?l0oooP203oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H0
0`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:0?ooh03oon006@3oon00
0`000?l0oooP0?ooh03o0?ooh0T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV
01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP3oon00oooP
01L0oooP0P000?oo0?ooh0`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0
[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP3oon00oooP01H0
oooP00<0003o0?ooh03oon00o`3oon0<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV
0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0oooP
0?ooh00E0?ooh0030000o`3oon00oooP0?l0oooP3@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0
<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0
<j7:0?ooh03oon004`3oon020000ool0oooP403oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:
0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:
0?ooh03oon004P3oon000`000?l0oooP0?ooh03o0?ooh100oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gH
iP0303>QbP3oon00oooP0140oooP00<0003o0?ooh03oon00o`3oon0A0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0@000001`3oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP03
03>QbP2]f>H0[MSV03<0[MSV00<0<j7:0?ooh03oon003`3oon020000ool0oooP503oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon000`000000oooP0?ooh0080?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>Q
bP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0oooP0?ooh00>0?ooh0030000
o`3oon00oooP0?l0oooP503oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3o
on000`000000oooP0?ooh0070?ooh0@00000203oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]
f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP3o
on00oooP00d0oooP00<0003o0?ooh03oon00o`3oon0B0?ooh0@000006`3oon0N0?[`iP40oooo000M
0?[`iPl0oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0
[MSV03<0[MSV00<0<j7:0?ooh03oon002`3oon020000ool0oooP603oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0
[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0oooP0?ooh00:0?ooh0030000o`3oon00
oooP0?l0oooP603oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon020000
00P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV
01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP3oon00oooP
00P0oooP0P000?oo0?ooh1/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0
[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP3oon00oooP00L0
oooP00<0003o0?ooh03oon00o`3oon0K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV
0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H00`0cXLX0oooP
0?ooh0060?ooh0030000o`3oon00oooP0?l0oooP703oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0
<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0
<j7:0?ooh03oon00103oon020000ool0oooP7`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:
0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0<j7:
0?ooh03oon000`3oon000`000?l0oooP0?ooh03o0?ooh1l0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gH
iP0403>QbP3oon00oooP0?ooh080003oo`3oon0R0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0c
XLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0<`2]f>H0100c
XLX0oooP0?ooh0000?oo0?ooh2@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV
01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0c0:gHiP0303>QbP000?l0003o
0?l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0
[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV03<0[MSV00<0003o0?ooh03oon00o`3oon0U0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV
00<0<j7:0:gHiP2]f>H0<P2]f>H00`000?l0<j7:0?ooh03o0?ooh2H0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gH
iP0`0:gHiP80003o00<0[MSV03>QbP3oon00o`3oon0V0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H0
0`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0;`2]f>H0
1@000?l0[MSV0:gHiP2]f>H0<j7:0?l0oooP9`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:
0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV02d0[MSV0P000?l4
0:gHiP0303>QbP3oon00oooP0?l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gH
iP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0;02]f>H00`000?l0[MSV0:gHiP040:gH
iP0303>QbP3oon00oooP0?l0oooP8`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP03
03>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H0:`2]f>H00`000?l0[MSV0:gHiP050:gHiP03
03>QbP3oon00oooP0?l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H0
7@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV02T0[MSV0P000?l80:gHiP0303>Q
bP3oon00oooP0?l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]
f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV02P0[MSV00<0003o0:gHiP2]f>H0202]
f>H00`0cXLX0oooP0?ooh03o0?ooh2D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0
[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gHiP0W0:gHiP030000o`2]f>H0
[MSV00T0[MSV00<0<j7:0?ooh03oon00o`3oon0U0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0c
XLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0:gHiP2]f>H09P2]f>H00`00
0?l0[MSV0:gHiP0:0:gHiP0303>QbP3oon00oooP0?l0oooP9@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0
[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV02@0
[MSV0P000?l=0:gHiP0303>QbP3oon00oooP0?l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV
00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP2]f>H0[MSV02<0[MSV
00<0003o0:gHiP2]f>H03@2]f>H00`0cXLX0oooP0?ooh03o0?ooh2D0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0[MSV0:gH
iP0R0:gHiP030000o`2]f>H0[MSV00h0[MSV00<0<j7:0?ooh03oon00o`3oon0U0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:
0:gHiP2]f>H07`2]f>H00`000000003o0000o`0A0:gHiP0303>QbP3oon00oooP0?l0oooP9@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gH
iR40<j7:00@000000000o`00000000004P0cXL[o0?ooh2L0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gH
iP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0oooP0?ooh00N0?oo
h0040000o`000000000000000?l0oooP>@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gH
iP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP3oon00oooP01d0oooP00@0003o0?oo
h00000000000o`3oon0j0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gH
iP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0?ooh03oon006`3oon020000ool0oooP?P3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP03
03>QbP3oon00oooP01X0oooP00<0003o0?ooh03oon00o`3oon0n0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0?ooh03oon00
6@3oon000`000?l0oooP0?ooh03o0?ooh3l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]
f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP3oon00oooP01P0oooP00<0003o0?ooh03oon00o`3o
on0n0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H0
0`0cXLX0oooP0?ooh00G0?ooh0030000o`3oon00oooP0?l0oooP@@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP3oon00oooP
01H0oooP00<0003o0?ooh03oon00o`3oon120?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0
[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0?ooh03oon00503oon020000ool0
oooPA@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV
0:gHiP0R0:gHiP0303>QbP3oon00oooP01<0oooP00<0003o0?ooh03oon00o`3oon150?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0
<j7:0?ooh03oon004P3oon000`000?l0oooP0?ooh03o0?ooh4H0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g
0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0oooP0?ooh00A
0?ooh0030000o`3oon00oooP0?l0oooPA`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gH
iP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP3oon00oooP0100oooP00<0003o0?oo
h03oon00o`3oon180?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP03
03>QbP2]f>H0[MSV0280[MSV00<0<j7:0?ooh03oon003`3oon000`000?l0oooP0?ooh03o0?ooh4T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H0
8P2]f>H00`0cXLX0oooP0?ooh00>0?ooh0030000o`3oon00oooP0?l0oooPBP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP3o
on00oooP00d0oooP00<0003o0?ooh03oon00o`3oon1;0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H0
0`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0?ooh03oon00303oon00
0`000?l0oooP0?ooh03o0?ooh4`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV
01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0oooP0?ooh00:0?ooh080003oo`3oon1?0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280
[MSV00<0<j7:0?ooh03oon002@3oon000`000?l0oooP0?ooh03o0?ooh4l0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0oooP
0?ooh0080?ooh0030000o`3oon00oooP0?l0oooPD03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0
<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP3oon00oooP00L0oooP00<0
003o0?ooh03oon00o`3oon1A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:
0:gHiP2]f>H08P2]f>H00`0cXLX0oooP0?ooh0060?ooh0030000o`3oon00oooP0?l0oooPD03oon03
000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV0280[MSV00<0<j7:0?oo
h03oon001@3oon000`000?l0oooP0?ooh03o0?ooh5<0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP03
03>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H00`0cXLX0oooP0?ooh0040?ooh003
0000o`3oon00oooP0?l0oooPE03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H0
7@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP3oon00oooP00<0oooP00<0003o0?ooh03oon00
o`3oon1E0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]
f>H0[MSV0280[MSV00<0<j7:0?ooh03oon000P3oon000`000?l0oooP0?ooh03o0?ooh5H0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H08P2]f>H0
0`0cXLX0oooP0?ooh0020000ool0oooPF@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gH
iP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP0303>QbP3oon00003o0?l0oooPF`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP03
03>QbP000?l0oooP0?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H0
7@2]f>H00`0cXLX0[MSV0:gHiP0R0:gHiP030000o`3oon00oooP0?l0oooPF`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0Q0:gHiP030000o`0c
XLX0oooP0?l0oooPG03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H0
0`0cXLX0[MSV0:gHiP0P0:gHiP030000o`2]f>H0<j7:0?l0oooPG@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP040000o`2]f>H0[MSV
03>Qb_l0oooPG@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0c
XLX0[MSV0:gHiP0N0:gHiP050000o`2]f>H0[MSV0:gHiP0cXLX0o`3oon1M0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0003o0:gH
iP2]f>H00P2]f>H00`0cXLX0oooP0?ooh03o0?ooh5/0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iPl0oooP0`0000060?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV01/0[MSV0P000?l50:gHiP03
03>QbP3oon00oooP0?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
403oon000`000000oooP0?ooh0050?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV01X0[MSV00<0003o0:gHiP2]f>H0
1@2]f>H00`0cXLX0oooP0?ooh03o0?ooh5/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iPd0oooP1@0000060?ooh0@00000203oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]
f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H06@2]f>H00`000?l0[MSV0:gHiP060:gHiP0303>QbP3o
on00oooP0?l0oooPF03oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00
oooP000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]
f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`000?l0[MSV0:gHiP070:gHiP0303>QbP3o
on00oooP0?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon00
0`000000oooP000000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H0
0`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0003o0:gHiP2]f>H0202]f>H0
0`0cXLX0oooP0?ooh03o0?ooh5/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPl0oooP0P0000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0c
XLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV01H0[MSV00<0003o0:gHiP2]f>H02@2]f>H00`0c
XLX0oooP0?ooh03o0?ooh5/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0
[MSV00<0<j7:0:gHiP2]f>H05@2]f>H00`000?l0[MSV0:gHiP0:0:gHiP0303>QbP3oon00oooP0?l0
oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV
0:gHiP0D0:gHiP030000o`2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03oon00o`3oon1K0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0
003o0:gHiP2]f>H0302]f>H00`0cXLX0oooP0?ooh03o0?ooh5/0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g
0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H04P2]f>H00`000?l0[MSV0:gHiP0=
0:gHiP0303>QbP3oon00oooP0?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gH
iP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP030000o`2]f>H0[MSV00h0[MSV00<0<j7:0?oo
h03oon00o`3oon1K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gHiP03
03>QbP2]f>H0[MSV0100[MSV00<0003o0:gHiP2]f>H03`2]f>H00`0cXLX0oooP0?ooh03o0?ooh5/0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`000?l0[MSV0:gHiP0@0:gHiP0303>QbP3oon00oooP0?l0oooPF`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP80003o4`2]
f>H00`0cXLX0oooP0?ooh03o0?ooh5/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0
[MSV01d0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H2000000030000o`2]f>H0[MSV01<0[MSV00<0<j7:
0?ooh03oon00o`3oon1K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gH
iP0303>QbP2]f>H0[MSV00T0[MSV0P0000000`000?l000000:gHiP0D0:gHiP0303>QbP3oon00oooP
0?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H<03>QbP04
000000000?l00000000001H0<j7:o`3oon1M0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0
[MSV0:gHiP0M0:gHiP0303>QbP3oon00oooP00T0oooP00<0003o000000000000o`3oon1d0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV
0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:0?ooh03oon00203oon000`000?l0oooP
0?ooh03o0?ooh7<0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?oo
h0070?ooh0030000o`3oon00oooP0?l0oooPMP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:
0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0060?ooh0030000o`3oon00oooP0?l0oooPM`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0050?oo
h0030000o`3oon00oooP0?l0oooPN03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]
f>H07@2]f>H00`0cXLX0oooP0?ooh0040?ooh0030000o`3oon00oooP0?l0oooPN@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H00`0cXLX0oooP0?ooh0030?ooh0030000
o`3oon00oooP0?l0oooPNP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]
f>H00`0cXLX0oooP0?ooh0020?ooh0030000o`3oon00oooP0?l0oooPN`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H01@0cXLX0oooP0?ooh03oon00003o0?l0oooPOP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H0100cXLX0oooP0?ooh000
0?oo0?ooh7l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01d0[MSV00<0<j7:
0?ooh0000?l0o`3oon200?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0M0:gH
iP0303>QbP000?l0oooP0?l0oooPP03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]
f>H07@2]f>H00`000?l0oooP0?ooh03o0?ooh800oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g0:gHiP0303>Q
bP2]f>H0[MSV01`0[MSV00<0003o03>QbP3oon00o`3oon210?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]
f>H00`0cXLX0[MSV0:gHiP0K0:gHiP030000o`2]f>H0<j7:0?l0oooPPP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV03L0[MSV00<0<j7:0:gHiP2]f>H06P2]f>H010000?l0[MSV0:gHiP0cXL[o0?ooh880oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV01T0[MSV00D0003o0:gHiP2]f>H0[MSV03>Q
bP3o0?ooh880oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`000009
0?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`000?l0[MSV0:gHiP02
0:gHiP0303>QbP3oon00oooP0?l0oooPOP3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0G0:gH
iP030000o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00o`3oon200?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0F0:gHiP030000o`2]f>H0[MSV00@0[MSV00<0<j7:0?ooh03o
on00o`3oon200?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0E0:gHiP030000
o`2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00o`3oon200?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]
f>H00`0cXLX0[MSV0:gHiP0D0:gHiP030000o`2]f>H0[MSV00H0[MSV00<0<j7:0?ooh03oon00o`3o
on200?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP030000o`2]f>H0
[MSV00L0[MSV00<0<j7:0?ooh03oon00o`3oon200?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0c
XLX0[MSV0:gHiP0B0:gHiP030000o`2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon00o`3oon200?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP030000o`2]f>H0[MSV00T0
[MSV00<0<j7:0?ooh03oon00o`3oon200?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV
0:gHiP0@0:gHiP030000o`2]f>H0[MSV00X0[MSV00<0<j7:0?ooh03oon00o`3oon200?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP030000o`2]f>H0[MSV00/0[MSV00<0
<j7:0?ooh03oon00o`3oon200?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0>
0:gHiP030000o`2]f>H0[MSV00`0[MSV00<0<j7:0?ooh03oon00o`3oon200?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP030000o`2]f>H0[MSV00d0[MSV00<0<j7:0?oo
h03oon00o`3oon200?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP03
0000o`2]f>H0[MSV00h0[MSV00<0<j7:0?ooh03oon00o`3oon200?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
=`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP030000o`2]f>H0[MSV00l0[MSV00<0<j7:0?ooh03oon00
o`3oon200?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP030000o`2]
f>H0[MSV0100[MSV00<0<j7:0?ooh03oon00o`3oon200?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=`2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV0140[MSV00<0<j7:0?ooh03oon00o`3oon20
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0c
XLX0[MSV0:gHiP0g0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0003o0:gHiP2]f>H04P2]f>H00`0c
XLX0oooP0?ooh03o0?ooh7h0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`000?l0
[MSV0:gHiP0C0:gHiP0303>QbP3oon00oooP0?l0oooPP03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gHiP0D0:gHiP0303>QbP3oon00oooP0?l0oooP
P03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gH
iP0D0:gHiP0303>QbP3oon00oooP0?l0oooPP03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP0E0:gHiP0303>QbP3oon00oooP0?l0oooPP03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gHiP0F0:gH
iP0303>QbP3oon00oooP0?l0oooPP03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`000?l0[MSV0:gHiP0G0:gHiP0303>QbP3oon00oooP0?l0oooPP03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV03L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP0H0:gHiP0303>Q
bP3oon00oooP0?l0oooPP03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00D0<j7:0:gHiP2]f>H0[MSV
0000o`0K0:gHiP0303>QbP3oon00oooP0?l0oooPP03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00@0
<j7:000000000000003o702]f>H00`0cXLX0oooP0?ooh03o0?ooh800oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0g0:gHiP80000000<0003o0000000cXLX0700cXL[o0?ooh880oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0g
0:gHiP04000000000?l0000000000?l0oooPW`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03L0[MSV00<0003o
000000000000o`3oon2P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=P2]f>H00`000?l0<j7:0?ooh03o0?oo
h:40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP0`0000080?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0=@2]f>H00`000?l0[MSV03>QbP3o0?ooh:80
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon00
00001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV03@0[MSV00@0003o0:gHiP2]
f>H0<j7:o`3oon2R0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh004
0000003oon00oooP000000L0oooP100000080?ooh00303>QbP2]f>H0[MSV03<0[MSV00D0003o0:gH
iP2]f>H0[MSV03>QbP3o0?ooh9l0oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3oon030000
00P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0b0:gHiP030000o`2]f>H0[MSV
0080[MSV00<0<j7:0?ooh03oon00o`3oon2P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H>0?ooh0030000003oon00oooP00L0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0b0:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon2P0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0<000001`3oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV0340[MSV00<0003o0:gHiP2]f>H00`2]f>H00`0cXLX0oooP
0?ooh03o0?ooh:00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0`0:gHiP030000o`2]f>H0[MSV00@0[MSV00<0
<j7:0?ooh03oon00o`3oon2P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0;`2]f>H00`000?l0[MSV0:gHiP05
0:gHiP0303>QbP3oon00oooP0?l0oooPX03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02h0[MSV00<0003o0:gH
iP2]f>H01P2]f>H00`0cXLX0oooP0?ooh03o0?ooh:00oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0]0:gHiP03
0000o`2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon00o`3oon2P0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
;02]f>H00`000?l0[MSV0:gHiP080:gHiP0303>QbP3oon00oooP0?l0oooPX03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV02/0[MSV00<0003o0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh03o0?ooh:00oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0Z0:gHiP030000o`2]f>H0[MSV00X0[MSV00<0<j7:0?ooh03oon00o`3oon2P
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0:@2]f>H00`000?l0[MSV0:gHiP0;0:gHiP0303>QbP3oon00oooP
0?l0oooPX03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02T0[MSV00<0003o0:gHiP2]f>H02`2]f>H00`0cXLX0
oooP0?ooh03o0?ooh:00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0X0:gHiP030000o`2]f>H0[MSV00`0[MSV
00<0<j7:0?ooh03oon00o`3oon2P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H09`2]f>H00`000?l0[MSV0:gH
iP0=0:gHiP0303>QbP3oon00oooP0?l0oooPX03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV02@0[MSV0P000000
0`000?l0[MSV0:gHiP0>0:gHiP0303>QbP3oon00oooP0?l0oooPX03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H08`2]f>H20000
00030000o`000000[MSV00l0[MSV00<0<j7:0?ooh03oon00o`3oon2N0?ooh0<000006`3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0V03>QbP04000000000?l000000000
0140<j7:o`3oon2R0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP02l0oooP00<0003o000000000000o`3oon2d0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02h0oooP00<0003o0?ooh03oon00
o`3oon2e0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP02d0oooP00<0003o0?ooh03oon00o`3oon2f0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02d0oooP00<0003o0?ooh03oon00o`3oon2f
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
02`0oooP00<0003o0?ooh03oon00o`3oon2g0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP02/0oooP00<0003o0?ooh03oon00o`3oon2h0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02X0oooP
00<0003o0?ooh03oon00o`3oon2i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP02T0oooP00<0003o0?ooh03oon00o`3oon2j0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02P0oooP00<0003o
0?ooh03oon00o`3oon2k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP02P0oooP00<0003o0?ooh03oon00o`3oon2k0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02L0oooP00<0003o0?ooh03o
on00o`3oon2l0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP02H0oooP00<0003o0?ooh03oon00o`3oon2m0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP02D0oooP00<0003o0?ooh03oon00o`3o
on2n0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP02@0oooP00<0003o0?ooh03oon00o`3oon2o0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0<000008`3oon000`000?l0oooP0?ooh03o0?ooh;h0oooP0`00000K0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00S0?ooh0030000o`3oon00oooP0?l0
oooP`03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh00R0?ooh0030000o`3oon00oooP0?l0oooP`@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh00Q0?ooh0030000o`3oon00oooP0?l0oooP`P3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00P
0?ooh0030000o`3oon00oooP0?l0oooP``3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh00O0?ooh0030000o`3oon00oooP0?l0oooPa03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00N0?ooh003
0000o`3oon00oooP0?l0oooPa@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh00N0?ooh0030000o`3oon00oooP0?l0oooPa@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00M0?ooh0030000o`3o
on00oooP0?l0oooPaP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh00L0?ooh0030000o`3oon00oooP0?l0oooPa`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00K0?ooh0030000o`3oon00oooP
0?l0oooPb03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh00J0?ooh0030000o`3oon00oooP0?l0oooPb@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00I0?ooh0030000o`3oon00oooP0?l0oooP
bP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h00I0?ooh0030000o`3oon00oooP0?l0oooPbP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh00H0?ooh0030000o`3oon00oooP0?l0oooPb`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh00G0?oo
h0030000o`3oon00oooP0?l0oooPc03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon03000001H0oooP00<0003o0?ooh03oon00o`3oon3;0?ooh0<000006`3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon005@3oon000`000?l0oooP0?ooh03o0?ooh<h0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00503o
on000`000?l0oooP0?ooh03o0?ooh<l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon004`3oon000`000?l0oooP0?ooh03o0?ooh=00oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon004P3oon000`00
0?l0oooP0?ooh03o0?ooh=40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon004P3oon000`000?l0oooP0?ooh03o0?ooh=40oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon004@3oon000`000?l0oooP
0?ooh03o0?ooh=80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00403oon000`000?l0oooP0?ooh03o0?ooh=<0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon003`3oon000`000?l0oooP0?ooh03o
0?ooh=@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon003P3oon000`000?l0oooP0?ooh03o0?ooh=D0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon003@3oon000`000?l0oooP0?ooh03o0?ooh=H0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
303oon000`000?l0oooP0?ooh03o0?ooh=L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00303oon000`000?l0oooP0?ooh03o0?ooh=L0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00
oooP00/0oooP00<0003o0?ooh03oon00o`3oon3H0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002P3oon00
0`000?l0oooP0?ooh03o0?ooh=T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPd0oooP00@000000?ooh03oon0000001`3oon04000000P0oooP00<0003o0?ooh03oon00o`3oon3G
0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP
0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000
oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00o`3oon3V0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
iP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?oo
h01;0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?oo
h01:0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon3o00000>X0
00006`3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=40
n_3V100000020?[`iPP000000P3jl>H4000000070?[`iP00000000000000003jl>H000000?[`iP0<
000000030?[`iP000000000000@0000000@0n_3V0000000000000000203jl>H5000000@0n_3V1`00
00000`3jl>H000000?[`iP03000000P0n_3V1@0000020?[`iP@000000P3jl>H5000000`0n_3V0`00
000A0?[`iP<000001P3jl>H3000000040?[`iP0000000000000000H0n_3V00<000000?[`iP3jl>H0
103jl>H3000000040?[`iP000000000000000=P0n_3V0@3oool00=80n_3V0P0000020?[`iP800000
0`3jl>H2000000<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP040000
0080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00T0n_3V00@000000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P00
00000`3jl>H000000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
000=0?[`iP80000000<0n_3V0000000000003`3jl>H2000000030?[`iP000000000000H0n_3V0P00
00000`3jl>H00000000000070?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000
003I0?[`iP40oooo003B0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P00
00020?[`iP8000003@3jl>H2000000030?[`iP000000000000D0n_3V1@0000050?[`iP80000000<0
n_3V0000000000001`3jl>H3000000H0n_3V1@0000060?[`iP<00000fP3jl>H10?ooo`00dP3jl>H5
000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`
iP000000000000<000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
0000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003j
l>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000003@3jl>H200000003
0?[`iP000000000000l0n_3V0P0000000`3jl>H00000000000070?[`iP<00000203jl>H00`000000
n_3V0?[`iP060?[`iP<00000fP3jl>H10?ooo`00dP3jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H200000080n_3V0P0000001P3jl>H000000000003jl>H000000?[`iP800000103jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002P3jl>H30000
00@0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H2
000000<0n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V00X0n_3V0`00000@
0?[`iP@000001`3jl>H2000000030?[`iP000000000000L0n_3V00<000000?[`iP3jl>H01@3jl>H2
000000030?[`iP00000000000=T0n_3V0@3oool00=80n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P0000040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3jl>H50000
0080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000002P3jl>H50000
0080n_3V100000020?[`iP<0000000<0n_3V0000000000002P3jl>H2000000030?[`iP0000000000
00l0n_3V0P0000080?[`iP<0000000@0n_3V00000000000000003@3jl>H3000000030?[`iP000000
000000D00000e03jl>H10?ooo`00dP3jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`00
0000n_3V0?[`iP0G0?[`iP8000006P3jl>H2000000030?[`iP00000000000100n_3V0P00000S0?[`
iP030000003jl>H0n_3V0=@0n_3V0@3oool00=40n_3V1P0000040?[`iP800000;`3jl>H5000001X0
n_3V0`00000I0?[`iP<000004P3jl>H300000280n_3V00<000000?[`iP3jl>H0d`3jl>H10?ooo`00
o`3jl>J30?[`iP030000003jl>H0n_3V0=80n_3V0@3oool00?l0n_3VP03jl>H010000000n_3V0?[`
iP00003D0?[`iP40oooo003o0?[`iX40n_3V0P00003E0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .58711 L
.06871 .58711 L
.06871 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .58711 L
.06871 .58711 L
.06871 .08012 L
s
.678 .847 .902 r
.06871 .08012 m
.06871 .49496 L
.13213 .49496 L
.13213 .08012 L
F
.2 .63 .79 r
.06871 .08012 m
.06871 .49496 L
.13213 .49496 L
.13213 .08012 L
s
.678 .847 .902 r
.13213 .08012 m
.13213 .46239 L
.16202 .46239 L
.16202 .08012 L
F
.2 .63 .79 r
.13213 .08012 m
.13213 .46239 L
.16202 .46239 L
.16202 .08012 L
s
.678 .847 .902 r
.16202 .08012 m
.16202 .37597 L
.23311 .37597 L
.23311 .08012 L
F
.2 .63 .79 r
.16202 .08012 m
.16202 .37597 L
.23311 .37597 L
.23311 .08012 L
s
.678 .847 .902 r
.23311 .08012 m
.23311 .32989 L
.28926 .32989 L
.28926 .08012 L
F
.2 .63 .79 r
.23311 .08012 m
.23311 .32989 L
.28926 .32989 L
.28926 .08012 L
s
.678 .847 .902 r
.28926 .08012 m
.28926 .28006 L
.34194 .28006 L
.34194 .08012 L
F
.2 .63 .79 r
.28926 .08012 m
.28926 .28006 L
.34194 .28006 L
.34194 .08012 L
s
.678 .847 .902 r
.34194 .08012 m
.34194 .26138 L
.40513 .26138 L
.40513 .08012 L
F
.2 .63 .79 r
.34194 .08012 m
.34194 .26138 L
.40513 .26138 L
.40513 .08012 L
s
.678 .847 .902 r
.40513 .08012 m
.40513 .20139 L
.44127 .20139 L
.44127 .08012 L
F
.2 .63 .79 r
.40513 .08012 m
.40513 .20139 L
.44127 .20139 L
.44127 .08012 L
s
.678 .847 .902 r
.44127 .08012 m
.44127 .19438 L
.51122 .19438 L
.51122 .08012 L
F
.2 .63 .79 r
.44127 .08012 m
.44127 .19438 L
.51122 .19438 L
.51122 .08012 L
s
.678 .847 .902 r
.51122 .08012 m
.51122 .14885 L
.54888 .14885 L
.54888 .08012 L
F
.2 .63 .79 r
.51122 .08012 m
.51122 .14885 L
.54888 .14885 L
.54888 .08012 L
s
.678 .847 .902 r
.54888 .08012 m
.54888 .128 L
.57036 .128 L
.57036 .08012 L
F
.2 .63 .79 r
.54888 .08012 m
.54888 .128 L
.57036 .128 L
.57036 .08012 L
s
.678 .847 .902 r
.57036 .08012 m
.57036 .10184 L
.62966 .10184 L
.62966 .08012 L
F
.2 .63 .79 r
.57036 .08012 m
.57036 .10184 L
.62966 .10184 L
.62966 .08012 L
s
.678 .847 .902 r
.62966 .08012 m
.62966 .08952 L
.67607 .08952 L
.67607 .08012 L
F
.2 .63 .79 r
.62966 .08012 m
.62966 .08952 L
.67607 .08952 L
.67607 .08012 L
s
1 .894 .882 r
.67607 .08012 m
.67607 .05047 L
.74511 .05047 L
.74511 .08012 L
F
.804 .522 .247 r
.67607 .08012 m
.67607 .05047 L
.74511 .05047 L
.74511 .08012 L
s
1 .894 .882 r
.74511 .08012 m
.74511 .04458 L
.78273 .04458 L
.78273 .08012 L
F
.804 .522 .247 r
.74511 .08012 m
.74511 .04458 L
.78273 .04458 L
.78273 .08012 L
s
1 .894 .882 r
.78273 .08012 m
.78273 .02776 L
.83989 .02776 L
.83989 .08012 L
F
.804 .522 .247 r
.78273 .08012 m
.78273 .02776 L
.83989 .02776 L
.83989 .08012 L
s
1 .894 .882 r
.83989 .08012 m
.83989 .02378 L
.86777 .02378 L
.86777 .08012 L
F
.804 .522 .247 r
.83989 .08012 m
.83989 .02378 L
.86777 .02378 L
.86777 .08012 L
s
1 .894 .882 r
.86777 .08012 m
.86777 .01802 L
.90512 .01802 L
.90512 .08012 L
F
.804 .522 .247 r
.86777 .08012 m
.86777 .01802 L
.90512 .01802 L
.90512 .08012 L
s
1 .894 .882 r
.90512 .08012 m
.90512 .01752 L
.95223 .01752 L
.95223 .08012 L
F
.804 .522 .247 r
.90512 .08012 m
.90512 .01752 L
.95223 .01752 L
.95223 .08012 L
s
1 .894 .882 r
.95223 .08012 m
.95223 .01496 L
.97619 .01496 L
.97619 .08012 L
F
.804 .522 .247 r
.95223 .08012 m
.95223 .01496 L
.97619 .01496 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.03702 .58711 Mdot
.11592 .49496 Mdot
.14561 .46239 Mdot
.23008 .37597 Mdot
.27929 .32989 Mdot
.33675 .28006 Mdot
.35966 .26138 Mdot
.43984 .20139 Mdot
.45002 .19438 Mdot
.52154 .14885 Mdot
.55838 .128 Mdot
.60977 .10184 Mdot
.63667 .08952 Mdot
.74148 .05047 Mdot
.76165 .04458 Mdot
.83441 .02776 Mdot
.85798 .02378 Mdot
.90482 .01802 Mdot
.9105 .01752 Mdot
.9567 .01496 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.223939) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.80319) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000<0n_3V1P000000103jl>H0
000000000000003o0?[`iZD0n_3V0@3oool00200n_3V0P0000020?[`iP8000000`3jl>H2000000<0
n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP0400000080n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000T0n_3V00@00000
0?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H00000
0?[`iP02000000T0n_3V1@00000:0?[`iP030000003jl>H0n_3V008000000`3jl>H2000000@0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H00`000000n_3V
0?[`iP02000000@0n_3V0P0000050?[`iP800000o`3jl>JT0?[`iP40oooo000P0?[`iP80000000<0
n_3V000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H01000
00020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
000=0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H0
0P00000K0?[`iP8000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000050?[`iP800000103jl>H2000000H0n_3V0P00003o0?[`iZ<0n_3V0@3oool00200n_3V1@00
00040?[`iP8000000`3jl>H6000000060?[`iP00000000000?[`iP000000n_3V0P0000000`3jl>H0
00000000000300000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
00002`3jl>H3000000<0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V
008000002@3jl>H5000000d0n_3V0P0000090?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000D0n_3V0P0000040?[`iP800000103jl>H400000?l0n_3VX`3jl>H10?oo
o`00803jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H0
00000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V00800000603jl>H00`000000n_3V0?[`iP02000000X0n_3V0`00
00030?[`iP80000000<0n_3V0000000000000`3jl>H3000000D0n_3V0P0000030?[`iP80000000<0
n_3V000000000000o`3jl>JS0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000
000000800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@000002
0?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V1000000:
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000D0n_3V0P000004
0?[`iP8000000`3jl>H2000000030?[`iP00000000000?l0n_3VX`3jl>H10?ooo`00803jl>H20000
0080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0U0?[`iP800000303jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V
008000000P3jl>H4000000<0n_3V0P0000000`3jl>H000000000003o0?[`iZ<0n_3V0@3oool001l0
n_3V1P0000040?[`iP800000;`3jl>H5000002L0n_3V1@00000:0?[`iP<00000103jl>H3000000@0
n_3V0`0000050?[`iP800000103jl>H300000?l0n_3VY03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`
iQP0n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`
iP00000000000000003jl>H00`0000020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H0
00000000003jl>H5000000<0n_3V3000000_0?[`iP<00000103jl>H200000?l0n_3Vb@3jl>H10?oo
o`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3jl>H010000000
n_3V0000000000030?[`iP050000003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H2
00000080n_3V0P0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H0000000000003
0?[`iP800000o`3jl>K90?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP0000000000
0080n_3V0P0000040?[`iP8000001@3jl>H200000080n_3V0P0000020?[`iP800000103jl>H20000
0080n_3V0P0000030?[`iP800000<03jl>H2000000030?[`iP00000000000?l0n_3VcP3jl>H10?oo
o`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H600000003
0?[`iP00000000000080n_3V0P0000020?[`iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD0
00002@3jl>H2000000030?[`iP00000000000?l0n_3VcP3jl>H10?ooo`008P3jl>H2000000@0n_3V
0P0000000`3jl>H00000000000020?[`iP800000103jl>H200000080n_3V0P000000103jl>H00000
0000003jl>H300000080n_3V0`0000000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300
n_3V1000003o0?[`i/l0n_3V0@3oool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V
100000030?[`iP80000000<0n_3V000000000000100000000`3jl>H00000000000020?[`iP@00000
103jl>H200000300n_3V0P00003o0?[`i]40n_3V0@3oool00280n_3V0P00000;0?[`iP8000008P3j
l>H200000340n_3V0P00003o0?[`i]00n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H4
00000380n_3V0`00003o0?[`i/h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000
n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`
iP000000n_3V0P0000020?[`iP030000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool0
0200n_3V0`0000000`3jl>H0000000000002000000050?[`iP000000n_3V0000003jl>H00`000002
0?[`iP030000003jl>H0000001T0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`000002
0?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP000000
0000000000P0n_3V100000000`3jl>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00
000000000000003jl>H000000?[`iP03000001P0n_3V0`0000040?[`iP800000103jl>H500000080
n_3V1@0000030?[`iP<000000`3jl>H3000000D0n_3V0`0000030?[`iP<00000NP3jl>H10?ooo`00
8@3jl>H2000000030?[`iP000000000000D0000000@0n_3V00000000000000000P3jl>H200000003
0?[`iP000000000000T0n_3V1@0000090?[`iP030000003jl>H0n_3V00800000g03jl>H2000000@0
n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`
iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V0P0000000`3jl>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5
000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2000000D0n_3V0P000005
0?[`iP030000003jl>H0n_3V00800000103jl>H2000000<0n_3V00<000000?[`iP3jl>H00P000004
0?[`iP800000N@3jl>H10?ooo`008P3jl>H3000002/0n_3V0P00003L0?[`iP800000103jl>H20000
0080n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3j
l>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V
0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002P3jl>H2000000D0n_3V0P000007
0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000N03jl>H10?ooo`008P3jl>H30000
01X0n_3V1@00000<0?[`iP800000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00030?[`iP000000000000X0n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H2
00000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H2
000000030?[`iP000000000000/0n_3V0P0000050?[`iP8000001P3jl>H2000000<0n_3V10000005
0?[`iP8000000`3jl>H4000007P0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000X0?[`
iP<00000g@3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000
003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H2
00000080n_3V0P0000000`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P00
00020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00
000H0?[`iP80000000<0n_3V000000000000303jl>H2000000D0n_3V0P0000030?[`iP<000000`3j
l>H2000000030?[`iP000000000000<0n_3V0`0000030?[`iP80000000<0n_3V000000000000N03j
l>H10?ooo`00803jl>H3000000040?[`iP0000000000000002T0n_3V0P00003L0?[`iP80000000<0
n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003jl>H500000080n_3V
100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000002`3jl>H3000000030?[`
iP00000000000080n_3V100000020?[`iP<0000000<0n_3V0000000000001`00000I0?[`iP800000
00<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000050?[`iP8000000P3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP800000
00<0n_3V000000000000N03jl>H10?ooo`00C@3jl>H00`000000n_3V0?[`iP0200000=`0n_3V0P00
00000`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`iP800000;P3j
l>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H000000000
00020?[`iP030000003jl>H0n_3V008000000P3jl>H2000000030?[`iP000000000007P0n_3V0@3o
ool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2
000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000;0?[`iP<00000103jl>H3
000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`00001i0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P00
00000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W
0?[`iP050000003jl>H000000?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000
003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P00
0000103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3j
l>H05`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<0
00000P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V0000000000001P00000J0?[`iPD0
00000`3jl>H300000<40n_3V0@3oool00240n_3V0P0000000`3jl>H0000000000005000000050?[`
iP00000000000000003jl>H01000000;0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0
n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000
n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000002`3j
l>H5000000T0n_3V0P0000050?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`008P3jl>H3
000002P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P000002
0?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P000002
0?[`iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000J0?[`iP800000103jl>H2
000000030?[`iP00000000000<00n_3V0@3oool00280n_3V0`0000090?[`iP030000003jl>H0n_3V
00h0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H4000000<0n_3V1@0000020?[`
iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP@000003@3jl>H5000000/0n_3V0P000003
0?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`008@3jl>H2000000030?[`iP0000000000
02L0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H20000
0080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2
000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3j
l>H2000001`0n_3V0P0000020?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00803jl>H3
000000040?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0
n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003jl>H500000080n_3V
100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000000`3jl>H5000001T0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00C@3j
l>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303j
l>H2000003P0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000`03j
l>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P000006
0?[`iP800000<@3jl>H3000000@0n_3V0`0000310?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`007@3jl>HS0?ooh0800000A@3oon02000000@0oooP0P00
00040?ooh0800000A03oon05000004<0oooP1@0000020?ooh0800000103oon02000004@0oooP1000
00140?ooh0@000000`3oon02000000@0oooP0P0000150?ooh08000009`3oon0N0?[`iP40oooo000M
0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh00000080?ooh0040000
003oon00oooP000004D0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0070?ooh004
0000003oon00oooP000004<0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0090?oo
h0040000003oon00oooP000004<0oooP00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo000M
0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh000000;0?ooh0030000
003oon00oooP04<0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh00:0?ooh0030000
003oon00oooP0480oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh00;0?ooh0030000
003oon00oooP04<0oooP00<000000?ooh03oon009@3oon0N0?[`iP40oooo000M0?[`iR80oooP00@0
00000?ooh03oon000000@`3oon0010000000oooP0?ooh00000090?ooh0800000AP3oon000`000000
oooP0?ooh0150?ooh0030000003oon00oooP00P0oooP0P0000160?ooh0030000003oon00oooP04D0
oooP00<000000?ooh03oon00203oon02000004L0oooP00<000000?ooh03oon00903oon0N0?[`iP40
oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh00000090?oo
h0030000003oon00oooP04D0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0080?oo
h0030000003oon00oooP04<0oooP00@000000?ooh03oon000000A03oon0010000000oooP0?ooh000
00090?ooh0030000003oon00oooP04<0oooP00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo
000M0?[`iR<0oooP0P0000150?ooh08000002P3oon03000004@0oooP0P0000160?ooh08000002P3o
on03000004@0oooP0P0000160?ooh08000002P3oon03000004@0oooP0P00000W0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`iQP0oooPo`00003Z000001/0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00303oon000`000000oooP0?oo
h00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?oo
h00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?oo
h00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?oo
h00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?oo
h00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?oo
h00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?oo
h00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?oo
h00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?oo
h00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?oo
h00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04X0oooP00<000000?oo
h03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?oo
h03oon00BP3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3@0?ooh0800000503o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o
0?ooh;T0oooP0P00000D0?ooh0@000004`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon0300000?l0oooP]`3oon05000000D0oooP6P000?l90?ooh0<000006`3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2U0?ooh140cHDo0`0000080000o`h0
cHDo00<0onCQ000000000000203oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPX03oon02000000<0oooP
00<0cHDo0?oTh@3oi>40203oi>490000o`8000004`3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5
?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00o`3oon2O0?ooh0@000000P3oon000`3=QCl0003o0000o`080000o`L0onCQ0P00
000E0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh9@0oooP0P000002
0?ooh0H0cHDo20000?lA0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0?l0oooPT`3oon04000000030?ooh0000?l0003o00@0003o0P3oi>420000
00<0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ
00T0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh03o0?ooh7`0oooP5@3=QCl70000o`030<f5?`3oi>40onCQ00X0
onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00T0
onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh7`0oooP00<0cHDo0?oTh@3oi>403@3oi>450000o`<0onCQ
0P0000020?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ
0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh7`0oooP00<0
cHDo0?oTh@3oi>402@3oi>440000o``0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oT
h@0?0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0oooP0?oo
h0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPO03oon000`3=QCl0onCQ0?oTh@050?oTh@@0003o403oi>400`3=QCl0onCQ0?oTh@0:
0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon1l0?ooh0040<f5?`3oi>40onCQ0?oTh@@0003o503oi>40
0`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40503oi>40
0`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1l0?ooh0@0003o603oi>400`3=
QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=
QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1h0?ooh0@0003o00<0cHDo0?oTh@3o
i>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3o
i>40503oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1a0?ooh0800000
00<0oooP0000o`000?l00P000?l40?ooh0030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>40
2P3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>40
2@3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP0?l0oooPJ@3oon070<f5?`@0003o2@3=QClK0?oTh@030<f5?`3o
i>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh6T0oooP00<0cHDo0?oTh@3oi>4010000?l4
000000P0onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40
onCQ00l0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00
oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`00003o0?oo
h6L0oooP00<000000000o`000?l00P000?l50?oTh@8000002@3oi>400`3=QCl0onCQ0?oTh@0I0?oT
h@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@0D0?oT
h@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?ooh03oon001`3oon03000001/0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPB03oon0M0<f5?`<0003o0P00000B0?oTh@03
0<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@03
0<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0oooP0?ooh0090?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
B03oon000`3=QCl0onCQ0?oTh@0G0?oTh@<0003o00<0onCQ0000000000000P00000B0?oTh@030<f5
?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5
?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0oooP0?ooh0090?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPB03o
on000`3=QCl0onCQ0?oTh@0D0?oTh@<0003o1@3oi>42000000030<f5?`3oi>40onCQ0100onCQ00<0
cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0
cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon18
0?ooh0030<f5?`3oi>40onCQ0180onCQ0P000?l:0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo
0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo
0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon180?oo
h0030<f5?`3oi>40onCQ00l0onCQ0`000?l<0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oT
h@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oT
h@3oi>40503oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon180?ooh003
0<f5?`3oi>40onCQ00`0onCQ0`000?l?0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3o
i>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3o
i>40503oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon180?ooh0030<f5
?`3oi>40onCQ00T0onCQ0`000?lB0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40
6@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40
503oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon180?ooh0030<f5?`3o
i>40onCQ00H0onCQ0`000?lE0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>406@3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40503o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon180?ooh0030<f5?`3oi>40
onCQ00@0onCQ0P000?lH0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>406@3oi>40
0`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40503oi>40
0`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon180?ooh0040<f5?`3oi>40onCQ
0?oTh@<0003o6P3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo
0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0?0?oTh@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPB03oon00103=QCl0onCQ0000o`000?lM
0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:
0?oTh@030<f5?`3oi>40onCQ00l0onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon170?ooh0<0003o7`3oi>400`3=QCl0onCQ0?oTh@0@0?oT
h@030<f5?`3oi>40onCQ01T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0?0?oT
h@030<f5?`3oi>40onCQ01@0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0oooP0?ooh0090?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon000`000000
oooP0?ooh03o0?ooh4@0oooP0`000?l00`3oon00cHDo0?oTh@0O0?oTh@030<f5?`3oi>40onCQ0100
onCQ00<0cHDo0?oTh@3oi>406@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00l0
onCQ00<0cHDo0?oTh@3oi>40503oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oon00oooP00T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon00
00001`3oon000`000000oooP0?ooh03o0?ooh480oooP0P000?l40?ooh0030<f5?`3oi>40onCQ01h0
onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@0I0?oTh@030<f5?`3oi>40onCQ00X0
onCQ00<0cHDo0?oTh@3oi>403`3oi>400`3=QCl0onCQ0?oTh@0D0?oTh@030<f5?`3oi>40onCQ00T0
onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
3@3oon0010000000oooP0?ooh00000070?ooh0@00000203oon3o000003H000000`000?nI000000P0
oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP03
03>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP03
03>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV01X0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H20000o`T0[MSV00<0<j7:0?ooh03o
on00V`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP
0?ooh00000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0
[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0
[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV01X0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H20000o`/0
[MSV00<0<j7:0?ooh03oon00V`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
3P3oon02000000P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>Q
bP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H06P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP80003o
3@2]f>H00`0cXLX0oooP0?ooh02K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gH
iP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gH
iP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gH
iP0>0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV01X0[MSV00<0<j7:0:gHiP2]f>H00P0000000`2]f>H0003o0000
o`0?0:gHiP0303>QbP3oon00oooP09/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0
[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0
[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0
[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H06P2]f>H203>QbP04000000000?l0003o0000oa80<j7:W@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;
0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0O
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0J
0:gHiP0303>QbP000?l0003o00<00000[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gH
iP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gH
iP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gH
iP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0I0:gHiP80003o0P3oon0200000;00oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0
[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0
[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H20000o`03
0:gHiP0cXLX0oooP0;<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV
00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00h0[MSV
00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H05@2]f>H20000o`<0[MSV00<0<j7:0?ooh03oon00/P3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]
f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]
f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP80000000<0
[MSV0000o`000?l01@2]f>H00`0cXLX0oooP0?ooh02b0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H0
0`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H0
0`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H0
0`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H0
0`0cXLX0[MSV0:gHiP070:gHiQ80<j7:0P0000020000o`P0<j7:]03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV
01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV
0100[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh00?0?ooh080003o0P00002l0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV01l0
[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00d0
oooP0P000?l00`3oon0000000000002m0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV
0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV
0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV
0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP3oon00oooP00/0oooP0P000?o20?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]
f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]
f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]
f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP00T0oooP0P000?o40?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L
0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon001`3oon020000ol@0oooP0`00000K
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV
01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV
0100[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0050?ooh080003ob03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP03
03>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0oooP0?ooh0030?ooh080
003obP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV
0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV
0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0oooP
0?ooh03oon020000ol`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV
00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00h0[MSV
00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0?ooh0000?l0003ocP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0
702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0
3P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H20000om00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0
<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0
<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0403>QbP2]f>H0[MSV0:gHiP800000
0P2]f>H20000o`0303>QbP3oon00oooP0<l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]
f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]
f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP0303>QbP2]
f>H0[MSV00<000000P000?l20:gHiP0303>QbP3oon00oooP0<l0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L
0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@
0:gHiP<0<j7:00@000000000o`000?l00000100cXL[A0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H0
0`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H0
0`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H0
0`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H0402]f>H0
100cXLX0oooP0000o`000?l200000=H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0
[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0
[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0
[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP80003ofP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gH
iP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0O0:gH
iP0303>QbP2]f>H0[MSV00h0[MSV0P000?l00`0cXLX0oooP0?ooh03I0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]
f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]
f>H0302]f>H20000o`80[MSV00<0<j7:0?ooh03oon00f@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV
00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV
00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV
00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV00/0[MSV
00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh03I0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]
f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]
f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]
f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV01l0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H20000o`D0[MSV00<0<j7:0?ooh03oon00f@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:
0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:
0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:
0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV00L0[MSV0P000?l7
0:gHiP0303>QbP3oon00oooP0=T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0c
XLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0c
XLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0c
XLX0[MSV0:gHiP0O0:gHiP0303>QbP2]f>H0[MSV0080[MSV0P0000000`2]f>H0003o0000o`090:gH
iP0303>QbP3oon00oooP0=L0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0
[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0
[MSV0:gHiP0O0:gHiP0403>QbP2]f>H0[MSV0:gHiP<0000000<0003o0:gHiP2]f>H02@2]f>H00`0c
XLX0oooP0?ooh03I0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP03
03>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP03
03>QbP2]f>H0[MSV01l0[MSV100cXLX010000000003o0000o`00000<03>Qb]/0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0
[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0
[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H00`0cXLX0
oooP0?ooh0020000o`800000j03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0
702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0
3P2]f>H00`0cXLX0[MSV0:gHiP0O0:gHiP0303>QbP3oon00003o0>`0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gH
iP0L0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07`2]f>H20000ond0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H0
0`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H07@2]f>H2
0000o`0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV
01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV
01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H06`2]f>H20000o`80[MSV00<0<j7:0?ooh03oon00k03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0J0:gHiP03
0000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV
00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV
00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV
00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP80003o1@2]f>H00`0cXLX0oooP
0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]
f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV01L0[MSV00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:
0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:
0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV01D0[MSV0P000?l8
0:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV
01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV
01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H20000o`X0[MSV00<0<j7:0?ooh03oon00k03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0B0:gHiP03
0000o`2]f>H0[MSV00X0[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV
00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV
00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV
00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP80003o3@2]f>H00`0cXLX0oooP
0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]
f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00l0[MSV00<0003o0:gHiP2]f>H03@2]f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L
0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H20000oa00[MSV00<0<j7:
0?ooh03oon00jP3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV
01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV
00/0[MSV0P000?lB0:gHiP0303>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP03
03>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP03
03>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`000?l0[MSV0:gHiP0B0:gHiP03
03>QbP3oon00oooP0>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV
00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00h0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H20000oaD0[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]
f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP030000o`2]
f>H0[MSV01D0[MSV00<0<j7:0?ooh03oon00k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:
0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:
0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:
0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP80003o602]f>H00`0cXLX0oooP0?ooh03/
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV
01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0003o0:gHiP2]f>H0602]f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]
f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0403>QbP2]f>H0[MSV0:gHiP80000000<0003o0:gH
iP2]f>H06@2]f>H00`0cXLX0oooP0?ooh03/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0
[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0
[MSV0:gHiP0>0:gHiP<0<j7:00@000000000o`000?l00000700cXL[^0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]
f>H0702]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0403>QbP3oon00oooP0000o`<00000o`3oon0;0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0
[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP80000000<0oooP0000o`3o
on000P00003o0?ooh0`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV
00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00`0[MSV
0P0000020000ool0oooP403oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]
f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV3`0cXLX010000000003o0000
0000003o0?ooh100oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0
<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP3oon00oooP00`0oooP00<0
003o000000000000o`3oon0A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=
0?ooh0@000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:
0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:
0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:
0?ooh03oon002P3oon020000ool0oooP503oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V3@3oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gH
iP2]f>H0702]f>H00`0cXLX0oooP0?ooh0090?ooh0030000o`3oon00oooP0?l0oooP503oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon000`000000oooP0?ooh0070?ooh0@0
0000203oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]
f>H05`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP3oon00oooP00P0oooP00<0003o0?ooh03o
on00o`3oon0B0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPl0oooP00<000000?ooh03oon00
1P3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0
702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0?ooh03oon00
1P3oon020000ool0oooP603oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3o
on0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
4`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H0
702]f>H00`0cXLX0oooP0?ooh0050?ooh0030000o`3oon00oooP0?l0oooP603oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]
f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP3oon00oooP00<0oooP0P000?oo0?ooh1/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H0
0`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP3oon00oooP0080oooP00<0003o0?ooh03oon00o`3oon0K
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV
01L0[MSV00<0<j7:0:gHiP2]f>H0702]f>H01@0cXLX0oooP0?ooh03oon00003o0?l0oooP7P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gH
iP0303>QbP2]f>H0[MSV01`0[MSV00@0<j7:0?ooh0000?l0003oo`3oon0O0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01L0[MSV00<0<j7:0:gH
iP2]f>H0702]f>H00`0cXLX0003o0?ooh03o0?ooh200oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP03
03>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0K0:gHiP80
003oo`3oon0R0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>Q
bP2]f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H06P2]f>H00`000?l0[MSV03>QbP3o0?ooh280oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]
f>H00`0cXLX0[MSV0:gHiP0H0:gHiP80003o0P2]f>H00`0cXLX0oooP0?ooh03o0?ooh200oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon0P
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV
01L0[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`000?l0[MSV0:gHiP030:gHiP0303>QbP3oon00oooP
0?l0oooP803oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0
[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01@0[MSV0P000?l60:gHiP0303>QbP3oon00oooP0?l0
oooP803oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV
0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0003o0:gHiP2]f>H01P2]f>H00`0cXLX0oooP
0?ooh03o0?ooh200oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0
<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP80003o2@2]f>H00`0cXLX0oooP0?oo
h03o0?ooh200oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`000009
0?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;
0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G
0:gHiP0303>QbP2]f>H0[MSV0100[MSV00<0003o0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh03o
0?ooh1h0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gH
iP0303>QbP2]f>H0[MSV00l0[MSV00<0003o0:gHiP2]f>H02P2]f>H00`0cXLX0oooP0?ooh03o0?oo
h200oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]
f>H05`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP80003o3@2]f>H00`0cXLX0oooP0?ooh03o0?ooh200
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0
2`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H0
5`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP030000o`2]f>H0[MSV00d0[MSV00<0<j7:0?ooh03oon00
o`3oon0P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]
f>H0[MSV01L0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`000?l0[MSV0:gHiP0>0:gHiP0303>QbP3o
on00oooP0?l0oooP803oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H0
0`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0003o0:gHiP2]f>H03`2]f>H0
0`0cXLX0oooP0?ooh03o0?ooh200oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV
01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV
01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP80003o4P2]f>H00`0c
XLX0oooP0?ooh03o0?ooh200oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0
[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP80000000<0003o0:gHiP2]
f>H04P2]f>H00`0cXLX0oooP0?ooh03o0?ooh200oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>Q
bP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP800000
00<0003o0000002]f>H04`2]f>H00`0cXLX0oooP0?ooh03o0?ooh200oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H703>QbP80003o0P00
000E03>Qb_l0oooP8P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H0
0`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H0
0`0cXLX0[MSV0:gHiP0G0:gHiP0303>QbP3oon00oooP00<0oooP00@0003o0?ooh00000000000o`3o
on0h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0
[MSV01L0[MSV00<0<j7:0?ooh03oon000P3oon000`000?l0oooP0?ooh03o0?ooh3X0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0c
XLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H01@0c
XLX0oooP0?ooh03oon00003o0?l0oooP?@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gH
iP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gH
iP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP0403>QbP3oon00003o0000ool0oooP?P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gH
iP0303>QbP000?l0oooP0?l0oooP?`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]
f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]
f>H0602]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP030000o`3oon00oooP0?l0oooP?`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0
4`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP2]f>H0[MSV01@0[MSV0P0000000`000?l0<j7:
0?ooh03o0?ooh3h0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gH
iP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0[MSV0:gH
iP0C0:gHiP80000000<0003o0000000cXLX0o`3oon110?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H0
0`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H0
0`0cXLX0[MSV0:gHiP0H0:gHiQH0<j7:00D000000000o`000000000003>QbP3o0?ooh440oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0?ooh03oon004P3oon02
0000o`800000o`3oon130?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gH
iP0303>QbP3oon00oooP0140oooP00<0003o0?ooh03oon00o`3oon150?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP3oon00oooP0100oooP00<0003o0?ooh03o
on00o`3oon160?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>Q
bP3oon00oooP00l0oooP00<0003o0?ooh03oon00o`3oon170?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]
f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]
f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP3oon00oooP00h0oooP00<0003o0?ooh03oon00o`3o
on180?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP3oon00
oooP00d0oooP00<0003o0?ooh03oon00o`3oon190?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0c
XLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0c
XLX0[MSV0:gHiP0H0:gHiP0303>QbP3oon00oooP00`0oooP00<0003o0?ooh03oon00o`3oon1:0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP3oon00oooP00/0
oooP00<0003o0?ooh03oon00o`3oon1;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV
0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV
0:gHiP0H0:gHiP0303>QbP3oon00oooP00X0oooP00<0003o0?ooh03oon00o`3oon1<0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP3oon00oooP00P0oooP0P00
0?oo0?ooh4l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:
0?ooh03oon001`3oon000`000?l0oooP0?ooh03o0?ooh4l0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gH
iP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gH
iP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0?ooh03oon001P3oon000`000?l0oooP0?ooh03o0?oo
h500oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0<j7:0?ooh03o
on001@3oon000`000?l0oooP0?ooh03o0?ooh540oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0
702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0
602]f>H00`0cXLX0oooP0?ooh0040?ooh0030000o`3oon00oooP0?l0oooPD03oon03000001/0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]
f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]
f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP3oon00oooP00<0oooP00<0003o0?ooh03oon00o`3o
on1C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0303>QbP3oon00
oooP0080oooP00<0003o0?ooh03oon00o`3oon1D0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0c
XLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0c
XLX0[MSV0:gHiP0H0:gHiP0503>QbP3oon00oooP0?ooh0000?l0o`3oon1G0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0H0:gHiP0403>QbP3oon00oooP0000ool0oooPF03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H0602]f>H00`0cXLX0003o0000o`3o0?oo
h5T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0[MSV01P0[MSV00<0003o0?ooh03o
on00o`3oon1I0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0[MSV0:gHiP0G0:gHiP030000
o`0cXLX0oooP0?l0oooPFP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0:gHiP2]f>H05P2]
f>H00`000?l0[MSV03>QbP3o0?ooh5/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0
[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP2]f>H0
[MSV01<0[MSV0P00000010000?l0[MSV0:gHiP0cXL[o0?ooh5/0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiQD0<j7:0P0000000`000?l0000003>QbP0203>Qb_l0oooPF`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
0200[MSV00<0<j7:0?ooh03oon004P3oon0010000000003o00000000003o0?ooh5h0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0c
XLX0[MSV0:gHiP0P0:gHiP0303>QbP3oon00oooP0180oooP00<0003o000000000000o`3oon1O0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0oooP0?ooh00A0?ooh0030000o`3oon00oooP0?l0
oooPH03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3`3oon03000000H0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP3oon00oooP00l0oooP
0P000?oo0?ooh6<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQ00oooP00<0
00000?ooh03oon001@3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0
<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0
<j7:0?ooh03oon003P3oon000`000?l0oooP0?ooh03o0?ooh6<0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iPd0oooP1@0000060?ooh0@00000203oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiP0303>QbP3oon00oooP00d0oooP00<0003o0?ooh03oon00o`3oon1Q0?ooh0@000006`3oon0N
0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;
0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0?ooh03oon00303oon000`000?l0oooP0?ooh03o
0?ooh6D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<000000?oo
h00000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gH
iP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0?oo
h03oon002`3oon000`000?l0oooP0?ooh03o0?ooh6H0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iPl0oooP0P0000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0802]f>H00`0cXLX0oooP0?ooh00:0?ooh0030000o`3oon00oooP0?l0oooPI`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>Q
bP2]f>H0[MSV0200[MSV00<0<j7:0?ooh03oon002@3oon000`000?l0oooP0?ooh03o0?ooh6P0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP3oon00oooP00P0oooP00<0003o0?ooh03oon00o`3o
on1Y0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0oooP0?ooh0070?ooh0030000o`3oon00
oooP0?l0oooPJP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0c
XLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0?ooh03oon001P3oon000`00
0?l0oooP0?ooh03o0?ooh6/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP3oon00oooP00D0
oooP00<0003o0?ooh03oon00o`3oon1/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV
0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H00`0cXLX0oooP
0?ooh0040?ooh0030000o`3oon00oooP0?l0oooPK@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0
<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0
<j7:0?ooh03oon000`3oon000`000?l0oooP0?ooh03o0?ooh6h0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P
0:gHiP0403>QbP3oon00oooP0?ooh080003oo`3oon1a0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H0
0`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0802]f>H0
100cXLX0oooP0?ooh0000?oo0?ooh7<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0
[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0P0:gHiP0303>QbP3oon00
003o0?l0oooPM03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0c
XLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV0200[MSV00<0<j7:0000o`3oon00o`3oon1d0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H07P2]f>H2000000030000o`3oon00oooP0?l0oooPM03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0
4`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
7@2]f>H2000000030000o`000000oooP0?l0oooPL`3oon03000001/0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gH
iP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV800cXLX010000000003o00000000003o0?ooh7H0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0oooP0?ooh00M0?ooh0030000o`00000000000?l0oooPM`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP3oon00
oooP01`0oooP00<0003o0?ooh03oon00o`3oon1h0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0c
XLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03oon006`3oon000`00
0?l0oooP0?ooh03o0?ooh7T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0oooP0?ooh00J0?ooh0030000o`3oon00oooP0?l0
oooPNP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP3oon00oooP01T0oooP00<0003o0?ooh03oon00o`3oon1k0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0?ooh03oon00603oon000`000?l0oooP0?ooh03o0?ooh7`0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0oooP0?ooh00G
0?ooh0030000o`3oon00oooP0?l0oooPO@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gH
iP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP3oon00oooP01H0oooP00<0003o0?oo
h03oon00o`3oon1n0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03oon005@3oon000`000?l0oooP0?ooh03o0?ooh7l0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0
2`2]f>H00`0cXLX0oooP0?ooh00D0?ooh0030000o`3oon00oooP0?l0oooPP03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP3o
on00oooP01<0oooP00<0003o0?ooh03oon00o`3oon210?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H0
0`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03oon004P3oon00
0`000?l0oooP0?ooh03o0?ooh880oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV
01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0oooP0?ooh00A0?ooh0030000o`3oon00oooP
0?l0oooPP`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP3oon00oooP0100oooP00<0003o0?ooh03oon00o`3oon240?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV
0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0oooP
0?ooh00?0?ooh0030000o`3oon00oooP0?l0oooPP`3oon03000001/0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gH
iP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03oon003P3oon000`000?l0oooP0?oo
h03o0?ooh8H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0oooP0?ooh00=0?ooh0030000o`3oon00oooP0?l0oooPQ`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP3oon00oooP00`0oooP00<0003o0?ooh03oon00o`3oon280?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03o
on002`3oon000`000?l0oooP0?ooh03o0?ooh8T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0oooP0?ooh00:0?ooh0030000
o`3oon00oooP0?l0oooPRP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP3oon00oooP00T0oooP00<0003o0?ooh03oon00o`3o
on2;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0?ooh03oon00203oon000`000?l0oooP0?ooh03o0?ooh8`0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0c
XLX0oooP0?ooh0070?ooh0030000o`3oon00oooP0?l0oooPS@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP3oon00oooP00H0
oooP00<0003o0?ooh03oon00o`3oon2>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV
0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03oon001@3oon000`000?l0oooP
0?ooh03o0?ooh8l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0oooP0?ooh0040?ooh0030000o`3oon00oooP0?l0oooPT03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP0;
0:gHiP0303>QbP3oon00oooP00<0oooP00<0003o0?ooh03oon00o`3oon2A0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?oo
h03oon000P3oon000`000?l0oooP0?ooh03o0?ooh980oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H01@0cXLX0oooP0?ooh03oon00003o
0?l0oooPU@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0403>QbP3oon00oooP0000ool0oooPUP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh0000?l0o`3oon2E0?ooh0<0
00006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0003o
0?ooh03o0?ooh9L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`000?l0oooP0?ooh03o0?ooh9L0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`000?l0oooP0?ooh03o
0?ooh9L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gH
iP2]f>H02P2]f>H00`000?l0<j7:0?ooh03o0?ooh9P0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP03
03>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`000?l0[MSV03>QbP3o0?ooh9T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H010000?l0[MSV0:gHiP0cXL[o0?ooh9T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV01`0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H01@000?l0[MSV0:gHiP2]f>H0<j7:0?l0
oooPV@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV
0:gHiP060:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon2G0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0L0:gHiP0303>QbP2]f>H0[MSV00<0[MSV0P00
00000`000?l0[MSV0:gHiP030:gHiP0303>QbP3oon00oooP0?l0oooPU`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0[MSV0:gHiP020:gHiP80000000<0003o
0000002]f>H0102]f>H00`0cXLX0oooP0?ooh03o0?ooh9L0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gH
iP0303>QbP2]f>H0[MSV01`0[MSV1@0cXLX010000000003o00000000000603>Qb_l0oooPV@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0oooP0?ooh0020?oo
h0030000o`00000000000?l0oooPX03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]
f>H0702]f>H01@0cXLX0oooP0?ooh03oon00003o0?l0oooPX`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V3@3oon03000000P0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00@0<j7:0?ooh03oon00003oo`3oon2T0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP0000
00L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV
01`0[MSV00<0<j7:0?ooh0000?l0o`3oon2U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP100000080?ooh00303>QbP2]f>H0[MSV
01<0[MSV00<0<j7:0:gHiP2]f>H0702]f>H00`0cXLX0003o0?ooh03o0?ooh:80oooP1000000K0?oo
h1h0n_3V0@3oool001d0n_3V3@3oon03000000P0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV00<0003o0?ooh03oon00o`3oon2U0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00oooP00L0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV01`0[MSV
00<0003o0?ooh03oon00o`3oon2U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H>0?ooh0<000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0
<j7:0:gHiP2]f>H06`2]f>H00`000?l0<j7:0?ooh03o0?ooh:H0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV01X0[MSV00<0003o0:gHiP0cXLX0o`3oon2W0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP0I0:gHiP040000o`2]f>H0[MSV03>Qb_l0oooPY`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0602]f>H01@000?l0[MSV0:gHiP2]f>H0
<j7:0?l0oooPY`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H05`2]f>H00`00
0?l0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP0?l0oooPY@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:0:gHiP2]f>H05P2]f>H00`000?l0[MSV0:gHiP030:gHiP0303>QbP3oon00oooP0?l0
oooPY@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H2000000030000
o`2]f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon00o`3oon2U0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]
f>H00`0cXLX0[MSV0:gHiP0B0:gHiP80000000<0003o0000002]f>H01@2]f>H00`0cXLX0oooP0?oo
h03o0?ooh:D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiQD0<j7:00@000000000o`00000000001`0c
XL[o0?ooh:L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP3oon00oooP01<0oooP00<0003o
0000003oon00o`3oon2^0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0oooP0?ooh00B0?oo
h0030000o`3oon00oooP0?l0oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0?ooh03o
on004@3oon000`000?l0oooP0?ooh03o0?ooh;00oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP3oon00oooP0100oooP00<0003o0?ooh03oon00o`3oon2a0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP3o
on00oooP00l0oooP00<0003o0?ooh03oon00o`3oon2`0?ooh0<000006`3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP3oon00
oooP00h0oooP00<0003o0?ooh03oon00o`3oon2c0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0c
XLX0oooP0?ooh00=0?ooh0030000o`3oon00oooP0?l0oooP]03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:0?ooh03oon00303oon000`000?l0oooP0?ooh03o0?ooh;D0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0C0:gHiP0303>QbP3oon00oooP00/0oooP00<0003o0?ooh03oon00o`3oon2f0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0oooP0?ooh00;0?ooh0030000o`3oon00oooP0?l0oooP]P3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0?ooh03oon002P3oon000`000?l0oooP0?ooh03o
0?ooh;L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP3oon00oooP00T0oooP00<0003o0?oo
h03oon00o`3oon2h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0oooP0?ooh0080?ooh003
0000o`3oon00oooP0?l0oooP^@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0?ooh03oon00
1`3oon000`000?l0oooP0?ooh03o0?ooh;X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP3o
on00oooP00H0oooP00<0003o0?ooh03oon00o`3oon2k0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H0
0`0cXLX0oooP0?ooh0060?ooh0030000o`3oon00oooP0?l0oooP^`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
01<0[MSV00<0<j7:0?ooh03oon001@3oon000`000?l0oooP0?ooh03o0?ooh;`0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0C0:gHiP0303>QbP3oon00oooP00@0oooP00<0003o0?ooh03oon00o`3oon2m0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0oooP0?ooh0030?ooh0030000o`3oon00oooP0?l0oooP
_P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0?ooh03oon000P3oon000`000?l0oooP0?oo
h03o0?ooh;l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`000009
0?ooh00303>QbP2]f>H0[MSV01<0[MSV00D0<j7:0?ooh03oon00oooP0000o`3o0?ooh<00oooP0`00
000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV01<0[MSV00D0<j7:0?ooh03oon00oooP0000o`3o0?ooh<80oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0C
0:gHiP0403>QbP3oon00oooP0000ool0oooP``3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV01<0[MSV00<0<j7:
0?ooh0000?l0o`3oon340?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0003o0?ooh03o0?oo
h<@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0C0:gHiP030000o`3oon00oooP0?l0oooPa03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV0180[MSV00<0003o03>QbP3oon00o`3oon350?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H04P2]
f>H00`000?l0<j7:0?ooh03o0?ooh<D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0A0:gHiP030000o`2]f>H0
<j7:0?l0oooPaP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV0100[MSV00@0003o0:gHiP2]f>H0<j7:o`3oon36
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H03`2]f>H01@000?l0[MSV0:gHiP2]f>H0<j7:0?l0oooPaP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00h0[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh03o0?oo
h<@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP030000o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03o
on00o`3oon340?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`000?l0[MSV0:gHiP030:gHiP0303>Q
bP3oon00oooP0?l0oooPa03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00`0[MSV00<0003o0:gHiP2]f>H0102]
f>H00`0cXLX0oooP0?ooh03o0?ooh<@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0;0:gHiP030000o`2]f>H0
[MSV00D0[MSV00<0<j7:0?ooh03oon00o`3oon340?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP0:0:gHiP030000o`2]f>H0[MSV
00H0[MSV00<0<j7:0?ooh03oon00o`3oon320?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV00L0
[MSV00<0<j7:0?ooh03oon00o`3oon340?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV
0:gHiP080:gHiP0303>QbP3oon00oooP0?l0oooPa03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00L0[MSV00<0
003o0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh03o0?ooh<@0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP06
0:gHiP030000o`2]f>H0[MSV00X0[MSV00<0<j7:0?ooh03oon00o`3oon340?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H01P2]f>H00`000?l0[MSV0:gHiP0:0:gHiP0303>QbP3oon00oooP0?l0oooPa03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00<0[MSV0P0000000`000?l0[MSV0:gHiP0;0:gHiP0303>QbP3oon00oooP0?l0
oooPa03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV0080[MSV0P0000000`000?l000000:gHiP0<0:gHiP0303>Q
bP3oon00oooP0?l0oooPa03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh0D0<j7:00@000000000o`00000000003P0cXL[o0?ooh<H0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon003P3o
on000`000?l000000000003o0?ooh=D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon003@3oon000`000?l0oooP0?ooh03o0?ooh=H0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00303oon000`00
0?l0oooP0?ooh03o0?ooh=L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00303oon000`000?l0oooP0?ooh03o0?ooh=L0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00/0oooP
00<0003o0?ooh03oon00o`3oon3H0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002P3oon000`000?l0oooP
0?ooh03o0?ooh=T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@0
00000?ooh03oon0000001`3oon04000000P0oooP00<0003o0?ooh03oon00o`3oon3G0?ooh0@00000
6`3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP04X0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh003
0000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh003
0000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon3o00000>X000006`3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=40n_3V10000002
0?[`iPP000000P3jl>H4000000070?[`iP00000000000000003jl>H000000?[`iP0<000000030?[`
iP000000000000@0000000@0n_3V0000000000000000203jl>H5000000@0n_3V1`0000000`3jl>H0
00000?[`iP03000000P0n_3V1@0000020?[`iP@000000P3jl>H5000000`0n_3V0`00000A0?[`iP<0
00001P3jl>H3000000040?[`iP0000000000000000H0n_3V00<000000?[`iP3jl>H0103jl>H30000
00040?[`iP000000000000000=P0n_3V0@3oool00=80n_3V0P0000020?[`iP8000000`3jl>H20000
00<0n_3V0P0000030?[`iP070000003jl>H000000000003jl>H000000?[`iP0400000080n_3V0P00
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000T0n_3V00@0
00000?[`iP3jl>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80
000000<0n_3V0000000000003`3jl>H2000000030?[`iP000000000000H0n_3V0P0000000`3jl>H0
0000000000070?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003I0?[`iP40
oooo003B0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P0000050?[`iP800000
00<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80
000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80
00003@3jl>H2000000030?[`iP000000000000D0n_3V1@0000050?[`iP80000000<0n_3V00000000
00001`3jl>H3000000H0n_3V1@0000060?[`iP<00000fP3jl>H10?ooo`00dP3jl>H5000000@0n_3V
0P0000030?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP0000000000
00<000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`
iP<000000`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:
0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000003@3jl>H2000000030?[`iP000000
000000l0n_3V0P0000000`3jl>H00000000000070?[`iP<00000203jl>H00`000000n_3V0?[`iP06
0?[`iP<00000fP3jl>H10?ooo`00dP3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H20000
0080n_3V0P0000001P3jl>H000000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P00
0000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V
0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000n_3V00X0n_3V0`00000@0?[`iP@00000
1`3jl>H2000000030?[`iP000000000000L0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`
iP00000000000=T0n_3V0@3oool00=80n_3V0P0000020?[`iP80000000<0n_3V0000000000000P00
00040?[`iP@0000000<0n_3V0000000000001@0000020?[`iP@000000P3jl>H500000080n_3V1@00
000:0?[`iP8000001@3jl>H3000000030?[`iP000000000000L000002P3jl>H500000080n_3V1000
00020?[`iP<0000000<0n_3V0000000000002P3jl>H2000000030?[`iP000000000000l0n_3V0P00
00080?[`iP<0000000@0n_3V00000000000000003@3jl>H3000000030?[`iP000000000000D00000
e03jl>H10?ooo`00dP3jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`
iP0G0?[`iP8000006P3jl>H2000000030?[`iP00000000000100n_3V0P00000S0?[`iP030000003j
l>H0n_3V0=@0n_3V0@3oool00=40n_3V1P0000040?[`iP800000;`3jl>H5000001X0n_3V0`00000I
0?[`iP<000004P3jl>H300000280n_3V00<000000?[`iP3jl>H0d`3jl>H10?ooo`00o`3jl>J30?[`
iP030000003jl>H0n_3V0=80n_3V0@3oool00?l0n_3VP03jl>H010000000n_3V0?[`iP00003D0?[`
iP40oooo003o0?[`iX40n_3V0P00003E0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .59825 L
.05649 .59825 L
.05649 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .59825 L
.05649 .59825 L
.05649 .08012 L
s
.678 .847 .902 r
.05649 .08012 m
.05649 .55687 L
.09444 .55687 L
.09444 .08012 L
F
.2 .63 .79 r
.05649 .08012 m
.05649 .55687 L
.09444 .55687 L
.09444 .08012 L
s
.678 .847 .902 r
.09444 .08012 m
.09444 .5059 L
.12986 .5059 L
.12986 .08012 L
F
.2 .63 .79 r
.09444 .08012 m
.09444 .5059 L
.12986 .5059 L
.12986 .08012 L
s
.678 .847 .902 r
.12986 .08012 m
.12986 .47551 L
.1493 .47551 L
.1493 .08012 L
F
.2 .63 .79 r
.12986 .08012 m
.12986 .47551 L
.1493 .47551 L
.1493 .08012 L
s
.678 .847 .902 r
.1493 .08012 m
.1493 .45218 L
.17184 .45218 L
.17184 .08012 L
F
.2 .63 .79 r
.1493 .08012 m
.1493 .45218 L
.17184 .45218 L
.17184 .08012 L
s
.678 .847 .902 r
.17184 .08012 m
.17184 .39028 L
.2186 .39028 L
.2186 .08012 L
F
.2 .63 .79 r
.17184 .08012 m
.17184 .39028 L
.2186 .39028 L
.2186 .08012 L
s
.678 .847 .902 r
.2186 .08012 m
.2186 .3861 L
.23846 .3861 L
.23846 .08012 L
F
.2 .63 .79 r
.2186 .08012 m
.2186 .3861 L
.23846 .3861 L
.23846 .08012 L
s
.678 .847 .902 r
.23846 .08012 m
.23846 .3592 L
.25937 .3592 L
.25937 .08012 L
F
.2 .63 .79 r
.23846 .08012 m
.23846 .3592 L
.25937 .3592 L
.25937 .08012 L
s
.678 .847 .902 r
.25937 .08012 m
.25937 .32627 L
.28804 .32627 L
.28804 .08012 L
F
.2 .63 .79 r
.25937 .08012 m
.25937 .32627 L
.28804 .32627 L
.28804 .08012 L
s
.678 .847 .902 r
.28804 .08012 m
.28804 .31673 L
.3037 .31673 L
.3037 .08012 L
F
.2 .63 .79 r
.28804 .08012 m
.28804 .31673 L
.3037 .31673 L
.3037 .08012 L
s
.678 .847 .902 r
.3037 .08012 m
.3037 .27311 L
.34838 .27311 L
.34838 .08012 L
F
.2 .63 .79 r
.3037 .08012 m
.3037 .27311 L
.34838 .27311 L
.34838 .08012 L
s
.678 .847 .902 r
.34838 .08012 m
.34838 .25913 L
.37066 .25913 L
.37066 .08012 L
F
.2 .63 .79 r
.34838 .08012 m
.34838 .25913 L
.37066 .25913 L
.37066 .08012 L
s
.678 .847 .902 r
.37066 .08012 m
.37066 .23668 L
.39501 .23668 L
.39501 .08012 L
F
.2 .63 .79 r
.37066 .08012 m
.37066 .23668 L
.39501 .23668 L
.39501 .08012 L
s
.678 .847 .902 r
.39501 .08012 m
.39501 .21202 L
.43572 .21202 L
.43572 .08012 L
F
.2 .63 .79 r
.39501 .08012 m
.39501 .21202 L
.43572 .21202 L
.43572 .08012 L
s
.678 .847 .902 r
.43572 .08012 m
.43572 .19507 L
.46515 .19507 L
.46515 .08012 L
F
.2 .63 .79 r
.43572 .08012 m
.43572 .19507 L
.46515 .19507 L
.46515 .08012 L
s
.678 .847 .902 r
.46515 .08012 m
.46515 .16627 L
.499 .16627 L
.499 .08012 L
F
.2 .63 .79 r
.46515 .08012 m
.46515 .16627 L
.499 .16627 L
.499 .08012 L
s
.678 .847 .902 r
.499 .08012 m
.499 .15111 L
.51814 .15111 L
.51814 .08012 L
F
.2 .63 .79 r
.499 .08012 m
.499 .15111 L
.51814 .15111 L
.51814 .08012 L
s
.678 .847 .902 r
.51814 .08012 m
.51814 .14413 L
.56067 .14413 L
.56067 .08012 L
F
.2 .63 .79 r
.51814 .08012 m
.51814 .14413 L
.56067 .14413 L
.56067 .08012 L
s
.678 .847 .902 r
.56067 .08012 m
.56067 .11417 L
.60943 .11417 L
.60943 .08012 L
F
.2 .63 .79 r
.56067 .08012 m
.56067 .11417 L
.60943 .11417 L
.60943 .08012 L
s
.678 .847 .902 r
.60943 .08012 m
.60943 .09039 L
.64658 .09039 L
.64658 .08012 L
F
.2 .63 .79 r
.60943 .08012 m
.60943 .09039 L
.64658 .09039 L
.64658 .08012 L
s
1 .894 .882 r
.64658 .08012 m
.64658 .07609 L
.67783 .07609 L
.67783 .08012 L
F
.804 .522 .247 r
.64658 .08012 m
.64658 .07609 L
.67783 .07609 L
.67783 .08012 L
s
1 .894 .882 r
.67783 .08012 m
.67783 .05791 L
.72064 .05791 L
.72064 .08012 L
F
.804 .522 .247 r
.67783 .08012 m
.67783 .05791 L
.72064 .05791 L
.72064 .08012 L
s
1 .894 .882 r
.72064 .08012 m
.72064 .04656 L
.76546 .04656 L
.76546 .08012 L
F
.804 .522 .247 r
.72064 .08012 m
.72064 .04656 L
.76546 .04656 L
.76546 .08012 L
s
1 .894 .882 r
.76546 .08012 m
.76546 .03975 L
.79618 .03975 L
.79618 .08012 L
F
.804 .522 .247 r
.76546 .08012 m
.76546 .03975 L
.79618 .03975 L
.79618 .08012 L
s
1 .894 .882 r
.79618 .08012 m
.79618 .02975 L
.84403 .02975 L
.84403 .08012 L
F
.804 .522 .247 r
.79618 .08012 m
.79618 .02975 L
.84403 .02975 L
.84403 .08012 L
s
1 .894 .882 r
.84403 .08012 m
.84403 .02353 L
.86367 .02353 L
.86367 .08012 L
F
.804 .522 .247 r
.84403 .08012 m
.84403 .02353 L
.86367 .02353 L
.86367 .08012 L
s
1 .894 .882 r
.86367 .08012 m
.86367 .02149 L
.88786 .02149 L
.88786 .08012 L
F
.804 .522 .247 r
.86367 .08012 m
.86367 .02149 L
.88786 .02149 L
.88786 .08012 L
s
1 .894 .882 r
.88786 .08012 m
.88786 .01898 L
.91392 .01898 L
.91392 .08012 L
F
.804 .522 .247 r
.88786 .08012 m
.88786 .01898 L
.91392 .01898 L
.91392 .08012 L
s
1 .894 .882 r
.91392 .08012 m
.91392 .0163 L
.95403 .0163 L
.95403 .08012 L
F
.804 .522 .247 r
.91392 .08012 m
.91392 .0163 L
.95403 .0163 L
.95403 .08012 L
s
1 .894 .882 r
.95403 .08012 m
.95403 .01472 L
.97619 .01472 L
.97619 .08012 L
F
.804 .522 .247 r
.95403 .08012 m
.95403 .01472 L
.97619 .01472 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.02792 .59825 Mdot
.06216 .55687 Mdot
.10619 .5059 Mdot
.13353 .47551 Mdot
.15514 .45218 Mdot
.21544 .39028 Mdot
.21968 .3861 Mdot
.2476 .3592 Mdot
.28329 .32627 Mdot
.29399 .31673 Mdot
.34518 .27311 Mdot
.36248 .25913 Mdot
.39134 .23668 Mdot
.42479 .21202 Mdot
.449 .19507 Mdot
.49293 .16627 Mdot
.51774 .15111 Mdot
.52961 .14413 Mdot
.5847 .11417 Mdot
.63469 .09039 Mdot
.66865 .07609 Mdot
.7182 .05791 Mdot
.75467 .04656 Mdot
.77978 .03975 Mdot
.82396 .02975 Mdot
.85962 .02353 Mdot
.87402 .02149 Mdot
.8951 .01898 Mdot
.92682 .0163 Mdot
.97312 .01472 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.153607) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.93459) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000@0n_3V0`0000050?[`iP<00000103jl>H4000000<0n_3V0`0000030?[`iP<0
0000o`3jl>JU0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000060?[`iP8000000`3j
l>H00`000000n_3V0?[`iP02000000@0n_3V0P0000030?[`iP030000003jl>H0n_3V00800000103j
l>H200000?l0n_3VY03jl>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P000003
0?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000006`3jl>H2000000`0n_3V0P00
00050?[`iP80000000<0n_3V000000000000100000050?[`iP8000001@3jl>H200000?l0n_3VX`3j
l>H10?ooo`00803jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V000000000000n_3V0000
003jl>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`iP00000000000?[`iP80
000000<0n_3V0000003jl>H00P0000090?[`iPD000003@3jl>H2000000X0n_3V100000050?[`iP80
000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP8000000`3jl>H400000?l0n_3VX`3jl>H10?oo
o`00803jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H0
00000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V00800000603jl>H00`000000n_3V0?[`iP02000000T0n_3V0P00
00000`3jl>H00000000000030?[`iP<000000`3jl>H010000000n_3V0000000000030?[`iP030000
003jl>H0n_3V008000000P3jl>H2000000030?[`iP00000000000?l0n_3VX`3jl>H10?ooo`00803j
l>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H000000000
000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0
n_3V0000000000001`00000I0?[`iP@000002P3jl>H2000000030?[`iP000000000000D0n_3V0P00
00020?[`iP040000003jl>H00000000000<0n_3V100000030?[`iP80000000<0n_3V000000000000
o`3jl>JS0?[`iP40oooo000P0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003j
l>H0n_3V02D0n_3V0P00000<0?[`iP80000000<0n_3V0000000000000P3jl>H00`000000n_3V0?[`
iP02000000<0n_3V0`0000030?[`iP8000001@3jl>H2000000030?[`iP00000000000?l0n_3VX`3j
l>H10?ooo`007`3jl>H6000000@0n_3V0P00000_0?[`iPD000009`3jl>H5000000X0n_3V0`000004
0?[`iP<000001@3jl>H2000000<0n_3V1@0000030?[`iP<00000o`3jl>JT0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool003d0n_3V1000
003o0?[`i_l0n_3V603jl>H10?ooo`00@03jl>H200000?l0n_3Vo`3jl>HG0?[`iP40oooo000P0?[`
iPH0000000D0n_3V00000000000000000?[`iP0300000080n_3V0`0000030?[`iP@000000`3jl>H2
000000040?[`iP00000000000?[`iPD000000`3jl>H<000002l0n_3V0`0000040?[`iP800000o`3j
l>K90?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P000002
0?[`iP040000003jl>H00000000000<0n_3V00D000000?[`iP00000000000?[`iP0300000080n_3V
0P0000040?[`iP8000000P3jl>H2000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`
iP000000000000<0n_3V0P00003o0?[`i/T0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0
n_3V0000000000000P3jl>H2000000@0n_3V0P0000050?[`iP8000000P3jl>H200000080n_3V0P00
00040?[`iP8000000P3jl>H2000000<0n_3V0P00000`0?[`iP80000000<0n_3V000000000000o`3j
l>K>0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P000004
0?[`iPH0000000<0n_3V0000000000000P3jl>H200000080n_3V0P0000050?[`iPD000000`3jl>H2
00000280n_3V1@0000090?[`iP80000000<0n_3V000000000000o`3jl>K>0?[`iP40oooo000R0?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP8000000P3jl>H20000
00040?[`iP00000000000?[`iP<000000P3jl>H3000000030?[`iP000000n_3V00@0n_3V0P000003
0?[`iP800000<03jl>H400000?l0n_3Vc`3jl>H10?ooo`008P3jl>H2000000<0n_3V1@0000020?[`
iPD000000`3jl>H4000000<0n_3V0P0000000`3jl>H0000000000004000000030?[`iP0000000000
0080n_3V100000040?[`iP800000<03jl>H200000?l0n_3Vd@3jl>H10?ooo`008P3jl>H2000000/0
n_3V0P00000R0?[`iP800000<@3jl>H200000?l0n_3Vd03jl>H10?ooo`00803jl>H6000000T0n_3V
0P00000P0?[`iP@00000<P3jl>H300000?l0n_3VcP3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP800000
00<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3j
l>H010000000n_3V0000003jl>H200000080n_3V00<000000?[`iP3jl>H00`00003o0?[`i_l0n_3V
903jl>H10?ooo`00803jl>H3000000030?[`iP00000000000080000000D0n_3V0000003jl>H00000
0?[`iP0300000080n_3V00<000000?[`iP0000006@3jl>H300000=`0n_3V100000040?[`iP/00000
103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<00000
00@0n_3V0000000000000000203jl>H4000000030?[`iP00000000000080n_3V100000020?[`iPD0
000000L0n_3V00000000000000000?[`iP000000n_3V00<00000603jl>H3000000@0n_3V0P000004
0?[`iPH000000P3jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P00001i
0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@000000103jl>H00000000000000002
0?[`iP80000000<0n_3V0000000000002@3jl>H5000000T0n_3V00<000000?[`iP3jl>H00P00003L
0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@00000
0?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V
0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000020?[`iP800000
00<0n_3V0000000000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H0
0P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000060?[`iP800000
0`3jl>H00`000000n_3V0?[`iP0200000080n_3V00<000000?[`iP3jl>H00P0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00001i0?[`iP40oooo
000R0?[`iP<00000:`3jl>H200000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P00
00050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P00
00020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H0
0P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V
0P0000000`3jl>H000000000000;0?[`iP8000001P3jl>H2000000D0n_3V0P0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00001i0?[`iP40oooo
000R0?[`iP<000006P3jl>H5000000`0n_3V0P00003L0?[`iP@000000`3jl>H500000080n_3V0P00
00050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P00
00020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H0
0P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V
1@00000:0?[`iP80000000<0n_3V0000000000002`3jl>H2000000H0n_3V0P0000050?[`iP800000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP800000
N@3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002P0n_3V0`00003M0?[`iP80000000<0
n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V
0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`
iP000000000000X0n_3V0`000000103jl>H000000000003jl>H200000080n_3V0P0000020?[`iP<0
000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H0
00000000000;0?[`iP8000000`3jl>H00`000000n_3V0?[`iP02000000<0n_3V0`0000030?[`iP@0
00000`3jl>H2000000030?[`iP000000000000D0n_3V0P00001h0?[`iP40oooo000P0?[`iP<00000
00@0n_3V0000000000000000:@3jl>H200000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@0
00000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`
iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0n_3V0000000000000P3jl>H40000
0080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H000000000000;0?[`
iP8000000`3jl>H4000000H0n_3V0P0000020?[`iP8000001@3jl>H2000000030?[`iP0000000000
00D0n_3V0P00001h0?[`iP40oooo001=0?[`iP030000003jl>H0n_3V00800000g03jl>H200000003
0?[`iP00000000000100n_3V0P00000<0?[`iP8000008P3jl>H200000080n_3V0P00000^0?[`iP80
000000<0n_3V0000000000002@3jl>H4000000<0n_3V0P0000050?[`iP030000003jl>H0n_3V0080
00000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V0080
0000N03jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V
0P0000060?[`iP8000006@3jl>H3000000030?[`iP000000000000800000;P3jl>H3000000`0n_3V
0P0000030?[`iPD000000`3jl>H3000000D0n_3V0`0000030?[`iP<000000`3jl>H5000007P0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0
n_3V0@3oool002L0n_3V00D000000?[`iP000000n_3V000000020?[`iP040000003jl>H0n_3V0000
0080n_3V00<000000?[`iP3jl>H0o`3jl>Ko0?[`iR80n_3V0@3oool00200n_3V0`0000000`3jl>H0
000000000002000000040?[`iP000000n_3V00000080n_3V00@000000?[`iP3jl>H000000P3jl>H0
0`000000n_3V0?[`iP0G0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H6
000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000006
000001/0n_3V0`0000040?[`iP<00000`@3jl>H10?ooo`008@3jl>H2000000030?[`iP0000000000
00D0000000D0n_3V00000000000000000?[`iP04000000/0n_3V1@0000090?[`iP80000000<0n_3V
000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P000002
0?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V
0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080
n_3V0P00000;0?[`iPD000002@3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H0
0000000000300?[`iP40oooo000R0?[`iP<00000:03jl>H2000000030?[`iP00000000000=`0n_3V
0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V
0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V000000000000
0`3jl>H4000001`0n_3V0P0000020?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`008P3j
l>H3000000T0n_3V00<000000?[`iP3jl>H03P3jl>H5000000T0n_3V0P0000000`3jl>H000000000
003L0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P00
00060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V
1000000=0?[`iPD00000303jl>H200000080n_3V0P0000000`3jl>H00000000000300?[`iP40oooo
000Q0?[`iP80000000<0n_3V0000000000009`3jl>H2000000030?[`iP00000000000=`0n_3V0P00
00000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`iP800000
1P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP800000
00@0n_3V000000000000n_3V0P0000020?[`iP8000006P3jl>H3000000<0n_3V0P0000000`3jl>H0
0000000000300?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H200000003
0?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H300000004
0?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H40000
0080n_3V1@0000030?[`iPD00000703jl>H200000080n_3V0P0000000`3jl>H00000000000300?[`
iP40oooo001=0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100
n_3V0P00000<0?[`iP800000>03jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H0
0000000000300?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000
103jl>H2000000H0n_3V0P00000a0?[`iP<00000103jl>H300000<40n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iR<0oooP0P0000150?ooh080
0000103oon02000000@0oooP0P0000140?ooh0D00000@`3oon0500000080oooP0P0000040?ooh080
0000A03oon04000004@0oooP100000030?ooh0800000103oon02000004D0oooP0P00000W0?ooh1h0
n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP0000
00P0oooP00@000000?ooh03oon000000A@3oon000`000000oooP0?ooh0150?ooh0030000003oon00
oooP00L0oooP00@000000?ooh03oon000000@`3oon000`000000oooP0?ooh0150?ooh0030000003o
on00oooP00T0oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh000000V0?ooh1h0
n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP0000
00/0oooP00<000000?ooh03oon00@`3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP
00X0oooP00<000000?ooh03oon00@P3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP
00/0oooP00<000000?ooh03oon00@`3oon000`000000oooP0?ooh00U0?ooh1h0n_3V0@3oool001d0
n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP000000T0oooP0P000016
0?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00203oon02000004H0oooP00<00000
0?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0800000A`3oon000`000000oooP0?ooh00T
0?ooh1h0n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000003oon00
oooP000000T0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0150?ooh0030000003o
on00oooP00P0oooP00<000000?ooh03oon00@`3oon0010000000oooP0?ooh00000140?ooh0040000
003oon00oooP000000T0oooP00<000000?ooh03oon00@`3oon0010000000oooP0?ooh000000V0?oo
h1h0n_3V0@3oool001d0n_3V8`3oon02000004D0oooP0P00000:0?ooh0<00000A03oon02000004H0
oooP0P00000:0?ooh0<00000A03oon02000004H0oooP0P00000:0?ooh0<00000A03oon02000002L0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V603oon3o00000>X000006`3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh003
0000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00BP3o
on000`000000oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3o
on000`000000oooP0?ooh01:0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh=P0
oooP0P00000<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooP`@3oon02000001@0oooP1000000;0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000o`3oon2b0?ooh0800000203oon040<f5?`0300000000
0?l0003o01P0003o2@3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPZ03oon02000000L0oooP100000040?ooh0P0003o0`00000;0?oTh@030<f5?`3oi>40
onCQ00H0onCQ0P0000000`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPX@3oon02000000@0oooP100000040?oo
h0030<f5?`000?l0003o00L0003o103=QCl40?oTh@800000303oi>400`3=QCl0onCQ0?oTh@080?oT
h@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00o`3oon2P0?ooh0@000000P3=QCl:0000o`80onCQ0P0000080?oTh@03
0<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0oooP0?ooh0090?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
VP3oon040<f5?`P0003o0P3oi>42000000D0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ
0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh8l0oooP0P00
00070?ooh0H0003o0`3oi>42000000030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3o
i>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?ooh03oon002@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o
0?ooh8h0oooP0`0000070000o`80oooP00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@09
0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@08
0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon220?ooh0X0cHDo1@000?l00`000000cHDo0<f5?`070<f5
?`P0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ
0100onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPPP3oon000`3=QCl0
onCQ0?oTh@030?oTh@@0003o0`3oi>42000000T0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon220?ooh0030<f5?`3oi>40003o00<0003o
4P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>40
2P3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?ooh03oon00
2@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh7X0oooP0P0000040?ooh0@0003o5P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3o
i>40onCQ00P0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh7T0oooP0`0000040000o`80oooP00<0cHDo
0?oTh@3oi>405@3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo
0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo
0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh7<0oooP1@3=QCl40000o`030000003=QCl0cHDo00@0cHDo5`3oi>400`3=
QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=
QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?ooh03oon002@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh7<0
oooP00<0cHDo0000o`000?l00P000?l20?oTh@8000001P3oi>400`3=QCl0onCQ0?oTh@0E0?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0oooP0?ooh0090?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
K@3oon02000000030?ooh0000?l0003o0080003o3P3oi>400`3=QCl0onCQ0?oTh@0E0?oTh@030<f5
?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5
?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0oooP0?ooh0090?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPG@3o
on0?0<f5?`@0003o103=QCl>0?oTh@030<f5?`3oi>40onCQ01D0onCQ00<0cHDo0?oTh@3oi>401P3o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40403o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP0`00003o0?ooh5d0oooP00<0cHDo0?oTh@3oi>40203oi>44
0000o`@000000`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ01D0onCQ00<0cHDo
0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo
0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oon00oooP00L0oooP0`00000K
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5d0oooP00<0cHDo0?oT
h@3oi>401@3oi>430000o`D0onCQ0P0000040?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oT
h@3oi>405@3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oT
h@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh5d0oooP00<0cHDo0?oTh@3oi>400P3oi>430000o`h0onCQ00<0cHDo0?oTh@3o
i>40303oi>400`3=QCl0onCQ0?oTh@0E0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3o
i>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3o
i>40203oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP0?l0oooPG03oon02000000040?oTh@000?l0003o0000oa40
onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0E0?oTh@030<f5?`3oi>40onCQ00H0
onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ0100
onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPF`3oon0200000080003o
503oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ01D0onCQ00<0cHDo0?oTh@3oi>40
1P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40
403oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon190?ooh140cHDo0`00
0?l2000001@0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0E0?oTh@030<f5?`3o
i>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3o
i>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0oooP0?ooh0090?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPB@3oon00
0`3=QCl0onCQ0?oTh@0;0?oTh@<0003o0P3oi>42000001D0onCQ00<0cHDo0?oTh@3oi>40303oi>40
0`3=QCl0onCQ0?oTh@0E0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402@3oi>40
0`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40203oi>40
0`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0?l0oooPB@3oon000`3=QCl0onCQ0?oTh@080?oTh@<0003o1P3oi>400`3=
QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>405@3oi>400`3=
QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=
QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?ooh03oon002@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh4T0
oooP00<0cHDo0?oTh@3oi>401@3oi>430000o`T0onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0
onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ01D0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0
onCQ0?oTh@080?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon190?ooh0030<f5?`3oi>40onCQ00<0onCQ
0P000?l<0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo0?oTh@3oi>40303oi>400`3=QCl0onCQ
0?oTh@0E0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@0:0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo0?oTh@3oi>40203oi>400`3=QCl0oooP
0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP0?l0oooPB@3oon000`3=QCl0onCQ0?oTh@030000o`h0onCQ00<0cHDo0?oTh@3oi>404`3o
i>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40onCQ01D0onCQ00<0cHDo0?oTh@3oi>401P3o
i>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40403o
i>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon190?ooh0030<f5?`000?l0
003o0140onCQ00<0cHDo0?oTh@3oi>404`3oi>400`3=QCl0onCQ0?oTh@0<0?oTh@030<f5?`3oi>40
onCQ01D0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40
onCQ00X0onCQ00<0cHDo0?oTh@3oi>40403oi>400`3=QCl0onCQ0?oTh@080?oTh@030<f5?`3oon00
oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00o`3oon140?ooh080000000@0oooP0000o`000?l0003o4`3oi>400`3=QCl0onCQ0?oTh@0C
0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>405@3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0@
0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00o`3oon0i0?oo
h0X0cHDo00@000000000o`000?l0003o0`3=QClC0?oTh@030<f5?`3oi>40onCQ01<0onCQ00<0cHDo
0?oTh@3oi>40303oi>400`3=QCl0onCQ0?oTh@0E0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo
0?oTh@3oi>402@3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ0100onCQ00<0cHDo
0?oTh@3oi>40203oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon0i
0?ooh0030<f5?`3oi>40onCQ00H0onCQ0P000?l300000080onCQ00<0cHDo0?oTh@3oi>404@3oi>40
0`3=QCl0onCQ0?oTh@0C0?oTh@030<f5?`3oi>40onCQ00`0onCQ00<0cHDo0?oTh@3oi>405@3oi>40
0`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00T0onCQ00<0cHDo0?oTh@3oi>402P3oi>40
0`3=QCl0onCQ0?oTh@0@0?oTh@030<f5?`3oi>40onCQ00P0onCQ00<0cHDo0?ooh03oon002@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh0000007
0?ooh0@00000203oon3o000003H000000`000?nI000000P0oooP1000000K0?ooh1h0n_3V0@3oool0
01d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:
0:gHiP2]f>H05@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0403>QbP3oon00oooP0?ooh080003oY`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H05@2]f>H00`0cXLX0[MSV0:gH
iP0?0:gHiP0403>QbP3oon00003o0000ojT0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H05@2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP80003oZ`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01D0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H200000080[MSV0P000?l00`0cXLX0oooP0?ooh02Z0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gH
iP2]f>H05@2]f>H;03>QbP8000000`000?l303>QbZ`0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0E0:gHiP03
03>QbP3oon00oooP00P0oooP0P000?l200000;00oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0E0:gHiP0303>Q
bP3oon00oooP00H0oooP0P000?l00`3oon0000000000002a0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H05@2]
f>H00`0cXLX0oooP0?ooh0040?ooh080003o]P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01D0[MSV00<0<j7:
0?ooh03oon000P3oon020000okP0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0E0:gHiP0303>QbP3oon00oooP
0080003o^P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0
[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV01D0[MSV00<0<j7:0000o`000?l0_03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV0P000?nn0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H04P2]f>H20000o`030:gHiP0c
XLX0oooP0;d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:
0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0@0:gHiP80003o0`2]f>H00`0cXLX0oooP0?ooh02l
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
0140[MSV00<0<j7:0:gHiP2]f>H03P2]f>H20000o`D0[MSV00<0<j7:0?ooh03oon00_03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H2000000030:gHiP000?l0003o00L0[MSV00<0<j7:0?ooh03oon00^P3oon03000001/0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0140[MSV2`0cXLX200000080003o
2P0cXLZn0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV0140[MSV00<0<j7:0?ooh03oon00203oon020000o`800000b03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP3oon00
oooP00H0oooP0P000?l00`3oon000000000000390?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0c
XLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0?ooh03oon00103oon020000
olh0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]
f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H04@2]f>H00`0cXLX0oooP0?ooh0020?ooh080003od03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV
00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00d0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP3oon00oooP0080003o
dP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gH
iP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gH
iP0;0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP0A0:gHiP0303>QbP000?l0003o0=@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0402]f>H20000omH0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H20000o`030:gHiP0cXLX0oooP
0=D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]
f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0302]f>H20000o`<0[MSV00<0<j7:0?ooh03oon00e03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV
00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00d0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP80003o1@2]f>H00`0cXLX0oooP
0?ooh03D0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00P0[MSV0P000?l70:gHiP0303>QbP3oon00oooP0=@0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=
0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`000?l0[MSV0:gHiP07
0:gHiP0303>QbP3oon00oooP0=@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H2000000030:gHiP000?l0003o00X0[MSV00<0<j7:0?oo
h03oon00e03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0
[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0
[MSV0:gHiP2]f>H200000080003o302]f>H00`0cXLX0oooP0?ooh03D0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00L0[MSV100cXLX20000o`8000003@0cXL[D0?ooh0<000006`3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00D0<j7:0?ooh03oon00003o0?ooh00200000>@0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00H0[MSV0P0000020000onP0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP0=0:gHiPP0<j7:00@000000000o`000?l00000j@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0?ooh03oon001@3oon0010000?l0000000000000003Y0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0oooP0?ooh0030?ooh080003o00<0oooP000000000000jP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00d0[MSV00@0<j7:0?ooh03oon00oooP0P000?o_0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H0
100cXLX0oooP0000o`000?oa0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?
0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0003o0?ooh03b
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H200000080003om03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0
[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP`0<j7:0P0000000`000?l0
000003>QbP3d0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03oon002@3oon020000o`800000m@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP3o
on00oooP00L0oooP0P000?l00`3oon0000000000003f0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03oon001P3oon00
0`000?l0oooP0?ooh03i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gH
iP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0?ooh03oon00103oon020000oo`0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0
oooP0?ooh0030?ooh0030000o`3oon00oooP0?`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
4`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
4@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0403>QbP3oon00oooP0?ooh080003oo@3oon03000001/0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00@0<j7:0?ooh0000?l0
003oo`3oon020?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0000o`3oon00o`3oon030?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00X0[MSV0P000?oo0?ooh0D0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`000?l0[MSV03>QbP3o0?ooh0D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
0140[MSV00<0<j7:0:gHiP2]f>H01`2]f>H20000o`80[MSV00<0<j7:0?ooh03oon00o`3oon030?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh03o0?ooh0<0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0:gHiP2]f>H00`2]f>H2000000030000
o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00o`3oon030?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP0A0:gHiPD0<j7:00@000000000o`000?l000001P0cXL[o0?ooh0D0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0?ooh03oon000P3o
on0010000?l0000000000000003o0?ooh0/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV0140[MSV00H0<j7:0?ooh03oon00oooP0000o`3oon0200000?l0oooP303oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H04@2]f>H0100cXLX0oooP0000o`000?oo0?ooh100
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0
3P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
2`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV0140[MSV00<0<j7:0000o`3oon00
o`3oon0A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0A0:gHiP030000o`3o
on00oooP0?l0oooP4@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon04
000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00l0[MSV0P000?l00`0cXLX0oooP0?ooh03o0?ooh140oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iPd0oooP00<000000?ooh03oon00203oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H2000000050:gHiP000?l0[MSV
0:gHiP0cXLX0o`3oon0C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?oo
h0030000003oon00oooP00L0oooP100000080?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H02P2]f>H3000000050000o`2]f>H0[MSV0:gHiP0cXLX0o`3oon0@0?ooh0@000006`3oon0N
0?[`iP40oooo000M0?[`iPl0oooP00<000000?ooh03oon001P3oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00T0[MSV3@0cXLX010000000003o0000o`00000403>Qb_l0oooP4`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh0000007
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?
0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C
0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh00:
0?ooh0030000o`00000000000?l0oooP603oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP3oon00oooP00P0oooP0P000?oo0?ooh1/0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP03
03>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP3oon00oooP00L0oooP00<0003o0?ooh03oon00o`3oon0K0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0oooP0?ooh0060?ooh0030000o`3oon00oooP0?l0oooP703oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon00103oon020000ool0oooP7`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0?ooh03oon000`3oon000`000?l0oooP0?ooh03o0?ooh1l0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0403>QbP3oon00oooP0?ooh080003oo`3oon0R0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H0100cXLX0oooP0?ooh0000?oo0?ooh2@0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV01<0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP000?l0003o0?l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]
f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00H0[MSV0P0000000`2]f>H0
003o0?ooh03o0?ooh2H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV
00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP<0000000<0003o03>QbP3oon00
o`3oon0V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]
f>H0[MSV00P0[MSV200cXLX01@000000003o0000o`000000<j7:0?l0oooP9`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP3o
on00oooP00D0oooP00<0003o000000000000o`3oon0Y0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon000`3oon02
0000ool0oooP;03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon030000
00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0?ooh03oon000P3oon000`000?l0oooP0?ooh03o0?ooh2X0oooP0`00000K0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0
[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0503>QbP3oon00oooP0?oo
h0000?l0o`3oon0_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP03
03>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP03
03>QbP2]f>H0[MSV00P0[MSV00@0<j7:0?ooh0000?l0003oo`3oon0`0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0000o`3o
on00o`3oon0a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>Q
bP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0003o0?ooh03oon00o`3oon0a0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0003o03>QbP3oon00o`3o
on0b0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0
[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0303>QbP2]f>H0
[MSV00<0[MSV0P0000020000o`030:gHiP0cXLX0oooP0?l0oooP<P3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP80000000D0003o0000
002]f>H0[MSV03>QbP3o0?ooh3<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
01<0[MSV1@0cXLX010000000003o00000000000303>Qb_l0oooP<`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H0100cXLX0oooP0?ooh03oon020000o`800000o`3oon0g
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV
00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0C0:gHiP0403>QbP3oon00oooP
0000ool0oooP>`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0c
XLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0c
XLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0c
XLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H04`2]f>H00`0c
XLX0oooP0000o`3o0?ooh3`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0
[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV01<0
[MSV00<0<j7:0000o`3oon00o`3oon0l0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV
0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP0A0:gHiP03000000000?l0003o0?l0oooP?P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H0402]f>H010000000003o00000000003o0?ooh3h0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiQ<0<j7:00@0003o0000000000000000o`3oon0n0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP3o
on00oooP00l0oooP00@0003o0?ooh00000000000o`3oon0m0?ooh0<000006`3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP3o
on00oooP00h0oooP00<0003o0?ooh03oon00o`3oon110?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0oooP0?ooh00=0?ooh0030000o`3oon00oooP0?l0oooP@P3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0?ooh03oon002`3oon020000ool0oooPA@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0
[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0?ooh03oon002P3oon000`000?l0oooP0?ooh03o0?ooh4D0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP3oon00oooP00T0oooP00<0003o0?ooh03oon00o`3oon160?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0oooP0?ooh0080?ooh0030000o`3oon00oooP0?l0oooPA`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon001`3oon000`000?l0oooP0?ooh03o
0?ooh4P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gH
iP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP3oon00oooP00H0oooP00<0003o0?oo
h03oon00o`3oon190?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP03
03>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0oooP0?ooh0050?ooh003
0000o`3oon00oooP0?l0oooPBP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon00
103oon000`000?l0oooP0?ooh03o0?ooh4/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP3o
on00oooP00<0oooP00<0003o0?ooh03oon00o`3oon1<0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
100cXLX0oooP0?ooh03oon020000ool0oooPC`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:
0?ooh03oon00003oo`3oon1A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?
0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0oooP0000o`3o
0?ooh580oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gH
iP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gH
iP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP000?l0oooP0?l0oooPDP3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`000?l0oooP0?ooh03o0?ooh500oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0003o03>QbP3oon00
o`3oon1C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00P0<j7:0:gHiP00000000000:gHiP000?l0[MSV03>Qb_l0oooPE03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP05
03>QbP0000000000000000000?l00P2]f>H00`0cXLX0oooP0?ooh03o0?ooh580oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H01@0cXLX0
0000000000000?l0000000<0<j7:o`3oon1D0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0
[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00@0<j7:0000o`000?l00000o`3oon1H0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0003o0?ooh03oon00o`3oon1I0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV
0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00P0[MSV0P0000000`000?l0<j7:0?ooh03o0?ooh5X0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV2P0cXLX2000000030000o`00
0000<j7:0?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H0
0`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0oooP0?ooh0070?ooh004000000000?l0000000000?l0oooPG03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0oooP0?ooh0070?ooh0030000o`000000
00000?l0oooPG@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0c
XLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0c
XLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0c
XLX0oooP0?ooh0060?ooh0030000o`3oon00oooP0?l0oooPGP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0
[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0oooP0?ooh0050?ooh0030000o`3oon00oooP0?l0
oooPG`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV
0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0oooP
0?ooh0040?ooh0030000o`3oon00oooP0?l0oooPH03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V3`3oon03000000H0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon000P3oon020000ool0oooPH`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh005
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?
0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0503>QbP3oon00oooP0?ooh0000?l0o`3oon1U0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>H=0?ooh0D000001P3oon04000000P0oooP00<0<j7:0:gHiP2]f>H03@2]f>H0
0`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0403>QbP3oon00oooP0000ool0oooPH`3oon04000001/0oooP7P3j
l>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh0000?l0o`3o
on1W0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00
000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0000o`3oon00o`3oon1W0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>H?0?ooh08000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0oooP0?ooh03o0?ooh6L0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0003o03>QbP3oon00o`3oon1X0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP030000o`2]f>H0<j7:0?l0oooP
J@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gH
iP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H010000?l0[MSV0:gH
iP0cXL[o0?ooh6T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0
<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP060:gHiP0403>QbP2]f>H0[MSV0:gHiP800000
00<0[MSV0000o`2]f>H00P2]f>H00`0cXLX0oooP0?ooh03o0?ooh6L0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gH
iP060:gHiP<0<j7:0`0000000`000?l0<j7:03>QbP0303>Qb_l0oooPJ@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0?ooh03oon000P0000000`000?l000000?ooh03o0?ooh6d0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0603>QbP3oon00oooP0?ooh0000?l00000o`3oon1_0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H0100cXLX0oooP0000o`000?oo0?ooh740oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=
0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP000?l0oooP0?l0oooPLP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0003o0?oo
h03oon00o`3oon1b0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP03
03>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0<j7:0?ooh03o0?ooh7<0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0
3P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
502]f>H00`0cXLX0[MSV0:gHiP040:gHiP030000o`2]f>H0<j7:0?l0oooPM03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H03@2]
f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01@0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H010000?l0[MSV0:gHiP0cXL[o0?ooh780oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]
f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP0D0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0003o0:gHiP2]f>H0[MSV
03>QbP3o0?ooh7@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0
<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H0502]f>H01@0cXLX0[MSV0:gHiP2]f>H0003o00@0[MSV00<0<j7:0?ooh03oon00
o`3oon1b0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]
f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV01@0[MSV00@0<j7:0:gHiP2]f>H0003o1@2]f>H00`0cXLX0oooP0?ooh03o0?ooh780oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0502]
f>H2000000030000o`2]f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon00o`3oon1b0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV01<0[MSV0P000000
0`000?l000000:gHiP050:gHiP0303>QbP3oon00oooP0?l0oooPLP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0B0:gHiP80000000<0003o0000
000000001`0cXL[o0?ooh7@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0
[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H04@2]f>H2000000030000o`00000000000?l0oooPO03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>HD03>QbP04000000000?l0000000000?l0
oooPO@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV
0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0oooP
0?ooh00A0?ooh0030000o`00000000000?l0oooPOP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0
<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0oooP0?ooh00@0?ooh0030000o`3oon00oooP0?l0oooPO`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0oooP0?ooh00?
0?ooh0030000o`3oon00oooP0?l0oooPP03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0oooP0?ooh00>0?ooh0030000o`3oon00oooP0?l0oooPP@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0oooP0?ooh00=0?ooh003
0000o`3oon00oooP0?l0oooPPP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0
202]f>H00`0cXLX0oooP0?ooh00<0?ooh0030000o`3oon00oooP0?l0oooPP`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0oooP0?ooh00;0?ooh0030000o`3o
on00oooP0?l0oooPQ03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03
000000T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0
[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP3oon00
oooP00X0oooP00<0003o0?ooh03oon00o`3oon230?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV
00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0?ooh03oon002@3oon000`000?l0oooP0?ooh03o0?ooh8H0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon00203oon000`000?l0
oooP0?ooh03o0?ooh8L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV
00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0?ooh03oon001`3oon000`000?l0oooP0?ooh03o0?ooh8P0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon001P3oon000`000?l0oooP0?oo
h03o0?ooh8T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:
0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0?ooh03oon001@3oon000`000?l0oooP0?ooh03o0?ooh8X0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon00103oon000`000?l0oooP0?ooh03o0?oo
h8/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]
f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03o
on000`3oon000`000?l0oooP0?ooh03o0?ooh8`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>Q
bP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon000P3oon000`000?l0oooP0?ooh03o0?ooh8d0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00D0<j7:0?ooh03oon00oooP
0000o`3o0?ooh900oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0
<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00@0
<j7:0?ooh03oon00003oo`3oon2A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP3oon00003o0?l0oooPTP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0003o0?ooh03o0?ooh980oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gH
iP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0003o0?ooh03oon00o`3oon2B0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP030000o`0cXLX0oooP0?l0oooPT`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV03>QbP3o0?ooh9@0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H010000?l0[MSV0:gHiP0cXL[o0?ooh980oooP
0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@000?l0[MSV0:gHiP2]f>H0<j7:0?l0oooP
U03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gH
iP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gH
iP020:gHiP0303>QbP3oon00oooP0?l0oooPTP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP0?l0oooPTP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00H0<j7:0:gHiP00000000000:gHiP000?l50:gHiP0303>QbP3o
on00oooP0?l0oooPTP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H0
0`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0<j7:00000000000000000000
o`060:gHiP0303>QbP3oon00oooP0?l0oooPTP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0<j7:
000000000000003o0000000703>Qb_l0oooPU03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:
0?ooh0000?l00000o`3oon2L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?
0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0003o0?ooh03o
0?ooh9d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gH
iP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP030000o`3oon00oooP0?l0oooPW@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0003o03>QbP3oon00o`3oon2N0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`000?l0[MSV03>QbP3o0?ooh9l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]
f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H03P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP040000o`2]
f>H0[MSV03>Qb_l0oooPW`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]
f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0003o0:gHiP2]f>H0[MSV
03>QbP3o0?ooh9l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP0`00
00080?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gH
iP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gH
iP020:gHiP0303>QbP3oon00oooP0?l0oooPW@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00h0[MSV00D0
<j7:0:gHiP2]f>H0[MSV0000o`050:gHiP0303>QbP3oon00oooP0?l0oooPW@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0@00000
203oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H0
3P2]f>H0100cXLX0[MSV000000000?l60:gHiP0303>QbP3oon00oooP0?l0oooPVP3oon04000001/0
oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0<00000203oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>Q
bP000000003o008000001P0cXL[o0?ooh9l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iPh0oooP00<000000?ooh03oon001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0303>QbP00
0000003o00800000o`3oon2U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>
0?ooh0<000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>0:gHiP0403>QbP000?l0000000000?l0oooPYP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0>
0:gHiP030000o`3oon00oooP0?l0oooPY`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gH
iP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0=0:gHiP030000o`0cXLX0oooP0?l0oooPZ03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0<0:gHiP03
0000o`2]f>H0<j7:0?l0oooPZ@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP040000o`2]f>H0[MSV03>Qb_l0oooPZ@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP050000
o`2]f>H0[MSV0:gHiP0cXLX0o`3oon2Y0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV
0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0oooP
0?ooh03o0?ooh:L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`000?l0[MSV0:gHiP030:gHiP0303>QbP3oon00oooP0?l0oooPY`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP030000o`2]f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon00o`3oon2W0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0003o0:gH
iP2]f>H0102]f>H00`0cXLX0oooP0?ooh03o0?ooh:L0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP03
03>QbP2]f>H0[MSV00l0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gHiP050:gHiP03
03>QbP3oon00oooP0?l0oooPY`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0
3`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP80000000<0[MSV0000o`2]f>H01`2]f>H00`0cXLX0oooP
0?ooh03o0?ooh:L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00@0
<j7:0:gHiP2]f>H0[MSV0`0000000`000?l0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP0?l0oooP
Y`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0
<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP@0<j7:0P0000000`000?l0000003>Q
bP0903>Qb_l0oooPY`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>QbP3oon00
oooP0080oooP00<0003o0000003oon00o`3oon2c0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0c
XLX0[MSV0:gHiP0?0:gHiP0503>QbP3oon00oooP0?ooh0000?l0o`3oon2f0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0403>QbP3oon00oooP0000ool0oooP]`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]f>H00`0cXLX0oooP0000o`3o0?oo
h;P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00l0[MSV00<0<j7:0?ooh000
0?l0o`3oon2h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0?0:gHiP0303>Q
bP000?l0oooP0?l0oooP^03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H03`2]
f>H00`000?l0oooP0?ooh03o0?ooh;P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00h0[MSV00<0003o03>QbP3oon00o`3oon2i0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0c
XLX0[MSV0:gHiP0=0:gHiP030000o`2]f>H0<j7:0?l0oooP^P3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0
[MSV00<0<j7:0:gHiP2]f>H0302]f>H010000?l0[MSV0:gHiP0cXL[o0?ooh;X0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0[MSV00`0[MSV00@0003o0:gHiP2]f>H0<j7:o`3oon2j0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP050000o`2]f>H0[MSV0:gH
iP0cXLX0o`3oon2j0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP03
0000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon2h0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
3@2]f>H00`0cXLX0[MSV0:gHiP090:gHiP030000o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00
o`3oon2h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H03@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP030000o`2]
f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon00o`3oon2h0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0003o0:gHiP2]f>H01@2]f>H00`0cXLX0oooP0?ooh03o0?ooh;H0oooP0`00000K
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00d0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`000?l0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP
0?l0oooP^03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0
[MSV0:gHiP060:gHiP0303>QbP3oon00oooP0?l0oooP^03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP0?l0oooP
^03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0[MSV0:gH
iP080:gHiP0303>QbP3oon00oooP0?l0oooP^03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP090:gHiP0303>QbP3oon00oooP0?l0oooP^03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00d0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP0:0:gH
iP0303>QbP3oon00oooP0?l0oooP^03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00H0<j7:0:gHiP00
000000000:gHiP000?l<0:gHiP0303>QbP3oon00oooP0?l0oooP^03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00d0[MSV00D0<j7:00000000000000000000o`0=0:gHiP0303>QbP3oon00oooP0?l0oooP^03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00d0[MSV00D0<j7:000000000000003o0000000>03>Qb_l0oooP^P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00d0[MSV00@0<j7:0?ooh0000?l00000o`3oon390?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H03@2]f>H00`0cXLX0003o0?ooh03o0?ooh<X0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP0=0:gHiP03
0000o`3oon00oooP0?l0oooPbP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00d0[MSV00<0003o0?ooh03oon00
o`3oon3:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0302]f>H00`000?l0<j7:0?ooh03o0?ooh</0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP0;0:gHiP030000o`2]f>H0<j7:0?l0oooPc03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H02P2]f>H01000
0?l0[MSV0:gHiP0cXL[o0?ooh<X0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00T0[MSV00D0003o0:gHiP2]f>H0[MSV03>QbP3o
0?ooh<`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP080:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?oo
h03oon00o`3oon3:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H01`2]f>H00`000?l0[MSV0:gHiP030:gHiP03
03>QbP3oon00oooP0?l0oooPbP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00H0[MSV00<0003o0:gHiP2]f>H0
102]f>H00`0cXLX0oooP0?ooh03o0?ooh<X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP060:gHiP030000o`2]
f>H0[MSV00@0[MSV00<0<j7:0?ooh03oon00o`3oon3:0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H01@2]f>H0
0`000?l0[MSV0:gHiP050:gHiP0303>QbP3oon00oooP0?l0oooPbP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0003o0:gHiP2]f>H01P2]f>H00`0cXLX0oooP0?ooh03o0?ooh<X0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP030:gHiP030000o`2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon00o`3oon3:0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gHiP080:gHiP0303>QbP3oon00oooP0?l0oooP
bP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00503>QbP2]f>H0[MSV0:gHiP000?l02`2]f>H00`0cXLX0oooP0?ooh03o0?ooh<X0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on00100cXLX00000000000000?l<0:gHiP0303>QbP3oon00oooP0?l0oooPbP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0<0000000<0
003o0:gHiP2]f>H02P2]f>H00`0cXLX0oooP0?ooh03o0?ooh<X0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00T0oooP0P000000
0`000?l0000003>QbP0<03>Qb_l0oooPc03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00X0oooP00<0003o
0000003oon00o`3oon3I0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?oo
h0040000003oon00oooP000000L0oooP100000080?ooh0030000o`3oon00oooP0?l0oooPe`3oon04
000001/0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon000`000000oooP0?ooh03o0?oo
h>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03o
on0000001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh>H0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3o
on000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3o
on000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=
0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<
0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=
0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=
0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<
0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=
0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<
0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=
0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<
0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<
0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP
00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooPo`00003Z000001/0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003A0?[`iP@0
00000P3jl>H800000080n_3V100000001`3jl>H00000000000000000n_3V0000003jl>H030000000
0`3jl>H0000000000004000000040?[`iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0
n_3V0000003jl>H00`0000080?[`iPD000000P3jl>H400000080n_3V1@00000<0?[`iP<000004@3j
l>H3000000H0n_3V0`000000103jl>H000000000000000060?[`iP030000003jl>H0n_3V00@0n_3V
0`000000103jl>H0000000000000003H0?[`iP40oooo003B0?[`iP8000000P3jl>H2000000<0n_3V
0P0000030?[`iP8000000`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`
iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`
iP040000003jl>H0n_3V0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0
n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000003@3j
l>H2000000030?[`iP000000000000l0n_3V0P0000000`3jl>H00000000000060?[`iP80000000<0
n_3V0000000000001`3jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000f@3j
l>H10?ooo`00dP3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2
000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3j
l>H2000000d0n_3V0P0000000`3jl>H00000000000050?[`iPD000001@3jl>H2000000030?[`iP00
0000000000L0n_3V0`0000060?[`iPD000001P3jl>H300000=X0n_3V0@3oool00=80n_3V1@000004
0?[`iP8000000`3jl>H6000000060?[`iP00000000000?[`iP000000n_3V0P0000000`3jl>H00000
0000000300000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
2`3jl>H3000000<0n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V0080
00002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V0P0000000`3jl>H0
00000000000?0?[`iP80000000<0n_3V0000000000001`3jl>H3000000P0n_3V00<000000?[`iP3j
l>H01P3jl>H300000=X0n_3V0@3oool00=80n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V
0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`
iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H000000?[`iP0:0?[`iP<00000403jl>H4
000000L0n_3V0P0000000`3jl>H00000000000070?[`iP030000003jl>H0n_3V00D0n_3V0P000000
0`3jl>H000000000003I0?[`iP40oooo003B0?[`iP8000000P3jl>H2000000030?[`iP0000000000
00800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`
iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000000X0n_3V1@0000020?[`
iP@000000P3jl>H3000000030?[`iP000000000000X0n_3V0P0000000`3jl>H000000000000?0?[`
iP800000203jl>H3000000040?[`iP0000000000000000d0n_3V0`0000000`3jl>H0000000000005
00000=@0n_3V0@3oool00=80n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`
iP3jl>H05`3jl>H2000001X0n_3V0P0000000`3jl>H000000000000@0?[`iP8000008`3jl>H00`00
0000n_3V0?[`iP3D0?[`iP40oooo003A0?[`iPH00000103jl>H2000002l0n_3V1@00000J0?[`iP<0
00006@3jl>H300000180n_3V0`00000R0?[`iP030000003jl>H0n_3V0=<0n_3V0@3oool00?l0n_3V
P`3jl>H00`000000n_3V0?[`iP3B0?[`iP40oooo003o0?[`iX00n_3V00@000000?[`iP3jl>H00000
e03jl>H10?ooo`00o`3jl>J10?[`iP800000e@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .59698 L
.03938 .59698 L
.03938 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .59698 L
.03938 .59698 L
.03938 .08012 L
s
.678 .847 .902 r
.03938 .08012 m
.03938 .5662 L
.06402 .5662 L
.06402 .08012 L
F
.2 .63 .79 r
.03938 .08012 m
.03938 .5662 L
.06402 .5662 L
.06402 .08012 L
s
.678 .847 .902 r
.06402 .08012 m
.06402 .54402 L
.08179 .54402 L
.08179 .08012 L
F
.2 .63 .79 r
.06402 .08012 m
.06402 .54402 L
.08179 .54402 L
.08179 .08012 L
s
.678 .847 .902 r
.08179 .08012 m
.08179 .52202 L
.09947 .52202 L
.09947 .08012 L
F
.2 .63 .79 r
.08179 .08012 m
.08179 .52202 L
.09947 .52202 L
.09947 .08012 L
s
.678 .847 .902 r
.09947 .08012 m
.09947 .50574 L
.11642 .50574 L
.11642 .08012 L
F
.2 .63 .79 r
.09947 .08012 m
.09947 .50574 L
.11642 .50574 L
.11642 .08012 L
s
.678 .847 .902 r
.11642 .08012 m
.11642 .48131 L
.12878 .48131 L
.12878 .08012 L
F
.2 .63 .79 r
.11642 .08012 m
.11642 .48131 L
.12878 .48131 L
.12878 .08012 L
s
.678 .847 .902 r
.12878 .08012 m
.12878 .48058 L
.14947 .48058 L
.14947 .08012 L
F
.2 .63 .79 r
.12878 .08012 m
.12878 .48058 L
.14947 .48058 L
.14947 .08012 L
s
.678 .847 .902 r
.14947 .08012 m
.14947 .45697 L
.17236 .45697 L
.17236 .08012 L
F
.2 .63 .79 r
.14947 .08012 m
.14947 .45697 L
.17236 .45697 L
.17236 .08012 L
s
.678 .847 .902 r
.17236 .08012 m
.17236 .43007 L
.19997 .43007 L
.19997 .08012 L
F
.2 .63 .79 r
.17236 .08012 m
.17236 .43007 L
.19997 .43007 L
.19997 .08012 L
s
.678 .847 .902 r
.19997 .08012 m
.19997 .39326 L
.21581 .39326 L
.21581 .08012 L
F
.2 .63 .79 r
.19997 .08012 m
.19997 .39326 L
.21581 .39326 L
.21581 .08012 L
s
.678 .847 .902 r
.21581 .08012 m
.21581 .38982 L
.23691 .38982 L
.23691 .08012 L
F
.2 .63 .79 r
.21581 .08012 m
.21581 .38982 L
.23691 .38982 L
.23691 .08012 L
s
.678 .847 .902 r
.23691 .08012 m
.23691 .36548 L
.25456 .36548 L
.25456 .08012 L
F
.2 .63 .79 r
.23691 .08012 m
.23691 .36548 L
.25456 .36548 L
.25456 .08012 L
s
.678 .847 .902 r
.25456 .08012 m
.25456 .33889 L
.2726 .33889 L
.2726 .08012 L
F
.2 .63 .79 r
.25456 .08012 m
.25456 .33889 L
.2726 .33889 L
.2726 .08012 L
s
.678 .847 .902 r
.2726 .08012 m
.2726 .33286 L
.29465 .33286 L
.29465 .08012 L
F
.2 .63 .79 r
.2726 .08012 m
.2726 .33286 L
.29465 .33286 L
.29465 .08012 L
s
.678 .847 .902 r
.29465 .08012 m
.29465 .29873 L
.32145 .29873 L
.32145 .08012 L
F
.2 .63 .79 r
.29465 .08012 m
.29465 .29873 L
.32145 .29873 L
.32145 .08012 L
s
.678 .847 .902 r
.32145 .08012 m
.32145 .28262 L
.3402 .28262 L
.3402 .08012 L
F
.2 .63 .79 r
.32145 .08012 m
.32145 .28262 L
.3402 .28262 L
.3402 .08012 L
s
.678 .847 .902 r
.3402 .08012 m
.3402 .26097 L
.36293 .26097 L
.36293 .08012 L
F
.2 .63 .79 r
.3402 .08012 m
.3402 .26097 L
.36293 .26097 L
.36293 .08012 L
s
.678 .847 .902 r
.36293 .08012 m
.36293 .25604 L
.37592 .25604 L
.37592 .08012 L
F
.2 .63 .79 r
.36293 .08012 m
.36293 .25604 L
.37592 .25604 L
.37592 .08012 L
s
.678 .847 .902 r
.37592 .08012 m
.37592 .23896 L
.39146 .23896 L
.39146 .08012 L
F
.2 .63 .79 r
.37592 .08012 m
.37592 .23896 L
.39146 .23896 L
.39146 .08012 L
s
.678 .847 .902 r
.39146 .08012 m
.39146 .23599 L
.41421 .23599 L
.41421 .08012 L
F
.2 .63 .79 r
.39146 .08012 m
.39146 .23599 L
.41421 .23599 L
.41421 .08012 L
s
.678 .847 .902 r
.41421 .08012 m
.41421 .20943 L
.42863 .20943 L
.42863 .08012 L
F
.2 .63 .79 r
.41421 .08012 m
.41421 .20943 L
.42863 .20943 L
.42863 .08012 L
s
.678 .847 .902 r
.42863 .08012 m
.42863 .20435 L
.45565 .20435 L
.45565 .08012 L
F
.2 .63 .79 r
.42863 .08012 m
.42863 .20435 L
.45565 .20435 L
.45565 .08012 L
s
.678 .847 .902 r
.45565 .08012 m
.45565 .18559 L
.46494 .18559 L
.46494 .08012 L
F
.2 .63 .79 r
.45565 .08012 m
.45565 .18559 L
.46494 .18559 L
.46494 .08012 L
s
.678 .847 .902 r
.46494 .08012 m
.46494 .17531 L
.49039 .17531 L
.49039 .08012 L
F
.2 .63 .79 r
.46494 .08012 m
.46494 .17531 L
.49039 .17531 L
.49039 .08012 L
s
.678 .847 .902 r
.49039 .08012 m
.49039 .15708 L
.51697 .15708 L
.51697 .08012 L
F
.2 .63 .79 r
.49039 .08012 m
.49039 .15708 L
.51697 .15708 L
.51697 .08012 L
s
.678 .847 .902 r
.51697 .08012 m
.51697 .14744 L
.52767 .14744 L
.52767 .08012 L
F
.2 .63 .79 r
.51697 .08012 m
.51697 .14744 L
.52767 .14744 L
.52767 .08012 L
s
.678 .847 .902 r
.52767 .08012 m
.52767 .14206 L
.54692 .14206 L
.54692 .08012 L
F
.2 .63 .79 r
.52767 .08012 m
.52767 .14206 L
.54692 .14206 L
.54692 .08012 L
s
.678 .847 .902 r
.54692 .08012 m
.54692 .12582 L
.56301 .12582 L
.56301 .08012 L
F
.2 .63 .79 r
.54692 .08012 m
.54692 .12582 L
.56301 .12582 L
.56301 .08012 L
s
.678 .847 .902 r
.56301 .08012 m
.56301 .1231 L
.58096 .1231 L
.58096 .08012 L
F
.2 .63 .79 r
.56301 .08012 m
.56301 .1231 L
.58096 .1231 L
.58096 .08012 L
s
.678 .847 .902 r
.58096 .08012 m
.58096 .107 L
.60704 .107 L
.60704 .08012 L
F
.2 .63 .79 r
.58096 .08012 m
.58096 .107 L
.60704 .107 L
.60704 .08012 L
s
.678 .847 .902 r
.60704 .08012 m
.60704 .09964 L
.63333 .09964 L
.63333 .08012 L
F
.2 .63 .79 r
.60704 .08012 m
.60704 .09964 L
.63333 .09964 L
.63333 .08012 L
s
.678 .847 .902 r
.63333 .08012 m
.63333 .08275 L
.65427 .08275 L
.65427 .08012 L
F
.2 .63 .79 r
.63333 .08012 m
.63333 .08275 L
.65427 .08275 L
.65427 .08012 L
s
.678 .847 .902 r
.65427 .08012 m
.65427 .08112 L
.67234 .08112 L
.67234 .08012 L
F
.2 .63 .79 r
.65427 .08012 m
.65427 .08112 L
.67234 .08112 L
.67234 .08012 L
s
1 .894 .882 r
.67234 .08012 m
.67234 .06816 L
.6909 .06816 L
.6909 .08012 L
F
.804 .522 .247 r
.67234 .08012 m
.67234 .06816 L
.6909 .06816 L
.6909 .08012 L
s
1 .894 .882 r
.6909 .08012 m
.6909 .06616 L
.70441 .06616 L
.70441 .08012 L
F
.804 .522 .247 r
.6909 .08012 m
.6909 .06616 L
.70441 .06616 L
.70441 .08012 L
s
1 .894 .882 r
.70441 .08012 m
.70441 .0599 L
.71603 .0599 L
.71603 .08012 L
F
.804 .522 .247 r
.70441 .08012 m
.70441 .0599 L
.71603 .0599 L
.71603 .08012 L
s
1 .894 .882 r
.71603 .08012 m
.71603 .05782 L
.72437 .05782 L
.72437 .08012 L
F
.804 .522 .247 r
.71603 .08012 m
.71603 .05782 L
.72437 .05782 L
.72437 .08012 L
s
1 .894 .882 r
.72437 .08012 m
.72437 .05011 L
.74862 .05011 L
.74862 .08012 L
F
.804 .522 .247 r
.72437 .08012 m
.72437 .05011 L
.74862 .05011 L
.74862 .08012 L
s
1 .894 .882 r
.74862 .08012 m
.74862 .0461 L
.76306 .0461 L
.76306 .08012 L
F
.804 .522 .247 r
.74862 .08012 m
.74862 .0461 L
.76306 .0461 L
.76306 .08012 L
s
1 .894 .882 r
.76306 .08012 m
.76306 .04403 L
.78366 .04403 L
.78366 .08012 L
F
.804 .522 .247 r
.76306 .08012 m
.76306 .04403 L
.78366 .04403 L
.78366 .08012 L
s
1 .894 .882 r
.78366 .08012 m
.78366 .03742 L
.79701 .03742 L
.79701 .08012 L
F
.804 .522 .247 r
.78366 .08012 m
.78366 .03742 L
.79701 .03742 L
.79701 .08012 L
s
1 .894 .882 r
.79701 .08012 m
.79701 .03339 L
.81659 .03339 L
.81659 .08012 L
F
.804 .522 .247 r
.79701 .08012 m
.79701 .03339 L
.81659 .03339 L
.81659 .08012 L
s
1 .894 .882 r
.81659 .08012 m
.81659 .02746 L
.84322 .02746 L
.84322 .08012 L
F
.804 .522 .247 r
.81659 .08012 m
.81659 .02746 L
.84322 .02746 L
.84322 .08012 L
s
1 .894 .882 r
.84322 .08012 m
.84322 .02223 L
.8688 .02223 L
.8688 .08012 L
F
.804 .522 .247 r
.84322 .08012 m
.84322 .02223 L
.8688 .02223 L
.8688 .08012 L
s
1 .894 .882 r
.8688 .08012 m
.8688 .0207 L
.89547 .0207 L
.89547 .08012 L
F
.804 .522 .247 r
.8688 .08012 m
.8688 .0207 L
.89547 .0207 L
.89547 .08012 L
s
1 .894 .882 r
.89547 .08012 m
.89547 .01847 L
.91576 .01847 L
.91576 .08012 L
F
.804 .522 .247 r
.89547 .08012 m
.89547 .01847 L
.91576 .01847 L
.91576 .08012 L
s
1 .894 .882 r
.91576 .08012 m
.91576 .01558 L
.94142 .01558 L
.94142 .08012 L
F
.804 .522 .247 r
.91576 .08012 m
.91576 .01558 L
.94142 .01558 L
.94142 .08012 L
s
1 .894 .882 r
.94142 .08012 m
.94142 .01534 L
.94988 .01534 L
.94988 .08012 L
F
.804 .522 .247 r
.94142 .08012 m
.94142 .01534 L
.94988 .01534 L
.94988 .08012 L
s
1 .894 .882 r
.94988 .08012 m
.94988 .01497 L
.95828 .01497 L
.95828 .08012 L
F
.804 .522 .247 r
.94988 .08012 m
.94988 .01497 L
.95828 .01497 L
.95828 .08012 L
s
1 .894 .882 r
.95828 .08012 m
.95828 .01475 L
.97619 .01475 L
.97619 .08012 L
F
.804 .522 .247 r
.95828 .08012 m
.95828 .01475 L
.97619 .01475 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.02895 .59698 Mdot
.05433 .5662 Mdot
.07305 .54402 Mdot
.09203 .52202 Mdot
.10633 .50574 Mdot
.12824 .48131 Mdot
.12891 .48058 Mdot
.15065 .45697 Mdot
.17616 .43007 Mdot
.21243 .39326 Mdot
.21591 .38982 Mdot
.24099 .36548 Mdot
.2694 .33889 Mdot
.27601 .33286 Mdot
.31463 .29873 Mdot
.33367 .28262 Mdot
.36018 .26097 Mdot
.36638 .25604 Mdot
.38835 .23896 Mdot
.39226 .23599 Mdot
.42842 .20943 Mdot
.43562 .20435 Mdot
.46304 .18559 Mdot
.47872 .17531 Mdot
.50781 .15708 Mdot
.52395 .14744 Mdot
.5332 .14206 Mdot
.56241 .12582 Mdot
.56751 .1231 Mdot
.59909 .107 Mdot
.61443 .09964 Mdot
.6524 .08275 Mdot
.65631 .08112 Mdot
.6892 .06816 Mdot
.69464 .06616 Mdot
.71231 .0599 Mdot
.71845 .05782 Mdot
.74265 .05011 Mdot
.75629 .0461 Mdot
.76363 .04403 Mdot
.78915 .03742 Mdot
.80657 .03339 Mdot
.83605 .02746 Mdot
.86861 .02223 Mdot
.88015 .0207 Mdot
.90014 .01847 Mdot
.93976 .01558 Mdot
.94524 .01534 Mdot
.95635 .01497 Mdot
.96863 .01475 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0869821) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.02668) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000030?[`iPD000000`3jl>H3000000@0n_3V0`0000040?[`iP<0
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0
n_3V0000000000000P3jl>H2000000D0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000?l0n_3VX`3jl>H10?ooo`00803jl>H2
000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000
n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H000000000
00030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V000000000000o`3jl>JS0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000000000@0
n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H000000000003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP800000
0`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H20000
00@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02
000001P0n_3V1000000:0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V10000003
0?[`iP@00000103jl>H300000?l0n_3VY03jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3j
l>H0000000000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`
iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`
iP800000303jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP8000001@3jl>H2000000D0n_3V0P0000000`3jl>H000000000003o0?[`iZ<0n_3V0@3oool00200
n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09P3jl>H2000000/0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000`3jl>H2000000D0
n_3V0P0000040?[`iP80000000<0n_3V000000000000o`3jl>JS0?[`iP40oooo000O0?[`iPH00000
103jl>H2000002l0n_3V1@00000Y0?[`iP<000002P3jl>H3000000@0n_3V0`0000050?[`iP<00000
103jl>H3000000<0n_3V0`00003o0?[`iZ@0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40
oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200n_3V1P0000001@3jl>H000000000
00000000n_3V00<000000P3jl>H3000000<0n_3V100000030?[`iP80000000@0n_3V000000000000
n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P00003o0?[`i/T0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V00@000000?[`iP000000
00000`3jl>H01@000000n_3V000000000000n_3V00<000000P3jl>H2000000@0n_3V0P0000020?[`
iP8000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000000000000`3jl>H20000
0?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP80
0000103jl>H2000000D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000020?[`iP80
00000`3jl>H200000300n_3V0P0000000`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V1P0000000`3jl>H00000
000000020?[`iP8000000P3jl>H2000000D0n_3V1@0000030?[`iP8000008P3jl>H5000000T0n_3V
0P0000000`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0
n_3V0000000000000P3jl>H2000000@0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V
0`0000020?[`iP<0000000<0n_3V0000003jl>H0103jl>H2000000<0n_3V0P00000`0?[`iP@00000
o`3jl>K?0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080n_3V1@0000030?[`iP@000000`3j
l>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H4000000@0n_3V0P00
000`0?[`iP800000o`3jl>KA0?[`iP40oooo000R0?[`iP8000002`3jl>H200000280n_3V0P00000a
0?[`iP800000o`3jl>K@0?[`iP40oooo000P0?[`iPH000002@3jl>H200000200n_3V1000000b0?[`
iP<00000o`3jl>K>0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP080000
00030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP040000003jl>H000000?[`
iP8000000P3jl>H00`000000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0
000000<0n_3V0000000000000P0000001@3jl>H000000?[`iP000000n_3V00<000000P3jl>H00`00
0000n_3V0000000I0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H60000
00<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`000000103jl>H00000000000000008
0?[`iP@0000000<0n_3V0000000000000P3jl>H400000080n_3V1@0000001`3jl>H0000000000000
0000n_3V0000003jl>H00`00000H0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<00000
103jl>H3000000<0n_3V0`0000050?[`iP<000000`3jl>H500000080n_3V1P00001`0?[`iP40oooo
000Q0?[`iP80000000<0n_3V0000000000001@000000103jl>H000000000000000020?[`iP800000
00<0n_3V0000000000002@3jl>H5000000T0n_3V00<000000?[`iP3jl>H00P00003L0?[`iP800000
103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0
n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`
iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`
iP8000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000070?[`iP800000LP3jl>H10?oo
o`008P3jl>H3000002/0n_3V0P00003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP80
00001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H00000000000000000n_3V
008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`
iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0P0000000`3j
l>H00000000000030?[`iP8000001P3jl>H200000780n_3V0@3oool00280n_3V0`00000J0?[`iPD0
0000303jl>H200000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H0
00000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3j
l>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000030?[`iP@000000P3jl>H2000000030?[`iP0000000000
00@0n_3V0P0000050?[`iP800000LP3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002P0
n_3V0`00003M0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H0
00000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0`000000103jl>H000000000003jl>H2
00000080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02
000001P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000`3jl>H3
000000<0n_3V100000030?[`iP80000000<0n_3V0000000000000`3jl>H3000000H0n_3V0P000004
0?[`iP800000LP3jl>H10?ooo`00803jl>H3000000040?[`iP0000000000000002T0n_3V0P00003L
0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003j
l>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000002`3j
l>H3000000030?[`iP00000000000080n_3V100000020?[`iP<0000000<0n_3V0000000000001`00
000I0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000020?[`iP8000001@3jl>H2000000030?[`iP00000000000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H200000780n_3V0@3o
ool004d0n_3V00<000000?[`iP3jl>H00P00003L0?[`iP80000000<0n_3V000000000000403jl>H2
000000`0n_3V0P00000R0?[`iP8000000P3jl>H2000002h0n_3V0P0000000`3jl>H0000000000009
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P000004
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000020?[`iP@00000LP3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000006@3jl>H3000000030?[`iP0000000000
00800000;P3jl>H3000000/0n_3V0`0000040?[`iP<000001@3jl>H3000000<0n_3V0`0000040?[`
iP<00000103jl>H3000000D0n_3V0P00001b0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08
000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H00000
0?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3j
l>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P000000103jl>H000000?[`iP00
00020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V
100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V
100000020?[`iP<0000000<0n_3V0000000000001P00000K0?[`iP<00000103jl>H300000<40n_3V
0@3oool00240n_3V0P0000000`3jl>H0000000000005000000050?[`iP00000000000000003jl>H0
1000000;0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP800000
0P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0
n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000002`3jl>H5000000T0n_3V00<00000
0?[`iP3jl>H00P0000020?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`008P3jl>H30000
02P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`
iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000L0?[`iP8000000P3jl>H20000
00030?[`iP00000000000<00n_3V0@3oool00280n_3V0`0000090?[`iP030000003jl>H0n_3V00h0
n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H4000000<0n_3V1@0000020?[`iP80
00001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000040?[`iP00000000000?[`iP@000003@3jl>H5000000`0n_3V0P0000020?[`
iP80000000<0n_3V000000000000`03jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002L0
n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080
n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2
000001T0n_3V00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V000000000000`03jl>H1
0?ooo`00803jl>H3000000040?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000003L
0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003j
l>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000000`3j
l>H5000001T0n_3V100000030?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00C@3jl>H2
000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2
000003P0n_3V0P0000050?[`iP80000000<0n_3V000000000000`03jl>H10?ooo`00CP3jl>H30000
0=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<03jl>H50000
00<0n_3V0`0000310?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`007@3jl>HS0?ooh0800000A@3oon02000000@0oooP0P0000040?ooh0800000A03oon05
000004<0oooP1@0000020?ooh0800000103oon02000004@0oooP100000140?ooh0@000000`3oon02
000000@0oooP0P0000150?ooh08000009`3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?oo
h03oon000000@`3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP000004D0oooP
00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0070?ooh0040000003oon00oooP000004<0
oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0090?ooh0040000003oon00oooP0000
04<0oooP00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?oo
h03oon000000@`3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP04<0oooP00<0
00000?ooh03oon00A@3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP0480oooP00<0
00000?ooh03oon00A@3oon000`000000oooP0?ooh00;0?ooh0030000003oon00oooP04<0oooP00<0
00000?ooh03oon009@3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3o
on0010000000oooP0?ooh00000090?ooh0800000AP3oon000`000000oooP0?ooh0150?ooh0030000
003oon00oooP00P0oooP0P0000160?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00
203oon02000004L0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iR80oooP00@0
00000?ooh03oon000000@`3oon0010000000oooP0?ooh00000090?ooh0030000003oon00oooP04D0
oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP04<0
oooP00@000000?ooh03oon000000A03oon0010000000oooP0?ooh00000090?ooh0030000003oon00
oooP04<0oooP00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR<0oooP0P000015
0?ooh08000002P3oon03000004@0oooP0P0000160?ooh08000002P3oon03000004@0oooP0P000016
0?ooh08000002P3oon03000004@0oooP0P00000W0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`iQP0oooPo`00003Z000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh01:0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000
oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00o`3oon380?ooh0@00000103oon02000000@0oooP0P00000>
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
0?l0oooPa`3oon0600000080oooP100000020?ooh0@000003@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon0300000?l0oooP]03oon02000000H0oooP1@3=QClJ0000o`T0
oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh:/0oooP
0P0000060?ooh0@000000P3=QCl80000o`L0onCQ10000000103oi>40cHDo0?oTh@3oi>42000000@0
onCQ0P0000020?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2U0?ooh08000000`3=QCl400000080cHDo
2@000?l30?oTh@030<f5?`3oi>40onCQ00X0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh9T0oooP2`3=QCl2000000X0003o
0`3oi>400`3=QCl00000000000060?oTh@030<f5?`3oi>40onCQ00X0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh9D0oooP
0P0000020?ooh0030<f5?`3oi>40onCQ0080onCQ20000?l2000000<0onCQ0P0000060?oTh@030<f5
?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPU03oon04000000H0003o
1`3oi>42000000`0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5
?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP00T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon2<0?ooh0D0cHDo1`000?l20<f5?``0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh8L0oooP0P0000030?ooh0D0003o
103oi>4200000080onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5
?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPQP3oon02000000@0003o
00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1n0?ooh0800000
0`3oon000`3=QCl0003o0000o`020000o`8000000`3=QCl<0?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03o
on002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh03o0?ooh7d0oooP0`0000040000o`<0onCQ0P0000030?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>402P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3o
i>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP0?l0oooPO03oon040000o`040000003=QCl0cHDo0<f5?`P0
onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1b0?ooh080
0000103oon040000o`040<f5?`3oi>400000000000<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=
QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=
QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`03
0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh6h0oooP0P000000103o
on0000000000000000040000o`@0oooP00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:
0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPK@3oon03
000000@0003o00<000000<f5?`3=QCl01P3=QCl60?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo
0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo
0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3o
i>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1X0?ooh080000000<0oooP
0<f5?`000?l00`000?l010000000cHDo0000000000080?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0
cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0
cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00D0
cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon00
2@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon0300000?l0oooPI`3o
on000`000000003o0000o`020000o`80onCQ0P0000020?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0
cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0
cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0
cHDo0?oTh@3oi>402P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>40
1P3oi>400`3=QCl0oooP0?ooh0070?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00o`3oon1O0?ooh0H0cHDo0`000?l3000000030<f5?`3oi>40onCQ00@0onCQ00<0
cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0
cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0
cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0
0`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1O0?ooh0030<f5?`3o
i>40onCQ00<0003o0`3oi>42000000030?oTh@3=QCl0onCQ00D0onCQ00<0cHDo0?oTh@3oi>401`3o
i>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>401P3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1L0?ooh080000000@0oooP0000o`000?l0003o
2@3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>40
103oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>40
2P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>40
2P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPF@3oon0400000080003o00<0cHDo0?oTh@3oi>402@3oi>400`3=QCl0onCQ
0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ
0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
F03oon02000000<0003o0P0000000`3=QCl0onCQ0?oTh@090?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ
00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl00`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1E0?ooh080cHDo
0`000?l4000000030?oTh@3=QCl0onCQ00X0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ
0?oTh@070?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ
0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh500oooP0P0000020?ooh0<0003o
0P3oi>42000000050<f5?`3oi>40onCQ0?oTh@3=QCl02`3oi>400`3=QCl0onCQ0?oTh@040?oTh@03
0<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPCP3oon03000000<0
003o00<0oooP0<f5?`3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00/0onCQ00<0cHDo0?oT
h@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oT
h@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oT
h@3oi>402P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?oo
h4d0oooP0P0000020000o`8000000`3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl02`3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402P3oi>40
0`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?oo
h0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPAP3oon060<f5?`<0003o0`0000030?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`0;0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3o
i>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>401P3o
i>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon160?ooh0040<f5?`3oi>40onCQ0?oTh@80003o
0P3oi>42000000D0onCQ00<0cHDo0?oTh@3oi>400`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00/0
onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@070?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40onCQ00X0
onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00X0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh4H0oooP00@0cHDo0000o`000?l0003o1@3oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`0;0?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40
onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3oi>40
onCQ00X0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00
oooP0?l0oooPA03oon030000o`P0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@03
0?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl02`3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3o
i>40onCQ00L0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3o
i>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@030<f5?`3o
i>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ
00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00
o`3oon0n0?ooh08000000P3oon020000o`80oooP00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ
0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`0;0?oTh@03
0<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>401`3oi>400`3=QCl0onCQ0?oTh@040?oTh@03
0<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>402P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@03
0<f5?`3oi>40onCQ00X0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@0:0?oTh@05
0<f5?`3oi>40onCQ0?oTh@3=QCl00`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP
00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03o
on0000001`3oon04000000P0oooPo`00000f000000<0003oV@0000080?ooh0@000006`3oon0N0?[`
iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H200000080003o0P00000603>Q
bYl0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03o
on0000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00X0[MSV200cXLX20000
o`<00000YP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP3oon00oooP00<0
oooP0P000?l00`3oon0000000000002X0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0100cXLX0oooP
0?ooh03oon020000ojd0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0403>QbP000?l0003o0000ojl0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
2`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
2@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP80003o/P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00L0[MSV0P00
0?l00`2]f>H0<j7:0?ooh02a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P0000030:gHiP80003o0`2]f>H0
0`0cXLX0oooP0?ooh02`0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP0000000`0000020000o`D0[MSV00<0<j7:0?oo
h03oon00/03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP80<j7:0P0000020000o`P0<j7:/P3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0503>QbP3oon00003o0000o`00
0000^`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP8000000P2]f>H20000okh0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H300000080003o00<0<j7:0?ooh03oon00_@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H803>QbP04000000000?l0
003o00000080<j7:_`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0oooP0?ooh0040?ooh080003o0P0000320?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0?ooh03oon000P3oon020000ol@0oooP0`00000K0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0oooP0?ooh0020000olP0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0000o`000?l0bP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H20000ol`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP000000
00000080[MSV0P000?l00`2]f>H0<j7:0?ooh03;0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0102]f>H40000
0080003o100cXL[<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H300000080003o00<000000?ooh03o
on00c`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiPH0<j7:00<000000000o`000?l00P00003B0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0?ooh03oon000P3o
on020000o`800000e03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP3oon00oooP0080003of03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP000?l0003o
0=X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H20000om`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H20000o`030:gHiP0cXLX0oooP0=/0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P0000000`2]f>H0003o0:gH
iP020:gHiP0303>QbP3oon00oooP0=X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV0080[MSV00@0<j7:0:gHiP00000000000P000?l40:gHiP0303>QbP3oon00oooP0=X0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV0P0cXLX20000o`8000001@0cXL[L
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV008000000P000?l00`3oon0000000000003P0?oo
h0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP80<j7:0P0000000`000?l000000?ooh03U0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H0100cXLX0oooP0000o`000?l200000>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP80003o
00<0oooP000000000000i`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00D0[MSV0P0000020:gHiP030000o`0c
XLX0oooP0>X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP<000000P000?l00`2]f>H0<j7:0?ooh03Z
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00T0[MSV1`0cXLX010000000003o0000o`00000303>Qb^/0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0oooP0?ooh0030?oo
h080003o0P00003_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh03oon000P3oon000`000?l0oooP0?ooh03a0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0?ooh03oon000P000?od0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh0000?l0mP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP090:gHiP80003om`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP80003o00<0<j7:0?ooh03oon00mP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP80000000D0[MSV0000o`2]f>H0[MSV03>QbP3h0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080
[MSV0P0000020000o`<0[MSV00<0<j7:0?ooh03oon00mP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H503>QbP04000000000?l00000000000@0<j7:n03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
2P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP3oon00oooP0?ooh080003o0P00003k0?ooh0<0
00006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0?ooh0000?l0003oo`3oon020?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP020000000303>QbP000?l0oooP0?l0oooP
0`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00X0[MSV00@0<j7:0:gHiP00000000000P000?oo0?ooh0D0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP80<j7:00@000000000o`0000000000o`3oon050?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0003o0000o`0200000?l0oooP1P3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00X0[MSV00<0003o0?ooh03oon00o`3oon080?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`00
0?l0<j7:0?ooh03o0?ooh0T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP070:gHiP80003o00<0[MSV03>QbP3o
on00o`3oon090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@000?l0[MSV0:gHiP2]f>H0<j7:0?l0
oooP2P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0oooP
0?ooh03o0?ooh0P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP80003o1@2]f>H00`0cXLX0oooP0?oo
h03o0?ooh0P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP02000000030000o`2]f>H0[MSV00D0[MSV00<0<j7:
0?ooh03oon00o`3oon080?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00@0[MSV0P0cXLX2000000030000o`000000<j7:00L0<j7:o`3oon0:0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0@000001`3oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP030:gHiP80000000<0oooP0000o`000?l00P00003o0?ooh180oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00<000000?ooh03oon00203oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H503>QbP<00000
00@0003o0?ooh00000000000o`3oon0C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>H>0?ooh0030000003oon00oooP00L0oooP100000080?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0oooP0?ooh0020?ooh080000000<0003o0000003oon00
o`3oon0B0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPl0oooP00<000000?ooh03oon001P3o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0oooP0?ooh0020?ooh080003o00<000000?ooh03oon00o`3oon0E0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00D0
<j7:0?ooh03oon00oooP0000o`3o0?ooh1X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0403>QbP3oon00003o0000ool0oooP6`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0003o0?ooh03o0?ooh1`0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0003o0?ooh03oon00o`3oon0L
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP80003o00<0<j7:0?oo
h03oon00o`3oon0L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP050:gHiP04
0000o`2]f>H0[MSV03>Qb_l0oooP7P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H20000o`<0[MSV00<0<j7:0?ooh03oon00o`3oon0L0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00
o`3oon0L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020000o`H0[MSV00<0
<j7:0?ooh03oon00o`3oon0L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H2000000030000o`2]f>H0
[MSV00H0[MSV00<0<j7:0?ooh03oon00o`3oon0L0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H30000
00030000o`000000<j7:00P0<j7:o`3oon0N0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H200000080
003o0P00003o0?ooh2L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H503>QbP03000000000?l0000000800000o`3oon0X0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0
<j7:0?ooh03oon00oooP0P000?l200000?l0oooP:P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0?ooh03oon00003oo`3oon0/0?ooh0<00000
6`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0oooP0000
o`3o0?ooh2l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H20000ool0oooP<03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000o`0cXLX0oooP0?l0oooP<03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H01`0cXLX0[MSV0:gHiP2]f>H0003o
0:gHiP0cXLX0o`3oon0a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0403>QbP00000000000000o`80[MSV00<0<j7:0?ooh03oon00o`3oon0_0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP04000000000?l0003o000000<0<j7:o`3oon0a
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP80000000@0003o0000
000000000000o`3oon0d0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP80000000@0003o0000000000000000o`3oon0e0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H803>Q
bP80003o0P00003o0?ooh3L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP3oon00oooP00@0
oooP00@0003o0?ooh00000000000o`3oon0h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
oooP0?ooh0030?ooh0030000o`3oon00oooP0?l0oooP>P3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0?ooh03oon000P3oon000`000?l0oooP0?ooh03o0?ooh3/0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP3oon00oooP0080003oo`3oon0n0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0oooP0000o`3o0?ooh400oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP000?l0oooP
0?l0oooP@03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0
oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0oooP0?ooh03o0?ooh3h0oooP0`00000K0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0003o03>QbP3oon00o`3oon110?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H2000000030000o`2]
f>H0<j7:0?l0oooP@P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP@0<j7:00@000000000o`000?l000000P0cXL[o0?ooh480oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02P2]f>H0
1@0cXLX0oooP0?ooh03oon00003o00<00000o`3oon140?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00X0[MSV00D0<j7:0?ooh03oon00003o0?oo
h00200000?l0oooPA@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H0
0`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP3oon00003o0?l0oooPB@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP0303>QbP000?l0oooP
0?l0oooPB@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0
[MSV0:gHiP0:0:gHiP030000o`3oon00oooP0?l0oooPB@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP090:gHiP030000o`0cXLX0oooP0?l0oooP
BP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP060:gHiP80000000<0003o0:gHiP0cXLX0o`3oon1;0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiPP0<j7:0P00000010000?l0000003>QbP0cXL[o0?ooh4/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh03oon001@3oon02
0000o`800000o`3oon1=0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gH
iP0303>QbP3oon00oooP00@0oooP00@0003o0?ooh00000000000o`3oon1>0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP3oon00oooP00<0oooP00<0003o0?oo
h03oon00o`3oon1@0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP3oon00oooP0080oooP00<0003o0?ooh03oon00o`3oon1A0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00D0<j7:0?ooh03oon00oooP0000o`3o0?ooh580oooP0`00000K0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H0202]f>H0100cXLX0oooP0?ooh0000?oo0?ooh5D0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0?ooh0000?l0o`3oon1F0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP000?l0oooP0?l0oooPEP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`000?l0oooP0?ooh03o
0?ooh5H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV0P000?l00`0c
XLX0oooP0?ooh03o0?ooh5H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00@0003o0:gHiP2]f>H0<j7:o`3oon1H0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP050000o`2]f>H0[MSV0:gHiP0cXLX0o`3oon1H0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03o
on00o`3oon1F0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000
o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00o`3oon1F0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H01@0cXLX000000000002]f>H0003o00H0[MSV00<0<j7:0?ooh03oon00o`3oon1F0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H3000000030000o`2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00o`3o
on1F0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H2000000030000o`000000<j7:00L0<j7:o`3oon1H
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H20000000303>QbP000?l000000?l0oooPH@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3`3oon03000000H0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP8000000P000?oo0?ooh6<0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQ00oooP00<000000?ooh03oon001@3oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP050:gHiPH0<j7:00@000000000o`0000000000o`3oon1S0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0D000001P3oon04000000P0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00
0`3oon000`000?l000000000003o0?ooh640oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3o
on0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0?ooh03oon00
0P3oon000`000?l0oooP0?ooh03o0?ooh6D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iPh0oooP00<000000?ooh00000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0503>QbP3o
on00oooP0?ooh0000?l0o`3oon1X0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H?0?ooh08000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0403>QbP3oon00oooP0000ool0oooP
J@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP3oon00003o0?l0oooPJP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP000?l0oooP0?l0oooPJP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP050:gH
iP030000o`3oon00oooP0?l0oooPJP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP040:gHiP030000o`0cXLX0oooP0?l0oooPJ`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP030:gHiP030000
o`2]f>H0<j7:0?l0oooPK03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]
f>H00`0cXLX0[MSV0:gHiP020:gHiP040000o`2]f>H0[MSV03>Qb_l0oooPK03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H01@0cXLX000000000002]f>H0003o00<0[MSV
00<0<j7:0?ooh03oon00o`3oon1Z0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP080:gHiP8000000P000?l40:gHiP0303>QbP3oon00oooP0?l0oooPJP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H010000000003o00000000000503>Qb_l0oooPK03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`000?l000000000003o
0?ooh780oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gH
iP2]f>H02`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0003o03>Q
bP3oon00o`3oon1c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP03
03>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
0000o`2]f>H0<j7:0?l0oooPM03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP040000
o`2]f>H0[MSV03>Qb_l0oooPLP3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gHiP050000
o`2]f>H0[MSV0:gHiP0cXLX0o`3oon1d0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV
0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon1b0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV00<0[MSV00<0
<j7:0?ooh03oon00o`3oon1b0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP09
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP08
0:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV0:gHiP2]
f>H0003o00H0[MSV00<0<j7:0?ooh03oon00o`3oon1b0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
0`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
100cXLX0[MSV0:gHiP000?l70:gHiP0303>QbP3oon00oooP0?l0oooPLP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP0303>QbP2]f>H0
[MSV00@0[MSV0P0000000`000?l0[MSV0:gHiP060:gHiP0303>QbP3oon00oooP0?l0oooPLP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gH
iP0303>QbP2]f>H0[MSV00<0[MSV0P0000000`000?l0000003>QbP0803>Qb_l0oooPM03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0;0:gHiP03
03>QbP2]f>H0[MSV0080[MSV0P0000000`000?l000000000003o0?ooh7d0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H403>QbP800000
00<0003o000000000000o`3oon1n0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gH
iP080:gHiP0303>QbP2]f>H0[MSV00/0[MSV00H0<j7:0?ooh03oon00oooP000000000?l200000?l0
oooPO`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV
0:gHiP0;0:gHiP0503>QbP3oon00oooP0?ooh0000?l00P00003o0?ooh800oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H0100cXLX0oooP
0?ooh0000?oo0?ooh8<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0oooP0000o`3o0?ooh8@0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H02`2]f>H00`0cXLX0003o0?oo
h03o0?ooh8@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:
0:gHiP2]f>H02`2]f>H00`000?l0oooP0?ooh03o0?ooh8@0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gH
iP2]f>H0202]f>H00`0cXLX0[MSV0:gHiP0:0:gHiP030000o`0cXLX0oooP0?l0oooPP`3oon030000
01/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0003o0:gHiP0c
XLX0o`3oon260?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>Q
bP2]f>H0[MSV00P0[MSV00@0003o0:gHiP2]f>H0<j7:o`3oon260?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0003o0:gHiP2]f>H0
[MSV03>QbP3o0?ooh8H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP0?l0oooP
Q03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H00`0cXLX0[MSV0:gH
iP050:gHiP030000o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00o`3oon240?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0003o
0:gHiP2]f>H0102]f>H00`0cXLX0oooP0?ooh03o0?ooh8@0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0303>QbP2]f>H0[MSV00P0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0[MSV0:gHiP050:gH
iP0303>QbP3oon00oooP0?l0oooPQ03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]
f>H0202]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000o`2]f>H0[MSV00H0[MSV00<0<j7:0?ooh03o
on00o`3oon240?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP080:gHiP0503>Q
bP2]f>H0[MSV0:gHiP000?l02@2]f>H00`0cXLX0oooP0?ooh03o0?ooh8@0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV00@0<j7:0:gHiP000000003o2P2]f>H00`0cXLX0
oooP0?ooh03o0?ooh8@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00P0[MSV
00<0<j7:000000000?l00P00000:03>Qb_l0oooPQP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0
<j7:0:gHiP2]f>H0202]f>H00`0cXLX0003o0000000200000?l0oooPT03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00<0<j7:0:gHiP2]f>H0202]f>H010000?l0oooP00000000003o0?ooh940oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0003o03>QbP3oon00o`3oon2C
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP030000o`2]f>H0<j7:
0?l0oooPU03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0
oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP050:gHiP040000o`2]f>H0[MSV03>Q
b_l0oooPTP3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP050000o`2]f>H0[MSV0:gH
iP0cXLX0o`3oon2D0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
0000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon2B0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00
o`3oon2B0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000o`2]
f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00o`3oon2B0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0003o00H0[MSV00<0<j7:0?ooh03oon00o`3oon2B0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP000?l70:gHiP0303>QbP3oon00oooP0?l0oooPTP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV0P0000000`000?l0[MSV0:gHiP060:gHiP0303>QbP3oon00
oooP0?l0oooPTP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV0P0000000`000?l0000003>QbP0803>Q
b_l0oooPU03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00@000000000o`0000000000o`3oon2M0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`000?l000000000003o0?ooh9h0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP030000o`2]f>H0<j7:0?l0oooPW`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0
003o0:gHiP2]f>H0<j7:o`3oon2O0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@000?l0[MSV0:gH
iP2]f>H0<j7:0?l0oooPW`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3o
on03000000P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000o`2]
f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon2M0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0003o00D0[MSV00<0<j7:0?ooh03oon00o`3oon2M0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP
100000080?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0403>QbP2]f>H0[MSV0000o`H0[MSV00<0<j7:0?ooh03oon00o`3oon2J0?ooh0@0
00006`3oon0N0?[`iP40oooo000M0?[`iPd0oooP0`0000080?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP000?l01`2]f>H00`0cXLX0oooP0?ooh03o0?ooh9d0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<000000?ooh03oon001`3oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP80000000<0[MSV0000o`2]f>H01P2]f>H00`0cXLX0oooP0?ooh03o0?ooh9d0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0`0000070?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0403>QbP2]f>H0
[MSV0:gHiP<0000000<0003o0:gHiP2]f>H01P2]f>H00`0cXLX0oooP0?ooh03o0?ooh9d0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV100cXLX2000000030000o`000000
<j7:00P0<j7:o`3oon2O0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP3oon00oooP0080oooP00<0003o0000003oon00o`3oon2X0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0503>QbP3oon00oooP0?ooh0000?l0o`3oon2[0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0403>QbP3oon00oooP0000
ool0oooP[03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0
oooP0000o`3o0?ooh:d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0<j7:0000o`3oon00o`3oon2]0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP030000o`3oon00oooP0?l0oooP[@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`000?l0<j7:0?ooh03o0?ooh:h0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0003o03>QbP3oon00o`3oon2^0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP030000o`2]f>H0<j7:0?l0oooP[`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00H0<j7:0:gHiP00000000000:gHiP000?l20:gHiP0303>QbP3oon00oooP
0?l0oooP[@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:00000000000000000000o`030:gH
iP0303>QbP3oon00oooP0?l0oooP[@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon03000000T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX00000000000000?l00000
00@0<j7:o`3oon2]0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0403>QbP3oon00003o00000?l0oooP]03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0000o`3oon00o`3oon2e0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`000?l0oooP0?ooh03o0?ooh;D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP030000o`0c
XLX0oooP0?l0oooP]P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0003o03>QbP3oon00o`3oon2f
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H2000000030000o`2]f>H0<j7:0?l0oooP]`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP04
03>QbP2]f>H0[MSV0:gHiP80000000@0003o0000002]f>H0<j7:o`3oon2g0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00H0[MSV100cXLX01000
0000003o00000000000203>Qb_l0oooP]`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP3oon00oooP0?ooh0000?l00P00003o
0?ooh;X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H0100cXLX0oooP0?ooh0000?oo0?ooh;d0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0100cXLX0oooP0?ooh0000?oo
0?ooh;d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0oooP0000o`3o0?ooh;h0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0003o0?ooh03o0?ooh;h0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`000?l0oooP0?ooh03o0?ooh;h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00T0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0<j7:0?ooh03o0?ooh;l0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP030000o`2]f>H0
<j7:0?l0oooP_P3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0403>QbP2]f>H0[MSV
0:gHiP80000000@0[MSV0000o`2]f>H0<j7:o`3oon300?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP090:gHiP0303>QbP2]f>H0[MSV00<0000000@0003o0:gHiP2]f>H0<j7:o`3o
on300?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP<0<j7:0P000000
0`000?l0000003>QbP0203>Qb_l0oooP`03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H02@2]f>H01P0cXLX0oooP0?ooh03oon00003o00000?l0oooPa03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H0100cXLX0oooP0?ooh0000?oo0?ooh<H0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV00<0<j7:0?ooh0000?l0o`3oon37
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP090:gHiP0303>QbP3oon00003o
0?l0oooPa`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H02@2]f>H00`0cXLX0
003o0?ooh03o0?ooh<L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00T0[MSV
00<0003o0?ooh03oon00o`3oon370?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP080:gHiP030000o`0cXLX0oooP0?l0oooPb03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H00`000?l0[MSV03>QbP3o0?ooh<T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00@0[MSV0P00000010000?l0[MSV0:gHiP0cXL[o0?ooh<T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP040:gHiPH0<j7:0`00000010000?l0<j7:03>QbP0cXL[o0?ooh<T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP3oon00oooP00<0oooP0P0000000`000?l000000?ooh03o0?oo
h</0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP3oon00oooP00@0oooP00<0003o0000003o
on00o`3oon3<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000
2@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP3oon00oooP00<0oooP00<0003o0?ooh03oon00
o`3oon3;0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP3oon00oooP0080oooP00<0003o0?ooh03oon00o`3o
on3>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0oooP0?ooh03oon00003o0?l0oooPd@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0?ooh03oon00003oo`3oon3B0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0oooP0000o`3o0?ooh=<0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP3oon00003o0?l0oooPd`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0000o`3o
on00o`3oon3C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`000?l0oooP0?ooh03o0?ooh=<0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP030:gHiP030000o`0cXLX0oooP0?l0oooPe03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV0080[MSV00<0003o0:gHiP0cXLX0o`3oon3E0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV0000o`02
0:gHiP0303>QbP3oon00oooP0?l0oooPd`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00403>QbP2]f>H000000000o`<0[MSV00<0<j7:
0?ooh03oon00o`3oon3C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00D0<j7:000000000000003o0000000303>Qb_l0oooPe@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?oo
h03oon002P3oon0010000000003o00000000003o0?ooh=P0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh00:
0?ooh0030000o`00000000000?l0oooPf@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0@00000203oon000`000?l0oooP0?ooh03o
0?ooh=L0oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?oo
h03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh004
0000003oon00oooP000000L0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh>H0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01:0?ooh0030000003o
on00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000003o
on00oooP04X0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh?l0
0000jP00000K0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00d@3jl>H400000080n_3V200000020?[`iP@0000000L0n_3V00000000000000000?[`iP000000
n_3V00`0000000<0n_3V00000000000010000000103jl>H000000000000000080?[`iPD00000103j
l>H7000000030?[`iP000000n_3V00<00000203jl>H500000080n_3V100000020?[`iPD00000303j
l>H300000140n_3V0`0000060?[`iP<0000000@0n_3V00000000000000001P3jl>H00`000000n_3V
0?[`iP040?[`iP<0000000@0n_3V0000000000000000f03jl>H10?ooo`00dP3jl>H200000080n_3V
0P0000030?[`iP8000000`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V
00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000002@3jl>H010000000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3j
l>H2000000d0n_3V0P0000000`3jl>H000000000000?0?[`iP80000000<0n_3V0000000000001P3j
l>H2000000030?[`iP000000000000L0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00
000000000=T0n_3V0@3oool00=80n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2
000000D0n_3V0P0000000`3jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP000000000000d0n_3V0P0000020?[`iP80000000@0n_3V
000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3j
l>H200000080n_3V0P00000=0?[`iP80000000<0n_3V0000000000001@3jl>H5000000D0n_3V0P00
00000`3jl>H00000000000070?[`iP<000001P3jl>H5000000H0n_3V0`00003J0?[`iP40oooo003B
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80
000000<0n_3V0000000000003`3jl>H2000000030?[`iP000000000000L0n_3V0`0000080?[`iP03
0000003jl>H0n_3V00H0n_3V0`00003J0?[`iP40oooo003B0?[`iP8000000P3jl>H2000000<0n_3V
0P0000030?[`iP8000000P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`
iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`
iP<00000103jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:
0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H02P3jl>H3
00000100n_3V100000070?[`iP80000000<0n_3V0000000000001`3jl>H00`000000n_3V0?[`iP05
0?[`iP80000000<0n_3V000000000000f@3jl>H10?ooo`00dP3jl>H200000080n_3V0P0000000`3j
l>H0000000000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`
iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000:0?[`
iPD000000P3jl>H400000080n_3V0`0000000`3jl>H000000000000:0?[`iP80000000<0n_3V0000
000000003`3jl>H2000000P0n_3V0`000000103jl>H0000000000000000=0?[`iP<0000000<0n_3V
0000000000001@00003D0?[`iP40oooo003B0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`
iP030000003jl>H0n_3V01L0n_3V0P00000J0?[`iP80000000<0n_3V000000000000403jl>H20000
02<0n_3V00<000000?[`iP3jl>H0e03jl>H10?ooo`00d@3jl>H6000000@0n_3V0P00000_0?[`iPD0
00006P3jl>H3000001T0n_3V0`00000B0?[`iP<000008P3jl>H00`000000n_3V0?[`iP3C0?[`iP40
oooo003o0?[`iX<0n_3V00<000000?[`iP3jl>H0dP3jl>H10?ooo`00o`3jl>J00?[`iP040000003j
l>H0n_3V00000=@0n_3V0@3oool00?l0n_3VP@3jl>H200000=D0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .59033 L
.03844 .59033 L
.03844 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .59033 L
.03844 .59033 L
.03844 .08012 L
s
.678 .847 .902 r
.03844 .08012 m
.03844 .58055 L
.05091 .58055 L
.05091 .08012 L
F
.2 .63 .79 r
.03844 .08012 m
.03844 .58055 L
.05091 .58055 L
.05091 .08012 L
s
.678 .847 .902 r
.05091 .08012 m
.05091 .56723 L
.0638 .56723 L
.0638 .08012 L
F
.2 .63 .79 r
.05091 .08012 m
.05091 .56723 L
.0638 .56723 L
.0638 .08012 L
s
.678 .847 .902 r
.0638 .08012 m
.0638 .54254 L
.08163 .54254 L
.08163 .08012 L
F
.2 .63 .79 r
.0638 .08012 m
.0638 .54254 L
.08163 .54254 L
.08163 .08012 L
s
.678 .847 .902 r
.08163 .08012 m
.08163 .52477 L
.09244 .52477 L
.09244 .08012 L
F
.2 .63 .79 r
.08163 .08012 m
.08163 .52477 L
.09244 .52477 L
.09244 .08012 L
s
.678 .847 .902 r
.09244 .08012 m
.09244 .51104 L
.10612 .51104 L
.10612 .08012 L
F
.2 .63 .79 r
.09244 .08012 m
.09244 .51104 L
.10612 .51104 L
.10612 .08012 L
s
.678 .847 .902 r
.10612 .08012 m
.10612 .49556 L
.11748 .49556 L
.11748 .08012 L
F
.2 .63 .79 r
.10612 .08012 m
.10612 .49556 L
.11748 .49556 L
.11748 .08012 L
s
.678 .847 .902 r
.11748 .08012 m
.11748 .48053 L
.13655 .48053 L
.13655 .08012 L
F
.2 .63 .79 r
.11748 .08012 m
.11748 .48053 L
.13655 .48053 L
.13655 .08012 L
s
.678 .847 .902 r
.13655 .08012 m
.13655 .46959 L
.14361 .46959 L
.14361 .08012 L
F
.2 .63 .79 r
.13655 .08012 m
.13655 .46959 L
.14361 .46959 L
.14361 .08012 L
s
.678 .847 .902 r
.14361 .08012 m
.14361 .46272 L
.16164 .46272 L
.16164 .08012 L
F
.2 .63 .79 r
.14361 .08012 m
.14361 .46272 L
.16164 .46272 L
.16164 .08012 L
s
.678 .847 .902 r
.16164 .08012 m
.16164 .44353 L
.16905 .44353 L
.16905 .08012 L
F
.2 .63 .79 r
.16164 .08012 m
.16164 .44353 L
.16905 .44353 L
.16905 .08012 L
s
.678 .847 .902 r
.16905 .08012 m
.16905 .4368 L
.17788 .4368 L
.17788 .08012 L
F
.2 .63 .79 r
.16905 .08012 m
.16905 .4368 L
.17788 .4368 L
.17788 .08012 L
s
.678 .847 .902 r
.17788 .08012 m
.17788 .42264 L
.19131 .42264 L
.19131 .08012 L
F
.2 .63 .79 r
.17788 .08012 m
.17788 .42264 L
.19131 .42264 L
.19131 .08012 L
s
.678 .847 .902 r
.19131 .08012 m
.19131 .408 L
.20897 .408 L
.20897 .08012 L
F
.2 .63 .79 r
.19131 .08012 m
.19131 .408 L
.20897 .408 L
.20897 .08012 L
s
.678 .847 .902 r
.20897 .08012 m
.20897 .38366 L
.22438 .38366 L
.22438 .08012 L
F
.2 .63 .79 r
.20897 .08012 m
.20897 .38366 L
.22438 .38366 L
.22438 .08012 L
s
.678 .847 .902 r
.22438 .08012 m
.22438 .37941 L
.24016 .37941 L
.24016 .08012 L
F
.2 .63 .79 r
.22438 .08012 m
.22438 .37941 L
.24016 .37941 L
.24016 .08012 L
s
.678 .847 .902 r
.24016 .08012 m
.24016 .36248 L
.25725 .36248 L
.25725 .08012 L
F
.2 .63 .79 r
.24016 .08012 m
.24016 .36248 L
.25725 .36248 L
.25725 .08012 L
s
.678 .847 .902 r
.25725 .08012 m
.25725 .33792 L
.275 .33792 L
.275 .08012 L
F
.2 .63 .79 r
.25725 .08012 m
.25725 .33792 L
.275 .33792 L
.275 .08012 L
s
.678 .847 .902 r
.275 .08012 m
.275 .32601 L
.28463 .32601 L
.28463 .08012 L
F
.2 .63 .79 r
.275 .08012 m
.275 .32601 L
.28463 .32601 L
.28463 .08012 L
s
.678 .847 .902 r
.28463 .08012 m
.28463 .31481 L
.29728 .31481 L
.29728 .08012 L
F
.2 .63 .79 r
.28463 .08012 m
.28463 .31481 L
.29728 .31481 L
.29728 .08012 L
s
.678 .847 .902 r
.29728 .08012 m
.29728 .30533 L
.31525 .30533 L
.31525 .08012 L
F
.2 .63 .79 r
.29728 .08012 m
.29728 .30533 L
.31525 .30533 L
.31525 .08012 L
s
.678 .847 .902 r
.31525 .08012 m
.31525 .29088 L
.32687 .29088 L
.32687 .08012 L
F
.2 .63 .79 r
.31525 .08012 m
.31525 .29088 L
.32687 .29088 L
.32687 .08012 L
s
.678 .847 .902 r
.32687 .08012 m
.32687 .28369 L
.33962 .28369 L
.33962 .08012 L
F
.2 .63 .79 r
.32687 .08012 m
.32687 .28369 L
.33962 .28369 L
.33962 .08012 L
s
.678 .847 .902 r
.33962 .08012 m
.33962 .2631 L
.35801 .2631 L
.35801 .08012 L
F
.2 .63 .79 r
.33962 .08012 m
.33962 .2631 L
.35801 .2631 L
.35801 .08012 L
s
.678 .847 .902 r
.35801 .08012 m
.35801 .25673 L
.36717 .25673 L
.36717 .08012 L
F
.2 .63 .79 r
.35801 .08012 m
.35801 .25673 L
.36717 .25673 L
.36717 .08012 L
s
.678 .847 .902 r
.36717 .08012 m
.36717 .24929 L
.38574 .24929 L
.38574 .08012 L
F
.2 .63 .79 r
.36717 .08012 m
.36717 .24929 L
.38574 .24929 L
.38574 .08012 L
s
.678 .847 .902 r
.38574 .08012 m
.38574 .23752 L
.40502 .23752 L
.40502 .08012 L
F
.2 .63 .79 r
.38574 .08012 m
.38574 .23752 L
.40502 .23752 L
.40502 .08012 L
s
.678 .847 .902 r
.40502 .08012 m
.40502 .22461 L
.41141 .22461 L
.41141 .08012 L
F
.2 .63 .79 r
.40502 .08012 m
.40502 .22461 L
.41141 .22461 L
.41141 .08012 L
s
.678 .847 .902 r
.41141 .08012 m
.41141 .22071 L
.42917 .22071 L
.42917 .08012 L
F
.2 .63 .79 r
.41141 .08012 m
.41141 .22071 L
.42917 .22071 L
.42917 .08012 L
s
.678 .847 .902 r
.42917 .08012 m
.42917 .20326 L
.43989 .20326 L
.43989 .08012 L
F
.2 .63 .79 r
.42917 .08012 m
.42917 .20326 L
.43989 .20326 L
.43989 .08012 L
s
.678 .847 .902 r
.43989 .08012 m
.43989 .1974 L
.45363 .1974 L
.45363 .08012 L
F
.2 .63 .79 r
.43989 .08012 m
.43989 .1974 L
.45363 .1974 L
.45363 .08012 L
s
.678 .847 .902 r
.45363 .08012 m
.45363 .18837 L
.46036 .18837 L
.46036 .08012 L
F
.2 .63 .79 r
.45363 .08012 m
.45363 .18837 L
.46036 .18837 L
.46036 .08012 L
s
.678 .847 .902 r
.46036 .08012 m
.46036 .17933 L
.4769 .17933 L
.4769 .08012 L
F
.2 .63 .79 r
.46036 .08012 m
.46036 .17933 L
.4769 .17933 L
.4769 .08012 L
s
.678 .847 .902 r
.4769 .08012 m
.4769 .17141 L
.48899 .17141 L
.48899 .08012 L
F
.2 .63 .79 r
.4769 .08012 m
.4769 .17141 L
.48899 .17141 L
.48899 .08012 L
s
.678 .847 .902 r
.48899 .08012 m
.48899 .16726 L
.50114 .16726 L
.50114 .08012 L
F
.2 .63 .79 r
.48899 .08012 m
.48899 .16726 L
.50114 .16726 L
.50114 .08012 L
s
.678 .847 .902 r
.50114 .08012 m
.50114 .1537 L
.51847 .1537 L
.51847 .08012 L
F
.2 .63 .79 r
.50114 .08012 m
.50114 .1537 L
.51847 .1537 L
.51847 .08012 L
s
.678 .847 .902 r
.51847 .08012 m
.51847 .14893 L
.52741 .14893 L
.52741 .08012 L
F
.2 .63 .79 r
.51847 .08012 m
.51847 .14893 L
.52741 .14893 L
.52741 .08012 L
s
.678 .847 .902 r
.52741 .08012 m
.52741 .14308 L
.54126 .14308 L
.54126 .08012 L
F
.2 .63 .79 r
.52741 .08012 m
.52741 .14308 L
.54126 .14308 L
.54126 .08012 L
s
.678 .847 .902 r
.54126 .08012 m
.54126 .13441 L
.55741 .13441 L
.55741 .08012 L
F
.2 .63 .79 r
.54126 .08012 m
.54126 .13441 L
.55741 .13441 L
.55741 .08012 L
s
.678 .847 .902 r
.55741 .08012 m
.55741 .12624 L
.56479 .12624 L
.56479 .08012 L
F
.2 .63 .79 r
.55741 .08012 m
.55741 .12624 L
.56479 .12624 L
.56479 .08012 L
s
.678 .847 .902 r
.56479 .08012 m
.56479 .12397 L
.57605 .12397 L
.57605 .08012 L
F
.2 .63 .79 r
.56479 .08012 m
.56479 .12397 L
.57605 .12397 L
.57605 .08012 L
s
.678 .847 .902 r
.57605 .08012 m
.57605 .11426 L
.59156 .11426 L
.59156 .08012 L
F
.2 .63 .79 r
.57605 .08012 m
.57605 .11426 L
.59156 .11426 L
.59156 .08012 L
s
.678 .847 .902 r
.59156 .08012 m
.59156 .10799 L
.60392 .10799 L
.60392 .08012 L
F
.2 .63 .79 r
.59156 .08012 m
.59156 .10799 L
.60392 .10799 L
.60392 .08012 L
s
.678 .847 .902 r
.60392 .08012 m
.60392 .1002 L
.61806 .1002 L
.61806 .08012 L
F
.2 .63 .79 r
.60392 .08012 m
.60392 .1002 L
.61806 .1002 L
.61806 .08012 L
s
.678 .847 .902 r
.61806 .08012 m
.61806 .0947 L
.63076 .0947 L
.63076 .08012 L
F
.2 .63 .79 r
.61806 .08012 m
.61806 .0947 L
.63076 .0947 L
.63076 .08012 L
s
.678 .847 .902 r
.63076 .08012 m
.63076 .08867 L
.64048 .08867 L
.64048 .08012 L
F
.2 .63 .79 r
.63076 .08012 m
.63076 .08867 L
.64048 .08867 L
.64048 .08012 L
s
.678 .847 .902 r
.64048 .08012 m
.64048 .08774 L
.6595 .08774 L
.6595 .08012 L
F
.2 .63 .79 r
.64048 .08012 m
.64048 .08774 L
.6595 .08774 L
.6595 .08012 L
s
1 .894 .882 r
.6595 .08012 m
.6595 .07559 L
.67467 .07559 L
.67467 .08012 L
F
.804 .522 .247 r
.6595 .08012 m
.6595 .07559 L
.67467 .07559 L
.67467 .08012 L
s
1 .894 .882 r
.67467 .08012 m
.67467 .07104 L
.68404 .07104 L
.68404 .08012 L
F
.804 .522 .247 r
.67467 .08012 m
.67467 .07104 L
.68404 .07104 L
.68404 .08012 L
s
1 .894 .882 r
.68404 .08012 m
.68404 .06856 L
.6946 .06856 L
.6946 .08012 L
F
.804 .522 .247 r
.68404 .08012 m
.68404 .06856 L
.6946 .06856 L
.6946 .08012 L
s
1 .894 .882 r
.6946 .08012 m
.6946 .06085 L
.71377 .06085 L
.71377 .08012 L
F
.804 .522 .247 r
.6946 .08012 m
.6946 .06085 L
.71377 .06085 L
.71377 .08012 L
s
1 .894 .882 r
.71377 .08012 m
.71377 .05791 L
.72837 .05791 L
.72837 .08012 L
F
.804 .522 .247 r
.71377 .08012 m
.71377 .05791 L
.72837 .05791 L
.72837 .08012 L
s
1 .894 .882 r
.72837 .08012 m
.72837 .05226 L
.73939 .05226 L
.73939 .08012 L
F
.804 .522 .247 r
.72837 .08012 m
.72837 .05226 L
.73939 .05226 L
.73939 .08012 L
s
1 .894 .882 r
.73939 .08012 m
.73939 .04741 L
.75865 .04741 L
.75865 .08012 L
F
.804 .522 .247 r
.73939 .08012 m
.73939 .04741 L
.75865 .04741 L
.75865 .08012 L
s
1 .894 .882 r
.75865 .08012 m
.75865 .04428 L
.76991 .04428 L
.76991 .08012 L
F
.804 .522 .247 r
.75865 .08012 m
.75865 .04428 L
.76991 .04428 L
.76991 .08012 L
s
1 .894 .882 r
.76991 .08012 m
.76991 .04045 L
.7836 .04045 L
.7836 .08012 L
F
.804 .522 .247 r
.76991 .08012 m
.76991 .04045 L
.7836 .04045 L
.7836 .08012 L
s
1 .894 .882 r
.7836 .08012 m
.7836 .03568 L
.7975 .03568 L
.7975 .08012 L
F
.804 .522 .247 r
.7836 .08012 m
.7836 .03568 L
.7975 .03568 L
.7975 .08012 L
s
1 .894 .882 r
.7975 .08012 m
.7975 .03256 L
.81049 .03256 L
.81049 .08012 L
F
.804 .522 .247 r
.7975 .08012 m
.7975 .03256 L
.81049 .03256 L
.81049 .08012 L
s
1 .894 .882 r
.81049 .08012 m
.81049 .03187 L
.82901 .03187 L
.82901 .08012 L
F
.804 .522 .247 r
.81049 .08012 m
.81049 .03187 L
.82901 .03187 L
.82901 .08012 L
s
1 .894 .882 r
.82901 .08012 m
.82901 .02642 L
.84479 .02642 L
.84479 .08012 L
F
.804 .522 .247 r
.82901 .08012 m
.82901 .02642 L
.84479 .02642 L
.84479 .08012 L
s
1 .894 .882 r
.84479 .08012 m
.84479 .02485 L
.85558 .02485 L
.85558 .08012 L
F
.804 .522 .247 r
.84479 .08012 m
.84479 .02485 L
.85558 .02485 L
.85558 .08012 L
s
1 .894 .882 r
.85558 .08012 m
.85558 .02224 L
.87415 .02224 L
.87415 .08012 L
F
.804 .522 .247 r
.85558 .08012 m
.85558 .02224 L
.87415 .02224 L
.87415 .08012 L
s
1 .894 .882 r
.87415 .08012 m
.87415 .0206 L
.88233 .0206 L
.88233 .08012 L
F
.804 .522 .247 r
.87415 .08012 m
.87415 .0206 L
.88233 .0206 L
.88233 .08012 L
s
1 .894 .882 r
.88233 .08012 m
.88233 .02002 L
.89656 .02002 L
.89656 .08012 L
F
.804 .522 .247 r
.88233 .08012 m
.88233 .02002 L
.89656 .02002 L
.89656 .08012 L
s
1 .894 .882 r
.89656 .08012 m
.89656 .01791 L
.91551 .01791 L
.91551 .08012 L
F
.804 .522 .247 r
.89656 .08012 m
.89656 .01791 L
.91551 .01791 L
.91551 .08012 L
s
1 .894 .882 r
.91551 .08012 m
.91551 .017 L
.92438 .017 L
.92438 .08012 L
F
.804 .522 .247 r
.91551 .08012 m
.91551 .017 L
.92438 .017 L
.92438 .08012 L
s
1 .894 .882 r
.92438 .08012 m
.92438 .01608 L
.93963 .01608 L
.93963 .08012 L
F
.804 .522 .247 r
.92438 .08012 m
.92438 .01608 L
.93963 .01608 L
.93963 .08012 L
s
1 .894 .882 r
.93963 .08012 m
.93963 .01543 L
.94554 .01543 L
.94554 .08012 L
F
.804 .522 .247 r
.93963 .08012 m
.93963 .01543 L
.94554 .01543 L
.94554 .08012 L
s
1 .894 .882 r
.94554 .08012 m
.94554 .01496 L
.95761 .01496 L
.95761 .08012 L
F
.804 .522 .247 r
.94554 .08012 m
.94554 .01496 L
.95761 .01496 L
.95761 .08012 L
s
1 .894 .882 r
.95761 .08012 m
.95761 .01481 L
.97619 .01481 L
.97619 .08012 L
F
.804 .522 .247 r
.95761 .08012 m
.95761 .01481 L
.97619 .01481 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.03438 .59033 Mdot
.04241 .58055 Mdot
.05347 .56723 Mdot
.07432 .54254 Mdot
.08963 .52477 Mdot
.10164 .51104 Mdot
.11539 .49556 Mdot
.12895 .48053 Mdot
.13896 .46959 Mdot
.1453 .46272 Mdot
.16329 .44353 Mdot
.1697 .4368 Mdot
.18335 .42264 Mdot
.1977 .408 Mdot
.22218 .38366 Mdot
.22653 .37941 Mdot
.24414 .36248 Mdot
.27046 .33792 Mdot
.28358 .32601 Mdot
.29616 .31481 Mdot
.30698 .30533 Mdot
.32383 .29088 Mdot
.33238 .28369 Mdot
.35752 .2631 Mdot
.3655 .25673 Mdot
.37497 .24929 Mdot
.39024 .23752 Mdot
.40746 .22461 Mdot
.41278 .22071 Mdot
.43718 .20326 Mdot
.44562 .1974 Mdot
.45889 .18837 Mdot
.47254 .17933 Mdot
.48479 .17141 Mdot
.49135 .16726 Mdot
.51341 .1537 Mdot
.52141 .14893 Mdot
.53143 .14308 Mdot
.54671 .13441 Mdot
.56163 .12624 Mdot
.56587 .12397 Mdot
.58453 .11426 Mdot
.59707 .10799 Mdot
.61325 .1002 Mdot
.62512 .0947 Mdot
.63861 .08867 Mdot
.64074 .08774 Mdot
.66992 .07559 Mdot
.68159 .07104 Mdot
.68814 .06856 Mdot
.70956 .06085 Mdot
.71821 .05791 Mdot
.73566 .05226 Mdot
.75175 .04741 Mdot
.76274 .04428 Mdot
.77706 .04045 Mdot
.79646 .03568 Mdot
.81035 .03256 Mdot
.81362 .03187 Mdot
.84187 .02642 Mdot
.85122 .02485 Mdot
.86854 .02224 Mdot
.88095 .0206 Mdot
.8858 .02002 Mdot
.90604 .01791 Mdot
.91685 .017 Mdot
.93026 .01608 Mdot
.94308 .01543 Mdot
.95694 .01496 Mdot
.96399 .01481 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0607061) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.99874) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000@0n_3V0`0000040?[`iP<000001@3jl>H3000000D0n_3V0P0000040?[`iP@0
0000o`3jl>JS0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000060?[`iP8000001@3j
l>H2000000<0n_3V0P0000000`3jl>H00000000000040?[`iP8000001@3jl>H200000?l0n_3VY03j
l>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2
000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000006`3jl>H2000000`0n_3V0P0000050?[`iP8000000P3j
l>H2000000030?[`iP000000000000@0n_3V0P0000020?[`iPH00000o`3jl>JS0?[`iP40oooo000P
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000T0n_3V1@00000=0?[`iP8000002P3jl>H4000000<0n_3V100000020?[`iP80
000000<0n_3V000000000000103jl>H200000080n_3V00<000000?[`iP3jl>H00P00003o0?[`iZ@0
n_3V0@3oool00200n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP800000
00H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V0000
00000000n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V00<000000?[`iP3jl>H00P000009
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0`000006
0?[`iP8000000P3jl>H010000000n_3V00000000003o0?[`iZ@0n_3V0@3oool00200n_3V0P000002
0?[`iP80000000<0n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000000000001@000002
0?[`iP@000000P3jl>H500000080n_3V1@00000:0?[`iP8000001@3jl>H3000000030?[`iP000000
000000L000006@3jl>H4000000X0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP040000003jl>H0
000000000?l0n_3VY03jl>H10?ooo`00803jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H0
0`000000n_3V0?[`iP0U0?[`iP800000303jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H00`000000n_3V0?[`iP02
000000<0n_3V0`00003o0?[`iZ@0n_3V0@3oool001l0n_3V1P0000040?[`iP800000;`3jl>H50000
02L0n_3V1@00000:0?[`iP<00000103jl>H3000000@0n_3V0`0000030?[`iPD00000103jl>H20000
0?l0n_3VY03jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V0P00003o0?[`
i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00000000000000003jl>H00`0000020?[`
iP<000000`3jl>H4000000<0n_3V0P000000103jl>H000000000003jl>H5000000<0n_3V3000000_
0?[`iP<00000103jl>H200000?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3j
l>H00000000000020?[`iP8000000P3jl>H010000000n_3V0000000000030?[`iP050000003jl>H0
00000000003jl>H00`0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP8000008P3j
l>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`iP800000o`3jl>K90?[`iP40oooo000R
0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H2
00000080n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H2
000000030?[`iP00000000000?l0n_3VcP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3j
l>H00000000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`
iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP0000000000
0?l0n_3VcP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP80
0000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V0`0000000`3j
l>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V1000003o0?[`i/l0n_3V0@3oool00280
n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V100000030?[`iP80000000<0n_3V00000000
0000100000000`3jl>H00000000000020?[`iP@00000103jl>H200000300n_3V0P00003o0?[`i]40
n_3V0@3oool00280n_3V0P00000;0?[`iP8000008P3jl>H200000340n_3V0P00003o0?[`i]00n_3V
0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000380n_3V0`00003o0?[`i/h0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3j
l>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`iP030000003j
l>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H0000000000002
000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H0000001T0n_3V0`00
003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P00
00020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V100000000`3jl>H00000
000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H000000?[`iP030000
01P0n_3V0`0000040?[`iP8000001@3jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H20000
00@0n_3V0`0000040?[`iP<000000`3jl>H600000700n_3V0@3oool00240n_3V0P0000000`3jl>H0
000000000005000000040?[`iP000000000000000080n_3V0P0000000`3jl>H00000000000090?[`
iPD000002@3jl>H00`000000n_3V0?[`iP0200000=`0n_3V0P0000040?[`iP8000000P3jl>H20000
0080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P000002
0?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0
n_3V0000000000002P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP8000000P3j
l>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0
n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00001b0?[`iP40oooo000R
0?[`iP<00000:`3jl>H200000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P000005
0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P000002
0?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P00
00020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P00
00000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H00000000000040?[`iP800000LP3jl>H10?ooo`008P3jl>H3
000001X0n_3V1@00000<0?[`iP800000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2
000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2
000000030?[`iP000000000000X0n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3j
l>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3j
l>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00001b0?[`iP40oooo000Q
0?[`iP80000000<0n_3V000000000000:03jl>H300000=d0n_3V0P0000000`3jl>H0000000000005
0?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P00
00060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3j
l>H3000000040?[`iP00000000000?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H00000
0?[`iP02000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V
0P0000000`3jl>H00000000000020?[`iP@000000`3jl>H2000000030?[`iP000000000000D0n_3V
0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H4000000D0n_3V0P00001b0?[`iP40oooo
000P0?[`iP<0000000@0n_3V0000000000000000:@3jl>H200000=`0n_3V0P0000000`3jl>H00000
000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0
n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0n_3V00000000
00000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H0
0000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000D0n_3V0P0000000`3jl>H0
0000000000050?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000070?[`iP80
0000LP3jl>H10?ooo`00C@3jl>H00`000000n_3V0?[`iP0200000=`0n_3V0P0000000`3jl>H00000
0000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`iP800000;P3jl>H2000000030?[`
iP000000000000T0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2000000030?[`
iP00000000000080n_3V00<000000?[`iP3jl>H00P0000020?[`iP80000000<0n_3V000000000000
0`3jl>H2000000@0n_3V1000001b0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P00
00060?[`iP800000103jl>H2000000H0n_3V0P00000I0?[`iP<0000000<0n_3V0000000000000P00
000^0?[`iP<000002`3jl>H3000000D0n_3V0`0000030?[`iP<000000`3jl>H5000000<0n_3V0`00
00050?[`iP<00000103jl>H200000780n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P00000
00<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00D000000?[`iP000000n_3V
000000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H0o`3jl>Ko0?[`iR80
n_3V0@3oool00200n_3V0`0000000`3jl>H0000000000002000000040?[`iP000000n_3V00000080
n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP0G0?[`iP<00000g03jl>H40000
00@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H40000
0080n_3V0`0000000`3jl>H0000000000006000001`0n_3V0P0000040?[`iP<00000`@3jl>H10?oo
o`008@3jl>H2000000030?[`iP000000000000D0000000D0n_3V00000000000000000?[`iP040000
00/0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P0000020?[`
iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H2
00000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
0000103jl>H000000000003jl>H200000080n_3V0P00000;0?[`iPD000002`3jl>H2000000<0n_3V
0P0000000`3jl>H00000000000300?[`iP40oooo000R0?[`iP<00000:03jl>H2000000030?[`iP00
000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000001P3j
l>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000<0
n_3V0000000000000`3jl>H4000001/0n_3V0P0000030?[`iP80000000<0n_3V000000000000`03j
l>H10?ooo`008P3jl>H3000000T0n_3V00<000000?[`iP3jl>H03P3jl>H5000000T0n_3V0P000000
0`3jl>H000000000003L0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2
000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V
000000000000n_3V1000000=0?[`iPD000002`3jl>H2000000<0n_3V0P0000000`3jl>H000000000
00300?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000009`3jl>H2000000030?[`iP000000
00000=`0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP000000
n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P00
00020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP800000703jl>H200000080n_3V
0P0000000`3jl>H00000000000300?[`iP40oooo000P0?[`iP<0000000@0n_3V0000000000000000
9P3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@00000
0P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@0
0000103jl>H400000080n_3V1@0000030?[`iPD00000703jl>H200000080n_3V0P0000000`3jl>H0
0000000000300?[`iP40oooo001=0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`
iP00000000000100n_3V0P00000<0?[`iP800000>03jl>H00`000000n_3V0?[`iP0200000080n_3V
0P0000000`3jl>H00000000000300?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P00
00060?[`iP800000103jl>H2000000H0n_3V0P00000`0?[`iPD000000`3jl>H300000<40n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iR<0oooP
0P0000150?ooh0800000103oon02000000@0oooP0P0000140?ooh0D00000@`3oon0500000080oooP
0P0000040?ooh0800000A03oon04000004@0oooP100000030?ooh0800000103oon02000004D0oooP
0P00000W0?ooh1h0n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000
003oon00oooP000000P0oooP00@000000?ooh03oon000000A@3oon000`000000oooP0?ooh0150?oo
h0030000003oon00oooP00L0oooP00@000000?ooh03oon000000@`3oon000`000000oooP0?ooh015
0?ooh0030000003oon00oooP00T0oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?oo
h000000V0?ooh1h0n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000
003oon00oooP000000/0oooP00<000000?ooh03oon00@`3oon000`000000oooP0?ooh0150?ooh003
0000003oon00oooP00X0oooP00<000000?ooh03oon00@P3oon000`000000oooP0?ooh0150?ooh003
0000003oon00oooP00/0oooP00<000000?ooh03oon00@`3oon000`000000oooP0?ooh00U0?ooh1h0
n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP0000
00T0oooP0P0000160?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00203oon020000
04H0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0800000A`3oon000`00
0000oooP0?ooh00T0?ooh1h0n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?oo
h0040000003oon00oooP000000T0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh015
0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00@`3oon0010000000oooP0?ooh000
00140?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03oon00@`3oon0010000000oooP
0?ooh000000V0?ooh1h0n_3V0@3oool001d0n_3V8`3oon02000004D0oooP0P00000:0?ooh0<00000
A03oon02000004H0oooP0P00000:0?ooh0<00000A03oon02000004H0oooP0P00000:0?ooh0<00000
A03oon02000002L0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V603oon3o00000>X0
00006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP04X0oooP00<00000
0?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<00000
0?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP00T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0
oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh03o0?ooh<T0oooP0P0000050?ooh08000000P3oon0200000100oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2m0?ooh0800000103o
on02000000<0oooP100000030?ooh0P000003`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon0300000?l0oooP]`3oon02000000<0oooP100000000`3oon00003o0000o`0H
0000o`T0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?oo
h:/0oooP100000040?ooh0<0cHDo0`0000080000o`030<f5?`0000000000008000000P3oi>40103=
QCl000000000003=QCl40?oTh@8000000P3oi>42000000@0onCQ00<0cHDo0?ooh03oon002@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?oo
h:D0oooP0P0000000`3oon00cHDo0<f5?`06000000T0003o00@000000?oTh@3oi>40cHDo0P000002
0?oTh@040<f5?`3oi>400000000000<0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2M0?ooh08000001@3=QCl2000000X0003o0`3o
i>40103=QCl0onCQ0?oTh@3oi>42000000<0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPV03oon0200000080oooP0P0000080000o`80000000<0cHDo0?oTh@3oi>40
100000040?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ
0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPTP3oon050<f5?`03000000000?l0003o00@0003o0P0000050?oTh@800000
00<0onCQ0<f5?`3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPRP3oon02000000D0oooP
1`000?l300000080onCQ0P0000000`3=QCl0onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh8T0oooP0`0000050000o`030?ooh03=QCl0onCQ00@0onCQ0P0000000`3=QCl0
onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oT
h@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oT
h@040<f5?`3oi>40onCQ0<f5?`D0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh009
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
0?l0oooPPP3oon02000000@0cHDo10000?l00`000000cHDo0<f5?`040<f5?`L0onCQ00<0cHDo0?oT
h@3oi>400P3oi>400`3=QCl0onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>40
0`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40
103=QCl0onCQ0?oTh@3=QCl50?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o
0?ooh840oooP0`0000040000o`@000001P3oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40
onCQ0080onCQ00<0cHDo0?oTh@3oi>401P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00<0
cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0
cHDo0?oTh@3oi>40cHDo1@3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3o
on1l0?ooh0@0cHDo10000?l00`000000onCQ0?oTh@020?oTh@8000001`3oi>400`3=QCl0onCQ0?oT
h@050?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>401P3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5
?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon1h0?ooh08000000P3oon040000o`80onCQ0P0000050?oTh@030<f5
?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5
?`3oi>40onCQ00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00H0
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5
?`D0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPL@3oon0200000080
oooP0P3=QCl00`000000003o0000o`020000o`030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3o
i>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3o
i>400P3oi>400`3=QCl0onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>400`3=
QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=
QCl0onCQ0?oTh@3=QCl50?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?oo
h700oooP100000040000o`<0000000<0onCQ0<f5?`3oi>401@3oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@020?oT
h@030<f5?`3oi>40onCQ00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40
onCQ00H0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40
onCQ0<f5?`D0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPK03oon02
00000080oooP10000?l20<f5?`80onCQ0P0000020?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo
0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo
0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3o
i>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103o
i>40103=QCl0onCQ0?oTh@3=QCl50?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon00
2@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh6/0oooP00<000000000o`000?l00P000?l00`3=QCl00000000000020?oTh@030<f5?`3o
i>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000o`3oon1T0?ooh080000000<0oooP0<f5?`000?l0
0`000?l300000080cHDo103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00D0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oo
h03oon001`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0
oooPH`3oon02000000<0003o103oi>4200000080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0
onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0
onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@060?oT
h@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl5
0?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh640oooP00@0cHDo0000
o`000?l0003o0P0000000`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo
0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo
0?oTh@3oi>401P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>401P3o
i>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo
1@3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1L0?ooh080000000@0
oooP0000o`000?l0003o0P3oi>42000000030?oTh@3=QCl0onCQ00L0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40
0`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>40
0P3oi>400`3=QCl0onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>400`3=QCl0
onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0
onCQ0?oTh@3=QCl50?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5/0
oooP0P0000020000o`80oooP00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@03
0<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@050?oTh@03
0<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>401P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00H0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ
00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00
oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00o`3oon1G0?ooh080000000@0oooP0000o`000?l0003o0P0000030<f5?`D0onCQ00<0cHDo
0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo
0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo
0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00H0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>400P3o
i>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00<0cHDo0?oTh@3oi>40
1P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP0?l0oooPD@3oon050<f5?`06000000000?l0003o0000o`3=QCl0
onCQ0P0000030?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0
onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>401@3oi>400`3=QCl0
onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oT
h@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oT
h@040<f5?`3oi>40onCQ0<f5?`D0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0oooP0?ooh009
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
0?l0oooPD@3oon000`3=QCl0onCQ0?oTh@030000o`<0000000<0cHDo0?oTh@3oi>40103oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=
QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00D0onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=
QCl0onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=
QCl50?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh4d0oooP0P000002
0?ooh0<0003o0`3oi>42000000030?oTh@3=QCl0onCQ00D0onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>40
0`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>40
0`3=QCl0onCQ0?oTh@050?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>401P3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oT
h@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>400`3=QCl0onCQ
0?oTh@060?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1<0?ooh0<000000P000?l00`3=QCl0onCQ0?oT
h@060?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oT
h@040?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oT
h@050?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>401P3oi>401@3=QCl0onCQ0?oT
h@3oi>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5
?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>400`3=QCl0onCQ0?oTh@060?oTh@03
0<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon1:0?ooh08000000`000?l00`000000cHDo0<f5?`080?oTh@030<f5
?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@050?oTh@030<f5
?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>401P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0
onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0
onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oon00oooP
00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on00o`3oon170?ooh080cHDo00<000000000o`000?l00`0000020?oTh@030<f5?`3oi>40onCQ00H0
onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00D0
onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oT
h@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oT
h@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo
0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh4@0oooP0P000000103oon00003o0000o`000?l3000000@0onCQ00<0cHDo
0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo
0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo
0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo
0?oTh@3oi>401@3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00H0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oTh@3oi>400P3o
i>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00<0cHDo0?oTh@3oi>40
1P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H>0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh400oooP0`3=QCl01@000000003o0000
o`000?l0cHDo0080onCQ0P0000000`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00H0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@040?oTh@030<f5?`3oi>40onCQ00@0onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ00D0onCQ
00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@060?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl01P3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3o
i>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@030<f5?`3oi>40onCQ00H0onCQ00<0cHDo0?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000
oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooP@03oon00103=QCl0onCQ0000o`000?l3
000000030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>400P3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@06
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>40103oi>400`3=QCl0onCQ0?oTh@04
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@05
0?oTh@030<f5?`3oi>40onCQ0080onCQ00<0cHDo0?oTh@3oi>401P3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00H0onCQ00<0cHDo0?oTh@3oi>401P3oi>400`3=QCl0onCQ0?oTh@020?oTh@030<f5?`3o
i>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>400`3=QCl0onCQ0?oTh@060?oTh@030<f5
?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@0
00000?ooh03oon0000001`3oon04000000P0oooPo`00000f000000<0003oV@0000080?ooh0@00000
6`3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV
0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00@0<j7:0:gHiP2]
f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]f>H2
0000o`030:gHiP0cXLX0oooP0:@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H20000o`<0[MSV00<0<j7:0?ooh03o
on00X`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP04
03>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030000
00030:gHiP000?l0003o00D0[MSV00<0<j7:0?ooh03oon00X`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP060:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H00000008000000P000?l803>QbZD0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H203>QbP<0003o0P00002]0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>Q
bPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV008000000P2]f>H20000o`040?oo
h0000000000000000:h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP04
03>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP0000000P0000020000o`0303>QbP3oon00oooP
0;40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]
f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0403>QbP2]f>H0[MSV
03>QbPD0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV0P0cXLX010000000003o0000o`00000203>Qb[<0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0403>QbP2]f>H0[MSV03>QbPD0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV0:gHiP80000000<0<j7:0000o`00
0?l00P00002f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>Q
bP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0100cXLX0
[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0102]f>H303>Q
bP8000000P000?nj0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP04
03>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0100c
XLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0oooP0?ooh0020000o`800000^P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV
0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00@0<j7:0000o`000?l0oooP0P00002k0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00P0000000`2]f>H0003o0000o`300?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV
00@0[MSV0P0cXLX200000080003o0P0cXL[00?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]
f>H0[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:
0?ooh0000?l0003o0P0000320?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:
0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP07
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0403>QbP2]
f>H0[MSV03>QbPD0[MSV00@0<j7:0:gHiP2]f>H0[MSV0P000000102]f>H0003o0000o`3oon020000
0<40oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00@0<j7:0:gHiP2]f>H0<j7:1@2]f>H3
03>QbP8000000P000?l00`0cXLX0oooP0?ooh0350?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>Q
bP2]f>H0[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP0303>QbP3oon00oooP0080003o0P00
00380?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0
[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0100cXLX0[MSV0:gH
iP0cXLX50:gHiP0403>QbP000?l0003o0?ooh0800000b@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP060:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P0000030:gHiP80003ocP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0000000000000`0000020000o`03
0:gHiP0cXLX0oooP0<d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP@0
00000P000?l403>Qb/h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP80
00000P000?l00`000000oooP0?ooh03A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0
[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H20000o`030000003oon00oooP0=<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:
0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]f>H0100cXLX0
[MSV0000000000020:gHiP80003o00<0<j7:0?ooh03oon00e@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP060:gH
iP0403>QbP000000000000000080003o0P2]f>H00`0cXLX0oooP0?ooh03E0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00H0[MSV00D0<j7:000000000?l0003o0000000403>Qb]L0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01P2]
f>H20000o`800000g03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP030000o`0cXLX0oooP0=h0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0603>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV0P0000020000o`030:gHiP0cXLX0oooP0=h0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0603>QbP2]f>H0[MSV0:gHiP0cXLX0
00000P000?l010000000<j7:03>QbP0cXL[O0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:
1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0403>QbP00000000000:gHiP80003o0`00003P0?ooh0<000006`3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0
<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP<0000000<0003o03>QbP3oon000P00003S0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@000000003o
0000o`000000<j7:0>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP8000000P000?l200000>P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H503>QbP80000000<0003o0000000cXLX0jP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0
[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP3oon00oooP0080oooP0P000?l200000>/0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0oooP0?ooh0020000o`030?ooh000000000000>`0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0003o0000o`3a0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0003o0?ooh03oon00l@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100c
XLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX000000000
002]f>H20000o`0303>QbP3oon00oooP0?40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP070:gHiP0303>QbP2]f>H0[MSV0080[MSV0`00000010000?l0[MSV0:gH
iP0cXL[c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]
f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01`2]
f>H00`0cXLX0[MSV0:gHiP0300000080003o00@0000003>QbP0cXLX0<j7:l`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00@0<j7:0:gHiP0000000000
0P000?l200000?L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0
<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP070:gHiP80<j7:00@000000000o`0000000000n@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100c
XLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00L0[MSV00<0<j7:0000o`000?l00P00003j0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H2000000030:gHiP000?l0
oooP0?d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX8
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV0P0000020000
o`0303>QbP3oon00oooP0?X0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0
[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP2]f>H403>QbP80
003o0P0000000`0cXLX0oooP0?ooh03l0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0
[MSV03>QbPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P3oon0010000?l0oooP00000000003o0?ooh040oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0
[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020000ool0oooP1@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV000000000000003o0?l0oooP1`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H01@0cXLX000000000o`000?l000000?l0oooP1`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0003o0000000200000?l0oooP1`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H010000?l0oooP00000000003o0?ooh0P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gH
iP2]f>H0<j7:1`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0000000000080003o00<0
<j7:0?ooh03oon00o`3oon090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>Q
bPL0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01`0cXLX00000000000000?l000000:gHiP0cXLX0o`3o
on0;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0
[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX000000000o`0200000080<j7:o`3oon0;0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gH
iP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00@0<j7:0:gHiP2]f>H0[MSV0P0000020000o`80
0000o`3oon0>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>Q
bP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV0`0c
XLX2000000030000o`000000oooP0?l0oooP403oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0
[MSV0:gHiP0cXLX70:gHiP0503>QbP3oon00oooP000000000?l00P00003o0?ooh140oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP100000070?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV
03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPL0[MSV00@0<j7:0?ooh000
0?l0003o0P00003o0?ooh180oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0
oooP00<000000?ooh03oon00203oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H01`2]
f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP0303>QbP000?l0oooP0?l0oooP5@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon000`000000oooP0?ooh0070?ooh0@00000203o
on000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:
202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H00`000?l0oooP0?ooh03o
0?ooh180oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3`3oon000`000000oooP0?ooh0060?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPD0
[MSV0P000?l00`0cXLX0oooP0?ooh03o0?ooh1D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP040000o`2]f>H0[MSV03>Qb_l0
oooP5`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P000000
0`2]f>H0003o0000o`030:gHiP0303>QbP3oon00oooP0?l0oooP5@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H00`0cXLX0[MSV00000002000000030000o`2]f>H0[MSV00<0[MSV00<0<j7:0?ooh03oon00
o`3oon0E0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]
f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX0202]f>H00`0cXLX0[MSV0:gHiP070:gHiP@0000000<0003o0000000cXLX01@0cXL[o0?oo
h1L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]
f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP080:gHiP0303>QbP2]f>H0[MSV00H0[MSV0`0000020000o`030000003oon00oooP0?l0oooP703o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0c
XLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H2000000030000o`000000<j7:0?l0oooP7`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H20000o`030000003oon00oooP0?l0oooP7`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`000?l0[MSV03>QbP3o0?ooh280oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP080:gHiP0303>QbP2]f>H0[MSV00<0[MSV0P000?l20:gH
iP0303>QbP3oon00oooP0?l0oooP803oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0[MSV0:gH
iP020:gHiP0303>QbP3oon00oooP0?l0oooP803oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00D0<j7:0:gHiP00000000000000o`050:gH
iP0303>QbP3oon00oooP0?l0oooP803oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00P0[MSV00D0<j7:000000000?l0003o0000000603>Qb_l0oooP
8P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gH
iP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00P0[MSV00<0<j7:0000o`0000000P00003o0?ooh2P0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP070:gHiP80003o00<0oooP000000000000o`3o
on0Y0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP060:gHiP03
0000o`2]f>H0<j7:0?l0oooP:P3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>Q
bP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H2000000050:gHiP000?l0[MSV0:gHiP0cXLX0o`3oon0/0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0603>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV0P0000020000
o`<0[MSV00<0<j7:0?ooh03oon00o`3oon0Z0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0403>QbP2]f>H0[MSV0:gHiP80<j7:00@000000000o`0000000000100cXL[o0?ooh2`0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:
202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP3oon00
003o00800000o`3oon0a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gH
iP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080000000<0003o0?ooh03oon00o`3oon0b0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H000000080003o00<000000?ooh03oon00o`3oon0b0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP80<j7:00@0003o0000000000000000o`3oon0d0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>Q
bPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP050:gHiP80000000@0003o0?ooh00000000000o`3o
on0e0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0
[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP040:gHiP04000000000?l0003o00000?l0
oooP>03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV
0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00@0[MSV1`0cXLX010000?l0000000000000003o0?ooh3P0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP3oon00oooP00<0oooP00@0003o0?ooh00000000000o`3oon0i0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0oooP0?ooh0020?ooh0030000o`3oon00oooP0?l0oooP>`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0?ooh03oon000P000?oo0?ooh3h0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP3oon00
003o0?l0oooP@03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100c
XLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0000o`3oon00o`3oon100?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP030000
o`3oon00oooP0?l0oooP?P3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]
f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0<j7:0?ooh03o0?ooh440oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020000
00030000o`2]f>H0<j7:0?l0oooP@P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H000000080003o00<000000:gHiP0cXLX0o`3oon12
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV
03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV0P0c
XLX010000?l0000000000000000203>Qb_l0oooP@P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP000?l0oooP00800000o`3oon150?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080000000<0003o0?oo
h03oon00o`3oon170?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP04
03>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP80<j7:0P000000
0`000?l000000?ooh03o0?ooh4P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00@0
<j7:0?ooh0000000003o0P00003o0?ooh4T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0?ooh0000?l00P00003o0?ooh4X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0000o`3oon00o`3oon1<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP030000o`3oon00oooP0?l0oooPC03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H20000o`0303>QbP3oon00oooP0?l0oooPC03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0
[MSV0P00000010000?l0[MSV0:gHiP0cXL[o0?ooh4h0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0
[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP<0<j7:0P000000
0`000?l0000003>QbP0203>Qb_l0oooPCP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0?ooh03oon000000
0000o`0200000?l0oooPD@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on03000000T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]
f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0oooP0?ooh0000?l200000?l0oooPD03oon030000
01/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H2
000000030?ooh0000?l0oooP0?l0oooPE03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV0:gHiP<0000000<0003o0?ooh03oon00
o`3oon1D0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]
f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080
[MSV100cXLX2000000030000o`000000oooP0?l0oooPE@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP3oon00oooP0080oooP00<0003o0000
003oon00o`3oon1F0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP04
03>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0?ooh03oon000P000?oo0?ooh5T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0000o`3o0?ooh5/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00@0<j7:0:gHiP2]f>H0[MSV0P0000000`000?l0
oooP0?ooh03o0?ooh5X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV0`0cXLX20000
00030000o`000000oooP0?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H0
1@0cXLX0oooP0?ooh0000000003o00800000o`3oon1L0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0403>QbP3oon00oooP0000o`800000o`3oon1M0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP050:gHiP0303>QbP3oon00003o0?l0oooPH03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:
0:gHiP2]f>H01@2]f>H00`0cXLX0003o0?ooh03o0?ooh600oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV0P0000000`2]f>H0003o0?ooh03o0?ooh640oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iPl0oooP0`0000060?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H403>QbP8000000P000?l00`0cXLX0oooP0?ooh03o0?ooh600oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQ00oooP00<000000?ooh03oon001@3oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gH
iP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00H0<j7:0?ooh03oon00oooP000000000?l200000?l0oooPH`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon05000000H0oooP100000080?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX8
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00D0<j7:0?ooh03oon00oooP0000o`0200000?l0oooPH@3oon04000001/0oooP
7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0
<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0403>QbP3oon00oooP0000ool0oooPI`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V3P3oon000`000000oooP000000070?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV
03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0oooP0000o`3o0?ooh6P0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iPl0oooP0P0000070?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0003o0?ooh03o0?ooh6P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP060:gHiP030000o`3oon00oooP0?l0
oooPJ03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV
0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00D0[MSV00<0003o03>QbP3oon00o`3oon1Y0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`000?l0[MSV03>QbP3o0?ooh6X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP040000o`2]f>H0[MSV03>Qb_l0oooP
JP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gH
iP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0003o0:gHiP2]f>H0[MSV03>QbP3o0?ooh6X0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV00D0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0[MSV00000000
0000003o00@0[MSV00<0<j7:0?ooh03oon00o`3oon1X0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP050:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:000000000000003o0000000503>Qb_l0
oooPJP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV
0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP000?l0003o00800000o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP05
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0003o0?ooh00000000000o`3oon1`0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0003o03>QbP3oon00
o`3oon1b0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]
f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0003o0:gHiP0cXLX0o`3oon1c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP000?l00P2]f>H00`0cXLX0oooP0?ooh03o0?ooh740oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H01@2]f>H0100cXLX0[MSV0:gHiP000?l30:gHiP0303>QbP3oon00oooP0?l0oooP
K`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`0cXLX0[MSV0:gHiP050:gHiP80000000<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0
oooP0?ooh03o0?ooh740oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV00@0[MSV0P0000000`00
0?l0000003>QbP0403>Qb_l0oooPL`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H2
000000030000o`00000000000?l0oooPN03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV1@0cXLX2000000030000o`00
000000000?l0oooPN@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0
100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0?ooh03oon000P3oon0010000000003o
00000000003o0?ooh7X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV
00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP3oon00oooP0080oooP00<0003o0000
00000000o`3oon1k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP04
03>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0oooP0?ooh03oon00003o0?l0oooPOP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0c
XLX80:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00@0<j7:0?ooh03oon00003oo`3oon1o0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0oooP0000o`3o0?ooh800oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0
[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP000?l0oooP0?l0oooPP03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX8
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00H0[MSV00<0003o0?ooh03oon00o`3oon200?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01@2]f>H00`000?l0<j7:
0?ooh03o0?ooh840oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0
<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP030000o`2]f>H0<j7:0?l0oooPPP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00@0003o0:gHiP2]f>H0<j7:o`3oon220?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P0000001@000?l0[MSV0:gH
iP2]f>H0<j7:0?l0oooPPP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on03000000T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]
f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0
[MSV0P0cXLX2000000030000o`000000<j7:00<0<j7:o`3oon200?ooh0<000006`3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0oooP000000000?l200000?l0oooPQP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX8
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP3o
on00003o00800000o`3oon270?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP07
0:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0000o`3oon00o`3oon290?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0003o0?ooh03oon00o`3oon290?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0003o03>Q
bP3oon00o`3oon2:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP04
03>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0703>QbP2]f>H0
0000000000000?l0[MSV03>QbP3o0?ooh8/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00D0<j7:000000000000003o0000000203>Qb_l0oooPR`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H00`0cXLX000000000o`0200000?l0oooPS@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H0100cXLX0003o00000000003o0?ooh8h0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0003o0?ooh03oon00o`3oon2?0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
1P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP030000o`0cXLX0oooP0?l0oooPT03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0903>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV0000o`2]f>H0<j7:0?l0oooPT@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP0303>QbP2]f>H0[MSV00800000
00@0003o0:gHiP2]f>H0<j7:o`3oon2A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0403>QbP2]f>H0[MSV03>QbPP0[MSV00H0<j7:0:gHiP00000000000000o`000003
03>Qb_l0oooPT@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100c
XLX0[MSV0:gHiP0cXLX80:gHiP0403>QbP2]f>H000000000o`800000o`3oon2D0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP06
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:202]f>H2000000030000o`00
000000000?l0oooPT`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0
[MSV03>QbPL0[MSV0P00000010000?l000000:gHiP0cXL[o0?ooh9D0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00@0<j7:0:gHiP2]f>H0<j7:1`2]f>H010000000003o
00000000000203>Qb_l0oooPU@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H0100cXLX0[MSV0:gHiP0cXLX80:gHiP030000o`000000oooP0?l0oooPU`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX70:gHiP03
0000o`0cXLX0oooP0?l0oooPV03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
1`2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP030000o`2]f>H0<j7:0?l0oooPV@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP04
0000o`2]f>H0[MSV03>Qb_l0oooPV@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01`2]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP050000o`2]f>H0[MSV0:gHiP0cXLX0o`3oon2I
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP070:gHiP0403>QbP2]f>H0[MSV
03>QbP<0[MSV00<0003o0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0?ooh03o0?ooh9L0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00<0<j7:0:gHiP2]f>H00P0000000`2]
f>H0003o0:gHiP040:gHiP0303>QbP3oon00oooP0?l0oooPU`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H01`2]f>H00`0cXLX0[MSV00000002000000030000o`2]f>H0[MSV00@0
[MSV00<0<j7:0?ooh03oon00o`3oon2G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP070:gHiP0603>QbP2]f>H00000000000000?l000001`0cXL[o0?ooh9T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV00D0<j7:0:gHiP2]f>H0003o0000003o0?oo
h:40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00L0[MSV0P0000000`000?l0
<j7:0?ooh03o0?ooh:40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP
0`0000080?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP060:gHiP80000000<0003o0000000cXLX0o`3oon2R0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00H0[MSV00@000000000o`000000
0000o`3oon2S0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000
003oon00oooP000000L0oooP100000080?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H01P2]f>H00`000?l000000000003o0?ooh:40oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V
3@3oon03000000P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00D0[MSV00<0003o0:gHiP0cXLX0o`3oon2U0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00oooP00L0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV0P0000000`000?l0[MSV03>Q
bP3o0?ooh:D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0`000007
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP80000000@0003o0000002]f>H0<j7:o`3oon2U0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H5
03>QbP04000000000?l0000000000080<j7:o`3oon2U0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0oooP0?ooh0020?ooh0030000o`00000000000?l0oooPZ03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0?ooh03oon00oooP0000o`3o0?ooh:/0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0403>QbP3oon00oooP0000ool0oooP[03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?oo
h0000?l0o`3oon2]0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0[MSV0P0000000`000?l0oooP0?ooh03o0?oo
h:`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP02000000030000o`000000oooP0?l0oooP[@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP<0<j7:
00@000000000o`0000000000o`3oon2^0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00H0<j7:0?ooh03oon00oooP0000o`00003o0?oo
h:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H0102]f>H0100cXLX0oooP0?ooh0000?oo0?ooh;40oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0oooP0000o`3o0?ooh;80
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0003o0?ooh03o0?ooh;80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP030000o`3oon00oooP0?l0oooP/03oon03000001/0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV0:gHiP80000000<0003o03>QbP3oon00o`3o
on2c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP<0<j7:0P000000
0`000?l0000003>QbP3o0?ooh;@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0?ooh03oon0000000000o`0200000?l0oooP]@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0oooP0?ooh0000?l200000?l0oooP]P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0oooP0?ooh0000?oo
0?ooh;P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?oo
h0000?l0o`3oon2i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP000?l0oooP0?l0oooP^@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0:gHiP2]f>H0
0P0000000`000?l0oooP0?ooh03o0?ooh;T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP80<j7:0P00
00000`000?l000000?ooh03o0?ooh;X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP060:gHiP0403>QbP3oon00
00000000o`800000o`3oon2k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H01@0cXLX0oooP0?ooh000
0?l000000?l0oooP_03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00H0[MSV00<0<j7:0?ooh0000?l0o`3oon2n
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H01P2]f>H00`0cXLX0003o0?ooh03o0?ooh;h0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP060:gHiP030000o`3oon00oooP0?l0oooP_P3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00D0[MSV
00<0003o03>QbP3oon00o`3oon2o0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0<000002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP80000000<0003o0:gHiP0cXLX0o`3o
on2n0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
100cXLX0[MSV0:gHiP2]f>H3000000030000o`2]f>H0<j7:0?l0oooP`03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP@0<j7:0P000000
10000?l0000003>QbP0cXL[o0?ooh<00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0oooP0?ooh0020?ooh0030000o`000000
oooP0?l0oooP`P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0503>QbP3oon00oooP0?ooh0000?l0o`3oon350?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0?oo
h03oon00003oo`3oon360?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0?ooh0000?l0o`3oon370?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0?ooh000
0?l0o`3oon370?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0000o`3oon00o`3oon370?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0003o0?ooh03oon00o`3o
on370?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0003o03>QbP3oon00o`3oon380?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0703>QbP2]f>H0[MSV0:gHiP000?l0[MSV03>QbP3o0?ooh<T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:000000000000003o0P2]
f>H00`0cXLX0oooP0?ooh03o0?ooh<L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV0`00000010000?l0[MSV0:gHiP0cXL[o0?ooh<T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV0P0000000`000?l0000003>QbP0203>Qb_l0oooPb@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0003o0000003o0?oo
h<d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh003
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0oooP0?ooh03o0?ooh</0
oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`000?l0<j7:0?ooh03o0?ooh<h0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV0:gHiP040:gHiP0703>QbP2]f>H0[MSV0:gHiP000?l0[MSV03>QbP3o0?ooh<l0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV0:gHiP040:gHiP0403>QbP00000000000000o`80[MSV00<0<j7:0?ooh03o
on00o`3oon3=0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H2000000030000o`000000<j7:0080<j7:
o`3oon3?0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP2]f>H0102]f>H2000000030000o`000000oooP0?l0oooPd@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0000o`000000o`3oon3C0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP2]f>H0102]f>H00`000?l0oooP0?ooh03o0?ooh=<0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00100cXLX0[MSV0:gHiP2]f>H20000
00030000o`0cXLX0oooP0?l0oooPe03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh0<0<j7:0P0000000`000?l0000003>QbP3o0?ooh=D0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
303oon0010000000003o00000000003o0?ooh=H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00303oon000`000?l000000000003o0?ooh=L0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00303o
on000`000?l0oooP0?ooh03o0?ooh=L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00/0oooP00<0003o0?ooh03oon00o`3oon3H
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP
000000L0oooP00<000000?ooh03oon002P3oon000`000?l0oooP0?ooh03o0?ooh=T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon04
000000P0oooP00<0003o0?ooh03oon00o`3oon3G0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`
iPh0oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP
0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0
oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP04X0oooP00<0
00000?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<0
00000?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon3o00000>X000006`3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=40n_3V100000020?[`iPP000000P3jl>H400000007
0?[`iP00000000000000003jl>H000000?[`iP0<000000030?[`iP000000000000@0000000@0n_3V
0000000000000000203jl>H5000000@0n_3V1`0000000`3jl>H000000?[`iP03000000P0n_3V1@00
00020?[`iP@000000P3jl>H5000000`0n_3V0`00000A0?[`iP<000001P3jl>H3000000040?[`iP00
00000000000000H0n_3V00<000000?[`iP3jl>H0103jl>H3000000040?[`iP000000000000000=P0
n_3V0@3oool00=80n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000030?[`iP070000
003jl>H000000000003jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000T0n_3V00@000000?[`iP3jl>H0n_3V0P000002
0?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V0P00
00030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80000000<0n_3V0000000000003`3j
l>H2000000030?[`iP000000000000H0n_3V0P0000000`3jl>H00000000000070?[`iP030000003j
l>H0n_3V00D0n_3V0P0000000`3jl>H000000000003I0?[`iP40oooo003B0?[`iP80000000<0n_3V
000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000003jl>H010000002
0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000=
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000003@3jl>H2000000030?[`iP00
0000000000D0n_3V1@0000050?[`iP80000000<0n_3V0000000000001`3jl>H3000000H0n_3V1@00
00060?[`iP<00000fP3jl>H10?ooo`00dP3jl>H5000000@0n_3V0P0000030?[`iPH0000000H0n_3V
000000000000n_3V0000003jl>H2000000030?[`iP000000000000<000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3jl>H2000000040?[`
iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP8000003@3jl>H2000000030?[`iP000000000000l0n_3V0P0000000`3jl>H0
0000000000070?[`iP<00000203jl>H00`000000n_3V0?[`iP060?[`iP<00000fP3jl>H10?ooo`00
dP3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P0000001P3jl>H00000
0000003jl>H000000?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000103jl>H000000000003jl>H2
000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H3
000000030?[`iP000000n_3V00X0n_3V0`00000@0?[`iP@000001`3jl>H2000000030?[`iP000000
000000L0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000=T0n_3V0@3oool0
0=80n_3V0P0000020?[`iP80000000<0n_3V0000000000000P0000040?[`iP@0000000<0n_3V0000
000000001@0000020?[`iP@000000P3jl>H500000080n_3V1@00000:0?[`iP8000001@3jl>H30000
00030?[`iP000000000000L000002P3jl>H500000080n_3V100000020?[`iP<0000000<0n_3V0000
000000002P3jl>H2000000030?[`iP000000000000l0n_3V0P0000080?[`iP<0000000@0n_3V0000
0000000000003@3jl>H3000000030?[`iP000000000000D00000e03jl>H10?ooo`00dP3jl>H20000
0080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0G0?[`iP8000006P3jl>H20000
00030?[`iP00000000000100n_3V0P00000S0?[`iP030000003jl>H0n_3V0=@0n_3V0@3oool00=40
n_3V1P0000040?[`iP800000;`3jl>H5000001X0n_3V0`00000I0?[`iP<000004P3jl>H300000280
n_3V00<000000?[`iP3jl>H0d`3jl>H10?ooo`00o`3jl>J30?[`iP030000003jl>H0n_3V0=80n_3V
0@3oool00?l0n_3VP03jl>H010000000n_3V0?[`iP00003D0?[`iP40oooo003o0?[`iX40n_3V0P00
003E0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .59371 L
.032 .59371 L
.032 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .59371 L
.032 .59371 L
.032 .08012 L
s
.678 .847 .902 r
.032 .08012 m
.032 .59219 L
.04557 .59219 L
.04557 .08012 L
F
.2 .63 .79 r
.032 .08012 m
.032 .59219 L
.04557 .59219 L
.04557 .08012 L
s
.678 .847 .902 r
.04557 .08012 m
.04557 .57509 L
.05206 .57509 L
.05206 .08012 L
F
.2 .63 .79 r
.04557 .08012 m
.04557 .57509 L
.05206 .57509 L
.05206 .08012 L
s
.678 .847 .902 r
.05206 .08012 m
.05206 .56803 L
.06623 .56803 L
.06623 .08012 L
F
.2 .63 .79 r
.05206 .08012 m
.05206 .56803 L
.06623 .56803 L
.06623 .08012 L
s
.678 .847 .902 r
.06623 .08012 m
.06623 .54386 L
.07666 .54386 L
.07666 .08012 L
F
.2 .63 .79 r
.06623 .08012 m
.06623 .54386 L
.07666 .54386 L
.07666 .08012 L
s
.678 .847 .902 r
.07666 .08012 m
.07666 .53018 L
.08712 .53018 L
.08712 .08012 L
F
.2 .63 .79 r
.07666 .08012 m
.07666 .53018 L
.08712 .53018 L
.08712 .08012 L
s
.678 .847 .902 r
.08712 .08012 m
.08712 .51932 L
.09708 .51932 L
.09708 .08012 L
F
.2 .63 .79 r
.08712 .08012 m
.08712 .51932 L
.09708 .51932 L
.09708 .08012 L
s
.678 .847 .902 r
.09708 .08012 m
.09708 .51537 L
.10468 .51537 L
.10468 .08012 L
F
.2 .63 .79 r
.09708 .08012 m
.09708 .51537 L
.10468 .51537 L
.10468 .08012 L
s
.678 .847 .902 r
.10468 .08012 m
.10468 .50523 L
.11139 .50523 L
.11139 .08012 L
F
.2 .63 .79 r
.10468 .08012 m
.10468 .50523 L
.11139 .50523 L
.11139 .08012 L
s
.678 .847 .902 r
.11139 .08012 m
.11139 .49579 L
.1165 .49579 L
.1165 .08012 L
F
.2 .63 .79 r
.11139 .08012 m
.11139 .49579 L
.1165 .49579 L
.1165 .08012 L
s
.678 .847 .902 r
.1165 .08012 m
.1165 .4855 L
.12723 .4855 L
.12723 .08012 L
F
.2 .63 .79 r
.1165 .08012 m
.1165 .4855 L
.12723 .4855 L
.12723 .08012 L
s
.678 .847 .902 r
.12723 .08012 m
.12723 .47427 L
.13494 .47427 L
.13494 .08012 L
F
.2 .63 .79 r
.12723 .08012 m
.12723 .47427 L
.13494 .47427 L
.13494 .08012 L
s
.678 .847 .902 r
.13494 .08012 m
.13494 .47112 L
.13993 .47112 L
.13993 .08012 L
F
.2 .63 .79 r
.13494 .08012 m
.13494 .47112 L
.13993 .47112 L
.13993 .08012 L
s
.678 .847 .902 r
.13993 .08012 m
.13993 .46614 L
.14693 .46614 L
.14693 .08012 L
F
.2 .63 .79 r
.13993 .08012 m
.13993 .46614 L
.14693 .46614 L
.14693 .08012 L
s
.678 .847 .902 r
.14693 .08012 m
.14693 .45807 L
.15156 .45807 L
.15156 .08012 L
F
.2 .63 .79 r
.14693 .08012 m
.14693 .45807 L
.15156 .45807 L
.15156 .08012 L
s
.678 .847 .902 r
.15156 .08012 m
.15156 .45359 L
.16236 .45359 L
.16236 .08012 L
F
.2 .63 .79 r
.15156 .08012 m
.15156 .45359 L
.16236 .45359 L
.16236 .08012 L
s
.678 .847 .902 r
.16236 .08012 m
.16236 .43905 L
.16907 .43905 L
.16907 .08012 L
F
.2 .63 .79 r
.16236 .08012 m
.16236 .43905 L
.16907 .43905 L
.16907 .08012 L
s
.678 .847 .902 r
.16907 .08012 m
.16907 .43586 L
.17357 .43586 L
.17357 .08012 L
F
.2 .63 .79 r
.16907 .08012 m
.16907 .43586 L
.17357 .43586 L
.17357 .08012 L
s
.678 .847 .902 r
.17357 .08012 m
.17357 .43096 L
.18331 .43096 L
.18331 .08012 L
F
.2 .63 .79 r
.17357 .08012 m
.17357 .43096 L
.18331 .43096 L
.18331 .08012 L
s
.678 .847 .902 r
.18331 .08012 m
.18331 .41765 L
.19256 .41765 L
.19256 .08012 L
F
.2 .63 .79 r
.18331 .08012 m
.18331 .41765 L
.19256 .41765 L
.19256 .08012 L
s
.678 .847 .902 r
.19256 .08012 m
.19256 .41307 L
.20556 .41307 L
.20556 .08012 L
F
.2 .63 .79 r
.19256 .08012 m
.19256 .41307 L
.20556 .41307 L
.20556 .08012 L
s
.678 .847 .902 r
.20556 .08012 m
.20556 .39861 L
.21433 .39861 L
.21433 .08012 L
F
.2 .63 .79 r
.20556 .08012 m
.20556 .39861 L
.21433 .39861 L
.21433 .08012 L
s
.678 .847 .902 r
.21433 .08012 m
.21433 .38317 L
.22464 .38317 L
.22464 .08012 L
F
.2 .63 .79 r
.21433 .08012 m
.21433 .38317 L
.22464 .38317 L
.22464 .08012 L
s
.678 .847 .902 r
.22464 .08012 m
.22464 .37681 L
.23037 .37681 L
.23037 .08012 L
F
.2 .63 .79 r
.22464 .08012 m
.22464 .37681 L
.23037 .37681 L
.23037 .08012 L
s
.678 .847 .902 r
.23037 .08012 m
.23037 .37518 L
.23957 .37518 L
.23957 .08012 L
F
.2 .63 .79 r
.23037 .08012 m
.23037 .37518 L
.23957 .37518 L
.23957 .08012 L
s
.678 .847 .902 r
.23957 .08012 m
.23957 .36583 L
.24939 .36583 L
.24939 .08012 L
F
.2 .63 .79 r
.23957 .08012 m
.23957 .36583 L
.24939 .36583 L
.24939 .08012 L
s
.678 .847 .902 r
.24939 .08012 m
.24939 .35289 L
.25758 .35289 L
.25758 .08012 L
F
.2 .63 .79 r
.24939 .08012 m
.24939 .35289 L
.25758 .35289 L
.25758 .08012 L
s
.678 .847 .902 r
.25758 .08012 m
.25758 .34554 L
.26377 .34554 L
.26377 .08012 L
F
.2 .63 .79 r
.25758 .08012 m
.25758 .34554 L
.26377 .34554 L
.26377 .08012 L
s
.678 .847 .902 r
.26377 .08012 m
.26377 .33927 L
.27716 .33927 L
.27716 .08012 L
F
.2 .63 .79 r
.26377 .08012 m
.26377 .33927 L
.27716 .33927 L
.27716 .08012 L
s
.678 .847 .902 r
.27716 .08012 m
.27716 .32782 L
.29115 .32782 L
.29115 .08012 L
F
.2 .63 .79 r
.27716 .08012 m
.27716 .32782 L
.29115 .32782 L
.29115 .08012 L
s
.678 .847 .902 r
.29115 .08012 m
.29115 .30939 L
.304 .30939 L
.304 .08012 L
F
.2 .63 .79 r
.29115 .08012 m
.29115 .30939 L
.304 .30939 L
.304 .08012 L
s
.678 .847 .902 r
.304 .08012 m
.304 .30054 L
.31721 .30054 L
.31721 .08012 L
F
.2 .63 .79 r
.304 .08012 m
.304 .30054 L
.31721 .30054 L
.31721 .08012 L
s
.678 .847 .902 r
.31721 .08012 m
.31721 .29579 L
.32827 .29579 L
.32827 .08012 L
F
.2 .63 .79 r
.31721 .08012 m
.31721 .29579 L
.32827 .29579 L
.32827 .08012 L
s
.678 .847 .902 r
.32827 .08012 m
.32827 .28079 L
.34154 .28079 L
.34154 .08012 L
F
.2 .63 .79 r
.32827 .08012 m
.32827 .28079 L
.34154 .28079 L
.34154 .08012 L
s
.678 .847 .902 r
.34154 .08012 m
.34154 .2754 L
.34805 .2754 L
.34805 .08012 L
F
.2 .63 .79 r
.34154 .08012 m
.34154 .2754 L
.34805 .2754 L
.34805 .08012 L
s
.678 .847 .902 r
.34805 .08012 m
.34805 .2653 L
.35794 .2653 L
.35794 .08012 L
F
.2 .63 .79 r
.34805 .08012 m
.34805 .2653 L
.35794 .2653 L
.35794 .08012 L
s
.678 .847 .902 r
.35794 .08012 m
.35794 .25814 L
.36839 .25814 L
.36839 .08012 L
F
.2 .63 .79 r
.35794 .08012 m
.35794 .25814 L
.36839 .25814 L
.36839 .08012 L
s
.678 .847 .902 r
.36839 .08012 m
.36839 .2523 L
.37905 .2523 L
.37905 .08012 L
F
.2 .63 .79 r
.36839 .08012 m
.36839 .2523 L
.37905 .2523 L
.37905 .08012 L
s
.678 .847 .902 r
.37905 .08012 m
.37905 .24347 L
.38532 .24347 L
.38532 .08012 L
F
.2 .63 .79 r
.37905 .08012 m
.37905 .24347 L
.38532 .24347 L
.38532 .08012 L
s
.678 .847 .902 r
.38532 .08012 m
.38532 .23635 L
.39903 .23635 L
.39903 .08012 L
F
.2 .63 .79 r
.38532 .08012 m
.38532 .23635 L
.39903 .23635 L
.39903 .08012 L
s
.678 .847 .902 r
.39903 .08012 m
.39903 .22616 L
.40716 .22616 L
.40716 .08012 L
F
.2 .63 .79 r
.39903 .08012 m
.39903 .22616 L
.40716 .22616 L
.40716 .08012 L
s
.678 .847 .902 r
.40716 .08012 m
.40716 .21777 L
.4177 .21777 L
.4177 .08012 L
F
.2 .63 .79 r
.40716 .08012 m
.40716 .21777 L
.4177 .21777 L
.4177 .08012 L
s
.678 .847 .902 r
.4177 .08012 m
.4177 .21416 L
.42884 .21416 L
.42884 .08012 L
F
.2 .63 .79 r
.4177 .08012 m
.4177 .21416 L
.42884 .21416 L
.42884 .08012 L
s
.678 .847 .902 r
.42884 .08012 m
.42884 .20325 L
.43769 .20325 L
.43769 .08012 L
F
.2 .63 .79 r
.42884 .08012 m
.42884 .20325 L
.43769 .20325 L
.43769 .08012 L
s
.678 .847 .902 r
.43769 .08012 m
.43769 .19769 L
.44745 .19769 L
.44745 .08012 L
F
.2 .63 .79 r
.43769 .08012 m
.43769 .19769 L
.44745 .19769 L
.44745 .08012 L
s
.678 .847 .902 r
.44745 .08012 m
.44745 .193 L
.4536 .193 L
.4536 .08012 L
F
.2 .63 .79 r
.44745 .08012 m
.44745 .193 L
.4536 .193 L
.4536 .08012 L
s
.678 .847 .902 r
.4536 .08012 m
.4536 .18996 L
.45883 .18996 L
.45883 .08012 L
F
.2 .63 .79 r
.4536 .08012 m
.4536 .18996 L
.45883 .18996 L
.45883 .08012 L
s
.678 .847 .902 r
.45883 .08012 m
.45883 .18768 L
.46634 .18768 L
.46634 .08012 L
F
.2 .63 .79 r
.45883 .08012 m
.45883 .18768 L
.46634 .18768 L
.46634 .08012 L
s
.678 .847 .902 r
.46634 .08012 m
.46634 .18109 L
.47128 .18109 L
.47128 .08012 L
F
.2 .63 .79 r
.46634 .08012 m
.46634 .18109 L
.47128 .18109 L
.47128 .08012 L
s
.678 .847 .902 r
.47128 .08012 m
.47128 .1756 L
.48223 .1756 L
.48223 .08012 L
F
.2 .63 .79 r
.47128 .08012 m
.47128 .1756 L
.48223 .1756 L
.48223 .08012 L
s
.678 .847 .902 r
.48223 .08012 m
.48223 .16596 L
.49388 .16596 L
.49388 .08012 L
F
.2 .63 .79 r
.48223 .08012 m
.48223 .16596 L
.49388 .16596 L
.49388 .08012 L
s
.678 .847 .902 r
.49388 .08012 m
.49388 .16424 L
.49959 .16424 L
.49959 .08012 L
F
.2 .63 .79 r
.49388 .08012 m
.49388 .16424 L
.49959 .16424 L
.49959 .08012 L
s
.678 .847 .902 r
.49959 .08012 m
.49959 .16089 L
.50577 .16089 L
.50577 .08012 L
F
.2 .63 .79 r
.49959 .08012 m
.49959 .16089 L
.50577 .16089 L
.50577 .08012 L
s
.678 .847 .902 r
.50577 .08012 m
.50577 .15604 L
.51735 .15604 L
.51735 .08012 L
F
.2 .63 .79 r
.50577 .08012 m
.50577 .15604 L
.51735 .15604 L
.51735 .08012 L
s
.678 .847 .902 r
.51735 .08012 m
.51735 .15062 L
.53077 .15062 L
.53077 .08012 L
F
.2 .63 .79 r
.51735 .08012 m
.51735 .15062 L
.53077 .15062 L
.53077 .08012 L
s
.678 .847 .902 r
.53077 .08012 m
.53077 .14037 L
.53788 .14037 L
.53788 .08012 L
F
.2 .63 .79 r
.53077 .08012 m
.53077 .14037 L
.53788 .14037 L
.53788 .08012 L
s
.678 .847 .902 r
.53788 .08012 m
.53788 .13802 L
.54764 .13802 L
.54764 .08012 L
F
.2 .63 .79 r
.53788 .08012 m
.53788 .13802 L
.54764 .13802 L
.54764 .08012 L
s
.678 .847 .902 r
.54764 .08012 m
.54764 .12856 L
.56057 .12856 L
.56057 .08012 L
F
.2 .63 .79 r
.54764 .08012 m
.54764 .12856 L
.56057 .12856 L
.56057 .08012 L
s
.678 .847 .902 r
.56057 .08012 m
.56057 .12104 L
.57187 .12104 L
.57187 .08012 L
F
.2 .63 .79 r
.56057 .08012 m
.56057 .12104 L
.57187 .12104 L
.57187 .08012 L
s
.678 .847 .902 r
.57187 .08012 m
.57187 .12033 L
.58371 .12033 L
.58371 .08012 L
F
.2 .63 .79 r
.57187 .08012 m
.57187 .12033 L
.58371 .12033 L
.58371 .08012 L
s
.678 .847 .902 r
.58371 .08012 m
.58371 .10983 L
.59763 .10983 L
.59763 .08012 L
F
.2 .63 .79 r
.58371 .08012 m
.58371 .10983 L
.59763 .10983 L
.59763 .08012 L
s
.678 .847 .902 r
.59763 .08012 m
.59763 .1061 L
.60429 .1061 L
.60429 .08012 L
F
.2 .63 .79 r
.59763 .08012 m
.59763 .1061 L
.60429 .1061 L
.60429 .08012 L
s
.678 .847 .902 r
.60429 .08012 m
.60429 .1026 L
.61372 .1026 L
.61372 .08012 L
F
.2 .63 .79 r
.60429 .08012 m
.60429 .1026 L
.61372 .1026 L
.61372 .08012 L
s
.678 .847 .902 r
.61372 .08012 m
.61372 .0964 L
.62646 .0964 L
.62646 .08012 L
F
.2 .63 .79 r
.61372 .08012 m
.61372 .0964 L
.62646 .0964 L
.62646 .08012 L
s
.678 .847 .902 r
.62646 .08012 m
.62646 .08992 L
.63663 .08992 L
.63663 .08012 L
F
.2 .63 .79 r
.62646 .08012 m
.62646 .08992 L
.63663 .08992 L
.63663 .08012 L
s
.678 .847 .902 r
.63663 .08012 m
.63663 .08682 L
.64738 .08682 L
.64738 .08012 L
F
.2 .63 .79 r
.63663 .08012 m
.63663 .08682 L
.64738 .08682 L
.64738 .08012 L
s
.678 .847 .902 r
.64738 .08012 m
.64738 .08463 L
.66029 .08463 L
.66029 .08012 L
F
.2 .63 .79 r
.64738 .08012 m
.64738 .08463 L
.66029 .08463 L
.66029 .08012 L
s
1 .894 .882 r
.66029 .08012 m
.66029 .07725 L
.66857 .07725 L
.66857 .08012 L
F
.804 .522 .247 r
.66029 .08012 m
.66029 .07725 L
.66857 .07725 L
.66857 .08012 L
s
1 .894 .882 r
.66857 .08012 m
.66857 .07585 L
.67337 .07585 L
.67337 .08012 L
F
.804 .522 .247 r
.66857 .08012 m
.66857 .07585 L
.67337 .07585 L
.67337 .08012 L
s
1 .894 .882 r
.67337 .08012 m
.67337 .07132 L
.68235 .07132 L
.68235 .08012 L
F
.804 .522 .247 r
.67337 .08012 m
.67337 .07132 L
.68235 .07132 L
.68235 .08012 L
s
1 .894 .882 r
.68235 .08012 m
.68235 .06854 L
.69442 .06854 L
.69442 .08012 L
F
.804 .522 .247 r
.68235 .08012 m
.68235 .06854 L
.69442 .06854 L
.69442 .08012 L
s
1 .894 .882 r
.69442 .08012 m
.69442 .06527 L
.69958 .06527 L
.69958 .08012 L
F
.804 .522 .247 r
.69442 .08012 m
.69442 .06527 L
.69958 .06527 L
.69958 .08012 L
s
1 .894 .882 r
.69958 .08012 m
.69958 .06215 L
.71405 .06215 L
.71405 .08012 L
F
.804 .522 .247 r
.69958 .08012 m
.69958 .06215 L
.71405 .06215 L
.71405 .08012 L
s
1 .894 .882 r
.71405 .08012 m
.71405 .05847 L
.72671 .05847 L
.72671 .08012 L
F
.804 .522 .247 r
.71405 .08012 m
.71405 .05847 L
.72671 .05847 L
.72671 .08012 L
s
1 .894 .882 r
.72671 .08012 m
.72671 .05429 L
.73151 .05429 L
.73151 .08012 L
F
.804 .522 .247 r
.72671 .08012 m
.72671 .05429 L
.73151 .05429 L
.73151 .08012 L
s
1 .894 .882 r
.73151 .08012 m
.73151 .05305 L
.74558 .05305 L
.74558 .08012 L
F
.804 .522 .247 r
.73151 .08012 m
.73151 .05305 L
.74558 .05305 L
.74558 .08012 L
s
1 .894 .882 r
.74558 .08012 m
.74558 .04881 L
.75826 .04881 L
.75826 .08012 L
F
.804 .522 .247 r
.74558 .08012 m
.74558 .04881 L
.75826 .04881 L
.75826 .08012 L
s
1 .894 .882 r
.75826 .08012 m
.75826 .0442 L
.76373 .0442 L
.76373 .08012 L
F
.804 .522 .247 r
.75826 .08012 m
.75826 .0442 L
.76373 .0442 L
.76373 .08012 L
s
1 .894 .882 r
.76373 .08012 m
.76373 .04329 L
.76972 .04329 L
.76972 .08012 L
F
.804 .522 .247 r
.76373 .08012 m
.76373 .04329 L
.76972 .04329 L
.76972 .08012 L
s
1 .894 .882 r
.76972 .08012 m
.76972 .0413 L
.78108 .0413 L
.78108 .08012 L
F
.804 .522 .247 r
.76972 .08012 m
.76972 .0413 L
.78108 .0413 L
.78108 .08012 L
s
1 .894 .882 r
.78108 .08012 m
.78108 .03785 L
.78839 .03785 L
.78839 .08012 L
F
.804 .522 .247 r
.78108 .08012 m
.78108 .03785 L
.78839 .03785 L
.78839 .08012 L
s
1 .894 .882 r
.78839 .08012 m
.78839 .03739 L
.79555 .03739 L
.79555 .08012 L
F
.804 .522 .247 r
.78839 .08012 m
.78839 .03739 L
.79555 .03739 L
.79555 .08012 L
s
1 .894 .882 r
.79555 .08012 m
.79555 .03487 L
.80486 .03487 L
.80486 .08012 L
F
.804 .522 .247 r
.79555 .08012 m
.79555 .03487 L
.80486 .03487 L
.80486 .08012 L
s
1 .894 .882 r
.80486 .08012 m
.80486 .03288 L
.81899 .03288 L
.81899 .08012 L
F
.804 .522 .247 r
.80486 .08012 m
.80486 .03288 L
.81899 .03288 L
.81899 .08012 L
s
1 .894 .882 r
.81899 .08012 m
.81899 .03047 L
.82701 .03047 L
.82701 .08012 L
F
.804 .522 .247 r
.81899 .08012 m
.81899 .03047 L
.82701 .03047 L
.82701 .08012 L
s
1 .894 .882 r
.82701 .08012 m
.82701 .02857 L
.8319 .02857 L
.8319 .08012 L
F
.804 .522 .247 r
.82701 .08012 m
.82701 .02857 L
.8319 .02857 L
.8319 .08012 L
s
1 .894 .882 r
.8319 .08012 m
.8319 .02806 L
.8464 .02806 L
.8464 .08012 L
F
.804 .522 .247 r
.8319 .08012 m
.8319 .02806 L
.8464 .02806 L
.8464 .08012 L
s
1 .894 .882 r
.8464 .08012 m
.8464 .02499 L
.85218 .02499 L
.85218 .08012 L
F
.804 .522 .247 r
.8464 .08012 m
.8464 .02499 L
.85218 .02499 L
.85218 .08012 L
s
1 .894 .882 r
.85218 .08012 m
.85218 .02418 L
.86464 .02418 L
.86464 .08012 L
F
.804 .522 .247 r
.85218 .08012 m
.85218 .02418 L
.86464 .02418 L
.86464 .08012 L
s
1 .894 .882 r
.86464 .08012 m
.86464 .02273 L
.8734 .02273 L
.8734 .08012 L
F
.804 .522 .247 r
.86464 .08012 m
.86464 .02273 L
.8734 .02273 L
.8734 .08012 L
s
1 .894 .882 r
.8734 .08012 m
.8734 .02156 L
.87939 .02156 L
.87939 .08012 L
F
.804 .522 .247 r
.8734 .08012 m
.8734 .02156 L
.87939 .02156 L
.87939 .08012 L
s
1 .894 .882 r
.87939 .08012 m
.87939 .02077 L
.89151 .02077 L
.89151 .08012 L
F
.804 .522 .247 r
.87939 .08012 m
.87939 .02077 L
.89151 .02077 L
.89151 .08012 L
s
1 .894 .882 r
.89151 .08012 m
.89151 .01922 L
.90356 .01922 L
.90356 .08012 L
F
.804 .522 .247 r
.89151 .08012 m
.89151 .01922 L
.90356 .01922 L
.90356 .08012 L
s
1 .894 .882 r
.90356 .08012 m
.90356 .01786 L
.91795 .01786 L
.91795 .08012 L
F
.804 .522 .247 r
.90356 .08012 m
.90356 .01786 L
.91795 .01786 L
.91795 .08012 L
s
1 .894 .882 r
.91795 .08012 m
.91795 .01659 L
.9265 .01659 L
.9265 .08012 L
F
.804 .522 .247 r
.91795 .08012 m
.91795 .01659 L
.9265 .01659 L
.9265 .08012 L
s
1 .894 .882 r
.9265 .08012 m
.9265 .01597 L
.93784 .01597 L
.93784 .08012 L
F
.804 .522 .247 r
.9265 .08012 m
.9265 .01597 L
.93784 .01597 L
.93784 .08012 L
s
1 .894 .882 r
.93784 .08012 m
.93784 .0153 L
.95005 .0153 L
.95005 .08012 L
F
.804 .522 .247 r
.93784 .08012 m
.93784 .0153 L
.95005 .0153 L
.95005 .08012 L
s
1 .894 .882 r
.95005 .08012 m
.95005 .01515 L
.95616 .01515 L
.95616 .08012 L
F
.804 .522 .247 r
.95005 .08012 m
.95005 .01515 L
.95616 .01515 L
.95616 .08012 L
s
1 .894 .882 r
.95616 .08012 m
.95616 .01497 L
.9643 .01497 L
.9643 .08012 L
F
.804 .522 .247 r
.95616 .08012 m
.95616 .01497 L
.9643 .01497 L
.9643 .08012 L
s
1 .894 .882 r
.9643 .08012 m
.9643 .01475 L
.97619 .01475 L
.97619 .08012 L
F
.804 .522 .247 r
.9643 .08012 m
.9643 .01475 L
.97619 .01475 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.03162 .59371 Mdot
.03285 .59219 Mdot
.04693 .57509 Mdot
.0528 .56803 Mdot
.07319 .54386 Mdot
.08494 .53018 Mdot
.09438 .51932 Mdot
.09784 .51537 Mdot
.10678 .50523 Mdot
.11519 .49579 Mdot
.12445 .4855 Mdot
.13467 .47427 Mdot
.13755 .47112 Mdot
.14214 .46614 Mdot
.14963 .45807 Mdot
.15381 .45359 Mdot
.16755 .43905 Mdot
.1706 .43586 Mdot
.1753 .43096 Mdot
.18821 .41765 Mdot
.1927 .41307 Mdot
.20706 .39861 Mdot
.22268 .38317 Mdot
.2292 .37681 Mdot
.23089 .37518 Mdot
.24062 .36583 Mdot
.2543 .35289 Mdot
.26219 .34554 Mdot
.26899 .33927 Mdot
.28157 .32782 Mdot
.30233 .30939 Mdot
.31252 .30054 Mdot
.31806 .29579 Mdot
.33586 .28079 Mdot
.34238 .2754 Mdot
.35478 .2653 Mdot
.36372 .25814 Mdot
.37112 .2523 Mdot
.38247 .24347 Mdot
.39178 .23635 Mdot
.40537 .22616 Mdot
.41682 .21777 Mdot
.42181 .21416 Mdot
.43718 .20325 Mdot
.4452 .19769 Mdot
.45204 .193 Mdot
.45653 .18996 Mdot
.45992 .18768 Mdot
.46986 .18109 Mdot
.47827 .1756 Mdot
.49342 .16596 Mdot
.49617 .16424 Mdot
.50158 .16089 Mdot
.50951 .15604 Mdot
.51856 .15062 Mdot
.53615 .14037 Mdot
.54028 .13802 Mdot
.55735 .12856 Mdot
.57142 .12104 Mdot
.57276 .12033 Mdot
.59335 .10983 Mdot
.60093 .1061 Mdot
.60819 .1026 Mdot
.62141 .0964 Mdot
.63575 .08992 Mdot
.64286 .08682 Mdot
.64796 .08463 Mdot
.66576 .07725 Mdot
.66926 .07585 Mdot
.68085 .07132 Mdot
.6882 .06854 Mdot
.69708 .06527 Mdot
.70584 .06215 Mdot
.71651 .05847 Mdot
.72923 .05429 Mdot
.73313 .05305 Mdot
.74698 .04881 Mdot
.76303 .0442 Mdot
.76633 .04329 Mdot
.77381 .0413 Mdot
.7874 .03785 Mdot
.78925 .03739 Mdot
.79996 .03487 Mdot
.80888 .03288 Mdot
.82037 .03047 Mdot
.83006 .02857 Mdot
.83277 .02806 Mdot
.85033 .02499 Mdot
.85539 .02418 Mdot
.86504 .02273 Mdot
.87349 .02156 Mdot
.87963 .02077 Mdot
.89287 .01922 Mdot
.90662 .01786 Mdot
.92249 .01659 Mdot
.93221 .01597 Mdot
.94615 .0153 Mdot
.95016 .01515 Mdot
.95621 .01497 Mdot
.96892 .01475 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0456937) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.01445) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000030?[`iPH000000P3jl>H4000000<0n_3V100000030?[`iP<0
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0
n_3V000000000000103jl>H2000000D0n_3V0P0000050?[`iP8000000`3jl>H00`000000n_3V0?[`
iP0200000?l0n_3VX`3jl>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P000003
0?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H2000000030?[`iP000000n_3V00800000603jl>H2000000030?[`iP00
0000000000T0n_3V0P0000000`3jl>H00000000000040?[`iP8000000P3jl>H6000000030?[`iP00
0000000000@000001@3jl>H200000?l0n_3VX`3jl>H10?ooo`00803jl>H5000000@0n_3V0P000003
0?[`iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<00000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<00000
0`3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD0
00002P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000040?[`iP80
00000P3jl>H00`000000n_3V0?[`iP0200000080n_3V00<000000?[`iP3jl>H00P0000060?[`iP80
0000o`3jl>JS0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP@000002P3jl>H2
000000030?[`iP000000000000@0n_3V0P0000030?[`iP040000003jl>H00000000000<0n_3V00@0
00000?[`iP00000000000`3jl>H00`000000n_3V0?[`iP0200000?l0n_3VX`3jl>H10?ooo`00803j
l>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3jl>H000000000
000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0
n_3V0000000000001`00000I0?[`iP800000303jl>H2000000030?[`iP000000000000@0n_3V0P00
00030?[`iP040000003jl>H00000000000<0n_3V00@000000?[`iP00000000000`3jl>H400000?l0
n_3VY03jl>H10?ooo`00803jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V
0?[`iP0V0?[`iP8000002`3jl>H2000000030?[`iP00000000000080n_3V100000040?[`iP<00000
103jl>H3000000<0n_3V0P00003o0?[`iZH0n_3V0@3oool001l0n_3V1P0000040?[`iP800000;`3j
l>H5000002T0n_3V0`00000:0?[`iP<000001@3jl>H2000000D0n_3V0P0000050?[`iP8000000`3j
l>H500000?l0n_3VX`3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V0P00
003o0?[`i_l0n_3V5`3jl>H10?ooo`00803jl>H6000000050?[`iP00000000000000003jl>H00`00
00020?[`iP<000000`3jl>H4000000<0n_3V0P000000103jl>H000000000003jl>H5000000<0n_3V
3000000_0?[`iP<00000103jl>H200000?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0n_3V0P00
00000`3jl>H00000000000020?[`iP8000000P3jl>H010000000n_3V0000000000030?[`iP050000
003jl>H000000000003jl>H00`0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP80
00008P3jl>H5000000T0n_3V0P0000000`3jl>H00000000000030?[`iP800000o`3jl>K90?[`iP40
oooo000R0?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP800000
1@3jl>H200000080n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP800000
<03jl>H2000000030?[`iP00000000000?l0n_3VcP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P00
00000`3jl>H00000000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P00
00020?[`iP8000001@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP00
000000000?l0n_3VcP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H0000000000002
0?[`iP800000103jl>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V0`00
00000`3jl>H000000?[`iP040?[`iP8000000`3jl>H200000300n_3V1000003o0?[`i/l0n_3V0@3o
ool00280n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V100000030?[`iP80000000<0n_3V
000000000000100000000`3jl>H00000000000020?[`iP@00000103jl>H200000300n_3V0P00003o
0?[`i]40n_3V0@3oool00280n_3V0P00000;0?[`iP8000008P3jl>H200000340n_3V0P00003o0?[`
i]00n_3V0@3oool00200n_3V1P0000090?[`iP800000803jl>H400000380n_3V0`00003o0?[`i/h0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V00000000
0000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`iP03
0000003jl>H0n_3V00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H00000
00000002000000050?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H0000001T0
n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080
n_3V1P0000020?[`iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V100000000`3j
l>H00000000000020?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H000000?[`
iP03000001P0n_3V0`0000040?[`iP8000001@3jl>H3000000@0n_3V100000030?[`iP<00000103j
l>H3000000<0n_3V0`0000050?[`iP<000001@3jl>H200000780n_3V0@3oool00240n_3V0P000000
0`3jl>H0000000000005000000040?[`iP000000000000000080n_3V0P0000000`3jl>H000000000
00090?[`iPD000002@3jl>H00`000000n_3V0?[`iP0200000=`0n_3V0P0000040?[`iP8000000P3j
l>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V
0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80
000000<0n_3V0000000000002P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80
00000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80
000000<0n_3V0000000000000`3jl>H2000000@0n_3V0P0000000`3jl>H00000000000040?[`iP80
00000`3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H00000000000040?[`iP80
00000`3jl>H00`000000n_3V0?[`iP02000000@0n_3V0P00001b0?[`iP40oooo000R0?[`iP<00000
:`3jl>H200000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP800000
1P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP800000
00<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000003jl>H00P0000020?[`iP80
00000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H0
0000000000090?[`iP80000000@0n_3V000000000000n_3V1P0000050?[`iP8000000P3jl>H20000
00030?[`iP000000000000D0n_3V0P0000050?[`iP800000103jl>H200000780n_3V0@3oool00280
n_3V0`00000J0?[`iPD00000303jl>H200000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0
n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP020000
0080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H50000
00X0n_3V0P0000000`3jl>H00000000000090?[`iP80000000D0n_3V000000000000n_3V00000002
0?[`iP8000001P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP@000001@3jl>H2
000000@0n_3V0P00001b0?[`iP40oooo000Q0?[`iP80000000<0n_3V000000000000:03jl>H30000
0=d0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V
0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P000002
0?[`iP80000000<0n_3V0000000000002P3jl>H3000000040?[`iP00000000000?[`iP8000000P3j
l>H200000080n_3V0`0000000`3jl>H000000?[`iP02000000030?[`iP000000n_3V00800000603j
l>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP040000003j
l>H00000000000<0n_3V00<000000?[`iP3jl>H00P0000020?[`iP@000000`3jl>H2000000030?[`
iP000000000000<0n_3V0`0000060?[`iP800000L@3jl>H10?ooo`00803jl>H3000000040?[`iP00
00000000000002T0n_3V0P00003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V
0`000000103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0
n_3V100000020?[`iPD000002`3jl>H3000000030?[`iP00000000000080n_3V100000020?[`iP<0
000000<0n_3V0000000000001`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H200000003
0?[`iP00000000000080n_3V00@000000?[`iP00000000000`3jl>H4000000<0n_3V0P0000050?[`
iP80000000<0n_3V0000000000001@3jl>H2000000D0n_3V0P00001a0?[`iP40oooo001=0?[`iP03
0000003jl>H0n_3V00800000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP80
00008P3jl>H200000080n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H200000003
0?[`iP000000000000<0n_3V0`0000030?[`iP8000001P3jl>H2000000@0n_3V0P0000000`3jl>H0
0000000000020?[`iP030000003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`iP0200000740
n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP800000
1P3jl>H2000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000;0?[`iP<00000
1@3jl>H2000000<0n_3V1@0000040?[`iP<000000`3jl>H3000000@0n_3V0`0000030?[`iPD00000
L@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H0200000000`3jl>H000000000003o0?[`i_l0
n_3V8`3jl>H10?ooo`009`3jl>H01@000000n_3V0000003jl>H000000080n_3V00@000000?[`iP3j
l>H000000P3jl>H00`000000n_3V0?[`iP3o0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H300000003
0?[`iP00000000000080000000@0n_3V0000003jl>H000000P3jl>H010000000n_3V0?[`iP000002
0?[`iP030000003jl>H0n_3V01L0n_3V0`00003L0?[`iP@00000103jl>H;000000@0n_3V0`000002
0?[`iPH000000`3jl>H300000080n_3V1P0000020?[`iP@000000P3jl>H3000000030?[`iP000000
000000H000006P3jl>H600000080n_3V0`0000040?[`iP<00000^P3jl>H10?ooo`008@3jl>H20000
00030?[`iP000000000000D0000000D0n_3V00000000000000000?[`iP04000000/0n_3V1@000009
0?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2
000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@0
00000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H00000
0000003jl>H200000080n_3V0P00000;0?[`iPD000002`3jl>H2000000<0n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000^@3jl>H10?ooo`008P3jl>H3000002P0n_3V
0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP800000
1@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP800000
0P3jl>H2000000030?[`iP000000000000<0n_3V1000000K0?[`iP8000000`3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H000000000002i0?[`iP40oooo000R0?[`iP<000002@3j
l>H00`000000n_3V0?[`iP0>0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V1000
00030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00
00030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H4000000d0n_3V
1@00000;0?[`iP8000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
0000002i0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000009`3jl>H2000000030?[`iP00
000000000=`0n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H3000000040?[`iP00
0000n_3V0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V
0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000006`3jl>H2000000<0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000^@3jl>H10?ooo`00
803jl>H3000000040?[`iP0000000000000002H0n_3V0P0000000`3jl>H000000000003L0?[`iP80
000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000103jl>H000000000003jl>H50000
0080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V100000020?[`iPD000000`3jl>H50000
01/0n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0;T0n_3V0@3oool004d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V00000000
0000403jl>H2000000`0n_3V0P00000h0?[`iP@000000`3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H000000000002i0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V
0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000b0?[`iP800000103jl>H3000000@0n_3V
0`00002j0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`007@3jl>HS0?ooh0800000A@3oon02000000@0oooP0P0000040?ooh0800000A03oon05000004<0
oooP1@0000020?ooh0800000103oon02000004@0oooP100000140?ooh0@000000`3oon02000000@0
oooP0P0000150?ooh08000009`3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon00
0000@`3oon0010000000oooP0?ooh00000080?ooh0040000003oon00oooP000004D0oooP00<00000
0?ooh03oon00A@3oon000`000000oooP0?ooh0070?ooh0040000003oon00oooP000004<0oooP00<0
00000?ooh03oon00A@3oon000`000000oooP0?ooh0090?ooh0040000003oon00oooP000004<0oooP
00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon00
0000@`3oon0010000000oooP0?ooh000000;0?ooh0030000003oon00oooP04<0oooP00<000000?oo
h03oon00A@3oon000`000000oooP0?ooh00:0?ooh0030000003oon00oooP0480oooP00<000000?oo
h03oon00A@3oon000`000000oooP0?ooh00;0?ooh0030000003oon00oooP04<0oooP00<000000?oo
h03oon009@3oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon001000
0000oooP0?ooh00000090?ooh0800000AP3oon000`000000oooP0?ooh0150?ooh0030000003oon00
oooP00P0oooP0P0000160?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00203oon02
000004L0oooP00<000000?ooh03oon00903oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?oo
h03oon000000@`3oon0010000000oooP0?ooh00000090?ooh0030000003oon00oooP04D0oooP00<0
00000?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP04<0oooP00@0
00000?ooh03oon000000A03oon0010000000oooP0?ooh00000090?ooh0030000003oon00oooP04<0
oooP00@000000?ooh03oon0000009P3oon0N0?[`iP40oooo000M0?[`iR<0oooP0P0000150?ooh080
00002P3oon03000004@0oooP0P0000160?ooh08000002P3oon03000004@0oooP0P0000160?ooh080
00002P3oon03000004@0oooP0P00000W0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
iQP0oooPo`00003Z000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0
oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00
3@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00
303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00
3@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00
3@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00
303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00
3@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00
303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00
3@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00
303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00
303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?oo
h01:0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?oo
h01:0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?oo
h0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00o`3oon3;0?ooh0@0000000<0oooP000000000000103oon02000000h0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon2o0?ooh08000000`3oon02000000@0oooP2@0000020?ooh0@000003@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon0300000?l0oooP/@3oon02000000D0oooP0P00
00040?ooh0<000006P000?l90?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon00o`3oon2W0?ooh080000000<0oooP000000000000103oon04000000<0oooP0P000008
0000o`030000003=QCl0000000<0000000@0cHDo0?oTh@3oi>40onCQ100000000`3oi>4000000000
00020?oTh@040<f5?`3oi>40000000000080onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh:<0oooP0P00
00000`3oon00000000000005000000<0oooP2@000?l2000000<0onCQ00H0cHDo000000000000onCQ
0<f5?`3oi>42000000030?oTh@3=QCl0onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2L0?ooh080000000@0oooP00000000
0000oooP1000000:0000o`030<f5?`000000000000@0onCQ00<0cHDo000000000000103oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=
QCl30?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh9/0oooP0`000008
0000o`040?oTh@00000000000?oTh@8000001@3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3o
i>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ
00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oon00oooP00T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon2B0?ooh0@000000P3oon060000o`@0000000<0onCQ0000000000000`3oi>40103=QCl0onCQ
0?oTh@3=QCl50?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl3
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh8h0oooP0P0000000`3o
on00003o0000o`050000o`@0cHDo0P0000000`3=QCl00000000000030?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo
0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400`3o
i>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?ooh03oon00
2@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh8P0oooP0P0000020?ooh0D0003o1P0000040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3o
i>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=
QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0?l0oooPQ03oon02000000030<f5?`000000003o00<0003o00<0cHDo0000
000000000P0000000`3=QCl0000000000002000000D0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5
?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon1m0?ooh0<000000P3oon000`3=QCl000000000o`030000o`<00000
0P3oi>401@3=QCl000000000003oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0
onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@03
0?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5
?`3oi>40onCQ00<0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh7`0oooP100000040000o`<0000000<0
onCQ0000000000000`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40
103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=
QCl30?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh7L0oooP0P000002
0?ooh0030<f5?`000?l0003o0080003o00@000000<f5?`3=QCl0onCQ0P0000000`3=QCl0onCQ0?oT
h@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5
?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ
00<0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ
0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0
cHDo0?oTh@3oi>400`3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPLP3oon03000000030?ooh0000000
000000@0003o00@0onCQ00000000000000000P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3o
i>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ
0?oTh@030?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1a0?ooh0<0000010000?l200000080cHDo0P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo00<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh700oooP10000?l2000000030?oTh@00000000000080onCQ00@0
cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00D0cHDo0?oTh@3o
i>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>40
1@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oT
h@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5
?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@030?oTh@03
0<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon1Z0?ooh080000010000?l00`3=QCl0onCQ00000002000000030<f5
?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo
0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40
0`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP0`00003o0?ooh6P0oooP10000?l00`000000cHDo0<f5?`020<f5?`05
0?oTh@3=QCl0onCQ0?oTh@3=QCl01@3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl01P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40
103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=
QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=
QCl30?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?ooh03oon001`3oon03000001/0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPH@3oon04000000<0003o00<0oooP
0000000000000P0000030?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh600oooP0P0000030000o`030000003=QCl0cHDo0080cHDo0P00
00040?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oT
h@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3oi>40
onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0
cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3oi>40
0`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?ooh03o
on002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh03o0?ooh5/0oooP0P0000020?ooh0<0003o100000040?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`<0
onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>40
0`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ
0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@030?oTh@04
0<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0oooP0?ooh0090?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0
oooPFP3oon0300000080003o00<0oooP0<f5?`0000000`0000050?oTh@030<f5?`3oi>40onCQ00<0
onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5
?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3o
i>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl0103oi>400`3=QCl0onCQ0?oTh@030?oT
h@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0oooP0?ooh009
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
0?l0oooPEP3oon0200000080oooP0`000?l010000000cHDo0<f5?`3=QCl20?oTh@030<f5?`3oi>40
onCQ00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3o
i>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5
?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ
0?oTh@030?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1E0?ooh08000000`000?l00`3=QCl000000000
00030?oTh@040<f5?`3oi>40onCQ0<f5?`H0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ
0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0
onCQ0?oTh@3oi>40cHDo00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40
onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ
00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3o
i>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oon00oooP00T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1A0?ooh080
000000@0cHDo0000o`000?l0003o0P0000020<f5?`D0onCQ00@0cHDo0?oTh@3oi>40cHDo1P3oi>40
0`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40
103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>401@3=QCl0onCQ
0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40
onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0
cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh4d0oooP0P0000000`3oon0000000000o`020000o`80onCQ0P00
00020?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo1P3oi>400`3=QCl0onCQ
0?oTh@030?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ
0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ0?oTh@3=QCl50?oTh@050<f5?`3o
i>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00@0onCQ00<0cHDo0?oTh@3o
i>400`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh4`0oooP0`0000020000o`<000001P3oi>400`3=QCl0onCQ0?oTh@030?oTh@04
0<f5?`3oi>40onCQ0<f5?`H0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`020?oT
h@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00@0onCQ
00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1:0?ooh08000000`000?l0
1@000000cHDo000000000000cHDo00H0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oT
h@3=QCl60?oTh@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`060?oT
h@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@040?oTh@040<f5?`3oi>40
onCQ0<f5?`D0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0?oTh@040?oTh@050<f5?`3oi>40onCQ0?oTh@3=
QCl0103oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`<0onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPAP3oon030<f5?`03000000000?l0003o00<0
00000P3oi>400`3=QCl0onCQ0<f5?`060?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3o
i>40cHDo1P3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl01P3o
i>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40103oi>40103=QCl0onCQ
0?oTh@3=QCl50?oTh@050<f5?`3oi>40onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@030?oT
h@030<f5?`3oi>40onCQ00<0onCQ00<0cHDo0?oTh@3oi>40103oi>401@3=QCl0onCQ0?oTh@3oi>40
cHDo00@0onCQ00<0cHDo0?oTh@3oi>400`3oi>40103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3o
i>40onCQ00<0onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh4@0oooP0P000000103=QCl0003o0000o`00
0?l3000000@0onCQ00<0cHDo0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3o
i>40onCQ0<f5?`H0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5
?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo
00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo
0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40
0`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40
onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=
QCl0onCQ0?oTh@030?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP0?l0oooP@P3oon02000000<0
003o0`3oi>42000000D0onCQ00<0cHDo0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@030?oTh@04
0<f5?`3oi>40onCQ0<f5?`H0onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`020?oT
h@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3o
i>40cHDo00H0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00@0onCQ
00@0cHDo0?oTh@3oi>40cHDo1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oT
h@3oi>400`3oi>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oT
h@3oi>40onCQ0<f5?`040?oTh@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3o
i>400`3=QCl0onCQ0?oTh@030?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?oo
h03o0?ooh400oooP00@0cHDo000000000?l0003o0`0000040?oTh@030<f5?`3oi>40onCQ00<0onCQ
00<0cHDo0?oTh@3=QCl01P3oi>400`3=QCl0onCQ0?oTh@030?oTh@040<f5?`3oi>40onCQ0<f5?`H0
onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00<0
onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo00H0onCQ00D0cHDo
0?oTh@3oi>40onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ00@0onCQ00@0cHDo0?oTh@3oi>40cHDo
1@3oi>401@3=QCl0onCQ0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400`3oi>400`3=QCl0
onCQ0?oTh@030?oTh@030<f5?`3oi>40onCQ00@0onCQ00D0cHDo0?oTh@3oi>40onCQ0<f5?`040?oT
h@030<f5?`3oi>40onCQ00<0onCQ00@0cHDo0?oTh@3oi>40cHDo0`3oi>400`3=QCl0onCQ0?oTh@03
0?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPd0oooP00@000000?ooh03oon0000001`3oon04000000P0oooPo`00000f000000<0003oV@000008
0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon00
0`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:
0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP8000000P2]f>H20000o`030:gHiP0cXLX0oooP00800000XP3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?oo
h0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP04
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00@000000P000?l30:gHiP0303>QbP3oon00oooP0:<0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00T0oooP
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV
03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H00000008000000P00
0?l00`000000<j7:03>QbP0303>QbZD0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV0`0000020000o`800000Z`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV100cXLX010000000003o
0000o`000?l200000:d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>Q
bP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP04
03>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP3oon00oooP0080003o0`00
002_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0c
XLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0[MSV0P0000000`0cXLX0003o0000o`020?ooh0800000/03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP<0
<j7:0P0000020000okH0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>Q
bP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP04
03>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H00`0cXLX0oooP0?ooh0020000o`800000]P3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02000000050:gHiP0cXLX0003o
0000o`3oon000P00002g0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP04
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV
0:gHiP2]f>H300000080003o_03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0c
XLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP0000000P0000020000o`030000003oon00oooP0;/0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV
0:gHiP2]f>H20000000303>QbP00000000000080003o0P00002n0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP04
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0100000020000o`800000`03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP<0<j7:0P0000020000o`030?oo
h000000000000<40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`00
00090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0
<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0
[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP3oon00oooP0080003o00<000000?ooh03oon00`@3oon030000
01/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0000o`000?l0b03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:
0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP80003obP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H3000000050:gHiP000?l0003o0:gHiP0cXLX0bP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV
0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV00<0[MSV100cXLX300000080003o100cXL[:0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV
03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H01@0cXLX0oooP0?ooh03oon0000000080003o0P00
003>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0c
XLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0oooP0?ooh0020000o`<0
0000c`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0
<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]
f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0403>QbP2]f>H0[MSV0:gHiP80000000<0<j7:0000o`000?l0e03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:
1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV
0:gHiP0cXLX40:gHiP<0<j7:0P0000020000omH0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP03
03>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0oooP0?ooh002
0000o`800000eP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gH
iP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]
f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0403>QbP000?l0003o0?ooh0800000e`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX2
000000030:gHiP000?l0003o0=`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP0000000P0000020000o`030:gHiP0cXLX0oooP0=/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00D0<j7:000000000000
00000000o`0200000080<j7:g03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0c
XLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H0102]f>H0100cXLX000000000o`000?l200000=l0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV0P000?l200000>40oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0
<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H20000o`0303>QbP3oon00oooP0>00oooP0`00000K0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
[MSV0P0000020:gHiP040000o`2]f>H0[MSV03>Qb^@0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gH
iP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP2]
f>H300000080003o0`2]f>H00`0cXLX0oooP0?ooh03R0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0
[MSV000000020000o`030000000cXLX0<j7:00<0<j7:i03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0503>QbP0000000000
0:gHiP000?l00P00003Z0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP04
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV0P0000020000o`80<j7:j`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02000000030:gHiP00
0?l0003o00800000k@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:
0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0
<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H0100cXLX0[MSV0000000000020000o`0303>QbP00000000000>h0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP04
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV0`00000010000?l000000000000cXL[`0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP8000000P000?l200000?80
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>Q
bPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP@0<j7:0P0000000`000?l000000000003d0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX0102]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0oooP0?ooh03oon020000o`800000m@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh005
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0?ooh0000?l0003o0?ooh00200000?H0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP020000000303>QbP000?l0oooP0?X0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV00000000
00020000oo`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0
[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]
f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H203>QbP04000000000?l0000000000?`0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV008000000P000?l200000?/0oooP
0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX000000080003o
00<000000?ooh03oon00oP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0
102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0
<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H01@0cXLX0[MSV0:gHiP0cXLX0003o00<00000o`3oon010?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP8000000P000?l00`3oon0000000000003o0?ooh080oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP040:gHiP0403>QbP2]f>H0[MSV03>QbP<0000000<0003o0000000cXLX0o`3oon05
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX4
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP0200000080003o0P0000000`0cXLX0
oooP0?ooh03o0?ooh0<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>Q
bP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>Q
bP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP04
03>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0503>QbP2]f>H00000000000000?l0
0`00003o0?ooh0L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]
f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>Q
bP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP040:gHiP0403>QbP00000000000000o`800000o`3o
on090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0c
XLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gH
iP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H200000080003o0P00003o0?ooh0X0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP80000000@0003o0000000000000000o`3oon0;0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP04
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV0:gHiP<0<j7:00@0
00000000o`0000000000o`3oon0=0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]
f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV0:gHiP8000000P000?l200000?l0oooP3P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H303>QbP800000
00<0003o0000003oon00o`3oon0@0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]
f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0503>QbP3oon00oooP000000000?l00P00003o0?ooh140oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP100000070?ooh0030000003oon00oooP
00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX4
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0c
XLX60:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>Q
bP3oon00003o0000o`800000o`3oon0B0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>H=0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0000o`3oon00o`3oon0E
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00oooP
00L0oooP100000080?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gH
iP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:
0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0<j7:000000000000
0P2]f>H00`000?l0oooP0?ooh03o0?ooh180oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3`3o
on000`000000oooP0?ooh0060?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX0102]f>H300000080003o00<0<j7:0?ooh03oon00o`3oon0E0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?oo
h03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV
03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0
[MSV03>QbPH0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP<0000000@0003o0000000cXLX0
<j7:o`3oon0G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000
203oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0c
XLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV0P000002
0000o`030000003oon00oooP0?l0oooP603oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H0100cXLX0[MSV0:gHiP2]f>H303>QbP040000
00000?l0000000000?l0oooP6`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0c
XLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080
[MSV00@0<j7:0:gHiP2]f>H0<j7:1P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080oooP00<0003o
000000000000o`3oon0L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP04
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0c
XLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100c
XLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
100cXLX0[MSV0:gHiP0cXLX60:gHiP0503>QbP2]f>H000000000000cXLX00P000?oo0?ooh1l0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0
[MSV00D0<j7:00000000000000000000o`3o0?ooh240oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gH
iP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0403>QbP2]f>H0[MSV03>QbPH0[MSV00D0<j7:000000000?l0003o0000
003o0?ooh240oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0
[MSV03>QbP@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]
f>H0[MSV03>QbPH0[MSV00@0<j7:0000o`0000000000o`3oon0R0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP04
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX50:gHiP80003oo`3oon0U0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP80000000<0003o0:gHiP0cXLX0o`3oon0U0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080000000@0003o0000002]f>H0<j7:
o`3oon0U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP0203>QbP80003o0P00000203>Qb_l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0000o`3oon0200000?l0oooP:03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh005
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0<j7:000000000?l0003oo`3oon0/
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon001@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gH
iP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP04000000000?l0000000000?l0oooP:P3o
on03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV
0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0
[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gHiP0cXLX40:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H010000?l0000000000000003o0?ooh2`0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020000o`0303>QbP00000000000?l0oooP
;@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV00@0[MSV00@0<j7:0:gHiP2]f>H0<j7:
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP000000003o0080[MSV00<0<j7:0?ooh03oon00
o`3oon0]0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0102]f>H0100cXLX0[MSV0:gH
iP0cXLX40:gHiP0303>QbP2]f>H0[MSV0080[MSV00@000000000o`00000000000P0cXL[o0?ooh2l0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H010000?l0000000000000003o0?ooh340oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0:gH
iP0000000P000?l00`0cXLX000000000003o0?ooh380oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gH
iP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:000000000?l00P0000000`0c
XLX0oooP0?ooh03o0?ooh380oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP04
03>QbP2]f>H0[MSV03>QbP@0[MSV00<0<j7:0000o`0000000P00003o0?ooh3D0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@000000000
o`000?l0oooP0P00003o0?ooh3H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gH
iP0703>QbP2]f>H0[MSV03>QbP2]f>H000000000o`0200000?l0oooP>@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]
f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP04
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P0cXLX010000?l0000000000000
003o0?ooh3T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0603>QbP2]f>H0
[MSV03>QbP000?l0oooP0P00003o0?ooh3X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>Q
bP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gH
iP040:gHiP0403>QbP2]f>H0003o0000ool0oooP?P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV00@0[MSV00@000000000o`2]f>H0<j7:o`3oon0n0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@000000003o000000000000<j7:0?l0oooP?P3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H01@000?l00000000000000000<j7:0?l0oooP?03oon03000001/0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP2]f>H00P00000010000?l0[MSV00000000003o0?ooh400oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H203>QbP80000000@0003o0000000cXLX0<j7:o`3oon110?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00@0
<j7:0?ooh0000?l0003o0P00003o0?ooh4<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>Q
bP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0003o0?oo
h00200000?l0oooPA03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000o`3oon00oooP0?l0oooPAP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0c
XLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01P0c
XLX0[MSV0:gHiP2]f>H0003o03>Qb_l0oooPB03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0
<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gH
iP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0
[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H01P0cXLX0[MSV0:gHiP000?l0[MSV03>Qb_l0oooP
B03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:
0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]
f>H2000000040000o`2]f>H0[MSV03>Qb_l0oooPB03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H2000000050000o`000000[MSV0:gHiP0cXLX0
o`3oon180?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0100cXLX0[MSV0:gH
iP2]f>H3000000030000o`000000000000<0<j7:o`3oon180?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP03000000030000o`00000000000?l0oooPC03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV0`0cXLX01@000000003o0000o`00
0000<j7:0?l0oooPC@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV00<0[MSV00@0<j7:
0?ooh03oon00003o0P00003o0?ooh4l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0102]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP3oon00003o0?l0oooPDP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV0P0000000`000?l0oooP0?ooh03o0?ooh540oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP0`0000090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP@0<j7:0P0000000`000?l0
00000?ooh03o0?ooh500oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H0
0`2]f>H00`0cXLX0[MSV0:gHiP040:gHiP0603>QbP3oon00oooP0?ooh0000000003o0P00003o0?oo
h5<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gH
iP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H0102]f>H01@0cXLX0oooP0?ooh03oon00003o00800000o`3oon1D0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
0`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV00@0[MSV00@0<j7:0?ooh03oon00003oo`3oon1G0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0
[MSV00<0<j7:0?ooh0000?l0o`3oon1H0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0
<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV00@0[MSV0P000?oo0?ooh5T0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`000?l0<j7:0?ooh03o0?ooh5T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
0`000?l0[MSV03>QbP3o0?ooh5X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0
<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0
[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00D0<j7:0:gHiP00000000000000o`020:gHiP0303>QbP3oon00
oooP0?l0oooPF03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H0
1`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP2]f>H00`2]f>H01@0cXLX00000000000000?l0000000<0<j7:o`3oon1J0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP000000003o
00800000o`3oon1M0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0
102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0403>QbP000?l0000000000?l0oooPGP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0oooP0?ooh03o0?ooh5l0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0703>QbP2]f>H000000000002]
f>H0003o03>QbP3o0?ooh640oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPl0
oooP0`0000060?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0c
XLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV
00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX00000000000020000o`030:gHiP0cXLX0oooP0?l0oooPH03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh0050?ooh0030000
003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP07
03>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX00000
0000o`0200000080<j7:o`3oon1Q0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H=0?ooh0D000001P3oon04000000P0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:
0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P00
0000100cXLX0003o00000000003o0?ooh640oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3o
on0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP04
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]
f>H0[MSV0:gHiP<0000000<0003o0?ooh03oon00o`3oon1U0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00000000L0oooP00<000000?ooh03oon002@3o
on001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00@0<j7:0:gHiP2]f>H0[MSV0P0000000`000?l000000?ooh03o0?ooh6H0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPl0oooP0P0000070?ooh0030000003oon00
oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0003o0000003o0?ooh6P0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV
0080[MSV00D0<j7:0:gHiP00000000000000o`3o0?ooh6X0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0
<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:00000000
0000003o0000003o0?ooh6X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV
03>QbP040:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:000000000?l00P00003o0?ooh6X0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP040:gHiP0303>QbP2]f>H0
[MSV0080[MSV00@0<j7:0000o`0000000000o`3oon1[0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV
0080[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP020:gHiP030000o`3oon00oooP
0?l0oooPK03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0<j7:00@0[MSV
00H0<j7:0:gHiP2]f>H0[MSV0000o`0cXL[o0?ooh6h0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gH
iP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0[MSV03>QbP040:gHiP80000000@0[MSV0000o`2]f>H0<j7:o`3oon1^0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP03
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gH
iP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H200000080003o0P2]
f>H00`0cXLX0oooP0?ooh03o0?ooh6`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]
f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP04000000000?l00000000000<0<j7:o`3oon1^0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`000?l000000000003o0?ooh780
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]
f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP030000o`2]
f>H0<j7:0?l0oooPL`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H00000
000000000?l00P2]f>H00`0cXLX0oooP0?ooh03o0?ooh740oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP00000000000000o`0000000`0cXL[o0?ooh740oooP0`00000K0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP800000
00<0003o000000000000o`3oon1f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080[MSV00@00000
0000o`0000000000o`3oon1g0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gH
iP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>Q
bP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP2]f>H0[MSV0080000000<0003o0000
00000000o`3oon1h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gH
iP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H00`0cXLX0[MSV0:gHiP020:gHiP80<j7:0P0000000`000?l000000?ooh03o0?ooh7T0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP03
03>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0
[MSV0080[MSV00@0<j7:0?ooh0000000003o0P00003o0?ooh7X0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?oo
h0000?l00P00003o0?ooh7/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0000o`3oon00o`3oon1m0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0
<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0
[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0c
XLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP030000o`3oon00oooP0?l0oooPO@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00H0<j7:0:gHiP2]f>H0[MSV0000o`0cXL[o0?ooh7l0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>Q
bP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0603>QbP00000000000000
o`2]f>H0<j7:o`3oon1o0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP04
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX01@2]f>H2000000040000o`000000[MSV03>Qb_l0oooPO`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00@000000000o`00000000000P0cXL[o0?ooh7l0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]
f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP030000o`00
000000000?l0oooPPP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00@0[MSV00<0003o03>QbP3oon00o`3oon230?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0c
XLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H00`000?l0[MSV03>QbP3o0?ooh8@0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0
[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0003o0:gHiP2]f>H0<j7:o`3oon220?ooh0<000006`3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00@0
[MSV00@0<j7:0:gHiP2]f>H0[MSV0P0000001@000?l0[MSV0:gHiP2]f>H0<j7:0?l0oooPQ03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]
f>H0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0[MSV0:gHiP02000000030000o`000000[MSV0080[MSV
00<0<j7:0?ooh03oon00o`3oon220?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:
0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV
03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP040:gHiP0503>QbP0000000000
000000000?l00P00000403>Qb_l0oooPQ03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H3000000030000
o`00000000000?l0oooPR@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0
102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H2000000030000o`000000<j7:
0?l0oooPRP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV
00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01`0c
XLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX0102]f>H00`0cXLX0003o0000003o0?ooh8`0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV
0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00L0<j7:0:gHiP2]f>H0[MSV
03>QbP2]f>H0<j7:00@0[MSV00<0003o0?ooh03oon00o`3oon2<0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0c
XLX00`2]f>H00`0cXLX0[MSV03>QbP040:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP030000o`0cXLX0oooP0?l0oooPS@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP0cXLX0102]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`000?l0[MSV
03>QbP3o0?ooh8h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV
00H0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H2000000040000o`2]f>H0[MSV03>Qb_l0oooPSP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0
<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]
f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080000000<0003o0000000cXLX00P0cXL[o0?ooh8h0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00@0<j7:0:gHiP2]f>H0[MSV0P0000000`000?l00000
0000003o0?ooh940oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
0:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV
00<0<j7:0:gHiP2]f>H00P0000000`000?l000000000003o0?ooh980oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV
03>QbP030:gHiP0303>QbP2]f>H0<j7:00@0[MSV00D0<j7:0:gHiP00000000000000o`0200000?l0
oooPT`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0
<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H0100cXLX0
0000000000000?l200000?l0oooPU03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon03000000T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP040:gH
iP0303>QbP000000003o00800000o`3oon2C0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:
00@0[MSV00@0<j7:0000o`0000000000o`3oon2F0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
0`0cXLX0[MSV03>QbP040:gHiP030000o`3oon00oooP0?l0oooPU`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0102]f>H00`000?l0oooP0?ooh03o0?ooh9L0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]
f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>QbP2]f>H0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0003o03>QbP3oon00o`3oon2H
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0
[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP02000000030000o`2]f>H0
<j7:0?l0oooPV@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP00000000000000
o`00000203>Qb_l0oooPV@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080[MSV00L0<j7:0:gHiP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00@0<j7:000000000000
003o0P00003o0?ooh9/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gH
iP020:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP80000000<0003o00000000
0000o`3oon2L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]
f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H010000000003o00000000003o0?oo
h9d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0703>Q
bP2]f>H0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP030000o`00000000000?l0oooPWP3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh005
03>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:
0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00L0<j7:0:gHiP2]f>H0
[MSV03>QbP2]f>H0<j7:0080000000<0003o03>QbP3oon00o`3oon2O0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01P0cXLX0[MSV0:gHiP2]f>H0<j7:0:gH
iP80000000<0003o0000000cXLX0o`3oon2P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0
[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00<0<j7:0:gHiP2]f>H00P2]f>H0200cXLX0[MSV0:gHiP2]f>H0<j7:0:gHiP000000003o0P000000
0`0cXLX0oooP0?ooh03o0?ooh9h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPd0oooP0`0000080?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]
f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01`0cXLX0[MSV0:gHiP2]f>H0<j7:000000000?l00P00003o
0?ooh:80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?oo
h03oon0000001`3oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P0000000`000?l000000000003o0?oo
h:<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03o
on0000001`3oon04000000P0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV000000000000003o00<00000o`3oon2P0?ooh0@000006`3oon0N0?[`
iP40oooo000M0?[`iPd0oooP0`0000080?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P2]f>H203>QbP03000000000?l0000000800000
o`3oon2T0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003o
on00oooP00L0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP020:gHiP0503>QbP3oon00oooP0000o`000000o`3oon2V0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0<000001`3oon000`000000oooP0?ooh009
0?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080[MSV00<0<j7:0?oo
h0000?l0o`3oon2X0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P2]f>H00`0cXLX0003o0?ooh03o0?ooh:P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV0:gHiP02000000030000o`3oon00oooP0?l0oooPZ03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV
0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]
f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP80<j7:0P0000000`000?l000000?ooh03o0?ooh:T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0oooP000000000?l200000?l0oooPZP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]
f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00`2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP3oon00003o00800000o`3oon2[0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gH
iP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gH
iP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00<0<j7:0000o`3oon00o`3oon2]0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP0703>QbP2]f>H0
[MSV03>QbP2]f>H000000000o`3o0?ooh:l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]
f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:00000000
0?l200000?l0oooP[P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0503>Q
bP2]f>H0[MSV0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX000000000o`800000o`3oon2^
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP030:gHiP0503>QbP2]f>H0[MSV03>QbP000?l00P00003o0?ooh:l0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@0<j7:
000000000000003oo`3oon2b0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0303>QbP2]f>H0[MSV0080[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP80000000<0003o0000003oon00o`3oon2a0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon001@0cXLX0[MSV
0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H0[MSV
00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00<0[MSV00@00000
0000o`0000000000o`3oon2`0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:00<0[MSV00<0003o000000000000o`3oon2c0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0
[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gH
iP0303>QbP2]f>H0[MSV0080[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP030000o`0cXLX0
oooP0?l0oooP]03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0403>QbP2]
f>H0[MSV0:gHiP80000000<0003o0:gHiP0cXLX0o`3oon2e0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP03
03>QbP2]f>H0[MSV0080[MSV00<0<j7:0:gHiP2]f>H00P00000010000?l000000:gHiP0cXL[o0?oo
h;D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP05
0:gHiP0303>QbP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0[MSV0:gHiP02
000000040000o`000000<j7:03>Qb_l0oooP]@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV
0:gHiP020:gHiP0603>QbP2]f>H00000000000000?l00000o`3oon2h0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]
f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0[MSV0:gHiP03
0:gHiP0303>QbP2]f>H0[MSV0080[MSV0P0cXLX010000000003o00000000003o0?ooh;P0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
1@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>Q
bP2]f>H0[MSV00<0[MSV00<0<j7:0:gHiP2]f>H00P2]f>H00`0cXLX0oooP0000o`0200000?l0oooP
^@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0
[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP020:gHiP0303>QbP000?l0oooP0?l0
oooP^`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV0:gHiP02000000030000o`3oon00oooP
0?l0oooP^`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`0cXLX0[MSV00000002000000030000o`3oon00
oooP0?l0oooP^`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H203>QbP80000000<0003o0000003oon00o`3o
on2l0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
1@2]f>H00`0cXLX0[MSV0:gHiP030:gHiP0503>QbP3oon00oooP0000o`000000o`3oon2n0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0c
XLX0[MSV0:gHiP030:gHiP0303>QbP3oon00003o0?l0oooP`03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gH
iP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H0
0`0cXLX0003o0?ooh03o0?ooh<00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP0`0000090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H00`2]f>H00`000?l0oooP0?ooh03o0?ooh;h0oooP0`00
000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0
[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00<0<j7:0:gHiP2]f>H0
0P0000000`2]f>H0003o0?ooh03o0?ooh<40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP80<j7:0`0000000`000?l0<j7:0?ooh03o0?ooh<40
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0603>QbP3oon000000000000000?l00000o`3oon330?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>Q
bP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0oooP0?ooh0000?l000000?l0
oooPa03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
00D0[MSV00<0<j7:0?ooh0000?l0o`3oon360?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0003o0?ooh03o0?ooh<H0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001@0c
XLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP00
0?l0oooP0?l0oooPaP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:00D0[MSV00<0003o0?ooh03oon00o`3oon360?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV
03>QbP050:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`000?l0<j7:0?ooh03o0?ooh<L0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP030:gH
iP030000o`2]f>H0<j7:0?l0oooPb03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0003o0:gHiP2]f>H0<j7:o`3oon380?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:
0:gHiP2]f>H0[MSV03>QbP050:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0[MSV0000o`030:gHiP03
03>QbP3oon00oooP0?l0oooPaP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H00`0cXLX0
[MSV0:gHiP02000000030:gHiP000?l0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon360?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP0303>QbP2]f>H000000080000000<0003o03>QbP0c
XLX00`0cXL[o0?ooh<P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001@0cXLX0[MSV0:gHiP2]f>H0<j7:00D0[MSV00H0<j7:0:gHiP00
000000000000o`00003o0?ooh<d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP0`0000090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX01@2]f>H01@0cXLX0000000000000
0?l000000?l0oooPc03oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP80000000<0003o0000000cXLX0o`3o
on3>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP05000000000?l000000000000cXLX0
o`3oon3>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00D0<j7:0:gHiP2]f>H0[MSV03>QbP050:gHiP030000o`00000000000?l0oooP
d03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00503>QbP2]f>H0[MSV0:gHiP0cXLX0102]f>H00`000?l0<j7:0?ooh03o0?ooh=40oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001@0cXLX0[MSV0:gHiP2]f>H0<j7:00@0[MSV00<0003o03>QbP3oon00o`3oon3A0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0
<j7:0:gHiP2]f>H0[MSV03>QbP030:gHiP030000o`2]f>H0<j7:0?l0oooPdP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H010000?l0[MSV0:gHiP0cXL[o0?ooh=80oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001`0cXLX0[MSV
0:gHiP2]f>H0<j7:0:gHiP000?l00`2]f>H00`0cXLX0oooP0?ooh03o0?ooh=00oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV0:gHiP02000000030000o`2]f>H0[MSV0080[MSV00<0<j7:0?ooh03oon00o`3oon3@0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00D0<j7:0:gHiP00000000000000o`02000000@0<j7:o`3oon3B0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX00`000000003o
0000000200000?l0oooPeP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh00<0?ooh0030000o`00000000000?l0oooPe`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon002`3oon00
0`000?l0oooP0?ooh03o0?ooh=P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh00:0?ooh0030000o`3oon00
oooP0?l0oooPf@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon001000
0000oooP0?ooh00000070?ooh0@00000203oon000`000?l0oooP0?ooh03o0?ooh=L0oooP1000000K
0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00o`3oon3V0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP0000
00L0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H>0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
00000?ooh03oon00BP3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<0
00000?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<0
00000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh?l00000jP00000K0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00d@3jl>H400000080
n_3V200000020?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V
00000000000010000000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP00
0000n_3V00<00000203jl>H500000080n_3V100000020?[`iPD00000303jl>H300000140n_3V0`00
00060?[`iP<0000000@0n_3V00000000000000001P3jl>H00`000000n_3V0?[`iP040?[`iP<00000
00@0n_3V0000000000000000f03jl>H10?ooo`00dP3jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V0P00
00000`3jl>H000000000000?0?[`iP80000000<0n_3V0000000000001P3jl>H2000000030?[`iP00
0000000000L0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000=T0n_3V0@3o
ool00=80n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000D0n_3V0P000000
0`3jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP000000000000d0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P00
00000`3jl>H000000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
000=0?[`iP80000000<0n_3V0000000000001@3jl>H5000000D0n_3V0P0000000`3jl>H000000000
00070?[`iP<000001P3jl>H5000000H0n_3V0`00003J0?[`iP40oooo003B0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80000000<0n_3V00000000
00003`3jl>H2000000030?[`iP000000000000L0n_3V0`0000080?[`iP030000003jl>H0n_3V00H0
n_3V0`00003J0?[`iP40oooo003B0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H2
00000080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H02P3jl>H300000100n_3V10000007
0?[`iP80000000<0n_3V0000000000001`3jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V
000000000000f@3jl>H10?ooo`00dP3jl>H200000080n_3V0P0000000`3jl>H00000000000020000
00@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H50000
00X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000:0?[`iPD000000P3jl>H40000
0080n_3V0`0000000`3jl>H000000000000:0?[`iP80000000<0n_3V0000000000003`3jl>H20000
00P0n_3V0`000000103jl>H0000000000000000=0?[`iP<0000000<0n_3V0000000000001@00003D
0?[`iP40oooo003B0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V
01L0n_3V0P00000J0?[`iP80000000<0n_3V000000000000403jl>H2000002<0n_3V00<000000?[`
iP3jl>H0e03jl>H10?ooo`00d@3jl>H6000000@0n_3V0P00000_0?[`iPD000006P3jl>H3000001T0
n_3V0`00000B0?[`iP<000008P3jl>H00`000000n_3V0?[`iP3C0?[`iP40oooo003o0?[`iX<0n_3V
00<000000?[`iP3jl>H0dP3jl>H10?ooo`00o`3jl>J00?[`iP040000003jl>H0n_3V00000=@0n_3V
0@3oool00?l0n_3VP@3jl>H200000=D0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .5993 L
.02889 .5993 L
.02889 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .5993 L
.02889 .5993 L
.02889 .08012 L
s
.678 .847 .902 r
.02889 .08012 m
.02889 .59606 L
.03182 .59606 L
.03182 .08012 L
F
.2 .63 .79 r
.02889 .08012 m
.02889 .59606 L
.03182 .59606 L
.03182 .08012 L
s
.678 .847 .902 r
.03182 .08012 m
.03182 .58857 L
.03692 .58857 L
.03692 .08012 L
F
.2 .63 .79 r
.03182 .08012 m
.03182 .58857 L
.03692 .58857 L
.03692 .08012 L
s
.678 .847 .902 r
.03692 .08012 m
.03692 .58691 L
.03925 .58691 L
.03925 .08012 L
F
.2 .63 .79 r
.03692 .08012 m
.03692 .58691 L
.03925 .58691 L
.03925 .08012 L
s
.678 .847 .902 r
.03925 .08012 m
.03925 .57838 L
.04502 .57838 L
.04502 .08012 L
F
.2 .63 .79 r
.03925 .08012 m
.03925 .57838 L
.04502 .57838 L
.04502 .08012 L
s
.678 .847 .902 r
.04502 .08012 m
.04502 .57493 L
.04734 .57493 L
.04734 .08012 L
F
.2 .63 .79 r
.04502 .08012 m
.04502 .57493 L
.04734 .57493 L
.04734 .08012 L
s
.678 .847 .902 r
.04734 .08012 m
.04734 .57229 L
.05002 .57229 L
.05002 .08012 L
F
.2 .63 .79 r
.04734 .08012 m
.04734 .57229 L
.05002 .57229 L
.05002 .08012 L
s
.678 .847 .902 r
.05002 .08012 m
.05002 .56562 L
.05599 .56562 L
.05599 .08012 L
F
.2 .63 .79 r
.05002 .08012 m
.05002 .56562 L
.05599 .56562 L
.05599 .08012 L
s
.678 .847 .902 r
.05599 .08012 m
.05599 .56339 L
.06089 .56339 L
.06089 .08012 L
F
.2 .63 .79 r
.05599 .08012 m
.05599 .56339 L
.06089 .56339 L
.06089 .08012 L
s
.678 .847 .902 r
.06089 .08012 m
.06089 .55392 L
.06513 .55392 L
.06513 .08012 L
F
.2 .63 .79 r
.06089 .08012 m
.06089 .55392 L
.06513 .55392 L
.06513 .08012 L
s
.678 .847 .902 r
.06513 .08012 m
.06513 .55213 L
.0675 .55213 L
.0675 .08012 L
F
.2 .63 .79 r
.06513 .08012 m
.06513 .55213 L
.0675 .55213 L
.0675 .08012 L
s
.678 .847 .902 r
.0675 .08012 m
.0675 .54987 L
.07 .54987 L
.07 .08012 L
F
.2 .63 .79 r
.0675 .08012 m
.0675 .54987 L
.07 .54987 L
.07 .08012 L
s
.678 .847 .902 r
.07 .08012 m
.07 .54391 L
.07359 .54391 L
.07359 .08012 L
F
.2 .63 .79 r
.07 .08012 m
.07 .54391 L
.07359 .54391 L
.07359 .08012 L
s
.678 .847 .902 r
.07359 .08012 m
.07359 .54015 L
.07759 .54015 L
.07759 .08012 L
F
.2 .63 .79 r
.07359 .08012 m
.07359 .54015 L
.07759 .54015 L
.07759 .08012 L
s
.678 .847 .902 r
.07759 .08012 m
.07759 .53869 L
.07988 .53869 L
.07988 .08012 L
F
.2 .63 .79 r
.07759 .08012 m
.07759 .53869 L
.07988 .53869 L
.07988 .08012 L
s
.678 .847 .902 r
.07988 .08012 m
.07988 .53468 L
.08229 .53468 L
.08229 .08012 L
F
.2 .63 .79 r
.07988 .08012 m
.07988 .53468 L
.08229 .53468 L
.08229 .08012 L
s
.678 .847 .902 r
.08229 .08012 m
.08229 .53096 L
.0853 .53096 L
.0853 .08012 L
F
.2 .63 .79 r
.08229 .08012 m
.08229 .53096 L
.0853 .53096 L
.0853 .08012 L
s
.678 .847 .902 r
.0853 .08012 m
.0853 .52921 L
.08822 .52921 L
.08822 .08012 L
F
.2 .63 .79 r
.0853 .08012 m
.0853 .52921 L
.08822 .52921 L
.08822 .08012 L
s
.678 .847 .902 r
.08822 .08012 m
.08822 .52439 L
.0929 .52439 L
.0929 .08012 L
F
.2 .63 .79 r
.08822 .08012 m
.08822 .52439 L
.0929 .52439 L
.0929 .08012 L
s
.678 .847 .902 r
.0929 .08012 m
.0929 .5171 L
.09783 .5171 L
.09783 .08012 L
F
.2 .63 .79 r
.0929 .08012 m
.0929 .5171 L
.09783 .5171 L
.09783 .08012 L
s
.678 .847 .902 r
.09783 .08012 m
.09783 .51314 L
.10247 .51314 L
.10247 .08012 L
F
.2 .63 .79 r
.09783 .08012 m
.09783 .51314 L
.10247 .51314 L
.10247 .08012 L
s
.678 .847 .902 r
.10247 .08012 m
.10247 .50962 L
.10529 .50962 L
.10529 .08012 L
F
.2 .63 .79 r
.10247 .08012 m
.10247 .50962 L
.10529 .50962 L
.10529 .08012 L
s
.678 .847 .902 r
.10529 .08012 m
.10529 .50441 L
.10994 .50441 L
.10994 .08012 L
F
.2 .63 .79 r
.10529 .08012 m
.10529 .50441 L
.10994 .50441 L
.10994 .08012 L
s
.678 .847 .902 r
.10994 .08012 m
.10994 .49877 L
.1129 .49877 L
.1129 .08012 L
F
.2 .63 .79 r
.10994 .08012 m
.10994 .49877 L
.1129 .49877 L
.1129 .08012 L
s
.678 .847 .902 r
.1129 .08012 m
.1129 .49238 L
.11973 .49238 L
.11973 .08012 L
F
.2 .63 .79 r
.1129 .08012 m
.1129 .49238 L
.11973 .49238 L
.11973 .08012 L
s
.678 .847 .902 r
.11973 .08012 m
.11973 .48378 L
.1269 .48378 L
.1269 .08012 L
F
.2 .63 .79 r
.11973 .08012 m
.11973 .48378 L
.1269 .48378 L
.1269 .08012 L
s
.678 .847 .902 r
.1269 .08012 m
.1269 .4776 L
.13372 .4776 L
.13372 .08012 L
F
.2 .63 .79 r
.1269 .08012 m
.1269 .4776 L
.13372 .4776 L
.13372 .08012 L
s
.678 .847 .902 r
.13372 .08012 m
.13372 .47297 L
.13653 .47297 L
.13653 .08012 L
F
.2 .63 .79 r
.13372 .08012 m
.13372 .47297 L
.13653 .47297 L
.13653 .08012 L
s
.678 .847 .902 r
.13653 .08012 m
.13653 .46897 L
.13977 .46897 L
.13977 .08012 L
F
.2 .63 .79 r
.13653 .08012 m
.13653 .46897 L
.13977 .46897 L
.13977 .08012 L
s
.678 .847 .902 r
.13977 .08012 m
.13977 .46113 L
.1468 .46113 L
.1468 .08012 L
F
.2 .63 .79 r
.13977 .08012 m
.13977 .46113 L
.1468 .46113 L
.1468 .08012 L
s
.678 .847 .902 r
.1468 .08012 m
.1468 .45446 L
.15313 .45446 L
.15313 .08012 L
F
.2 .63 .79 r
.1468 .08012 m
.1468 .45446 L
.15313 .45446 L
.15313 .08012 L
s
.678 .847 .902 r
.15313 .08012 m
.15313 .45013 L
.15725 .45013 L
.15725 .08012 L
F
.2 .63 .79 r
.15313 .08012 m
.15313 .45013 L
.15725 .45013 L
.15725 .08012 L
s
.678 .847 .902 r
.15725 .08012 m
.15725 .44527 L
.16286 .44527 L
.16286 .08012 L
F
.2 .63 .79 r
.15725 .08012 m
.15725 .44527 L
.16286 .44527 L
.16286 .08012 L
s
.678 .847 .902 r
.16286 .08012 m
.16286 .44342 L
.16784 .44342 L
.16784 .08012 L
F
.2 .63 .79 r
.16286 .08012 m
.16286 .44342 L
.16784 .44342 L
.16784 .08012 L
s
.678 .847 .902 r
.16784 .08012 m
.16784 .43526 L
.17398 .43526 L
.17398 .08012 L
F
.2 .63 .79 r
.16784 .08012 m
.16784 .43526 L
.17398 .43526 L
.17398 .08012 L
s
.678 .847 .902 r
.17398 .08012 m
.17398 .42948 L
.17777 .42948 L
.17777 .08012 L
F
.2 .63 .79 r
.17398 .08012 m
.17398 .42948 L
.17777 .42948 L
.17777 .08012 L
s
.678 .847 .902 r
.17777 .08012 m
.17777 .42446 L
.18197 .42446 L
.18197 .08012 L
F
.2 .63 .79 r
.17777 .08012 m
.17777 .42446 L
.18197 .42446 L
.18197 .08012 L
s
.678 .847 .902 r
.18197 .08012 m
.18197 .4227 L
.18514 .4227 L
.18514 .08012 L
F
.2 .63 .79 r
.18197 .08012 m
.18197 .4227 L
.18514 .4227 L
.18514 .08012 L
s
.678 .847 .902 r
.18514 .08012 m
.18514 .4175 L
.19117 .4175 L
.19117 .08012 L
F
.2 .63 .79 r
.18514 .08012 m
.18514 .4175 L
.19117 .4175 L
.19117 .08012 L
s
.678 .847 .902 r
.19117 .08012 m
.19117 .41378 L
.19474 .41378 L
.19474 .08012 L
F
.2 .63 .79 r
.19117 .08012 m
.19117 .41378 L
.19474 .41378 L
.19474 .08012 L
s
.678 .847 .902 r
.19474 .08012 m
.19474 .41015 L
.19811 .41015 L
.19811 .08012 L
F
.2 .63 .79 r
.19474 .08012 m
.19474 .41015 L
.19811 .41015 L
.19811 .08012 L
s
.678 .847 .902 r
.19811 .08012 m
.19811 .40697 L
.20054 .40697 L
.20054 .08012 L
F
.2 .63 .79 r
.19811 .08012 m
.19811 .40697 L
.20054 .40697 L
.20054 .08012 L
s
.678 .847 .902 r
.20054 .08012 m
.20054 .40457 L
.20407 .40457 L
.20407 .08012 L
F
.2 .63 .79 r
.20054 .08012 m
.20054 .40457 L
.20407 .40457 L
.20407 .08012 L
s
.678 .847 .902 r
.20407 .08012 m
.20407 .39841 L
.20999 .39841 L
.20999 .08012 L
F
.2 .63 .79 r
.20407 .08012 m
.20407 .39841 L
.20999 .39841 L
.20999 .08012 L
s
.678 .847 .902 r
.20999 .08012 m
.20999 .39079 L
.21599 .39079 L
.21599 .08012 L
F
.2 .63 .79 r
.20999 .08012 m
.20999 .39079 L
.21599 .39079 L
.21599 .08012 L
s
.678 .847 .902 r
.21599 .08012 m
.21599 .38906 L
.22287 .38906 L
.22287 .08012 L
F
.2 .63 .79 r
.21599 .08012 m
.21599 .38906 L
.22287 .38906 L
.22287 .08012 L
s
.678 .847 .902 r
.22287 .08012 m
.22287 .37887 L
.22903 .37887 L
.22903 .08012 L
F
.2 .63 .79 r
.22287 .08012 m
.22287 .37887 L
.22903 .37887 L
.22903 .08012 L
s
.678 .847 .902 r
.22903 .08012 m
.22903 .37367 L
.23417 .37367 L
.23417 .08012 L
F
.2 .63 .79 r
.22903 .08012 m
.22903 .37367 L
.23417 .37367 L
.23417 .08012 L
s
.678 .847 .902 r
.23417 .08012 m
.23417 .37176 L
.24062 .37176 L
.24062 .08012 L
F
.2 .63 .79 r
.23417 .08012 m
.23417 .37176 L
.24062 .37176 L
.24062 .08012 L
s
.678 .847 .902 r
.24062 .08012 m
.24062 .36434 L
.2476 .36434 L
.2476 .08012 L
F
.2 .63 .79 r
.24062 .08012 m
.24062 .36434 L
.2476 .36434 L
.2476 .08012 L
s
.678 .847 .902 r
.2476 .08012 m
.2476 .35303 L
.25421 .35303 L
.25421 .08012 L
F
.2 .63 .79 r
.2476 .08012 m
.2476 .35303 L
.25421 .35303 L
.25421 .08012 L
s
.678 .847 .902 r
.25421 .08012 m
.25421 .34916 L
.25872 .34916 L
.25872 .08012 L
F
.2 .63 .79 r
.25421 .08012 m
.25421 .34916 L
.25872 .34916 L
.25872 .08012 L
s
.678 .847 .902 r
.25872 .08012 m
.25872 .34818 L
.26411 .34818 L
.26411 .08012 L
F
.2 .63 .79 r
.25872 .08012 m
.25872 .34818 L
.26411 .34818 L
.26411 .08012 L
s
.678 .847 .902 r
.26411 .08012 m
.26411 .34224 L
.27134 .34224 L
.27134 .08012 L
F
.2 .63 .79 r
.26411 .08012 m
.26411 .34224 L
.27134 .34224 L
.27134 .08012 L
s
.678 .847 .902 r
.27134 .08012 m
.27134 .33708 L
.2738 .33708 L
.2738 .08012 L
F
.2 .63 .79 r
.27134 .08012 m
.27134 .33708 L
.2738 .33708 L
.2738 .08012 L
s
.678 .847 .902 r
.2738 .08012 m
.2738 .33264 L
.27638 .33264 L
.27638 .08012 L
F
.2 .63 .79 r
.2738 .08012 m
.2738 .33264 L
.27638 .33264 L
.27638 .08012 L
s
.678 .847 .902 r
.27638 .08012 m
.27638 .3304 L
.28344 .3304 L
.28344 .08012 L
F
.2 .63 .79 r
.27638 .08012 m
.27638 .3304 L
.28344 .3304 L
.28344 .08012 L
s
.678 .847 .902 r
.28344 .08012 m
.28344 .32568 L
.28787 .32568 L
.28787 .08012 L
F
.2 .63 .79 r
.28344 .08012 m
.28344 .32568 L
.28787 .32568 L
.28787 .08012 L
s
.678 .847 .902 r
.28787 .08012 m
.28787 .32067 L
.29145 .32067 L
.29145 .08012 L
F
.2 .63 .79 r
.28787 .08012 m
.28787 .32067 L
.29145 .32067 L
.29145 .08012 L
s
.678 .847 .902 r
.29145 .08012 m
.29145 .31776 L
.29752 .31776 L
.29752 .08012 L
F
.2 .63 .79 r
.29145 .08012 m
.29145 .31776 L
.29752 .31776 L
.29752 .08012 L
s
.678 .847 .902 r
.29752 .08012 m
.29752 .31172 L
.30256 .31172 L
.30256 .08012 L
F
.2 .63 .79 r
.29752 .08012 m
.29752 .31172 L
.30256 .31172 L
.30256 .08012 L
s
.678 .847 .902 r
.30256 .08012 m
.30256 .30708 L
.30601 .30708 L
.30601 .08012 L
F
.2 .63 .79 r
.30256 .08012 m
.30256 .30708 L
.30601 .30708 L
.30601 .08012 L
s
.678 .847 .902 r
.30601 .08012 m
.30601 .30226 L
.31084 .30226 L
.31084 .08012 L
F
.2 .63 .79 r
.30601 .08012 m
.30601 .30226 L
.31084 .30226 L
.31084 .08012 L
s
.678 .847 .902 r
.31084 .08012 m
.31084 .298 L
.31551 .298 L
.31551 .08012 L
F
.2 .63 .79 r
.31084 .08012 m
.31084 .298 L
.31551 .298 L
.31551 .08012 L
s
.678 .847 .902 r
.31551 .08012 m
.31551 .29738 L
.31936 .29738 L
.31936 .08012 L
F
.2 .63 .79 r
.31551 .08012 m
.31551 .29738 L
.31936 .29738 L
.31936 .08012 L
s
.678 .847 .902 r
.31936 .08012 m
.31936 .29345 L
.32256 .29345 L
.32256 .08012 L
F
.2 .63 .79 r
.31936 .08012 m
.31936 .29345 L
.32256 .29345 L
.32256 .08012 L
s
.678 .847 .902 r
.32256 .08012 m
.32256 .28967 L
.32604 .28967 L
.32604 .08012 L
F
.2 .63 .79 r
.32256 .08012 m
.32256 .28967 L
.32604 .28967 L
.32604 .08012 L
s
.678 .847 .902 r
.32604 .08012 m
.32604 .2867 L
.33208 .2867 L
.33208 .08012 L
F
.2 .63 .79 r
.32604 .08012 m
.32604 .2867 L
.33208 .2867 L
.33208 .08012 L
s
.678 .847 .902 r
.33208 .08012 m
.33208 .28243 L
.3372 .28243 L
.3372 .08012 L
F
.2 .63 .79 r
.33208 .08012 m
.33208 .28243 L
.3372 .28243 L
.3372 .08012 L
s
.678 .847 .902 r
.3372 .08012 m
.3372 .27864 L
.34079 .27864 L
.34079 .08012 L
F
.2 .63 .79 r
.3372 .08012 m
.3372 .27864 L
.34079 .27864 L
.34079 .08012 L
s
.678 .847 .902 r
.34079 .08012 m
.34079 .27636 L
.34539 .27636 L
.34539 .08012 L
F
.2 .63 .79 r
.34079 .08012 m
.34079 .27636 L
.34539 .27636 L
.34539 .08012 L
s
.678 .847 .902 r
.34539 .08012 m
.34539 .27095 L
.34846 .27095 L
.34846 .08012 L
F
.2 .63 .79 r
.34539 .08012 m
.34539 .27095 L
.34846 .27095 L
.34846 .08012 L
s
.678 .847 .902 r
.34846 .08012 m
.34846 .2689 L
.35441 .2689 L
.35441 .08012 L
F
.2 .63 .79 r
.34846 .08012 m
.34846 .2689 L
.35441 .2689 L
.35441 .08012 L
s
.678 .847 .902 r
.35441 .08012 m
.35441 .2652 L
.35829 .2652 L
.35829 .08012 L
F
.2 .63 .79 r
.35441 .08012 m
.35441 .2652 L
.35829 .2652 L
.35829 .08012 L
s
.678 .847 .902 r
.35829 .08012 m
.35829 .26206 L
.36356 .26206 L
.36356 .08012 L
F
.2 .63 .79 r
.35829 .08012 m
.35829 .26206 L
.36356 .26206 L
.36356 .08012 L
s
.678 .847 .902 r
.36356 .08012 m
.36356 .25418 L
.3694 .25418 L
.3694 .08012 L
F
.2 .63 .79 r
.36356 .08012 m
.36356 .25418 L
.3694 .25418 L
.3694 .08012 L
s
.678 .847 .902 r
.3694 .08012 m
.3694 .25322 L
.37214 .25322 L
.37214 .08012 L
F
.2 .63 .79 r
.3694 .08012 m
.3694 .25322 L
.37214 .25322 L
.37214 .08012 L
s
.678 .847 .902 r
.37214 .08012 m
.37214 .24874 L
.37606 .24874 L
.37606 .08012 L
F
.2 .63 .79 r
.37214 .08012 m
.37214 .24874 L
.37606 .24874 L
.37606 .08012 L
s
.678 .847 .902 r
.37606 .08012 m
.37606 .24809 L
.38105 .24809 L
.38105 .08012 L
F
.2 .63 .79 r
.37606 .08012 m
.37606 .24809 L
.38105 .24809 L
.38105 .08012 L
s
.678 .847 .902 r
.38105 .08012 m
.38105 .24065 L
.38649 .24065 L
.38649 .08012 L
F
.2 .63 .79 r
.38105 .08012 m
.38105 .24065 L
.38649 .24065 L
.38649 .08012 L
s
.678 .847 .902 r
.38649 .08012 m
.38649 .23842 L
.38945 .23842 L
.38945 .08012 L
F
.2 .63 .79 r
.38649 .08012 m
.38649 .23842 L
.38945 .23842 L
.38945 .08012 L
s
.678 .847 .902 r
.38945 .08012 m
.38945 .23411 L
.39621 .23411 L
.39621 .08012 L
F
.2 .63 .79 r
.38945 .08012 m
.38945 .23411 L
.39621 .23411 L
.39621 .08012 L
s
.678 .847 .902 r
.39621 .08012 m
.39621 .23133 L
.3998 .23133 L
.3998 .08012 L
F
.2 .63 .79 r
.39621 .08012 m
.39621 .23133 L
.3998 .23133 L
.3998 .08012 L
s
.678 .847 .902 r
.3998 .08012 m
.3998 .22679 L
.40645 .22679 L
.40645 .08012 L
F
.2 .63 .79 r
.3998 .08012 m
.3998 .22679 L
.40645 .22679 L
.40645 .08012 L
s
.678 .847 .902 r
.40645 .08012 m
.40645 .22367 L
.41164 .22367 L
.41164 .08012 L
F
.2 .63 .79 r
.40645 .08012 m
.40645 .22367 L
.41164 .22367 L
.41164 .08012 L
s
.678 .847 .902 r
.41164 .08012 m
.41164 .22121 L
.41714 .22121 L
.41714 .08012 L
F
.2 .63 .79 r
.41164 .08012 m
.41164 .22121 L
.41714 .22121 L
.41714 .08012 L
s
.678 .847 .902 r
.41714 .08012 m
.41714 .21456 L
.42318 .21456 L
.42318 .08012 L
F
.2 .63 .79 r
.41714 .08012 m
.41714 .21456 L
.42318 .21456 L
.42318 .08012 L
s
.678 .847 .902 r
.42318 .08012 m
.42318 .21105 L
.42733 .21105 L
.42733 .08012 L
F
.2 .63 .79 r
.42318 .08012 m
.42318 .21105 L
.42733 .21105 L
.42733 .08012 L
s
.678 .847 .902 r
.42733 .08012 m
.42733 .20955 L
.43086 .20955 L
.43086 .08012 L
F
.2 .63 .79 r
.42733 .08012 m
.42733 .20955 L
.43086 .20955 L
.43086 .08012 L
s
.678 .847 .902 r
.43086 .08012 m
.43086 .20571 L
.43534 .20571 L
.43534 .08012 L
F
.2 .63 .79 r
.43086 .08012 m
.43086 .20571 L
.43534 .20571 L
.43534 .08012 L
s
.678 .847 .902 r
.43534 .08012 m
.43534 .20155 L
.44008 .20155 L
.44008 .08012 L
F
.2 .63 .79 r
.43534 .08012 m
.43534 .20155 L
.44008 .20155 L
.44008 .08012 L
s
.678 .847 .902 r
.44008 .08012 m
.44008 .20026 L
.44546 .20026 L
.44546 .08012 L
F
.2 .63 .79 r
.44008 .08012 m
.44008 .20026 L
.44546 .20026 L
.44546 .08012 L
s
.678 .847 .902 r
.44546 .08012 m
.44546 .19397 L
.45115 .19397 L
.45115 .08012 L
F
.2 .63 .79 r
.44546 .08012 m
.44546 .19397 L
.45115 .19397 L
.45115 .08012 L
s
.678 .847 .902 r
.45115 .08012 m
.45115 .19302 L
.45422 .19302 L
.45422 .08012 L
F
.2 .63 .79 r
.45115 .08012 m
.45115 .19302 L
.45422 .19302 L
.45422 .08012 L
s
.678 .847 .902 r
.45422 .08012 m
.45422 .19024 L
.45655 .19024 L
.45655 .08012 L
F
.2 .63 .79 r
.45422 .08012 m
.45422 .19024 L
.45655 .19024 L
.45655 .08012 L
s
.678 .847 .902 r
.45655 .08012 m
.45655 .18853 L
.46103 .18853 L
.46103 .08012 L
F
.2 .63 .79 r
.45655 .08012 m
.45655 .18853 L
.46103 .18853 L
.46103 .08012 L
s
.678 .847 .902 r
.46103 .08012 m
.46103 .18417 L
.46804 .18417 L
.46804 .08012 L
F
.2 .63 .79 r
.46103 .08012 m
.46103 .18417 L
.46804 .18417 L
.46804 .08012 L
s
.678 .847 .902 r
.46804 .08012 m
.46804 .18163 L
.47451 .18163 L
.47451 .08012 L
F
.2 .63 .79 r
.46804 .08012 m
.46804 .18163 L
.47451 .18163 L
.47451 .08012 L
s
.678 .847 .902 r
.47451 .08012 m
.47451 .17604 L
.47884 .17604 L
.47884 .08012 L
F
.2 .63 .79 r
.47451 .08012 m
.47451 .17604 L
.47884 .17604 L
.47884 .08012 L
s
.678 .847 .902 r
.47884 .08012 m
.47884 .173 L
.48477 .173 L
.48477 .08012 L
F
.2 .63 .79 r
.47884 .08012 m
.47884 .173 L
.48477 .173 L
.48477 .08012 L
s
.678 .847 .902 r
.48477 .08012 m
.48477 .16981 L
.49122 .16981 L
.49122 .08012 L
F
.2 .63 .79 r
.48477 .08012 m
.48477 .16981 L
.49122 .16981 L
.49122 .08012 L
s
.678 .847 .902 r
.49122 .08012 m
.49122 .16659 L
.49595 .16659 L
.49595 .08012 L
F
.2 .63 .79 r
.49122 .08012 m
.49122 .16659 L
.49595 .16659 L
.49595 .08012 L
s
.678 .847 .902 r
.49595 .08012 m
.49595 .16182 L
.50256 .16182 L
.50256 .08012 L
F
.2 .63 .79 r
.49595 .08012 m
.49595 .16182 L
.50256 .16182 L
.50256 .08012 L
s
.678 .847 .902 r
.50256 .08012 m
.50256 .15922 L
.50523 .15922 L
.50523 .08012 L
F
.2 .63 .79 r
.50256 .08012 m
.50256 .15922 L
.50523 .15922 L
.50523 .08012 L
s
.678 .847 .902 r
.50523 .08012 m
.50523 .15683 L
.5109 .15683 L
.5109 .08012 L
F
.2 .63 .79 r
.50523 .08012 m
.50523 .15683 L
.5109 .15683 L
.5109 .08012 L
s
.678 .847 .902 r
.5109 .08012 m
.5109 .15372 L
.51614 .15372 L
.51614 .08012 L
F
.2 .63 .79 r
.5109 .08012 m
.5109 .15372 L
.51614 .15372 L
.51614 .08012 L
s
.678 .847 .902 r
.51614 .08012 m
.51614 .15204 L
.52135 .15204 L
.52135 .08012 L
F
.2 .63 .79 r
.51614 .08012 m
.51614 .15204 L
.52135 .15204 L
.52135 .08012 L
s
.678 .847 .902 r
.52135 .08012 m
.52135 .14714 L
.52465 .14714 L
.52465 .08012 L
F
.2 .63 .79 r
.52135 .08012 m
.52135 .14714 L
.52465 .14714 L
.52465 .08012 L
s
.678 .847 .902 r
.52465 .08012 m
.52465 .14689 L
.52731 .14689 L
.52731 .08012 L
F
.2 .63 .79 r
.52465 .08012 m
.52465 .14689 L
.52731 .14689 L
.52731 .08012 L
s
.678 .847 .902 r
.52731 .08012 m
.52731 .14389 L
.53432 .14389 L
.53432 .08012 L
F
.2 .63 .79 r
.52731 .08012 m
.52731 .14389 L
.53432 .14389 L
.53432 .08012 L
s
.678 .847 .902 r
.53432 .08012 m
.53432 .14022 L
.54076 .14022 L
.54076 .08012 L
F
.2 .63 .79 r
.53432 .08012 m
.53432 .14022 L
.54076 .14022 L
.54076 .08012 L
s
.678 .847 .902 r
.54076 .08012 m
.54076 .13694 L
.54719 .13694 L
.54719 .08012 L
F
.2 .63 .79 r
.54076 .08012 m
.54076 .13694 L
.54719 .13694 L
.54719 .08012 L
s
.678 .847 .902 r
.54719 .08012 m
.54719 .13124 L
.5536 .13124 L
.5536 .08012 L
F
.2 .63 .79 r
.54719 .08012 m
.54719 .13124 L
.5536 .13124 L
.5536 .08012 L
s
.678 .847 .902 r
.5536 .08012 m
.5536 .12865 L
.55831 .12865 L
.55831 .08012 L
F
.2 .63 .79 r
.5536 .08012 m
.5536 .12865 L
.55831 .12865 L
.55831 .08012 L
s
.678 .847 .902 r
.55831 .08012 m
.55831 .12715 L
.56219 .12715 L
.56219 .08012 L
F
.2 .63 .79 r
.55831 .08012 m
.55831 .12715 L
.56219 .12715 L
.56219 .08012 L
s
.678 .847 .902 r
.56219 .08012 m
.56219 .12427 L
.56542 .12427 L
.56542 .08012 L
F
.2 .63 .79 r
.56219 .08012 m
.56219 .12427 L
.56542 .12427 L
.56542 .08012 L
s
.678 .847 .902 r
.56542 .08012 m
.56542 .1228 L
.56832 .1228 L
.56832 .08012 L
F
.2 .63 .79 r
.56542 .08012 m
.56542 .1228 L
.56832 .1228 L
.56832 .08012 L
s
.678 .847 .902 r
.56832 .08012 m
.56832 .1217 L
.57214 .1217 L
.57214 .08012 L
F
.2 .63 .79 r
.56832 .08012 m
.56832 .1217 L
.57214 .1217 L
.57214 .08012 L
s
.678 .847 .902 r
.57214 .08012 m
.57214 .11946 L
.57588 .11946 L
.57588 .08012 L
F
.2 .63 .79 r
.57214 .08012 m
.57214 .11946 L
.57588 .11946 L
.57588 .08012 L
s
.678 .847 .902 r
.57588 .08012 m
.57588 .11717 L
.5819 .11717 L
.5819 .08012 L
F
.2 .63 .79 r
.57588 .08012 m
.57588 .11717 L
.5819 .11717 L
.5819 .08012 L
s
.678 .847 .902 r
.5819 .08012 m
.5819 .11508 L
.58507 .11508 L
.58507 .08012 L
F
.2 .63 .79 r
.5819 .08012 m
.5819 .11508 L
.58507 .11508 L
.58507 .08012 L
s
.678 .847 .902 r
.58507 .08012 m
.58507 .11322 L
.58969 .11322 L
.58969 .08012 L
F
.2 .63 .79 r
.58507 .08012 m
.58507 .11322 L
.58969 .11322 L
.58969 .08012 L
s
.678 .847 .902 r
.58969 .08012 m
.58969 .10866 L
.59637 .10866 L
.59637 .08012 L
F
.2 .63 .79 r
.58969 .08012 m
.58969 .10866 L
.59637 .10866 L
.59637 .08012 L
s
.678 .847 .902 r
.59637 .08012 m
.59637 .10731 L
.59865 .10731 L
.59865 .08012 L
F
.2 .63 .79 r
.59637 .08012 m
.59637 .10731 L
.59865 .10731 L
.59865 .08012 L
s
.678 .847 .902 r
.59865 .08012 m
.59865 .10541 L
.60264 .10541 L
.60264 .08012 L
F
.2 .63 .79 r
.59865 .08012 m
.59865 .10541 L
.60264 .10541 L
.60264 .08012 L
s
.678 .847 .902 r
.60264 .08012 m
.60264 .10501 L
.60981 .10501 L
.60981 .08012 L
F
.2 .63 .79 r
.60264 .08012 m
.60264 .10501 L
.60981 .10501 L
.60981 .08012 L
s
.678 .847 .902 r
.60981 .08012 m
.60981 .10153 L
.61206 .10153 L
.61206 .08012 L
F
.2 .63 .79 r
.60981 .08012 m
.60981 .10153 L
.61206 .10153 L
.61206 .08012 L
s
.678 .847 .902 r
.61206 .08012 m
.61206 .09992 L
.61894 .09992 L
.61894 .08012 L
F
.2 .63 .79 r
.61206 .08012 m
.61206 .09992 L
.61894 .09992 L
.61894 .08012 L
s
.678 .847 .902 r
.61894 .08012 m
.61894 .0965 L
.62453 .0965 L
.62453 .08012 L
F
.2 .63 .79 r
.61894 .08012 m
.61894 .0965 L
.62453 .0965 L
.62453 .08012 L
s
.678 .847 .902 r
.62453 .08012 m
.62453 .09383 L
.62864 .09383 L
.62864 .08012 L
F
.2 .63 .79 r
.62453 .08012 m
.62453 .09383 L
.62864 .09383 L
.62864 .08012 L
s
.678 .847 .902 r
.62864 .08012 m
.62864 .09257 L
.63296 .09257 L
.63296 .08012 L
F
.2 .63 .79 r
.62864 .08012 m
.62864 .09257 L
.63296 .09257 L
.63296 .08012 L
s
.678 .847 .902 r
.63296 .08012 m
.63296 .09034 L
.63872 .09034 L
.63872 .08012 L
F
.2 .63 .79 r
.63296 .08012 m
.63296 .09034 L
.63872 .09034 L
.63872 .08012 L
s
.678 .847 .902 r
.63872 .08012 m
.63872 .08791 L
.64384 .08791 L
.64384 .08012 L
F
.2 .63 .79 r
.63872 .08012 m
.63872 .08791 L
.64384 .08791 L
.64384 .08012 L
s
.678 .847 .902 r
.64384 .08012 m
.64384 .08599 L
.64821 .08599 L
.64821 .08012 L
F
.2 .63 .79 r
.64384 .08012 m
.64384 .08599 L
.64821 .08599 L
.64821 .08012 L
s
.678 .847 .902 r
.64821 .08012 m
.64821 .08246 L
.65337 .08246 L
.65337 .08012 L
F
.2 .63 .79 r
.64821 .08012 m
.64821 .08246 L
.65337 .08246 L
.65337 .08012 L
s
.678 .847 .902 r
.65337 .08012 m
.65337 .08208 L
.65996 .08208 L
.65996 .08012 L
F
.2 .63 .79 r
.65337 .08012 m
.65337 .08208 L
.65996 .08208 L
.65996 .08012 L
s
1 .894 .882 r
.65996 .08012 m
.65996 .0784 L
.66595 .0784 L
.66595 .08012 L
F
.804 .522 .247 r
.65996 .08012 m
.65996 .0784 L
.66595 .0784 L
.66595 .08012 L
s
1 .894 .882 r
.66595 .08012 m
.66595 .0759 L
.67289 .0759 L
.67289 .08012 L
F
.804 .522 .247 r
.66595 .08012 m
.66595 .0759 L
.67289 .0759 L
.67289 .08012 L
s
1 .894 .882 r
.67289 .08012 m
.67289 .0737 L
.67635 .0737 L
.67635 .08012 L
F
.804 .522 .247 r
.67289 .08012 m
.67289 .0737 L
.67635 .0737 L
.67635 .08012 L
s
1 .894 .882 r
.67635 .08012 m
.67635 .07277 L
.68189 .07277 L
.68189 .08012 L
F
.804 .522 .247 r
.67635 .08012 m
.67635 .07277 L
.68189 .07277 L
.68189 .08012 L
s
1 .894 .882 r
.68189 .08012 m
.68189 .06976 L
.68717 .06976 L
.68717 .08012 L
F
.804 .522 .247 r
.68189 .08012 m
.68189 .06976 L
.68717 .06976 L
.68717 .08012 L
s
1 .894 .882 r
.68717 .08012 m
.68717 .067 L
.69246 .067 L
.69246 .08012 L
F
.804 .522 .247 r
.68717 .08012 m
.68717 .067 L
.69246 .067 L
.69246 .08012 L
s
1 .894 .882 r
.69246 .08012 m
.69246 .06464 L
.69945 .06464 L
.69945 .08012 L
F
.804 .522 .247 r
.69246 .08012 m
.69246 .06464 L
.69945 .06464 L
.69945 .08012 L
s
1 .894 .882 r
.69945 .08012 m
.69945 .06286 L
.70626 .06286 L
.70626 .08012 L
F
.804 .522 .247 r
.69945 .08012 m
.69945 .06286 L
.70626 .06286 L
.70626 .08012 L
s
1 .894 .882 r
.70626 .08012 m
.70626 .06161 L
.71055 .06161 L
.71055 .08012 L
F
.804 .522 .247 r
.70626 .08012 m
.70626 .06161 L
.71055 .06161 L
.71055 .08012 L
s
1 .894 .882 r
.71055 .08012 m
.71055 .05987 L
.7134 .05987 L
.7134 .08012 L
F
.804 .522 .247 r
.71055 .08012 m
.71055 .05987 L
.7134 .05987 L
.7134 .08012 L
s
1 .894 .882 r
.7134 .08012 m
.7134 .05952 L
.71589 .05952 L
.71589 .08012 L
F
.804 .522 .247 r
.7134 .08012 m
.7134 .05952 L
.71589 .05952 L
.71589 .08012 L
s
1 .894 .882 r
.71589 .08012 m
.71589 .05705 L
.7226 .05705 L
.7226 .08012 L
F
.804 .522 .247 r
.71589 .08012 m
.71589 .05705 L
.7226 .05705 L
.7226 .08012 L
s
1 .894 .882 r
.7226 .08012 m
.7226 .05617 L
.72508 .05617 L
.72508 .08012 L
F
.804 .522 .247 r
.7226 .08012 m
.7226 .05617 L
.72508 .05617 L
.72508 .08012 L
s
1 .894 .882 r
.72508 .08012 m
.72508 .05508 L
.72804 .05508 L
.72804 .08012 L
F
.804 .522 .247 r
.72508 .08012 m
.72508 .05508 L
.72804 .05508 L
.72804 .08012 L
s
1 .894 .882 r
.72804 .08012 m
.72804 .0541 L
.73046 .0541 L
.73046 .08012 L
F
.804 .522 .247 r
.72804 .08012 m
.72804 .0541 L
.73046 .0541 L
.73046 .08012 L
s
1 .894 .882 r
.73046 .08012 m
.73046 .05284 L
.73757 .05284 L
.73757 .08012 L
F
.804 .522 .247 r
.73046 .08012 m
.73046 .05284 L
.73757 .05284 L
.73757 .08012 L
s
1 .894 .882 r
.73757 .08012 m
.73757 .05047 L
.74173 .05047 L
.74173 .08012 L
F
.804 .522 .247 r
.73757 .08012 m
.73757 .05047 L
.74173 .05047 L
.74173 .08012 L
s
1 .894 .882 r
.74173 .08012 m
.74173 .0486 L
.74785 .0486 L
.74785 .08012 L
F
.804 .522 .247 r
.74173 .08012 m
.74173 .0486 L
.74785 .0486 L
.74785 .08012 L
s
1 .894 .882 r
.74785 .08012 m
.74785 .04781 L
.75323 .04781 L
.75323 .08012 L
F
.804 .522 .247 r
.74785 .08012 m
.74785 .04781 L
.75323 .04781 L
.75323 .08012 L
s
1 .894 .882 r
.75323 .08012 m
.75323 .04682 L
.75676 .04682 L
.75676 .08012 L
F
.804 .522 .247 r
.75323 .08012 m
.75323 .04682 L
.75676 .04682 L
.75676 .08012 L
s
1 .894 .882 r
.75676 .08012 m
.75676 .04486 L
.76308 .04486 L
.76308 .08012 L
F
.804 .522 .247 r
.75676 .08012 m
.75676 .04486 L
.76308 .04486 L
.76308 .08012 L
s
1 .894 .882 r
.76308 .08012 m
.76308 .04337 L
.76701 .04337 L
.76701 .08012 L
F
.804 .522 .247 r
.76308 .08012 m
.76308 .04337 L
.76701 .04337 L
.76701 .08012 L
s
1 .894 .882 r
.76701 .08012 m
.76701 .04277 L
.76941 .04277 L
.76941 .08012 L
F
.804 .522 .247 r
.76701 .08012 m
.76701 .04277 L
.76941 .04277 L
.76941 .08012 L
s
1 .894 .882 r
.76941 .08012 m
.76941 .0424 L
.77363 .0424 L
.77363 .08012 L
F
.804 .522 .247 r
.76941 .08012 m
.76941 .0424 L
.77363 .0424 L
.77363 .08012 L
s
1 .894 .882 r
.77363 .08012 m
.77363 .04126 L
.77613 .04126 L
.77613 .08012 L
F
.804 .522 .247 r
.77363 .08012 m
.77363 .04126 L
.77613 .04126 L
.77613 .08012 L
s
1 .894 .882 r
.77613 .08012 m
.77613 .04036 L
.7804 .04036 L
.7804 .08012 L
F
.804 .522 .247 r
.77613 .08012 m
.77613 .04036 L
.7804 .04036 L
.7804 .08012 L
s
1 .894 .882 r
.7804 .08012 m
.7804 .03804 L
.78662 .03804 L
.78662 .08012 L
F
.804 .522 .247 r
.7804 .08012 m
.7804 .03804 L
.78662 .03804 L
.78662 .08012 L
s
1 .894 .882 r
.78662 .08012 m
.78662 .03671 L
.79256 .03671 L
.79256 .08012 L
F
.804 .522 .247 r
.78662 .08012 m
.78662 .03671 L
.79256 .03671 L
.79256 .08012 L
s
1 .894 .882 r
.79256 .08012 m
.79256 .03602 L
.79707 .03602 L
.79707 .08012 L
F
.804 .522 .247 r
.79256 .08012 m
.79256 .03602 L
.79707 .03602 L
.79707 .08012 L
s
1 .894 .882 r
.79707 .08012 m
.79707 .03508 L
.80331 .03508 L
.80331 .08012 L
F
.804 .522 .247 r
.79707 .08012 m
.79707 .03508 L
.80331 .03508 L
.80331 .08012 L
s
1 .894 .882 r
.80331 .08012 m
.80331 .03398 L
.80982 .03398 L
.80982 .08012 L
F
.804 .522 .247 r
.80331 .08012 m
.80331 .03398 L
.80982 .03398 L
.80982 .08012 L
s
1 .894 .882 r
.80982 .08012 m
.80982 .03229 L
.81623 .03229 L
.81623 .08012 L
F
.804 .522 .247 r
.80982 .08012 m
.80982 .03229 L
.81623 .03229 L
.81623 .08012 L
s
1 .894 .882 r
.81623 .08012 m
.81623 .03118 L
.81863 .03118 L
.81863 .08012 L
F
.804 .522 .247 r
.81623 .08012 m
.81623 .03118 L
.81863 .03118 L
.81863 .08012 L
s
1 .894 .882 r
.81863 .08012 m
.81863 .03008 L
.8242 .03008 L
.8242 .08012 L
F
.804 .522 .247 r
.81863 .08012 m
.81863 .03008 L
.8242 .03008 L
.8242 .08012 L
s
1 .894 .882 r
.8242 .08012 m
.8242 .02961 L
.8304 .02961 L
.8304 .08012 L
F
.804 .522 .247 r
.8242 .08012 m
.8242 .02961 L
.8304 .02961 L
.8304 .08012 L
s
1 .894 .882 r
.8304 .08012 m
.8304 .02779 L
.83738 .02779 L
.83738 .08012 L
F
.804 .522 .247 r
.8304 .08012 m
.8304 .02779 L
.83738 .02779 L
.83738 .08012 L
s
1 .894 .882 r
.83738 .08012 m
.83738 .02602 L
.84457 .02602 L
.84457 .08012 L
F
.804 .522 .247 r
.83738 .08012 m
.83738 .02602 L
.84457 .02602 L
.84457 .08012 L
s
1 .894 .882 r
.84457 .08012 m
.84457 .02589 L
.84936 .02589 L
.84936 .08012 L
F
.804 .522 .247 r
.84457 .08012 m
.84457 .02589 L
.84936 .02589 L
.84936 .08012 L
s
1 .894 .882 r
.84936 .08012 m
.84936 .02482 L
.85532 .02482 L
.85532 .08012 L
F
.804 .522 .247 r
.84936 .08012 m
.84936 .02482 L
.85532 .02482 L
.85532 .08012 L
s
1 .894 .882 r
.85532 .08012 m
.85532 .0241 L
.86247 .0241 L
.86247 .08012 L
F
.804 .522 .247 r
.85532 .08012 m
.85532 .0241 L
.86247 .0241 L
.86247 .08012 L
s
1 .894 .882 r
.86247 .08012 m
.86247 .0231 L
.86768 .0231 L
.86768 .08012 L
F
.804 .522 .247 r
.86247 .08012 m
.86247 .0231 L
.86768 .0231 L
.86768 .08012 L
s
1 .894 .882 r
.86768 .08012 m
.86768 .02226 L
.87363 .02226 L
.87363 .08012 L
F
.804 .522 .247 r
.86768 .08012 m
.86768 .02226 L
.87363 .02226 L
.87363 .08012 L
s
1 .894 .882 r
.87363 .08012 m
.87363 .02122 L
.87639 .02122 L
.87639 .08012 L
F
.804 .522 .247 r
.87363 .08012 m
.87363 .02122 L
.87639 .02122 L
.87639 .08012 L
s
1 .894 .882 r
.87639 .08012 m
.87639 .0205 L
.88218 .0205 L
.88218 .08012 L
F
.804 .522 .247 r
.87639 .08012 m
.87639 .0205 L
.88218 .0205 L
.88218 .08012 L
s
1 .894 .882 r
.88218 .08012 m
.88218 .02016 L
.88835 .02016 L
.88835 .08012 L
F
.804 .522 .247 r
.88218 .08012 m
.88218 .02016 L
.88835 .02016 L
.88835 .08012 L
s
1 .894 .882 r
.88835 .08012 m
.88835 .01955 L
.89256 .01955 L
.89256 .08012 L
F
.804 .522 .247 r
.88835 .08012 m
.88835 .01955 L
.89256 .01955 L
.89256 .08012 L
s
1 .894 .882 r
.89256 .08012 m
.89256 .01916 L
.8951 .01916 L
.8951 .08012 L
F
.804 .522 .247 r
.89256 .08012 m
.89256 .01916 L
.8951 .01916 L
.8951 .08012 L
s
1 .894 .882 r
.8951 .08012 m
.8951 .01864 L
.89886 .01864 L
.89886 .08012 L
F
.804 .522 .247 r
.8951 .08012 m
.8951 .01864 L
.89886 .01864 L
.89886 .08012 L
s
1 .894 .882 r
.89886 .08012 m
.89886 .01844 L
.9047 .01844 L
.9047 .08012 L
F
.804 .522 .247 r
.89886 .08012 m
.89886 .01844 L
.9047 .01844 L
.9047 .08012 L
s
1 .894 .882 r
.9047 .08012 m
.9047 .01799 L
.91192 .01799 L
.91192 .08012 L
F
.804 .522 .247 r
.9047 .08012 m
.9047 .01799 L
.91192 .01799 L
.91192 .08012 L
s
1 .894 .882 r
.91192 .08012 m
.91192 .01729 L
.91551 .01729 L
.91551 .08012 L
F
.804 .522 .247 r
.91192 .08012 m
.91192 .01729 L
.91551 .01729 L
.91551 .08012 L
s
1 .894 .882 r
.91551 .08012 m
.91551 .01674 L
.9206 .01674 L
.9206 .08012 L
F
.804 .522 .247 r
.91551 .08012 m
.91551 .01674 L
.9206 .01674 L
.9206 .08012 L
s
1 .894 .882 r
.9206 .08012 m
.9206 .01654 L
.92412 .01654 L
.92412 .08012 L
F
.804 .522 .247 r
.9206 .08012 m
.9206 .01654 L
.92412 .01654 L
.92412 .08012 L
s
1 .894 .882 r
.92412 .08012 m
.92412 .01632 L
.92728 .01632 L
.92728 .08012 L
F
.804 .522 .247 r
.92412 .08012 m
.92412 .01632 L
.92728 .01632 L
.92728 .08012 L
s
1 .894 .882 r
.92728 .08012 m
.92728 .01619 L
.93164 .01619 L
.93164 .08012 L
F
.804 .522 .247 r
.92728 .08012 m
.92728 .01619 L
.93164 .01619 L
.93164 .08012 L
s
1 .894 .882 r
.93164 .08012 m
.93164 .01578 L
.93759 .01578 L
.93759 .08012 L
F
.804 .522 .247 r
.93164 .08012 m
.93164 .01578 L
.93759 .01578 L
.93759 .08012 L
s
1 .894 .882 r
.93759 .08012 m
.93759 .01561 L
.94088 .01561 L
.94088 .08012 L
F
.804 .522 .247 r
.93759 .08012 m
.93759 .01561 L
.94088 .01561 L
.94088 .08012 L
s
1 .894 .882 r
.94088 .08012 m
.94088 .01551 L
.94576 .01551 L
.94576 .08012 L
F
.804 .522 .247 r
.94088 .08012 m
.94088 .01551 L
.94576 .01551 L
.94576 .08012 L
s
1 .894 .882 r
.94576 .08012 m
.94576 .01528 L
.95119 .01528 L
.95119 .08012 L
F
.804 .522 .247 r
.94576 .08012 m
.94576 .01528 L
.95119 .01528 L
.95119 .08012 L
s
1 .894 .882 r
.95119 .08012 m
.95119 .0151 L
.95743 .0151 L
.95743 .08012 L
F
.804 .522 .247 r
.95119 .08012 m
.95119 .0151 L
.95743 .0151 L
.95743 .08012 L
s
1 .894 .882 r
.95743 .08012 m
.95743 .0149 L
.96081 .0149 L
.96081 .08012 L
F
.804 .522 .247 r
.95743 .08012 m
.95743 .0149 L
.96081 .0149 L
.96081 .08012 L
s
1 .894 .882 r
.96081 .08012 m
.96081 .01483 L
.96307 .01483 L
.96307 .08012 L
F
.804 .522 .247 r
.96081 .08012 m
.96081 .01483 L
.96307 .01483 L
.96307 .08012 L
s
1 .894 .882 r
.96307 .08012 m
.96307 .01475 L
.96982 .01475 L
.96982 .08012 L
F
.804 .522 .247 r
.96307 .08012 m
.96307 .01475 L
.96982 .01475 L
.96982 .08012 L
s
1 .894 .882 r
.96982 .08012 m
.96982 .01474 L
.97619 .01474 L
.97619 .08012 L
F
.804 .522 .247 r
.96982 .08012 m
.96982 .01474 L
.97619 .01474 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.02707 .5993 Mdot
.0297 .59606 Mdot
.03581 .58857 Mdot
.03718 .58691 Mdot
.0442 .57838 Mdot
.04706 .57493 Mdot
.04925 .57229 Mdot
.05482 .56562 Mdot
.05668 .56339 Mdot
.06465 .55392 Mdot
.06616 .55213 Mdot
.06808 .54987 Mdot
.07315 .54391 Mdot
.07637 .54015 Mdot
.07761 .53869 Mdot
.08106 .53468 Mdot
.08427 .53096 Mdot
.08578 .52921 Mdot
.08996 .52439 Mdot
.09632 .5171 Mdot
.09979 .51314 Mdot
.10289 .50962 Mdot
.1075 .50441 Mdot
.11252 .49877 Mdot
.11824 .49238 Mdot
.126 .48378 Mdot
.13162 .4776 Mdot
.13586 .47297 Mdot
.13953 .46897 Mdot
.14679 .46113 Mdot
.153 .45446 Mdot
.15707 .45013 Mdot
.16165 .44527 Mdot
.1634 .44342 Mdot
.17117 .43526 Mdot
.17673 .42948 Mdot
.18158 .42446 Mdot
.18329 .4227 Mdot
.18835 .4175 Mdot
.192 .41378 Mdot
.19557 .41015 Mdot
.19872 .40697 Mdot
.20111 .40457 Mdot
.20725 .39841 Mdot
.21493 .39079 Mdot
.21668 .38906 Mdot
.22709 .37887 Mdot
.23245 .37367 Mdot
.23443 .37176 Mdot
.24219 .36434 Mdot
.25416 .35303 Mdot
.2583 .34916 Mdot
.25935 .34818 Mdot
.26576 .34224 Mdot
.27137 .33708 Mdot
.27625 .33264 Mdot
.27872 .3304 Mdot
.28396 .32568 Mdot
.28955 .32067 Mdot
.29282 .31776 Mdot
.29966 .31172 Mdot
.30498 .30708 Mdot
.31053 .30226 Mdot
.31548 .298 Mdot
.3162 .29738 Mdot
.32081 .29345 Mdot
.32526 .28967 Mdot
.32879 .2867 Mdot
.3339 .28243 Mdot
.33846 .27864 Mdot
.34121 .27636 Mdot
.34782 .27095 Mdot
.35034 .2689 Mdot
.3549 .2652 Mdot
.35882 .26206 Mdot
.36872 .25418 Mdot
.36994 .25322 Mdot
.37566 .24874 Mdot
.3765 .24809 Mdot
.38614 .24065 Mdot
.38906 .23842 Mdot
.39474 .23411 Mdot
.39843 .23133 Mdot
.40452 .22679 Mdot
.40874 .22367 Mdot
.41209 .22121 Mdot
.42125 .21456 Mdot
.42615 .21105 Mdot
.42826 .20955 Mdot
.43368 .20571 Mdot
.43962 .20155 Mdot
.44148 .20026 Mdot
.45062 .19397 Mdot
.452 .19302 Mdot
.45611 .19024 Mdot
.45865 .18853 Mdot
.46519 .18417 Mdot
.46902 .18163 Mdot
.47759 .17604 Mdot
.48231 .173 Mdot
.48731 .16981 Mdot
.49241 .16659 Mdot
.50007 .16182 Mdot
.5043 .15922 Mdot
.50822 .15683 Mdot
.51337 .15372 Mdot
.51618 .15204 Mdot
.52445 .14714 Mdot
.52488 .14689 Mdot
.53003 .14389 Mdot
.53642 .14022 Mdot
.5422 .13694 Mdot
.55245 .13124 Mdot
.55717 .12865 Mdot
.55995 .12715 Mdot
.5653 .12427 Mdot
.56807 .1228 Mdot
.57015 .1217 Mdot
.57443 .11946 Mdot
.57886 .11717 Mdot
.58292 .11508 Mdot
.58658 .11322 Mdot
.5957 .10866 Mdot
.59844 .10731 Mdot
.60235 .10541 Mdot
.60318 .10501 Mdot
.61043 .10153 Mdot
.61385 .09992 Mdot
.62117 .0965 Mdot
.62702 .09383 Mdot
.62981 .09257 Mdot
.63481 .09034 Mdot
.64033 .08791 Mdot
.64479 .08599 Mdot
.65308 .08246 Mdot
.654 .08208 Mdot
.66293 .0784 Mdot
.66914 .0759 Mdot
.67469 .0737 Mdot
.67708 .07277 Mdot
.68496 .06976 Mdot
.69235 .067 Mdot
.69883 .06464 Mdot
.7038 .06286 Mdot
.70738 .06161 Mdot
.71241 .05987 Mdot
.71343 .05952 Mdot
.72079 .05705 Mdot
.72343 .05617 Mdot
.72679 .05508 Mdot
.72982 .0541 Mdot
.7338 .05284 Mdot
.74146 .05047 Mdot
.74768 .0486 Mdot
.75035 .04781 Mdot
.75376 .04682 Mdot
.76067 .04486 Mdot
.76605 .04337 Mdot
.76826 .04277 Mdot
.76964 .0424 Mdot
.77394 .04126 Mdot
.7774 .04036 Mdot
.78661 .03804 Mdot
.79209 .03671 Mdot
.79501 .03602 Mdot
.79905 .03508 Mdot
.80388 .03398 Mdot
.81162 .03229 Mdot
.81691 .03118 Mdot
.82233 .03008 Mdot
.82467 .02961 Mdot
.83425 .02779 Mdot
.84419 .02602 Mdot
.84499 .02589 Mdot
.8514 .02482 Mdot
.85591 .0241 Mdot
.86253 .0231 Mdot
.86837 .02226 Mdot
.87605 .02122 Mdot
.88179 .0205 Mdot
.88461 .02016 Mdot
.88987 .01955 Mdot
.89346 .01916 Mdot
.89841 .01864 Mdot
.90043 .01844 Mdot
.90516 .01799 Mdot
.91321 .01729 Mdot
.92039 .01674 Mdot
.92316 .01654 Mdot
.92648 .01632 Mdot
.92846 .01619 Mdot
.93567 .01578 Mdot
.93906 .01561 Mdot
.94129 .01551 Mdot
.94682 .01528 Mdot
.95197 .0151 Mdot
.95912 .0149 Mdot
.96306 .01483 Mdot
.96883 .01475 Mdot
.9701 .01474 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0227774) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.99446) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000@0n_3V0`0000040?[`iP<000001@3jl>H4000000<0n_3V100000030?[`iP<0
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000060?[`iP8000001@3j
l>H2000000D0n_3V0P0000050?[`iP8000000`3jl>H2000000030?[`iP00000000000?l0n_3VX`3j
l>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2
000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000006`3jl>H2000000`0n_3V0P0000050?[`iP80000000<0
n_3V000000000000100000000`3jl>H000000000000400000080n_3V0P0000000`3jl>H000000000
003o0?[`iZ<0n_3V0@3oool00200n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`iP000000
00000?[`iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V0P000000103jl>H00000
0000003jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000d0n_3V0P00000:0?[`iP@0
00000`3jl>H4000000040?[`iP000000n_3V0?[`iP8000000P3jl>H00`000000n_3V0?[`iP020000
00<0n_3V0P0000000`3jl>H000000000003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP80
00000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2
000000@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
000000X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`
iP02000001P0n_3V00<000000?[`iP3jl>H00P0000090?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP00000000000080n_3V00@000000?[`iP00000000000`3jl>H010000000n_3V
0000000000030?[`iP@00000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`
iP000000000000800000103jl>H4000000030?[`iP000000000000D000000P3jl>H400000080n_3V
1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V
1000000:0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V
00@000000?[`iP00000000000`3jl>H010000000n_3V0000000000030?[`iP800000o`3jl>JV0?[`
iP40oooo000P0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V02D0
n_3V0P00000<0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0
n_3V0`0000040?[`iP<00000103jl>H200000?l0n_3VY@3jl>H10?ooo`007`3jl>H6000000@0n_3V
0P00000_0?[`iPD000009`3jl>H5000000X0n_3V0`0000040?[`iP<000001@3jl>H2000000D0n_3V
0P0000050?[`iP<00000o`3jl>JS0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool003d0n_3V1000003o0?[`i_l0n_3V603jl>H10?ooo`00
@03jl>H200000?l0n_3Vo`3jl>HG0?[`iP40oooo000P0?[`iPH0000000D0n_3V0000000000000000
0?[`iP0300000080n_3V0`0000030?[`iP@000000`3jl>H2000000040?[`iP00000000000?[`iPD0
00000`3jl>H<000002l0n_3V0`0000040?[`iP800000o`3jl>K90?[`iP40oooo000R0?[`iP800000
103jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`iP040000003jl>H00000000000<0
n_3V00D000000?[`iP00000000000?[`iP0300000080n_3V0P0000040?[`iP8000000P3jl>H20000
00<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP000000000000<0n_3V0P00003o0?[`
i/T0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0
n_3V0P0000050?[`iP8000000P3jl>H200000080n_3V0P0000040?[`iP8000000P3jl>H2000000<0
n_3V0P00000`0?[`iP80000000<0n_3V000000000000o`3jl>K>0?[`iP40oooo000R0?[`iP800000
103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iPH0000000<0n_3V000000000000
0P3jl>H200000080n_3V0P0000050?[`iPD000000`3jl>H200000280n_3V1@0000090?[`iP800000
00<0n_3V000000000000o`3jl>K>0?[`iP40oooo000R0?[`iP800000103jl>H2000000030?[`iP00
000000000080n_3V0P0000040?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP<00000
0P3jl>H3000000030?[`iP000000n_3V00@0n_3V0P0000030?[`iP800000<03jl>H400000?l0n_3V
c`3jl>H10?ooo`008P3jl>H2000000<0n_3V1@0000020?[`iPD000000`3jl>H4000000<0n_3V0P00
00000`3jl>H0000000000004000000030?[`iP00000000000080n_3V100000040?[`iP800000<03j
l>H200000?l0n_3Vd@3jl>H10?ooo`008P3jl>H2000000/0n_3V0P00000R0?[`iP800000<@3jl>H2
00000?l0n_3Vd03jl>H10?ooo`00803jl>H6000000T0n_3V0P00000P0?[`iP@00000<P3jl>H30000
0?l0n_3VcP3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000003jl>H0200000000`3j
l>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H010000000n_3V0000003jl>H20000
0080n_3V00<000000?[`iP3jl>H00`00003o0?[`i_l0n_3V903jl>H10?ooo`00803jl>H300000003
0?[`iP00000000000080000000D0n_3V0000003jl>H000000?[`iP0300000080n_3V00<000000?[`
iP0000006@3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`
iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000@0n_3V0000000000000000203jl>H4
000000030?[`iP00000000000080n_3V100000020?[`iPD0000000L0n_3V00000000000000000?[`
iP000000n_3V00<00000603jl>H3000000@0n_3V0P0000050?[`iP<000000`3jl>H500000080n_3V
1@0000040?[`iP8000001@3jl>H2000000D0n_3V0P0000040?[`iP@00000L@3jl>H10?ooo`008@3j
l>H2000000030?[`iP000000000000D0000000@0n_3V00000000000000000P3jl>H2000000030?[`
iP000000000000T0n_3V1@0000090?[`iP030000003jl>H0n_3V00800000g03jl>H2000000@0n_3V
0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP80
0000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H50000
00X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H2000000030?[`iP0000000000
0080n_3V0P0000050?[`iP8000001`3jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H20000
0780n_3V0@3oool00280n_3V0`00000[0?[`iP800000g03jl>H2000000@0n_3V0P0000020?[`iP80
00000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000
000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V
00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000030?[`
iP8000001@3jl>H2000000H0n_3V0P0000050?[`iP8000001@3jl>H200000080n_3V1P00001a0?[`
iP40oooo000R0?[`iP<000006P3jl>H5000000`0n_3V0P00003L0?[`iP@000000`3jl>H500000080
n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000
003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP020000
00T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP0000000000
00@0n_3V0P0000050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000000P3jl>H00`00
0000n_3V0?[`iP0200000780n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000X0?[`iP<0
0000g@3jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003j
l>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P000002
0?[`iP8000000P3jl>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00000H
0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000000000D0n_3V0P000005
0?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V00000000
001b0?[`iP40oooo000P0?[`iP<0000000@0n_3V0000000000000000:@3jl>H200000=`0n_3V0P00
00000`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD00000
0P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<00000
00<0n_3V0000000000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V
0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H00000000000050?[`iP8000001@3jl>H2000000D0n_3V
0P0000020?[`iP040000003jl>H0000000000780n_3V0@3oool004d0n_3V00<000000?[`iP3jl>H0
0P00003L0?[`iP80000000<0n_3V000000000000403jl>H2000000`0n_3V0P00000R0?[`iP800000
0P3jl>H2000002h0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP030000
003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`iP0200000080n_3V00<000000?[`iP3jl>H0
0P0000030?[`iP<00000LP3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3j
l>H2000000@0n_3V0P0000060?[`iP8000006@3jl>H3000000030?[`iP000000000000800000;P3j
l>H3000000/0n_3V0`0000040?[`iP<00000103jl>H3000000<0n_3V1@0000020?[`iPD000000P3j
l>H5000000@0n_3V0P00001b0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`
iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`iP000000
0P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40
oooo000P0?[`iP<0000000<0n_3V0000000000000P000000103jl>H000000?[`iP0000020?[`iP04
0000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V100000040?[`
iP/00000103jl>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`
iP<0000000<0n_3V0000000000001P00000J0?[`iPD000000`3jl>H3000000@0n_3V0`00002j0?[`
iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@0000001@3jl>H00000000000000000n_3V
00@000002`3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H20000
0080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P000004
0?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3j
l>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000/0n_3V1@0000090?[`iP800000
1@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000002i0?[`iP40oooo
000R0?[`iP<00000:03jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3j
l>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3j
l>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H4000001X0n_3V0P00
00040?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000;T0n_3V0@3o
ool00280n_3V0`0000090?[`iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V
000000000000g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P000004
0?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP@000003@3jl>H5000000/0n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP00000000000;T0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W
0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP000000000000D0n_3V0P000002
0?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00
00030?[`iP8000000P3jl>H200000080n_3V0P000000103jl>H000000000003jl>H200000080n_3V
0P00000L0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
0000002i0?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`
iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`
iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080
n_3V1@0000030?[`iPD000006@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000^@3jl>H10?ooo`00C@3jl>H2000000030?[`
iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H2000003P0n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000;T0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P00
00040?[`iP8000001P3jl>H200000340n_3V0`0000040?[`iP<00000103jl>H300000;X0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iR<0oooP
0P0000150?ooh0800000103oon02000000@0oooP0P0000140?ooh0D00000@`3oon0500000080oooP
0P0000040?ooh0800000A03oon04000004@0oooP100000030?ooh0800000103oon02000004D0oooP
0P00000W0?ooh1h0n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000
003oon00oooP000000P0oooP00@000000?ooh03oon000000A@3oon000`000000oooP0?ooh0150?oo
h0030000003oon00oooP00L0oooP00@000000?ooh03oon000000@`3oon000`000000oooP0?ooh015
0?ooh0030000003oon00oooP00T0oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?oo
h000000V0?ooh1h0n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000
003oon00oooP000000/0oooP00<000000?ooh03oon00@`3oon000`000000oooP0?ooh0150?ooh003
0000003oon00oooP00X0oooP00<000000?ooh03oon00@P3oon000`000000oooP0?ooh0150?ooh003
0000003oon00oooP00/0oooP00<000000?ooh03oon00@`3oon000`000000oooP0?ooh00U0?ooh1h0
n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP0000
00T0oooP0P0000160?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00203oon020000
04H0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0800000A`3oon000`00
0000oooP0?ooh00T0?ooh1h0n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh00000130?oo
h0040000003oon00oooP000000T0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh015
0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon00@`3oon0010000000oooP0?ooh000
00140?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03oon00@`3oon0010000000oooP
0?ooh000000V0?ooh1h0n_3V0@3oool001d0n_3V8`3oon02000004D0oooP0P00000:0?ooh0<00000
A03oon02000004H0oooP0P00000:0?ooh0<00000A03oon02000004H0oooP0P00000:0?ooh0<00000
A03oon02000002L0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V603oon3o00000>X0
00006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP04X0oooP00<00000
0?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<00000
0?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP00T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0
oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh03o0?ooh<P0oooP0P000000103oon0000000000003oon02000000030?ooh000000000000080
000000<0oooP0000000000003P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh;/0oooP0P0000000`3oon0000000000000400000080oooP
4`00000=0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000o`3o
on2_0?ooh0@0000000<0oooP0000000000000`0000000`3oon00000000000005000001X0003o2@3o
on03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPZ@3oon0@
000000P0003o2@000000103oi>4000000000003oi>42000000030?oTh@00000000000080000000<0
onCQ0000000000000P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPXP3oon02000000040?ooh0000000
00000?ooh0P000002@000?l01@000000onCQ000000000000onCQ00H0000000<0cHDo0?oTh@000000
0P0000000`3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ0080cHDo00D0onCQ0<f5?`3oi>40
onCQ0<f5?`020?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2M0?ooh0T000002P000?l3000000030?oT
h@000000000000<000000P3oi>420<f5?`80onCQ00H0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl20?oT
h@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`050?oTh@3=QCl0
onCQ0?oTh@3=QCl00P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPU03oon02000000<0oooP1@000008
0000o`80000000<0cHDo000000000000100000001P3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`80onCQ
00@0cHDo0?oTh@3oi>40onCQ0P3=QCl20?oTh@060<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0P3oi>40
1@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl01@3oi>40cHDo0?oT
h@3oi>40cHDo0080onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh900oooP0P0000000`3oon0000000000
0002000000030<f5?`000?l0003o00@0003o1P000000103oi>4000000000003oi>420<f5?`80onCQ
00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>420<f5
?`80onCQ00H0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0
oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPS03oon05000000L0003o2@0000020?oTh@030<f5?`3oi>40cHDo0080onCQ
0P3=QCl20?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo
00<0onCQ0P3=QCl20?oTh@060<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0<f5
?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080
onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh8D0oooP0P0000020?ooh0<000001@000?l2000000040<f5
?`00000000000<f5?`80onCQ0`000000103=QCl0onCQ0?oTh@3=QCl30?oTh@030<f5?`3oi>40cHDo
0080onCQ0P3=QCl20?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3o
i>40cHDo00<0onCQ0P3=QCl20?oTh@060<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0P3oi>401@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl01@3oi>40cHDo0?oTh@3oi>40
cHDo0080onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh03o0?ooh840oooP1`0000040000o`H0000000D0onCQ0<f5
?`3oi>40onCQ0<f5?`030?oTh@030<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5
?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl01@3oi>40
cHDo0?oTh@3oi>40cHDo00<0onCQ0P3=QCl20?oTh@060<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0P3o
i>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl01@3oi>40cHDo
0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh7d0oooP0P0000000`3oon000000
00000002000000@0003o20000000103=QCl0onCQ0?oTh@3=QCl20?oTh@070<f5?`3oi>40onCQ0?oT
h@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@80cHDo
0P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oT
h@80cHDo0P3oi>401P3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ
0<f5?`020?oTh@030<f5?`3oi>40onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@03
0<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon1l0?ooh0@0000010000?l300000080onCQ0P0000000`3oi>40cHDo
0<f5?`020?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40
cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@050<f5
?`3oi>40onCQ0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ0P3=QCl20?oT
h@060<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ
00<0cHDo0?oTh@3oi>400P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?ooh03o
on002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh03o0?ooh7L0oooP100000000`3=QCl0003o0000o`020000o`D0000000D0onCQ0<f5?`3oi>40
onCQ0<f5?`020?oTh@80cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@070<f5?`3oi>40onCQ
0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@80
cHDo0P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`03
0?oTh@80cHDo0P3oi>401P3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0
onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oT
h@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00o`3oon1c0?ooh0D0000010000?l0103oi>4000000000003oi>420000
00050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ00@0cHDo
0?oTh@3oi>40cHDo0P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0
onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ00D0cHDo0?oTh@3oi>40cHDo0?oT
h@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>420<f5?`80onCQ00H0cHDo0?oTh@3=QCl0
cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@02
0<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPL03oon04
000000@0003o100000020?oTh@030<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo0P3o
i>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401`3=QCl0onCQ
0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3o
i>420<f5?`80onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=
QCl00`3oi>420<f5?`80onCQ00H0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40
cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl0
0P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP0?l0oooPJ`3oon05000000@0003o1`0000001P3=QCl0onCQ0?oT
h@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5
?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl0
0P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ00D0cHDo0?oT
h@3oi>40cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>420<f5?`80onCQ00H0
cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=
QCl0onCQ0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0oooP0?ooh009
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
0?l0oooPJP3oon02000000@0003o1`0000020<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=
QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@040<f5
?`3oi>40onCQ0<f5?`80onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo
0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@050<f5?`3oi>40onCQ0<f5?`3o
i>400P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ0P3=QCl20?oTh@060<f5?`3oi>40cHDo
0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>40
0P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?ooh03oon002@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon0300000?l0oooPI`3oon000`000000003o
0000o`020000o`H0000000D0cHDo0?oTh@3=QCl0cHDo0?oTh@020<f5?`80onCQ00H0cHDo0?oTh@3o
i>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=
QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo
0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ0P3=QCl20?oTh@050<f5?`3o
i>40onCQ0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo00<0onCQ0P3=QCl20?oTh@06
0<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0
cHDo0?oTh@3oi>400P3=QCl01@3oi>40cHDo0?oTh@3oi>40cHDo0080onCQ00<0cHDo0?ooh03oon00
1`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPH@3o
on04000000<0003o1`0000001@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl0
0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40
0`3=QCl0onCQ0?oTh@020<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401`3=QCl0onCQ0?oT
h@3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>42
0<f5?`80onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl0
0`3oi>420<f5?`80onCQ00H0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40cHDo
0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3o
i>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP0?l0oooPGP3oon04000000<0003o1`000000103oi>40cHDo0?oTh@3=
QCl20?oTh@050<f5?`3oi>40cHDo0<f5?`3oi>400P3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3o
i>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@07
0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>401@3=QCl0onCQ0?oTh@3=
QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@80cHDo0P3oi>401P3=QCl0onCQ
0<f5?`3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1M
0?ooh08000000`000?l4000000030<f5?`00000000000080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5
?`020?oTh@050<f5?`3oi>40cHDo0<f5?`3oi>400P3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3o
i>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@07
0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>401@3=QCl0onCQ0?oTh@3=
QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@80cHDo0P3oi>401P3=QCl0onCQ
0<f5?`3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40
onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oon00oooP00T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1I
0?ooh080000000@0cHDo000000000?l0003o1P000000103oi>40cHDo0?oTh@3=QCl20?oTh@050<f5
?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3=QCl0onCQ0080cHDo0P3oi>401P3=
QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ
0?oTh@020<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo
0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ
00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>420<f5
?`80onCQ00H0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl0
0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0
oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPEP3oon04000000<0003o1@0000001`3=QCl0onCQ0?oTh@3oi>40cHDo0?oT
h@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0cHDo0?oT
h@020<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5
?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00L0cHDo
0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo
0080onCQ0P3=QCl20?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oTh@3o
i>40cHDo00<0onCQ0P3=QCl20?oTh@060<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0P3oi>401@3=QCl0
onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl01@3oi>40cHDo0?oTh@3oi>40
cHDo0080onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh03o0?ooh580oooP0P0000000`3oon000000000000030000
o`80000000@0onCQ000000000000onCQ0`3=QCl30?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo
0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0<f5?`3oi>400P3=QCl20?oTh@060<f5
?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40
onCQ0080cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0
onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>40
1@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@80cHDo
0P3oi>401P3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`02
0?oTh@030<f5?`3oi>40onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3o
on00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon00o`3oon1A0?ooh0<000000`000?l4000000050<f5?`3oi>40onCQ0<f5?`3oi>400`3=
QCl30?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5
?`3oi>40cHDo0<f5?`3oi>400P3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40
103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ
0?oTh@3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo
00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@80cHDo0P3oi>401P3=QCl0onCQ0<f5?`3=QCl0onCQ
0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ0080cHDo00D0
onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1?0?ooh08000000`00
0?l4000000040<f5?`3oi>40cHDo0<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3=QCl30?oTh@030<f5
?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0<f5
?`3oi>400P3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oT
h@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@07
0<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ
0<f5?`020?oTh@80cHDo0P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3o
i>40onCQ0<f5?`030?oTh@80cHDo0P3oi>401P3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`80onCQ00D0
cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ0080cHDo00D0onCQ0<f5?`3oi>40
onCQ0<f5?`020?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1<0?ooh0<000000P000?l3000000060?oT
h@00000000000?oTh@3=QCl0onCQ0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080cHDo0`3oi>400`3=
QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3=
QCl0onCQ0080cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0cHDo0?oTh@3o
i>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>40
1`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oT
h@3=QCl00P3oi>420<f5?`80onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`050?oTh@3=QCl0
onCQ0?oTh@3=QCl00`3oi>420<f5?`80onCQ00H0cHDo0?oTh@3=QCl0cHDo0?oTh@3=QCl20?oTh@05
0<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`050?oTh@3=QCl0onCQ
0?oTh@3=QCl00P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPB03oon02000000030?ooh0000000003o
0080003o0`000000203oi>40cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@030<f5
?`3oi>40cHDo0080cHDo0`3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=
QCl00P3oi>401@3=QCl0onCQ0<f5?`3=QCl0onCQ0080cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0
onCQ0<f5?`80onCQ00@0cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ
00@0cHDo0?oTh@3oi>40cHDo0P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>40
1`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ00D0cHDo0?oTh@3oi>40
cHDo0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>420<f5?`80onCQ00H0cHDo0?oT
h@3=QCl0cHDo0?oTh@3=QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ
0?oTh@020<f5?`050?oTh@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0oooP0?ooh0090?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
A`3oon0300000080003o1@0000020?oTh@070<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0?oTh@020<f5
?`80onCQ00<0cHDo0?oTh@3=QCl00P3=QCl30?oTh@030<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oT
h@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0<f5?`3oi>400P3=QCl20?oTh@060<f5?`3o
i>40onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ
0080cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ
0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@80cHDo0P3oi>401@3=
QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`030?oTh@80cHDo0P3o
i>401P3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`80onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oT
h@030<f5?`3oi>40onCQ0080cHDo00D0onCQ0<f5?`3oi>40onCQ0<f5?`020?oTh@030<f5?`3oon00
oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00o`3oon140?ooh0<000000`000?l010000000cHDo0000000000020?oTh@040<f5?`3oi>40
onCQ0<f5?`80onCQ00@0cHDo0?oTh@3=QCl0onCQ0P3=QCl20?oTh@030<f5?`3oi>40cHDo0080cHDo
0`3oi>400`3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>401@3=QCl0
onCQ0<f5?`3=QCl0onCQ0080cHDo0P3oi>401P3=QCl0onCQ0?oTh@3=QCl0onCQ0<f5?`80onCQ00@0
cHDo0?oTh@3oi>40cHDo0P3oi>400`3=QCl0onCQ0?oTh@020<f5?`80onCQ00@0cHDo0?oTh@3oi>40
cHDo0P3oi>401`3=QCl0onCQ0?oTh@3oi>40cHDo0?oTh@3=QCl00P3oi>401`3=QCl0onCQ0?oTh@3o
i>40cHDo0?oTh@3=QCl00P3oi>420<f5?`80onCQ00D0cHDo0?oTh@3oi>40cHDo0?oTh@020<f5?`05
0?oTh@3=QCl0onCQ0?oTh@3=QCl00`3oi>420<f5?`80onCQ00H0cHDo0?oTh@3=QCl0cHDo0?oTh@3=
QCl20?oTh@050<f5?`3oi>40cHDo0?oTh@3=QCl00P3oi>400`3=QCl0onCQ0?oTh@020<f5?`050?oT
h@3=QCl0onCQ0?oTh@3=QCl00P3oi>400`3=QCl0oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh440oooP
0`0000030000o`<0000000@0onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@040<f5?`3oi>40cHDo0?oTh@80cHDo0P3oi>400`3=QCl0onCQ0<f5?`020<f5?`<0onCQ00<0cHDo
0?oTh@3=QCl00P3oi>401@3=QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0cHDo
0?oTh@020<f5?`80onCQ00H0cHDo0?oTh@3oi>40cHDo0?oTh@3=QCl20?oTh@040<f5?`3oi>40onCQ
0<f5?`80onCQ00<0cHDo0?oTh@3oi>400P3=QCl20?oTh@040<f5?`3oi>40onCQ0<f5?`80onCQ00L0
cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40cHDo0080onCQ00L0cHDo0?oTh@3oi>40onCQ0<f5?`3oi>40
cHDo0080onCQ0P3=QCl20?oTh@050<f5?`3oi>40onCQ0<f5?`3oi>400P3=QCl01@3oi>40cHDo0?oT
h@3oi>40cHDo00<0onCQ0P3=QCl20?oTh@060<f5?`3oi>40cHDo0<f5?`3oi>40cHDo0P3oi>401@3=
QCl0onCQ0<f5?`3oi>40cHDo0080onCQ00<0cHDo0?oTh@3oi>400P3=QCl01@3oi>40cHDo0?oTh@3o
i>40cHDo0080onCQ00<0cHDo0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooP@03o
on0200000080003o1@0000020?oTh@030<f5?`3oi>40cHDo0080onCQ00@0cHDo0?oTh@3oi>40cHDo
0P3oi>40103=QCl0onCQ0<f5?`3oi>420<f5?`80onCQ00<0cHDo0?oTh@3=QCl00P3=QCl30?oTh@03
0<f5?`3oi>40cHDo0080onCQ00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@050<f5?`3oi>40cHDo
0<f5?`3oi>400P3=QCl20?oTh@060<f5?`3oi>40onCQ0<f5?`3oi>40cHDo0P3oi>40103=QCl0onCQ
0?oTh@3=QCl20?oTh@030<f5?`3oi>40onCQ0080cHDo0P3oi>40103=QCl0onCQ0?oTh@3=QCl20?oT
h@070<f5?`3oi>40onCQ0?oTh@3=QCl0onCQ0<f5?`020?oTh@070<f5?`3oi>40onCQ0?oTh@3=QCl0
onCQ0<f5?`020?oTh@80cHDo0P3oi>401@3=QCl0onCQ0?oTh@3=QCl0onCQ0080cHDo00D0onCQ0<f5
?`3oi>40onCQ0<f5?`030?oTh@80cHDo0P3oi>401P3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`80onCQ
00D0cHDo0?oTh@3=QCl0onCQ0<f5?`020?oTh@030<f5?`3oi>40onCQ0080cHDo00D0onCQ0<f5?`3o
i>40onCQ0<f5?`020?oTh@030<f5?`3oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon04000000P0oooPo`00000f0000
00<0003oV@0000080?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03o
on0000001`3oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>Q
bP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gH
iP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:
0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>Q
bP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80
[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0903>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>Q
bP2]f>H0<j7:0P2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP2]
f>H203>QbP<0[MSV00X0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0200000080003o0P0cXLX200000:<0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh009
0?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:
0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0
[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>Q
bP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]
f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:
00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0903>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00<0
<j7:0:gHiP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP<0[MSV00X0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H20000000303>QbP000?l0003o00800000Y`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<00000
0?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gH
iP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP05
0:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0
[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0c
XLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H0
1@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV
0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H02@0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV0P0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX30:gHiP0:03>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<000000P000?l00`3oon0000000000
002X0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0
<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0
100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gH
iP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00T0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:0`2]f>H01`0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP2]f>H0100000020000o`800000Z`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gH
iP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]
f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80
[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gH
iP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]
f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0c
XLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX0
0P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0`2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0903>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX0102]
f>H0<j7:0:gHiP2]f>H203>QbP<0[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP03000000<0003o0`00
002/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0
<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0
100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gH
iP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00T0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:0`2]f>H00`0cXLX0[MSV
0:gHiP0300000080003o1000002^0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080
<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gH
iP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]
f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00T0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP040:gHiP0cXLX0[MSV0:gHiP80
<j7:0`2]f>H400000080003o0`00002a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>Q
bP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gH
iP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV
0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX2
0:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:
0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>Q
bP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:0P2]
f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00T0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:
0:gHiP0cXLX20:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP040:gHiP0cXLX0[MSV0:gH
iP80<j7:0P2]f>H300000080003o0`00002c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H2
03>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0
[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0
<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX3
0:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0
[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0
[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0c
XLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80
<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:
0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00T0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP040:gHiP0cXLX0[MSV
0:gHiPD000000P000?l300000;D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gH
iP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0c
XLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0c
XLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gH
iP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP07
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H02@0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV0P0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:00<0[MSV03>QbP2]f>H010000002
0000o`800000^03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV
03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gH
iP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0903>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H2
03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX500000080003o0P00002j0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
1@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]
f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gH
iP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
[MSV03>QbP020:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX3
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00T0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0:gHiP05
00000080003o0`00002k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0c
XLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>Q
bP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gH
iP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]
f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>Q
bP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>Q
bP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0
<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:0P2]f>H01`0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00T0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX2
0:gHiP80<j7:0P2]f>H00`0cXLX0[MSV0000000300000080003o00<0000003>QbP3oon00_@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP05
0:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0903>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP80[MSV00@0<j7:
00000000000000000P000?l200000<00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX2
0:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H0
0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX2
0:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gH
iP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H02@0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV0P0cXLX20000000503>QbP000000003o0000o`000000``3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV
03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gH
iP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV
0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>Q
bP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX30:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00T0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@000000P000?l200000<80oooP0`00000K0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0
<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0
<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV
0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]
f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H2
03>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0`2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0903>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP2]f>H0<j7:100000020000o`030000003oon00oooP0<D0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>Q
bP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:
00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>Q
bP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]
f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>Q
bP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0
<j7:0080[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H02@0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0000000<000000P000?l200000<P0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0c
XLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]
f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0
[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]
f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0
<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:
0080[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H02@0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP@000000P000?l200000<X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gH
iP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0c
XLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0c
XLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gH
iP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP07
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H0200cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:1@0000020000o`800000c03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh006
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0c
XLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gH
iP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:
03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0:gHiP0400000080003o0P00003>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080
<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gH
iP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]
f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gHiP80<j7:0P2]f>H0
1`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX300000080003o0P00003@0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
1@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]
f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gH
iP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0
[MSV03>QbP020:gHiP80<j7:0P2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX3
0:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0`0000020000o`<00000
d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>Q
bP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0
<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H2
03>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>Q
bP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
<j7:00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H000000080
00000P000?l200000=@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>Q
bP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gH
iP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:
0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:
0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP0703>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0c
XLX00000000000020000o`<00000e@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80
[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP02
03>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]
f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80
[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX2
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV
00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0303>QbP000?l0003o00<00000e`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>Q
bP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gH
iP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:
0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>Q
bP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80
[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0`2]f>H00`0cXLX0[MSV0:gHiP02
00000080003o00<0oooP000000000000f@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>Q
bP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gH
iP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:
0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>Q
bP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0c
XLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80
[MSV00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0`2]f>H300000080003o00<00000
03>QbP3oon00f`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV
03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gH
iP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]
f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV00L0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:0P2]f>H3000000040000o`000000000000000=d0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
1P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0
<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]
f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>Q
bP0cXLX0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gH
iP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP<000000P000?l300000=h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX2
0:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H0
0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX2
0:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gH
iP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:100000020000o`800000h@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>Q
bP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gH
iP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]
f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP02
0:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP020:gH
iP80<j7:0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV00<000000P000?l20000000303>QbP3oon00
oooP0=h0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP05
0:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H203>QbP80[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP020000
00040000o`000000000000000>@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gH
iP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0c
XLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0c
XLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gH
iP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP05
03>QbP2]f>H000000000002]f>H00P000?l200000>H0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:
03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV
03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gH
iP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080
[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP030:gHiP0303>QbP2]f>H0<j7:0080[MSV
0P0cXLX20:gHiP0303>QbP00000000000080003o00<0<j7:000000000000i`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0
[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H203>QbP@0000000@0003o000000000000<j7:j@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0
<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0c
XLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0
<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV
0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0
<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX000000000000000020000o`800000j`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:
0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
1`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:
0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gH
iP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H200000080003o0`00003/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>Q
bP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gH
iP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV
0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX2
0:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:
0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>Q
bP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00`2]f>H00`0cXLX0[MSV03>QbP0200000080003o0P00
003_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0
<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0
100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV
03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gH
iP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0
<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00`2]f>H01@0cXLX0[MSV000000000000003o00<00000l03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:
0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
1`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:
0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gH
iP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]f>H0<j7:
0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0[MSV0P0000020000o`<0
0000l@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>Q
bP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV
03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]
f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H01`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP06
03>QbP2]f>H0<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080[MSV0P00000010000?l0000000000000003c0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV
03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gH
iP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV
0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>Q
bP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0000020000o`800000m@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP05
0:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP00000000000080
003o0`00003f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
1@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:
0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0c
XLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0
<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV
00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gH
iP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080
[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV0P00
000010000?l0000000000000003h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080
<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gH
iP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]
f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80
[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0[MSV
03>QbP8000000P000?l300000?T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gH
iP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0c
XLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV
0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0c
XLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gH
iP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP2]f>H0
0P00000010000?l0000000000000003k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0<000002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>Q
bP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gH
iP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:
0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:
0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV03>QbP80[MSV0P0000000`2]f>H0003o0000o`02
00000?/0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP05
0:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0703>QbP2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP0200000080003o00<0<j7:000000000000oP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0
[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0<j7:03>QbP2]
f>H0<j7:0P00000010000?l000000000000cXL[o0?ooh040oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0
<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0
[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:
0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV03>QbP0cXLX0[MSV00000080003o
0P00003o0?ooh0<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP05
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]
f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0
[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP02000000040000o`000000000000000?l0oooP103oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0
[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080
[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0c
XLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01`0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H000000080
003o0`00003o0?ooh0D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>Q
bP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:
0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gH
iP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:
0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:
0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0c
XLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0c
XLX0[MSV0`00000010000?l0000000000000003o0?ooh0L0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0
<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0
[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:
0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`00000010000?l0000000000000003o0?ooh0P0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
1P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0c
XLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0
<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]
f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00L0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX000000P000?l300000?l0oooP
2@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>Q
bP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0
<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H2
03>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080
<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1`0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP000?l300000?l0
oooP2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>Q
bP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV
03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP03
03>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gH
iP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]
f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>Q
bP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV
0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H0200cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0`0000000`000?l0oooP0?ooh03o0?oo
h0d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP04
03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0
[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV
00L0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:008000000P000?l00`000000oooP0?ooh03o0?oo
h0d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP04
03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0
[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP02
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV
00D0<j7:0:gHiP0cXLX0[MSV03>QbP03000000040000o`000000000000000?l0oooP3`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh006
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0c
XLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gH
iP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0100cXLX0[MSV
03>QbP2]f>H3000000040000o`000000000000000?l0oooP403oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V3@3oon04000000L0oooP00<000000?ooh03oon002@3oon001P0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0
<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gH
iP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:
0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP000000
0P0000020000o`030000003oon00oooP0?l0oooP4@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V3@3oon000`000000oooP0?ooh0080?ooh0030000003oon00oooP00T0oooP00H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>Q
bP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV
03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP03
03>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP000000
0000000000000?l00P00003o0?ooh1@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iPh0oooP00<000000?ooh03oon001`3oon04000000P0oooP00H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>Q
bP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gH
iP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]
f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP02
0:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV
00L0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0[MSV00@0000000<0003o0000003oon00o`3oon0B0?oo
h0@000006`3oon0N0?[`iP40oooo000M0?[`iPl0oooP00<000000?ooh03oon001P3oon000`000000
oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0
[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>Q
bP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP05
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0`0000020000o`030000003oon00oooP0?l0oooP5@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP
00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0
<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV
03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0
[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gH
iP0303>QbP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2000000030000o`00
000000000?l0oooP603oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02
000000P0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX2
0:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H0
0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX2
0:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80003o00<000000?ooh03oon00o`3oon0H0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100c
XLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>Q
bP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0c
XLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0
<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0
[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0000000`000?l0oooP0?ooh03o0?ooh1/0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:
0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0
<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H01P0cXLX00000000000000000003o00000?l0oooP7@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80
[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0
[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080
[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0c
XLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100c
XLX0[MSV03>QbP2]f>H300000080003o0P00003o0?ooh1d0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0
<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0
[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:
0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00<0<j7:0:gHiP0cXLX00`00
000010000?l0000000000000003o0?ooh1h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80
<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0c
XLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0
[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]
f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0c
XLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX000000P000?l20000
0?l0oooP803oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0
[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>Q
bP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP05
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0
[MSV0080<j7:0P2]f>H0100cXLX00000000000000?l200000?l0oooP8P3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0
<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0c
XLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0
<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV
0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP0303>QbP2]f>H0[MSV0080<j7:00<0[MSV000000000000
0P000?l00`000000oooP0?ooh03o0?ooh280oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80
<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0c
XLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0
[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]
f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]
f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0c
XLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0
<j7:0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80000000@0003o0000000000000000o`3oon0T0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0
[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]
f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:
00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00<0<j7:0:gHiP2]f>H00`000000
10000?l0000000000000003o0?ooh2D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX2
0:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0
[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H0
0P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX2
0:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H0100cXLX0[MSV0000000000020000o`800000o`3oon0W0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0
[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP07
0:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0
[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV
03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0<j7:03>QbP80[MSV00@0<j7:000000000000003o0P00003o0?ooh2T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:
0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP02
0:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0
<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H00`0cXLX0003o0000o`0200000?l0oooP:P3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]
f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]
f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>Q
bP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV00@0003o0?ooh00000000000o`3oon0Y0?ooh0<0
00006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP04
03>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP05
03>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gH
iP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0cXLX00P0000000`000?l0<j7:0?ooh03o0?ooh2d0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP04
03>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP05
03>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gH
iP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV00<0<j7:0:gHiP0000000P000?l00`000000<j7:0?ooh03o0?ooh2d0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP04
03>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP05
03>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gH
iP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080
[MSV0P00000010000?l0000000000000003o0?ooh2l0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:
03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP05
03>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV
03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gH
iP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080
[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80000000@0003o
0000000000000000o`3oon0`0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV
0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]
f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H2
03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:
0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]
f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:
0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP04
03>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H2
03>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP02000000030000o`00000000000?l0oooP<P3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:
0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]
f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0
[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>Q
bP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0cXLX20:gHiP0503>QbP2]f>H0
<j7:0:gHiP0cXLX00P000?l200000?l0oooP<`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP03
0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:
03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:
0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:
0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080
<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H2
03>QbP80[MSV0P0cXLX20:gHiP0603>QbP2]f>H0<j7:0:gHiP000?l0oooP0P00003o0?ooh3@0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]
f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
1@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX20:gHiP80<j7:0P2]f>H01@0cXLX0[MSV0000
00000?l0<j7:0?l0oooP=`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV
00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0c
XLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]
f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV
03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80
[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100c
XLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P0c
XLX20:gHiP03000000000?l0003o00800000o`3oon0g0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>Q
bP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
1@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gH
iP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]
f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP02
0:gHiP80<j7:0P2]f>H203>QbP030:gHiP000000003o00@00000o`3oon0g0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
1@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]
f>H0[MSV03>QbP020:gHiP80<j7:0P2]f>H0100cXLX00000000000000?l400000?l0oooP>03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP05
0:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP80[MSV0P00000010000?l0000000000000003o
0?ooh3X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gH
iP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100c
XLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gH
iP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]
f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0
[MSV0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV0P0cXLX0102]f>H000000000o`000?l2
00000?l0oooP?03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV
03>QbP2]f>H203>QbP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P2]f>H203>QbP030:gHiP000?l00000
00800000o`3oon0m0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0
102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0c
XLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80
<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H0
1@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]
f>H0<j7:0:gHiP80<j7:00D0[MSV03>QbP2]f>H0[MSV03>QbP020:gHiP0403>QbP000000003o0:gH
iP800000o`3oon0n0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<0
00002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP04
03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:0:gHiP2]f>H0<j7:0080[MSV00D000000000o`000000000003>QbP3o0?oo
h3d0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh006
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0c
XLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:
0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>Q
bP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP080:gH
iP0cXLX0[MSV0:gHiP0cXLX0[MSV000000000?l300000?l0oooP@03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:
0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
1`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:
0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>Q
bP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0[MSV0:gH
iP80000000@0003o0000000000000000o`3oon110?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:
00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0c
XLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0c
XLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0c
XLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H0
0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP2]f>H000000P000?l30000
0?l0oooP@P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0
[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gH
iP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:
0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>Q
bP2]f>H203>QbP040:gHiP0cXLX000000000o`<00000o`3oon140?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0
[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP07
0:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0
[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP2]f>H00P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P00000010000?l000000000
0000003o0?ooh4D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP05
03>QbP2]f>H0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP80[MSV00D0<j7:0:gH
iP0cXLX0[MSV03>QbP02000000040000o`000000000000000?l0oooPAP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0
<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0c
XLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0
<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP03
03>QbP2]f>H0[MSV0080<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H2000000040000o`0000000000
00000?l0oooPA`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gH
iP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX0
0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP02
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0
<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV0080<j7:0P2]f>H00`0cXLX0[MSV
03>QbP02000000030000o`00000000000?l0oooPB@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0
<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0
<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0
<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0[MSV
0080<j7:0P2]f>H01@0cXLX00000000000000000003o00800000o`3oon1:0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0
1@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080[MSV
00<0<j7:0:gHiP2]f>H00P0cXLX20:gHiP<0000000<0003o000000000000o`3oon1;0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>Q
bP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:
0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX01@2]f>H00000000000000000003o00800000o`3oon1<
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:
03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100c
XLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>Q
bP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP2]f>H00P0cXLX200000080003o0P00003o0?ooh4d0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]
f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0<j7:0:gH
iP0cXLX00P2]f>H00`0cXLX0[MSV0:gHiP0203>QbP04000000000?l0000000000?l0oooPC`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV
03>QbP020:gHiP0303>QbP2]f>H0[MSV0080000000<0003o000000000000o`3oon1@0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:
0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>Q
bP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX0
0P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV0080<j7:0P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:
0080[MSV00H0<j7:0:gHiP00000000000000o`00003o0?ooh580oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP03
0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:
03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:
0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:
0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:
0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP0403>QbP00000000000000
o`800000o`3oon1@0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP04
03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0c
XLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0503>QbP2]f>H0
<j7:0:gHiP0cXLX00P2]f>H2000000030000o`00000000000?l0oooPD`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0
<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0c
XLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0
<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP020:gHiP04
000000000?l0000000000?l0oooPE03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80
[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0
<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]
f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP02
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P000000102]f>H0003o00000000003o0?ooh5D0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gH
iP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]
f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gH
iP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP0303>QbP2]f>H0<j7:00<0
000000<0003o03>QbP3oon00o`3oon1F0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>Q
bP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gH
iP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV
0080<j7:0P2]f>H0100cXLX0[MSV0000000000020000o`030000003oon00oooP0?l0oooPEP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV
0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0
<j7:0080[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP0203>QbP80[MSV00@0<j7:0:gHiP000000003o
0P00003o0?ooh5T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX0
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0[MSV03>QbP2]f>H00P0cXLX20:gHiP80
000000<0003o000000000000o`3oon1J0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>Q
bP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:
0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gH
iP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gH
iP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV
0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H01@0cXLX0[MSV0:gHiP0cXLX0[MSV
0080<j7:00D0[MSV000000000000003o0000003o0?ooh5`0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0
<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gH
iP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H0
[MSV03>QbP2]f>H00P0cXLX2000000030000o`00000000000?l0oooPG03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0
<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0c
XLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0
<j7:0:gHiP2]f>H0<j7:0:gHiP03000000030000o`00000000000?l0oooPG@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00D0<j7:0:gHiP2]f>H0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP2]f>H0<j7:0`0000000`000?l000000000003o0?ooh5h0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP04
03>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP03
03>QbP2]f>H0[MSV00<0000000<0003o000000000000o`3oon1O0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0
[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP07
0:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV00000002000000030000o`000000oooP0?l0oooPH03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V3`3oon03000000H0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP04
03>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gH
iP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0[MSV03>QbP020:gHiP03
03>QbP2]f>H000000080003o00<000000?ooh03oon00o`3oon1P0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0030000003oon00oooP00D0oooP00<000000?ooh03oon00
2@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>Q
bP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP80000000<0003o000000000000o`3oon1S0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0D000001P3oon04000000P0oooP00H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0
<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0
[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP07
0:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H01@0cXLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0000000`00
0?l0000003>QbP3o0?ooh640oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000
oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:
00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0c
XLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0c
XLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0c
XLX0[MSV0:gHiP2]f>H0<j7:0080[MSV00H0<j7:0:gHiP0cXLX0[MSV000000000?l200000?l0oooP
I@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon000`000000oooP0000
00070?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H01@0cXLX0[MSV0:gH
iP2]f>H0<j7:0080[MSV00D0<j7:0:gHiP00000000000000o`0200000?l0oooPIP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3`3oon02000000L0oooP00<000000?ooh03oon00
2@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>Q
bP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP2]f>H0[MSV0:gHiP0cXLX00P2]f>H01P0cXLX0
0000000000000?l0000003>Qb_l0oooPI`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>Q
bP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]
f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D0<j7:0:gH
iP2]f>H0[MSV03>QbP020:gHiP80000000<0003o000000000000o`3oon1X0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080
[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0
100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H0100cXLX0[MSV0:gHiP2]f>H203>QbP80000000<0003o000000000000o`3oon1Y
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:
03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gH
iP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100c
XLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0603>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H0200cXLX0[MSV0:gHiP2]f>H0<j7:0?ooh0000000003o
0P00003o0?ooh6X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0c
XLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0703>QbP2]f>H0[MSV0:gHiP0cXLX0
oooP0000o`0200000?l0oooPJ`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV
0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:
0:gHiP0cXLX00`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00H0<j7:0:gHiP2]f>H0
[MSV03>QbP000?oo0?ooh6h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H2
03>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80
<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0
[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:00<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP00000000000:gH
iP000?l0o`3oon1_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0
102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0c
XLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0
[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80
<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>Q
bP030:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H3000000030000o`0cXLX0oooP0?l0
oooPKP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>Q
bP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV
03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00D000000000o`000?l0000003>QbP3o0?ooh6l0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>Q
bP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP030000o`00000000000?l0oooPL@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H01@0cXLX0[MSV0:gHiP0cXLX0
[MSV0080000000<0003o03>QbP3oon00o`3oon1b0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:
00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0c
XLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0c
XLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP2]f>H0[MSV03>QbP80000000<0003o0000000c
XLX0o`3oon1c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
1@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:
0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP03
0:gHiP0303>QbP2]f>H0[MSV0080000000@0003o000000000000<j7:o`3oon1c0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon001P0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0c
XLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100c
XLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]
f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:
0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0
[MSV03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:00<0[MSV00D0<j7:0:gHiP2]f>H000000000o`020000
0?l0oooPL`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0
[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP0403>QbP00
000000000000o`800000o`3oon1f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]
f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP06
03>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP030:gHiP80000000<0003o0000003oon00o`3oon1g0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100c
XLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>Q
bP070:gHiP0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP030:gHiP04000000000?l0000000000?l0oooP
N03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>Q
bP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0
<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX00`2]f>H00`00
0?l000000000003o0?ooh7T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H2
03>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80
<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0
[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0080[MSV00<0003o03>QbP3oon00o`3oon1j0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>Q
bP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0c
XLX0[MSV0:gHiP0cXLX00`0000000`000?l0[MSV03>QbP3o0?ooh7/0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>Q
bP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:
00@0[MSV03>QbP2]f>H0[MSV0`00000010000?l0000003>QbP0cXL[o0?ooh7/0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0
<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX0
0P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gH
iP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:0:gH
iP80<j7:00@0[MSV03>QbP2]f>H0[MSV0P0000000`000?l000000000003o0?ooh7d0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0c
XLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX2
0:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP03
03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0403>QbP2]f>H0<j7:
0:gHiP80<j7:00H0[MSV03>QbP2]f>H0[MSV03>QbP000?l200000?l0oooPOP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP02
0:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV
00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:000000000000003o0?l0oooPP@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP02
03>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0c
XLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX01@2]f>H0
0000000000000?l000000?l0oooPP@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80
[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H0
1P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H000000000o`020000
0?l0oooPP@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0
[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV00D0<j7:0:gHiP0cXLX0[MSV03>QbP02000000030000o`00000000000?l0oooPPP3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh006
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP2]f>H203>QbP80[MSV00@0<j7:0:gHiP0c
XLX0[MSV0P0000000`000?l000000?ooh03o0?ooh8<0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:
03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV
00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0303>QbP2]f>H0<j7:0080000000<0003o00000000
0000o`3oon240?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000
2@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0
<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV
0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP0503>Q
bP2]f>H00000000000000?l00P00003o0?ooh8<0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV
0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0c
XLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV00@0<j7:000000000000003o0P00003o0?ooh8H0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP04
03>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]
f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80000000<0003o000000000000
o`3oon270?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]
f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0
<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>Q
bP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80<j7:0`00
00000`000?l000000000003o0?ooh8P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX2
0:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV
00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00D0<j7:0:gH
iP0cXLX0[MSV03>QbP03000000030000o`00000000000?l0oooPR@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP04
03>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:
0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0c
XLX00P2]f>H01@0cXLX0[MSV03>QbP2]f>H0<j7:0080000000<0003o000000000000o`3oon2:0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:0:gHiP80000000<0003o0000003o
on00o`3oon2;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
1@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0303>QbP2]f>H0<j7:0080000000<0
003o0000003oon00o`3oon2<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV
0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]
f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H2
03>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>Q
bP2]f>H0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP020:gHiP0503>QbP2]f>H00000
000000000?l00P00003o0?ooh8d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gH
iP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0
<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@0<j7:00000000
0000003o0P00003o0?ooh8h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H2
03>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80
<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:
0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV0P0000000`000?l00000
0000003o0?ooh8l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0[MSV00H0<j7:0:gHiP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080[MSV00@000000000o`0000000000o`3o
on2@0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0
<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:
0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP02000000030000o`00000000000?l0oooPT@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh006
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX0[MSV0:gHiP0cXLX0[MSV03>QbP80[MSV
00H0<j7:0:gHiP00000000000000o`00003o0?ooh9<0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV
03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:
03>QbP<0[MSV00H0<j7:0:gHiP2]f>H0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H000000000o`80
0000o`3oon2C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
1@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV
00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV0000o`0200000?l0oooPU03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gH
iP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]f>H0<j7:0P2]f>H0100cXLX0[MSV03>Q
bP0cXLX30:gHiP0703>QbP2]f>H0[MSV03>QbP2]f>H0<j7:0:gHiP02000000030000o`0cXLX0oooP
0?l0oooPT`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H0100cXLX0[MSV03>QbP0cXLX30:gHiP0603>QbP2]f>H0[MSV03>QbP2]f>H0<j7:
0P0000000`000?l0000003>QbP3o0?ooh9H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80
<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0c
XLX20:gHiP80<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0
[MSV00D0<j7:0:gHiP2]f>H0<j7:0:gHiP02000000040000o`000000000003>Qb_l0oooPUP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0
[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV
03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H0100cXLX0[MSV0:gHiP0cXLX3000000030000
o`000000oooP0?l0oooPU`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV
00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0c
XLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H00`0cXLX0
[MSV0:gHiP03000000030000o`000000oooP0?l0oooPV03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP02
03>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]
f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0c
XLX0<j7:0`2]f>H00`0cXLX0[MSV00000002000000030000o`000000oooP0?l0oooPV@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh006
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV
03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>Q
bP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01P0cXLX00000000000000000003o00000?l0oooP
V`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>Q
bP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]
f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H01@0cXLX00000000000000?l00000
0?l0oooPW03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0
[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00@0<j7:0:gHiP0cXLX0<j7:0`2]f>H0100cXLX0oooP0000o`00
003o0?ooh9d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gH
iP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP05
0:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0
100cXLX0[MSV0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0000000`000?l0oooP
0?ooh03o0?ooh9d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:0P0000000`000?l00000
0?ooh03o0?ooh9h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]
f>H0100cXLX0[MSV0:gHiP0cXLX20:gHiP0703>QbP2]f>H0<j7:03>QbP3oon0000000000o`020000
0?l0oooPW`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0
[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP04
03>QbP2]f>H0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0000000`000?l000000000003o0?oo
h:00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0c
XLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H0100cXLX0
[MSV0:gHiP0cXLX20:gHiP0603>QbP2]f>H00000000000000?l00000o`3oon2R0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0<00000203oon000`000000oooP0?ooh009
0?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0
[MSV03>QbP80[MSV00@0<j7:000000000000003o0P00003o0?ooh:80oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP
0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>Q
bP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV
03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>Q
bP2]f>H0[MSV03>QbP80[MSV0P0000000`000?l000000000003o0?ooh:<0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon04000000P0
oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>Q
bP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00@0<j7:0:gHiP2]
f>H0<j7:0P2]f>H010000000003o00000000003o0?ooh:40oooP1000000K0?ooh1h0n_3V0@3oool0
01d0n_3V3@3oon03000000P0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0
[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H01`0cXLX0[MSV0:gHiP0cXLX0[MSV000000000?l00P00
003o0?ooh:D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<00000
0?ooh03oon001`3oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP03
0:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:
03>QbP80[MSV0P0cXLX30:gHiP0403>QbP2]f>H0[MSV03>QbP80000000<0003o0000003oon00o`3o
on2U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0<000001`3oon00
0`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:
00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0
<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX3
0:gHiP0603>QbP2]f>H0[MSV03>QbP000000003o0P00003o0?ooh:H0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0
100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0`2]f>H01@0cXLX0[MSV000000000000003o00800000
o`3oon2W0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]
f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0cXLX0<j7:0P2]f>H203>QbP<0[MSV00D0
<j7:000000000000003o0000003o0?ooh:T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80
<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0c
XLX20:gHiP80<j7:0`2]f>H00`0cXLX000000000o`0200000?l0oooPZ@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0
[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gH
iP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX30:gHiP0403>QbP000?l0000000000?l0oooPZP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0c
XLX0[MSV03>QbP020:gHiP0403>QbP2]f>H0<j7:03>QbP80[MSV0P0cXLX0102]f>H0000000000000
0?oo0?ooh:d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gH
iP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP05
0:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP80<j7:0P000000
0`000?l000000?ooh03o0?ooh:`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]
f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0100cXLX0[MSV03>QbP0cXLX20:gH
iP80<j7:00@000000000o`0000000000o`3oon2]0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:
00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00@0<j7:0:gHiP0c
XLX0<j7:0P2]f>H00`0cXLX000000000o`0200000?l0oooP[P3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>Q
bP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>Q
bP2]f>H0<j7:03>QbP80[MSV0P0000000`000?l000000?ooh03o0?ooh:h0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]
f>H0100cXLX0[MSV03>QbP0cXLX20:gHiP04000000000?l0000000000?l0oooP[`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>Q
bP020:gHiP0403>QbP2]f>H0<j7:03>QbP80000000<0003o000000000000o`3oon2`0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gH
iP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:0080[MSV00<0<j7:0:gHiP0cXLX00P0000000`000?l000000?ooh03o0?ooh;40oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh00603>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP05
03>QbP2]f>H00000000000000?l00P00003o0?ooh;00oooP0`00000K0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00D0[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0403>QbP00000000000000o`80
0000o`3oon2c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
1@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV0P0000000`000?l000000000003o0?ooh;@0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
1P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80
[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP060:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV0P0000000`000?l000000000003o0?ooh;D0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV000000000?l2
00000?l0oooP]P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00D0[MSV03>QbP0cXLX0[MSV03>QbP02000000030000o`000000oooP0?l0oooP]P3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP0cXLX0[MSV03>Q
bP000000003o00800000o`3oon2g0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP02000000030000o`00000000000?l0oooP^03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh006
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00H0[MSV03>QbP0000000000
0000o`00003o0?ooh;X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>Q
bP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP040:gHiP0cXLX000000000o`800000o`3oon2j0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
<j7:00<0[MSV03>QbP2]f>H00`0cXLX2000000030000o`00000000000?l0oooP^`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:0`0000000`000?l0oooP0?ooh03o
0?ooh;/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX0102]f>H0<j7:0:gHiP0cXLX300000003
0000o`000000oooP0?l0oooP_03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gH
iP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0
[MSV00<0000000<0003o000000000000o`3oon2m0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:
00<0[MSV03>QbP0000000P0000000`000?l000000000003o0?ooh;h0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0cXLX00P0cXLX01P2]f>H00000000000000000003o00000?l0oooP`03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
<j7:00D0[MSV000000000000003o0000003o0?ooh;l0oooP0`00000K0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX2
0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP<0000000<0
003o0000003oon00o`3oon300?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV
0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP<0000000<0003o0000
003oon00o`3oon310?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0
102]f>H0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP80000000<0003o0000003oon00
o`3oon320?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080000000<0003o0000003oon00o`3oon330?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP0603>QbP2]f>H00000000000000?l00000o`3oon350?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0403>QbP000000
00000000o`800000o`3oon350?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV
0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP<0000000<0003o0000003oon00o`3oon350?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX2
0:gHiP80000000<0003o0000003oon00o`3oon360?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP000?l000000?l0oooP
b03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00<0[MSV03>QbP2]
f>H00P0000000`2]f>H0003o0?ooh03o0?ooh<T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP80<j7:0P2]f>H203>QbP030:gHiP0cXLX000000080000000<0003o03>QbP3oon00o`3oon390?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0cXLX01`2]f>H0<j7:00000000
0000003o0000000cXLX0o`3oon3:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80
[MSV0P0cXLX01@2]f>H00000000000000000003o0?l0oooPc03oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX20:gHiP80<j7:00D0[MSV000000000000003o0000003o0?ooh<`0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
1P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H203>QbP80000000<0003o0000003oon00
o`3oon3<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3o
on001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P2]f>H01@0cXLX00000000000000?l00000
0?l0oooPc03oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80[MSV0P0000000`000?l000000000003o
0?ooh<h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV000000000000003o
0P00003o0?ooh<l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0P0000000`000?l0
00000000003o0?ooh=00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001P0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00@000000000
o`0000000000o`3oon3A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP030?ooh000
0?l000000?l0oooPdP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00603>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0000000`000?l0oooP
0?ooh03o0?ooh=80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon001@0cXLX0[MSV03>QbP2]f>H0<j7:0080000000<0003o0000003oon00
o`3oon3C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00@0<j7:0:gHiP0cXLX0[MSV0P0000000`000?l000000000003o0?ooh=@0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on001P0cXLX0[MSV03>QbP2]f>H000000000o`800000o`3oon3E0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00D0<j7:0:gHiP000000
00000000o`0200000?l0oooPeP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00503>QbP00000000000000o`000000o`3oon3H0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00D0<j7:000000000000003o0000003o0?ooh=P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00T0oooP0P0000000`000?l00000
0?ooh03o0?ooh=P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@0
00000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh004000000000?l0000000000?l0
oooPf@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP
0?ooh00000070?ooh0@00000203oon000`000?l000000000003o0?ooh=L0oooP1000000K0?ooh1h0
n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP
00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H>0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon00BP3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?oo
h03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh?l00000jP00000K0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00d@3jl>H400000080n_3V2000
00020?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V00000000
000010000000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V
00<00000203jl>H500000080n_3V100000020?[`iPD00000303jl>H300000140n_3V0`0000060?[`
iP<0000000@0n_3V00000000000000001P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V
0000000000000000f03jl>H10?ooo`00dP3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H2
000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H200000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H010000000n_3V
0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V
008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V0P0000000`3j
l>H000000000000?0?[`iP80000000<0n_3V0000000000001P3jl>H2000000030?[`iP0000000000
00L0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000=T0n_3V0@3oool00=80
n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H0
00000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000d0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3j
l>H000000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`
iP80000000<0n_3V0000000000001@3jl>H5000000D0n_3V0P0000000`3jl>H00000000000070?[`
iP<000001P3jl>H5000000H0n_3V0`00003J0?[`iP40oooo003B0?[`iPD00000103jl>H2000000<0
n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`000003
0?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V0P00
00030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80000000<0n_3V0000000000003`3j
l>H2000000030?[`iP000000000000L0n_3V0`0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00
003J0?[`iP40oooo003B0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2
000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`
iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H02P3jl>H300000100n_3V100000070?[`iP80
000000<0n_3V0000000000001`3jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V00000000
0000f@3jl>H10?ooo`00dP3jl>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V
100000000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V
0P0000050?[`iP<0000000<0n_3V0000000000001`00000:0?[`iPD000000P3jl>H400000080n_3V
0`0000000`3jl>H000000000000:0?[`iP80000000<0n_3V0000000000003`3jl>H2000000P0n_3V
0`000000103jl>H0000000000000000=0?[`iP<0000000<0n_3V0000000000001@00003D0?[`iP40
oooo003B0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V01L0n_3V
0P00000J0?[`iP80000000<0n_3V000000000000403jl>H2000002<0n_3V00<000000?[`iP3jl>H0
e03jl>H10?ooo`00d@3jl>H6000000@0n_3V0P00000_0?[`iPD000006P3jl>H3000001T0n_3V0`00
000B0?[`iP<000008P3jl>H00`000000n_3V0?[`iP3C0?[`iP40oooo003o0?[`iX<0n_3V00<00000
0?[`iP3jl>H0dP3jl>H10?ooo`00o`3jl>J00?[`iP040000003jl>H0n_3V00000=@0n_3V0@3oool0
0?l0n_3VP@3jl>H200000=D0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .60227 L
.02686 .60227 L
.02686 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .60227 L
.02686 .60227 L
.02686 .08012 L
s
.678 .847 .902 r
.02686 .08012 m
.02686 .59647 L
.03123 .59647 L
.03123 .08012 L
F
.2 .63 .79 r
.02686 .08012 m
.02686 .59647 L
.03123 .59647 L
.03123 .08012 L
s
.678 .847 .902 r
.03123 .08012 m
.03123 .59056 L
.03592 .59056 L
.03592 .08012 L
F
.2 .63 .79 r
.03123 .08012 m
.03123 .59056 L
.03592 .59056 L
.03592 .08012 L
s
.678 .847 .902 r
.03592 .08012 m
.03592 .58822 L
.03773 .58822 L
.03773 .08012 L
F
.2 .63 .79 r
.03592 .08012 m
.03592 .58822 L
.03773 .58822 L
.03773 .08012 L
s
.678 .847 .902 r
.03773 .08012 m
.03773 .58599 L
.03947 .58599 L
.03947 .08012 L
F
.2 .63 .79 r
.03773 .08012 m
.03773 .58599 L
.03947 .58599 L
.03947 .08012 L
s
.678 .847 .902 r
.03947 .08012 m
.03947 .58255 L
.04263 .58255 L
.04263 .08012 L
F
.2 .63 .79 r
.03947 .08012 m
.03947 .58255 L
.04263 .58255 L
.04263 .08012 L
s
.678 .847 .902 r
.04263 .08012 m
.04263 .57836 L
.04614 .57836 L
.04614 .08012 L
F
.2 .63 .79 r
.04263 .08012 m
.04263 .57836 L
.04614 .57836 L
.04614 .08012 L
s
.678 .847 .902 r
.04614 .08012 m
.04614 .57414 L
.04834 .57414 L
.04834 .08012 L
F
.2 .63 .79 r
.04614 .08012 m
.04614 .57414 L
.04834 .57414 L
.04834 .08012 L
s
.678 .847 .902 r
.04834 .08012 m
.04834 .57106 L
.05252 .57106 L
.05252 .08012 L
F
.2 .63 .79 r
.04834 .08012 m
.04834 .57106 L
.05252 .57106 L
.05252 .08012 L
s
.678 .847 .902 r
.05252 .08012 m
.05252 .56528 L
.05547 .56528 L
.05547 .08012 L
F
.2 .63 .79 r
.05252 .08012 m
.05252 .56528 L
.05547 .56528 L
.05547 .08012 L
s
.678 .847 .902 r
.05547 .08012 m
.05547 .56385 L
.05778 .56385 L
.05778 .08012 L
F
.2 .63 .79 r
.05547 .08012 m
.05547 .56385 L
.05778 .56385 L
.05778 .08012 L
s
.678 .847 .902 r
.05778 .08012 m
.05778 .56089 L
.06012 .56089 L
.06012 .08012 L
F
.2 .63 .79 r
.05778 .08012 m
.05778 .56089 L
.06012 .56089 L
.06012 .08012 L
s
.678 .847 .902 r
.06012 .08012 m
.06012 .55904 L
.06187 .55904 L
.06187 .08012 L
F
.2 .63 .79 r
.06012 .08012 m
.06012 .55904 L
.06187 .55904 L
.06187 .08012 L
s
.678 .847 .902 r
.06187 .08012 m
.06187 .55507 L
.06566 .55507 L
.06566 .08012 L
F
.2 .63 .79 r
.06187 .08012 m
.06187 .55507 L
.06566 .55507 L
.06566 .08012 L
s
.678 .847 .902 r
.06566 .08012 m
.06566 .54961 L
.0704 .54961 L
.0704 .08012 L
F
.2 .63 .79 r
.06566 .08012 m
.06566 .54961 L
.0704 .54961 L
.0704 .08012 L
s
.678 .847 .902 r
.0704 .08012 m
.0704 .54662 L
.07382 .54662 L
.07382 .08012 L
F
.2 .63 .79 r
.0704 .08012 m
.0704 .54662 L
.07382 .54662 L
.07382 .08012 L
s
.678 .847 .902 r
.07382 .08012 m
.07382 .54172 L
.07742 .54172 L
.07742 .08012 L
F
.2 .63 .79 r
.07382 .08012 m
.07382 .54172 L
.07742 .54172 L
.07742 .08012 L
s
.678 .847 .902 r
.07742 .08012 m
.07742 .5386 L
.08093 .5386 L
.08093 .08012 L
F
.2 .63 .79 r
.07742 .08012 m
.07742 .5386 L
.08093 .5386 L
.08093 .08012 L
s
.678 .847 .902 r
.08093 .08012 m
.08093 .53237 L
.08502 .53237 L
.08502 .08012 L
F
.2 .63 .79 r
.08093 .08012 m
.08093 .53237 L
.08502 .53237 L
.08502 .08012 L
s
.678 .847 .902 r
.08502 .08012 m
.08502 .52863 L
.08802 .52863 L
.08802 .08012 L
F
.2 .63 .79 r
.08502 .08012 m
.08502 .52863 L
.08802 .52863 L
.08802 .08012 L
s
.678 .847 .902 r
.08802 .08012 m
.08802 .52502 L
.08995 .52502 L
.08995 .08012 L
F
.2 .63 .79 r
.08802 .08012 m
.08802 .52502 L
.08995 .52502 L
.08995 .08012 L
s
.678 .847 .902 r
.08995 .08012 m
.08995 .5229 L
.09348 .5229 L
.09348 .08012 L
F
.2 .63 .79 r
.08995 .08012 m
.08995 .5229 L
.09348 .5229 L
.09348 .08012 L
s
.678 .847 .902 r
.09348 .08012 m
.09348 .51525 L
.09806 .51525 L
.09806 .08012 L
F
.2 .63 .79 r
.09348 .08012 m
.09348 .51525 L
.09806 .51525 L
.09806 .08012 L
s
.678 .847 .902 r
.09806 .08012 m
.09806 .51431 L
.10091 .51431 L
.10091 .08012 L
F
.2 .63 .79 r
.09806 .08012 m
.09806 .51431 L
.10091 .51431 L
.10091 .08012 L
s
.678 .847 .902 r
.10091 .08012 m
.10091 .51003 L
.10456 .51003 L
.10456 .08012 L
F
.2 .63 .79 r
.10091 .08012 m
.10091 .51003 L
.10456 .51003 L
.10456 .08012 L
s
.678 .847 .902 r
.10456 .08012 m
.10456 .50421 L
.10848 .50421 L
.10848 .08012 L
F
.2 .63 .79 r
.10456 .08012 m
.10456 .50421 L
.10848 .50421 L
.10848 .08012 L
s
.678 .847 .902 r
.10848 .08012 m
.10848 .5015 L
.11314 .5015 L
.11314 .08012 L
F
.2 .63 .79 r
.10848 .08012 m
.10848 .5015 L
.11314 .5015 L
.11314 .08012 L
s
.678 .847 .902 r
.11314 .08012 m
.11314 .49767 L
.11562 .49767 L
.11562 .08012 L
F
.2 .63 .79 r
.11314 .08012 m
.11314 .49767 L
.11562 .49767 L
.11562 .08012 L
s
.678 .847 .902 r
.11562 .08012 m
.11562 .4941 L
.11895 .4941 L
.11895 .08012 L
F
.2 .63 .79 r
.11562 .08012 m
.11562 .4941 L
.11895 .4941 L
.11895 .08012 L
s
.678 .847 .902 r
.11895 .08012 m
.11895 .49065 L
.12114 .49065 L
.12114 .08012 L
F
.2 .63 .79 r
.11895 .08012 m
.11895 .49065 L
.12114 .49065 L
.12114 .08012 L
s
.678 .847 .902 r
.12114 .08012 m
.12114 .4866 L
.12373 .4866 L
.12373 .08012 L
F
.2 .63 .79 r
.12114 .08012 m
.12114 .4866 L
.12373 .4866 L
.12373 .08012 L
s
.678 .847 .902 r
.12373 .08012 m
.12373 .48548 L
.12543 .48548 L
.12543 .08012 L
F
.2 .63 .79 r
.12373 .08012 m
.12373 .48548 L
.12543 .48548 L
.12543 .08012 L
s
.678 .847 .902 r
.12543 .08012 m
.12543 .48068 L
.12935 .48068 L
.12935 .08012 L
F
.2 .63 .79 r
.12543 .08012 m
.12543 .48068 L
.12935 .48068 L
.12935 .08012 L
s
.678 .847 .902 r
.12935 .08012 m
.12935 .47783 L
.13336 .47783 L
.13336 .08012 L
F
.2 .63 .79 r
.12935 .08012 m
.12935 .47783 L
.13336 .47783 L
.13336 .08012 L
s
.678 .847 .902 r
.13336 .08012 m
.13336 .4747 L
.13506 .4747 L
.13506 .08012 L
F
.2 .63 .79 r
.13336 .08012 m
.13336 .4747 L
.13506 .4747 L
.13506 .08012 L
s
.678 .847 .902 r
.13506 .08012 m
.13506 .47382 L
.13919 .47382 L
.13919 .08012 L
F
.2 .63 .79 r
.13506 .08012 m
.13506 .47382 L
.13919 .47382 L
.13919 .08012 L
s
.678 .847 .902 r
.13919 .08012 m
.13919 .46645 L
.14279 .46645 L
.14279 .08012 L
F
.2 .63 .79 r
.13919 .08012 m
.13919 .46645 L
.14279 .46645 L
.14279 .08012 L
s
.678 .847 .902 r
.14279 .08012 m
.14279 .46537 L
.14445 .46537 L
.14445 .08012 L
F
.2 .63 .79 r
.14279 .08012 m
.14279 .46537 L
.14445 .46537 L
.14445 .08012 L
s
.678 .847 .902 r
.14445 .08012 m
.14445 .46183 L
.14617 .46183 L
.14617 .08012 L
F
.2 .63 .79 r
.14445 .08012 m
.14445 .46183 L
.14617 .46183 L
.14617 .08012 L
s
.678 .847 .902 r
.14617 .08012 m
.14617 .45978 L
.14831 .45978 L
.14831 .08012 L
F
.2 .63 .79 r
.14617 .08012 m
.14617 .45978 L
.14831 .45978 L
.14831 .08012 L
s
.678 .847 .902 r
.14831 .08012 m
.14831 .45886 L
.14975 .45886 L
.14975 .08012 L
F
.2 .63 .79 r
.14831 .08012 m
.14831 .45886 L
.14975 .45886 L
.14975 .08012 L
s
.678 .847 .902 r
.14975 .08012 m
.14975 .45496 L
.15265 .45496 L
.15265 .08012 L
F
.2 .63 .79 r
.14975 .08012 m
.14975 .45496 L
.15265 .45496 L
.15265 .08012 L
s
.678 .847 .902 r
.15265 .08012 m
.15265 .45366 L
.15505 .45366 L
.15505 .08012 L
F
.2 .63 .79 r
.15265 .08012 m
.15265 .45366 L
.15505 .45366 L
.15505 .08012 L
s
.678 .847 .902 r
.15505 .08012 m
.15505 .45039 L
.15896 .45039 L
.15896 .08012 L
F
.2 .63 .79 r
.15505 .08012 m
.15505 .45039 L
.15896 .45039 L
.15896 .08012 L
s
.678 .847 .902 r
.15896 .08012 m
.15896 .44502 L
.16323 .44502 L
.16323 .08012 L
F
.2 .63 .79 r
.15896 .08012 m
.15896 .44502 L
.16323 .44502 L
.16323 .08012 L
s
.678 .847 .902 r
.16323 .08012 m
.16323 .44103 L
.16738 .44103 L
.16738 .08012 L
F
.2 .63 .79 r
.16323 .08012 m
.16323 .44103 L
.16738 .44103 L
.16738 .08012 L
s
.678 .847 .902 r
.16738 .08012 m
.16738 .43792 L
.16996 .43792 L
.16996 .08012 L
F
.2 .63 .79 r
.16738 .08012 m
.16738 .43792 L
.16996 .43792 L
.16996 .08012 L
s
.678 .847 .902 r
.16996 .08012 m
.16996 .436 L
.17245 .436 L
.17245 .08012 L
F
.2 .63 .79 r
.16996 .08012 m
.16996 .436 L
.17245 .436 L
.17245 .08012 L
s
.678 .847 .902 r
.17245 .08012 m
.17245 .43341 L
.17451 .43341 L
.17451 .08012 L
F
.2 .63 .79 r
.17245 .08012 m
.17245 .43341 L
.17451 .43341 L
.17451 .08012 L
s
.678 .847 .902 r
.17451 .08012 m
.17451 .43043 L
.17615 .43043 L
.17615 .08012 L
F
.2 .63 .79 r
.17451 .08012 m
.17451 .43043 L
.17615 .43043 L
.17615 .08012 L
s
.678 .847 .902 r
.17615 .08012 m
.17615 .42968 L
.17885 .42968 L
.17885 .08012 L
F
.2 .63 .79 r
.17615 .08012 m
.17615 .42968 L
.17885 .42968 L
.17885 .08012 L
s
.678 .847 .902 r
.17885 .08012 m
.17885 .42719 L
.1803 .42719 L
.1803 .08012 L
F
.2 .63 .79 r
.17885 .08012 m
.17885 .42719 L
.1803 .42719 L
.1803 .08012 L
s
.678 .847 .902 r
.1803 .08012 m
.1803 .42249 L
.18379 .42249 L
.18379 .08012 L
F
.2 .63 .79 r
.1803 .08012 m
.1803 .42249 L
.18379 .42249 L
.18379 .08012 L
s
.678 .847 .902 r
.18379 .08012 m
.18379 .42044 L
.18801 .42044 L
.18801 .08012 L
F
.2 .63 .79 r
.18379 .08012 m
.18379 .42044 L
.18801 .42044 L
.18801 .08012 L
s
.678 .847 .902 r
.18801 .08012 m
.18801 .41746 L
.18955 .41746 L
.18955 .08012 L
F
.2 .63 .79 r
.18801 .08012 m
.18801 .41746 L
.18955 .41746 L
.18955 .08012 L
s
.678 .847 .902 r
.18955 .08012 m
.18955 .4134 L
.19407 .4134 L
.19407 .08012 L
F
.2 .63 .79 r
.18955 .08012 m
.18955 .4134 L
.19407 .4134 L
.19407 .08012 L
s
.678 .847 .902 r
.19407 .08012 m
.19407 .41145 L
.19839 .41145 L
.19839 .08012 L
F
.2 .63 .79 r
.19407 .08012 m
.19407 .41145 L
.19839 .41145 L
.19839 .08012 L
s
.678 .847 .902 r
.19839 .08012 m
.19839 .40583 L
.20003 .40583 L
.20003 .08012 L
F
.2 .63 .79 r
.19839 .08012 m
.19839 .40583 L
.20003 .40583 L
.20003 .08012 L
s
.678 .847 .902 r
.20003 .08012 m
.20003 .40233 L
.20465 .40233 L
.20465 .08012 L
F
.2 .63 .79 r
.20003 .08012 m
.20003 .40233 L
.20465 .40233 L
.20465 .08012 L
s
.678 .847 .902 r
.20465 .08012 m
.20465 .39988 L
.20646 .39988 L
.20646 .08012 L
F
.2 .63 .79 r
.20465 .08012 m
.20465 .39988 L
.20646 .39988 L
.20646 .08012 L
s
.678 .847 .902 r
.20646 .08012 m
.20646 .39853 L
.20862 .39853 L
.20862 .08012 L
F
.2 .63 .79 r
.20646 .08012 m
.20646 .39853 L
.20862 .39853 L
.20862 .08012 L
s
.678 .847 .902 r
.20862 .08012 m
.20862 .39301 L
.21337 .39301 L
.21337 .08012 L
F
.2 .63 .79 r
.20862 .08012 m
.20862 .39301 L
.21337 .39301 L
.21337 .08012 L
s
.678 .847 .902 r
.21337 .08012 m
.21337 .38918 L
.21769 .38918 L
.21769 .08012 L
F
.2 .63 .79 r
.21337 .08012 m
.21337 .38918 L
.21769 .38918 L
.21769 .08012 L
s
.678 .847 .902 r
.21769 .08012 m
.21769 .38479 L
.22213 .38479 L
.22213 .08012 L
F
.2 .63 .79 r
.21769 .08012 m
.21769 .38479 L
.22213 .38479 L
.22213 .08012 L
s
.678 .847 .902 r
.22213 .08012 m
.22213 .3818 L
.22428 .3818 L
.22428 .08012 L
F
.2 .63 .79 r
.22213 .08012 m
.22213 .3818 L
.22428 .3818 L
.22428 .08012 L
s
.678 .847 .902 r
.22428 .08012 m
.22428 .37874 L
.22756 .37874 L
.22756 .08012 L
F
.2 .63 .79 r
.22428 .08012 m
.22428 .37874 L
.22756 .37874 L
.22756 .08012 L
s
.678 .847 .902 r
.22756 .08012 m
.22756 .3775 L
.23091 .3775 L
.23091 .08012 L
F
.2 .63 .79 r
.22756 .08012 m
.22756 .3775 L
.23091 .3775 L
.23091 .08012 L
s
.678 .847 .902 r
.23091 .08012 m
.23091 .3746 L
.23287 .3746 L
.23287 .08012 L
F
.2 .63 .79 r
.23091 .08012 m
.23091 .3746 L
.23287 .3746 L
.23287 .08012 L
s
.678 .847 .902 r
.23287 .08012 m
.23287 .3727 L
.23552 .3727 L
.23552 .08012 L
F
.2 .63 .79 r
.23287 .08012 m
.23287 .3727 L
.23552 .3727 L
.23552 .08012 L
s
.678 .847 .902 r
.23552 .08012 m
.23552 .36957 L
.23942 .36957 L
.23942 .08012 L
F
.2 .63 .79 r
.23552 .08012 m
.23552 .36957 L
.23942 .36957 L
.23942 .08012 L
s
.678 .847 .902 r
.23942 .08012 m
.23942 .36532 L
.24161 .36532 L
.24161 .08012 L
F
.2 .63 .79 r
.23942 .08012 m
.23942 .36532 L
.24161 .36532 L
.24161 .08012 L
s
.678 .847 .902 r
.24161 .08012 m
.24161 .36451 L
.24585 .36451 L
.24585 .08012 L
F
.2 .63 .79 r
.24161 .08012 m
.24161 .36451 L
.24585 .36451 L
.24585 .08012 L
s
.678 .847 .902 r
.24585 .08012 m
.24585 .35898 L
.24787 .35898 L
.24787 .08012 L
F
.2 .63 .79 r
.24585 .08012 m
.24585 .35898 L
.24787 .35898 L
.24787 .08012 L
s
.678 .847 .902 r
.24787 .08012 m
.24787 .35715 L
.25156 .35715 L
.25156 .08012 L
F
.2 .63 .79 r
.24787 .08012 m
.24787 .35715 L
.25156 .35715 L
.25156 .08012 L
s
.678 .847 .902 r
.25156 .08012 m
.25156 .35285 L
.25582 .35285 L
.25582 .08012 L
F
.2 .63 .79 r
.25156 .08012 m
.25156 .35285 L
.25582 .35285 L
.25582 .08012 L
s
.678 .847 .902 r
.25582 .08012 m
.25582 .35133 L
.26004 .35133 L
.26004 .08012 L
F
.2 .63 .79 r
.25582 .08012 m
.25582 .35133 L
.26004 .35133 L
.26004 .08012 L
s
.678 .847 .902 r
.26004 .08012 m
.26004 .34733 L
.26335 .34733 L
.26335 .08012 L
F
.2 .63 .79 r
.26004 .08012 m
.26004 .34733 L
.26335 .34733 L
.26335 .08012 L
s
.678 .847 .902 r
.26335 .08012 m
.26335 .34403 L
.26758 .34403 L
.26758 .08012 L
F
.2 .63 .79 r
.26335 .08012 m
.26335 .34403 L
.26758 .34403 L
.26758 .08012 L
s
.678 .847 .902 r
.26758 .08012 m
.26758 .33902 L
.27172 .33902 L
.27172 .08012 L
F
.2 .63 .79 r
.26758 .08012 m
.26758 .33902 L
.27172 .33902 L
.27172 .08012 L
s
.678 .847 .902 r
.27172 .08012 m
.27172 .33509 L
.2762 .33509 L
.2762 .08012 L
F
.2 .63 .79 r
.27172 .08012 m
.27172 .33509 L
.2762 .33509 L
.2762 .08012 L
s
.678 .847 .902 r
.2762 .08012 m
.2762 .33264 L
.27994 .33264 L
.27994 .08012 L
F
.2 .63 .79 r
.2762 .08012 m
.2762 .33264 L
.27994 .33264 L
.27994 .08012 L
s
.678 .847 .902 r
.27994 .08012 m
.27994 .32849 L
.28396 .32849 L
.28396 .08012 L
F
.2 .63 .79 r
.27994 .08012 m
.27994 .32849 L
.28396 .32849 L
.28396 .08012 L
s
.678 .847 .902 r
.28396 .08012 m
.28396 .32301 L
.28826 .32301 L
.28826 .08012 L
F
.2 .63 .79 r
.28396 .08012 m
.28396 .32301 L
.28826 .32301 L
.28826 .08012 L
s
.678 .847 .902 r
.28826 .08012 m
.28826 .31895 L
.29235 .31895 L
.29235 .08012 L
F
.2 .63 .79 r
.28826 .08012 m
.28826 .31895 L
.29235 .31895 L
.29235 .08012 L
s
.678 .847 .902 r
.29235 .08012 m
.29235 .3163 L
.29537 .3163 L
.29537 .08012 L
F
.2 .63 .79 r
.29235 .08012 m
.29235 .3163 L
.29537 .3163 L
.29537 .08012 L
s
.678 .847 .902 r
.29537 .08012 m
.29537 .3142 L
.29941 .3142 L
.29941 .08012 L
F
.2 .63 .79 r
.29537 .08012 m
.29537 .3142 L
.29941 .3142 L
.29941 .08012 L
s
.678 .847 .902 r
.29941 .08012 m
.29941 .30799 L
.30415 .30799 L
.30415 .08012 L
F
.2 .63 .79 r
.29941 .08012 m
.29941 .30799 L
.30415 .30799 L
.30415 .08012 L
s
.678 .847 .902 r
.30415 .08012 m
.30415 .30765 L
.30856 .30765 L
.30856 .08012 L
F
.2 .63 .79 r
.30415 .08012 m
.30415 .30765 L
.30856 .30765 L
.30856 .08012 L
s
.678 .847 .902 r
.30856 .08012 m
.30856 .30237 L
.31087 .30237 L
.31087 .08012 L
F
.2 .63 .79 r
.30856 .08012 m
.30856 .30237 L
.31087 .30237 L
.31087 .08012 L
s
.678 .847 .902 r
.31087 .08012 m
.31087 .30108 L
.31306 .30108 L
.31306 .08012 L
F
.2 .63 .79 r
.31087 .08012 m
.31087 .30108 L
.31306 .30108 L
.31306 .08012 L
s
.678 .847 .902 r
.31306 .08012 m
.31306 .29844 L
.31588 .29844 L
.31588 .08012 L
F
.2 .63 .79 r
.31306 .08012 m
.31306 .29844 L
.31588 .29844 L
.31588 .08012 L
s
.678 .847 .902 r
.31588 .08012 m
.31588 .29519 L
.31976 .29519 L
.31976 .08012 L
F
.2 .63 .79 r
.31588 .08012 m
.31588 .29519 L
.31976 .29519 L
.31976 .08012 L
s
.678 .847 .902 r
.31976 .08012 m
.31976 .29217 L
.32418 .29217 L
.32418 .08012 L
F
.2 .63 .79 r
.31976 .08012 m
.31976 .29217 L
.32418 .29217 L
.32418 .08012 L
s
.678 .847 .902 r
.32418 .08012 m
.32418 .29016 L
.32724 .29016 L
.32724 .08012 L
F
.2 .63 .79 r
.32418 .08012 m
.32418 .29016 L
.32724 .29016 L
.32724 .08012 L
s
.678 .847 .902 r
.32724 .08012 m
.32724 .28648 L
.32931 .28648 L
.32931 .08012 L
F
.2 .63 .79 r
.32724 .08012 m
.32724 .28648 L
.32931 .28648 L
.32931 .08012 L
s
.678 .847 .902 r
.32931 .08012 m
.32931 .28387 L
.33371 .28387 L
.33371 .08012 L
F
.2 .63 .79 r
.32931 .08012 m
.32931 .28387 L
.33371 .28387 L
.33371 .08012 L
s
.678 .847 .902 r
.33371 .08012 m
.33371 .28068 L
.33754 .28068 L
.33754 .08012 L
F
.2 .63 .79 r
.33371 .08012 m
.33371 .28068 L
.33754 .28068 L
.33754 .08012 L
s
.678 .847 .902 r
.33754 .08012 m
.33754 .27717 L
.34168 .27717 L
.34168 .08012 L
F
.2 .63 .79 r
.33754 .08012 m
.33754 .27717 L
.34168 .27717 L
.34168 .08012 L
s
.678 .847 .902 r
.34168 .08012 m
.34168 .2755 L
.34425 .2755 L
.34425 .08012 L
F
.2 .63 .79 r
.34168 .08012 m
.34168 .2755 L
.34425 .2755 L
.34425 .08012 L
s
.678 .847 .902 r
.34425 .08012 m
.34425 .27305 L
.34587 .27305 L
.34587 .08012 L
F
.2 .63 .79 r
.34425 .08012 m
.34425 .27305 L
.34587 .27305 L
.34587 .08012 L
s
.678 .847 .902 r
.34587 .08012 m
.34587 .2717 L
.34782 .2717 L
.34782 .08012 L
F
.2 .63 .79 r
.34587 .08012 m
.34587 .2717 L
.34782 .2717 L
.34782 .08012 L
s
.678 .847 .902 r
.34782 .08012 m
.34782 .2689 L
.35249 .2689 L
.35249 .08012 L
F
.2 .63 .79 r
.34782 .08012 m
.34782 .2689 L
.35249 .2689 L
.35249 .08012 L
s
.678 .847 .902 r
.35249 .08012 m
.35249 .26503 L
.35569 .26503 L
.35569 .08012 L
F
.2 .63 .79 r
.35249 .08012 m
.35249 .26503 L
.35569 .26503 L
.35569 .08012 L
s
.678 .847 .902 r
.35569 .08012 m
.35569 .26426 L
.3576 .26426 L
.3576 .08012 L
F
.2 .63 .79 r
.35569 .08012 m
.35569 .26426 L
.3576 .26426 L
.3576 .08012 L
s
.678 .847 .902 r
.3576 .08012 m
.3576 .2618 L
.36057 .2618 L
.36057 .08012 L
F
.2 .63 .79 r
.3576 .08012 m
.3576 .2618 L
.36057 .2618 L
.36057 .08012 L
s
.678 .847 .902 r
.36057 .08012 m
.36057 .26013 L
.36265 .26013 L
.36265 .08012 L
F
.2 .63 .79 r
.36057 .08012 m
.36057 .26013 L
.36265 .26013 L
.36265 .08012 L
s
.678 .847 .902 r
.36265 .08012 m
.36265 .25861 L
.36632 .25861 L
.36632 .08012 L
F
.2 .63 .79 r
.36265 .08012 m
.36265 .25861 L
.36632 .25861 L
.36632 .08012 L
s
.678 .847 .902 r
.36632 .08012 m
.36632 .25523 L
.3689 .25523 L
.3689 .08012 L
F
.2 .63 .79 r
.36632 .08012 m
.36632 .25523 L
.3689 .25523 L
.3689 .08012 L
s
.678 .847 .902 r
.3689 .08012 m
.3689 .25102 L
.37363 .25102 L
.37363 .08012 L
F
.2 .63 .79 r
.3689 .08012 m
.3689 .25102 L
.37363 .25102 L
.37363 .08012 L
s
.678 .847 .902 r
.37363 .08012 m
.37363 .24825 L
.37644 .24825 L
.37644 .08012 L
F
.2 .63 .79 r
.37363 .08012 m
.37363 .24825 L
.37644 .24825 L
.37644 .08012 L
s
.678 .847 .902 r
.37644 .08012 m
.37644 .24763 L
.38012 .24763 L
.38012 .08012 L
F
.2 .63 .79 r
.37644 .08012 m
.37644 .24763 L
.38012 .24763 L
.38012 .08012 L
s
.678 .847 .902 r
.38012 .08012 m
.38012 .24442 L
.38306 .24442 L
.38306 .08012 L
F
.2 .63 .79 r
.38012 .08012 m
.38012 .24442 L
.38306 .24442 L
.38306 .08012 L
s
.678 .847 .902 r
.38306 .08012 m
.38306 .24296 L
.38691 .24296 L
.38691 .08012 L
F
.2 .63 .79 r
.38306 .08012 m
.38306 .24296 L
.38691 .24296 L
.38691 .08012 L
s
.678 .847 .902 r
.38691 .08012 m
.38691 .23931 L
.38897 .23931 L
.38897 .08012 L
F
.2 .63 .79 r
.38691 .08012 m
.38691 .23931 L
.38897 .23931 L
.38897 .08012 L
s
.678 .847 .902 r
.38897 .08012 m
.38897 .23761 L
.39125 .23761 L
.39125 .08012 L
F
.2 .63 .79 r
.38897 .08012 m
.38897 .23761 L
.39125 .23761 L
.39125 .08012 L
s
.678 .847 .902 r
.39125 .08012 m
.39125 .23491 L
.39509 .23491 L
.39509 .08012 L
F
.2 .63 .79 r
.39125 .08012 m
.39125 .23491 L
.39509 .23491 L
.39509 .08012 L
s
.678 .847 .902 r
.39509 .08012 m
.39509 .23245 L
.39928 .23245 L
.39928 .08012 L
F
.2 .63 .79 r
.39509 .08012 m
.39509 .23245 L
.39928 .23245 L
.39928 .08012 L
s
.678 .847 .902 r
.39928 .08012 m
.39928 .22981 L
.40304 .22981 L
.40304 .08012 L
F
.2 .63 .79 r
.39928 .08012 m
.39928 .22981 L
.40304 .22981 L
.40304 .08012 L
s
.678 .847 .902 r
.40304 .08012 m
.40304 .22712 L
.4047 .22712 L
.4047 .08012 L
F
.2 .63 .79 r
.40304 .08012 m
.40304 .22712 L
.4047 .22712 L
.4047 .08012 L
s
.678 .847 .902 r
.4047 .08012 m
.4047 .22361 L
.40889 .22361 L
.40889 .08012 L
F
.2 .63 .79 r
.4047 .08012 m
.4047 .22361 L
.40889 .22361 L
.40889 .08012 L
s
.678 .847 .902 r
.40889 .08012 m
.40889 .22245 L
.41068 .22245 L
.41068 .08012 L
F
.2 .63 .79 r
.40889 .08012 m
.40889 .22245 L
.41068 .22245 L
.41068 .08012 L
s
.678 .847 .902 r
.41068 .08012 m
.41068 .22011 L
.41508 .22011 L
.41508 .08012 L
F
.2 .63 .79 r
.41068 .08012 m
.41068 .22011 L
.41508 .22011 L
.41508 .08012 L
s
.678 .847 .902 r
.41508 .08012 m
.41508 .21792 L
.41892 .21792 L
.41892 .08012 L
F
.2 .63 .79 r
.41508 .08012 m
.41508 .21792 L
.41892 .21792 L
.41892 .08012 L
s
.678 .847 .902 r
.41892 .08012 m
.41892 .21517 L
.42293 .21517 L
.42293 .08012 L
F
.2 .63 .79 r
.41892 .08012 m
.41892 .21517 L
.42293 .21517 L
.42293 .08012 L
s
.678 .847 .902 r
.42293 .08012 m
.42293 .21231 L
.42754 .21231 L
.42754 .08012 L
F
.2 .63 .79 r
.42293 .08012 m
.42293 .21231 L
.42754 .21231 L
.42754 .08012 L
s
.678 .847 .902 r
.42754 .08012 m
.42754 .20966 L
.43203 .20966 L
.43203 .08012 L
F
.2 .63 .79 r
.42754 .08012 m
.42754 .20966 L
.43203 .20966 L
.43203 .08012 L
s
.678 .847 .902 r
.43203 .08012 m
.43203 .20603 L
.43411 .20603 L
.43411 .08012 L
F
.2 .63 .79 r
.43203 .08012 m
.43203 .20603 L
.43411 .20603 L
.43411 .08012 L
s
.678 .847 .902 r
.43411 .08012 m
.43411 .20499 L
.43764 .20499 L
.43764 .08012 L
F
.2 .63 .79 r
.43411 .08012 m
.43411 .20499 L
.43764 .20499 L
.43764 .08012 L
s
.678 .847 .902 r
.43764 .08012 m
.43764 .20123 L
.4407 .20123 L
.4407 .08012 L
F
.2 .63 .79 r
.43764 .08012 m
.43764 .20123 L
.4407 .20123 L
.4407 .08012 L
s
.678 .847 .902 r
.4407 .08012 m
.4407 .19865 L
.44454 .19865 L
.44454 .08012 L
F
.2 .63 .79 r
.4407 .08012 m
.4407 .19865 L
.44454 .19865 L
.44454 .08012 L
s
.678 .847 .902 r
.44454 .08012 m
.44454 .19716 L
.44772 .19716 L
.44772 .08012 L
F
.2 .63 .79 r
.44454 .08012 m
.44454 .19716 L
.44772 .19716 L
.44772 .08012 L
s
.678 .847 .902 r
.44772 .08012 m
.44772 .19473 L
.4501 .19473 L
.4501 .08012 L
F
.2 .63 .79 r
.44772 .08012 m
.44772 .19473 L
.4501 .19473 L
.4501 .08012 L
s
.678 .847 .902 r
.4501 .08012 m
.4501 .19225 L
.4532 .19225 L
.4532 .08012 L
F
.2 .63 .79 r
.4501 .08012 m
.4501 .19225 L
.4532 .19225 L
.4532 .08012 L
s
.678 .847 .902 r
.4532 .08012 m
.4532 .19078 L
.45566 .19078 L
.45566 .08012 L
F
.2 .63 .79 r
.4532 .08012 m
.4532 .19078 L
.45566 .19078 L
.45566 .08012 L
s
.678 .847 .902 r
.45566 .08012 m
.45566 .18978 L
.45992 .18978 L
.45992 .08012 L
F
.2 .63 .79 r
.45566 .08012 m
.45566 .18978 L
.45992 .18978 L
.45992 .08012 L
s
.678 .847 .902 r
.45992 .08012 m
.45992 .18662 L
.46413 .18662 L
.46413 .08012 L
F
.2 .63 .79 r
.45992 .08012 m
.45992 .18662 L
.46413 .18662 L
.46413 .08012 L
s
.678 .847 .902 r
.46413 .08012 m
.46413 .18231 L
.46815 .18231 L
.46815 .08012 L
F
.2 .63 .79 r
.46413 .08012 m
.46413 .18231 L
.46815 .18231 L
.46815 .08012 L
s
.678 .847 .902 r
.46815 .08012 m
.46815 .18175 L
.46998 .18175 L
.46998 .08012 L
F
.2 .63 .79 r
.46815 .08012 m
.46815 .18175 L
.46998 .18175 L
.46998 .08012 L
s
.678 .847 .902 r
.46998 .08012 m
.46998 .1793 L
.47339 .1793 L
.47339 .08012 L
F
.2 .63 .79 r
.46998 .08012 m
.46998 .1793 L
.47339 .1793 L
.47339 .08012 L
s
.678 .847 .902 r
.47339 .08012 m
.47339 .1779 L
.47519 .1779 L
.47519 .08012 L
F
.2 .63 .79 r
.47339 .08012 m
.47339 .1779 L
.47519 .1779 L
.47519 .08012 L
s
.678 .847 .902 r
.47519 .08012 m
.47519 .17605 L
.47978 .17605 L
.47978 .08012 L
F
.2 .63 .79 r
.47519 .08012 m
.47519 .17605 L
.47978 .17605 L
.47978 .08012 L
s
.678 .847 .902 r
.47978 .08012 m
.47978 .17451 L
.48262 .17451 L
.48262 .08012 L
F
.2 .63 .79 r
.47978 .08012 m
.47978 .17451 L
.48262 .17451 L
.48262 .08012 L
s
.678 .847 .902 r
.48262 .08012 m
.48262 .17252 L
.4858 .17252 L
.4858 .08012 L
F
.2 .63 .79 r
.48262 .08012 m
.48262 .17252 L
.4858 .17252 L
.4858 .08012 L
s
.678 .847 .902 r
.4858 .08012 m
.4858 .16962 L
.48818 .16962 L
.48818 .08012 L
F
.2 .63 .79 r
.4858 .08012 m
.4858 .16962 L
.48818 .16962 L
.48818 .08012 L
s
.678 .847 .902 r
.48818 .08012 m
.48818 .16745 L
.49241 .16745 L
.49241 .08012 L
F
.2 .63 .79 r
.48818 .08012 m
.48818 .16745 L
.49241 .16745 L
.49241 .08012 L
s
.678 .847 .902 r
.49241 .08012 m
.49241 .16579 L
.49563 .16579 L
.49563 .08012 L
F
.2 .63 .79 r
.49241 .08012 m
.49241 .16579 L
.49563 .16579 L
.49563 .08012 L
s
.678 .847 .902 r
.49563 .08012 m
.49563 .16269 L
.49973 .16269 L
.49973 .08012 L
F
.2 .63 .79 r
.49563 .08012 m
.49563 .16269 L
.49973 .16269 L
.49973 .08012 L
s
.678 .847 .902 r
.49973 .08012 m
.49973 .16128 L
.50286 .16128 L
.50286 .08012 L
F
.2 .63 .79 r
.49973 .08012 m
.49973 .16128 L
.50286 .16128 L
.50286 .08012 L
s
.678 .847 .902 r
.50286 .08012 m
.50286 .15913 L
.50726 .15913 L
.50726 .08012 L
F
.2 .63 .79 r
.50286 .08012 m
.50286 .15913 L
.50726 .15913 L
.50726 .08012 L
s
.678 .847 .902 r
.50726 .08012 m
.50726 .15684 L
.51075 .15684 L
.51075 .08012 L
F
.2 .63 .79 r
.50726 .08012 m
.50726 .15684 L
.51075 .15684 L
.51075 .08012 L
s
.678 .847 .902 r
.51075 .08012 m
.51075 .15495 L
.5142 .15495 L
.5142 .08012 L
F
.2 .63 .79 r
.51075 .08012 m
.51075 .15495 L
.5142 .15495 L
.5142 .08012 L
s
.678 .847 .902 r
.5142 .08012 m
.5142 .15264 L
.51857 .15264 L
.51857 .08012 L
F
.2 .63 .79 r
.5142 .08012 m
.5142 .15264 L
.51857 .15264 L
.51857 .08012 L
s
.678 .847 .902 r
.51857 .08012 m
.51857 .14969 L
.52133 .14969 L
.52133 .08012 L
F
.2 .63 .79 r
.51857 .08012 m
.51857 .14969 L
.52133 .14969 L
.52133 .08012 L
s
.678 .847 .902 r
.52133 .08012 m
.52133 .14777 L
.52575 .14777 L
.52575 .08012 L
F
.2 .63 .79 r
.52133 .08012 m
.52133 .14777 L
.52575 .14777 L
.52575 .08012 L
s
.678 .847 .902 r
.52575 .08012 m
.52575 .14567 L
.52745 .14567 L
.52745 .08012 L
F
.2 .63 .79 r
.52575 .08012 m
.52575 .14567 L
.52745 .14567 L
.52745 .08012 L
s
.678 .847 .902 r
.52745 .08012 m
.52745 .14446 L
.53087 .14446 L
.53087 .08012 L
F
.2 .63 .79 r
.52745 .08012 m
.52745 .14446 L
.53087 .14446 L
.53087 .08012 L
s
.678 .847 .902 r
.53087 .08012 m
.53087 .14192 L
.5353 .14192 L
.5353 .08012 L
F
.2 .63 .79 r
.53087 .08012 m
.53087 .14192 L
.5353 .14192 L
.5353 .08012 L
s
.678 .847 .902 r
.5353 .08012 m
.5353 .13968 L
.53869 .13968 L
.53869 .08012 L
F
.2 .63 .79 r
.5353 .08012 m
.5353 .13968 L
.53869 .13968 L
.53869 .08012 L
s
.678 .847 .902 r
.53869 .08012 m
.53869 .13836 L
.54089 .13836 L
.54089 .08012 L
F
.2 .63 .79 r
.53869 .08012 m
.53869 .13836 L
.54089 .13836 L
.54089 .08012 L
s
.678 .847 .902 r
.54089 .08012 m
.54089 .13747 L
.54488 .13747 L
.54488 .08012 L
F
.2 .63 .79 r
.54089 .08012 m
.54089 .13747 L
.54488 .13747 L
.54488 .08012 L
s
.678 .847 .902 r
.54488 .08012 m
.54488 .1348 L
.54672 .1348 L
.54672 .08012 L
F
.2 .63 .79 r
.54488 .08012 m
.54488 .1348 L
.54672 .1348 L
.54672 .08012 L
s
.678 .847 .902 r
.54672 .08012 m
.54672 .13403 L
.5497 .13403 L
.5497 .08012 L
F
.2 .63 .79 r
.54672 .08012 m
.54672 .13403 L
.5497 .13403 L
.5497 .08012 L
s
.678 .847 .902 r
.5497 .08012 m
.5497 .13139 L
.55327 .13139 L
.55327 .08012 L
F
.2 .63 .79 r
.5497 .08012 m
.5497 .13139 L
.55327 .13139 L
.55327 .08012 L
s
.678 .847 .902 r
.55327 .08012 m
.55327 .13009 L
.55688 .13009 L
.55688 .08012 L
F
.2 .63 .79 r
.55327 .08012 m
.55327 .13009 L
.55688 .13009 L
.55688 .08012 L
s
.678 .847 .902 r
.55688 .08012 m
.55688 .1287 L
.55889 .1287 L
.55889 .08012 L
F
.2 .63 .79 r
.55688 .08012 m
.55688 .1287 L
.55889 .1287 L
.55889 .08012 L
s
.678 .847 .902 r
.55889 .08012 m
.55889 .12758 L
.56046 .12758 L
.56046 .08012 L
F
.2 .63 .79 r
.55889 .08012 m
.55889 .12758 L
.56046 .12758 L
.56046 .08012 L
s
.678 .847 .902 r
.56046 .08012 m
.56046 .12633 L
.56228 .12633 L
.56228 .08012 L
F
.2 .63 .79 r
.56046 .08012 m
.56046 .12633 L
.56228 .12633 L
.56228 .08012 L
s
.678 .847 .902 r
.56228 .08012 m
.56228 .12505 L
.56494 .12505 L
.56494 .08012 L
F
.2 .63 .79 r
.56228 .08012 m
.56228 .12505 L
.56494 .12505 L
.56494 .08012 L
s
.678 .847 .902 r
.56494 .08012 m
.56494 .12389 L
.56749 .12389 L
.56749 .08012 L
F
.2 .63 .79 r
.56494 .08012 m
.56494 .12389 L
.56749 .12389 L
.56749 .08012 L
s
.678 .847 .902 r
.56749 .08012 m
.56749 .12185 L
.57062 .12185 L
.57062 .08012 L
F
.2 .63 .79 r
.56749 .08012 m
.56749 .12185 L
.57062 .12185 L
.57062 .08012 L
s
.678 .847 .902 r
.57062 .08012 m
.57062 .1204 L
.5731 .1204 L
.5731 .08012 L
F
.2 .63 .79 r
.57062 .08012 m
.57062 .1204 L
.5731 .1204 L
.5731 .08012 L
s
.678 .847 .902 r
.5731 .08012 m
.5731 .1197 L
.5774 .1197 L
.5774 .08012 L
F
.2 .63 .79 r
.5731 .08012 m
.5731 .1197 L
.5774 .1197 L
.5774 .08012 L
s
.678 .847 .902 r
.5774 .08012 m
.5774 .11783 L
.58032 .11783 L
.58032 .08012 L
F
.2 .63 .79 r
.5774 .08012 m
.5774 .11783 L
.58032 .11783 L
.58032 .08012 L
s
.678 .847 .902 r
.58032 .08012 m
.58032 .11531 L
.58472 .11531 L
.58472 .08012 L
F
.2 .63 .79 r
.58032 .08012 m
.58032 .11531 L
.58472 .11531 L
.58472 .08012 L
s
.678 .847 .902 r
.58472 .08012 m
.58472 .11293 L
.58852 .11293 L
.58852 .08012 L
F
.2 .63 .79 r
.58472 .08012 m
.58472 .11293 L
.58852 .11293 L
.58852 .08012 L
s
.678 .847 .902 r
.58852 .08012 m
.58852 .10994 L
.59321 .10994 L
.59321 .08012 L
F
.2 .63 .79 r
.58852 .08012 m
.58852 .10994 L
.59321 .10994 L
.59321 .08012 L
s
.678 .847 .902 r
.59321 .08012 m
.59321 .1095 L
.5948 .1095 L
.5948 .08012 L
F
.2 .63 .79 r
.59321 .08012 m
.59321 .1095 L
.5948 .1095 L
.5948 .08012 L
s
.678 .847 .902 r
.5948 .08012 m
.5948 .10905 L
.59955 .10905 L
.59955 .08012 L
F
.2 .63 .79 r
.5948 .08012 m
.5948 .10905 L
.59955 .10905 L
.59955 .08012 L
s
.678 .847 .902 r
.59955 .08012 m
.59955 .10519 L
.60308 .10519 L
.60308 .08012 L
F
.2 .63 .79 r
.59955 .08012 m
.59955 .10519 L
.60308 .10519 L
.60308 .08012 L
s
.678 .847 .902 r
.60308 .08012 m
.60308 .10438 L
.60579 .10438 L
.60579 .08012 L
F
.2 .63 .79 r
.60308 .08012 m
.60308 .10438 L
.60579 .10438 L
.60579 .08012 L
s
.678 .847 .902 r
.60579 .08012 m
.60579 .10291 L
.60771 .10291 L
.60771 .08012 L
F
.2 .63 .79 r
.60579 .08012 m
.60579 .10291 L
.60771 .10291 L
.60771 .08012 L
s
.678 .847 .902 r
.60771 .08012 m
.60771 .10227 L
.61051 .10227 L
.61051 .08012 L
F
.2 .63 .79 r
.60771 .08012 m
.60771 .10227 L
.61051 .10227 L
.61051 .08012 L
s
.678 .847 .902 r
.61051 .08012 m
.61051 .10089 L
.61326 .10089 L
.61326 .08012 L
F
.2 .63 .79 r
.61051 .08012 m
.61051 .10089 L
.61326 .10089 L
.61326 .08012 L
s
.678 .847 .902 r
.61326 .08012 m
.61326 .0995 L
.61674 .0995 L
.61674 .08012 L
F
.2 .63 .79 r
.61326 .08012 m
.61326 .0995 L
.61674 .0995 L
.61674 .08012 L
s
.678 .847 .902 r
.61674 .08012 m
.61674 .09835 L
.61826 .09835 L
.61826 .08012 L
F
.2 .63 .79 r
.61674 .08012 m
.61674 .09835 L
.61826 .09835 L
.61826 .08012 L
s
.678 .847 .902 r
.61826 .08012 m
.61826 .09745 L
.62284 .09745 L
.62284 .08012 L
F
.2 .63 .79 r
.61826 .08012 m
.61826 .09745 L
.62284 .09745 L
.62284 .08012 L
s
.678 .847 .902 r
.62284 .08012 m
.62284 .09434 L
.62679 .09434 L
.62679 .08012 L
F
.2 .63 .79 r
.62284 .08012 m
.62284 .09434 L
.62679 .09434 L
.62679 .08012 L
s
.678 .847 .902 r
.62679 .08012 m
.62679 .09378 L
.63143 .09378 L
.63143 .08012 L
F
.2 .63 .79 r
.62679 .08012 m
.62679 .09378 L
.63143 .09378 L
.63143 .08012 L
s
.678 .847 .902 r
.63143 .08012 m
.63143 .09147 L
.6357 .09147 L
.6357 .08012 L
F
.2 .63 .79 r
.63143 .08012 m
.63143 .09147 L
.6357 .09147 L
.6357 .08012 L
s
.678 .847 .902 r
.6357 .08012 m
.6357 .0899 L
.64015 .0899 L
.64015 .08012 L
F
.2 .63 .79 r
.6357 .08012 m
.6357 .0899 L
.64015 .0899 L
.64015 .08012 L
s
.678 .847 .902 r
.64015 .08012 m
.64015 .08765 L
.64371 .08765 L
.64371 .08012 L
F
.2 .63 .79 r
.64015 .08012 m
.64015 .08765 L
.64371 .08765 L
.64371 .08012 L
s
.678 .847 .902 r
.64371 .08012 m
.64371 .08575 L
.64712 .08575 L
.64712 .08012 L
F
.2 .63 .79 r
.64371 .08012 m
.64371 .08575 L
.64712 .08575 L
.64712 .08012 L
s
.678 .847 .902 r
.64712 .08012 m
.64712 .08396 L
.65026 .08396 L
.65026 .08012 L
F
.2 .63 .79 r
.64712 .08012 m
.64712 .08396 L
.65026 .08396 L
.65026 .08012 L
s
.678 .847 .902 r
.65026 .08012 m
.65026 .08334 L
.65301 .08334 L
.65301 .08012 L
F
.2 .63 .79 r
.65026 .08012 m
.65026 .08334 L
.65301 .08334 L
.65301 .08012 L
s
.678 .847 .902 r
.65301 .08012 m
.65301 .08205 L
.65553 .08205 L
.65553 .08012 L
F
.2 .63 .79 r
.65301 .08012 m
.65301 .08205 L
.65553 .08205 L
.65553 .08012 L
s
.678 .847 .902 r
.65553 .08012 m
.65553 .081 L
.6594 .081 L
.6594 .08012 L
F
.2 .63 .79 r
.65553 .08012 m
.65553 .081 L
.6594 .081 L
.6594 .08012 L
s
1 .894 .882 r
.6594 .08012 m
.6594 .07936 L
.66106 .07936 L
.66106 .08012 L
F
.804 .522 .247 r
.6594 .08012 m
.6594 .07936 L
.66106 .07936 L
.66106 .08012 L
s
1 .894 .882 r
.66106 .08012 m
.66106 .07818 L
.66417 .07818 L
.66417 .08012 L
F
.804 .522 .247 r
.66106 .08012 m
.66106 .07818 L
.66417 .07818 L
.66417 .08012 L
s
1 .894 .882 r
.66417 .08012 m
.66417 .07681 L
.66765 .07681 L
.66765 .08012 L
F
.804 .522 .247 r
.66417 .08012 m
.66417 .07681 L
.66765 .07681 L
.66765 .08012 L
s
1 .894 .882 r
.66765 .08012 m
.66765 .07603 L
.6716 .07603 L
.6716 .08012 L
F
.804 .522 .247 r
.66765 .08012 m
.66765 .07603 L
.6716 .07603 L
.6716 .08012 L
s
1 .894 .882 r
.6716 .08012 m
.6716 .07479 L
.6731 .07479 L
.6731 .08012 L
F
.804 .522 .247 r
.6716 .08012 m
.6716 .07479 L
.6731 .07479 L
.6731 .08012 L
s
1 .894 .882 r
.6731 .08012 m
.6731 .07341 L
.67623 .07341 L
.67623 .08012 L
F
.804 .522 .247 r
.6731 .08012 m
.6731 .07341 L
.67623 .07341 L
.67623 .08012 L
s
1 .894 .882 r
.67623 .08012 m
.67623 .07154 L
.68095 .07154 L
.68095 .08012 L
F
.804 .522 .247 r
.67623 .08012 m
.67623 .07154 L
.68095 .07154 L
.68095 .08012 L
s
1 .894 .882 r
.68095 .08012 m
.68095 .07049 L
.68363 .07049 L
.68363 .08012 L
F
.804 .522 .247 r
.68095 .08012 m
.68095 .07049 L
.68363 .07049 L
.68363 .08012 L
s
1 .894 .882 r
.68363 .08012 m
.68363 .06977 L
.68797 .06977 L
.68797 .08012 L
F
.804 .522 .247 r
.68363 .08012 m
.68363 .06977 L
.68797 .06977 L
.68797 .08012 L
s
1 .894 .882 r
.68797 .08012 m
.68797 .06841 L
.68973 .06841 L
.68973 .08012 L
F
.804 .522 .247 r
.68797 .08012 m
.68797 .06841 L
.68973 .06841 L
.68973 .08012 L
s
1 .894 .882 r
.68973 .08012 m
.68973 .06748 L
.69312 .06748 L
.69312 .08012 L
F
.804 .522 .247 r
.68973 .08012 m
.68973 .06748 L
.69312 .06748 L
.69312 .08012 L
s
1 .894 .882 r
.69312 .08012 m
.69312 .06619 L
.69708 .06619 L
.69708 .08012 L
F
.804 .522 .247 r
.69312 .08012 m
.69312 .06619 L
.69708 .06619 L
.69708 .08012 L
s
1 .894 .882 r
.69708 .08012 m
.69708 .06526 L
.70135 .06526 L
.70135 .08012 L
F
.804 .522 .247 r
.69708 .08012 m
.69708 .06526 L
.70135 .06526 L
.70135 .08012 L
s
1 .894 .882 r
.70135 .08012 m
.70135 .06364 L
.70329 .06364 L
.70329 .08012 L
F
.804 .522 .247 r
.70135 .08012 m
.70135 .06364 L
.70329 .06364 L
.70329 .08012 L
s
1 .894 .882 r
.70329 .08012 m
.70329 .06213 L
.7075 .06213 L
.7075 .08012 L
F
.804 .522 .247 r
.70329 .08012 m
.70329 .06213 L
.7075 .06213 L
.7075 .08012 L
s
1 .894 .882 r
.7075 .08012 m
.7075 .06116 L
.71158 .06116 L
.71158 .08012 L
F
.804 .522 .247 r
.7075 .08012 m
.7075 .06116 L
.71158 .06116 L
.71158 .08012 L
s
1 .894 .882 r
.71158 .08012 m
.71158 .05975 L
.71302 .05975 L
.71302 .08012 L
F
.804 .522 .247 r
.71158 .08012 m
.71158 .05975 L
.71302 .05975 L
.71302 .08012 L
s
1 .894 .882 r
.71302 .08012 m
.71302 .05958 L
.71527 .05958 L
.71527 .08012 L
F
.804 .522 .247 r
.71302 .08012 m
.71302 .05958 L
.71527 .05958 L
.71527 .08012 L
s
1 .894 .882 r
.71527 .08012 m
.71527 .05862 L
.71735 .05862 L
.71735 .08012 L
F
.804 .522 .247 r
.71527 .08012 m
.71527 .05862 L
.71735 .05862 L
.71735 .08012 L
s
1 .894 .882 r
.71735 .08012 m
.71735 .05762 L
.71946 .05762 L
.71946 .08012 L
F
.804 .522 .247 r
.71735 .08012 m
.71735 .05762 L
.71946 .05762 L
.71946 .08012 L
s
1 .894 .882 r
.71946 .08012 m
.71946 .05745 L
.72251 .05745 L
.72251 .08012 L
F
.804 .522 .247 r
.71946 .08012 m
.71946 .05745 L
.72251 .05745 L
.72251 .08012 L
s
1 .894 .882 r
.72251 .08012 m
.72251 .05529 L
.72679 .05529 L
.72679 .08012 L
F
.804 .522 .247 r
.72251 .08012 m
.72251 .05529 L
.72679 .05529 L
.72679 .08012 L
s
1 .894 .882 r
.72679 .08012 m
.72679 .05373 L
.73111 .05373 L
.73111 .08012 L
F
.804 .522 .247 r
.72679 .08012 m
.72679 .05373 L
.73111 .05373 L
.73111 .08012 L
s
1 .894 .882 r
.73111 .08012 m
.73111 .05319 L
.73412 .05319 L
.73412 .08012 L
F
.804 .522 .247 r
.73111 .08012 m
.73111 .05319 L
.73412 .05319 L
.73412 .08012 L
s
1 .894 .882 r
.73412 .08012 m
.73412 .05245 L
.73694 .05245 L
.73694 .08012 L
F
.804 .522 .247 r
.73412 .08012 m
.73412 .05245 L
.73694 .05245 L
.73694 .08012 L
s
1 .894 .882 r
.73694 .08012 m
.73694 .0518 L
.73953 .0518 L
.73953 .08012 L
F
.804 .522 .247 r
.73694 .08012 m
.73694 .0518 L
.73953 .0518 L
.73953 .08012 L
s
1 .894 .882 r
.73953 .08012 m
.73953 .05092 L
.74181 .05092 L
.74181 .08012 L
F
.804 .522 .247 r
.73953 .08012 m
.73953 .05092 L
.74181 .05092 L
.74181 .08012 L
s
1 .894 .882 r
.74181 .08012 m
.74181 .05009 L
.74563 .05009 L
.74563 .08012 L
F
.804 .522 .247 r
.74181 .08012 m
.74181 .05009 L
.74563 .05009 L
.74563 .08012 L
s
1 .894 .882 r
.74563 .08012 m
.74563 .04912 L
.74839 .04912 L
.74839 .08012 L
F
.804 .522 .247 r
.74563 .08012 m
.74563 .04912 L
.74839 .04912 L
.74839 .08012 L
s
1 .894 .882 r
.74839 .08012 m
.74839 .04798 L
.75262 .04798 L
.75262 .08012 L
F
.804 .522 .247 r
.74839 .08012 m
.74839 .04798 L
.75262 .04798 L
.75262 .08012 L
s
1 .894 .882 r
.75262 .08012 m
.75262 .04692 L
.75495 .04692 L
.75495 .08012 L
F
.804 .522 .247 r
.75262 .08012 m
.75262 .04692 L
.75495 .04692 L
.75495 .08012 L
s
1 .894 .882 r
.75495 .08012 m
.75495 .04614 L
.75752 .04614 L
.75752 .08012 L
F
.804 .522 .247 r
.75495 .08012 m
.75495 .04614 L
.75752 .04614 L
.75752 .08012 L
s
1 .894 .882 r
.75752 .08012 m
.75752 .04501 L
.76069 .04501 L
.76069 .08012 L
F
.804 .522 .247 r
.75752 .08012 m
.75752 .04501 L
.76069 .04501 L
.76069 .08012 L
s
1 .894 .882 r
.76069 .08012 m
.76069 .04377 L
.7646 .04377 L
.7646 .08012 L
F
.804 .522 .247 r
.76069 .08012 m
.76069 .04377 L
.7646 .04377 L
.7646 .08012 L
s
1 .894 .882 r
.7646 .08012 m
.7646 .04281 L
.7683 .04281 L
.7683 .08012 L
F
.804 .522 .247 r
.7646 .08012 m
.7646 .04281 L
.7683 .04281 L
.7683 .08012 L
s
1 .894 .882 r
.7683 .08012 m
.7683 .04267 L
.77168 .04267 L
.77168 .08012 L
F
.804 .522 .247 r
.7683 .08012 m
.7683 .04267 L
.77168 .04267 L
.77168 .08012 L
s
1 .894 .882 r
.77168 .08012 m
.77168 .04107 L
.77535 .04107 L
.77535 .08012 L
F
.804 .522 .247 r
.77168 .08012 m
.77168 .04107 L
.77535 .04107 L
.77535 .08012 L
s
1 .894 .882 r
.77535 .08012 m
.77535 .04013 L
.77875 .04013 L
.77875 .08012 L
F
.804 .522 .247 r
.77535 .08012 m
.77535 .04013 L
.77875 .04013 L
.77875 .08012 L
s
1 .894 .882 r
.77875 .08012 m
.77875 .03964 L
.78301 .03964 L
.78301 .08012 L
F
.804 .522 .247 r
.77875 .08012 m
.77875 .03964 L
.78301 .03964 L
.78301 .08012 L
s
1 .894 .882 r
.78301 .08012 m
.78301 .03811 L
.78707 .03811 L
.78707 .08012 L
F
.804 .522 .247 r
.78301 .08012 m
.78301 .03811 L
.78707 .03811 L
.78707 .08012 L
s
1 .894 .882 r
.78707 .08012 m
.78707 .03792 L
.79074 .03792 L
.79074 .08012 L
F
.804 .522 .247 r
.78707 .08012 m
.78707 .03792 L
.79074 .03792 L
.79074 .08012 L
s
1 .894 .882 r
.79074 .08012 m
.79074 .03657 L
.79331 .03657 L
.79331 .08012 L
F
.804 .522 .247 r
.79074 .08012 m
.79074 .03657 L
.79331 .03657 L
.79331 .08012 L
s
1 .894 .882 r
.79331 .08012 m
.79331 .03561 L
.79693 .03561 L
.79693 .08012 L
F
.804 .522 .247 r
.79331 .08012 m
.79331 .03561 L
.79693 .03561 L
.79693 .08012 L
s
1 .894 .882 r
.79693 .08012 m
.79693 .03556 L
.80031 .03556 L
.80031 .08012 L
F
.804 .522 .247 r
.79693 .08012 m
.79693 .03556 L
.80031 .03556 L
.80031 .08012 L
s
1 .894 .882 r
.80031 .08012 m
.80031 .03434 L
.80235 .03434 L
.80235 .08012 L
F
.804 .522 .247 r
.80031 .08012 m
.80031 .03434 L
.80235 .03434 L
.80235 .08012 L
s
1 .894 .882 r
.80235 .08012 m
.80235 .03371 L
.80542 .03371 L
.80542 .08012 L
F
.804 .522 .247 r
.80235 .08012 m
.80235 .03371 L
.80542 .03371 L
.80542 .08012 L
s
1 .894 .882 r
.80542 .08012 m
.80542 .03277 L
.80948 .03277 L
.80948 .08012 L
F
.804 .522 .247 r
.80542 .08012 m
.80542 .03277 L
.80948 .03277 L
.80948 .08012 L
s
1 .894 .882 r
.80948 .08012 m
.80948 .03256 L
.81128 .03256 L
.81128 .08012 L
F
.804 .522 .247 r
.80948 .08012 m
.80948 .03256 L
.81128 .03256 L
.81128 .08012 L
s
1 .894 .882 r
.81128 .08012 m
.81128 .03183 L
.81527 .03183 L
.81527 .08012 L
F
.804 .522 .247 r
.81128 .08012 m
.81128 .03183 L
.81527 .03183 L
.81527 .08012 L
s
1 .894 .882 r
.81527 .08012 m
.81527 .03119 L
.81717 .03119 L
.81717 .08012 L
F
.804 .522 .247 r
.81527 .08012 m
.81527 .03119 L
.81717 .03119 L
.81717 .08012 L
s
1 .894 .882 r
.81717 .08012 m
.81717 .03062 L
.82038 .03062 L
.82038 .08012 L
F
.804 .522 .247 r
.81717 .08012 m
.81717 .03062 L
.82038 .03062 L
.82038 .08012 L
s
1 .894 .882 r
.82038 .08012 m
.82038 .03033 L
.82313 .03033 L
.82313 .08012 L
F
.804 .522 .247 r
.82038 .08012 m
.82038 .03033 L
.82313 .03033 L
.82313 .08012 L
s
1 .894 .882 r
.82313 .08012 m
.82313 .02965 L
.8258 .02965 L
.8258 .08012 L
F
.804 .522 .247 r
.82313 .08012 m
.82313 .02965 L
.8258 .02965 L
.8258 .08012 L
s
1 .894 .882 r
.8258 .08012 m
.8258 .02916 L
.82823 .02916 L
.82823 .08012 L
F
.804 .522 .247 r
.8258 .08012 m
.8258 .02916 L
.82823 .02916 L
.82823 .08012 L
s
1 .894 .882 r
.82823 .08012 m
.82823 .02873 L
.83055 .02873 L
.83055 .08012 L
F
.804 .522 .247 r
.82823 .08012 m
.82823 .02873 L
.83055 .02873 L
.83055 .08012 L
s
1 .894 .882 r
.83055 .08012 m
.83055 .02824 L
.83216 .02824 L
.83216 .08012 L
F
.804 .522 .247 r
.83055 .08012 m
.83055 .02824 L
.83216 .02824 L
.83216 .08012 L
s
1 .894 .882 r
.83216 .08012 m
.83216 .02763 L
.83641 .02763 L
.83641 .08012 L
F
.804 .522 .247 r
.83216 .08012 m
.83216 .02763 L
.83641 .02763 L
.83641 .08012 L
s
1 .894 .882 r
.83641 .08012 m
.83641 .0271 L
.83971 .0271 L
.83971 .08012 L
F
.804 .522 .247 r
.83641 .08012 m
.83641 .0271 L
.83971 .0271 L
.83971 .08012 L
s
1 .894 .882 r
.83971 .08012 m
.83971 .02652 L
.84309 .02652 L
.84309 .08012 L
F
.804 .522 .247 r
.83971 .08012 m
.83971 .02652 L
.84309 .02652 L
.84309 .08012 L
s
1 .894 .882 r
.84309 .08012 m
.84309 .02586 L
.84609 .02586 L
.84609 .08012 L
F
.804 .522 .247 r
.84309 .08012 m
.84309 .02586 L
.84609 .02586 L
.84609 .08012 L
s
1 .894 .882 r
.84609 .08012 m
.84609 .0254 L
.8481 .0254 L
.8481 .08012 L
F
.804 .522 .247 r
.84609 .08012 m
.84609 .0254 L
.8481 .0254 L
.8481 .08012 L
s
1 .894 .882 r
.8481 .08012 m
.8481 .02487 L
.85277 .02487 L
.85277 .08012 L
F
.804 .522 .247 r
.8481 .08012 m
.8481 .02487 L
.85277 .02487 L
.85277 .08012 L
s
1 .894 .882 r
.85277 .08012 m
.85277 .02452 L
.85666 .02452 L
.85666 .08012 L
F
.804 .522 .247 r
.85277 .08012 m
.85277 .02452 L
.85666 .02452 L
.85666 .08012 L
s
1 .894 .882 r
.85666 .08012 m
.85666 .02349 L
.86036 .02349 L
.86036 .08012 L
F
.804 .522 .247 r
.85666 .08012 m
.85666 .02349 L
.86036 .02349 L
.86036 .08012 L
s
1 .894 .882 r
.86036 .08012 m
.86036 .02301 L
.86347 .02301 L
.86347 .08012 L
F
.804 .522 .247 r
.86036 .08012 m
.86036 .02301 L
.86347 .02301 L
.86347 .08012 L
s
1 .894 .882 r
.86347 .08012 m
.86347 .02251 L
.86699 .02251 L
.86699 .08012 L
F
.804 .522 .247 r
.86347 .08012 m
.86347 .02251 L
.86699 .02251 L
.86699 .08012 L
s
1 .894 .882 r
.86699 .08012 m
.86699 .02241 L
.8687 .02241 L
.8687 .08012 L
F
.804 .522 .247 r
.86699 .08012 m
.86699 .02241 L
.8687 .02241 L
.8687 .08012 L
s
1 .894 .882 r
.8687 .08012 m
.8687 .022 L
.87046 .022 L
.87046 .08012 L
F
.804 .522 .247 r
.8687 .08012 m
.8687 .022 L
.87046 .022 L
.87046 .08012 L
s
1 .894 .882 r
.87046 .08012 m
.87046 .02166 L
.87294 .02166 L
.87294 .08012 L
F
.804 .522 .247 r
.87046 .08012 m
.87046 .02166 L
.87294 .02166 L
.87294 .08012 L
s
1 .894 .882 r
.87294 .08012 m
.87294 .02139 L
.87483 .02139 L
.87483 .08012 L
F
.804 .522 .247 r
.87294 .08012 m
.87294 .02139 L
.87483 .02139 L
.87483 .08012 L
s
1 .894 .882 r
.87483 .08012 m
.87483 .02132 L
.87725 .02132 L
.87725 .08012 L
F
.804 .522 .247 r
.87483 .08012 m
.87483 .02132 L
.87725 .02132 L
.87725 .08012 L
s
1 .894 .882 r
.87725 .08012 m
.87725 .02084 L
.88197 .02084 L
.88197 .08012 L
F
.804 .522 .247 r
.87725 .08012 m
.87725 .02084 L
.88197 .02084 L
.88197 .08012 L
s
1 .894 .882 r
.88197 .08012 m
.88197 .02036 L
.88523 .02036 L
.88523 .08012 L
F
.804 .522 .247 r
.88197 .08012 m
.88197 .02036 L
.88523 .02036 L
.88523 .08012 L
s
1 .894 .882 r
.88523 .08012 m
.88523 .02 L
.88999 .02 L
.88999 .08012 L
F
.804 .522 .247 r
.88523 .08012 m
.88523 .02 L
.88999 .02 L
.88999 .08012 L
s
1 .894 .882 r
.88999 .08012 m
.88999 .01935 L
.89396 .01935 L
.89396 .08012 L
F
.804 .522 .247 r
.88999 .08012 m
.88999 .01935 L
.89396 .01935 L
.89396 .08012 L
s
1 .894 .882 r
.89396 .08012 m
.89396 .01905 L
.89736 .01905 L
.89736 .08012 L
F
.804 .522 .247 r
.89396 .08012 m
.89396 .01905 L
.89736 .01905 L
.89736 .08012 L
s
1 .894 .882 r
.89736 .08012 m
.89736 .01859 L
.89939 .01859 L
.89939 .08012 L
F
.804 .522 .247 r
.89736 .08012 m
.89736 .01859 L
.89939 .01859 L
.89939 .08012 L
s
1 .894 .882 r
.89939 .08012 m
.89939 .0183 L
.90314 .0183 L
.90314 .08012 L
F
.804 .522 .247 r
.89939 .08012 m
.89939 .0183 L
.90314 .0183 L
.90314 .08012 L
s
1 .894 .882 r
.90314 .08012 m
.90314 .01818 L
.90623 .01818 L
.90623 .08012 L
F
.804 .522 .247 r
.90314 .08012 m
.90314 .01818 L
.90623 .01818 L
.90623 .08012 L
s
1 .894 .882 r
.90623 .08012 m
.90623 .01779 L
.90945 .01779 L
.90945 .08012 L
F
.804 .522 .247 r
.90623 .08012 m
.90623 .01779 L
.90945 .01779 L
.90945 .08012 L
s
1 .894 .882 r
.90945 .08012 m
.90945 .01759 L
.91199 .01759 L
.91199 .08012 L
F
.804 .522 .247 r
.90945 .08012 m
.90945 .01759 L
.91199 .01759 L
.91199 .08012 L
s
1 .894 .882 r
.91199 .08012 m
.91199 .01737 L
.91387 .01737 L
.91387 .08012 L
F
.804 .522 .247 r
.91199 .08012 m
.91199 .01737 L
.91387 .01737 L
.91387 .08012 L
s
1 .894 .882 r
.91387 .08012 m
.91387 .01704 L
.91835 .01704 L
.91835 .08012 L
F
.804 .522 .247 r
.91387 .08012 m
.91387 .01704 L
.91835 .01704 L
.91835 .08012 L
s
1 .894 .882 r
.91835 .08012 m
.91835 .0168 L
.92 .0168 L
.92 .08012 L
F
.804 .522 .247 r
.91835 .08012 m
.91835 .0168 L
.92 .0168 L
.92 .08012 L
s
1 .894 .882 r
.92 .08012 m
.92 .01674 L
.92196 .01674 L
.92196 .08012 L
F
.804 .522 .247 r
.92 .08012 m
.92 .01674 L
.92196 .01674 L
.92196 .08012 L
s
1 .894 .882 r
.92196 .08012 m
.92196 .01655 L
.92394 .01655 L
.92394 .08012 L
F
.804 .522 .247 r
.92196 .08012 m
.92196 .01655 L
.92394 .01655 L
.92394 .08012 L
s
1 .894 .882 r
.92394 .08012 m
.92394 .01643 L
.92596 .01643 L
.92596 .08012 L
F
.804 .522 .247 r
.92394 .08012 m
.92394 .01643 L
.92596 .01643 L
.92596 .08012 L
s
1 .894 .882 r
.92596 .08012 m
.92596 .01621 L
.92868 .01621 L
.92868 .08012 L
F
.804 .522 .247 r
.92596 .08012 m
.92596 .01621 L
.92868 .01621 L
.92868 .08012 L
s
1 .894 .882 r
.92868 .08012 m
.92868 .01611 L
.9323 .01611 L
.9323 .08012 L
F
.804 .522 .247 r
.92868 .08012 m
.92868 .01611 L
.9323 .01611 L
.9323 .08012 L
s
1 .894 .882 r
.9323 .08012 m
.9323 .01585 L
.93551 .01585 L
.93551 .08012 L
F
.804 .522 .247 r
.9323 .08012 m
.9323 .01585 L
.93551 .01585 L
.93551 .08012 L
s
1 .894 .882 r
.93551 .08012 m
.93551 .01577 L
.93726 .01577 L
.93726 .08012 L
F
.804 .522 .247 r
.93551 .08012 m
.93551 .01577 L
.93726 .01577 L
.93726 .08012 L
s
1 .894 .882 r
.93726 .08012 m
.93726 .01559 L
.93965 .01559 L
.93965 .08012 L
F
.804 .522 .247 r
.93726 .08012 m
.93726 .01559 L
.93965 .01559 L
.93965 .08012 L
s
1 .894 .882 r
.93965 .08012 m
.93965 .01554 L
.94221 .01554 L
.94221 .08012 L
F
.804 .522 .247 r
.93965 .08012 m
.93965 .01554 L
.94221 .01554 L
.94221 .08012 L
s
1 .894 .882 r
.94221 .08012 m
.94221 .01539 L
.94497 .01539 L
.94497 .08012 L
F
.804 .522 .247 r
.94221 .08012 m
.94221 .01539 L
.94497 .01539 L
.94497 .08012 L
s
1 .894 .882 r
.94497 .08012 m
.94497 .01535 L
.94907 .01535 L
.94907 .08012 L
F
.804 .522 .247 r
.94497 .08012 m
.94497 .01535 L
.94907 .01535 L
.94907 .08012 L
s
1 .894 .882 r
.94907 .08012 m
.94907 .01515 L
.9515 .01515 L
.9515 .08012 L
F
.804 .522 .247 r
.94907 .08012 m
.94907 .01515 L
.9515 .01515 L
.9515 .08012 L
s
1 .894 .882 r
.9515 .08012 m
.9515 .0151 L
.95557 .0151 L
.95557 .08012 L
F
.804 .522 .247 r
.9515 .08012 m
.9515 .0151 L
.95557 .0151 L
.95557 .08012 L
s
1 .894 .882 r
.95557 .08012 m
.95557 .01496 L
.95834 .01496 L
.95834 .08012 L
F
.804 .522 .247 r
.95557 .08012 m
.95557 .01496 L
.95834 .01496 L
.95834 .08012 L
s
1 .894 .882 r
.95834 .08012 m
.95834 .0149 L
.9599 .0149 L
.9599 .08012 L
F
.804 .522 .247 r
.95834 .08012 m
.95834 .0149 L
.9599 .0149 L
.9599 .08012 L
s
1 .894 .882 r
.9599 .08012 m
.9599 .01486 L
.96369 .01486 L
.96369 .08012 L
F
.804 .522 .247 r
.9599 .08012 m
.9599 .01486 L
.96369 .01486 L
.96369 .08012 L
s
1 .894 .882 r
.96369 .08012 m
.96369 .0148 L
.96716 .0148 L
.96716 .08012 L
F
.804 .522 .247 r
.96369 .08012 m
.96369 .0148 L
.96716 .0148 L
.96716 .08012 L
s
1 .894 .882 r
.96716 .08012 m
.96716 .01474 L
.97095 .01474 L
.97095 .08012 L
F
.804 .522 .247 r
.96716 .08012 m
.96716 .01474 L
.97095 .01474 L
.97095 .08012 L
s
1 .894 .882 r
.97095 .08012 m
.97095 .01472 L
.97419 .01472 L
.97419 .08012 L
F
.804 .522 .247 r
.97095 .08012 m
.97095 .01472 L
.97419 .01472 L
.97419 .08012 L
s
1 .894 .882 r
.97419 .08012 m
.97419 .01472 L
.97619 .01472 L
.97619 .08012 L
F
.804 .522 .247 r
.97419 .08012 m
.97419 .01472 L
.97619 .01472 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.02466 .60227 Mdot
.02937 .59647 Mdot
.03419 .59056 Mdot
.03611 .58822 Mdot
.03793 .58599 Mdot
.04076 .58255 Mdot
.04422 .57836 Mdot
.04771 .57414 Mdot
.05027 .57106 Mdot
.0551 .56528 Mdot
.05629 .56385 Mdot
.05878 .56089 Mdot
.06033 .55904 Mdot
.06368 .55507 Mdot
.0683 .54961 Mdot
.07084 .54662 Mdot
.07502 .54172 Mdot
.07769 .5386 Mdot
.08305 .53237 Mdot
.08628 .52863 Mdot
.08942 .52502 Mdot
.09126 .5229 Mdot
.09795 .51525 Mdot
.09877 .51431 Mdot
.10253 .51003 Mdot
.10769 .50421 Mdot
.11009 .5015 Mdot
.1135 .49767 Mdot
.1167 .4941 Mdot
.1198 .49065 Mdot
.12345 .4866 Mdot
.12446 .48548 Mdot
.12881 .48068 Mdot
.13141 .47783 Mdot
.13427 .4747 Mdot
.13507 .47382 Mdot
.14186 .46645 Mdot
.14285 .46537 Mdot
.14613 .46183 Mdot
.14804 .45978 Mdot
.1489 .45886 Mdot
.15253 .45496 Mdot
.15375 .45366 Mdot
.15682 .45039 Mdot
.16189 .44502 Mdot
.16567 .44103 Mdot
.16863 .43792 Mdot
.17047 .436 Mdot
.17295 .43341 Mdot
.17581 .43043 Mdot
.17653 .42968 Mdot
.17893 .42719 Mdot
.18349 .42249 Mdot
.18549 .42044 Mdot
.18839 .41746 Mdot
.19237 .4134 Mdot
.19429 .41145 Mdot
.19985 .40583 Mdot
.20333 .40233 Mdot
.20578 .39988 Mdot
.20713 .39853 Mdot
.21268 .39301 Mdot
.21656 .38918 Mdot
.22102 .38479 Mdot
.22408 .3818 Mdot
.22722 .37874 Mdot
.22849 .3775 Mdot
.23149 .3746 Mdot
.23345 .3727 Mdot
.23671 .36957 Mdot
.24116 .36532 Mdot
.242 .36451 Mdot
.24783 .35898 Mdot
.24977 .35715 Mdot
.25434 .35285 Mdot
.25597 .35133 Mdot
.26026 .34733 Mdot
.26382 .34403 Mdot
.26926 .33902 Mdot
.27356 .33509 Mdot
.27625 .33264 Mdot
.28083 .32849 Mdot
.28693 .32301 Mdot
.29148 .31895 Mdot
.29447 .3163 Mdot
.29685 .3142 Mdot
.30393 .30799 Mdot
.30432 .30765 Mdot
.3104 .30237 Mdot
.3119 .30108 Mdot
.31496 .29844 Mdot
.31876 .29519 Mdot
.32231 .29217 Mdot
.32469 .29016 Mdot
.32906 .28648 Mdot
.33217 .28387 Mdot
.336 .28068 Mdot
.34023 .27717 Mdot
.34226 .2755 Mdot
.34524 .27305 Mdot
.3469 .2717 Mdot
.35034 .2689 Mdot
.35512 .26503 Mdot
.35608 .26426 Mdot
.35914 .2618 Mdot
.36123 .26013 Mdot
.36313 .25861 Mdot
.36739 .25523 Mdot
.37275 .25102 Mdot
.3763 .24825 Mdot
.37709 .24763 Mdot
.38123 .24442 Mdot
.38313 .24296 Mdot
.3879 .23931 Mdot
.39012 .23761 Mdot
.39368 .23491 Mdot
.39694 .23245 Mdot
.40046 .22981 Mdot
.40407 .22712 Mdot
.40882 .22361 Mdot
.4104 .22245 Mdot
.4136 .22011 Mdot
.4166 .21792 Mdot
.42041 .21517 Mdot
.42438 .21231 Mdot
.4281 .20966 Mdot
.43322 .20603 Mdot
.4347 .20499 Mdot
.44008 .20123 Mdot
.4438 .19865 Mdot
.44595 .19716 Mdot
.44951 .19473 Mdot
.45314 .19225 Mdot
.45531 .19078 Mdot
.4568 .18978 Mdot
.4615 .18662 Mdot
.468 .18231 Mdot
.46884 .18175 Mdot
.47258 .1793 Mdot
.47473 .1779 Mdot
.47758 .17605 Mdot
.47997 .17451 Mdot
.48307 .17252 Mdot
.48761 .16962 Mdot
.49104 .16745 Mdot
.4937 .16579 Mdot
.49867 .16269 Mdot
.50094 .16128 Mdot
.50445 .15913 Mdot
.50821 .15684 Mdot
.51132 .15495 Mdot
.51516 .15264 Mdot
.52013 .14969 Mdot
.52339 .14777 Mdot
.52698 .14567 Mdot
.52905 .14446 Mdot
.53345 .14192 Mdot
.53736 .13968 Mdot
.53969 .13836 Mdot
.54126 .13747 Mdot
.54602 .1348 Mdot
.5474 .13403 Mdot
.55216 .13139 Mdot
.55453 .13009 Mdot
.55708 .1287 Mdot
.55915 .12758 Mdot
.56146 .12633 Mdot
.56386 .12505 Mdot
.56602 .12389 Mdot
.56988 .12185 Mdot
.57262 .1204 Mdot
.57398 .1197 Mdot
.57758 .11783 Mdot
.58248 .11531 Mdot
.58716 .11293 Mdot
.59313 .10994 Mdot
.594 .1095 Mdot
.59492 .10905 Mdot
.6028 .10519 Mdot
.60447 .10438 Mdot
.60754 .10291 Mdot
.60888 .10227 Mdot
.61179 .10089 Mdot
.61473 .0995 Mdot
.61719 .09835 Mdot
.61913 .09745 Mdot
.6259 .09434 Mdot
.62713 .09378 Mdot
.63226 .09147 Mdot
.63582 .0899 Mdot
.64094 .08765 Mdot
.64534 .08575 Mdot
.64954 .08396 Mdot
.65099 .08334 Mdot
.65406 .08205 Mdot
.6566 .081 Mdot
.66058 .07936 Mdot
.66346 .07818 Mdot
.66687 .07681 Mdot
.66881 .07603 Mdot
.67192 .07479 Mdot
.67544 .07341 Mdot
.68026 .07154 Mdot
.68303 .07049 Mdot
.68493 .06977 Mdot
.68855 .06841 Mdot
.69105 .06748 Mdot
.69454 .06619 Mdot
.69711 .06526 Mdot
.70162 .06364 Mdot
.70588 .06213 Mdot
.70866 .06116 Mdot
.71274 .05975 Mdot
.71327 .05958 Mdot
.71609 .05862 Mdot
.71905 .05762 Mdot
.71958 .05745 Mdot
.72613 .05529 Mdot
.73101 .05373 Mdot
.7327 .05319 Mdot
.73505 .05245 Mdot
.73714 .0518 Mdot
.73999 .05092 Mdot
.74271 .05009 Mdot
.74595 .04912 Mdot
.74977 .04798 Mdot
.75342 .04692 Mdot
.75612 .04614 Mdot
.76011 .04501 Mdot
.7646 .04377 Mdot
.76813 .04281 Mdot
.76864 .04267 Mdot
.77466 .04107 Mdot
.77828 .04013 Mdot
.7802 .03964 Mdot
.78632 .03811 Mdot
.78708 .03792 Mdot
.79267 .03657 Mdot
.79674 .03561 Mdot
.79696 .03556 Mdot
.80228 .03434 Mdot
.80512 .03371 Mdot
.80937 .03277 Mdot
.81034 .03256 Mdot
.81381 .03183 Mdot
.81685 .03119 Mdot
.81965 .03062 Mdot
.82105 .03033 Mdot
.82451 .02965 Mdot
.82702 .02916 Mdot
.82922 .02873 Mdot
.83181 .02824 Mdot
.83513 .02763 Mdot
.83807 .0271 Mdot
.84131 .02652 Mdot
.84515 .02586 Mdot
.84787 .0254 Mdot
.85109 .02487 Mdot
.85328 .02452 Mdot
.85988 .02349 Mdot
.86311 .02301 Mdot
.8666 .02251 Mdot
.86731 .02241 Mdot
.87021 .022 Mdot
.87275 .02166 Mdot
.87481 .02139 Mdot
.87534 .02132 Mdot
.87904 .02084 Mdot
.88291 .02036 Mdot
.88598 .02 Mdot
.89172 .01935 Mdot
.89442 .01905 Mdot
.89893 .01859 Mdot
.90185 .0183 Mdot
.90317 .01818 Mdot
.90736 .01779 Mdot
.90964 .01759 Mdot
.91229 .01737 Mdot
.91627 .01704 Mdot
.91945 .0168 Mdot
.92037 .01674 Mdot
.92298 .01655 Mdot
.92476 .01643 Mdot
.92812 .01621 Mdot
.92976 .01611 Mdot
.93431 .01585 Mdot
.9359 .01577 Mdot
.93949 .01559 Mdot
.94061 .01554 Mdot
.94398 .01539 Mdot
.94502 .01535 Mdot
.95042 .01515 Mdot
.95186 .0151 Mdot
.9569 .01496 Mdot
.95924 .0149 Mdot
.96148 .01486 Mdot
.96479 .0148 Mdot
.97029 .01474 Mdot
.97279 .01472 Mdot
.97432 .01472 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0149792) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.00077) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0P0000050?[`iP80
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00040?[`iP8000001@3jl>H200000?l0n_3VY03jl>H10?ooo`00803jl>H2000000030?[`iP000000
000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V00800000603j
l>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000050?[`iP800000o`3j
l>JT0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003j
l>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V00000000
00002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V000000000000103jl>H2000000D0n_3V0P00003o0?[`iZ@0n_3V0@3oool00200n_3V
0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000
n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P000000
0`3jl>H000000?[`iP02000001P0n_3V1000000:0?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000050?[`iP8000001@3jl>H2
00000?l0n_3VX`3jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3jl>H00000000000020000
00@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H50000
00X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`iP800000303jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000001@3jl>H2000000D0n_3V0P00003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09P3jl>H2000000/0n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080
n_3V00<000000?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V00800000o`3jl>JS0?[`iP40
oooo000O0?[`iPH00000103jl>H2000002l0n_3V1@00000Y0?[`iP<000002P3jl>H3000000@0n_3V
0`0000040?[`iP<000000`3jl>H500000080n_3V1@00003o0?[`iZ<0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H400000?l0
n_3Vo`3jl>HH0?[`iP40oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200n_3V1P00
00001@3jl>H00000000000000000n_3V00<000000P3jl>H3000000<0n_3V100000030?[`iP800000
00@0n_3V000000000000n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P00003o0?[`i/T0
n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V
00@000000?[`iP00000000000`3jl>H01@000000n_3V000000000000n_3V00<000000P3jl>H20000
00@0n_3V0P0000020?[`iP8000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000
000000000`3jl>H200000?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H0
0000000000020?[`iP800000103jl>H2000000D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0
n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H000000000003o0?[`i/h0
n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V
1P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000D0n_3V1@0000030?[`iP800000
8P3jl>H5000000T0n_3V0P0000000`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V0P00
00040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000020?[`iP80000000@0
n_3V000000000000n_3V0`0000020?[`iP<0000000<0n_3V0000003jl>H0103jl>H2000000<0n_3V
0P00000`0?[`iP@00000o`3jl>K?0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080n_3V1@00
00030?[`iP@000000`3jl>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3j
l>H4000000@0n_3V0P00000`0?[`iP800000o`3jl>KA0?[`iP40oooo000R0?[`iP8000002`3jl>H2
00000280n_3V0P00000a0?[`iP800000o`3jl>K@0?[`iP40oooo000P0?[`iPH000002@3jl>H20000
0200n_3V1000000b0?[`iP<00000o`3jl>K>0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3j
l>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP04
0000003jl>H000000?[`iP8000000P3jl>H00`000000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`
iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P0000001@3jl>H000000?[`iP000000n_3V
00<000000P3jl>H00`000000n_3V0000000I0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`
iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`000000103j
l>H000000000000000080?[`iP@0000000<0n_3V0000000000000P3jl>H400000080n_3V1@000000
1`3jl>H00000000000000000n_3V0000003jl>H00`00000H0?[`iP<00000103jl>H2000000D0n_3V
0`0000030?[`iPH000000P3jl>H400000080n_3V0`0000060?[`iP8000000`3jl>H3000000@0n_3V
1@00001a0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@000000103jl>H000000000
000000020?[`iP80000000<0n_3V0000000000002@3jl>H5000000T0n_3V00<000000?[`iP3jl>H0
0P00003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V
00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000
003jl>H00P0000090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`
iP80000000<0n_3V000000000000103jl>H2000000D0n_3V0P0000050?[`iP8000001@3jl>H20000
00D0n_3V0P0000030?[`iP800000M03jl>H10?ooo`008P3jl>H3000002/0n_3V0P00003L0?[`iP80
0000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP80
00001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0
n_3V0P0000001@3jl>H00000000000000000n_3V008000000P3jl>H200000080n_3V0P0000040?[`
iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H20000
00030?[`iP000000000000@0n_3V0P0000020?[`iPH000001@3jl>H2000000@0n_3V0P0000060?[`
iP8000000`3jl>H2000007<0n_3V0@3oool00280n_3V0`00000J0?[`iPD00000303jl>H200000=`0
n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0
n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80
000000D0n_3V00000000000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H20000
00030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000090?[`
iP80000000<0n_3V000000000000103jl>H200000080n_3V00<000000?[`iP3jl>H00P0000040?[`
iP@00000103jl>H2000000@0n_3V100000040?[`iP800000LP3jl>H10?ooo`008@3jl>H200000003
0?[`iP000000000002P0n_3V0`00003M0?[`iP80000000<0n_3V0000000000001@3jl>H200000080
n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP000000000000X0n_3V0`000000103j
l>H000000000003jl>H200000080n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H00P000000
0`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V
000000000000103jl>H2000000<0n_3V00@000000?[`iP00000000000`3jl>H2000000030?[`iP00
0000000000D0n_3V0P0000020?[`iP80000000<0n_3V0000000000001@3jl>H200000740n_3V0@3o
ool00200n_3V0`000000103jl>H0000000000000000Y0?[`iP800000g03jl>H2000000030?[`iP00
000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@00000
0`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`0000000`3jl>H00000
000000020?[`iP@000000P3jl>H3000000030?[`iP000000000000L000006@3jl>H2000000030?[`
iP000000000000T0n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H010000000n_3V
0000000000030?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V000000000000L@3jl>H10?ooo`00C@3jl>H00`000000n_3V
0?[`iP0200000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V
0P0000020?[`iP800000;P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000
000000020?[`iP@00000103jl>H3000000<0n_3V0P0000000`3jl>H00000000000020?[`iP030000
003jl>H0n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
0000001a0?[`iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103j
l>H2000000H0n_3V0P00000I0?[`iP<0000000<0n_3V0000000000000P00000^0?[`iP<000002`3j
l>H3000000D0n_3V0P0000050?[`iP800000103jl>H3000000<0n_3V1@0000030?[`iP<00000103j
l>H300000780n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V000000000000
o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00D000000?[`iP000000n_3V000000020?[`iP040000
003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H0o`3jl>Ko0?[`iR80n_3V0@3oool00200n_3V
0`0000000`3jl>H0000000000002000000040?[`iP000000n_3V00000080n_3V00@000000?[`iP3j
l>H000000P3jl>H00`000000n_3V0?[`iP0G0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`
iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`0000000`3j
l>H0000000000006000001/0n_3V0`0000040?[`iP<00000103jl>H300000;X0n_3V0@3oool00240
n_3V0P0000000`3jl>H0000000000005000000050?[`iP00000000000000003jl>H01000000;0?[`
iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H20000
0080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P000002
0?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0
n_3V000000000000n_3V0P0000020?[`iP8000002`3jl>H5000000T0n_3V00<000000?[`iP3jl>H0
0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000;T0n_3V
0@3oool00280n_3V0`00000X0?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P00
00020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00
00030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`iP@00000703j
l>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000^@3j
l>H10?ooo`008P3jl>H3000000T0n_3V00<000000?[`iP3jl>H03P3jl>H5000000T0n_3V0P000000
0`3jl>H000000000003L0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP8000001P3jl>H2
000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V
000000000000n_3V1000000=0?[`iPD00000303jl>H200000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V000000000000^@3jl>H10?ooo`008@3jl>H2000000030?[`iP000000
000002L0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000001@3jl>H2
00000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP800000
0P3jl>H2000001X0n_3V0`0000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP00000000000;T0n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V0?[`iP800000
00<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V100000020?[`iP<00000
00@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@0
00000P3jl>H5000000<0n_3V1@00000L0?[`iP8000000P3jl>H2000000030?[`iP00000000000080
n_3V0P0000000`3jl>H000000000002i0?[`iP40oooo001=0?[`iP80000000<0n_3V000000000000
g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP800000>03jl>H00`000000n_3V
0?[`iP0200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000
^@3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P00
00060?[`iP800000<@3jl>H3000000@0n_3V0`0000040?[`iP<00000^P3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0n_3V8`3oon02000004D0oooP
0P0000040?ooh0800000103oon02000004@0oooP1@0000130?ooh0D000000P3oon02000000@0oooP
0P0000140?ooh0@00000A03oon04000000<0oooP0P0000040?ooh0800000A@3oon02000002L0oooP
7P3jl>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon00
0000203oon0010000000oooP0?ooh00000150?ooh0030000003oon00oooP04D0oooP00<000000?oo
h03oon001`3oon0010000000oooP0?ooh00000130?ooh0030000003oon00oooP04D0oooP00<00000
0?ooh03oon002@3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP000002H0oooP
7P3jl>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon00
00002`3oon000`000000oooP0?ooh0130?ooh0030000003oon00oooP04D0oooP00<000000?ooh03o
on002P3oon000`000000oooP0?ooh0120?ooh0030000003oon00oooP04D0oooP00<000000?ooh03o
on002`3oon000`000000oooP0?ooh0130?ooh0030000003oon00oooP02D0oooP7P3jl>H10?ooo`00
7@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon0000002@3oon020000
04H0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0800000AP3oon000`00
0000oooP0?ooh0150?ooh0030000003oon00oooP00P0oooP0P0000170?ooh0030000003oon00oooP
02@0oooP7P3jl>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?oo
h03oon0000002@3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP04D0oooP00<00000
0?ooh03oon00203oon000`000000oooP0?ooh0130?ooh0040000003oon00oooP000004@0oooP00@0
00000?ooh03oon0000002@3oon000`000000oooP0?ooh0130?ooh0040000003oon00oooP000002H0
oooP7P3jl>H10?ooo`007@3jl>HS0?ooh0800000A@3oon02000000X0oooP0`0000140?ooh0800000
AP3oon02000000X0oooP0`0000140?ooh0800000AP3oon02000000X0oooP0`0000140?ooh0800000
9`3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh?l00000jP00000K0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP
00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303o
on000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3o
on000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01:
0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01;
0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
b03oon04000000030?ooh0000000000000L0000000<0oooP0000000000000P00000;0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP^@3o
on0S000000X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`00003o
0?ooh;00oooP4@00000J0000o`030000003oon00oooP00H0oooP0`00000K0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh03o0?ooh:L0oooP4P0000080000o`/0000000<0onCQ0000
000000001`0000000`3=QCl0000000000002000000/0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2Q0?ooh0l000002@000?lA00000003
0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00<0onCQ
0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh9/0oooP2`00000:0000o`X0000000@0onCQ0<f5?`3=QCl0onCQ103=QCl0
0`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oT
h@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh9D0oooP2@0000080000o`T0000000D0
onCQ0<f5?`3oi>40cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=
QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh900oooP200000060000
o`X000000`3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@030<f5?`040?oT
h@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0?oTh@050<f5?`03
0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00<0onCQ
0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh8X0oooP1`0000070000o`P000000P3=QCl00`3oi>40cHDo0?oTh@020<f5
?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@030<f5
?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0?oTh@05
0<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo
00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh8H0oooP1P0000050000o`/0000000@0cHDo0?oTh@3=QCl0onCQ
0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=
QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh880oooP0P000000103o
on0000000000000000040000o`T0000000H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`030?oT
h@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3oi>400P3=QCl03@3oi>40cHDo0<f5?`3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`03
0?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@020<f5?`07
0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo00/0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1m0?oo
h080000000<0oooP0000000000000P0000040000o`P0000000<0onCQ0<f5?`3=QCl00P3=QCl01P3o
i>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0?oT
h@020<f5?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oT
h@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo
0?oTh@050<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ
0080cHDo00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh03o0?ooh7T0oooP1`0000040000o`L0000000<0onCQ0<f5?`3o
i>400P3=QCl00`3oi>40cHDo0<f5?`020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0
0`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00d0onCQ0<f5?`3=QCl0cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400P3=
QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`0;0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
M`3oon05000000@0003o100000001@3=QCl000000000003=QCl0onCQ0080cHDo00<0onCQ0<f5?`3o
i>400P3=QCl00`3oi>40cHDo0<f5?`020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl0
0`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00d0onCQ0<f5?`3=QCl0cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400P3=
QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`0;0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
LP3oon06000000@0003o0`000000103oi>4000000000003oi>430<f5?`030?oTh@3=QCl0onCQ0080
cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`020<f5?`060?oTh@3=QCl0cHDo0?oT
h@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00d0onCQ
0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ00<0cHDo00@0onCQ
0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0
onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl00`3oi>40
cHDo0<f5?`0;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPKP3oon06000000@0003o10000000103=QCl0onCQ0<f5?`3oi>420<f5?`07
0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>40
0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=
QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh6/0oooP1@0000040000
o`D0000000L0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo
0?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`020<f5?`06
0?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0
onCQ0080cHDo00d0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=
QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3o
i>400P3=QCl00`3oi>40cHDo0<f5?`0;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP0?l0oooPJ03oon04000000@0003o1P0000002P3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40
cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01P3oi>40
cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@02
0<f5?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@03
0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0?oT
h@050<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080
cHDo00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon0300000?l0oooPI03oon04000000@0003o1P0000000`3oi>40cHDo0?oTh@020<f5?`090?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oT
h@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`020<f5?`060?oT
h@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ
0080cHDo00d0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
onCQ00D0cHDo00<0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>40
0P3=QCl00`3oi>40cHDo0<f5?`090?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00o`3oon1R0?ooh0<000000`000?l7000000060<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=
QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl0
0`3oi>40cHDo0?oTh@020<f5?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5
?`3oi>40cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=
QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo
0?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh600oooP0P0000030000o`H00000
00<0cHDo0?oTh@3=QCl00P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00T0onCQ0<f5?`3o
i>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3o
i>400P3=QCl00`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo0080cHDo00H0onCQ0<f5?`3=
QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3oi>400P3=QCl0
3@3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400`3=QCl0
103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3oi>401@3=
QCl00`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`03
0?oTh@3=QCl0cHDo00/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon1K0?ooh0<0000000@0cHDo0000o`000?l0003o1P0000001@3=QCl0
onCQ0<f5?`3=QCl0onCQ00<0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0
onCQ0080cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`020<f5?`060?oTh@3=QCl0
cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo
00d0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ00<0cHDo
00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0onCQ00D0
cHDo00<0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0
0`3oi>40cHDo0<f5?`0;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0?l0oooPF@3oon0400000080003o1P0000001@3=QCl0onCQ0<f5?`3=QCl0
onCQ0080cHDo00T0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl02@3oi>40
cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40
cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01P3oi>40
cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@02
0<f5?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@03
0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0?oT
h@050<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080
cHDo00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh5H0oooP100000030000o`80000000D0onCQ000000000000
cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00T0onCQ0<f5?`3=QCl0cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@02
0<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo
00<0onCQ0<f5?`3=QCl00P3=QCl01P3oi>40cHDo0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5
?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@020<f5?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@030<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ
0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5@0oooP0`00
00030000o`@0000000H0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>420<f5?`040?oTh@3=QCl0cHDo0?oT
h@80cHDo00T0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo
0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01P3oi>40cHDo
0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@020<f5
?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@030<f5
?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0?oTh@05
0<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo
00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh03o0?ooh500oooP100000030000o`@00000103=QCl01@3oi>40cHDo0?oT
h@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl02@3oi>40cHDo0<f5?`3=QCl0onCQ
0<f5?`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ
0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3oi>400P3=
QCl00`3oi>40cHDo0<f5?`020<f5?`060?oTh@3=QCl0cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40
cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00d0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ00<0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3o
i>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0onCQ00D0cHDo00<0onCQ0<f5?`3oi>400P3=QCl01`3o
i>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`0;0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPC@3oon04
000000<0003o1@0000060<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5
?`3oi>420<f5?`090?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00T0onCQ
0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ
0<f5?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo0080cHDo00H0onCQ
0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3oi>40
0P3=QCl03@3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40
0`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3o
i>401@3=QCl00`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@02
0<f5?`030?oTh@3=QCl0cHDo00/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon1;0?ooh0@000000P000?l5000000030?oTh@3=QCl0onCQ
00H0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00T0
onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo0?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5
?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01P3oi>40cHDo0<f5?`3oi>40
cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@020<f5?`0=0?oTh@3=
QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@030<f5?`040?oTh@3=
QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0?oTh@050<f5?`030?oT
h@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5
?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh4T0oooP0`0000030000o`@0000000H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>46
0<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`090?oT
h@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00T0onCQ0<f5?`3oi>40cHDo0?oT
h@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0
0`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5
?`3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3oi>400P3=QCl03@3oi>40cHDo
0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400`3=QCl0103oi>40cHDo
0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40
cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0
cHDo00/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00o`3oon150?ooh0D000000P000?l4000000040<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ
0<f5?`3oi>401P3=QCl01@3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00@0onCQ0<f5?`3=QCl0onCQ
0P3=QCl02@3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`090?oTh@3=QCl0
onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0
onCQ0080cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0<f5?`020<f5?`060?oTh@3=QCl0
cHDo0?oTh@3=QCl0onCQ0P3=QCl00`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo
00d0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ00<0cHDo
00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0onCQ00D0
cHDo00<0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl0
0`3oi>40cHDo0<f5?`0;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0?l0oooP@`3oon04000000<0003o0`0000020<f5?`050?oTh@3=QCl0onCQ
0<f5?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@060<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=
QCl0103oi>40cHDo0<f5?`3oi>420<f5?`090?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0
onCQ0080cHDo00T0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40
cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0
cHDo0080cHDo00H0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo
00<0onCQ0<f5?`3oi>400P3=QCl03@3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=
QCl0onCQ0<f5?`3oi>400`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080
cHDo00<0onCQ0<f5?`3oi>401@3=QCl00`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5
?`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo00/0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP0?l0oooP@@3oon030000
00<0003o100000002@3=QCl0onCQ0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`030?oT
h@3=QCl0onCQ00H0cHDo00D0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`040?oTh@3=QCl0cHDo0?oT
h@80cHDo00T0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl02@3oi>40cHDo
0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo
0?oTh@020<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3=QCl00P3=QCl01P3oi>40cHDo
0<f5?`3oi>40cHDo0?oTh@80cHDo00<0onCQ0<f5?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@020<f5
?`0=0?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@030<f5
?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0?oTh@05
0<f5?`030?oTh@3=QCl0onCQ0080cHDo00L0onCQ0<f5?`3=QCl0cHDo0?oTh@3=QCl0onCQ0080cHDo
00<0onCQ0<f5?`3=QCl02`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3o
on0010000000oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooP?P3oon0400000080003o
1@000000103oi>40cHDo0<f5?`3oi>420<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl00`3o
i>40cHDo0?oTh@060<f5?`050?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl0103oi>40cHDo0<f5?`3o
i>420<f5?`090?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0080cHDo00T0onCQ0<f5
?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400P3=QCl01`3oi>40cHDo0<f5?`3=QCl0onCQ0<f5
?`3oi>400P3=QCl00`3oi>40cHDo0?oTh@020<f5?`030?oTh@3=QCl0cHDo0080cHDo00H0onCQ0<f5
?`3=QCl0onCQ0<f5?`3oi>420<f5?`030?oTh@3=QCl0onCQ0080cHDo00<0onCQ0<f5?`3oi>400P3=
QCl03@3oi>40cHDo0<f5?`3=QCl0onCQ0<f5?`3oi>40cHDo0?oTh@3=QCl0onCQ0<f5?`3oi>400`3=
QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3oi>40
1@3=QCl00`3oi>40cHDo0?oTh@020<f5?`070?oTh@3=QCl0cHDo0<f5?`3oi>40cHDo0?oTh@020<f5
?`030?oTh@3=QCl0cHDo00/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0
oooP00@000000?ooh03oon0000001`3oon04000000P0oooPo`00000f000000<0003oV@0000080?oo
h0@000006`3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`00
0000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:03>QbP0cXLX0
[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP80[MSV0P0cXLX01@2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080
[MSV00`0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H300000080
003o1000002S0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000
003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gH
iP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80
<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX2
0:gHiP80<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0
[MSV03>QbP0cXLX0[MSV03>QbP020:gHiP0:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP<000000P000?l500000:@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iPh0oooP0P0000080?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]
f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>Q
bP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080
<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:
0P2]f>H203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP05
0:gHiP0cXLX0<j7:0:gHiP0cXLX00P2]f>H0200cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0`0000020000o`<00000Z03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP08
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:03>Q
bP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP80[MSV0P0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0
<j7:0080[MSV00@0<j7:0:gHiP0cXLX0[MSV1@0000020000o`@00000Z@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV
03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H7
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0c
XLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:
03>QbP0203>QbP80[MSV0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV00<0<j7:0:gHiP0cXLX00`0000030000
o`<00000[03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0
<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV
03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP80[MSV0P0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080[MSV
00@0<j7:00000000000000000P000?l400000:h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80
<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
2@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gH
iP80<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX20:gH
iP80<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV
03>QbP0cXLX0[MSV0P0000000`2]f>H00000000000020000o`@00000/03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV
03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H7
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0c
XLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:
03>QbP0203>QbP80[MSV0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00`0cXLX00`2]f>H0<j7:0000000400000080003o0P00002d0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:
0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:
00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]
f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0
<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0
[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:
0080<j7:0P2]f>H203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP030:gHiP0000000000008000000P000?l00`0cXLX000000000002e0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]
f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
2`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0
[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>Q
bP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0c
XLX0<j7:0080<j7:0P2]f>H203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP@000000P000?l00`000000oooP0?ooh02g0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gH
iP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H2
03>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H4
03>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV
0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080
<j7:0P2]f>H203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:000000040000
0080003o0P00002j0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]
f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP080:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0<j7:03>Q
bP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:0P2]f>H203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H000000000000200000080003o0P00002l0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0
102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0c
XLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0
<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]
f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX0102]f>H0<j7:03>QbP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0<j7:0080<j7:0P2]f>H203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H01@0000020000o`80
0000_P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0202]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP80[MSV0P0cXLX0102]f>H0<j7:0:gHiP0cXLX4
00000080003o0P0000300?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0
[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP080:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0<j7:
03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:0P2]f>H203>QbP030:gHiP0c
XLX0000000<000000P000?l00`000000oooP0?ooh0310?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0<000002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV
00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0
<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX20:gHiP80<j7:
100000020000o`800000`P3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP08
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0
<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV0000000000000`0000020000o`03
0000003oon00oooP0<D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV00<0<j7:00L0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2
0:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00P0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP0cXLX0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0<j7:1@0000020000o`800000b03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gH
iP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0202]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H00`0c
XLX00`2]f>H0<j7:0000000400000080003o0P00003:0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]
f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>Q
bP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080
<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H2
03>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP000000000000800000
0P000?l00`000000oooP0?ooh03;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0
<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>Q
bP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP08
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP080:gHiP0c
XLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX500000080003o0P00003>0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0
<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>Q
bP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:
0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0c
XLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0400000080003o0`00003?
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]
f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV
03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP080:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H010000002
0000o`800000dP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX0102]f>H0<j7:03>QbP0cXLX3
00000080003o0P00003D0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0
[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP080:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0000000000
008000000P000?l200000=H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0
202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00P0[MSV
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0`0000020000o`<0
0000e`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:
0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0202]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0`0000020000o`<00000f@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0
[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:
00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0c
XLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0c
XLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP0cXLX00P0000020000o`<00000f`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]
f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gH
iP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:00<0000000<0003o000000000000
0P00003L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP06
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0c
XLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP080:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<000000P000?l200000=l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80
<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
2@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gH
iP80<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP00000000000P000?l300000>00oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh080<j7:00@0[MSV03>Q
bP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80
[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP04
03>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80
<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV
03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX200000080003o0`00003P0?ooh0<000006`3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0
[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gH
iP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gH
iP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]
f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0c
XLX0<j7:0:gHiP80<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:00L0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0000000@0003o0000000000000000i03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:
00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0
<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV
03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<000000P000?l300000>D0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gH
iP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0
<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H203>QbP030:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV
03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:
00<0[MSV03>QbP2]f>H00`0000020000o`<00000i`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0
5@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV
03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H000000000
0002000000040000o`000000000000000>T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:
00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:0:gHiP80
<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP80<j7:0`0000020000o`800000j`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP03
03>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:
00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
2@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0
<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP04
0:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV
03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0c
XLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX02@2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP0200000080003o0P00003]0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H2
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP05
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:
00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]
f>H203>QbP070:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP0200000080003o0P00003_0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gH
iP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV
03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:
0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P00
000010000?l0000000000000003`0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0
<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>Q
bP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP04
0:gHiP0cXLX0<j7:0:gHiP8000000P000?l300000?40oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gH
iP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0<j7:
0:gHiP80<j7:00<0[MSV03>QbP0cXLX00P0000000`000?l000000000000200000?80oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>Q
bP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP03
03>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>Q
bP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gH
iP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:
0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV
03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV
03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:
00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00<0[MSV0000000000000P000?l200000?D0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon02
03>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV
03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP050:gHiP0cXLX0<j7:0:gHiP0cXLX00P0000020000o`<00000mP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0
[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:
00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0c
XLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV
03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00@0[MSV03>QbP0cXLX0[MSV0P0000000`000?l000000000000200000?L0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gH
iP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0
<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0c
XLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H203>QbP030:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV
03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP04
0:gHiP0cXLX0000000000080003o0`00003i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0
[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX3000000040000o`0000000000
00000?/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?oo
h080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gH
iP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<000000P000?l300000?X0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV
00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP080:gHiP0cXLX0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX200000080003o0`00003n0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H2
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP05
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:
00X0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP000000003o1000003o0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0
102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0c
XLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0
<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0
<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]
f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX000000080003o0`00003o
0?ooh080oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV
0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0
[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>Q
bP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP03000000030000
o`000000000000800000o`3oon030?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0
<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>Q
bP00000000000P000?l300000?l0oooP1@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]
f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP80[MSV00<0<j7:0:gHiP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP040:gH
iP0cXLX000000000o`@00000o`3oon060?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV
00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0P2]f>H00`0cXLX0[MSV03>QbP0203>QbP030:gHiP0cXLX0[MSV0080<j7:0P000000
10000?l0000000000000003o0?ooh0P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV
00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080<j7:00<0[MSV03>QbP2]f>H00P0000020000o`<0
0000o`3oon090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P2]f>H0
0`0cXLX0[MSV03>QbP0203>QbP050:gHiP0cXLX00000000000000?l01000003o0?ooh0X0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon02
03>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV
03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0303>QbP2]f>H0<j7:0080
<j7:0`00000010000?l0000000000000003o0?ooh0`0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gH
iP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:
01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX20:gHiP0403>QbP2]f>H0<j7:03>QbP8000000P000?l200000?l0oooP
3P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV
00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP80[MSV00<0<j7:0:gH
iP0000000P00000010000?l0000000000000003o0?ooh0l0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV
0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80
<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0
<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP03
0:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX20:gHiP0503>QbP0000000000000000000?l00P00003o0?ooh140
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP100000070?ooh0030000
003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP03
00000080003o0P00003o0?ooh180oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPd0oooP00<000000?ooh03oon00203oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>Q
bP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80
[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP04
03>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80
<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0000000@0003o0000000000000000o`3oon0C0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00oooP00L0oooP
100000080?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0000000<0003o0000
000cXLX0o`3oon0B0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPl0oooP00<000000?ooh03o
on001P3oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP04
03>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX2
00000080003o00<000000?ooh03oon00o`3oon0E0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon02
03>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV
03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H203>QbP030:gHiP0cXLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0000000P0000000`000?l000000000003o0?ooh1P0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003oon00
oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
1@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP070:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP<000000P000?l200000?l0oooP6@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV
03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H7
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0c
XLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX0202]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0`00000010000?l0000000000000003o0?ooh1X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80
<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0000000<0003o00000000
0000o`3oon0L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP060:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0P0000020000o`030000003oon00oooP0?l0oooP703oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:
00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0
<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV
03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00800000
00<0003o000000000000o`3oon0O0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0
<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP060:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP030:gHiP0cXLX0[MSV008000000P000?l200000?l0oooP803oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>Q
bP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80
[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP04
03>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80
<j7:00<0[MSV03>QbP2]f>H00`0cXLX01@2]f>H00000000000000000003o00<00000o`3oon0Q0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP09
0:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0c
XLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP060:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP8000000P000?l300000?l0oooP
8P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0c
XLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV
00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0
[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX2000000040000o`000000
000000000?l0oooP903oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80<j7:00@0[MSV03>QbP2]f>H0<j7:0P000000
0`000?l000000000003o0?ooh2H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100c
XLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP040:gHiP0cXLX0[MSV0000
0080003o0P00003o0?ooh2L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0
202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00H0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H203>QbP<0000000@0003o000000000000
0000o`3oon0X0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H0
0P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP070:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP0200000080003o0`00003o0?ooh2T0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh080<j7:00@0[MSV
03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H7
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0c
XLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gH
iP0403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP80000000<0003o0000000000000P00003o0?ooh2P0oooP0`00000K0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP04
03>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080000000<0003o000000000000o`3o
on0]0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
1@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:008000000P000?l200000?l0oooP;P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0
5@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0403>QbP050:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:000000000000003o00<00000o`3oon0_0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP09
0:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0c
XLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0
[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP000000
00000000o`<00000o`3oon0`0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:
00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV
03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:00D0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP80000000<0003o000000000000o`3oon0b0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gH
iP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H2
03>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H4
03>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX000000080003o0P00003o0?ooh3<0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP04
0:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>Q
bP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0c
XLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gH
iP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>Q
bP2]f>H0100cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV000000000?l00`00003o0?ooh3@0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon02
03>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV
03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0
[MSV03>QbP2]f>H0100cXLX01P2]f>H0<j7:0:gHiP0cXLX000000000o`<00000o`3oon0e0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gH
iP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV
03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:
0:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0000000P000?l300000?l0oooP=P3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:
00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0
<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV
03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0
[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0
<j7:0:gHiP0403>QbP030:gHiP000000003o00@00000o`3oon0g0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:
0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:
00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]
f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]
f>H403>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:0P0000000`000?l000000000000200000?l0oooP>03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0
[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100c
XLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP80
000000@0003o0000000000000000o`3oon0j0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP050:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP0000000P000?l2
00000?l0oooP?03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P00000010000?l0000000000000003o0?ooh3d0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon02
03>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV
03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP04
0:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0
<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV0080000000@0003o0000000000000000o`3oon0n0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0<000002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX00000000000000?l00`00003o0?ooh3d0oooP0`00
000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV
03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H7
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0c
XLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gHiP0cXLX0[MSV03>Q
bP80[MSV100cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV000000000000003o0P00
003o0?ooh440oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:01D0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX20:gHiP@0<j7:00D0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP80000000<0003o000000000000o`3oon120?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H2
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:000000020000o`800000o`3oon130?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]
f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
2`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0
<j7:0P2]f>H403>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H000000000o`0300000?l0oooPA03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]
f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP040:gH
iP0cXLX0[MSV03>QbP80[MSV100cXLX00`2]f>H0<j7:0:gHiP02000000040000o`00000000000000
0?l0oooPA@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0203>QbP040:gHiP0cXLX0[MSV03>QbP80[MSV100cXLX01@2]f>H0<j7:000000000000003o00<0
0000o`3oon160?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP040:gHiP00000000000000o`<00000
o`3oon170?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P2]f>H403>QbP80000000<0003o000000000000o`3oon19
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00@0[MSV03>QbP2]f>H0<j7:0P2]f>H203>QbP<0000000<0003o000000000000o`3oon1:0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:
00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gH
iP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV
03>QbP2]f>H0<j7:0P2]f>H01@0cXLX00000000000000000003o00800000o`3oon1;0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0c
XLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0c
XLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]
f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>Q
bP2]f>H0<j7:0P2]f>H3000000030000o`00000000000?l0oooPC03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>Q
bP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0
[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0cXLX0[MSV03>QbP2]
f>H00P0000020000o`030000003oon00oooP0?l0oooPC03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0
[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX05@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H00000
0000o`0300000?l0oooPCP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP08
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080000000@0003o0000000000000000o`3oon1?
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:
00L0[MSV03>QbP00000000000000o`000000<j7:0?l0oooPD@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0E0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP000000003o0P00003o0?ooh500oooP
0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0
[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:
00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0c
XLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>Q
bP0cXLX0[MSV0P0cXLX05P2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX20000000403>QbP000?l0
000000000?l0oooPD`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gH
iP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX05@2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP03000000030000o`3oon00oooP0?l0oooPE03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0
[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0c
XLX0502]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`0000000`000?l000000?ooh03o0?ooh5D0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>Q
bP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP03
03>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>Q
bP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gH
iP0cXLX0<j7:0:gHiP80<j7:01<0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0000000<0003o0000003oon00o`3o
on1F0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
1@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0B0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P0000020000o`030000
003oon00oooP0?l0oooPEP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP08
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX04@2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00800000
00<0003o000000000000o`3oon1I0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0
<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP0C0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
00000000o`0200000?l0oooPFP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>Q
bP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX03`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP02000000030000
o`00000000000?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP08
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX03P2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P0000000`000?l000000?oo
h03o0?ooh5`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gHiP80<j7:00`0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX3000000030000o`00000000000?l0oooPG@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080
<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP03
0:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0
<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0000000<0003o000000000000o`3oon1N0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]
f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>Q
bP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0000000<0003o0000000c
XLX0o`3oon1O0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0000000<0003o0000003oon00o`3oon1P0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh0<000001P3oon000`000000oooP0?ooh0090?ooh080
<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP03
0:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0
<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0
[MSV03>QbP0cXLX0[MSV0P0cXLX0202]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P000002
0000o`030000003oon00oooP0?l0oooPH03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V403oon000`000000oooP0?ooh0050?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]
f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
2`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:
03>QbP2]f>H203>QbP0:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX000000000o`800000
o`3oon1S0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0D000001P3o
on04000000P0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]f>H203>QbP060:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0P0000000`000?l000000000003o0?ooh640oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3o
on0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:
0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:
00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0102]f>H0<j7:03>QbP2]
f>H203>QbP050:gHiP0cXLX0[MSV03>QbP2]f>H00P0000000`000?l0000003>QbP3o0?ooh6D0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<000000?ooh00000001`3o
on000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP08
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0cXLX0[MSV0P0cXLX0102]f>H0<j7:0:gHiP0c
XLX2000000030000o`00000000000?l0oooPIP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V3`3oon02000000L0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0
[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0cXLX0<j7:0:gH
iP80<j7:00<0[MSV03>QbP0000000P0000000`000?l000000000003o0?ooh6L0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP04
0:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>Q
bP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0c
XLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP040:gHiP0c
XLX0<j7:0:gHiP80<j7:00D0[MSV00000000000000000000o`0200000?l0oooPJ03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:
00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0
<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV
03>QbP0cXLX0[MSV0P0cXLX01P2]f>H00000000000000?l0000003>Qb_l0oooPJ@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:
00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0
<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00D0[MSV
03>QbP0cXLX0[MSV03>QbP03000000030000o`00000000000?l0oooPJP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV
03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H7
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:03>QbP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00@0[MSV03>QbP0c
XLX0[MSV0`0000000`000?l000000000003o0?ooh6/0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gH
iP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP07
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:00<0000000<0
003o0000003oon00o`3oon1/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:
00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP02000000030000o`000000oooP0?l0
oooPK@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX02@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00H0[MSV00000000000000000000o`00003o0?ooh6l0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0c
XLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP8000000P000?l00`00
0000oooP0?ooh03o0?ooh6h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0
202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP80000000@0003o0000000000000000o`3oon1`0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0c
XLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP090:gHiP0c
XLX0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P000000
10000?l0000000000000003o0?ooh740oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0
100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV0080<j7:00T0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:00000002000000030000o`00000000000?l0oooPL`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:
00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0
<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX02@2]f>H0<j7:
03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP050:gHiP0000000000000000000?l00P00
003o0?ooh7@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`000009
0?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP03
03>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:
00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
2@2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0203>QbP<0000000<0003o00000000
0000o`3oon1c0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:
00X0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0`0000000`000?l000000000
003o0?ooh7H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV0080<j7:00X0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0P0000000`00
0?l000000000003o0?ooh7L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0
202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00P0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP<0000000<0
003o000000000000o`3oon1h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:
00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0:gHiP03000000030000
o`00000000000?l0oooPN@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP08
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:03>QbP0cXLX0[MSV03>QbP2]f>H00P0000000`000?l0
00000000003o0?ooh7X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV0080<j7:00H0[MSV03>QbP0cXLX0<j7:0:gHiP0cXLX2000000030000o`000000oooP
0?l0oooPN`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H00P0cXLX0102]f>H0<j7:03>QbP0cXLX3000000030000o`000000oooP0?l0oooPO03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080
<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP03
0:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP03000000030000o`00000000000?l0oooPO@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0
[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP02000000030000
o`00000000000?l0oooPOP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP08
0:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H00P0cXLX01P2]f>H0<j7:000000000000003o00000?l0oooPP03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:
00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0
<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H00000
000000000?l000000?l0oooPP@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>Q
bP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H00P0cXLX2000000030000o`00000000000?l0oooPP@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0
[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:
00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0c
XLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H703>QbP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P0000000`000?l00000
0000003o0?ooh880oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0
<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0[MSV0080000000<0003o000000000000o`3oon230?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]
f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
1`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX01@2]f>H0<j7:000000000000003o00800000o`3oon240?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon0203>QbP040:gHiP0cXLX0
[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP<0000000<0003o000000000000o`3oon230?ooh0<000006`3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV
0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1`0cXLX0102]
f>H0<j7:0:gHiP0cXLX3000000030000o`00000000000?l0oooPQP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>Q
bP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV
0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>Q
bP030:gHiP0cXLX0[MSV00<0000000<0003o0000000cXLX0o`3oon270?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0
<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0
<j7:00<0[MSV03>QbP0000000P0000000`000?l000000?ooh03o0?ooh8P0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gH
iP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
1`0cXLX01P2]f>H00000000000000000003o00000?l0oooPRP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]
f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080
<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H703>QbP05
0:gHiP00000000000000o`000000o`3oon2;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiPL0<j7:0P0000000`000?l0
00000?ooh03o0?ooh8/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]
f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV1P0cXLX2000000030000o`00000000000?l0oooP
S03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0
<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP0403>QbP080:gHiP0cXLX0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H503>QbP80000000<0003o000000000000o`3oon2=0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0
102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0c
XLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV
03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00P0[MSV03>QbP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP@0<j7:0P0000000`000?l000000000003o0?ooh8h0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV
0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV0`0cXLX20000
00030000o`00000000000?l0oooPS`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]
f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:0:gHiP04
03>QbP080:gHiP0cXLX0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H203>QbP80000000<0003o00000000
0000o`3oon2@0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00T0[MSV03>Q
bP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX00P0000000`000?l000000000003o0?ooh940oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP03
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0202]f>H0<j7:03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV0P0000000`000?l000000000003o0?ooh980oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0
[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP2]f>H0100cXLX01`2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP0cXLX00P0000000`00
0?l000000000003o0?ooh9<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX0
1P2]f>H0<j7:03>QbP2]f>H0<j7:0:gHiP80000000<0003o000000000000o`3oon2D0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon0203>QbP040:gHiP0c
XLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP2]f>H0100cXLX01@2]f>H0<j7:03>QbP2]f>H0<j7:0080000000<0003o0000
00000000o`3oon2C0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP05
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX01`2]f>H0<j7:03>QbP2]
f>H0<j7:000000000?l00P00003o0?ooh9H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:
00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]
f>H0100cXLX01P2]f>H0<j7:03>QbP2]f>H000000000o`800000o`3oon2G0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]
f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
2`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0[MSV00@0<j7:00<0[MSV03>QbP0000000P0000000`000?l000000000
003o0?ooh9L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H0100cXLX01@2]f>H00000
000000000000003o00800000o`3oon2H0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV
00@0<j7:00D0[MSV000000000000003o0000003o0?ooh9X0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV
0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP2]f>H0100cXLX2000000030000o`000000oooP0?l0oooPVP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV
03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0[MSV03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP80000000<0003o000000000000o`3oon2K0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0c
XLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H01@0cXLX00`2]f>H0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0[MSV0080<j7:0P0000000`000?l000000000003o0?ooh9`0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>Q
bP030:gHiP0cXLX0[MSV0080<j7:00@0[MSV03>QbP2]f>H0<j7:0P0000000`000?l000000000003o
0?ooh9d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gH
iP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP2]f>H00P0000000`000?l000000000
003o0?ooh9h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0503>QbP030:gHiP0cXLX0[MSV0080<j7:00D0[MSV03>QbP00000000000000o`0200000?l0
oooPW`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00D0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H00000000000000?l200000?l0oooPX03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00<0
[MSV03>QbP2]f>H00P0cXLX00`2]f>H000000000o`0200000?l0oooPX@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon03000000P0oooP00<000000?ooh03oon002@3oon02
03>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0503>QbP030:gH
iP0cXLX0[MSV0080<j7:00@0[MSV0000o`0000000000o`3oon2R0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03o
on002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP05
03>QbP030:gHiP0cXLX0[MSV0080000000<0003o03>QbP3oon00o`3oon2S0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP10000008
0?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP03
03>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:
00D0[MSV03>QbP00000000000000o`0200000?l0oooPX@3oon04000001/0oooP7P3jl>H10?ooo`00
7@3jl>H=0?ooh0<00000203oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0
[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:
00L0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:00@0[MSV03>QbP000000003o0`00003o
0?ooh:@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<000000?oo
h03oon001`3oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00D0<j7:0`0000000`000?l000000000003o0?ooh:D0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0`0000070?ooh0030000003oon00
oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
100cXLX3000000030000o`00000000000?l0oooPYP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00L0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00@0<j7:0P0000000`000?l000000000003o0?ooh:L0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
0`0cXLX00`2]f>H0<j7:0:gHiP0203>QbP070:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP80000000<0003o0000003oon00o`3oon2X0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>Q
bP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00P0cXLX2000000030000o`000000oooP0?l0oooPZ@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0[MSV0080<j7:00P0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP800000
00<0003o000000000000o`3oon2Z0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gH
iP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>Q
bP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01`2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H00P0000000`000?l000000000003o0?ooh:/0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gH
iP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:
0:gHiP0203>QbP090:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP000000003o00800000o`3oon2/
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV
00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H0<j7:0:gHiP0cXLX0[MSV0080000000<0003o
000000000000o`3oon2]0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]f>H00P0cXLX0102]f>H0<j7:0:gHiP0cXLX2
000000040000o`000000000000000?l0oooP[@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP2]f>H00`0000000`000?l000000000003o0?ooh:h0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV
0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0
[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX000000080000000<0003o0000003oon00o`3oon2_0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0
<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP2]
f>H00P0cXLX01P2]f>H0<j7:000000000000003o00000?l0oooP/@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>Q
bP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV
0080<j7:00D0[MSV000000000000003o0000003o0?ooh;80oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX0
0`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gH
iP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0[MSV0080<j7:0P0000000`00
0?l000000000003o0?ooh;00oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0
<j7:0:gHiP0303>QbP040:gHiP0cXLX0[MSV03>QbP80000000<0003o000000000000o`3oon2c0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0
<j7:00H0[MSV03>QbP2]f>H0<j7:000000000?l200000?l0oooP]03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>Q
bP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00/0[MSV
03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>QbP050:gHiP0cXLX00000
000000000?l00P00003o0?ooh;D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP0cXLX0[MSV03>QbP2]f>H00`0cXLX0102]f>H00000000000000?l200000?l0oooP]P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0303>Q
bP040:gHiP00000000000000o`800000o`3oon2f0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H2
03>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX02`2]f>H0<j7:0:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP000?l00P00003o0?oo
h;L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0303>QbP0;0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]
f>H00P0cXLX2000000030000o`3oon00oooP0?l0oooP^03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0
[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00`0[MSV03>QbP2]
f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2000000030000o`000000oooP0?l0
oooP^@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00/0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:
0:gHiP02000000030000o`00000000000?l0oooP^P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00d0[MSV03>QbP2]f>H0
<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP000000003o00800000o`3oon2k0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0c
XLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX02@2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP2]f>H0<j7:0:gHiP03000000030000o`000000
oooP0?l0oooP^`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00P0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX0[MSV03>QbP<0
000000<0003o000000000000o`3oon2l0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP03
0:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0202]f>H0<j7:0:gHiP0cXLX0[MSV
03>QbP2]f>H0<j7:0P0000000`000?l000000000003o0?ooh;d0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0
[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP070:gHiP0c
XLX0[MSV03>QbP2]f>H0<j7:0:gHiP02000000030000o`000000oooP0?l0oooP_P3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:
00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0
<j7:00H0[MSV03>QbP2]f>H0<j7:0:gHiP0cXLX2000000030000o`000000oooP0?l0oooP_`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP0P0cXLX0102]
f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
1@2]f>H0<j7:0:gHiP0cXLX0[MSV0080000000<0003o000000000000o`3oon2n0?ooh0<000006`3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0
[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0c
XLX0[MSV03>QbP<0000000<0003o0000003oon00o`3oon300?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gH
iP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:
0:gHiP03000000030000o`000000oooP0?l0oooP`@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV
0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP000000
0P0000000`000?l000000?ooh03o0?ooh<80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:
00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP060:gHiP0cXLX0000000000000
0?l00000o`3oon340?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H00000000000000?l000000?l0oooPa@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:00<0<j7:0P0000000`000?l000000000003o0?ooh<D0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV
0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP<0000000<0003o
0000003oon00o`3oon350?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0
[MSV0080<j7:00@0[MSV03>QbP0cXLX0<j7:0`0000000`000?l000000?ooh03o0?ooh<H0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon02
03>QbP040:gHiP0cXLX0[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP03000000030000o`000000oooP0?l0oooPa`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV03>QbP2]f>H0[MSV0P0c
XLX00`2]f>H0<j7:0:gHiP0203>QbP030:gHiP0cXLX000000080000000<0003o0000003oon00o`3o
on380?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP030:gHiP0cXLX0[MSV0080<j7:00H0
[MSV03>QbP00000000000000o`00003o0?ooh<X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>QbP040:gHiP0cXLX0[MSV0:gHiP80
<j7:00<0[MSV03>QbP2]f>H00P0cXLX01@2]f>H00000000000000?l000000?l0oooPb`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080
<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX00`2]f>H0<j7:0:gHiP0203>QbP050:gHiP0000000000
0000o`000000o`3oon3;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]f>H203>QbP040:gHiP0cXLX0
[MSV03>QbP80000000<0<j7:0000o`000000o`3oon3<0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX0102]f>H0<j7:0:gHiP2]
f>H203>QbP030:gHiP0cXLX0[MSV00<0000000<0003o0?ooh03oon00o`3oon3<0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon0203>QbP040:gHiP0cXLX0
[MSV0:gHiP80<j7:00<0[MSV03>QbP2]f>H00P0000000`000?l000000?ooh03o0?ooh</0oooP0`00
000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV
03>QbP2]f>H0[MSV0P0cXLX01P2]f>H0<j7:000000000000003o00000?l0oooPc`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:
00@0[MSV03>QbP2]f>H0[MSV0P0cXLX0102]f>H00000000000000?l200000?l0oooPc`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080
<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX2000000030000o`00000000000?l0oooPd03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080
<j7:00@0[MSV03>QbP2]f>H0[MSV0P0cXLX010000000003o00000000003o0?ooh=40oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>Q
bP050:gHiP0cXLX0[MSV0:gHiP0cXLX00P0000000`000?l000000?ooh03o0?ooh=40oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0203>Q
bP040:gHiP0cXLX0[MSV0:gHiP80000000<0003o000000000000o`3oon3B0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX00`2]
f>H0<j7:0:gHiP02000000030000o`00000000000?l0oooPd`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00D0[MSV03>QbP00
000000000000o`0200000?l0oooPe03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh080<j7:00@0[MSV000000000000003o0P00003o0?oo
h=D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon0203>QbP030:gHiP000000003o00800000o`3oon3F0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0P0cXLX010000000003o
00000000003o0?ooh=L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001@0cXLX00000000000000?l000000?l0oooPf03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00
2@3oon02000000030000o`00000000000?l0oooPf03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00P0oooP
0P0000000`000?l000000000003o0?ooh=T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon04000000L0oooP00@000000000o`000000
0000o`3oon3G0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000
003oon00oooP00T0oooP0P00003o0?ooh=/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh03o0?ooh>H0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000003o
on00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP
04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP
04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooPo`00003Z000001/0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003A0?[`iP@000000P3jl>H800000080n_3V100000001`3jl>H000000000
00000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`iP00000000000000
00P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`0000080?[`iPD000000P3jl>H40000
0080n_3V1@00000<0?[`iP<000004@3jl>H3000000H0n_3V0`000000103jl>H00000000000000006
0?[`iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H0000000000000003H0?[`iP40oooo003B
0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000`3jl>H01`000000n_3V00000000
0000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V
0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V0?[`iP8000000P3jl>H200000004
0?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP8000003@3jl>H2000000030?[`iP000000000000l0n_3V0P0000000`3j
l>H00000000000060?[`iP80000000<0n_3V0000000000001`3jl>H00`000000n_3V0?[`iP050?[`
iP80000000<0n_3V000000000000f@3jl>H10?ooo`00dP3jl>H2000000030?[`iP000000000000@0
n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080
n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V0P0000000`3jl>H00000000000050?[`
iPD000001@3jl>H2000000030?[`iP000000000000L0n_3V0`0000060?[`iPD000001P3jl>H30000
0=X0n_3V0@3oool00=80n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`iP00000000000?[`
iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3j
l>H2000000d0n_3V0P0000000`3jl>H000000000000?0?[`iP80000000<0n_3V0000000000001`3j
l>H3000000P0n_3V00<000000?[`iP3jl>H01P3jl>H300000=X0n_3V0@3oool00=80n_3V0P000002
0?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000
003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0`0000000`3jl>H0
00000?[`iP0:0?[`iP<00000403jl>H4000000L0n_3V0P0000000`3jl>H00000000000070?[`iP03
0000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003I0?[`iP40oooo003B0?[`iP800000
0P3jl>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP000000000000D00000
0P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3jl>H00000
00000007000000X0n_3V1@0000020?[`iP@000000P3jl>H3000000030?[`iP000000000000X0n_3V
0P0000000`3jl>H000000000000?0?[`iP800000203jl>H3000000040?[`iP0000000000000000d0
n_3V0`0000000`3jl>H000000000000500000=@0n_3V0@3oool00=80n_3V0P0000020?[`iP800000
<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H05`3jl>H2000001X0n_3V0P0000000`3jl>H00000
0000000@0?[`iP8000008`3jl>H00`000000n_3V0?[`iP3D0?[`iP40oooo003A0?[`iPH00000103j
l>H2000002l0n_3V1@00000J0?[`iP<000006@3jl>H300000180n_3V0`00000R0?[`iP030000003j
l>H0n_3V0=<0n_3V0@3oool00?l0n_3VP`3jl>H00`000000n_3V0?[`iP3B0?[`iP40oooo003o0?[`
iX00n_3V00@000000?[`iP3jl>H00000e03jl>H10?ooo`00o`3jl>J10?[`iP800000e@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .60256 L
.02522 .60256 L
.02522 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .60256 L
.02522 .60256 L
.02522 .08012 L
s
.678 .847 .902 r
.02522 .08012 m
.02522 .59993 L
.02753 .59993 L
.02753 .08012 L
F
.2 .63 .79 r
.02522 .08012 m
.02522 .59993 L
.02753 .59993 L
.02753 .08012 L
s
.678 .847 .902 r
.02753 .08012 m
.02753 .59864 L
.02849 .59864 L
.02849 .08012 L
F
.2 .63 .79 r
.02753 .08012 m
.02753 .59864 L
.02849 .59864 L
.02849 .08012 L
s
.678 .847 .902 r
.02849 .08012 m
.02849 .59674 L
.03024 .59674 L
.03024 .08012 L
F
.2 .63 .79 r
.02849 .08012 m
.02849 .59674 L
.03024 .59674 L
.03024 .08012 L
s
.678 .847 .902 r
.03024 .08012 m
.03024 .59459 L
.03126 .59459 L
.03126 .08012 L
F
.2 .63 .79 r
.03024 .08012 m
.03024 .59459 L
.03126 .59459 L
.03126 .08012 L
s
.678 .847 .902 r
.03126 .08012 m
.03126 .59275 L
.03249 .59275 L
.03249 .08012 L
F
.2 .63 .79 r
.03126 .08012 m
.03126 .59275 L
.03249 .59275 L
.03249 .08012 L
s
.678 .847 .902 r
.03249 .08012 m
.03249 .59072 L
.0347 .59072 L
.0347 .08012 L
F
.2 .63 .79 r
.03249 .08012 m
.03249 .59072 L
.0347 .59072 L
.0347 .08012 L
s
.678 .847 .902 r
.0347 .08012 m
.0347 .58817 L
.03688 .58817 L
.03688 .08012 L
F
.2 .63 .79 r
.0347 .08012 m
.0347 .58817 L
.03688 .58817 L
.03688 .08012 L
s
.678 .847 .902 r
.03688 .08012 m
.03688 .58592 L
.03937 .58592 L
.03937 .08012 L
F
.2 .63 .79 r
.03688 .08012 m
.03688 .58592 L
.03937 .58592 L
.03937 .08012 L
s
.678 .847 .902 r
.03937 .08012 m
.03937 .58344 L
.04138 .58344 L
.04138 .08012 L
F
.2 .63 .79 r
.03937 .08012 m
.03937 .58344 L
.04138 .58344 L
.04138 .08012 L
s
.678 .847 .902 r
.04138 .08012 m
.04138 .58098 L
.04313 .58098 L
.04313 .08012 L
F
.2 .63 .79 r
.04138 .08012 m
.04138 .58098 L
.04313 .58098 L
.04313 .08012 L
s
.678 .847 .902 r
.04313 .08012 m
.04313 .57887 L
.04545 .57887 L
.04545 .08012 L
F
.2 .63 .79 r
.04313 .08012 m
.04313 .57887 L
.04545 .57887 L
.04545 .08012 L
s
.678 .847 .902 r
.04545 .08012 m
.04545 .57638 L
.04715 .57638 L
.04715 .08012 L
F
.2 .63 .79 r
.04545 .08012 m
.04545 .57638 L
.04715 .57638 L
.04715 .08012 L
s
.678 .847 .902 r
.04715 .08012 m
.04715 .57274 L
.04992 .57274 L
.04992 .08012 L
F
.2 .63 .79 r
.04715 .08012 m
.04715 .57274 L
.04992 .57274 L
.04992 .08012 L
s
.678 .847 .902 r
.04992 .08012 m
.04992 .57019 L
.05165 .57019 L
.05165 .08012 L
F
.2 .63 .79 r
.04992 .08012 m
.04992 .57019 L
.05165 .57019 L
.05165 .08012 L
s
.678 .847 .902 r
.05165 .08012 m
.05165 .56901 L
.0528 .56901 L
.0528 .08012 L
F
.2 .63 .79 r
.05165 .08012 m
.05165 .56901 L
.0528 .56901 L
.0528 .08012 L
s
.678 .847 .902 r
.0528 .08012 m
.0528 .56629 L
.05432 .56629 L
.05432 .08012 L
F
.2 .63 .79 r
.0528 .08012 m
.0528 .56629 L
.05432 .56629 L
.05432 .08012 L
s
.678 .847 .902 r
.05432 .08012 m
.05432 .56549 L
.05608 .56549 L
.05608 .08012 L
F
.2 .63 .79 r
.05432 .08012 m
.05432 .56549 L
.05608 .56549 L
.05608 .08012 L
s
.678 .847 .902 r
.05608 .08012 m
.05608 .56162 L
.05869 .56162 L
.05869 .08012 L
F
.2 .63 .79 r
.05608 .08012 m
.05608 .56162 L
.05869 .56162 L
.05869 .08012 L
s
.678 .847 .902 r
.05869 .08012 m
.05869 .55855 L
.06106 .55855 L
.06106 .08012 L
F
.2 .63 .79 r
.05869 .08012 m
.05869 .55855 L
.06106 .55855 L
.06106 .08012 L
s
.678 .847 .902 r
.06106 .08012 m
.06106 .55778 L
.06403 .55778 L
.06403 .08012 L
F
.2 .63 .79 r
.06106 .08012 m
.06106 .55778 L
.06403 .55778 L
.06403 .08012 L
s
.678 .847 .902 r
.06403 .08012 m
.06403 .55345 L
.06615 .55345 L
.06615 .08012 L
F
.2 .63 .79 r
.06403 .08012 m
.06403 .55345 L
.06615 .55345 L
.06615 .08012 L
s
.678 .847 .902 r
.06615 .08012 m
.06615 .55168 L
.06758 .55168 L
.06758 .08012 L
F
.2 .63 .79 r
.06615 .08012 m
.06615 .55168 L
.06758 .55168 L
.06758 .08012 L
s
.678 .847 .902 r
.06758 .08012 m
.06758 .54907 L
.06981 .54907 L
.06981 .08012 L
F
.2 .63 .79 r
.06758 .08012 m
.06758 .54907 L
.06981 .54907 L
.06981 .08012 L
s
.678 .847 .902 r
.06981 .08012 m
.06981 .54589 L
.07226 .54589 L
.07226 .08012 L
F
.2 .63 .79 r
.06981 .08012 m
.06981 .54589 L
.07226 .54589 L
.07226 .08012 L
s
.678 .847 .902 r
.07226 .08012 m
.07226 .54198 L
.07508 .54198 L
.07508 .08012 L
F
.2 .63 .79 r
.07226 .08012 m
.07226 .54198 L
.07508 .54198 L
.07508 .08012 L
s
.678 .847 .902 r
.07508 .08012 m
.07508 .54133 L
.07644 .54133 L
.07644 .08012 L
F
.2 .63 .79 r
.07508 .08012 m
.07508 .54133 L
.07644 .54133 L
.07644 .08012 L
s
.678 .847 .902 r
.07644 .08012 m
.07644 .53981 L
.07783 .53981 L
.07783 .08012 L
F
.2 .63 .79 r
.07644 .08012 m
.07644 .53981 L
.07783 .53981 L
.07783 .08012 L
s
.678 .847 .902 r
.07783 .08012 m
.07783 .53836 L
.08016 .53836 L
.08016 .08012 L
F
.2 .63 .79 r
.07783 .08012 m
.07783 .53836 L
.08016 .53836 L
.08016 .08012 L
s
.678 .847 .902 r
.08016 .08012 m
.08016 .53292 L
.08265 .53292 L
.08265 .08012 L
F
.2 .63 .79 r
.08016 .08012 m
.08016 .53292 L
.08265 .53292 L
.08265 .08012 L
s
.678 .847 .902 r
.08265 .08012 m
.08265 .53161 L
.0848 .53161 L
.0848 .08012 L
F
.2 .63 .79 r
.08265 .08012 m
.08265 .53161 L
.0848 .53161 L
.0848 .08012 L
s
.678 .847 .902 r
.0848 .08012 m
.0848 .52909 L
.08701 .52909 L
.08701 .08012 L
F
.2 .63 .79 r
.0848 .08012 m
.0848 .52909 L
.08701 .52909 L
.08701 .08012 L
s
.678 .847 .902 r
.08701 .08012 m
.08701 .52588 L
.08985 .52588 L
.08985 .08012 L
F
.2 .63 .79 r
.08701 .08012 m
.08701 .52588 L
.08985 .52588 L
.08985 .08012 L
s
.678 .847 .902 r
.08985 .08012 m
.08985 .5235 L
.09123 .5235 L
.09123 .08012 L
F
.2 .63 .79 r
.08985 .08012 m
.08985 .5235 L
.09123 .5235 L
.09123 .08012 L
s
.678 .847 .902 r
.09123 .08012 m
.09123 .52277 L
.09253 .52277 L
.09253 .08012 L
F
.2 .63 .79 r
.09123 .08012 m
.09123 .52277 L
.09253 .52277 L
.09253 .08012 L
s
.678 .847 .902 r
.09253 .08012 m
.09253 .52076 L
.09543 .52076 L
.09543 .08012 L
F
.2 .63 .79 r
.09253 .08012 m
.09253 .52076 L
.09543 .52076 L
.09543 .08012 L
s
.678 .847 .902 r
.09543 .08012 m
.09543 .51733 L
.09745 .51733 L
.09745 .08012 L
F
.2 .63 .79 r
.09543 .08012 m
.09543 .51733 L
.09745 .51733 L
.09745 .08012 L
s
.678 .847 .902 r
.09745 .08012 m
.09745 .51577 L
.09907 .51577 L
.09907 .08012 L
F
.2 .63 .79 r
.09745 .08012 m
.09745 .51577 L
.09907 .51577 L
.09907 .08012 L
s
.678 .847 .902 r
.09907 .08012 m
.09907 .51255 L
.10165 .51255 L
.10165 .08012 L
F
.2 .63 .79 r
.09907 .08012 m
.09907 .51255 L
.10165 .51255 L
.10165 .08012 L
s
.678 .847 .902 r
.10165 .08012 m
.10165 .50831 L
.1043 .50831 L
.1043 .08012 L
F
.2 .63 .79 r
.10165 .08012 m
.10165 .50831 L
.1043 .50831 L
.1043 .08012 L
s
.678 .847 .902 r
.1043 .08012 m
.1043 .50742 L
.1057 .50742 L
.1057 .08012 L
F
.2 .63 .79 r
.1043 .08012 m
.1043 .50742 L
.1057 .50742 L
.1057 .08012 L
s
.678 .847 .902 r
.1057 .08012 m
.1057 .50426 L
.10856 .50426 L
.10856 .08012 L
F
.2 .63 .79 r
.1057 .08012 m
.1057 .50426 L
.10856 .50426 L
.10856 .08012 L
s
.678 .847 .902 r
.10856 .08012 m
.10856 .50094 L
.11152 .50094 L
.11152 .08012 L
F
.2 .63 .79 r
.10856 .08012 m
.10856 .50094 L
.11152 .50094 L
.11152 .08012 L
s
.678 .847 .902 r
.11152 .08012 m
.11152 .49983 L
.1127 .49983 L
.1127 .08012 L
F
.2 .63 .79 r
.11152 .08012 m
.11152 .49983 L
.1127 .49983 L
.1127 .08012 L
s
.678 .847 .902 r
.1127 .08012 m
.1127 .49812 L
.11414 .49812 L
.11414 .08012 L
F
.2 .63 .79 r
.1127 .08012 m
.1127 .49812 L
.11414 .49812 L
.11414 .08012 L
s
.678 .847 .902 r
.11414 .08012 m
.11414 .49659 L
.11578 .49659 L
.11578 .08012 L
F
.2 .63 .79 r
.11414 .08012 m
.11414 .49659 L
.11578 .49659 L
.11578 .08012 L
s
.678 .847 .902 r
.11578 .08012 m
.11578 .49401 L
.11822 .49401 L
.11822 .08012 L
F
.2 .63 .79 r
.11578 .08012 m
.11578 .49401 L
.11822 .49401 L
.11822 .08012 L
s
.678 .847 .902 r
.11822 .08012 m
.11822 .49129 L
.12017 .49129 L
.12017 .08012 L
F
.2 .63 .79 r
.11822 .08012 m
.11822 .49129 L
.12017 .49129 L
.12017 .08012 L
s
.678 .847 .902 r
.12017 .08012 m
.12017 .48891 L
.12215 .48891 L
.12215 .08012 L
F
.2 .63 .79 r
.12017 .08012 m
.12017 .48891 L
.12215 .48891 L
.12215 .08012 L
s
.678 .847 .902 r
.12215 .08012 m
.12215 .48744 L
.12397 .48744 L
.12397 .08012 L
F
.2 .63 .79 r
.12215 .08012 m
.12215 .48744 L
.12397 .48744 L
.12397 .08012 L
s
.678 .847 .902 r
.12397 .08012 m
.12397 .48557 L
.12595 .48557 L
.12595 .08012 L
F
.2 .63 .79 r
.12397 .08012 m
.12397 .48557 L
.12595 .48557 L
.12595 .08012 L
s
.678 .847 .902 r
.12595 .08012 m
.12595 .48325 L
.12741 .48325 L
.12741 .08012 L
F
.2 .63 .79 r
.12595 .08012 m
.12595 .48325 L
.12741 .48325 L
.12741 .08012 L
s
.678 .847 .902 r
.12741 .08012 m
.12741 .48055 L
.13007 .48055 L
.13007 .08012 L
F
.2 .63 .79 r
.12741 .08012 m
.12741 .48055 L
.13007 .48055 L
.13007 .08012 L
s
.678 .847 .902 r
.13007 .08012 m
.13007 .47847 L
.1324 .47847 L
.1324 .08012 L
F
.2 .63 .79 r
.13007 .08012 m
.13007 .47847 L
.1324 .47847 L
.1324 .08012 L
s
.678 .847 .902 r
.1324 .08012 m
.1324 .47453 L
.13522 .47453 L
.13522 .08012 L
F
.2 .63 .79 r
.1324 .08012 m
.1324 .47453 L
.13522 .47453 L
.13522 .08012 L
s
.678 .847 .902 r
.13522 .08012 m
.13522 .47151 L
.13747 .47151 L
.13747 .08012 L
F
.2 .63 .79 r
.13522 .08012 m
.13522 .47151 L
.13747 .47151 L
.13747 .08012 L
s
.678 .847 .902 r
.13747 .08012 m
.13747 .46816 L
.1403 .46816 L
.1403 .08012 L
F
.2 .63 .79 r
.13747 .08012 m
.13747 .46816 L
.1403 .46816 L
.1403 .08012 L
s
.678 .847 .902 r
.1403 .08012 m
.1403 .46677 L
.14215 .46677 L
.14215 .08012 L
F
.2 .63 .79 r
.1403 .08012 m
.1403 .46677 L
.14215 .46677 L
.14215 .08012 L
s
.678 .847 .902 r
.14215 .08012 m
.14215 .46453 L
.14458 .46453 L
.14458 .08012 L
F
.2 .63 .79 r
.14215 .08012 m
.14215 .46453 L
.14458 .46453 L
.14458 .08012 L
s
.678 .847 .902 r
.14458 .08012 m
.14458 .46181 L
.14693 .46181 L
.14693 .08012 L
F
.2 .63 .79 r
.14458 .08012 m
.14458 .46181 L
.14693 .46181 L
.14693 .08012 L
s
.678 .847 .902 r
.14693 .08012 m
.14693 .45979 L
.14863 .45979 L
.14863 .08012 L
F
.2 .63 .79 r
.14693 .08012 m
.14693 .45979 L
.14863 .45979 L
.14863 .08012 L
s
.678 .847 .902 r
.14863 .08012 m
.14863 .45834 L
.14977 .45834 L
.14977 .08012 L
F
.2 .63 .79 r
.14863 .08012 m
.14863 .45834 L
.14977 .45834 L
.14977 .08012 L
s
.678 .847 .902 r
.14977 .08012 m
.14977 .45754 L
.15261 .45754 L
.15261 .08012 L
F
.2 .63 .79 r
.14977 .08012 m
.14977 .45754 L
.15261 .45754 L
.15261 .08012 L
s
.678 .847 .902 r
.15261 .08012 m
.15261 .45268 L
.15531 .45268 L
.15531 .08012 L
F
.2 .63 .79 r
.15261 .08012 m
.15261 .45268 L
.15531 .45268 L
.15531 .08012 L
s
.678 .847 .902 r
.15531 .08012 m
.15531 .45166 L
.15652 .45166 L
.15652 .08012 L
F
.2 .63 .79 r
.15531 .08012 m
.15531 .45166 L
.15652 .45166 L
.15652 .08012 L
s
.678 .847 .902 r
.15652 .08012 m
.15652 .44938 L
.1578 .44938 L
.1578 .08012 L
F
.2 .63 .79 r
.15652 .08012 m
.15652 .44938 L
.1578 .44938 L
.1578 .08012 L
s
.678 .847 .902 r
.1578 .08012 m
.1578 .44801 L
.16068 .44801 L
.16068 .08012 L
F
.2 .63 .79 r
.1578 .08012 m
.1578 .44801 L
.16068 .44801 L
.16068 .08012 L
s
.678 .847 .902 r
.16068 .08012 m
.16068 .44447 L
.1631 .44447 L
.1631 .08012 L
F
.2 .63 .79 r
.16068 .08012 m
.16068 .44447 L
.1631 .44447 L
.1631 .08012 L
s
.678 .847 .902 r
.1631 .08012 m
.1631 .44088 L
.16586 .44088 L
.16586 .08012 L
F
.2 .63 .79 r
.1631 .08012 m
.1631 .44088 L
.16586 .44088 L
.16586 .08012 L
s
.678 .847 .902 r
.16586 .08012 m
.16586 .43866 L
.16851 .43866 L
.16851 .08012 L
F
.2 .63 .79 r
.16586 .08012 m
.16586 .43866 L
.16851 .43866 L
.16851 .08012 L
s
.678 .847 .902 r
.16851 .08012 m
.16851 .43801 L
.16985 .43801 L
.16985 .08012 L
F
.2 .63 .79 r
.16851 .08012 m
.16851 .43801 L
.16985 .43801 L
.16985 .08012 L
s
.678 .847 .902 r
.16985 .08012 m
.16985 .43636 L
.17122 .43636 L
.17122 .08012 L
F
.2 .63 .79 r
.16985 .08012 m
.16985 .43636 L
.17122 .43636 L
.17122 .08012 L
s
.678 .847 .902 r
.17122 .08012 m
.17122 .43454 L
.1729 .43454 L
.1729 .08012 L
F
.2 .63 .79 r
.17122 .08012 m
.17122 .43454 L
.1729 .43454 L
.1729 .08012 L
s
.678 .847 .902 r
.1729 .08012 m
.1729 .43258 L
.17463 .43258 L
.17463 .08012 L
F
.2 .63 .79 r
.1729 .08012 m
.1729 .43258 L
.17463 .43258 L
.17463 .08012 L
s
.678 .847 .902 r
.17463 .08012 m
.17463 .42963 L
.177 .42963 L
.177 .08012 L
F
.2 .63 .79 r
.17463 .08012 m
.17463 .42963 L
.177 .42963 L
.177 .08012 L
s
.678 .847 .902 r
.177 .08012 m
.177 .42668 L
.17991 .42668 L
.17991 .08012 L
F
.2 .63 .79 r
.177 .08012 m
.177 .42668 L
.17991 .42668 L
.17991 .08012 L
s
.678 .847 .902 r
.17991 .08012 m
.17991 .4245 L
.18193 .4245 L
.18193 .08012 L
F
.2 .63 .79 r
.17991 .08012 m
.17991 .4245 L
.18193 .4245 L
.18193 .08012 L
s
.678 .847 .902 r
.18193 .08012 m
.18193 .4237 L
.18432 .4237 L
.18432 .08012 L
F
.2 .63 .79 r
.18193 .08012 m
.18193 .4237 L
.18432 .4237 L
.18432 .08012 L
s
.678 .847 .902 r
.18432 .08012 m
.18432 .42135 L
.18687 .42135 L
.18687 .08012 L
F
.2 .63 .79 r
.18432 .08012 m
.18432 .42135 L
.18687 .42135 L
.18687 .08012 L
s
.678 .847 .902 r
.18687 .08012 m
.18687 .41749 L
.18843 .41749 L
.18843 .08012 L
F
.2 .63 .79 r
.18687 .08012 m
.18687 .41749 L
.18843 .41749 L
.18843 .08012 L
s
.678 .847 .902 r
.18843 .08012 m
.18843 .4156 L
.19063 .4156 L
.19063 .08012 L
F
.2 .63 .79 r
.18843 .08012 m
.18843 .4156 L
.19063 .4156 L
.19063 .08012 L
s
.678 .847 .902 r
.19063 .08012 m
.19063 .41448 L
.19207 .41448 L
.19207 .08012 L
F
.2 .63 .79 r
.19063 .08012 m
.19063 .41448 L
.19207 .41448 L
.19207 .08012 L
s
.678 .847 .902 r
.19207 .08012 m
.19207 .41319 L
.19309 .41319 L
.19309 .08012 L
F
.2 .63 .79 r
.19207 .08012 m
.19207 .41319 L
.19309 .41319 L
.19309 .08012 L
s
.678 .847 .902 r
.19309 .08012 m
.19309 .41202 L
.1953 .41202 L
.1953 .08012 L
F
.2 .63 .79 r
.19309 .08012 m
.19309 .41202 L
.1953 .41202 L
.1953 .08012 L
s
.678 .847 .902 r
.1953 .08012 m
.1953 .41019 L
.1967 .41019 L
.1967 .08012 L
F
.2 .63 .79 r
.1953 .08012 m
.1953 .41019 L
.1967 .41019 L
.1967 .08012 L
s
.678 .847 .902 r
.1967 .08012 m
.1967 .40801 L
.1979 .40801 L
.1979 .08012 L
F
.2 .63 .79 r
.1967 .08012 m
.1967 .40801 L
.1979 .40801 L
.1979 .08012 L
s
.678 .847 .902 r
.1979 .08012 m
.1979 .40735 L
.19908 .40735 L
.19908 .08012 L
F
.2 .63 .79 r
.1979 .08012 m
.1979 .40735 L
.19908 .40735 L
.19908 .08012 L
s
.678 .847 .902 r
.19908 .08012 m
.19908 .40527 L
.2016 .40527 L
.2016 .08012 L
F
.2 .63 .79 r
.19908 .08012 m
.19908 .40527 L
.2016 .40527 L
.2016 .08012 L
s
.678 .847 .902 r
.2016 .08012 m
.2016 .40309 L
.20268 .40309 L
.20268 .08012 L
F
.2 .63 .79 r
.2016 .08012 m
.2016 .40309 L
.20268 .40309 L
.20268 .08012 L
s
.678 .847 .902 r
.20268 .08012 m
.20268 .40051 L
.20561 .40051 L
.20561 .08012 L
F
.2 .63 .79 r
.20268 .08012 m
.20268 .40051 L
.20561 .40051 L
.20561 .08012 L
s
.678 .847 .902 r
.20561 .08012 m
.20561 .39884 L
.20691 .39884 L
.20691 .08012 L
F
.2 .63 .79 r
.20561 .08012 m
.20561 .39884 L
.20691 .39884 L
.20691 .08012 L
s
.678 .847 .902 r
.20691 .08012 m
.20691 .39794 L
.2079 .39794 L
.2079 .08012 L
F
.2 .63 .79 r
.20691 .08012 m
.20691 .39794 L
.2079 .39794 L
.2079 .08012 L
s
.678 .847 .902 r
.2079 .08012 m
.2079 .39654 L
.20923 .39654 L
.20923 .08012 L
F
.2 .63 .79 r
.2079 .08012 m
.2079 .39654 L
.20923 .39654 L
.20923 .08012 L
s
.678 .847 .902 r
.20923 .08012 m
.20923 .39637 L
.21041 .39637 L
.21041 .08012 L
F
.2 .63 .79 r
.20923 .08012 m
.20923 .39637 L
.21041 .39637 L
.21041 .08012 L
s
.678 .847 .902 r
.21041 .08012 m
.21041 .39262 L
.21337 .39262 L
.21337 .08012 L
F
.2 .63 .79 r
.21041 .08012 m
.21041 .39262 L
.21337 .39262 L
.21337 .08012 L
s
.678 .847 .902 r
.21337 .08012 m
.21337 .39074 L
.21599 .39074 L
.21599 .08012 L
F
.2 .63 .79 r
.21337 .08012 m
.21337 .39074 L
.21599 .39074 L
.21599 .08012 L
s
.678 .847 .902 r
.21599 .08012 m
.21599 .38832 L
.21864 .38832 L
.21864 .08012 L
F
.2 .63 .79 r
.21599 .08012 m
.21599 .38832 L
.21864 .38832 L
.21864 .08012 L
s
.678 .847 .902 r
.21864 .08012 m
.21864 .38574 L
.2211 .38574 L
.2211 .08012 L
F
.2 .63 .79 r
.21864 .08012 m
.21864 .38574 L
.2211 .38574 L
.2211 .08012 L
s
.678 .847 .902 r
.2211 .08012 m
.2211 .3846 L
.22259 .3846 L
.22259 .08012 L
F
.2 .63 .79 r
.2211 .08012 m
.2211 .3846 L
.22259 .3846 L
.22259 .08012 L
s
.678 .847 .902 r
.22259 .08012 m
.22259 .3812 L
.2253 .3812 L
.2253 .08012 L
F
.2 .63 .79 r
.22259 .08012 m
.22259 .3812 L
.2253 .3812 L
.2253 .08012 L
s
.678 .847 .902 r
.2253 .08012 m
.2253 .37951 L
.22682 .37951 L
.22682 .08012 L
F
.2 .63 .79 r
.2253 .08012 m
.2253 .37951 L
.22682 .37951 L
.22682 .08012 L
s
.678 .847 .902 r
.22682 .08012 m
.22682 .37874 L
.22779 .37874 L
.22779 .08012 L
F
.2 .63 .79 r
.22682 .08012 m
.22682 .37874 L
.22779 .37874 L
.22779 .08012 L
s
.678 .847 .902 r
.22779 .08012 m
.22779 .37635 L
.22973 .37635 L
.22973 .08012 L
F
.2 .63 .79 r
.22779 .08012 m
.22779 .37635 L
.22973 .37635 L
.22973 .08012 L
s
.678 .847 .902 r
.22973 .08012 m
.22973 .37468 L
.23178 .37468 L
.23178 .08012 L
F
.2 .63 .79 r
.22973 .08012 m
.22973 .37468 L
.23178 .37468 L
.23178 .08012 L
s
.678 .847 .902 r
.23178 .08012 m
.23178 .37223 L
.23411 .37223 L
.23411 .08012 L
F
.2 .63 .79 r
.23178 .08012 m
.23178 .37223 L
.23411 .37223 L
.23411 .08012 L
s
.678 .847 .902 r
.23411 .08012 m
.23411 .36979 L
.23664 .36979 L
.23664 .08012 L
F
.2 .63 .79 r
.23411 .08012 m
.23411 .36979 L
.23664 .36979 L
.23664 .08012 L
s
.678 .847 .902 r
.23664 .08012 m
.23664 .36881 L
.23846 .36881 L
.23846 .08012 L
F
.2 .63 .79 r
.23664 .08012 m
.23664 .36881 L
.23846 .36881 L
.23846 .08012 L
s
.678 .847 .902 r
.23846 .08012 m
.23846 .36646 L
.2413 .36646 L
.2413 .08012 L
F
.2 .63 .79 r
.23846 .08012 m
.23846 .36646 L
.2413 .36646 L
.2413 .08012 L
s
.678 .847 .902 r
.2413 .08012 m
.2413 .36385 L
.24314 .36385 L
.24314 .08012 L
F
.2 .63 .79 r
.2413 .08012 m
.2413 .36385 L
.24314 .36385 L
.24314 .08012 L
s
.678 .847 .902 r
.24314 .08012 m
.24314 .36319 L
.24536 .36319 L
.24536 .08012 L
F
.2 .63 .79 r
.24314 .08012 m
.24314 .36319 L
.24536 .36319 L
.24536 .08012 L
s
.678 .847 .902 r
.24536 .08012 m
.24536 .36117 L
.2469 .36117 L
.2469 .08012 L
F
.2 .63 .79 r
.24536 .08012 m
.24536 .36117 L
.2469 .36117 L
.2469 .08012 L
s
.678 .847 .902 r
.2469 .08012 m
.2469 .3587 L
.24813 .3587 L
.24813 .08012 L
F
.2 .63 .79 r
.2469 .08012 m
.2469 .3587 L
.24813 .3587 L
.24813 .08012 L
s
.678 .847 .902 r
.24813 .08012 m
.24813 .35737 L
.24978 .35737 L
.24978 .08012 L
F
.2 .63 .79 r
.24813 .08012 m
.24813 .35737 L
.24978 .35737 L
.24978 .08012 L
s
.678 .847 .902 r
.24978 .08012 m
.24978 .35655 L
.25207 .35655 L
.25207 .08012 L
F
.2 .63 .79 r
.24978 .08012 m
.24978 .35655 L
.25207 .35655 L
.25207 .08012 L
s
.678 .847 .902 r
.25207 .08012 m
.25207 .3548 L
.25321 .3548 L
.25321 .08012 L
F
.2 .63 .79 r
.25207 .08012 m
.25207 .3548 L
.25321 .3548 L
.25321 .08012 L
s
.678 .847 .902 r
.25321 .08012 m
.25321 .35372 L
.25435 .35372 L
.25435 .08012 L
F
.2 .63 .79 r
.25321 .08012 m
.25321 .35372 L
.25435 .35372 L
.25435 .08012 L
s
.678 .847 .902 r
.25435 .08012 m
.25435 .35178 L
.25557 .35178 L
.25557 .08012 L
F
.2 .63 .79 r
.25435 .08012 m
.25435 .35178 L
.25557 .35178 L
.25557 .08012 L
s
.678 .847 .902 r
.25557 .08012 m
.25557 .35129 L
.25758 .35129 L
.25758 .08012 L
F
.2 .63 .79 r
.25557 .08012 m
.25557 .35129 L
.25758 .35129 L
.25758 .08012 L
s
.678 .847 .902 r
.25758 .08012 m
.25758 .34953 L
.25876 .34953 L
.25876 .08012 L
F
.2 .63 .79 r
.25758 .08012 m
.25758 .34953 L
.25876 .34953 L
.25876 .08012 L
s
.678 .847 .902 r
.25876 .08012 m
.25876 .34791 L
.26028 .34791 L
.26028 .08012 L
F
.2 .63 .79 r
.25876 .08012 m
.25876 .34791 L
.26028 .34791 L
.26028 .08012 L
s
.678 .847 .902 r
.26028 .08012 m
.26028 .34674 L
.26187 .34674 L
.26187 .08012 L
F
.2 .63 .79 r
.26028 .08012 m
.26028 .34674 L
.26187 .34674 L
.26187 .08012 L
s
.678 .847 .902 r
.26187 .08012 m
.26187 .34433 L
.26441 .34433 L
.26441 .08012 L
F
.2 .63 .79 r
.26187 .08012 m
.26187 .34433 L
.26441 .34433 L
.26441 .08012 L
s
.678 .847 .902 r
.26441 .08012 m
.26441 .34301 L
.26711 .34301 L
.26711 .08012 L
F
.2 .63 .79 r
.26441 .08012 m
.26441 .34301 L
.26711 .34301 L
.26711 .08012 L
s
.678 .847 .902 r
.26711 .08012 m
.26711 .33967 L
.26891 .33967 L
.26891 .08012 L
F
.2 .63 .79 r
.26711 .08012 m
.26711 .33967 L
.26891 .33967 L
.26891 .08012 L
s
.678 .847 .902 r
.26891 .08012 m
.26891 .33877 L
.26988 .33877 L
.26988 .08012 L
F
.2 .63 .79 r
.26891 .08012 m
.26891 .33877 L
.26988 .33877 L
.26988 .08012 L
s
.678 .847 .902 r
.26988 .08012 m
.26988 .33794 L
.27235 .33794 L
.27235 .08012 L
F
.2 .63 .79 r
.26988 .08012 m
.26988 .33794 L
.27235 .33794 L
.27235 .08012 L
s
.678 .847 .902 r
.27235 .08012 m
.27235 .33586 L
.27401 .33586 L
.27401 .08012 L
F
.2 .63 .79 r
.27235 .08012 m
.27235 .33586 L
.27401 .33586 L
.27401 .08012 L
s
.678 .847 .902 r
.27401 .08012 m
.27401 .33222 L
.27676 .33222 L
.27676 .08012 L
F
.2 .63 .79 r
.27401 .08012 m
.27401 .33222 L
.27676 .33222 L
.27676 .08012 L
s
.678 .847 .902 r
.27676 .08012 m
.27676 .33111 L
.2784 .33111 L
.2784 .08012 L
F
.2 .63 .79 r
.27676 .08012 m
.27676 .33111 L
.2784 .33111 L
.2784 .08012 L
s
.678 .847 .902 r
.2784 .08012 m
.2784 .32992 L
.28135 .32992 L
.28135 .08012 L
F
.2 .63 .79 r
.2784 .08012 m
.2784 .32992 L
.28135 .32992 L
.28135 .08012 L
s
.678 .847 .902 r
.28135 .08012 m
.28135 .32612 L
.28419 .32612 L
.28419 .08012 L
F
.2 .63 .79 r
.28135 .08012 m
.28135 .32612 L
.28419 .32612 L
.28419 .08012 L
s
.678 .847 .902 r
.28419 .08012 m
.28419 .32429 L
.2871 .32429 L
.2871 .08012 L
F
.2 .63 .79 r
.28419 .08012 m
.28419 .32429 L
.2871 .32429 L
.2871 .08012 L
s
.678 .847 .902 r
.2871 .08012 m
.2871 .32046 L
.2899 .32046 L
.2899 .08012 L
F
.2 .63 .79 r
.2871 .08012 m
.2871 .32046 L
.2899 .32046 L
.2899 .08012 L
s
.678 .847 .902 r
.2899 .08012 m
.2899 .32011 L
.29153 .32011 L
.29153 .08012 L
F
.2 .63 .79 r
.2899 .08012 m
.2899 .32011 L
.29153 .32011 L
.29153 .08012 L
s
.678 .847 .902 r
.29153 .08012 m
.29153 .31766 L
.29373 .31766 L
.29373 .08012 L
F
.2 .63 .79 r
.29153 .08012 m
.29153 .31766 L
.29373 .31766 L
.29373 .08012 L
s
.678 .847 .902 r
.29373 .08012 m
.29373 .31592 L
.29631 .31592 L
.29631 .08012 L
F
.2 .63 .79 r
.29373 .08012 m
.29373 .31592 L
.29631 .31592 L
.29631 .08012 L
s
.678 .847 .902 r
.29631 .08012 m
.29631 .31449 L
.29836 .31449 L
.29836 .08012 L
F
.2 .63 .79 r
.29631 .08012 m
.29631 .31449 L
.29836 .31449 L
.29836 .08012 L
s
.678 .847 .902 r
.29836 .08012 m
.29836 .31103 L
.3007 .31103 L
.3007 .08012 L
F
.2 .63 .79 r
.29836 .08012 m
.29836 .31103 L
.3007 .31103 L
.3007 .08012 L
s
.678 .847 .902 r
.3007 .08012 m
.3007 .31001 L
.30267 .31001 L
.30267 .08012 L
F
.2 .63 .79 r
.3007 .08012 m
.3007 .31001 L
.30267 .31001 L
.30267 .08012 L
s
.678 .847 .902 r
.30267 .08012 m
.30267 .30855 L
.30501 .30855 L
.30501 .08012 L
F
.2 .63 .79 r
.30267 .08012 m
.30267 .30855 L
.30501 .30855 L
.30501 .08012 L
s
.678 .847 .902 r
.30501 .08012 m
.30501 .30679 L
.30673 .30679 L
.30673 .08012 L
F
.2 .63 .79 r
.30501 .08012 m
.30501 .30679 L
.30673 .30679 L
.30673 .08012 L
s
.678 .847 .902 r
.30673 .08012 m
.30673 .30482 L
.30796 .30482 L
.30796 .08012 L
F
.2 .63 .79 r
.30673 .08012 m
.30673 .30482 L
.30796 .30482 L
.30796 .08012 L
s
.678 .847 .902 r
.30796 .08012 m
.30796 .30419 L
.30965 .30419 L
.30965 .08012 L
F
.2 .63 .79 r
.30796 .08012 m
.30796 .30419 L
.30965 .30419 L
.30965 .08012 L
s
.678 .847 .902 r
.30965 .08012 m
.30965 .302 L
.31137 .302 L
.31137 .08012 L
F
.2 .63 .79 r
.30965 .08012 m
.30965 .302 L
.31137 .302 L
.31137 .08012 L
s
.678 .847 .902 r
.31137 .08012 m
.31137 .30083 L
.31241 .30083 L
.31241 .08012 L
F
.2 .63 .79 r
.31137 .08012 m
.31137 .30083 L
.31241 .30083 L
.31241 .08012 L
s
.678 .847 .902 r
.31241 .08012 m
.31241 .30058 L
.3141 .30058 L
.3141 .08012 L
F
.2 .63 .79 r
.31241 .08012 m
.31241 .30058 L
.3141 .30058 L
.3141 .08012 L
s
.678 .847 .902 r
.3141 .08012 m
.3141 .29918 L
.31608 .29918 L
.31608 .08012 L
F
.2 .63 .79 r
.3141 .08012 m
.3141 .29918 L
.31608 .29918 L
.31608 .08012 L
s
.678 .847 .902 r
.31608 .08012 m
.31608 .29526 L
.31901 .29526 L
.31901 .08012 L
F
.2 .63 .79 r
.31608 .08012 m
.31608 .29526 L
.31901 .29526 L
.31901 .08012 L
s
.678 .847 .902 r
.31901 .08012 m
.31901 .29487 L
.31998 .29487 L
.31998 .08012 L
F
.2 .63 .79 r
.31901 .08012 m
.31901 .29487 L
.31998 .29487 L
.31998 .08012 L
s
.678 .847 .902 r
.31998 .08012 m
.31998 .29262 L
.32219 .29262 L
.32219 .08012 L
F
.2 .63 .79 r
.31998 .08012 m
.31998 .29262 L
.32219 .29262 L
.32219 .08012 L
s
.678 .847 .902 r
.32219 .08012 m
.32219 .29145 L
.32342 .29145 L
.32342 .08012 L
F
.2 .63 .79 r
.32219 .08012 m
.32219 .29145 L
.32342 .29145 L
.32342 .08012 L
s
.678 .847 .902 r
.32342 .08012 m
.32342 .2904 L
.32449 .2904 L
.32449 .08012 L
F
.2 .63 .79 r
.32342 .08012 m
.32342 .2904 L
.32449 .2904 L
.32449 .08012 L
s
.678 .847 .902 r
.32449 .08012 m
.32449 .2895 L
.32683 .2895 L
.32683 .08012 L
F
.2 .63 .79 r
.32449 .08012 m
.32449 .2895 L
.32683 .2895 L
.32683 .08012 L
s
.678 .847 .902 r
.32683 .08012 m
.32683 .28734 L
.3291 .28734 L
.3291 .08012 L
F
.2 .63 .79 r
.32683 .08012 m
.32683 .28734 L
.3291 .28734 L
.3291 .08012 L
s
.678 .847 .902 r
.3291 .08012 m
.3291 .28639 L
.33049 .28639 L
.33049 .08012 L
F
.2 .63 .79 r
.3291 .08012 m
.3291 .28639 L
.33049 .28639 L
.33049 .08012 L
s
.678 .847 .902 r
.33049 .08012 m
.33049 .28483 L
.33165 .28483 L
.33165 .08012 L
F
.2 .63 .79 r
.33049 .08012 m
.33049 .28483 L
.33165 .28483 L
.33165 .08012 L
s
.678 .847 .902 r
.33165 .08012 m
.33165 .28333 L
.33419 .28333 L
.33419 .08012 L
F
.2 .63 .79 r
.33165 .08012 m
.33165 .28333 L
.33419 .28333 L
.33419 .08012 L
s
.678 .847 .902 r
.33419 .08012 m
.33419 .28173 L
.33572 .28173 L
.33572 .08012 L
F
.2 .63 .79 r
.33419 .08012 m
.33419 .28173 L
.33572 .28173 L
.33572 .08012 L
s
.678 .847 .902 r
.33572 .08012 m
.33572 .28017 L
.33791 .28017 L
.33791 .08012 L
F
.2 .63 .79 r
.33572 .08012 m
.33572 .28017 L
.33791 .28017 L
.33791 .08012 L
s
.678 .847 .902 r
.33791 .08012 m
.33791 .27908 L
.33949 .27908 L
.33949 .08012 L
F
.2 .63 .79 r
.33791 .08012 m
.33791 .27908 L
.33949 .27908 L
.33949 .08012 L
s
.678 .847 .902 r
.33949 .08012 m
.33949 .27737 L
.34089 .27737 L
.34089 .08012 L
F
.2 .63 .79 r
.33949 .08012 m
.33949 .27737 L
.34089 .27737 L
.34089 .08012 L
s
.678 .847 .902 r
.34089 .08012 m
.34089 .2758 L
.34308 .2758 L
.34308 .08012 L
F
.2 .63 .79 r
.34089 .08012 m
.34089 .2758 L
.34308 .2758 L
.34308 .08012 L
s
.678 .847 .902 r
.34308 .08012 m
.34308 .27396 L
.34421 .27396 L
.34421 .08012 L
F
.2 .63 .79 r
.34308 .08012 m
.34308 .27396 L
.34421 .27396 L
.34421 .08012 L
s
.678 .847 .902 r
.34421 .08012 m
.34421 .27254 L
.34645 .27254 L
.34645 .08012 L
F
.2 .63 .79 r
.34421 .08012 m
.34421 .27254 L
.34645 .27254 L
.34645 .08012 L
s
.678 .847 .902 r
.34645 .08012 m
.34645 .27167 L
.34912 .27167 L
.34912 .08012 L
F
.2 .63 .79 r
.34645 .08012 m
.34645 .27167 L
.34912 .27167 L
.34912 .08012 L
s
.678 .847 .902 r
.34912 .08012 m
.34912 .26871 L
.35098 .26871 L
.35098 .08012 L
F
.2 .63 .79 r
.34912 .08012 m
.34912 .26871 L
.35098 .26871 L
.35098 .08012 L
s
.678 .847 .902 r
.35098 .08012 m
.35098 .26691 L
.35342 .26691 L
.35342 .08012 L
F
.2 .63 .79 r
.35098 .08012 m
.35098 .26691 L
.35342 .26691 L
.35342 .08012 L
s
.678 .847 .902 r
.35342 .08012 m
.35342 .26634 L
.35484 .26634 L
.35484 .08012 L
F
.2 .63 .79 r
.35342 .08012 m
.35342 .26634 L
.35484 .26634 L
.35484 .08012 L
s
.678 .847 .902 r
.35484 .08012 m
.35484 .26444 L
.35738 .26444 L
.35738 .08012 L
F
.2 .63 .79 r
.35484 .08012 m
.35484 .26444 L
.35738 .26444 L
.35738 .08012 L
s
.678 .847 .902 r
.35738 .08012 m
.35738 .26258 L
.35845 .26258 L
.35845 .08012 L
F
.2 .63 .79 r
.35738 .08012 m
.35738 .26258 L
.35845 .26258 L
.35845 .08012 L
s
.678 .847 .902 r
.35845 .08012 m
.35845 .26155 L
.3598 .26155 L
.3598 .08012 L
F
.2 .63 .79 r
.35845 .08012 m
.35845 .26155 L
.3598 .26155 L
.3598 .08012 L
s
.678 .847 .902 r
.3598 .08012 m
.3598 .26107 L
.3613 .26107 L
.3613 .08012 L
F
.2 .63 .79 r
.3598 .08012 m
.3598 .26107 L
.3613 .26107 L
.3613 .08012 L
s
.678 .847 .902 r
.3613 .08012 m
.3613 .25956 L
.36377 .25956 L
.36377 .08012 L
F
.2 .63 .79 r
.3613 .08012 m
.3613 .25956 L
.36377 .25956 L
.36377 .08012 L
s
.678 .847 .902 r
.36377 .08012 m
.36377 .25675 L
.36562 .25675 L
.36562 .08012 L
F
.2 .63 .79 r
.36377 .08012 m
.36377 .25675 L
.36562 .25675 L
.36562 .08012 L
s
.678 .847 .902 r
.36562 .08012 m
.36562 .25587 L
.36665 .25587 L
.36665 .08012 L
F
.2 .63 .79 r
.36562 .08012 m
.36562 .25587 L
.36665 .25587 L
.36665 .08012 L
s
.678 .847 .902 r
.36665 .08012 m
.36665 .25556 L
.36797 .25556 L
.36797 .08012 L
F
.2 .63 .79 r
.36665 .08012 m
.36665 .25556 L
.36797 .25556 L
.36797 .08012 L
s
.678 .847 .902 r
.36797 .08012 m
.36797 .25409 L
.369 .25409 L
.369 .08012 L
F
.2 .63 .79 r
.36797 .08012 m
.36797 .25409 L
.369 .25409 L
.369 .08012 L
s
.678 .847 .902 r
.369 .08012 m
.369 .25316 L
.3716 .25316 L
.3716 .08012 L
F
.2 .63 .79 r
.369 .08012 m
.369 .25316 L
.3716 .25316 L
.3716 .08012 L
s
.678 .847 .902 r
.3716 .08012 m
.3716 .25007 L
.37423 .25007 L
.37423 .08012 L
F
.2 .63 .79 r
.3716 .08012 m
.3716 .25007 L
.37423 .25007 L
.37423 .08012 L
s
.678 .847 .902 r
.37423 .08012 m
.37423 .2492 L
.3753 .2492 L
.3753 .08012 L
F
.2 .63 .79 r
.37423 .08012 m
.37423 .2492 L
.3753 .2492 L
.3753 .08012 L
s
.678 .847 .902 r
.3753 .08012 m
.3753 .24858 L
.37679 .24858 L
.37679 .08012 L
F
.2 .63 .79 r
.3753 .08012 m
.3753 .24858 L
.37679 .24858 L
.37679 .08012 L
s
.678 .847 .902 r
.37679 .08012 m
.37679 .24781 L
.37875 .24781 L
.37875 .08012 L
F
.2 .63 .79 r
.37679 .08012 m
.37679 .24781 L
.37875 .24781 L
.37875 .08012 L
s
.678 .847 .902 r
.37875 .08012 m
.37875 .24583 L
.38009 .24583 L
.38009 .08012 L
F
.2 .63 .79 r
.37875 .08012 m
.37875 .24583 L
.38009 .24583 L
.38009 .08012 L
s
.678 .847 .902 r
.38009 .08012 m
.38009 .24379 L
.38258 .24379 L
.38258 .08012 L
F
.2 .63 .79 r
.38009 .08012 m
.38009 .24379 L
.38258 .24379 L
.38258 .08012 L
s
.678 .847 .902 r
.38258 .08012 m
.38258 .24336 L
.38358 .24336 L
.38358 .08012 L
F
.2 .63 .79 r
.38258 .08012 m
.38258 .24336 L
.38358 .24336 L
.38358 .08012 L
s
.678 .847 .902 r
.38358 .08012 m
.38358 .24138 L
.38634 .24138 L
.38634 .08012 L
F
.2 .63 .79 r
.38358 .08012 m
.38358 .24138 L
.38634 .24138 L
.38634 .08012 L
s
.678 .847 .902 r
.38634 .08012 m
.38634 .24002 L
.38746 .24002 L
.38746 .08012 L
F
.2 .63 .79 r
.38634 .08012 m
.38634 .24002 L
.38746 .24002 L
.38746 .08012 L
s
.678 .847 .902 r
.38746 .08012 m
.38746 .2396 L
.38861 .2396 L
.38861 .08012 L
F
.2 .63 .79 r
.38746 .08012 m
.38746 .2396 L
.38861 .2396 L
.38861 .08012 L
s
.678 .847 .902 r
.38861 .08012 m
.38861 .2379 L
.38994 .2379 L
.38994 .08012 L
F
.2 .63 .79 r
.38861 .08012 m
.38861 .2379 L
.38994 .2379 L
.38994 .08012 L
s
.678 .847 .902 r
.38994 .08012 m
.38994 .23665 L
.39174 .23665 L
.39174 .08012 L
F
.2 .63 .79 r
.38994 .08012 m
.38994 .23665 L
.39174 .23665 L
.39174 .08012 L
s
.678 .847 .902 r
.39174 .08012 m
.39174 .23535 L
.39342 .23535 L
.39342 .08012 L
F
.2 .63 .79 r
.39174 .08012 m
.39174 .23535 L
.39342 .23535 L
.39342 .08012 L
s
.678 .847 .902 r
.39342 .08012 m
.39342 .23306 L
.39615 .23306 L
.39615 .08012 L
F
.2 .63 .79 r
.39342 .08012 m
.39342 .23306 L
.39615 .23306 L
.39615 .08012 L
s
.678 .847 .902 r
.39615 .08012 m
.39615 .23244 L
.39794 .23244 L
.39794 .08012 L
F
.2 .63 .79 r
.39615 .08012 m
.39615 .23244 L
.39794 .23244 L
.39794 .08012 L
s
.678 .847 .902 r
.39794 .08012 m
.39794 .23162 L
.39957 .23162 L
.39957 .08012 L
F
.2 .63 .79 r
.39794 .08012 m
.39794 .23162 L
.39957 .23162 L
.39957 .08012 L
s
.678 .847 .902 r
.39957 .08012 m
.39957 .23041 L
.40079 .23041 L
.40079 .08012 L
F
.2 .63 .79 r
.39957 .08012 m
.39957 .23041 L
.40079 .23041 L
.40079 .08012 L
s
.678 .847 .902 r
.40079 .08012 m
.40079 .22824 L
.40294 .22824 L
.40294 .08012 L
F
.2 .63 .79 r
.40079 .08012 m
.40079 .22824 L
.40294 .22824 L
.40294 .08012 L
s
.678 .847 .902 r
.40294 .08012 m
.40294 .22765 L
.40526 .22765 L
.40526 .08012 L
F
.2 .63 .79 r
.40294 .08012 m
.40294 .22765 L
.40526 .22765 L
.40526 .08012 L
s
.678 .847 .902 r
.40526 .08012 m
.40526 .22594 L
.40804 .22594 L
.40804 .08012 L
F
.2 .63 .79 r
.40526 .08012 m
.40526 .22594 L
.40804 .22594 L
.40804 .08012 L
s
.678 .847 .902 r
.40804 .08012 m
.40804 .22408 L
.40913 .22408 L
.40913 .08012 L
F
.2 .63 .79 r
.40804 .08012 m
.40804 .22408 L
.40913 .22408 L
.40913 .08012 L
s
.678 .847 .902 r
.40913 .08012 m
.40913 .22265 L
.41085 .22265 L
.41085 .08012 L
F
.2 .63 .79 r
.40913 .08012 m
.40913 .22265 L
.41085 .22265 L
.41085 .08012 L
s
.678 .847 .902 r
.41085 .08012 m
.41085 .22157 L
.41304 .22157 L
.41304 .08012 L
F
.2 .63 .79 r
.41085 .08012 m
.41085 .22157 L
.41304 .22157 L
.41304 .08012 L
s
.678 .847 .902 r
.41304 .08012 m
.41304 .21992 L
.41413 .21992 L
.41413 .08012 L
F
.2 .63 .79 r
.41304 .08012 m
.41304 .21992 L
.41413 .21992 L
.41413 .08012 L
s
.678 .847 .902 r
.41413 .08012 m
.41413 .21948 L
.41559 .21948 L
.41559 .08012 L
F
.2 .63 .79 r
.41413 .08012 m
.41413 .21948 L
.41559 .21948 L
.41559 .08012 L
s
.678 .847 .902 r
.41559 .08012 m
.41559 .21777 L
.41714 .21777 L
.41714 .08012 L
F
.2 .63 .79 r
.41559 .08012 m
.41559 .21777 L
.41714 .21777 L
.41714 .08012 L
s
.678 .847 .902 r
.41714 .08012 m
.41714 .21642 L
.41874 .21642 L
.41874 .08012 L
F
.2 .63 .79 r
.41714 .08012 m
.41714 .21642 L
.41874 .21642 L
.41874 .08012 L
s
.678 .847 .902 r
.41874 .08012 m
.41874 .21528 L
.42087 .21528 L
.42087 .08012 L
F
.2 .63 .79 r
.41874 .08012 m
.41874 .21528 L
.42087 .21528 L
.42087 .08012 L
s
.678 .847 .902 r
.42087 .08012 m
.42087 .21429 L
.42189 .21429 L
.42189 .08012 L
F
.2 .63 .79 r
.42087 .08012 m
.42087 .21429 L
.42189 .21429 L
.42189 .08012 L
s
.678 .847 .902 r
.42189 .08012 m
.42189 .21262 L
.42396 .21262 L
.42396 .08012 L
F
.2 .63 .79 r
.42189 .08012 m
.42189 .21262 L
.42396 .21262 L
.42396 .08012 L
s
.678 .847 .902 r
.42396 .08012 m
.42396 .21162 L
.42546 .21162 L
.42546 .08012 L
F
.2 .63 .79 r
.42396 .08012 m
.42396 .21162 L
.42546 .21162 L
.42546 .08012 L
s
.678 .847 .902 r
.42546 .08012 m
.42546 .21132 L
.42782 .21132 L
.42782 .08012 L
F
.2 .63 .79 r
.42546 .08012 m
.42546 .21132 L
.42782 .21132 L
.42782 .08012 L
s
.678 .847 .902 r
.42782 .08012 m
.42782 .20947 L
.43072 .20947 L
.43072 .08012 L
F
.2 .63 .79 r
.42782 .08012 m
.42782 .20947 L
.43072 .20947 L
.43072 .08012 L
s
.678 .847 .902 r
.43072 .08012 m
.43072 .20657 L
.43254 .20657 L
.43254 .08012 L
F
.2 .63 .79 r
.43072 .08012 m
.43072 .20657 L
.43254 .20657 L
.43254 .08012 L
s
.678 .847 .902 r
.43254 .08012 m
.43254 .20645 L
.43361 .20645 L
.43361 .08012 L
F
.2 .63 .79 r
.43254 .08012 m
.43254 .20645 L
.43361 .20645 L
.43361 .08012 L
s
.678 .847 .902 r
.43361 .08012 m
.43361 .20542 L
.43507 .20542 L
.43507 .08012 L
F
.2 .63 .79 r
.43361 .08012 m
.43361 .20542 L
.43507 .20542 L
.43507 .08012 L
s
.678 .847 .902 r
.43507 .08012 m
.43507 .20417 L
.4372 .20417 L
.4372 .08012 L
F
.2 .63 .79 r
.43507 .08012 m
.43507 .20417 L
.4372 .20417 L
.4372 .08012 L
s
.678 .847 .902 r
.4372 .08012 m
.4372 .20184 L
.43928 .20184 L
.43928 .08012 L
F
.2 .63 .79 r
.4372 .08012 m
.4372 .20184 L
.43928 .20184 L
.43928 .08012 L
s
.678 .847 .902 r
.43928 .08012 m
.43928 .20078 L
.44157 .20078 L
.44157 .08012 L
F
.2 .63 .79 r
.43928 .08012 m
.43928 .20078 L
.44157 .20078 L
.44157 .08012 L
s
.678 .847 .902 r
.44157 .08012 m
.44157 .19967 L
.4444 .19967 L
.4444 .08012 L
F
.2 .63 .79 r
.44157 .08012 m
.44157 .19967 L
.4444 .19967 L
.4444 .08012 L
s
.678 .847 .902 r
.4444 .08012 m
.4444 .19786 L
.44621 .19786 L
.44621 .08012 L
F
.2 .63 .79 r
.4444 .08012 m
.4444 .19786 L
.44621 .19786 L
.44621 .08012 L
s
.678 .847 .902 r
.44621 .08012 m
.44621 .19673 L
.44915 .19673 L
.44915 .08012 L
F
.2 .63 .79 r
.44621 .08012 m
.44621 .19673 L
.44915 .19673 L
.44915 .08012 L
s
.678 .847 .902 r
.44915 .08012 m
.44915 .19407 L
.45211 .19407 L
.45211 .08012 L
F
.2 .63 .79 r
.44915 .08012 m
.44915 .19407 L
.45211 .19407 L
.45211 .08012 L
s
.678 .847 .902 r
.45211 .08012 m
.45211 .19288 L
.45306 .19288 L
.45306 .08012 L
F
.2 .63 .79 r
.45211 .08012 m
.45211 .19288 L
.45306 .19288 L
.45306 .08012 L
s
.678 .847 .902 r
.45306 .08012 m
.45306 .19212 L
.45468 .19212 L
.45468 .08012 L
F
.2 .63 .79 r
.45306 .08012 m
.45306 .19212 L
.45468 .19212 L
.45468 .08012 L
s
.678 .847 .902 r
.45468 .08012 m
.45468 .19042 L
.4568 .19042 L
.4568 .08012 L
F
.2 .63 .79 r
.45468 .08012 m
.45468 .19042 L
.4568 .19042 L
.4568 .08012 L
s
.678 .847 .902 r
.4568 .08012 m
.4568 .18966 L
.45847 .18966 L
.45847 .08012 L
F
.2 .63 .79 r
.4568 .08012 m
.4568 .18966 L
.45847 .18966 L
.45847 .08012 L
s
.678 .847 .902 r
.45847 .08012 m
.45847 .18794 L
.46134 .18794 L
.46134 .08012 L
F
.2 .63 .79 r
.45847 .08012 m
.45847 .18794 L
.46134 .18794 L
.46134 .08012 L
s
.678 .847 .902 r
.46134 .08012 m
.46134 .18607 L
.46239 .18607 L
.46239 .08012 L
F
.2 .63 .79 r
.46134 .08012 m
.46134 .18607 L
.46239 .18607 L
.46239 .08012 L
s
.678 .847 .902 r
.46239 .08012 m
.46239 .18528 L
.46386 .18528 L
.46386 .08012 L
F
.2 .63 .79 r
.46239 .08012 m
.46239 .18528 L
.46386 .18528 L
.46386 .08012 L
s
.678 .847 .902 r
.46386 .08012 m
.46386 .18495 L
.46483 .18495 L
.46483 .08012 L
F
.2 .63 .79 r
.46386 .08012 m
.46386 .18495 L
.46483 .18495 L
.46483 .08012 L
s
.678 .847 .902 r
.46483 .08012 m
.46483 .18369 L
.46648 .18369 L
.46648 .08012 L
F
.2 .63 .79 r
.46483 .08012 m
.46483 .18369 L
.46648 .18369 L
.46648 .08012 L
s
.678 .847 .902 r
.46648 .08012 m
.46648 .1832 L
.46741 .1832 L
.46741 .08012 L
F
.2 .63 .79 r
.46648 .08012 m
.46648 .1832 L
.46741 .1832 L
.46741 .08012 L
s
.678 .847 .902 r
.46741 .08012 m
.46741 .18148 L
.46981 .18148 L
.46981 .08012 L
F
.2 .63 .79 r
.46741 .08012 m
.46741 .18148 L
.46981 .18148 L
.46981 .08012 L
s
.678 .847 .902 r
.46981 .08012 m
.46981 .18075 L
.47228 .18075 L
.47228 .08012 L
F
.2 .63 .79 r
.46981 .08012 m
.46981 .18075 L
.47228 .18075 L
.47228 .08012 L
s
.678 .847 .902 r
.47228 .08012 m
.47228 .17871 L
.47457 .17871 L
.47457 .08012 L
F
.2 .63 .79 r
.47228 .08012 m
.47228 .17871 L
.47457 .17871 L
.47457 .08012 L
s
.678 .847 .902 r
.47457 .08012 m
.47457 .178 L
.4756 .178 L
.4756 .08012 L
F
.2 .63 .79 r
.47457 .08012 m
.47457 .178 L
.4756 .178 L
.4756 .08012 L
s
.678 .847 .902 r
.4756 .08012 m
.4756 .17655 L
.47708 .17655 L
.47708 .08012 L
F
.2 .63 .79 r
.4756 .08012 m
.4756 .17655 L
.47708 .17655 L
.47708 .08012 L
s
.678 .847 .902 r
.47708 .08012 m
.47708 .17615 L
.47938 .17615 L
.47938 .08012 L
F
.2 .63 .79 r
.47708 .08012 m
.47708 .17615 L
.47938 .17615 L
.47938 .08012 L
s
.678 .847 .902 r
.47938 .08012 m
.47938 .17467 L
.48111 .17467 L
.48111 .08012 L
F
.2 .63 .79 r
.47938 .08012 m
.47938 .17467 L
.48111 .17467 L
.48111 .08012 L
s
.678 .847 .902 r
.48111 .08012 m
.48111 .17301 L
.48301 .17301 L
.48301 .08012 L
F
.2 .63 .79 r
.48111 .08012 m
.48111 .17301 L
.48301 .17301 L
.48301 .08012 L
s
.678 .847 .902 r
.48301 .08012 m
.48301 .17124 L
.4854 .17124 L
.4854 .08012 L
F
.2 .63 .79 r
.48301 .08012 m
.48301 .17124 L
.4854 .17124 L
.4854 .08012 L
s
.678 .847 .902 r
.4854 .08012 m
.4854 .17072 L
.48633 .17072 L
.48633 .08012 L
F
.2 .63 .79 r
.4854 .08012 m
.4854 .17072 L
.48633 .17072 L
.48633 .08012 L
s
.678 .847 .902 r
.48633 .08012 m
.48633 .16932 L
.48823 .16932 L
.48823 .08012 L
F
.2 .63 .79 r
.48633 .08012 m
.48633 .16932 L
.48823 .16932 L
.48823 .08012 L
s
.678 .847 .902 r
.48823 .08012 m
.48823 .16903 L
.48922 .16903 L
.48922 .08012 L
F
.2 .63 .79 r
.48823 .08012 m
.48823 .16903 L
.48922 .16903 L
.48922 .08012 L
s
.678 .847 .902 r
.48922 .08012 m
.48922 .16747 L
.49167 .16747 L
.49167 .08012 L
F
.2 .63 .79 r
.48922 .08012 m
.48922 .16747 L
.49167 .16747 L
.49167 .08012 L
s
.678 .847 .902 r
.49167 .08012 m
.49167 .16702 L
.49264 .16702 L
.49264 .08012 L
F
.2 .63 .79 r
.49167 .08012 m
.49167 .16702 L
.49264 .16702 L
.49264 .08012 L
s
.678 .847 .902 r
.49264 .08012 m
.49264 .16552 L
.49449 .16552 L
.49449 .08012 L
F
.2 .63 .79 r
.49264 .08012 m
.49264 .16552 L
.49449 .16552 L
.49449 .08012 L
s
.678 .847 .902 r
.49449 .08012 m
.49449 .16506 L
.49687 .16506 L
.49687 .08012 L
F
.2 .63 .79 r
.49449 .08012 m
.49449 .16506 L
.49687 .16506 L
.49687 .08012 L
s
.678 .847 .902 r
.49687 .08012 m
.49687 .16368 L
.4981 .16368 L
.4981 .08012 L
F
.2 .63 .79 r
.49687 .08012 m
.49687 .16368 L
.4981 .16368 L
.4981 .08012 L
s
.678 .847 .902 r
.4981 .08012 m
.4981 .16169 L
.50039 .16169 L
.50039 .08012 L
F
.2 .63 .79 r
.4981 .08012 m
.4981 .16169 L
.50039 .16169 L
.50039 .08012 L
s
.678 .847 .902 r
.50039 .08012 m
.50039 .1611 L
.50237 .1611 L
.50237 .08012 L
F
.2 .63 .79 r
.50039 .08012 m
.50039 .1611 L
.50237 .1611 L
.50237 .08012 L
s
.678 .847 .902 r
.50237 .08012 m
.50237 .1601 L
.5046 .1601 L
.5046 .08012 L
F
.2 .63 .79 r
.50237 .08012 m
.50237 .1601 L
.5046 .1601 L
.5046 .08012 L
s
.678 .847 .902 r
.5046 .08012 m
.5046 .15835 L
.50736 .15835 L
.50736 .08012 L
F
.2 .63 .79 r
.5046 .08012 m
.5046 .15835 L
.50736 .15835 L
.50736 .08012 L
s
.678 .847 .902 r
.50736 .08012 m
.50736 .15627 L
.50959 .15627 L
.50959 .08012 L
F
.2 .63 .79 r
.50736 .08012 m
.50736 .15627 L
.50959 .15627 L
.50959 .08012 L
s
.678 .847 .902 r
.50959 .08012 m
.50959 .15542 L
.51082 .15542 L
.51082 .08012 L
F
.2 .63 .79 r
.50959 .08012 m
.50959 .15542 L
.51082 .15542 L
.51082 .08012 L
s
.678 .847 .902 r
.51082 .08012 m
.51082 .15521 L
.51301 .15521 L
.51301 .08012 L
F
.2 .63 .79 r
.51082 .08012 m
.51082 .15521 L
.51301 .15521 L
.51301 .08012 L
s
.678 .847 .902 r
.51301 .08012 m
.51301 .15345 L
.51428 .15345 L
.51428 .08012 L
F
.2 .63 .79 r
.51301 .08012 m
.51301 .15345 L
.51428 .15345 L
.51428 .08012 L
s
.678 .847 .902 r
.51428 .08012 m
.51428 .15222 L
.51703 .15222 L
.51703 .08012 L
F
.2 .63 .79 r
.51428 .08012 m
.51428 .15222 L
.51703 .15222 L
.51703 .08012 L
s
.678 .847 .902 r
.51703 .08012 m
.51703 .15124 L
.51897 .15124 L
.51897 .08012 L
F
.2 .63 .79 r
.51703 .08012 m
.51703 .15124 L
.51897 .15124 L
.51897 .08012 L
s
.678 .847 .902 r
.51897 .08012 m
.51897 .15034 L
.52104 .15034 L
.52104 .08012 L
F
.2 .63 .79 r
.51897 .08012 m
.51897 .15034 L
.52104 .15034 L
.52104 .08012 L
s
.678 .847 .902 r
.52104 .08012 m
.52104 .14781 L
.52383 .14781 L
.52383 .08012 L
F
.2 .63 .79 r
.52104 .08012 m
.52104 .14781 L
.52383 .14781 L
.52383 .08012 L
s
.678 .847 .902 r
.52383 .08012 m
.52383 .14717 L
.52518 .14717 L
.52518 .08012 L
F
.2 .63 .79 r
.52383 .08012 m
.52383 .14717 L
.52518 .14717 L
.52518 .08012 L
s
.678 .847 .902 r
.52518 .08012 m
.52518 .14667 L
.52629 .14667 L
.52629 .08012 L
F
.2 .63 .79 r
.52518 .08012 m
.52518 .14667 L
.52629 .14667 L
.52629 .08012 L
s
.678 .847 .902 r
.52629 .08012 m
.52629 .14581 L
.52735 .14581 L
.52735 .08012 L
F
.2 .63 .79 r
.52629 .08012 m
.52629 .14581 L
.52735 .14581 L
.52735 .08012 L
s
.678 .847 .902 r
.52735 .08012 m
.52735 .14472 L
.52866 .14472 L
.52866 .08012 L
F
.2 .63 .79 r
.52735 .08012 m
.52735 .14472 L
.52866 .14472 L
.52866 .08012 L
s
.678 .847 .902 r
.52866 .08012 m
.52866 .14398 L
.52999 .14398 L
.52999 .08012 L
F
.2 .63 .79 r
.52866 .08012 m
.52866 .14398 L
.52999 .14398 L
.52999 .08012 L
s
.678 .847 .902 r
.52999 .08012 m
.52999 .14374 L
.53219 .14374 L
.53219 .08012 L
F
.2 .63 .79 r
.52999 .08012 m
.52999 .14374 L
.53219 .14374 L
.53219 .08012 L
s
.678 .847 .902 r
.53219 .08012 m
.53219 .1426 L
.53316 .1426 L
.53316 .08012 L
F
.2 .63 .79 r
.53219 .08012 m
.53219 .1426 L
.53316 .1426 L
.53316 .08012 L
s
.678 .847 .902 r
.53316 .08012 m
.53316 .14184 L
.53502 .14184 L
.53502 .08012 L
F
.2 .63 .79 r
.53316 .08012 m
.53316 .14184 L
.53502 .14184 L
.53502 .08012 L
s
.678 .847 .902 r
.53502 .08012 m
.53502 .1404 L
.53629 .1404 L
.53629 .08012 L
F
.2 .63 .79 r
.53502 .08012 m
.53502 .1404 L
.53629 .1404 L
.53629 .08012 L
s
.678 .847 .902 r
.53629 .08012 m
.53629 .14006 L
.53754 .14006 L
.53754 .08012 L
F
.2 .63 .79 r
.53629 .08012 m
.53629 .14006 L
.53754 .14006 L
.53754 .08012 L
s
.678 .847 .902 r
.53754 .08012 m
.53754 .13874 L
.53913 .13874 L
.53913 .08012 L
F
.2 .63 .79 r
.53754 .08012 m
.53754 .13874 L
.53913 .13874 L
.53913 .08012 L
s
.678 .847 .902 r
.53913 .08012 m
.53913 .13863 L
.54066 .13863 L
.54066 .08012 L
F
.2 .63 .79 r
.53913 .08012 m
.53913 .13863 L
.54066 .13863 L
.54066 .08012 L
s
.678 .847 .902 r
.54066 .08012 m
.54066 .13682 L
.54263 .13682 L
.54263 .08012 L
F
.2 .63 .79 r
.54066 .08012 m
.54066 .13682 L
.54263 .13682 L
.54263 .08012 L
s
.678 .847 .902 r
.54263 .08012 m
.54263 .13555 L
.54491 .13555 L
.54491 .08012 L
F
.2 .63 .79 r
.54263 .08012 m
.54263 .13555 L
.54491 .13555 L
.54491 .08012 L
s
.678 .847 .902 r
.54491 .08012 m
.54491 .13449 L
.54728 .13449 L
.54728 .08012 L
F
.2 .63 .79 r
.54491 .08012 m
.54491 .13449 L
.54728 .13449 L
.54728 .08012 L
s
.678 .847 .902 r
.54728 .08012 m
.54728 .13347 L
.54903 .13347 L
.54903 .08012 L
F
.2 .63 .79 r
.54728 .08012 m
.54728 .13347 L
.54903 .13347 L
.54903 .08012 L
s
.678 .847 .902 r
.54903 .08012 m
.54903 .13299 L
.55178 .13299 L
.55178 .08012 L
F
.2 .63 .79 r
.54903 .08012 m
.54903 .13299 L
.55178 .13299 L
.55178 .08012 L
s
.678 .847 .902 r
.55178 .08012 m
.55178 .13147 L
.55373 .13147 L
.55373 .08012 L
F
.2 .63 .79 r
.55178 .08012 m
.55178 .13147 L
.55373 .13147 L
.55373 .08012 L
s
.678 .847 .902 r
.55373 .08012 m
.55373 .13014 L
.55481 .13014 L
.55481 .08012 L
F
.2 .63 .79 r
.55373 .08012 m
.55373 .13014 L
.55481 .13014 L
.55481 .08012 L
s
.678 .847 .902 r
.55481 .08012 m
.55481 .12993 L
.55619 .12993 L
.55619 .08012 L
F
.2 .63 .79 r
.55481 .08012 m
.55481 .12993 L
.55619 .12993 L
.55619 .08012 L
s
.678 .847 .902 r
.55619 .08012 m
.55619 .12835 L
.55919 .12835 L
.55919 .08012 L
F
.2 .63 .79 r
.55619 .08012 m
.55619 .12835 L
.55919 .12835 L
.55919 .08012 L
s
.678 .847 .902 r
.55919 .08012 m
.55919 .12713 L
.5601 .12713 L
.5601 .08012 L
F
.2 .63 .79 r
.55919 .08012 m
.55919 .12713 L
.5601 .12713 L
.5601 .08012 L
s
.678 .847 .902 r
.5601 .08012 m
.5601 .12637 L
.56212 .12637 L
.56212 .08012 L
F
.2 .63 .79 r
.5601 .08012 m
.5601 .12637 L
.56212 .12637 L
.56212 .08012 L
s
.678 .847 .902 r
.56212 .08012 m
.56212 .12581 L
.5637 .12581 L
.5637 .08012 L
F
.2 .63 .79 r
.56212 .08012 m
.56212 .12581 L
.5637 .12581 L
.5637 .08012 L
s
.678 .847 .902 r
.5637 .08012 m
.5637 .12501 L
.56625 .12501 L
.56625 .08012 L
F
.2 .63 .79 r
.5637 .08012 m
.5637 .12501 L
.56625 .12501 L
.56625 .08012 L
s
.678 .847 .902 r
.56625 .08012 m
.56625 .12255 L
.56906 .12255 L
.56906 .08012 L
F
.2 .63 .79 r
.56625 .08012 m
.56625 .12255 L
.56906 .12255 L
.56906 .08012 L
s
.678 .847 .902 r
.56906 .08012 m
.56906 .12206 L
.57091 .12206 L
.57091 .08012 L
F
.2 .63 .79 r
.56906 .08012 m
.56906 .12206 L
.57091 .12206 L
.57091 .08012 L
s
.678 .847 .902 r
.57091 .08012 m
.57091 .12116 L
.57209 .12116 L
.57209 .08012 L
F
.2 .63 .79 r
.57091 .08012 m
.57091 .12116 L
.57209 .12116 L
.57209 .08012 L
s
.678 .847 .902 r
.57209 .08012 m
.57209 .12049 L
.57421 .12049 L
.57421 .08012 L
F
.2 .63 .79 r
.57209 .08012 m
.57209 .12049 L
.57421 .12049 L
.57421 .08012 L
s
.678 .847 .902 r
.57421 .08012 m
.57421 .11904 L
.57571 .11904 L
.57571 .08012 L
F
.2 .63 .79 r
.57421 .08012 m
.57421 .11904 L
.57571 .11904 L
.57571 .08012 L
s
.678 .847 .902 r
.57571 .08012 m
.57571 .11866 L
.5775 .11866 L
.5775 .08012 L
F
.2 .63 .79 r
.57571 .08012 m
.57571 .11866 L
.5775 .11866 L
.5775 .08012 L
s
.678 .847 .902 r
.5775 .08012 m
.5775 .11786 L
.57982 .11786 L
.57982 .08012 L
F
.2 .63 .79 r
.5775 .08012 m
.5775 .11786 L
.57982 .11786 L
.57982 .08012 L
s
.678 .847 .902 r
.57982 .08012 m
.57982 .11638 L
.58158 .11638 L
.58158 .08012 L
F
.2 .63 .79 r
.57982 .08012 m
.57982 .11638 L
.58158 .11638 L
.58158 .08012 L
s
.678 .847 .902 r
.58158 .08012 m
.58158 .11556 L
.58273 .11556 L
.58273 .08012 L
F
.2 .63 .79 r
.58158 .08012 m
.58158 .11556 L
.58273 .11556 L
.58273 .08012 L
s
.678 .847 .902 r
.58273 .08012 m
.58273 .11506 L
.58381 .11506 L
.58381 .08012 L
F
.2 .63 .79 r
.58273 .08012 m
.58273 .11506 L
.58381 .11506 L
.58381 .08012 L
s
.678 .847 .902 r
.58381 .08012 m
.58381 .11379 L
.58552 .11379 L
.58552 .08012 L
F
.2 .63 .79 r
.58381 .08012 m
.58381 .11379 L
.58552 .11379 L
.58552 .08012 L
s
.678 .847 .902 r
.58552 .08012 m
.58552 .11315 L
.5883 .11315 L
.5883 .08012 L
F
.2 .63 .79 r
.58552 .08012 m
.58552 .11315 L
.5883 .11315 L
.5883 .08012 L
s
.678 .847 .902 r
.5883 .08012 m
.5883 .11194 L
.59017 .11194 L
.59017 .08012 L
F
.2 .63 .79 r
.5883 .08012 m
.5883 .11194 L
.59017 .11194 L
.59017 .08012 L
s
.678 .847 .902 r
.59017 .08012 m
.59017 .11096 L
.59189 .11096 L
.59189 .08012 L
F
.2 .63 .79 r
.59017 .08012 m
.59017 .11096 L
.59189 .11096 L
.59189 .08012 L
s
.678 .847 .902 r
.59189 .08012 m
.59189 .11009 L
.59484 .11009 L
.59484 .08012 L
F
.2 .63 .79 r
.59189 .08012 m
.59189 .11009 L
.59484 .11009 L
.59484 .08012 L
s
.678 .847 .902 r
.59484 .08012 m
.59484 .10893 L
.59577 .10893 L
.59577 .08012 L
F
.2 .63 .79 r
.59484 .08012 m
.59484 .10893 L
.59577 .10893 L
.59577 .08012 L
s
.678 .847 .902 r
.59577 .08012 m
.59577 .10817 L
.5987 .10817 L
.5987 .08012 L
F
.2 .63 .79 r
.59577 .08012 m
.59577 .10817 L
.5987 .10817 L
.5987 .08012 L
s
.678 .847 .902 r
.5987 .08012 m
.5987 .10654 L
.60024 .10654 L
.60024 .08012 L
F
.2 .63 .79 r
.5987 .08012 m
.5987 .10654 L
.60024 .10654 L
.60024 .08012 L
s
.678 .847 .902 r
.60024 .08012 m
.60024 .10607 L
.60271 .10607 L
.60271 .08012 L
F
.2 .63 .79 r
.60024 .08012 m
.60024 .10607 L
.60271 .10607 L
.60271 .08012 L
s
.678 .847 .902 r
.60271 .08012 m
.60271 .10486 L
.60364 .10486 L
.60364 .08012 L
F
.2 .63 .79 r
.60271 .08012 m
.60271 .10486 L
.60364 .10486 L
.60364 .08012 L
s
.678 .847 .902 r
.60364 .08012 m
.60364 .10417 L
.60655 .10417 L
.60655 .08012 L
F
.2 .63 .79 r
.60364 .08012 m
.60364 .10417 L
.60655 .10417 L
.60655 .08012 L
s
.678 .847 .902 r
.60655 .08012 m
.60655 .10311 L
.60909 .10311 L
.60909 .08012 L
F
.2 .63 .79 r
.60655 .08012 m
.60655 .10311 L
.60909 .10311 L
.60909 .08012 L
s
.678 .847 .902 r
.60909 .08012 m
.60909 .10207 L
.61086 .10207 L
.61086 .08012 L
F
.2 .63 .79 r
.60909 .08012 m
.60909 .10207 L
.61086 .10207 L
.61086 .08012 L
s
.678 .847 .902 r
.61086 .08012 m
.61086 .10084 L
.61225 .10084 L
.61225 .08012 L
F
.2 .63 .79 r
.61086 .08012 m
.61086 .10084 L
.61225 .10084 L
.61225 .08012 L
s
.678 .847 .902 r
.61225 .08012 m
.61225 .10037 L
.61326 .10037 L
.61326 .08012 L
F
.2 .63 .79 r
.61225 .08012 m
.61225 .10037 L
.61326 .10037 L
.61326 .08012 L
s
.678 .847 .902 r
.61326 .08012 m
.61326 .09946 L
.61484 .09946 L
.61484 .08012 L
F
.2 .63 .79 r
.61326 .08012 m
.61326 .09946 L
.61484 .09946 L
.61484 .08012 L
s
.678 .847 .902 r
.61484 .08012 m
.61484 .09884 L
.61634 .09884 L
.61634 .08012 L
F
.2 .63 .79 r
.61484 .08012 m
.61484 .09884 L
.61634 .09884 L
.61634 .08012 L
s
.678 .847 .902 r
.61634 .08012 m
.61634 .09814 L
.6186 .09814 L
.6186 .08012 L
F
.2 .63 .79 r
.61634 .08012 m
.61634 .09814 L
.6186 .09814 L
.6186 .08012 L
s
.678 .847 .902 r
.6186 .08012 m
.6186 .0966 L
.62111 .0966 L
.62111 .08012 L
F
.2 .63 .79 r
.6186 .08012 m
.6186 .0966 L
.62111 .0966 L
.62111 .08012 L
s
.678 .847 .902 r
.62111 .08012 m
.62111 .09545 L
.62391 .09545 L
.62391 .08012 L
F
.2 .63 .79 r
.62111 .08012 m
.62111 .09545 L
.62391 .09545 L
.62391 .08012 L
s
.678 .847 .902 r
.62391 .08012 m
.62391 .09439 L
.62608 .09439 L
.62608 .08012 L
F
.2 .63 .79 r
.62391 .08012 m
.62391 .09439 L
.62608 .09439 L
.62608 .08012 L
s
.678 .847 .902 r
.62608 .08012 m
.62608 .0941 L
.62749 .0941 L
.62749 .08012 L
F
.2 .63 .79 r
.62608 .08012 m
.62608 .0941 L
.62749 .0941 L
.62749 .08012 L
s
.678 .847 .902 r
.62749 .08012 m
.62749 .09301 L
.62975 .09301 L
.62975 .08012 L
F
.2 .63 .79 r
.62749 .08012 m
.62749 .09301 L
.62975 .09301 L
.62975 .08012 L
s
.678 .847 .902 r
.62975 .08012 m
.62975 .09187 L
.63237 .09187 L
.63237 .08012 L
F
.2 .63 .79 r
.62975 .08012 m
.62975 .09187 L
.63237 .09187 L
.63237 .08012 L
s
.678 .847 .902 r
.63237 .08012 m
.63237 .09088 L
.63373 .09088 L
.63373 .08012 L
F
.2 .63 .79 r
.63237 .08012 m
.63237 .09088 L
.63373 .09088 L
.63373 .08012 L
s
.678 .847 .902 r
.63373 .08012 m
.63373 .09023 L
.63536 .09023 L
.63536 .08012 L
F
.2 .63 .79 r
.63373 .08012 m
.63373 .09023 L
.63536 .09023 L
.63536 .08012 L
s
.678 .847 .902 r
.63536 .08012 m
.63536 .09001 L
.63665 .09001 L
.63665 .08012 L
F
.2 .63 .79 r
.63536 .08012 m
.63536 .09001 L
.63665 .09001 L
.63665 .08012 L
s
.678 .847 .902 r
.63665 .08012 m
.63665 .08945 L
.63844 .08945 L
.63844 .08012 L
F
.2 .63 .79 r
.63665 .08012 m
.63665 .08945 L
.63844 .08945 L
.63844 .08012 L
s
.678 .847 .902 r
.63844 .08012 m
.63844 .08837 L
.63987 .08837 L
.63987 .08012 L
F
.2 .63 .79 r
.63844 .08012 m
.63844 .08837 L
.63987 .08837 L
.63987 .08012 L
s
.678 .847 .902 r
.63987 .08012 m
.63987 .08779 L
.64146 .08779 L
.64146 .08012 L
F
.2 .63 .79 r
.63987 .08012 m
.63987 .08779 L
.64146 .08779 L
.64146 .08012 L
s
.678 .847 .902 r
.64146 .08012 m
.64146 .08693 L
.64283 .08693 L
.64283 .08012 L
F
.2 .63 .79 r
.64146 .08012 m
.64146 .08693 L
.64283 .08693 L
.64283 .08012 L
s
.678 .847 .902 r
.64283 .08012 m
.64283 .08671 L
.64397 .08671 L
.64397 .08012 L
F
.2 .63 .79 r
.64283 .08012 m
.64283 .08671 L
.64397 .08671 L
.64397 .08012 L
s
.678 .847 .902 r
.64397 .08012 m
.64397 .0861 L
.64594 .0861 L
.64594 .08012 L
F
.2 .63 .79 r
.64397 .08012 m
.64397 .0861 L
.64594 .0861 L
.64594 .08012 L
s
.678 .847 .902 r
.64594 .08012 m
.64594 .08507 L
.6475 .08507 L
.6475 .08012 L
F
.2 .63 .79 r
.64594 .08012 m
.64594 .08507 L
.6475 .08507 L
.6475 .08012 L
s
.678 .847 .902 r
.6475 .08012 m
.6475 .08458 L
.64895 .08458 L
.64895 .08012 L
F
.2 .63 .79 r
.6475 .08012 m
.6475 .08458 L
.64895 .08458 L
.64895 .08012 L
s
.678 .847 .902 r
.64895 .08012 m
.64895 .08419 L
.65056 .08419 L
.65056 .08012 L
F
.2 .63 .79 r
.64895 .08012 m
.64895 .08419 L
.65056 .08419 L
.65056 .08012 L
s
.678 .847 .902 r
.65056 .08012 m
.65056 .08344 L
.65165 .08344 L
.65165 .08012 L
F
.2 .63 .79 r
.65056 .08012 m
.65056 .08344 L
.65165 .08344 L
.65165 .08012 L
s
.678 .847 .902 r
.65165 .08012 m
.65165 .08266 L
.65273 .08266 L
.65273 .08012 L
F
.2 .63 .79 r
.65165 .08012 m
.65165 .08266 L
.65273 .08266 L
.65273 .08012 L
s
.678 .847 .902 r
.65273 .08012 m
.65273 .08217 L
.65407 .08217 L
.65407 .08012 L
F
.2 .63 .79 r
.65273 .08012 m
.65273 .08217 L
.65407 .08217 L
.65407 .08012 L
s
.678 .847 .902 r
.65407 .08012 m
.65407 .08204 L
.655 .08204 L
.655 .08012 L
F
.2 .63 .79 r
.65407 .08012 m
.65407 .08204 L
.655 .08204 L
.655 .08012 L
s
.678 .847 .902 r
.655 .08012 m
.655 .08134 L
.6576 .08134 L
.6576 .08012 L
F
.2 .63 .79 r
.655 .08012 m
.655 .08134 L
.6576 .08134 L
.6576 .08012 L
s
.678 .847 .902 r
.6576 .08012 m
.6576 .08034 L
.65941 .08034 L
.65941 .08012 L
F
.2 .63 .79 r
.6576 .08012 m
.6576 .08034 L
.65941 .08034 L
.65941 .08012 L
s
1 .894 .882 r
.65941 .08012 m
.65941 .07921 L
.66125 .07921 L
.66125 .08012 L
F
.804 .522 .247 r
.65941 .08012 m
.65941 .07921 L
.66125 .07921 L
.66125 .08012 L
s
1 .894 .882 r
.66125 .08012 m
.66125 .079 L
.66238 .079 L
.66238 .08012 L
F
.804 .522 .247 r
.66125 .08012 m
.66125 .079 L
.66238 .079 L
.66238 .08012 L
s
1 .894 .882 r
.66238 .08012 m
.66238 .07839 L
.6637 .07839 L
.6637 .08012 L
F
.804 .522 .247 r
.66238 .08012 m
.66238 .07839 L
.6637 .07839 L
.6637 .08012 L
s
1 .894 .882 r
.6637 .08012 m
.6637 .07805 L
.66501 .07805 L
.66501 .08012 L
F
.804 .522 .247 r
.6637 .08012 m
.6637 .07805 L
.66501 .07805 L
.66501 .08012 L
s
1 .894 .882 r
.66501 .08012 m
.66501 .07731 L
.66758 .07731 L
.66758 .08012 L
F
.804 .522 .247 r
.66501 .08012 m
.66501 .07731 L
.66758 .07731 L
.66758 .08012 L
s
1 .894 .882 r
.66758 .08012 m
.66758 .07618 L
.6691 .07618 L
.6691 .08012 L
F
.804 .522 .247 r
.66758 .08012 m
.66758 .07618 L
.6691 .07618 L
.6691 .08012 L
s
1 .894 .882 r
.6691 .08012 m
.6691 .07529 L
.67205 .07529 L
.67205 .08012 L
F
.804 .522 .247 r
.6691 .08012 m
.6691 .07529 L
.67205 .07529 L
.67205 .08012 L
s
1 .894 .882 r
.67205 .08012 m
.67205 .07447 L
.67473 .07447 L
.67473 .08012 L
F
.804 .522 .247 r
.67205 .08012 m
.67205 .07447 L
.67473 .07447 L
.67473 .08012 L
s
1 .894 .882 r
.67473 .08012 m
.67473 .07362 L
.67691 .07362 L
.67691 .08012 L
F
.804 .522 .247 r
.67473 .08012 m
.67473 .07362 L
.67691 .07362 L
.67691 .08012 L
s
1 .894 .882 r
.67691 .08012 m
.67691 .07234 L
.67964 .07234 L
.67964 .08012 L
F
.804 .522 .247 r
.67691 .08012 m
.67691 .07234 L
.67964 .07234 L
.67964 .08012 L
s
1 .894 .882 r
.67964 .08012 m
.67964 .0709 L
.68208 .0709 L
.68208 .08012 L
F
.804 .522 .247 r
.67964 .08012 m
.67964 .0709 L
.68208 .0709 L
.68208 .08012 L
s
1 .894 .882 r
.68208 .08012 m
.68208 .07026 L
.68406 .07026 L
.68406 .08012 L
F
.804 .522 .247 r
.68208 .08012 m
.68208 .07026 L
.68406 .07026 L
.68406 .08012 L
s
1 .894 .882 r
.68406 .08012 m
.68406 .06994 L
.68578 .06994 L
.68578 .08012 L
F
.804 .522 .247 r
.68406 .08012 m
.68406 .06994 L
.68578 .06994 L
.68578 .08012 L
s
1 .894 .882 r
.68578 .08012 m
.68578 .06923 L
.68826 .06923 L
.68826 .08012 L
F
.804 .522 .247 r
.68578 .08012 m
.68578 .06923 L
.68826 .06923 L
.68826 .08012 L
s
1 .894 .882 r
.68826 .08012 m
.68826 .06818 L
.68963 .06818 L
.68963 .08012 L
F
.804 .522 .247 r
.68826 .08012 m
.68826 .06818 L
.68963 .06818 L
.68963 .08012 L
s
1 .894 .882 r
.68963 .08012 m
.68963 .06793 L
.69096 .06793 L
.69096 .08012 L
F
.804 .522 .247 r
.68963 .08012 m
.68963 .06793 L
.69096 .06793 L
.69096 .08012 L
s
1 .894 .882 r
.69096 .08012 m
.69096 .06715 L
.69212 .06715 L
.69212 .08012 L
F
.804 .522 .247 r
.69096 .08012 m
.69096 .06715 L
.69212 .06715 L
.69212 .08012 L
s
1 .894 .882 r
.69212 .08012 m
.69212 .06694 L
.69389 .06694 L
.69389 .08012 L
F
.804 .522 .247 r
.69212 .08012 m
.69212 .06694 L
.69389 .06694 L
.69389 .08012 L
s
1 .894 .882 r
.69389 .08012 m
.69389 .06622 L
.69508 .06622 L
.69508 .08012 L
F
.804 .522 .247 r
.69389 .08012 m
.69389 .06622 L
.69508 .06622 L
.69508 .08012 L
s
1 .894 .882 r
.69508 .08012 m
.69508 .06589 L
.69622 .06589 L
.69622 .08012 L
F
.804 .522 .247 r
.69508 .08012 m
.69508 .06589 L
.69622 .06589 L
.69622 .08012 L
s
1 .894 .882 r
.69622 .08012 m
.69622 .06551 L
.69904 .06551 L
.69904 .08012 L
F
.804 .522 .247 r
.69622 .08012 m
.69622 .06551 L
.69904 .06551 L
.69904 .08012 L
s
1 .894 .882 r
.69904 .08012 m
.69904 .06444 L
.70078 .06444 L
.70078 .08012 L
F
.804 .522 .247 r
.69904 .08012 m
.69904 .06444 L
.70078 .06444 L
.70078 .08012 L
s
1 .894 .882 r
.70078 .08012 m
.70078 .06383 L
.70238 .06383 L
.70238 .08012 L
F
.804 .522 .247 r
.70078 .08012 m
.70078 .06383 L
.70238 .06383 L
.70238 .08012 L
s
1 .894 .882 r
.70238 .08012 m
.70238 .0626 L
.70471 .0626 L
.70471 .08012 L
F
.804 .522 .247 r
.70238 .08012 m
.70238 .0626 L
.70471 .0626 L
.70471 .08012 L
s
1 .894 .882 r
.70471 .08012 m
.70471 .06239 L
.70659 .06239 L
.70659 .08012 L
F
.804 .522 .247 r
.70471 .08012 m
.70471 .06239 L
.70659 .06239 L
.70659 .08012 L
s
1 .894 .882 r
.70659 .08012 m
.70659 .06188 L
.70811 .06188 L
.70811 .08012 L
F
.804 .522 .247 r
.70659 .08012 m
.70659 .06188 L
.70811 .06188 L
.70811 .08012 L
s
1 .894 .882 r
.70811 .08012 m
.70811 .06105 L
.70928 .06105 L
.70928 .08012 L
F
.804 .522 .247 r
.70811 .08012 m
.70811 .06105 L
.70928 .06105 L
.70928 .08012 L
s
1 .894 .882 r
.70928 .08012 m
.70928 .06038 L
.71121 .06038 L
.71121 .08012 L
F
.804 .522 .247 r
.70928 .08012 m
.70928 .06038 L
.71121 .06038 L
.71121 .08012 L
s
1 .894 .882 r
.71121 .08012 m
.71121 .05949 L
.71351 .05949 L
.71351 .08012 L
F
.804 .522 .247 r
.71121 .08012 m
.71121 .05949 L
.71351 .05949 L
.71351 .08012 L
s
1 .894 .882 r
.71351 .08012 m
.71351 .05905 L
.71651 .05905 L
.71651 .08012 L
F
.804 .522 .247 r
.71351 .08012 m
.71351 .05905 L
.71651 .05905 L
.71651 .08012 L
s
1 .894 .882 r
.71651 .08012 m
.71651 .05839 L
.71773 .05839 L
.71773 .08012 L
F
.804 .522 .247 r
.71651 .08012 m
.71651 .05839 L
.71773 .05839 L
.71773 .08012 L
s
1 .894 .882 r
.71773 .08012 m
.71773 .05762 L
.71998 .05762 L
.71998 .08012 L
F
.804 .522 .247 r
.71773 .08012 m
.71773 .05762 L
.71998 .05762 L
.71998 .08012 L
s
1 .894 .882 r
.71998 .08012 m
.71998 .057 L
.721 .057 L
.721 .08012 L
F
.804 .522 .247 r
.71998 .08012 m
.71998 .057 L
.721 .057 L
.721 .08012 L
s
1 .894 .882 r
.721 .08012 m
.721 .0566 L
.72217 .0566 L
.72217 .08012 L
F
.804 .522 .247 r
.721 .08012 m
.721 .0566 L
.72217 .0566 L
.72217 .08012 L
s
1 .894 .882 r
.72217 .08012 m
.72217 .05642 L
.72396 .05642 L
.72396 .08012 L
F
.804 .522 .247 r
.72217 .08012 m
.72217 .05642 L
.72396 .05642 L
.72396 .08012 L
s
1 .894 .882 r
.72396 .08012 m
.72396 .05569 L
.72512 .05569 L
.72512 .08012 L
F
.804 .522 .247 r
.72396 .08012 m
.72396 .05569 L
.72512 .05569 L
.72512 .08012 L
s
1 .894 .882 r
.72512 .08012 m
.72512 .05511 L
.72744 .05511 L
.72744 .08012 L
F
.804 .522 .247 r
.72512 .08012 m
.72512 .05511 L
.72744 .05511 L
.72744 .08012 L
s
1 .894 .882 r
.72744 .08012 m
.72744 .05447 L
.72912 .05447 L
.72912 .08012 L
F
.804 .522 .247 r
.72744 .08012 m
.72744 .05447 L
.72912 .05447 L
.72912 .08012 L
s
1 .894 .882 r
.72912 .08012 m
.72912 .05407 L
.73044 .05407 L
.73044 .08012 L
F
.804 .522 .247 r
.72912 .08012 m
.72912 .05407 L
.73044 .05407 L
.73044 .08012 L
s
1 .894 .882 r
.73044 .08012 m
.73044 .05331 L
.73327 .05331 L
.73327 .08012 L
F
.804 .522 .247 r
.73044 .08012 m
.73044 .05331 L
.73327 .05331 L
.73327 .08012 L
s
1 .894 .882 r
.73327 .08012 m
.73327 .05247 L
.73533 .05247 L
.73533 .08012 L
F
.804 .522 .247 r
.73327 .08012 m
.73327 .05247 L
.73533 .05247 L
.73533 .08012 L
s
1 .894 .882 r
.73533 .08012 m
.73533 .05189 L
.73824 .05189 L
.73824 .08012 L
F
.804 .522 .247 r
.73533 .08012 m
.73533 .05189 L
.73824 .05189 L
.73824 .08012 L
s
1 .894 .882 r
.73824 .08012 m
.73824 .05141 L
.73927 .05141 L
.73927 .08012 L
F
.804 .522 .247 r
.73824 .08012 m
.73824 .05141 L
.73927 .05141 L
.73927 .08012 L
s
1 .894 .882 r
.73927 .08012 m
.73927 .05081 L
.74186 .05081 L
.74186 .08012 L
F
.804 .522 .247 r
.73927 .08012 m
.73927 .05081 L
.74186 .05081 L
.74186 .08012 L
s
1 .894 .882 r
.74186 .08012 m
.74186 .04983 L
.74411 .04983 L
.74411 .08012 L
F
.804 .522 .247 r
.74186 .08012 m
.74186 .04983 L
.74411 .04983 L
.74411 .08012 L
s
1 .894 .882 r
.74411 .08012 m
.74411 .04946 L
.74617 .04946 L
.74617 .08012 L
F
.804 .522 .247 r
.74411 .08012 m
.74411 .04946 L
.74617 .04946 L
.74617 .08012 L
s
1 .894 .882 r
.74617 .08012 m
.74617 .04836 L
.74861 .04836 L
.74861 .08012 L
F
.804 .522 .247 r
.74617 .08012 m
.74617 .04836 L
.74861 .04836 L
.74861 .08012 L
s
1 .894 .882 r
.74861 .08012 m
.74861 .04816 L
.74976 .04816 L
.74976 .08012 L
F
.804 .522 .247 r
.74861 .08012 m
.74861 .04816 L
.74976 .04816 L
.74976 .08012 L
s
1 .894 .882 r
.74976 .08012 m
.74976 .04779 L
.75103 .04779 L
.75103 .08012 L
F
.804 .522 .247 r
.74976 .08012 m
.74976 .04779 L
.75103 .04779 L
.75103 .08012 L
s
1 .894 .882 r
.75103 .08012 m
.75103 .04747 L
.75248 .04747 L
.75248 .08012 L
F
.804 .522 .247 r
.75103 .08012 m
.75103 .04747 L
.75248 .04747 L
.75248 .08012 L
s
1 .894 .882 r
.75248 .08012 m
.75248 .04707 L
.75465 .04707 L
.75465 .08012 L
F
.804 .522 .247 r
.75248 .08012 m
.75248 .04707 L
.75465 .04707 L
.75465 .08012 L
s
1 .894 .882 r
.75465 .08012 m
.75465 .04616 L
.75687 .04616 L
.75687 .08012 L
F
.804 .522 .247 r
.75465 .08012 m
.75465 .04616 L
.75687 .04616 L
.75687 .08012 L
s
1 .894 .882 r
.75687 .08012 m
.75687 .04563 L
.75884 .04563 L
.75884 .08012 L
F
.804 .522 .247 r
.75687 .08012 m
.75687 .04563 L
.75884 .04563 L
.75884 .08012 L
s
1 .894 .882 r
.75884 .08012 m
.75884 .04501 L
.76029 .04501 L
.76029 .08012 L
F
.804 .522 .247 r
.75884 .08012 m
.75884 .04501 L
.76029 .04501 L
.76029 .08012 L
s
1 .894 .882 r
.76029 .08012 m
.76029 .04446 L
.76214 .04446 L
.76214 .08012 L
F
.804 .522 .247 r
.76029 .08012 m
.76029 .04446 L
.76214 .04446 L
.76214 .08012 L
s
1 .894 .882 r
.76214 .08012 m
.76214 .04442 L
.76512 .04442 L
.76512 .08012 L
F
.804 .522 .247 r
.76214 .08012 m
.76214 .04442 L
.76512 .04442 L
.76512 .08012 L
s
1 .894 .882 r
.76512 .08012 m
.76512 .04332 L
.76695 .04332 L
.76695 .08012 L
F
.804 .522 .247 r
.76512 .08012 m
.76512 .04332 L
.76695 .04332 L
.76695 .08012 L
s
1 .894 .882 r
.76695 .08012 m
.76695 .04283 L
.76814 .04283 L
.76814 .08012 L
F
.804 .522 .247 r
.76695 .08012 m
.76695 .04283 L
.76814 .04283 L
.76814 .08012 L
s
1 .894 .882 r
.76814 .08012 m
.76814 .04262 L
.7691 .04262 L
.7691 .08012 L
F
.804 .522 .247 r
.76814 .08012 m
.76814 .04262 L
.7691 .04262 L
.7691 .08012 L
s
1 .894 .882 r
.7691 .08012 m
.7691 .04238 L
.77182 .04238 L
.77182 .08012 L
F
.804 .522 .247 r
.7691 .08012 m
.7691 .04238 L
.77182 .04238 L
.77182 .08012 L
s
1 .894 .882 r
.77182 .08012 m
.77182 .04119 L
.77434 .04119 L
.77434 .08012 L
F
.804 .522 .247 r
.77182 .08012 m
.77182 .04119 L
.77434 .04119 L
.77434 .08012 L
s
1 .894 .882 r
.77434 .08012 m
.77434 .04103 L
.77685 .04103 L
.77685 .08012 L
F
.804 .522 .247 r
.77434 .08012 m
.77434 .04103 L
.77685 .04103 L
.77685 .08012 L
s
1 .894 .882 r
.77685 .08012 m
.77685 .04045 L
.77949 .04045 L
.77949 .08012 L
F
.804 .522 .247 r
.77685 .08012 m
.77685 .04045 L
.77949 .04045 L
.77949 .08012 L
s
1 .894 .882 r
.77949 .08012 m
.77949 .03941 L
.78238 .03941 L
.78238 .08012 L
F
.804 .522 .247 r
.77949 .08012 m
.77949 .03941 L
.78238 .03941 L
.78238 .08012 L
s
1 .894 .882 r
.78238 .08012 m
.78238 .03905 L
.78374 .03905 L
.78374 .08012 L
F
.804 .522 .247 r
.78238 .08012 m
.78238 .03905 L
.78374 .03905 L
.78374 .08012 L
s
1 .894 .882 r
.78374 .08012 m
.78374 .03831 L
.78633 .03831 L
.78633 .08012 L
F
.804 .522 .247 r
.78374 .08012 m
.78374 .03831 L
.78633 .03831 L
.78633 .08012 L
s
1 .894 .882 r
.78633 .08012 m
.78633 .03752 L
.78884 .03752 L
.78884 .08012 L
F
.804 .522 .247 r
.78633 .08012 m
.78633 .03752 L
.78884 .03752 L
.78884 .08012 L
s
1 .894 .882 r
.78884 .08012 m
.78884 .03745 L
.79005 .03745 L
.79005 .08012 L
F
.804 .522 .247 r
.78884 .08012 m
.78884 .03745 L
.79005 .03745 L
.79005 .08012 L
s
1 .894 .882 r
.79005 .08012 m
.79005 .03703 L
.79216 .03703 L
.79216 .08012 L
F
.804 .522 .247 r
.79005 .08012 m
.79005 .03703 L
.79216 .03703 L
.79216 .08012 L
s
1 .894 .882 r
.79216 .08012 m
.79216 .03657 L
.79359 .03657 L
.79359 .08012 L
F
.804 .522 .247 r
.79216 .08012 m
.79216 .03657 L
.79359 .03657 L
.79359 .08012 L
s
1 .894 .882 r
.79359 .08012 m
.79359 .03635 L
.79457 .03635 L
.79457 .08012 L
F
.804 .522 .247 r
.79359 .08012 m
.79359 .03635 L
.79457 .03635 L
.79457 .08012 L
s
1 .894 .882 r
.79457 .08012 m
.79457 .03597 L
.79553 .03597 L
.79553 .08012 L
F
.804 .522 .247 r
.79457 .08012 m
.79457 .03597 L
.79553 .03597 L
.79553 .08012 L
s
1 .894 .882 r
.79553 .08012 m
.79553 .03557 L
.79726 .03557 L
.79726 .08012 L
F
.804 .522 .247 r
.79553 .08012 m
.79553 .03557 L
.79726 .03557 L
.79726 .08012 L
s
1 .894 .882 r
.79726 .08012 m
.79726 .03548 L
.80024 .03548 L
.80024 .08012 L
F
.804 .522 .247 r
.79726 .08012 m
.79726 .03548 L
.80024 .03548 L
.80024 .08012 L
s
1 .894 .882 r
.80024 .08012 m
.80024 .03447 L
.80205 .03447 L
.80205 .08012 L
F
.804 .522 .247 r
.80024 .08012 m
.80024 .03447 L
.80205 .03447 L
.80205 .08012 L
s
1 .894 .882 r
.80205 .08012 m
.80205 .03438 L
.80379 .03438 L
.80379 .08012 L
F
.804 .522 .247 r
.80205 .08012 m
.80205 .03438 L
.80379 .03438 L
.80379 .08012 L
s
1 .894 .882 r
.80379 .08012 m
.80379 .03384 L
.80656 .03384 L
.80656 .08012 L
F
.804 .522 .247 r
.80379 .08012 m
.80379 .03384 L
.80656 .03384 L
.80656 .08012 L
s
1 .894 .882 r
.80656 .08012 m
.80656 .03332 L
.80899 .03332 L
.80899 .08012 L
F
.804 .522 .247 r
.80656 .08012 m
.80656 .03332 L
.80899 .03332 L
.80899 .08012 L
s
1 .894 .882 r
.80899 .08012 m
.80899 .03233 L
.81195 .03233 L
.81195 .08012 L
F
.804 .522 .247 r
.80899 .08012 m
.80899 .03233 L
.81195 .03233 L
.81195 .08012 L
s
1 .894 .882 r
.81195 .08012 m
.81195 .03185 L
.81371 .03185 L
.81371 .08012 L
F
.804 .522 .247 r
.81195 .08012 m
.81195 .03185 L
.81371 .03185 L
.81371 .08012 L
s
1 .894 .882 r
.81371 .08012 m
.81371 .0316 L
.81555 .0316 L
.81555 .08012 L
F
.804 .522 .247 r
.81371 .08012 m
.81371 .0316 L
.81555 .0316 L
.81555 .08012 L
s
1 .894 .882 r
.81555 .08012 m
.81555 .03137 L
.81768 .03137 L
.81768 .08012 L
F
.804 .522 .247 r
.81555 .08012 m
.81555 .03137 L
.81768 .03137 L
.81768 .08012 L
s
1 .894 .882 r
.81768 .08012 m
.81768 .03094 L
.82059 .03094 L
.82059 .08012 L
F
.804 .522 .247 r
.81768 .08012 m
.81768 .03094 L
.82059 .03094 L
.82059 .08012 L
s
1 .894 .882 r
.82059 .08012 m
.82059 .03011 L
.82263 .03011 L
.82263 .08012 L
F
.804 .522 .247 r
.82059 .08012 m
.82059 .03011 L
.82263 .03011 L
.82263 .08012 L
s
1 .894 .882 r
.82263 .08012 m
.82263 .02969 L
.82495 .02969 L
.82495 .08012 L
F
.804 .522 .247 r
.82263 .08012 m
.82263 .02969 L
.82495 .02969 L
.82495 .08012 L
s
1 .894 .882 r
.82495 .08012 m
.82495 .02956 L
.82758 .02956 L
.82758 .08012 L
F
.804 .522 .247 r
.82495 .08012 m
.82495 .02956 L
.82758 .02956 L
.82758 .08012 L
s
1 .894 .882 r
.82758 .08012 m
.82758 .02904 L
.82875 .02904 L
.82875 .08012 L
F
.804 .522 .247 r
.82758 .08012 m
.82758 .02904 L
.82875 .02904 L
.82875 .08012 L
s
1 .894 .882 r
.82875 .08012 m
.82875 .02874 L
.83089 .02874 L
.83089 .08012 L
F
.804 .522 .247 r
.82875 .08012 m
.82875 .02874 L
.83089 .02874 L
.83089 .08012 L
s
1 .894 .882 r
.83089 .08012 m
.83089 .02821 L
.83276 .02821 L
.83276 .08012 L
F
.804 .522 .247 r
.83089 .08012 m
.83089 .02821 L
.83276 .02821 L
.83276 .08012 L
s
1 .894 .882 r
.83276 .08012 m
.83276 .02801 L
.83369 .02801 L
.83369 .08012 L
F
.804 .522 .247 r
.83276 .08012 m
.83276 .02801 L
.83369 .02801 L
.83369 .08012 L
s
1 .894 .882 r
.83369 .08012 m
.83369 .02786 L
.83535 .02786 L
.83535 .08012 L
F
.804 .522 .247 r
.83369 .08012 m
.83369 .02786 L
.83535 .02786 L
.83535 .08012 L
s
1 .894 .882 r
.83535 .08012 m
.83535 .02757 L
.83719 .02757 L
.83719 .08012 L
F
.804 .522 .247 r
.83535 .08012 m
.83535 .02757 L
.83719 .02757 L
.83719 .08012 L
s
1 .894 .882 r
.83719 .08012 m
.83719 .02713 L
.83995 .02713 L
.83995 .08012 L
F
.804 .522 .247 r
.83719 .08012 m
.83719 .02713 L
.83995 .02713 L
.83995 .08012 L
s
1 .894 .882 r
.83995 .08012 m
.83995 .02633 L
.84245 .02633 L
.84245 .08012 L
F
.804 .522 .247 r
.83995 .08012 m
.83995 .02633 L
.84245 .02633 L
.84245 .08012 L
s
1 .894 .882 r
.84245 .08012 m
.84245 .0263 L
.84404 .0263 L
.84404 .08012 L
F
.804 .522 .247 r
.84245 .08012 m
.84245 .0263 L
.84404 .0263 L
.84404 .08012 L
s
1 .894 .882 r
.84404 .08012 m
.84404 .02593 L
.84581 .02593 L
.84581 .08012 L
F
.804 .522 .247 r
.84404 .08012 m
.84404 .02593 L
.84581 .02593 L
.84581 .08012 L
s
1 .894 .882 r
.84581 .08012 m
.84581 .0256 L
.84773 .0256 L
.84773 .08012 L
F
.804 .522 .247 r
.84581 .08012 m
.84581 .0256 L
.84773 .0256 L
.84773 .08012 L
s
1 .894 .882 r
.84773 .08012 m
.84773 .02502 L
.85026 .02502 L
.85026 .08012 L
F
.804 .522 .247 r
.84773 .08012 m
.84773 .02502 L
.85026 .02502 L
.85026 .08012 L
s
1 .894 .882 r
.85026 .08012 m
.85026 .02488 L
.85304 .02488 L
.85304 .08012 L
F
.804 .522 .247 r
.85026 .08012 m
.85026 .02488 L
.85304 .02488 L
.85304 .08012 L
s
1 .894 .882 r
.85304 .08012 m
.85304 .0245 L
.85398 .0245 L
.85398 .08012 L
F
.804 .522 .247 r
.85304 .08012 m
.85304 .0245 L
.85398 .0245 L
.85398 .08012 L
s
1 .894 .882 r
.85398 .08012 m
.85398 .02435 L
.85613 .02435 L
.85613 .08012 L
F
.804 .522 .247 r
.85398 .08012 m
.85398 .02435 L
.85613 .02435 L
.85613 .08012 L
s
1 .894 .882 r
.85613 .08012 m
.85613 .02394 L
.85713 .02394 L
.85713 .08012 L
F
.804 .522 .247 r
.85613 .08012 m
.85613 .02394 L
.85713 .02394 L
.85713 .08012 L
s
1 .894 .882 r
.85713 .08012 m
.85713 .02371 L
.85994 .02371 L
.85994 .08012 L
F
.804 .522 .247 r
.85713 .08012 m
.85713 .02371 L
.85994 .02371 L
.85994 .08012 L
s
1 .894 .882 r
.85994 .08012 m
.85994 .02336 L
.86212 .02336 L
.86212 .08012 L
F
.804 .522 .247 r
.85994 .08012 m
.85994 .02336 L
.86212 .02336 L
.86212 .08012 L
s
1 .894 .882 r
.86212 .08012 m
.86212 .02306 L
.86333 .02306 L
.86333 .08012 L
F
.804 .522 .247 r
.86212 .08012 m
.86212 .02306 L
.86333 .02306 L
.86333 .08012 L
s
1 .894 .882 r
.86333 .08012 m
.86333 .02281 L
.86521 .02281 L
.86521 .08012 L
F
.804 .522 .247 r
.86333 .08012 m
.86333 .02281 L
.86521 .02281 L
.86521 .08012 L
s
1 .894 .882 r
.86521 .08012 m
.86521 .02257 L
.86811 .02257 L
.86811 .08012 L
F
.804 .522 .247 r
.86521 .08012 m
.86521 .02257 L
.86811 .02257 L
.86811 .08012 L
s
1 .894 .882 r
.86811 .08012 m
.86811 .02221 L
.86915 .02221 L
.86915 .08012 L
F
.804 .522 .247 r
.86811 .08012 m
.86811 .02221 L
.86915 .02221 L
.86915 .08012 L
s
1 .894 .882 r
.86915 .08012 m
.86915 .02193 L
.87104 .02193 L
.87104 .08012 L
F
.804 .522 .247 r
.86915 .08012 m
.86915 .02193 L
.87104 .02193 L
.87104 .08012 L
s
1 .894 .882 r
.87104 .08012 m
.87104 .0217 L
.87329 .0217 L
.87329 .08012 L
F
.804 .522 .247 r
.87104 .08012 m
.87104 .0217 L
.87329 .0217 L
.87329 .08012 L
s
1 .894 .882 r
.87329 .08012 m
.87329 .02148 L
.87592 .02148 L
.87592 .08012 L
F
.804 .522 .247 r
.87329 .08012 m
.87329 .02148 L
.87592 .02148 L
.87592 .08012 L
s
1 .894 .882 r
.87592 .08012 m
.87592 .02114 L
.87783 .02114 L
.87783 .08012 L
F
.804 .522 .247 r
.87592 .08012 m
.87592 .02114 L
.87783 .02114 L
.87783 .08012 L
s
1 .894 .882 r
.87783 .08012 m
.87783 .02097 L
.87875 .02097 L
.87875 .08012 L
F
.804 .522 .247 r
.87783 .08012 m
.87783 .02097 L
.87875 .02097 L
.87875 .08012 L
s
1 .894 .882 r
.87875 .08012 m
.87875 .02079 L
.88096 .02079 L
.88096 .08012 L
F
.804 .522 .247 r
.87875 .08012 m
.87875 .02079 L
.88096 .02079 L
.88096 .08012 L
s
1 .894 .882 r
.88096 .08012 m
.88096 .02055 L
.88284 .02055 L
.88284 .08012 L
F
.804 .522 .247 r
.88096 .08012 m
.88096 .02055 L
.88284 .02055 L
.88284 .08012 L
s
1 .894 .882 r
.88284 .08012 m
.88284 .02033 L
.8838 .02033 L
.8838 .08012 L
F
.804 .522 .247 r
.88284 .08012 m
.88284 .02033 L
.8838 .02033 L
.8838 .08012 L
s
1 .894 .882 r
.8838 .08012 m
.8838 .02012 L
.88497 .02012 L
.88497 .08012 L
F
.804 .522 .247 r
.8838 .08012 m
.8838 .02012 L
.88497 .02012 L
.88497 .08012 L
s
1 .894 .882 r
.88497 .08012 m
.88497 .02001 L
.88768 .02001 L
.88768 .08012 L
F
.804 .522 .247 r
.88497 .08012 m
.88497 .02001 L
.88768 .02001 L
.88768 .08012 L
s
1 .894 .882 r
.88768 .08012 m
.88768 .01978 L
.88887 .01978 L
.88887 .08012 L
F
.804 .522 .247 r
.88768 .08012 m
.88768 .01978 L
.88887 .01978 L
.88887 .08012 L
s
1 .894 .882 r
.88887 .08012 m
.88887 .01943 L
.89106 .01943 L
.89106 .08012 L
F
.804 .522 .247 r
.88887 .08012 m
.88887 .01943 L
.89106 .01943 L
.89106 .08012 L
s
1 .894 .882 r
.89106 .08012 m
.89106 .01929 L
.89331 .01929 L
.89331 .08012 L
F
.804 .522 .247 r
.89106 .08012 m
.89106 .01929 L
.89331 .01929 L
.89331 .08012 L
s
1 .894 .882 r
.89331 .08012 m
.89331 .01913 L
.89439 .01913 L
.89439 .08012 L
F
.804 .522 .247 r
.89331 .08012 m
.89331 .01913 L
.89439 .01913 L
.89439 .08012 L
s
1 .894 .882 r
.89439 .08012 m
.89439 .01893 L
.8958 .01893 L
.8958 .08012 L
F
.804 .522 .247 r
.89439 .08012 m
.89439 .01893 L
.8958 .01893 L
.8958 .08012 L
s
1 .894 .882 r
.8958 .08012 m
.8958 .01878 L
.89796 .01878 L
.89796 .08012 L
F
.804 .522 .247 r
.8958 .08012 m
.8958 .01878 L
.89796 .01878 L
.89796 .08012 L
s
1 .894 .882 r
.89796 .08012 m
.89796 .01865 L
.89895 .01865 L
.89895 .08012 L
F
.804 .522 .247 r
.89796 .08012 m
.89796 .01865 L
.89895 .01865 L
.89895 .08012 L
s
1 .894 .882 r
.89895 .08012 m
.89895 .01854 L
.89993 .01854 L
.89993 .08012 L
F
.804 .522 .247 r
.89895 .08012 m
.89895 .01854 L
.89993 .01854 L
.89993 .08012 L
s
1 .894 .882 r
.89993 .08012 m
.89993 .01843 L
.90153 .01843 L
.90153 .08012 L
F
.804 .522 .247 r
.89993 .08012 m
.89993 .01843 L
.90153 .01843 L
.90153 .08012 L
s
1 .894 .882 r
.90153 .08012 m
.90153 .01828 L
.90451 .01828 L
.90451 .08012 L
F
.804 .522 .247 r
.90153 .08012 m
.90153 .01828 L
.90451 .01828 L
.90451 .08012 L
s
1 .894 .882 r
.90451 .08012 m
.90451 .01784 L
.9073 .01784 L
.9073 .08012 L
F
.804 .522 .247 r
.90451 .08012 m
.90451 .01784 L
.9073 .01784 L
.9073 .08012 L
s
1 .894 .882 r
.9073 .08012 m
.9073 .01763 L
.90939 .01763 L
.90939 .08012 L
F
.804 .522 .247 r
.9073 .08012 m
.9073 .01763 L
.90939 .01763 L
.90939 .08012 L
s
1 .894 .882 r
.90939 .08012 m
.90939 .01761 L
.9111 .01761 L
.9111 .08012 L
F
.804 .522 .247 r
.90939 .08012 m
.90939 .01761 L
.9111 .01761 L
.9111 .08012 L
s
1 .894 .882 r
.9111 .08012 m
.9111 .01733 L
.91394 .01733 L
.91394 .08012 L
F
.804 .522 .247 r
.9111 .08012 m
.9111 .01733 L
.91394 .01733 L
.91394 .08012 L
s
1 .894 .882 r
.91394 .08012 m
.91394 .01709 L
.91573 .01709 L
.91573 .08012 L
F
.804 .522 .247 r
.91394 .08012 m
.91394 .01709 L
.91573 .01709 L
.91573 .08012 L
s
1 .894 .882 r
.91573 .08012 m
.91573 .01703 L
.91859 .01703 L
.91859 .08012 L
F
.804 .522 .247 r
.91573 .08012 m
.91573 .01703 L
.91859 .01703 L
.91859 .08012 L
s
1 .894 .882 r
.91859 .08012 m
.91859 .01676 L
.92066 .01676 L
.92066 .08012 L
F
.804 .522 .247 r
.91859 .08012 m
.91859 .01676 L
.92066 .01676 L
.92066 .08012 L
s
1 .894 .882 r
.92066 .08012 m
.92066 .0167 L
.92249 .0167 L
.92249 .08012 L
F
.804 .522 .247 r
.92066 .08012 m
.92066 .0167 L
.92249 .0167 L
.92249 .08012 L
s
1 .894 .882 r
.92249 .08012 m
.92249 .01649 L
.92426 .01649 L
.92426 .08012 L
F
.804 .522 .247 r
.92249 .08012 m
.92249 .01649 L
.92426 .01649 L
.92426 .08012 L
s
1 .894 .882 r
.92426 .08012 m
.92426 .01636 L
.92581 .01636 L
.92581 .08012 L
F
.804 .522 .247 r
.92426 .08012 m
.92426 .01636 L
.92581 .01636 L
.92581 .08012 L
s
1 .894 .882 r
.92581 .08012 m
.92581 .01632 L
.92691 .01632 L
.92691 .08012 L
F
.804 .522 .247 r
.92581 .08012 m
.92581 .01632 L
.92691 .01632 L
.92691 .08012 L
s
1 .894 .882 r
.92691 .08012 m
.92691 .0162 L
.92867 .0162 L
.92867 .08012 L
F
.804 .522 .247 r
.92691 .08012 m
.92691 .0162 L
.92867 .0162 L
.92867 .08012 L
s
1 .894 .882 r
.92867 .08012 m
.92867 .01611 L
.93017 .01611 L
.93017 .08012 L
F
.804 .522 .247 r
.92867 .08012 m
.92867 .01611 L
.93017 .01611 L
.93017 .08012 L
s
1 .894 .882 r
.93017 .08012 m
.93017 .01602 L
.93201 .01602 L
.93201 .08012 L
F
.804 .522 .247 r
.93017 .08012 m
.93017 .01602 L
.93201 .01602 L
.93201 .08012 L
s
1 .894 .882 r
.93201 .08012 m
.93201 .01591 L
.93493 .01591 L
.93493 .08012 L
F
.804 .522 .247 r
.93201 .08012 m
.93201 .01591 L
.93493 .01591 L
.93493 .08012 L
s
1 .894 .882 r
.93493 .08012 m
.93493 .0157 L
.9375 .0157 L
.9375 .08012 L
F
.804 .522 .247 r
.93493 .08012 m
.93493 .0157 L
.9375 .0157 L
.9375 .08012 L
s
1 .894 .882 r
.9375 .08012 m
.9375 .01566 L
.93976 .01566 L
.93976 .08012 L
F
.804 .522 .247 r
.9375 .08012 m
.9375 .01566 L
.93976 .01566 L
.93976 .08012 L
s
1 .894 .882 r
.93976 .08012 m
.93976 .01555 L
.94142 .01555 L
.94142 .08012 L
F
.804 .522 .247 r
.93976 .08012 m
.93976 .01555 L
.94142 .01555 L
.94142 .08012 L
s
1 .894 .882 r
.94142 .08012 m
.94142 .01544 L
.94382 .01544 L
.94382 .08012 L
F
.804 .522 .247 r
.94142 .08012 m
.94142 .01544 L
.94382 .01544 L
.94382 .08012 L
s
1 .894 .882 r
.94382 .08012 m
.94382 .01538 L
.94513 .01538 L
.94513 .08012 L
F
.804 .522 .247 r
.94382 .08012 m
.94382 .01538 L
.94513 .01538 L
.94513 .08012 L
s
1 .894 .882 r
.94513 .08012 m
.94513 .01526 L
.94729 .01526 L
.94729 .08012 L
F
.804 .522 .247 r
.94513 .08012 m
.94513 .01526 L
.94729 .01526 L
.94729 .08012 L
s
1 .894 .882 r
.94729 .08012 m
.94729 .01521 L
.94888 .01521 L
.94888 .08012 L
F
.804 .522 .247 r
.94729 .08012 m
.94729 .01521 L
.94888 .01521 L
.94888 .08012 L
s
1 .894 .882 r
.94888 .08012 m
.94888 .01519 L
.95057 .01519 L
.95057 .08012 L
F
.804 .522 .247 r
.94888 .08012 m
.94888 .01519 L
.95057 .01519 L
.95057 .08012 L
s
1 .894 .882 r
.95057 .08012 m
.95057 .01514 L
.95191 .01514 L
.95191 .08012 L
F
.804 .522 .247 r
.95057 .08012 m
.95057 .01514 L
.95191 .01514 L
.95191 .08012 L
s
1 .894 .882 r
.95191 .08012 m
.95191 .01509 L
.95429 .01509 L
.95429 .08012 L
F
.804 .522 .247 r
.95191 .08012 m
.95191 .01509 L
.95429 .01509 L
.95429 .08012 L
s
1 .894 .882 r
.95429 .08012 m
.95429 .01497 L
.95678 .01497 L
.95678 .08012 L
F
.804 .522 .247 r
.95429 .08012 m
.95429 .01497 L
.95678 .01497 L
.95678 .08012 L
s
1 .894 .882 r
.95678 .08012 m
.95678 .01494 L
.95976 .01494 L
.95976 .08012 L
F
.804 .522 .247 r
.95678 .08012 m
.95678 .01494 L
.95976 .01494 L
.95976 .08012 L
s
1 .894 .882 r
.95976 .08012 m
.95976 .01487 L
.96127 .01487 L
.96127 .08012 L
F
.804 .522 .247 r
.95976 .08012 m
.95976 .01487 L
.96127 .01487 L
.96127 .08012 L
s
1 .894 .882 r
.96127 .08012 m
.96127 .01486 L
.96275 .01486 L
.96275 .08012 L
F
.804 .522 .247 r
.96127 .08012 m
.96127 .01486 L
.96275 .01486 L
.96275 .08012 L
s
1 .894 .882 r
.96275 .08012 m
.96275 .01481 L
.96539 .01481 L
.96539 .08012 L
F
.804 .522 .247 r
.96275 .08012 m
.96275 .01481 L
.96539 .01481 L
.96539 .08012 L
s
1 .894 .882 r
.96539 .08012 m
.96539 .01478 L
.9672 .01478 L
.9672 .08012 L
F
.804 .522 .247 r
.96539 .08012 m
.96539 .01478 L
.9672 .01478 L
.9672 .08012 L
s
1 .894 .882 r
.9672 .08012 m
.9672 .01476 L
.96988 .01476 L
.96988 .08012 L
F
.804 .522 .247 r
.9672 .08012 m
.9672 .01476 L
.96988 .01476 L
.96988 .08012 L
s
1 .894 .882 r
.96988 .08012 m
.96988 .01473 L
.97259 .01473 L
.97259 .08012 L
F
.804 .522 .247 r
.96988 .08012 m
.96988 .01473 L
.97259 .01473 L
.97259 .08012 L
s
1 .894 .882 r
.97259 .08012 m
.97259 .01472 L
.97459 .01472 L
.97459 .08012 L
F
.804 .522 .247 r
.97259 .08012 m
.97259 .01472 L
.97459 .01472 L
.97459 .08012 L
s
1 .894 .882 r
.97459 .08012 m
.97459 .01472 L
.97619 .01472 L
.97619 .08012 L
F
.804 .522 .247 r
.97459 .08012 m
.97459 .01472 L
.97619 .01472 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.02442 .60256 Mdot
.02655 .59993 Mdot
.0276 .59864 Mdot
.02915 .59674 Mdot
.03089 .59459 Mdot
.0324 .59275 Mdot
.03406 .59072 Mdot
.03614 .58817 Mdot
.03799 .58592 Mdot
.04003 .58344 Mdot
.04205 .58098 Mdot
.0438 .57887 Mdot
.04586 .57638 Mdot
.04888 .57274 Mdot
.051 .57019 Mdot
.05199 .56901 Mdot
.05425 .56629 Mdot
.05492 .56549 Mdot
.05816 .56162 Mdot
.06074 .55855 Mdot
.06139 .55778 Mdot
.06505 .55345 Mdot
.06655 .55168 Mdot
.06876 .54907 Mdot
.07146 .54589 Mdot
.0748 .54198 Mdot
.07535 .54133 Mdot
.07665 .53981 Mdot
.0779 .53836 Mdot
.08258 .53292 Mdot
.08371 .53161 Mdot
.08589 .52909 Mdot
.08867 .52588 Mdot
.09074 .5235 Mdot
.09137 .52277 Mdot
.09312 .52076 Mdot
.09612 .51733 Mdot
.09749 .51577 Mdot
.10031 .51255 Mdot
.10406 .50831 Mdot
.10484 .50742 Mdot
.10764 .50426 Mdot
.11059 .50094 Mdot
.11158 .49983 Mdot
.1131 .49812 Mdot
.11447 .49659 Mdot
.11678 .49401 Mdot
.11922 .49129 Mdot
.12137 .48891 Mdot
.12269 .48744 Mdot
.12438 .48557 Mdot
.12648 .48325 Mdot
.12893 .48055 Mdot
.13083 .47847 Mdot
.13442 .47453 Mdot
.13719 .47151 Mdot
.14028 .46816 Mdot
.14156 .46677 Mdot
.14363 .46453 Mdot
.14615 .46181 Mdot
.14803 .45979 Mdot
.14938 .45834 Mdot
.15013 .45754 Mdot
.15467 .45268 Mdot
.15563 .45166 Mdot
.15777 .44938 Mdot
.15906 .44801 Mdot
.16241 .44447 Mdot
.16582 .44088 Mdot
.16793 .43866 Mdot
.16855 .43801 Mdot
.17013 .43636 Mdot
.17186 .43454 Mdot
.17374 .43258 Mdot
.17658 .42963 Mdot
.17943 .42668 Mdot
.18153 .4245 Mdot
.18231 .4237 Mdot
.18459 .42135 Mdot
.18837 .41749 Mdot
.19022 .4156 Mdot
.19132 .41448 Mdot
.19258 .41319 Mdot
.19373 .41202 Mdot
.19554 .41019 Mdot
.19769 .40801 Mdot
.19834 .40735 Mdot
.20041 .40527 Mdot
.20258 .40309 Mdot
.20515 .40051 Mdot
.20682 .39884 Mdot
.20772 .39794 Mdot
.20913 .39654 Mdot
.2093 .39637 Mdot
.21308 .39262 Mdot
.21498 .39074 Mdot
.21743 .38832 Mdot
.22005 .38574 Mdot
.22122 .3846 Mdot
.2247 .3812 Mdot
.22643 .37951 Mdot
.22722 .37874 Mdot
.22968 .37635 Mdot
.23141 .37468 Mdot
.23394 .37223 Mdot
.23648 .36979 Mdot
.2375 .36881 Mdot
.23996 .36646 Mdot
.2427 .36385 Mdot
.2434 .36319 Mdot
.24552 .36117 Mdot
.24813 .3587 Mdot
.24954 .35737 Mdot
.25041 .35655 Mdot
.25227 .3548 Mdot
.25342 .35372 Mdot
.25549 .35178 Mdot
.25601 .35129 Mdot
.2579 .34953 Mdot
.25964 .34791 Mdot
.2609 .34674 Mdot
.2635 .34433 Mdot
.26493 .34301 Mdot
.26855 .33967 Mdot
.26954 .33877 Mdot
.27043 .33794 Mdot
.27271 .33586 Mdot
.27671 .33222 Mdot
.27794 .33111 Mdot
.27925 .32992 Mdot
.28346 .32612 Mdot
.28551 .32429 Mdot
.28978 .32046 Mdot
.29018 .32011 Mdot
.29294 .31766 Mdot
.2949 .31592 Mdot
.29653 .31449 Mdot
.30046 .31103 Mdot
.30162 .31001 Mdot
.30329 .30855 Mdot
.3053 .30679 Mdot
.30757 .30482 Mdot
.3083 .30419 Mdot
.31084 .302 Mdot
.31218 .30083 Mdot
.31248 .30058 Mdot
.31411 .29918 Mdot
.31869 .29526 Mdot
.31914 .29487 Mdot
.32179 .29262 Mdot
.32316 .29145 Mdot
.3244 .2904 Mdot
.32547 .2895 Mdot
.32803 .28734 Mdot
.32916 .28639 Mdot
.33102 .28483 Mdot
.33281 .28333 Mdot
.33473 .28173 Mdot
.33661 .28017 Mdot
.33792 .27908 Mdot
.33999 .27737 Mdot
.34189 .2758 Mdot
.34414 .27396 Mdot
.34587 .27254 Mdot
.34694 .27167 Mdot
.35057 .26871 Mdot
.35279 .26691 Mdot
.3535 .26634 Mdot
.35585 .26444 Mdot
.35817 .26258 Mdot
.35944 .26155 Mdot
.36005 .26107 Mdot
.36194 .25956 Mdot
.36548 .25675 Mdot
.36659 .25587 Mdot
.36698 .25556 Mdot
.36884 .25409 Mdot
.37002 .25316 Mdot
.37396 .25007 Mdot
.37508 .2492 Mdot
.37587 .24858 Mdot
.37686 .24781 Mdot
.37941 .24583 Mdot
.38205 .24379 Mdot
.38261 .24336 Mdot
.38518 .24138 Mdot
.38696 .24002 Mdot
.38751 .2396 Mdot
.38973 .2379 Mdot
.39138 .23665 Mdot
.3931 .23535 Mdot
.39613 .23306 Mdot
.39695 .23244 Mdot
.39805 .23162 Mdot
.39967 .23041 Mdot
.40257 .22824 Mdot
.40337 .22765 Mdot
.40566 .22594 Mdot
.40818 .22408 Mdot
.41013 .22265 Mdot
.4116 .22157 Mdot
.41386 .21992 Mdot
.41447 .21948 Mdot
.41681 .21777 Mdot
.41867 .21642 Mdot
.42026 .21528 Mdot
.42162 .21429 Mdot
.42395 .21262 Mdot
.42534 .21162 Mdot
.42577 .21132 Mdot
.42837 .20947 Mdot
.43245 .20657 Mdot
.43263 .20645 Mdot
.4341 .20542 Mdot
.43587 .20417 Mdot
.4392 .20184 Mdot
.44073 .20078 Mdot
.44232 .19967 Mdot
.44494 .19786 Mdot
.44659 .19673 Mdot
.45048 .19407 Mdot
.45222 .19288 Mdot
.45333 .19212 Mdot
.45585 .19042 Mdot
.45698 .18966 Mdot
.45953 .18794 Mdot
.46232 .18607 Mdot
.46352 .18528 Mdot
.46401 .18495 Mdot
.46591 .18369 Mdot
.46666 .1832 Mdot
.46926 .18148 Mdot
.47037 .18075 Mdot
.47348 .17871 Mdot
.47457 .178 Mdot
.47681 .17655 Mdot
.47742 .17615 Mdot
.47971 .17467 Mdot
.4823 .17301 Mdot
.48507 .17124 Mdot
.48588 .17072 Mdot
.48809 .16932 Mdot
.48855 .16903 Mdot
.49101 .16747 Mdot
.49174 .16702 Mdot
.49412 .16552 Mdot
.49486 .16506 Mdot
.49708 .16368 Mdot
.50029 .16169 Mdot
.50125 .1611 Mdot
.50287 .1601 Mdot
.50572 .15835 Mdot
.50915 .15627 Mdot
.51054 .15542 Mdot
.51089 .15521 Mdot
.51382 .15345 Mdot
.51587 .15222 Mdot
.51752 .15124 Mdot
.51904 .15034 Mdot
.52332 .14781 Mdot
.52441 .14717 Mdot
.52525 .14667 Mdot
.52672 .14581 Mdot
.5286 .14472 Mdot
.52987 .14398 Mdot
.53029 .14374 Mdot
.53227 .1426 Mdot
.53358 .14184 Mdot
.53609 .1404 Mdot
.5367 .14006 Mdot
.53901 .13874 Mdot
.53921 .13863 Mdot
.54242 .13682 Mdot
.54468 .13555 Mdot
.54657 .13449 Mdot
.54841 .13347 Mdot
.54928 .13299 Mdot
.55203 .13147 Mdot
.55445 .13014 Mdot
.55482 .12993 Mdot
.55773 .12835 Mdot
.55999 .12713 Mdot
.56138 .12637 Mdot
.56242 .12581 Mdot
.56392 .12501 Mdot
.56854 .12255 Mdot
.56948 .12206 Mdot
.57119 .12116 Mdot
.57246 .12049 Mdot
.57523 .11904 Mdot
.57598 .11866 Mdot
.57752 .11786 Mdot
.58039 .11638 Mdot
.58197 .11556 Mdot
.58297 .11506 Mdot
.58545 .11379 Mdot
.58672 .11315 Mdot
.58913 .11194 Mdot
.59107 .11096 Mdot
.59282 .11009 Mdot
.59516 .10893 Mdot
.5967 .10817 Mdot
.60002 .10654 Mdot
.601 .10607 Mdot
.60348 .10486 Mdot
.60492 .10417 Mdot
.60711 .10311 Mdot
.60929 .10207 Mdot
.6119 .10084 Mdot
.61288 .10037 Mdot
.61483 .09946 Mdot
.61615 .09884 Mdot
.61763 .09814 Mdot
.62097 .0966 Mdot
.62347 .09545 Mdot
.62579 .09439 Mdot
.62643 .0941 Mdot
.62884 .09301 Mdot
.63137 .09187 Mdot
.6336 .09088 Mdot
.63506 .09023 Mdot
.63556 .09001 Mdot
.63682 .08945 Mdot
.63928 .08837 Mdot
.64062 .08779 Mdot
.64261 .08693 Mdot
.6431 .08671 Mdot
.64453 .0861 Mdot
.64694 .08507 Mdot
.64808 .08458 Mdot
.64898 .08419 Mdot
.65075 .08344 Mdot
.65262 .08266 Mdot
.65377 .08217 Mdot
.6541 .08204 Mdot
.65578 .08134 Mdot
.65818 .08034 Mdot
.66094 .07921 Mdot
.66145 .079 Mdot
.66295 .07839 Mdot
.66379 .07805 Mdot
.66561 .07731 Mdot
.66844 .07618 Mdot
.67067 .07529 Mdot
.67274 .07447 Mdot
.67491 .07362 Mdot
.6782 .07234 Mdot
.68194 .0709 Mdot
.68364 .07026 Mdot
.68448 .06994 Mdot
.68635 .06923 Mdot
.68916 .06818 Mdot
.68983 .06793 Mdot
.69193 .06715 Mdot
.6925 .06694 Mdot
.69447 .06622 Mdot
.69536 .06589 Mdot
.69641 .06551 Mdot
.69936 .06444 Mdot
.70108 .06383 Mdot
.70454 .0626 Mdot
.70515 .06239 Mdot
.70659 .06188 Mdot
.70899 .06105 Mdot
.71093 .06038 Mdot
.71351 .05949 Mdot
.71482 .05905 Mdot
.71678 .05839 Mdot
.71907 .05762 Mdot
.72092 .057 Mdot
.72213 .0566 Mdot
.72267 .05642 Mdot
.7249 .05569 Mdot
.72669 .05511 Mdot
.72867 .05447 Mdot
.72994 .05407 Mdot
.73232 .05331 Mdot
.73499 .05247 Mdot
.73684 .05189 Mdot
.73838 .05141 Mdot
.74034 .05081 Mdot
.74359 .04983 Mdot
.74479 .04946 Mdot
.74848 .04836 Mdot
.74917 .04816 Mdot
.75044 .04779 Mdot
.75151 .04747 Mdot
.75291 .04707 Mdot
.75605 .04616 Mdot
.75793 .04563 Mdot
.76013 .04501 Mdot
.7621 .04446 Mdot
.76224 .04442 Mdot
.76626 .04332 Mdot
.76806 .04283 Mdot
.76881 .04262 Mdot
.76971 .04238 Mdot
.7742 .04119 Mdot
.77483 .04103 Mdot
.77707 .04045 Mdot
.78111 .03941 Mdot
.78253 .03905 Mdot
.7855 .03831 Mdot
.78872 .03752 Mdot
.78902 .03745 Mdot
.79077 .03703 Mdot
.79266 .03657 Mdot
.79359 .03635 Mdot
.7952 .03597 Mdot
.79693 .03557 Mdot
.79732 .03548 Mdot
.8017 .03447 Mdot
.8021 .03438 Mdot
.80453 .03384 Mdot
.80687 .03332 Mdot
.81144 .03233 Mdot
.8137 .03185 Mdot
.8149 .0316 Mdot
.81598 .03137 Mdot
.81805 .03094 Mdot
.82215 .03011 Mdot
.82427 .02969 Mdot
.82497 .02956 Mdot
.82763 .02904 Mdot
.82919 .02874 Mdot
.83201 .02821 Mdot
.83306 .02801 Mdot
.83385 .02786 Mdot
.83547 .02757 Mdot
.83789 .02713 Mdot
.8424 .02633 Mdot
.8426 .0263 Mdot
.84475 .02593 Mdot
.84667 .0256 Mdot
.85016 .02502 Mdot
.85106 .02488 Mdot
.85339 .0245 Mdot
.85436 .02435 Mdot
.85696 .02394 Mdot
.85843 .02371 Mdot
.86078 .02336 Mdot
.86277 .02306 Mdot
.86451 .02281 Mdot
.86618 .02257 Mdot
.86875 .02221 Mdot
.87072 .02193 Mdot
.87245 .0217 Mdot
.87407 .02148 Mdot
.8767 .02114 Mdot
.87804 .02097 Mdot
.87941 .02079 Mdot
.88134 .02055 Mdot
.88317 .02033 Mdot
.88494 .02012 Mdot
.88583 .02001 Mdot
.88781 .01978 Mdot
.89094 .01943 Mdot
.89224 .01929 Mdot
.89369 .01913 Mdot
.89555 .01893 Mdot
.89703 .01878 Mdot
.8983 .01865 Mdot
.89947 .01854 Mdot
.90051 .01843 Mdot
.90208 .01828 Mdot
.90678 .01784 Mdot
.90918 .01763 Mdot
.90944 .01761 Mdot
.9127 .01733 Mdot
.91571 .01709 Mdot
.91651 .01703 Mdot
.92011 .01676 Mdot
.92095 .0167 Mdot
.92383 .01649 Mdot
.92577 .01636 Mdot
.92639 .01632 Mdot
.92833 .0162 Mdot
.92985 .01611 Mdot
.93139 .01602 Mdot
.93324 .01591 Mdot
.93714 .0157 Mdot
.93808 .01566 Mdot
.94025 .01555 Mdot
.94285 .01544 Mdot
.9442 .01538 Mdot
.9471 .01526 Mdot
.94852 .01521 Mdot
.94927 .01519 Mdot
.95072 .01514 Mdot
.95214 .01509 Mdot
.95647 .01497 Mdot
.95739 .01494 Mdot
.96058 .01487 Mdot
.96143 .01486 Mdot
.96435 .01481 Mdot
.96625 .01478 Mdot
.96824 .01476 Mdot
.97083 .01473 Mdot
.97385 .01472 Mdot
.9761 .01472 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00944961) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.99862) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000@0n_3V0`0000040?[`iP<000001@3jl>H3000000@0n_3V0`0000030?[`iPD0
0000o`3jl>JS0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000060?[`iP8000001@3j
l>H2000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3j
l>H200000?l0n_3VYP3jl>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P000003
0?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000006`3jl>H2000000`0n_3V0P00
00050?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00030?[`iP800000o`3jl>JU0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P000000
1P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP800000
00@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000=0?[`iP80
00002P3jl>H4000000<0n_3V100000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000@0n_3V0P00003o0?[`iZ@0n_3V0@3oool00200n_3V0P0000020?[`iP800000
0`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H20000
00@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02
000001P0n_3V00<000000?[`iP3jl>H00P0000090?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP000000000000<0n_3V0`0000030?[`iP@000001P3jl>H200000?l0n_3VX`3jl>H1
0?ooo`00803jl>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V100000000`3j
l>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P0000050?[`
iP<0000000<0n_3V0000000000001`00000I0?[`iP@000002P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00D0n_3V0P0000000`3jl>H000000000003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP80
0000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000`0n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0
n_3V0P0000040?[`iP80000000<0n_3V000000000000o`3jl>JS0?[`iP40oooo000O0?[`iPH00000
103jl>H2000002l0n_3V1@00000W0?[`iPD000002P3jl>H3000000@0n_3V0`0000040?[`iP<00000
1@3jl>H3000000<0n_3V0`00003o0?[`iZ@0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40
oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200n_3V1P0000001@3jl>H000000000
00000000n_3V00<000000P3jl>H3000000<0n_3V100000030?[`iP80000000@0n_3V000000000000
n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P00003o0?[`i/T0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V00@000000?[`iP000000
00000`3jl>H01@000000n_3V000000000000n_3V00<000000P3jl>H2000000@0n_3V0P0000020?[`
iP8000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000000000000`3jl>H20000
0?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP80
0000103jl>H2000000D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000020?[`iP80
00000`3jl>H200000300n_3V0P0000000`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V
0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V1P0000000`3jl>H00000
000000020?[`iP8000000P3jl>H2000000D0n_3V1@0000030?[`iP8000008P3jl>H5000000T0n_3V
0P0000000`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0
n_3V0000000000000P3jl>H2000000@0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V
0`0000020?[`iP<0000000<0n_3V0000003jl>H0103jl>H2000000<0n_3V0P00000`0?[`iP@00000
o`3jl>K?0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080n_3V1@0000030?[`iP@000000`3j
l>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3jl>H4000000@0n_3V0P00
000`0?[`iP800000o`3jl>KA0?[`iP40oooo000R0?[`iP8000002`3jl>H200000280n_3V0P00000a
0?[`iP800000o`3jl>K@0?[`iP40oooo000P0?[`iPH000002@3jl>H200000200n_3V1000000b0?[`
iP<00000o`3jl>K>0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP080000
00030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP040000003jl>H000000?[`
iP8000000P3jl>H00`000000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0
000000<0n_3V0000000000000P0000001@3jl>H000000?[`iP000000n_3V00<000000P3jl>H00`00
0000n_3V0000000I0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H60000
00<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`000000103jl>H00000000000000008
0?[`iP@0000000<0n_3V0000000000000P3jl>H400000080n_3V1@0000001`3jl>H0000000000000
0000n_3V0000003jl>H00`00000H0?[`iP<00000103jl>H2000000D0n_3V0`0000040?[`iP<00000
0`3jl>H3000000D0n_3V100000030?[`iP@000000P3jl>H3000000D0n_3V0`0000030?[`iPH00000
J@3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000@0n_3V0000000000000000
0P3jl>H2000000030?[`iP000000000000T0n_3V1@0000090?[`iP030000003jl>H0n_3V00800000
g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000
003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`
iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V
008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000103jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000040?[`iP8000001@3jl>H20000
00D0n_3V0P0000050?[`iP8000000`3jl>H2000000030?[`iP000000000000@0n_3V0P00001[0?[`
iP40oooo000R0?[`iP<00000:`3jl>H200000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080
n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000
003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP020000
01P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000D0n_3V0P0000000`3jl>H0000000000004000000030?[`iP0000000000
00@000001@3jl>H200000080n_3V0P0000000`3jl>H00000000000040?[`iP800000J`3jl>H10?oo
o`008P3jl>H3000001X0n_3V1@00000<0?[`iP800000g03jl>H4000000<0n_3V1@0000020?[`iP80
00001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000030?[`iP000000000000X0n_3V0P0000001@3jl>H00000000000000000n_3V
008000000P3jl>H200000080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`
iPD000002P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000`3jl>H4000000040?[`iP000000n_3V0?[`iP8000000P3jl>H0
0`000000n_3V0?[`iP02000000@0n_3V100000020?[`iP80000000<0n_3V000000000000103jl>H2
000006/0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000X0?[`iP<00000g@3jl>H20000
00030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P000006
0?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P000000
0`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3j
l>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0
n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H010000000n_3V0000000000030?[`iP040000
003jl>H00000000000<0n_3V0P0000000`3jl>H00000000000020?[`iP@000001@3jl>H2000006/0
n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000Y0?[`iP800000g03jl>H200000003
0?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`
iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000/0n_3V0`0000000`3j
l>H00000000000020?[`iP@000000P3jl>H3000000030?[`iP000000000000L000006@3jl>H20000
00030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP00000000000080n_3V00@000000?[`iP00000000000`3jl>H0
10000000n_3V0000000000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000L0n_3V0P00
001[0?[`iP40oooo001=0?[`iP030000003jl>H0n_3V00800000g03jl>H2000000030?[`iP000000
00000100n_3V0P00000<0?[`iP8000008P3jl>H200000080n_3V0P00000^0?[`iP80000000<0n_3V
0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000000`3jl>H3000000@0n_3V0`0000030?[`iP80000000<0n_3V
0000000000000`3jl>H2000000@0n_3V1000001[0?[`iP40oooo001>0?[`iP<00000g03jl>H50000
0140n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000I0?[`iP<0000000<0n_3V0000
000000000P00000^0?[`iP<000002`3jl>H3000000@0n_3V0`0000040?[`iP<000001@3jl>H20000
00D0n_3V0P0000040?[`iP<000001@3jl>H3000000@0n_3V0P00001[0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P000000
0`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`
iP050000003jl>H000000?[`iP0000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003j
l>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P000000
103jl>H000000?[`iP0000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H0
5`3jl>H300000=`0n_3V100000040?[`iP/00000103jl>H300000080n_3V1P0000030?[`iP<00000
0P3jl>H600000080n_3V100000020?[`iP<0000000<0n_3V0000000000001P00000K0?[`iP<00000
103jl>H3000000@0n_3V0`00002j0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@00
00001@3jl>H00000000000000000n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3jl>H00000
0000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V
00@000000?[`iP3jl>H0n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2
000000/0n_3V1@0000090?[`iP030000003jl>H0n_3V008000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000002i0?[`iP40oooo000R0?[`iP<00000:03jl>H20000
00030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`
iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`
iP80000000<0n_3V0000000000000`3jl>H4000001`0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP00000000000;T0n_3V0@3oool00280n_3V0`0000090?[`iP03
0000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H4000000<0
n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0
n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP@000003@3jl>H50000
00`0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0;T0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0n_3V00000000
0000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003j
l>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000I0?[`iP030000003jl>H0
n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000002i
0?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H2000000030?[`iP000000
00000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP000000
00000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00
00030?[`iPD000006@3jl>H4000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V000000000000^@3jl>H10?ooo`00C@3jl>H2000000030?[`iP00000000000=`0n_3V0P000000
0`3jl>H000000000000@0?[`iP800000303jl>H2000003P0n_3V0P0000050?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP00000000000;T0n_3V0@3oool004h0n_3V0`00003L0?[`
iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H200000300n_3V1@0000030?[`
iP<00000103jl>H300000;X0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo000M0?[`iR<0oooP0P0000150?ooh0800000103oon02000000@0oooP0P000014
0?ooh0D00000@`3oon0500000080oooP0P0000040?ooh0800000A03oon04000004@0oooP10000003
0?ooh0800000103oon02000004D0oooP0P00000W0?ooh1h0n_3V0@3oool001d0n_3V8P3oon001000
0000oooP0?ooh00000130?ooh0040000003oon00oooP000000P0oooP00@000000?ooh03oon000000
A@3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00L0oooP00@000000?ooh03oon00
0000@`3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00T0oooP00@000000?ooh03o
on000000@`3oon0010000000oooP0?ooh000000V0?ooh1h0n_3V0@3oool001d0n_3V8P3oon001000
0000oooP0?ooh00000130?ooh0040000003oon00oooP000000/0oooP00<000000?ooh03oon00@`3o
on000`000000oooP0?ooh0150?ooh0030000003oon00oooP00X0oooP00<000000?ooh03oon00@P3o
on000`000000oooP0?ooh0150?ooh0030000003oon00oooP00/0oooP00<000000?ooh03oon00@`3o
on000`000000oooP0?ooh00U0?ooh1h0n_3V0@3oool001d0n_3V8P3oon0010000000oooP0?ooh000
00130?ooh0040000003oon00oooP000000T0oooP0P0000160?ooh0030000003oon00oooP04D0oooP
00<000000?ooh03oon00203oon02000004H0oooP00<000000?ooh03oon00A@3oon000`000000oooP
0?ooh0080?ooh0800000A`3oon000`000000oooP0?ooh00T0?ooh1h0n_3V0@3oool001d0n_3V8P3o
on0010000000oooP0?ooh00000130?ooh0040000003oon00oooP000000T0oooP00<000000?ooh03o
on00A@3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00P0oooP00<000000?ooh03o
on00@`3oon0010000000oooP0?ooh00000140?ooh0040000003oon00oooP000000T0oooP00<00000
0?ooh03oon00@`3oon0010000000oooP0?ooh000000V0?ooh1h0n_3V0@3oool001d0n_3V8`3oon02
000004D0oooP0P00000:0?ooh0<00000A03oon02000004H0oooP0P00000:0?ooh0<00000A03oon02
000004H0oooP0P00000:0?ooh0<00000A03oon02000002L0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3V603oon3o00000>X000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
0000003oon00oooP04X0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh003
0000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh003
0000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh<P0oooP4`00000;0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP^@3oon0S0000
00X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`00003o0?ooh;00
oooP1`0000000`3oon00000000000007000001X0003o00<000000?ooh03oon001P3oon03000001/0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPY`3oon0B000000P0003o
6P00000;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP0?l0oooPX03oon0@000000T0003o400000080<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo
2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh9X0oooP3000000:0000o`L0000000L0cHDo000000000000cHDo0?oTh@3=QCl0onCQ00L0
cHDo00<0onCQ0<f5?`3=QCl02@3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`/0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2D0?ooh0X0
000020000?l:000000030<f5?`3oi>40cHDo00P0cHDo00<0onCQ0<f5?`3oi>401`3=QCl00`3oi>40
cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo2`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh8l0oooP2@0000060000o`X0
00000`3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo00L0cHDo00<0onCQ0<f5
?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo2`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?oo
h8X0oooP1`0000070000o`T000002P3=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0
cHDo00L0cHDo00<0onCQ0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0
cHDo0?oTh@H0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh03o0?ooh8H0oooP1P0000050000o`X0000000<0cHDo0?oTh@3=QCl03@3=QCl0
103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo00L0cHDo00<0onCQ0<f5?`3oi>401`3=
QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo2`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh840oooP1`00
00040000o`X0000000<0cHDo0?oTh@3=QCl00`3=QCl00`3oi>40cHDo0<f5?`0<0<f5?`040?oTh@3=
QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl01`3=QCl00`3oi>40cHDo0?oTh@070<f5?`030?oT
h@3=QCl0cHDo00T0cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl;0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPOP3oon06000000@0003o
200000000`3=QCl0onCQ0<f5?`040<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0
303=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo00L0cHDo00<0onCQ0<f5?`3o
i>401`3=QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo2`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh7X0
oooP1P0000040000o`L000001P3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080
cHDo00<0onCQ0<f5?`3=QCl0303=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo
00L0cHDo00<0onCQ0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo
0?oTh@H0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh7L0oooP1@0000040000o`L000000P3=QCl00`3oi>40cHDo0<f5?`050<f5
?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0<0<f5
?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl01`3=QCl00`3oi>40cHDo0?oTh@07
0<f5?`030?oTh@3=QCl0cHDo00T0cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl;0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPL`3oon05
000000@0003o1P0000070<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl0
0`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00`0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=
QCl00`3oi>40cHDo0<f5?`070<f5?`030?oTh@3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl02@3=
QCl0103oi>40cHDo0<f5?`3oi>460<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1^0?ooh0H0000010000?l7000000X0cHDo00<0
onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0
onCQ0<f5?`3=QCl0303=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo00L0cHDo
00<0onCQ0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo0?oTh@H0
cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh03o0?ooh6X0oooP1P0000040000o`H00000103=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oT
h@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oT
h@3=QCl0cHDo00`0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`070<f5?`03
0?oTh@3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl02@3=QCl0103oi>40cHDo0<f5?`3oi>460<f5
?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on00o`3oon1X0?ooh0@0000010000?l7000000030?oTh@3=QCl0cHDo00@0cHDo00<0onCQ0<f5?`3=
QCl0203=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=
QCl00P3=QCl00`3oi>40cHDo0<f5?`0<0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5
?`3=QCl01`3=QCl00`3oi>40cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo00T0cHDo00@0onCQ0<f5
?`3=QCl0onCQ1P3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0<00000o`3oon1T0?ooh0@0000010000?l7000000@0cHDo00<0onCQ0<f5?`3=QCl0103=QCl00`3o
i>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3o
i>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00`0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl0
0`3oi>40cHDo0<f5?`070<f5?`030?oTh@3=QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl02@3=QCl0
103oi>40cHDo0<f5?`3oi>460<f5?`T0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh03o0?ooh640oooP100000030000o`L00000203=QCl00`3oi>40cHDo0<f5?`04
0<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`03
0<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0303=QCl0103oi>40cHDo0<f5?`3o
i>420<f5?`030?oTh@3=QCl0cHDo00L0cHDo00<0onCQ0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5
?`090<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5h0oooP100000030000o`H00000303=
QCl00`3oi>40cHDo0<f5?`040<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5?`3=QCl01@3=
QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5?`3=QCl0303=
QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo00L0cHDo00<0onCQ0<f5?`3oi>40
1`3=QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo2`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5/0oooP
100000030000o`H000003`3=QCl00`3oi>40cHDo0<f5?`040<f5?`030?oTh@3=QCl0cHDo00P0cHDo
00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo
00<0onCQ0<f5?`3=QCl0303=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo00L0
cHDo00<0onCQ0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo0?oT
h@H0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh5P0oooP1@0000020000o`H000000P3=QCl00`3oi>40cHDo0<f5?`0=0<f5?`03
0?oTh@3=QCl0cHDo00@0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`050<f5?`03
0?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0<0<f5?`04
0?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl01`3=QCl00`3oi>40cHDo0?oTh@070<f5
?`030?oTh@3=QCl0cHDo00T0cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl;0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPE@3oon050000
00<0003o1@0000000`3=QCl0onCQ0<f5?`020<f5?`030?oTh@3=QCl0cHDo00d0cHDo00<0onCQ0<f5
?`3=QCl0103=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo00D0cHDo00<0onCQ0<f5
?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo00`0cHDo00@0onCQ0<f5
?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`070<f5?`030?oTh@3=QCl0onCQ00L0cHDo00<0onCQ
0<f5?`3=QCl02@3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`/0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1C0?ooh0@000000`000?l5
000000@0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@0?0<f5?`030?oTh@3=QCl0cHDo00@0cHDo00<0
onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0
onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0<0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo
00<0onCQ0<f5?`3=QCl01`3=QCl00`3oi>40cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo00T0cHDo
00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP0?l0oooPD03oon04000000<0003o1@0000070<f5?`050?oT
h@3=QCl0cHDo0<f5?`3oi>403`3=QCl00`3oi>40cHDo0<f5?`040<f5?`030?oTh@3=QCl0cHDo00P0
cHDo00<0onCQ0<f5?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080
cHDo00<0onCQ0<f5?`3=QCl0303=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo
00L0cHDo00<0onCQ0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo
0?oTh@H0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh4h0oooP0`0000030000o`D000002P3=QCl01@3oi>40cHDo0<f5?`3=QCl0
onCQ00l0cHDo00<0onCQ0<f5?`3=QCl0103=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0
cHDo00D0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0
cHDo00`0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`070<f5?`030?oTh@3=
QCl0onCQ00L0cHDo00<0onCQ0<f5?`3=QCl02@3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`/0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3o
on1:0?ooh0D000000P000?l4000000030?oTh@3=QCl0cHDo00/0cHDo00D0onCQ0<f5?`3=QCl0cHDo
0?oTh@0?0<f5?`030?oTh@3=QCl0cHDo00@0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3oi>40cHDo
0<f5?`050<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3oi>40cHDo
0<f5?`0<0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl01`3=QCl00`3oi>40
cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo00T0cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=QCl;0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0
oooPB03oon04000000<0003o100000020<f5?`030?oTh@3=QCl0cHDo00/0cHDo00D0onCQ0<f5?`3=
QCl0cHDo0?oTh@0?0<f5?`030?oTh@3=QCl0cHDo00@0cHDo00<0onCQ0<f5?`3=QCl0203=QCl00`3o
i>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl00P3=QCl00`3o
i>40cHDo0<f5?`0<0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=QCl01`3=QCl0
0`3oi>40cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo00T0cHDo00@0onCQ0<f5?`3=QCl0onCQ1P3=
QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPAP3oon0400000080003o1@0000001@3=QCl0onCQ0<f5?`3=QCl0onCQ00d0cHDo00D0
onCQ0<f5?`3=QCl0cHDo0?oTh@0?0<f5?`030?oTh@3=QCl0cHDo00@0cHDo00<0onCQ0<f5?`3=QCl0
203=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ0<f5?`3=QCl0
0P3=QCl00`3oi>40cHDo0<f5?`0<0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0onCQ0<f5?`3=
QCl01`3=QCl00`3oi>40cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo00T0cHDo00@0onCQ0<f5?`3=
QCl0onCQ1P3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP0?l0oooP@`3oon04000000<0003o100000040<f5?`040?oTh@3=QCl0cHDo0?oT
h@d0cHDo00D0onCQ0<f5?`3=QCl0cHDo0?oTh@0?0<f5?`030?oTh@3=QCl0cHDo00@0cHDo00<0onCQ
0<f5?`3=QCl0203=QCl00`3oi>40cHDo0<f5?`050<f5?`030?oTh@3=QCl0cHDo00<0cHDo00<0onCQ
0<f5?`3=QCl00P3=QCl00`3oi>40cHDo0<f5?`0<0<f5?`040?oTh@3=QCl0cHDo0?oTh@80cHDo00<0
onCQ0<f5?`3=QCl01`3=QCl00`3oi>40cHDo0?oTh@070<f5?`030?oTh@3=QCl0cHDo00T0cHDo00@0
onCQ0<f5?`3=QCl0onCQ1P3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H>0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh400oooP100000030000o`<0000000@0
onCQ0<f5?`3=QCl0onCQ103=QCl0103oi>40cHDo0<f5?`3oi>4=0<f5?`050?oTh@3=QCl0cHDo0<f5
?`3oi>403`3=QCl00`3oi>40cHDo0<f5?`040<f5?`030?oTh@3=QCl0cHDo00P0cHDo00<0onCQ0<f5
?`3=QCl01@3=QCl00`3oi>40cHDo0<f5?`030<f5?`030?oTh@3=QCl0cHDo0080cHDo00<0onCQ0<f5
?`3=QCl0303=QCl0103oi>40cHDo0<f5?`3oi>420<f5?`030?oTh@3=QCl0cHDo00L0cHDo00<0onCQ
0<f5?`3oi>401`3=QCl00`3oi>40cHDo0<f5?`090<f5?`040?oTh@3=QCl0cHDo0?oTh@H0cHDo2`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh000
00070?ooh0030000003oon00oooP0?l0oooP?P3oon0400000080003o1@0000001@3=QCl0onCQ0<f5
?`3=QCl0onCQ00@0cHDo00@0onCQ0<f5?`3=QCl0onCQ3@3=QCl01@3oi>40cHDo0<f5?`3=QCl0onCQ
00l0cHDo00<0onCQ0<f5?`3=QCl0103=QCl00`3oi>40cHDo0<f5?`080<f5?`030?oTh@3=QCl0cHDo
00D0cHDo00<0onCQ0<f5?`3=QCl00`3=QCl00`3oi>40cHDo0<f5?`020<f5?`030?oTh@3=QCl0cHDo
00`0cHDo00@0onCQ0<f5?`3=QCl0onCQ0P3=QCl00`3oi>40cHDo0<f5?`070<f5?`030?oTh@3=QCl0
onCQ00L0cHDo00<0onCQ0<f5?`3=QCl02@3=QCl0103oi>40cHDo0<f5?`3oi>460<f5?`/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3o
on04000000P0oooPo`00000f000000<0003oV@0000080?ooh0@000006`3oon0N0?[`iP40oooo000M
0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:
00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:
00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0K03>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX02P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00l0<j7:00<0[MSV03>QbP0cXLX04@0cXLX40000
0080003o1@00002R0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh004
0000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0
<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0
<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
6`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00X0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0?03>QbP030:gHiP0cXLX0<j7:00l0<j7:100000020000o`D00000
Y03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0
200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H06`0cXLX00`2]f>H0<j7:03>QbP0803>Q
bP030:gHiP0cXLX0<j7:00X0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0?03>Q
bP030:gHiP0cXLX0<j7:00d0<j7:100000020000o`@00000Y`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0
<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>Q
bP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0K03>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX02P0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00l0<j7:00<0[MSV03>QbP0cXLX02P0cXLX500000080003o1000
002Y0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0
[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
7@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0
<j7:03>QbP0:03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX03`0cXLX00`2]f>H0
<j7:03>QbP0803>QbP@000000`000?l300000:`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gH
iP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100
<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H06`0cXLX0
0`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00X0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0?03>QbP030:gHiP0cXLX0<j7:00H0<j7:100000020000o`@00000[P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0K03>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX0
2P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00l0<j7:00<0[MSV03>QbP0cXLX0
100cXLX400000080003o1000002`0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gH
iP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gH
iP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>Q
bP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0:03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX03`0cXLX0102]f>H0<j7:03>QbP0cXLX500000080003o0`00002c0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX0
0`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX0
0`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0:03>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX03`0cXLX00`2]f>H0<j7:03>QbP0400000080003o
0`00002e0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:
00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]
f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]
f>H0<j7:03>QbP0:03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX03`0cXLX00`2]
f>H000000000000200000080003o0P00002h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0
<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>Q
bP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>Q
bP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0<j7:00<0
[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0:03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX03P0cXLX400000080003o0`00002i0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>Q
bP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>Q
bP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0
<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0:03>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX0300cXLX400000080003o0P00002l0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX0
5@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0
<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0
<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0:03>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX02P0cXLX400000080003o0`00002m0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX0
0`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX0
0`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0:03>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01`0cXLX500000080003o0P0000300?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0
500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0:03>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX500000080003o0`0000310?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0
[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>Q
bP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H06`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00X0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0303>QbPD000000P000?l200000<80oooP0`00
000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0
[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0
[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0K03>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX02P0cXLX00`2]f>H0
<j7:03>QbP0203>QbP040:gHiP0cXLX0<j7:03>QbPD000000P000?l300000<D0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>Q
bP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H06`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:00X0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0400000080003o0P0000380?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0c
XLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500c
XLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:
03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0:03>QbP03
0:gHiP0cXLX0<j7:0080<j7:1@0000020000o`800000bP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:
00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]
f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0c
XLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0c
XLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0K
03>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX02P0cXLX0102]f>H0<j7:03>QbP0c
XLX400000080003o0`00003;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP03
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0c
XLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0c
XLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0c
XLX0200cXLX00`2]f>H0<j7:03>QbP0:03>QbP030:gHiP000000000000<000000P000?l200000<h0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0
<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0M03>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H06`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0
<j7:00T0<j7:1@0000020000o`<00000c`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX0
0`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
0`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0K03>QbP030:gH
iP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX0200cXLX400000080003o0`00003A0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0
500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0703>Q
bP<000000P000?l300000=<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>Q
bP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H06`0cXLX00`2]f>H0<j7:03>Q
bP0803>QbP030:gHiP0cXLX0<j7:00@0<j7:100000020000o`<00000e@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0
[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0
[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0K03>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00`0cXLX300000080
003o0P00003H0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0
<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX0
0`2]f>H0<j7:03>QbP0400000080003o0`00003I0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]
f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@
03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP03
03>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0<j7:
00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:0000000200000080003o0`00003K0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0
500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX0200cXLX4000000040000o`0000000000
00000=d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX0
0`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H06`0cXLX00`2]f>H0<j7:03>QbP0603>QbP@00000
0P000?l300000=h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0
200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H06`0cXLX00`2]f>H0<j7:03>QbP0503>Q
bP<000000P000?l300000>00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP0`0000090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>Q
bP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV01d0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0K03>QbP030:gHiP0cXLX0<j7:00@0<j7:0P00
00020000o`<00000h03oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0
[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
7@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0<j7:00<0[MSV03>QbP0cXLX00P0cXLX300000004
0000o`000000000000000>@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>Q
bP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H06`0cXLX00`2]f>H0<j7:03>Q
bP0300000080003o0P00003V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP03
03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0c
XLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0c
XLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0c
XLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01/0<j7:00@0[MSV03>QbP00
000000000P000?l300000>L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>Q
bP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H06`0cXLX3000000040000o`00
0000000000000>T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0
200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H06@0cXLX300000080003o0`00003Z0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>Q
bP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV01L0<j7:0`0000020000o`<00000k03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0
[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0
[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0F03>QbP8000000P000?l400000>d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gH
iP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100
<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0500cXLX3
000000040000o`000000000000000?00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0
<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0
[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H04P0cXLX300000080
003o0`00003a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0
<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0140<j7:0`0000000`000?l0000000000002
00000?80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX0
0`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03`0cXLX300000080003o0`00003d0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0
500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV00h0<j7:0P0000020000o`<00000mP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0
<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>Q
bP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0<03>QbP<0000000<0003o0000000000000P00003g0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>Q
bP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>Q
bP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00/0
<j7:0P0000020000o`800000nP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0
<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0
<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0903>QbP<0000000@0003o
0000000000000000n`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03
000000T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0
[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
7@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00L0<j7:0`0000020000o`800000n`3oon03000001/0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX0
5@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0
<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0
<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV00H0<j7:0P0000020000o`<00000oP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>Q
bP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX0
0`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
0`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV01d0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0503>QbP800000
00<0003o0000000000000P00003o0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gH
iP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gH
iP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H07@0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00@0<j7:00<000000000
o`000?l00`00003o0?ooh080oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>Q
bP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0M03>QbP060:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0`00000010000?l00000
00000000003o0?ooh0@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:
00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0c
XLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0c
XLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0M03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0000020000o`<00000o`3oon05
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:
03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV
03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV
03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV
03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV
03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0c
XLX00`2]f>H0<j7:03>QbP03000000030000o`000000000000800000o`3oon060?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0c
XLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500c
XLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX00`2]f>H0<j7:
00000002000000030000o`000000000000800000o`3oon070?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0c
XLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:
03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:
03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H07@0cXLX00`2]f>H00000000000020000o`<0
0000o`3oon090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0
<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H0700cXLX3000000030000o`000000000000800000o`3oon0:0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0c
XLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]
f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]
f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H06`0cXLX3000000030000o`000000
00000?l0oooP3@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]
f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP06
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP06
03>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP08
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV01T0<j7:0`0000020000o`800000o`3oon0>0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>Q
bP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>Q
bP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0600cXLX3000000030000o`00000000000?l0oooP
403oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gH
iP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV01L0
<j7:0`0000000`000?l000000000003o0?ooh140oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iPd0oooP100000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX0
5@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0
<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0
<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H05@0cXLX300000080003o00<000000?oo
h03oon00o`3oon0A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh003
0000003oon00oooP00P0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV
00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:
0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:
00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0D03>QbP<0000000@0003o0000000000000000o`3o
on0C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00
oooP00L0oooP100000080?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>Q
bP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV0180<j7:1000000010000?l0000000000000003o0?ooh140oooP1000000K0?ooh1h0
n_3V0@3oool001d0n_3V3`3oon000`000000oooP0?ooh0060?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]
f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H04@0cXLX30000
0080003o00<000000?ooh03oon00o`3oon0E0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP05
03>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0@03>QbP<0000000<0
003o000000000000o`3oon0H0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>
0?ooh0800000203oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV
03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400c
XLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0c
XLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00h0<j7:0`0000020000o`800000o`3oon0I0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0
500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H03@0cXLX300000003
0000o`00000000000?l0oooP6`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0
<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0
<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV00`0<j7:0`0000000`000?l000000000003o0?ooh1`0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>Q
bP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0:03>QbP<000000P000?l2
00000?l0oooP7@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]
f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP06
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP06
03>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP08
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV00T0<j7:0`0000000`000?l000000000003o0?ooh1l0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0c
XLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0c
XLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0703>QbP<000000P000?l200000?l0oooP
803oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gH
iP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00H0
<j7:0`0000000`000?l000000000003o0?ooh280oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gH
iP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100
<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0503>QbP8000000P000?l200000?l0oooP8`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV
01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX04`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV00<0<j7:0`000000
10000?l0000000000000003o0?ooh2@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0
<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0
[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:01<0<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP<0000000@0003o0000000000000000o`3oon0U0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]
f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0c
XLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]
f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0c
XLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP060:gHiP0cXLX0<j7:03>QbP2]f>H0<j7:0P000002
0000o`800000o`3oon0W0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0
<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0
<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0C03>QbP050:gHiP0cXLX0
<j7:03>QbP2]f>H00P00000010000?l0000000000000003o0?ooh2P0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>Q
bP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gH
iP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gH
iP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX0<j7:000000020000o`<00000o`3oon0Y0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV
03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP03
0:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0<j7:01<0<j7:00D0[MSV03>QbP0cXLX000000000o`0400000?l0oooP:03oon030000
01/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0c
XLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]
f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]
f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0C03>QbP<0000000@0003o0000000000000000o`3oon0/0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX0
0`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX0
0`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0B03>QbP8000000P000?l300000?l0oooP;@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:
01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV
03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV
03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV
03>QbP0cXLX04@0cXLX2000000030000o`000000000000800000o`3oon0^0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX0
0`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX0
0`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX0
0`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0
0`2]f>H0<j7:03>QbP0@03>QbP80000000@0003o0000000000000000o`3oon0`0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0c
XLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500c
XLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0?03>QbP80000000@0003o0000000000000000o`3oon0a0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0
<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H0
0P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0
500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0=03>QbP8000000P000?l200000?l0oooP<`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:
00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:
00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX0300cXLX2000000040000o`000000000000000?l0oooP=03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0
<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0
<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX02`0cXLX2000000040000o`000000000000000?l0oooP=@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV
01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX02P0cXLX00`000000003o0000o`0200000?l0oooP=`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV
01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX02@0cXLX00`000000003o0000000200000?l0oooP>03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV
01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX0200cXLX00`000000003o0000000200000?l0oooP>@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV
01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX2000000040000o`000000000000000?l0oooP>P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX0100cXLX200000080003o0`00003o0?ooh3/0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP05
03>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0<j7:00<0<j7:0P0000000`000?l000000000000200000?l0oooP?03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX2000000040000o`000000000000000?l0oooP?P3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:
0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0c
XLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500c
XLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX0102]f>H0<j7:03>QbP0cXLX2000000040000o`000000000000000?l0oooP?@3oon03000001/0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX0
5@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0
<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0
<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP02000000030000o`00000000000?l0oooP@@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:
00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0c
XLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]
f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0c
XLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0c
XLX00`0cXLX00`2]f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP00
000000000000o`0200000?l0oooP@P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0c
XLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]
f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]
f>H0<j7:03>QbP0803>QbP030:gHiP0cXLX0<j7:0080<j7:0P0000020000o`800000o`3oon130?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>Q
bP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>Q
bP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>Q
bP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00P0<j7:00@0[MSV03>Q
bP0cXLX0<j7:0P00000010000?l0000000000000003o0?ooh4@0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0c
XLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0c
XLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX00`2]f>H0<j7:03>QbP02000000040000o`00
0000000000000?l0oooPA@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:
03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:
03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:
03>QbP0803>QbP050:gHiP0cXLX00000000000000?l00`00003o0?ooh4H0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP03
0:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX0200cXLX0102]f>H00000000000000?l30000
0?l0oooPA`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0
<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>Q
bP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP0803>Q
bP80000000<0003o000000000000o`3oon190?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0
<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>Q
bP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>Q
bP030:gHiP0cXLX0<j7:00L0<j7:0P00000010000?l0000000000000003o0?ooh4T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP05
03>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00<0[MSV03>QbP0cXLX01@0cXLX3000000040000o`000000
000000000?l0oooPBP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>Q
bP0403>QbP<0000000<0003o000000000000o`3oon1<0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>Q
bP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>Q
bP0303>QbP030:gHiP0cXLX0<j7:00<0<j7:0P0000020000o`800000o`3oon1=0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0c
XLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500c
XLX00`2]f>H0<j7:03>QbP0303>QbP040:gHiP0cXLX0<j7:03>QbP<0000000@0003o000000000000
0000o`3oon1>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gH
iP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0
<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>QbP030:gHiP0cXLX0<j7:00<0
000000@0003o0000000000000000o`3oon1?0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0
<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>Q
bP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX00`2]f>H0<j7:03>QbP0303>Q
bP030:gHiP0cXLX000000080000000<0003o000000000000o`3oon1A0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV03>QbP0E03>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV
00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:
0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:
00<0<j7:00H0[MSV00000000000000000000o`00003o0?ooh540oooP0`00000K0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV
03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400c
XLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00`0c
XLX3000000030000o`00000000000?l0oooPD`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV
03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400c
XLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX3000000030000o`00000000000?l0oooPE03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV
03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400c
XLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00@0[MSV03>QbP0cXLX0<j7:
0`0000000`000?l000000?ooh03o0?ooh5D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0c
XLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:
00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0D03>QbP030:gHiP0cXLX0<j7:00<00000
00<0003o0000003oon00o`3oon1F0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gH
iP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0500cXLX0102]f>H0<j7:0000000000020000o`03
0000003oon00oooP0?l0oooPEP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0
<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV01@0<j7:00@0[MSV000000000000003o0P00003o0?oo
h5T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:0:gHiP0D03>QbP80000000<0003o000000000000o`3oon1J0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0c
XLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]
f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H04`0cXLX20000
00030000o`00000000000?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0c
XLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]
f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV0140<j7:0`0000000`000?l000000000003o0?oo
h5`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:0:gHiP0@03>QbP<0000000<0003o000000000000o`3oon1M0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0c
XLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]
f>H0<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0400cXLX20000
00030000o`00000000000?l0oooPGP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0c
XLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]
f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV00l0<j7:0P0000000`000?l000000000003o0?oo
h5l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:0:gHiP0=03>QbP<0000000<0003o000000000000o`3oon1P0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh0<000001P3oon000`000000oooP0?ooh0090?ooh003
03>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV
0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0[MSV
00`0<j7:0P0000020000o`800000o`3oon1Q0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H@0?ooh0030000003oon00oooP00D0oooP00<000000?ooh03oon002@3oon000`0cXLX0
[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>Q
bP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>Q
bP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>Q
bP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0;03>Q
bP80000000@0003o0000000000000000o`3oon1R0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>H=0?ooh0D000001P3oon04000000P0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]
f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP03
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@
03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H02P0cXLX2000000030000o`000000
00000?l0oooPH@3oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP
000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0
<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0803>QbP<0000000<0003o000000000000o`3o
on1U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00
000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0
<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0
[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gHiP0703>QbP<0000000<0003o000000000000o`3o
on1V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh08000001`3oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0[MSV00H0<j7:0`0000000`000?l000000000003o0?ooh6L0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gH
iP0503>QbP<0000000<0003o000000000000o`3oon1X0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>Q
bP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP2]f>H0100cXLX3000000030000o`00
0000oooP0?l0oooPJ@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0[MSV00<0<j7:0`0000000`000?l000000?ooh03o0?ooh6X0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gH
iP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:0:gH
iP0203>QbP<0000000<0003o000000000000o`3oon1[0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gH
iP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>Q
bP0@03>QbP030:gHiP0cXLX0<j7:00H0<j7:00@0[MSV03>QbP2]f>H0<j7:0`0000000`000?l00000
0000003o0?ooh6`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX0
1P0cXLX00`2]f>H0<j7:0:gHiP03000000030000o`00000000000?l0oooPK@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:
00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0000000800000
00<0003o000000000000o`3oon1^0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP030:gH
iP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0000000P000?l00`000000oooP0?ooh03o0?ooh6h0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:
0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:
03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX01P0cXLX2000000030000
o`00000000000?l0oooPL@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:
03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX00`2]f>H0<j7:
03>QbP0503>QbP80000000@0003o0000000000000000o`3oon1a0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX0
5@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0
<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0
<j7:03>QbP0@03>QbP030:gHiP0cXLX0<j7:00@0<j7:0P00000010000?l0000000000000003o0?oo
h780oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV03>QbP0cXLX00`0cXLX20000
00030000o`00000000000?l0oooPM03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon03000000T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:03>QbP0@03>QbP040:gHiP0cXLX0<j7:
03>QbP<0000000<0003o000000000000o`3oon1c0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:
00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV
03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV
03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0<j7:0100<j7:00<0[MSV
03>QbP0cXLX00`0000000`000?l000000000003o0?ooh7H0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0cXLX0
<j7:0100<j7:00<0[MSV03>QbP0cXLX00P0000000`000?l000000000003o0?ooh7L0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP02
03>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP05
03>QbP030:gHiP0cXLX0<j7:0100<j7:00D0[MSV00000000000000000000o`0200000?l0oooPN03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX3000000030000o`00000000000?l0oooPN@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0400cXLX2000000030000o`00000000000?l0oooPNP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX03P0cXLX3000000030000o`00000000000?l0oooPN`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX03@0cXLX3000000030000o`00000000000?l0oooPO03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX03@0cXLX2000000030000o`00000000000?l0oooPO@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0300cXLX2000000030000o`00000000000?l0oooPOP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX02P0cXLX3000000030000o`00000000000?l0oooPO`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX02@0cXLX3000000030000o`00000000000?l0oooPP03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0200cXLX3000000030000o`00000000000?l0oooPP@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX01`0cXLX3000000030000o`00000000000?l0oooPPP3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX01P0cXLX3000000030000o`00000000000?l0oooPP`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0c
XLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX01@0cXLX3000000030000o`000000oooP0?l0oooPQ03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0<j7:
0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0c
XLX00`2]f>H0<j7:03>QbP0503>QbP80000000<0003o0000003oon00o`3oon230?ooh0<000006`3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0c
XLX0<j7:00@0<j7:0P0000000`000?l000000000003o0?ooh8H0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP030:gHiP0c
XLX0<j7:0080<j7:0`0000000`000?l000000000003o0?ooh8L0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E
03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0c
XLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0c
XLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP040:gHiP0c
XLX0<j7:03>QbP<0000000<0003o000000000000o`3oon280?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0c
XLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX00`2]f>H0<j7:
03>QbP03000000030000o`00000000000?l0oooPR@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0
[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H0
0`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00D0<j7:00<0[MSV03>QbP0cXLX0
0P0000000`000?l000000000003o0?ooh8X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0c
XLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:
00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:
00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0503>QbP060:gHiP0cXLX0000000000000
0?l00000o`3oon2<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP05
0:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:
00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX01@0cXLX0102]f>H00000000000000?l200000?l0oooPS03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:00D0<j7:0P0000000`000?l000000000003o0?ooh8d0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0403>QbP80000000<0003o
000000000000o`3oon2>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>Q
bP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX00`0cXLX2000000030000o`00000000000?l0oooPS`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0
[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
<j7:0080<j7:0P0000000`000?l000000000003o0?ooh900oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>Q
bP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0
<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0
[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0cXLX0102]f>H0<j7:03>QbP0cXLX2000000030000o`00
000000000?l0oooPT@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
1@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>Q
bP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:03>Q
bP0203>QbP030:gHiP0cXLX0<j7:0080000000<0003o000000000000o`3oon2B0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0c
XLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP0000000000
0000o`0200000?l0oooPT`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0c
XLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP2]f>H00`0cXLX00`2]f>H0<j7:
03>QbP0203>QbP040:gHiP00000000000000o`<00000o`3oon2C0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gH
iP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080
<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0
<j7:00<0[MSV03>QbP0cXLX00P0cXLX2000000040000o`000000000000000?l0oooPTP3oon030000
01/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0c
XLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]
f>H0<j7:0:gHiP0303>QbP030:gHiP0cXLX0<j7:0080<j7:00<000000000o`0000000P00003o0?oo
h9D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>QbP0cXLX00P0000000`00
0?l000000000003o0?ooh9L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV00<0<j7:00<0[MSV03>Q
bP0000000P0000000`000?l000000000003o0?ooh9L0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0[MSV
00<0<j7:00D0[MSV03>QbP00000000000000o`0200000?l0oooPV03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:
01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV
03>QbP2]f>H00`0cXLX0102]f>H00000000000000?l200000?l0oooPV@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00<0
[MSV03>QbP2]f>H00`0cXLX2000000030000o`00000000000?l0oooPVP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00@0
[MSV03>QbP2]f>H0<j7:0`0000000`000?l000000000003o0?ooh9/0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>Q
bP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0[MSV00<0000000<0003o000000000000o`3oon2L0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0c
XLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:
03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:
0:gHiP02000000030000o`00000000000?l0oooPW@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0
[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX0
0P0cXLX00`2]f>H0<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00D0[MSV03>QbP000000
00000000o`0200000?l0oooPWP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX0
0`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0
<j7:03>QbP0603>QbP030:gHiP0cXLX0<j7:0080<j7:00@0[MSV000000000000003o0P00003o0?oo
h9l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0c
XLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP80000000<0003o000000000000o`3oon2P0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0c
XLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]
f>H0<j7:03>QbP0203>QbP030:gHiP0cXLX0<j7:00H0<j7:00@0[MSV03>QbP0cXLX0<j7:0P000000
0`000?l000000000003o0?ooh:40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPd0oooP0`0000080?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]
f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP02
03>QbP030:gHiP0cXLX0<j7:00H0<j7:00H0[MSV03>QbP0cXLX0<j7:000000000?l200000?l0oooP
XP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?oo
h00000070?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:
03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP03
0:gHiP0cXLX0<j7:00H0<j7:00D0[MSV03>QbP00000000000000o`0200000?l0oooPX`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?oo
h0@00000203oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>Q
bP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX01P0cXLX0
102]f>H00000000000000?l300000?l0oooPX03oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H=
0?ooh0<00000203oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV
03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0c
XLX00`2]f>H0<j7:03>QbP0603>QbP80000000@0003o0000000000000000o`3oon2T0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00oooP00L0oooP00<0
00000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0
[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0
1@0cXLX3000000030000o`000000oooP0?l0oooPY@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V3P3oon03000000L0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>Q
bP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:0080<j7:00<0[MSV03>QbP0cXLX0100cXLX3000000030000o`000000oooP0?l0oooP
YP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>Q
bP0cXLX0[MSV0080<j7:00<0[MSV03>QbP0cXLX00P0cXLX00`2]f>H0<j7:03>QbP0303>QbP<00000
00<0003o000000000000o`3oon2W0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>Q
bP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX00`2]f>H0<j7:03>QbP0203>QbP030:gH
iP0cXLX0<j7:0080<j7:0`0000000`000?l000000000003o0?ooh:P0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>Q
bP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gH
iP0cXLX0<j7:0080<j7:00@0[MSV03>QbP0cXLX0<j7:0`0000000`000?l000000?ooh03o0?ooh:T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0
<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00@0[MSV03>QbP0cXLX0<j7:0P0000000`00
0?l000000000003o0?ooh:X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:0080<j7:00<0[MSV03>Q
bP0cXLX00P0000000`000?l000000000003o0?ooh:/0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP03
0:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP030:gHiP0cXLX0<j7:
0080<j7:00D0[MSV03>QbP0cXLX000000000o`0200000?l0oooP[03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:
01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0[MSV
03>QbP0cXLX00P0cXLX0102]f>H00000000000000?l200000?l0oooP[@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:00<0
[MSV03>QbP0cXLX00P0cXLX2000000040000o`000000000000000?l0oooP[@3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00<0[MSV03>QbP0cXLX00P0cXLX2000000030000o`00000000000?l0oooP[P3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX01@2]f>H0<j7:03>QbP0cXLX0[MSV0080<j7:
00@0[MSV03>QbP0cXLX0<j7:0P0000000`000?l000000000003o0?ooh:l0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV
03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP03
0:gHiP0cXLX0<j7:0080000000<0003o000000000000o`3oon2`0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX0
5@0cXLX00`2]f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX01@2]f>H0
<j7:000000000000003o00800000o`3oon2a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0<000002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0
<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP0203>QbP040:gHiP00000000000000o`800000o`3oon2`
0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0c
XLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV03>QbP0cXLX0<j7:0:gHiP02
03>QbP80000000<0003o000000000000o`3oon2c0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]
f>H0<j7:03>QbP0303>QbP050:gHiP0cXLX0<j7:03>QbP2]f>H00P0cXLX010000000003o00000000
003o0?ooh;@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:00<0<j7:00D0[MSV
03>QbP0cXLX0<j7:0:gHiP02000000030000o`00000000000?l0oooP]@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0
<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0102]f>H0<j7:03>QbP0cXLX2000000040000o`00
0000000000000?l0oooP]@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0c
XLX0102]f>H0<j7:03>QbP0cXLX2000000030000o`00000000000?l0oooP]P3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]
f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX00`2]f>H0<j7:03>QbP02000000030000o`00
000000000?l0oooP]`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00<0[MSV03>QbP0cXLX00`0cXLX0
1@2]f>H0<j7:000000000000003o00800000o`3oon2h0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX0
0`2]f>H0<j7:03>QbP0303>QbP040:gHiP00000000000000o`800000o`3oon2i0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:
0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP80000000<0003o000000000000o`3oon2j
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0<j7:03>QbP0303>QbP04000000000?l00000
00000?l0oooP^`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:00@0[MSV03>QbP0cXLX0<j7:0`000000
0`000?l000000?ooh03o0?ooh;/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0E03>QbP030:gHiP0cXLX0<j7:
00<0000000<0003o000000000000o`3oon2l0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX05@0cXLX00`2]f>H0
<j7:03>QbP02000000030000o`00000000000?l0oooP_@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:
00D0[MSV03>QbP00000000000000o`0200000?l0oooP_P3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:01D0<j7:
00@0[MSV000000000000003o0P00003o0?ooh;l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP0`0000090?ooh00303>QbP2]f>H0<j7:01D0<j7:0P0000000`000?l00000
0000003o0?ooh;h0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0<j7:01@0<j7:0`0000000`000?l000000?ooh03o0?ooh<00oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV03>QbP0C03>QbP<0000000<0003o0000003oon00o`3oon310?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP0cXLX04P0cXLX3000000030000o`000000oooP0?l0oooP`P3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:0180
<j7:0P0000000`000?l000000?ooh03o0?ooh<<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0A03>QbP800000
00<0003o0000003oon00o`3oon340?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX0400cXLX2000000030000o`00
000000000?l0oooPa@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:00l0<j7:0`0000000`000?l000000?ooh03o
0?ooh<D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`0cXLX0[MSV03>QbP0>03>QbP<0000000<0003o0000003oon00o`3oon360?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP00<0<j7:0:gHiP0cXLX03@0cXLX3000000030000o`000000oooP0?l0oooPa`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>Q
bP2]f>H0<j7:00d0<j7:0P0000000`000?l000000000003o0?ooh<P0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>Q
bP0<03>QbP80000000<0003o000000000000o`3oon390?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX02`0cXLX2
000000030000o`00000000000?l0oooPbP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:00X0<j7:0`0000000`00
0?l000000?ooh03o0?ooh<X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0903>QbP<0000000<0003o0000003o
on00o`3oon3;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX0200cXLX3000000030000o`000000oooP0?l0oooP
c03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP00<0
<j7:0:gHiP0cXLX01`0cXLX3000000030000o`00000000000?l0oooPb`3oon03000001/0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX01`0cXLX2
000000030000o`00000000000?l0oooPcP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh00303>QbP2]f>H0<j7:00H0<j7:0P0000000`00
0?l000000?ooh03o0?ooh<l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`0cXLX0[MSV03>QbP0503>QbP80000000<0003o00000000
0000o`3oon3@0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX0100cXLX2000000030000o`00000000000?l0oooP
d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh00303>QbP2]f>H0<j7:00<0<j7:0`0000000`000?l000000?ooh03o0?ooh=40oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00
0`0cXLX0[MSV03>QbP0203>QbP<0000000<0003o0000003oon00o`3oon3B0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gH
iP0cXLX00P0cXLX2000000030000o`000000oooP0?l0oooPd`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh00403>QbP2]f>H0<j7:03>Q
bP80000000<0003o0000003oon00o`3oon3D0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<0<j7:0:gHiP0cXLX00P0000000`000?l0
00000000003o0?ooh=D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon001@0cXLX0[MSV000000000000003o00800000o`3oon3F0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00@0<j7:0:gHiP000000003o0P00003o0?ooh=L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon00100cXLX00000000000000?l200000?l0
oooPe`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP
00<000000?ooh03oon002@3oon02000000030000o`00000000000?l0oooPf03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000
003oon00oooP00T0oooP00@000000000o`0000000000o`3oon3I0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP100000070?ooh004
000000000?l0000000000?l0oooPe`3oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh080
0000203oon000`000000oooP0?ooh0080?ooh0@00000o`3oon3J0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03o
on002@3oon0200000?l0oooPf`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
3P3oon02000000P0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP04X0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000003oon00
oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon3o00000>X000006`3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3o
on0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?oo
h1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooP
o`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko
0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00=40n_3V100000020?[`iPP00000
0P3jl>H4000000070?[`iP00000000000000003jl>H000000?[`iP0<000000030?[`iP0000000000
00@0000000@0n_3V0000000000000000203jl>H5000000@0n_3V1`0000000`3jl>H000000?[`iP03
000000P0n_3V1@0000020?[`iP@000000P3jl>H5000000`0n_3V0`00000A0?[`iP<000001P3jl>H3
000000040?[`iP0000000000000000H0n_3V00<000000?[`iP3jl>H0103jl>H3000000040?[`iP00
0000000000000=P0n_3V0@3oool00=80n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P00
00030?[`iP070000003jl>H000000000003jl>H000000?[`iP0400000080n_3V0P0000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000T0n_3V00@000000?[`iP3j
l>H0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02
000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80000000<0n_3V
0000000000003`3jl>H2000000030?[`iP000000000000H0n_3V0P0000000`3jl>H0000000000007
0?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003I0?[`iP40oooo003B0?[`
iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P0000050?[`iP80000000<0n_3V0000
003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V
0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000003@3jl>H2
000000030?[`iP000000000000D0n_3V1@0000050?[`iP80000000<0n_3V0000000000001`3jl>H3
000000H0n_3V1@0000060?[`iP<00000fP3jl>H10?ooo`00dP3jl>H5000000@0n_3V0P0000030?[`
iPH0000000H0n_3V000000000000n_3V0000003jl>H2000000030?[`iP000000000000<000000P3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000;0?[`iP<000000`3j
l>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP800000
0`3jl>H200000080n_3V0P0000020?[`iP8000003@3jl>H2000000030?[`iP000000000000l0n_3V
0P0000000`3jl>H00000000000070?[`iP<00000203jl>H00`000000n_3V0?[`iP060?[`iP<00000
fP3jl>H10?ooo`00dP3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H200000080n_3V0P00
00001P3jl>H000000000003jl>H000000?[`iP800000103jl>H200000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000002P3jl>H3000000@0n_3V0P000000103jl>H0
00000000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H3000000030?[`iP000000n_3V00X0n_3V0`00000@0?[`iP@000001`3jl>H20000
00030?[`iP000000000000L0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP0000000000
0=T0n_3V0@3oool00=80n_3V0P0000020?[`iP80000000<0n_3V0000000000000P0000040?[`iP@0
000000<0n_3V0000000000001@0000020?[`iP@000000P3jl>H500000080n_3V1@00000:0?[`iP80
00001@3jl>H3000000030?[`iP000000000000L000002P3jl>H500000080n_3V100000020?[`iP<0
000000<0n_3V0000000000002P3jl>H2000000030?[`iP000000000000l0n_3V0P0000080?[`iP<0
000000@0n_3V00000000000000003@3jl>H3000000030?[`iP000000000000D00000e03jl>H10?oo
o`00dP3jl>H200000080n_3V0P00000c0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0G0?[`iP80
00006P3jl>H2000000030?[`iP00000000000100n_3V0P00000S0?[`iP030000003jl>H0n_3V0=@0
n_3V0@3oool00=40n_3V1P0000040?[`iP800000;`3jl>H5000001X0n_3V0`00000I0?[`iP<00000
4P3jl>H300000280n_3V00<000000?[`iP3jl>H0d`3jl>H10?ooo`00o`3jl>J30?[`iP030000003j
l>H0n_3V0=80n_3V0@3oool00?l0n_3VP03jl>H010000000n_3V0?[`iP00003D0?[`iP40oooo003o
0?[`iX40n_3V0P00003E0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .60262 L
.02529 .60262 L
.02529 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .60262 L
.02529 .60262 L
.02529 .08012 L
s
.678 .847 .902 r
.02529 .08012 m
.02529 .60014 L
.02675 .60014 L
.02675 .08012 L
F
.2 .63 .79 r
.02529 .08012 m
.02529 .60014 L
.02675 .60014 L
.02675 .08012 L
s
.678 .847 .902 r
.02675 .08012 m
.02675 .59776 L
.02879 .59776 L
.02879 .08012 L
F
.2 .63 .79 r
.02675 .08012 m
.02675 .59776 L
.02879 .59776 L
.02879 .08012 L
s
.678 .847 .902 r
.02879 .08012 m
.02879 .59645 L
.03019 .59645 L
.03019 .08012 L
F
.2 .63 .79 r
.02879 .08012 m
.02879 .59645 L
.03019 .59645 L
.03019 .08012 L
s
.678 .847 .902 r
.03019 .08012 m
.03019 .59444 L
.03187 .59444 L
.03187 .08012 L
F
.2 .63 .79 r
.03019 .08012 m
.03019 .59444 L
.03187 .59444 L
.03187 .08012 L
s
.678 .847 .902 r
.03187 .08012 m
.03187 .59221 L
.03295 .59221 L
.03295 .08012 L
F
.2 .63 .79 r
.03187 .08012 m
.03187 .59221 L
.03295 .59221 L
.03295 .08012 L
s
.678 .847 .902 r
.03295 .08012 m
.03295 .59156 L
.03456 .59156 L
.03456 .08012 L
F
.2 .63 .79 r
.03295 .08012 m
.03295 .59156 L
.03456 .59156 L
.03456 .08012 L
s
.678 .847 .902 r
.03456 .08012 m
.03456 .58937 L
.03654 .58937 L
.03654 .08012 L
F
.2 .63 .79 r
.03456 .08012 m
.03456 .58937 L
.03654 .58937 L
.03654 .08012 L
s
.678 .847 .902 r
.03654 .08012 m
.03654 .58735 L
.03779 .58735 L
.03779 .08012 L
F
.2 .63 .79 r
.03654 .08012 m
.03654 .58735 L
.03779 .58735 L
.03779 .08012 L
s
.678 .847 .902 r
.03779 .08012 m
.03779 .5852 L
.039 .5852 L
.039 .08012 L
F
.2 .63 .79 r
.03779 .08012 m
.03779 .5852 L
.039 .5852 L
.039 .08012 L
s
.678 .847 .902 r
.039 .08012 m
.039 .58328 L
.04094 .58328 L
.04094 .08012 L
F
.2 .63 .79 r
.039 .08012 m
.039 .58328 L
.04094 .58328 L
.04094 .08012 L
s
.678 .847 .902 r
.04094 .08012 m
.04094 .58133 L
.04259 .58133 L
.04259 .08012 L
F
.2 .63 .79 r
.04094 .08012 m
.04094 .58133 L
.04259 .58133 L
.04259 .08012 L
s
.678 .847 .902 r
.04259 .08012 m
.04259 .57997 L
.04368 .57997 L
.04368 .08012 L
F
.2 .63 .79 r
.04259 .08012 m
.04259 .57997 L
.04368 .57997 L
.04368 .08012 L
s
.678 .847 .902 r
.04368 .08012 m
.04368 .5787 L
.04475 .5787 L
.04475 .08012 L
F
.2 .63 .79 r
.04368 .08012 m
.04368 .5787 L
.04475 .5787 L
.04475 .08012 L
s
.678 .847 .902 r
.04475 .08012 m
.04475 .57744 L
.04541 .57744 L
.04541 .08012 L
F
.2 .63 .79 r
.04475 .08012 m
.04475 .57744 L
.04541 .57744 L
.04541 .08012 L
s
.678 .847 .902 r
.04541 .08012 m
.04541 .57575 L
.04675 .57575 L
.04675 .08012 L
F
.2 .63 .79 r
.04541 .08012 m
.04541 .57575 L
.04675 .57575 L
.04675 .08012 L
s
.678 .847 .902 r
.04675 .08012 m
.04675 .57384 L
.04851 .57384 L
.04851 .08012 L
F
.2 .63 .79 r
.04675 .08012 m
.04675 .57384 L
.04851 .57384 L
.04851 .08012 L
s
.678 .847 .902 r
.04851 .08012 m
.04851 .57225 L
.04942 .57225 L
.04942 .08012 L
F
.2 .63 .79 r
.04851 .08012 m
.04851 .57225 L
.04942 .57225 L
.04942 .08012 L
s
.678 .847 .902 r
.04942 .08012 m
.04942 .57083 L
.05065 .57083 L
.05065 .08012 L
F
.2 .63 .79 r
.04942 .08012 m
.04942 .57083 L
.05065 .57083 L
.05065 .08012 L
s
.678 .847 .902 r
.05065 .08012 m
.05065 .57003 L
.05131 .57003 L
.05131 .08012 L
F
.2 .63 .79 r
.05065 .08012 m
.05065 .57003 L
.05131 .57003 L
.05131 .08012 L
s
.678 .847 .902 r
.05131 .08012 m
.05131 .56972 L
.0525 .56972 L
.0525 .08012 L
F
.2 .63 .79 r
.05131 .08012 m
.05131 .56972 L
.0525 .56972 L
.0525 .08012 L
s
.678 .847 .902 r
.0525 .08012 m
.0525 .56691 L
.05436 .56691 L
.05436 .08012 L
F
.2 .63 .79 r
.0525 .08012 m
.0525 .56691 L
.05436 .56691 L
.05436 .08012 L
s
.678 .847 .902 r
.05436 .08012 m
.05436 .56481 L
.05614 .56481 L
.05614 .08012 L
F
.2 .63 .79 r
.05436 .08012 m
.05436 .56481 L
.05614 .56481 L
.05614 .08012 L
s
.678 .847 .902 r
.05614 .08012 m
.05614 .56323 L
.05687 .56323 L
.05687 .08012 L
F
.2 .63 .79 r
.05614 .08012 m
.05614 .56323 L
.05687 .56323 L
.05687 .08012 L
s
.678 .847 .902 r
.05687 .08012 m
.05687 .56167 L
.05868 .56167 L
.05868 .08012 L
F
.2 .63 .79 r
.05687 .08012 m
.05687 .56167 L
.05868 .56167 L
.05868 .08012 L
s
.678 .847 .902 r
.05868 .08012 m
.05868 .55989 L
.0597 .55989 L
.0597 .08012 L
F
.2 .63 .79 r
.05868 .08012 m
.05868 .55989 L
.0597 .55989 L
.0597 .08012 L
s
.678 .847 .902 r
.0597 .08012 m
.0597 .5579 L
.06153 .5579 L
.06153 .08012 L
F
.2 .63 .79 r
.0597 .08012 m
.0597 .5579 L
.06153 .5579 L
.06153 .08012 L
s
.678 .847 .902 r
.06153 .08012 m
.06153 .55679 L
.06297 .55679 L
.06297 .08012 L
F
.2 .63 .79 r
.06153 .08012 m
.06153 .55679 L
.06297 .55679 L
.06297 .08012 L
s
.678 .847 .902 r
.06297 .08012 m
.06297 .55574 L
.06371 .55574 L
.06371 .08012 L
F
.2 .63 .79 r
.06297 .08012 m
.06297 .55574 L
.06371 .55574 L
.06371 .08012 L
s
.678 .847 .902 r
.06371 .08012 m
.06371 .55499 L
.06575 .55499 L
.06575 .08012 L
F
.2 .63 .79 r
.06371 .08012 m
.06371 .55499 L
.06575 .55499 L
.06575 .08012 L
s
.678 .847 .902 r
.06575 .08012 m
.06575 .55201 L
.06659 .55201 L
.06659 .08012 L
F
.2 .63 .79 r
.06575 .08012 m
.06575 .55201 L
.06659 .55201 L
.06659 .08012 L
s
.678 .847 .902 r
.06659 .08012 m
.06659 .55129 L
.06814 .55129 L
.06814 .08012 L
F
.2 .63 .79 r
.06659 .08012 m
.06659 .55129 L
.06814 .55129 L
.06814 .08012 L
s
.678 .847 .902 r
.06814 .08012 m
.06814 .54799 L
.06972 .54799 L
.06972 .08012 L
F
.2 .63 .79 r
.06814 .08012 m
.06814 .54799 L
.06972 .54799 L
.06972 .08012 L
s
.678 .847 .902 r
.06972 .08012 m
.06972 .54731 L
.07117 .54731 L
.07117 .08012 L
F
.2 .63 .79 r
.06972 .08012 m
.06972 .54731 L
.07117 .54731 L
.07117 .08012 L
s
.678 .847 .902 r
.07117 .08012 m
.07117 .54621 L
.07217 .54621 L
.07217 .08012 L
F
.2 .63 .79 r
.07117 .08012 m
.07117 .54621 L
.07217 .54621 L
.07217 .08012 L
s
.678 .847 .902 r
.07217 .08012 m
.07217 .54347 L
.07416 .54347 L
.07416 .08012 L
F
.2 .63 .79 r
.07217 .08012 m
.07217 .54347 L
.07416 .54347 L
.07416 .08012 L
s
.678 .847 .902 r
.07416 .08012 m
.07416 .54182 L
.07528 .54182 L
.07528 .08012 L
F
.2 .63 .79 r
.07416 .08012 m
.07416 .54182 L
.07528 .54182 L
.07528 .08012 L
s
.678 .847 .902 r
.07528 .08012 m
.07528 .54127 L
.07629 .54127 L
.07629 .08012 L
F
.2 .63 .79 r
.07528 .08012 m
.07528 .54127 L
.07629 .54127 L
.07629 .08012 L
s
.678 .847 .902 r
.07629 .08012 m
.07629 .5395 L
.07725 .5395 L
.07725 .08012 L
F
.2 .63 .79 r
.07629 .08012 m
.07629 .5395 L
.07725 .5395 L
.07725 .08012 L
s
.678 .847 .902 r
.07725 .08012 m
.07725 .53769 L
.07853 .53769 L
.07853 .08012 L
F
.2 .63 .79 r
.07725 .08012 m
.07725 .53769 L
.07853 .53769 L
.07853 .08012 L
s
.678 .847 .902 r
.07853 .08012 m
.07853 .53761 L
.07998 .53761 L
.07998 .08012 L
F
.2 .63 .79 r
.07853 .08012 m
.07853 .53761 L
.07998 .53761 L
.07998 .08012 L
s
.678 .847 .902 r
.07998 .08012 m
.07998 .53571 L
.08071 .53571 L
.08071 .08012 L
F
.2 .63 .79 r
.07998 .08012 m
.07998 .53571 L
.08071 .53571 L
.08071 .08012 L
s
.678 .847 .902 r
.08071 .08012 m
.08071 .53338 L
.08253 .53338 L
.08253 .08012 L
F
.2 .63 .79 r
.08071 .08012 m
.08071 .53338 L
.08253 .53338 L
.08253 .08012 L
s
.678 .847 .902 r
.08253 .08012 m
.08253 .53265 L
.08378 .53265 L
.08378 .08012 L
F
.2 .63 .79 r
.08253 .08012 m
.08253 .53265 L
.08378 .53265 L
.08378 .08012 L
s
.678 .847 .902 r
.08378 .08012 m
.08378 .53057 L
.08466 .53057 L
.08466 .08012 L
F
.2 .63 .79 r
.08378 .08012 m
.08378 .53057 L
.08466 .53057 L
.08466 .08012 L
s
.678 .847 .902 r
.08466 .08012 m
.08466 .52984 L
.08562 .52984 L
.08562 .08012 L
F
.2 .63 .79 r
.08466 .08012 m
.08466 .52984 L
.08562 .52984 L
.08562 .08012 L
s
.678 .847 .902 r
.08562 .08012 m
.08562 .52926 L
.08629 .52926 L
.08629 .08012 L
F
.2 .63 .79 r
.08562 .08012 m
.08562 .52926 L
.08629 .52926 L
.08629 .08012 L
s
.678 .847 .902 r
.08629 .08012 m
.08629 .52821 L
.08743 .52821 L
.08743 .08012 L
F
.2 .63 .79 r
.08629 .08012 m
.08629 .52821 L
.08743 .52821 L
.08743 .08012 L
s
.678 .847 .902 r
.08743 .08012 m
.08743 .52697 L
.0886 .52697 L
.0886 .08012 L
F
.2 .63 .79 r
.08743 .08012 m
.08743 .52697 L
.0886 .52697 L
.0886 .08012 L
s
.678 .847 .902 r
.0886 .08012 m
.0886 .52437 L
.09063 .52437 L
.09063 .08012 L
F
.2 .63 .79 r
.0886 .08012 m
.0886 .52437 L
.09063 .52437 L
.09063 .08012 L
s
.678 .847 .902 r
.09063 .08012 m
.09063 .5233 L
.09156 .5233 L
.09156 .08012 L
F
.2 .63 .79 r
.09063 .08012 m
.09063 .5233 L
.09156 .5233 L
.09156 .08012 L
s
.678 .847 .902 r
.09156 .08012 m
.09156 .52086 L
.09335 .52086 L
.09335 .08012 L
F
.2 .63 .79 r
.09156 .08012 m
.09156 .52086 L
.09335 .52086 L
.09335 .08012 L
s
.678 .847 .902 r
.09335 .08012 m
.09335 .52044 L
.0944 .52044 L
.0944 .08012 L
F
.2 .63 .79 r
.09335 .08012 m
.09335 .52044 L
.0944 .52044 L
.0944 .08012 L
s
.678 .847 .902 r
.0944 .08012 m
.0944 .51771 L
.09649 .51771 L
.09649 .08012 L
F
.2 .63 .79 r
.0944 .08012 m
.0944 .51771 L
.09649 .51771 L
.09649 .08012 L
s
.678 .847 .902 r
.09649 .08012 m
.09649 .51635 L
.0972 .51635 L
.0972 .08012 L
F
.2 .63 .79 r
.09649 .08012 m
.09649 .51635 L
.0972 .51635 L
.0972 .08012 L
s
.678 .847 .902 r
.0972 .08012 m
.0972 .51546 L
.09808 .51546 L
.09808 .08012 L
F
.2 .63 .79 r
.0972 .08012 m
.0972 .51546 L
.09808 .51546 L
.09808 .08012 L
s
.678 .847 .902 r
.09808 .08012 m
.09808 .51496 L
.09963 .51496 L
.09963 .08012 L
F
.2 .63 .79 r
.09808 .08012 m
.09808 .51496 L
.09963 .51496 L
.09963 .08012 L
s
.678 .847 .902 r
.09963 .08012 m
.09963 .5129 L
.10089 .5129 L
.10089 .08012 L
F
.2 .63 .79 r
.09963 .08012 m
.09963 .5129 L
.10089 .5129 L
.10089 .08012 L
s
.678 .847 .902 r
.10089 .08012 m
.10089 .51049 L
.10271 .51049 L
.10271 .08012 L
F
.2 .63 .79 r
.10089 .08012 m
.10089 .51049 L
.10271 .51049 L
.10271 .08012 L
s
.678 .847 .902 r
.10271 .08012 m
.10271 .50879 L
.10368 .50879 L
.10368 .08012 L
F
.2 .63 .79 r
.10271 .08012 m
.10271 .50879 L
.10368 .50879 L
.10368 .08012 L
s
.678 .847 .902 r
.10368 .08012 m
.10368 .50828 L
.10474 .50828 L
.10474 .08012 L
F
.2 .63 .79 r
.10368 .08012 m
.10368 .50828 L
.10474 .50828 L
.10474 .08012 L
s
.678 .847 .902 r
.10474 .08012 m
.10474 .50736 L
.10561 .50736 L
.10561 .08012 L
F
.2 .63 .79 r
.10474 .08012 m
.10474 .50736 L
.10561 .50736 L
.10561 .08012 L
s
.678 .847 .902 r
.10561 .08012 m
.10561 .50651 L
.10709 .50651 L
.10709 .08012 L
F
.2 .63 .79 r
.10561 .08012 m
.10561 .50651 L
.10709 .50651 L
.10709 .08012 L
s
.678 .847 .902 r
.10709 .08012 m
.10709 .50487 L
.10888 .50487 L
.10888 .08012 L
F
.2 .63 .79 r
.10709 .08012 m
.10709 .50487 L
.10888 .50487 L
.10888 .08012 L
s
.678 .847 .902 r
.10888 .08012 m
.10888 .50214 L
.11058 .50214 L
.11058 .08012 L
F
.2 .63 .79 r
.10888 .08012 m
.10888 .50214 L
.11058 .50214 L
.11058 .08012 L
s
.678 .847 .902 r
.11058 .08012 m
.11058 .50015 L
.11135 .50015 L
.11135 .08012 L
F
.2 .63 .79 r
.11058 .08012 m
.11058 .50015 L
.11135 .50015 L
.11135 .08012 L
s
.678 .847 .902 r
.11135 .08012 m
.11135 .49966 L
.11311 .49966 L
.11311 .08012 L
F
.2 .63 .79 r
.11135 .08012 m
.11135 .49966 L
.11311 .49966 L
.11311 .08012 L
s
.678 .847 .902 r
.11311 .08012 m
.11311 .49711 L
.11426 .49711 L
.11426 .08012 L
F
.2 .63 .79 r
.11311 .08012 m
.11311 .49711 L
.11426 .49711 L
.11426 .08012 L
s
.678 .847 .902 r
.11426 .08012 m
.11426 .4961 L
.11572 .4961 L
.11572 .08012 L
F
.2 .63 .79 r
.11426 .08012 m
.11426 .4961 L
.11572 .4961 L
.11572 .08012 L
s
.678 .847 .902 r
.11572 .08012 m
.11572 .49452 L
.11761 .49452 L
.11761 .08012 L
F
.2 .63 .79 r
.11572 .08012 m
.11572 .49452 L
.11761 .49452 L
.11761 .08012 L
s
.678 .847 .902 r
.11761 .08012 m
.11761 .493 L
.11933 .493 L
.11933 .08012 L
F
.2 .63 .79 r
.11761 .08012 m
.11761 .493 L
.11933 .493 L
.11933 .08012 L
s
.678 .847 .902 r
.11933 .08012 m
.11933 .49083 L
.11997 .49083 L
.11997 .08012 L
F
.2 .63 .79 r
.11933 .08012 m
.11933 .49083 L
.11997 .49083 L
.11997 .08012 L
s
.678 .847 .902 r
.11997 .08012 m
.11997 .49025 L
.12089 .49025 L
.12089 .08012 L
F
.2 .63 .79 r
.11997 .08012 m
.11997 .49025 L
.12089 .49025 L
.12089 .08012 L
s
.678 .847 .902 r
.12089 .08012 m
.12089 .48806 L
.12284 .48806 L
.12284 .08012 L
F
.2 .63 .79 r
.12089 .08012 m
.12089 .48806 L
.12284 .48806 L
.12284 .08012 L
s
.678 .847 .902 r
.12284 .08012 m
.12284 .48612 L
.12426 .48612 L
.12426 .08012 L
F
.2 .63 .79 r
.12284 .08012 m
.12284 .48612 L
.12426 .48612 L
.12426 .08012 L
s
.678 .847 .902 r
.12426 .08012 m
.12426 .48504 L
.12519 .48504 L
.12519 .08012 L
F
.2 .63 .79 r
.12426 .08012 m
.12426 .48504 L
.12519 .48504 L
.12519 .08012 L
s
.678 .847 .902 r
.12519 .08012 m
.12519 .48435 L
.12715 .48435 L
.12715 .08012 L
F
.2 .63 .79 r
.12519 .08012 m
.12519 .48435 L
.12715 .48435 L
.12715 .08012 L
s
.678 .847 .902 r
.12715 .08012 m
.12715 .48042 L
.12911 .48042 L
.12911 .08012 L
F
.2 .63 .79 r
.12715 .08012 m
.12715 .48042 L
.12911 .48042 L
.12911 .08012 L
s
.678 .847 .902 r
.12911 .08012 m
.12911 .48029 L
.13044 .48029 L
.13044 .08012 L
F
.2 .63 .79 r
.12911 .08012 m
.12911 .48029 L
.13044 .48029 L
.13044 .08012 L
s
.678 .847 .902 r
.13044 .08012 m
.13044 .47889 L
.13113 .47889 L
.13113 .08012 L
F
.2 .63 .79 r
.13044 .08012 m
.13044 .47889 L
.13113 .47889 L
.13113 .08012 L
s
.678 .847 .902 r
.13113 .08012 m
.13113 .47806 L
.13216 .47806 L
.13216 .08012 L
F
.2 .63 .79 r
.13113 .08012 m
.13113 .47806 L
.13216 .47806 L
.13216 .08012 L
s
.678 .847 .902 r
.13216 .08012 m
.13216 .47604 L
.13349 .47604 L
.13349 .08012 L
F
.2 .63 .79 r
.13216 .08012 m
.13216 .47604 L
.13349 .47604 L
.13349 .08012 L
s
.678 .847 .902 r
.13349 .08012 m
.13349 .47492 L
.13509 .47492 L
.13509 .08012 L
F
.2 .63 .79 r
.13349 .08012 m
.13349 .47492 L
.13509 .47492 L
.13509 .08012 L
s
.678 .847 .902 r
.13509 .08012 m
.13509 .47371 L
.1369 .47371 L
.1369 .08012 L
F
.2 .63 .79 r
.13509 .08012 m
.13509 .47371 L
.1369 .47371 L
.1369 .08012 L
s
.678 .847 .902 r
.1369 .08012 m
.1369 .47029 L
.13896 .47029 L
.13896 .08012 L
F
.2 .63 .79 r
.1369 .08012 m
.1369 .47029 L
.13896 .47029 L
.13896 .08012 L
s
.678 .847 .902 r
.13896 .08012 m
.13896 .46902 L
.14004 .46902 L
.14004 .08012 L
F
.2 .63 .79 r
.13896 .08012 m
.13896 .46902 L
.14004 .46902 L
.14004 .08012 L
s
.678 .847 .902 r
.14004 .08012 m
.14004 .46814 L
.14078 .46814 L
.14078 .08012 L
F
.2 .63 .79 r
.14004 .08012 m
.14004 .46814 L
.14078 .46814 L
.14078 .08012 L
s
.678 .847 .902 r
.14078 .08012 m
.14078 .46757 L
.14144 .46757 L
.14144 .08012 L
F
.2 .63 .79 r
.14078 .08012 m
.14078 .46757 L
.14144 .46757 L
.14144 .08012 L
s
.678 .847 .902 r
.14144 .08012 m
.14144 .46657 L
.14243 .46657 L
.14243 .08012 L
F
.2 .63 .79 r
.14144 .08012 m
.14144 .46657 L
.14243 .46657 L
.14243 .08012 L
s
.678 .847 .902 r
.14243 .08012 m
.14243 .46526 L
.14336 .46526 L
.14336 .08012 L
F
.2 .63 .79 r
.14243 .08012 m
.14243 .46526 L
.14336 .46526 L
.14336 .08012 L
s
.678 .847 .902 r
.14336 .08012 m
.14336 .46468 L
.14444 .46468 L
.14444 .08012 L
F
.2 .63 .79 r
.14336 .08012 m
.14336 .46468 L
.14444 .46468 L
.14444 .08012 L
s
.678 .847 .902 r
.14444 .08012 m
.14444 .46319 L
.14603 .46319 L
.14603 .08012 L
F
.2 .63 .79 r
.14444 .08012 m
.14444 .46319 L
.14603 .46319 L
.14603 .08012 L
s
.678 .847 .902 r
.14603 .08012 m
.14603 .46042 L
.14766 .46042 L
.14766 .08012 L
F
.2 .63 .79 r
.14603 .08012 m
.14603 .46042 L
.14766 .46042 L
.14766 .08012 L
s
.678 .847 .902 r
.14766 .08012 m
.14766 .45989 L
.14878 .45989 L
.14878 .08012 L
F
.2 .63 .79 r
.14766 .08012 m
.14766 .45989 L
.14878 .45989 L
.14878 .08012 L
s
.678 .847 .902 r
.14878 .08012 m
.14878 .45885 L
.15023 .45885 L
.15023 .08012 L
F
.2 .63 .79 r
.14878 .08012 m
.14878 .45885 L
.15023 .45885 L
.15023 .08012 L
s
.678 .847 .902 r
.15023 .08012 m
.15023 .45606 L
.15181 .45606 L
.15181 .08012 L
F
.2 .63 .79 r
.15023 .08012 m
.15023 .45606 L
.15181 .45606 L
.15181 .08012 L
s
.678 .847 .902 r
.15181 .08012 m
.15181 .45478 L
.15315 .45478 L
.15315 .08012 L
F
.2 .63 .79 r
.15181 .08012 m
.15181 .45478 L
.15315 .45478 L
.15315 .08012 L
s
.678 .847 .902 r
.15315 .08012 m
.15315 .45348 L
.15441 .45348 L
.15441 .08012 L
F
.2 .63 .79 r
.15315 .08012 m
.15315 .45348 L
.15441 .45348 L
.15441 .08012 L
s
.678 .847 .902 r
.15441 .08012 m
.15441 .45271 L
.15507 .45271 L
.15507 .08012 L
F
.2 .63 .79 r
.15441 .08012 m
.15441 .45271 L
.15507 .45271 L
.15507 .08012 L
s
.678 .847 .902 r
.15507 .08012 m
.15507 .45203 L
.15634 .45203 L
.15634 .08012 L
F
.2 .63 .79 r
.15507 .08012 m
.15507 .45203 L
.15634 .45203 L
.15634 .08012 L
s
.678 .847 .902 r
.15634 .08012 m
.15634 .45009 L
.15781 .45009 L
.15781 .08012 L
F
.2 .63 .79 r
.15634 .08012 m
.15634 .45009 L
.15781 .45009 L
.15781 .08012 L
s
.678 .847 .902 r
.15781 .08012 m
.15781 .44839 L
.1592 .44839 L
.1592 .08012 L
F
.2 .63 .79 r
.15781 .08012 m
.15781 .44839 L
.1592 .44839 L
.1592 .08012 L
s
.678 .847 .902 r
.1592 .08012 m
.1592 .4474 L
.16063 .4474 L
.16063 .08012 L
F
.2 .63 .79 r
.1592 .08012 m
.1592 .4474 L
.16063 .4474 L
.16063 .08012 L
s
.678 .847 .902 r
.16063 .08012 m
.16063 .44615 L
.16184 .44615 L
.16184 .08012 L
F
.2 .63 .79 r
.16063 .08012 m
.16063 .44615 L
.16184 .44615 L
.16184 .08012 L
s
.678 .847 .902 r
.16184 .08012 m
.16184 .44457 L
.1629 .44457 L
.1629 .08012 L
F
.2 .63 .79 r
.16184 .08012 m
.16184 .44457 L
.1629 .44457 L
.1629 .08012 L
s
.678 .847 .902 r
.1629 .08012 m
.1629 .44324 L
.16358 .44324 L
.16358 .08012 L
F
.2 .63 .79 r
.1629 .08012 m
.1629 .44324 L
.16358 .44324 L
.16358 .08012 L
s
.678 .847 .902 r
.16358 .08012 m
.16358 .44131 L
.16551 .44131 L
.16551 .08012 L
F
.2 .63 .79 r
.16358 .08012 m
.16358 .44131 L
.16551 .44131 L
.16551 .08012 L
s
.678 .847 .902 r
.16551 .08012 m
.16551 .44104 L
.167 .44104 L
.167 .08012 L
F
.2 .63 .79 r
.16551 .08012 m
.16551 .44104 L
.167 .44104 L
.167 .08012 L
s
.678 .847 .902 r
.167 .08012 m
.167 .43876 L
.16809 .43876 L
.16809 .08012 L
F
.2 .63 .79 r
.167 .08012 m
.167 .43876 L
.16809 .43876 L
.16809 .08012 L
s
.678 .847 .902 r
.16809 .08012 m
.16809 .43762 L
.16978 .43762 L
.16978 .08012 L
F
.2 .63 .79 r
.16809 .08012 m
.16809 .43762 L
.16978 .43762 L
.16978 .08012 L
s
.678 .847 .902 r
.16978 .08012 m
.16978 .43557 L
.17159 .43557 L
.17159 .08012 L
F
.2 .63 .79 r
.16978 .08012 m
.16978 .43557 L
.17159 .43557 L
.17159 .08012 L
s
.678 .847 .902 r
.17159 .08012 m
.17159 .43474 L
.17306 .43474 L
.17306 .08012 L
F
.2 .63 .79 r
.17159 .08012 m
.17159 .43474 L
.17306 .43474 L
.17306 .08012 L
s
.678 .847 .902 r
.17306 .08012 m
.17306 .43296 L
.17378 .43296 L
.17378 .08012 L
F
.2 .63 .79 r
.17306 .08012 m
.17306 .43296 L
.17378 .43296 L
.17378 .08012 L
s
.678 .847 .902 r
.17378 .08012 m
.17378 .4312 L
.17518 .4312 L
.17518 .08012 L
F
.2 .63 .79 r
.17378 .08012 m
.17378 .4312 L
.17518 .4312 L
.17518 .08012 L
s
.678 .847 .902 r
.17518 .08012 m
.17518 .43041 L
.17653 .43041 L
.17653 .08012 L
F
.2 .63 .79 r
.17518 .08012 m
.17518 .43041 L
.17653 .43041 L
.17653 .08012 L
s
.678 .847 .902 r
.17653 .08012 m
.17653 .4281 L
.17849 .4281 L
.17849 .08012 L
F
.2 .63 .79 r
.17653 .08012 m
.17653 .4281 L
.17849 .4281 L
.17849 .08012 L
s
.678 .847 .902 r
.17849 .08012 m
.17849 .42693 L
.17968 .42693 L
.17968 .08012 L
F
.2 .63 .79 r
.17849 .08012 m
.17849 .42693 L
.17968 .42693 L
.17968 .08012 L
s
.678 .847 .902 r
.17968 .08012 m
.17968 .42579 L
.18058 .42579 L
.18058 .08012 L
F
.2 .63 .79 r
.17968 .08012 m
.17968 .42579 L
.18058 .42579 L
.18058 .08012 L
s
.678 .847 .902 r
.18058 .08012 m
.18058 .42468 L
.18258 .42468 L
.18258 .08012 L
F
.2 .63 .79 r
.18058 .08012 m
.18058 .42468 L
.18258 .42468 L
.18258 .08012 L
s
.678 .847 .902 r
.18258 .08012 m
.18258 .42242 L
.18359 .42242 L
.18359 .08012 L
F
.2 .63 .79 r
.18258 .08012 m
.18258 .42242 L
.18359 .42242 L
.18359 .08012 L
s
.678 .847 .902 r
.18359 .08012 m
.18359 .42057 L
.18552 .42057 L
.18552 .08012 L
F
.2 .63 .79 r
.18359 .08012 m
.18359 .42057 L
.18552 .42057 L
.18552 .08012 L
s
.678 .847 .902 r
.18552 .08012 m
.18552 .42029 L
.18726 .42029 L
.18726 .08012 L
F
.2 .63 .79 r
.18552 .08012 m
.18552 .42029 L
.18726 .42029 L
.18726 .08012 L
s
.678 .847 .902 r
.18726 .08012 m
.18726 .41853 L
.18922 .41853 L
.18922 .08012 L
F
.2 .63 .79 r
.18726 .08012 m
.18726 .41853 L
.18922 .41853 L
.18922 .08012 L
s
.678 .847 .902 r
.18922 .08012 m
.18922 .41511 L
.19105 .41511 L
.19105 .08012 L
F
.2 .63 .79 r
.18922 .08012 m
.18922 .41511 L
.19105 .41511 L
.19105 .08012 L
s
.678 .847 .902 r
.19105 .08012 m
.19105 .41431 L
.19214 .41431 L
.19214 .08012 L
F
.2 .63 .79 r
.19105 .08012 m
.19105 .41431 L
.19214 .41431 L
.19214 .08012 L
s
.678 .847 .902 r
.19214 .08012 m
.19214 .41322 L
.19312 .41322 L
.19312 .08012 L
F
.2 .63 .79 r
.19214 .08012 m
.19214 .41322 L
.19312 .41322 L
.19312 .08012 L
s
.678 .847 .902 r
.19312 .08012 m
.19312 .41178 L
.19427 .41178 L
.19427 .08012 L
F
.2 .63 .79 r
.19312 .08012 m
.19312 .41178 L
.19427 .41178 L
.19427 .08012 L
s
.678 .847 .902 r
.19427 .08012 m
.19427 .41064 L
.19552 .41064 L
.19552 .08012 L
F
.2 .63 .79 r
.19427 .08012 m
.19427 .41064 L
.19552 .41064 L
.19552 .08012 L
s
.678 .847 .902 r
.19552 .08012 m
.19552 .40958 L
.19617 .40958 L
.19617 .08012 L
F
.2 .63 .79 r
.19552 .08012 m
.19552 .40958 L
.19617 .40958 L
.19617 .08012 L
s
.678 .847 .902 r
.19617 .08012 m
.19617 .40913 L
.1971 .40913 L
.1971 .08012 L
F
.2 .63 .79 r
.19617 .08012 m
.19617 .40913 L
.1971 .40913 L
.1971 .08012 L
s
.678 .847 .902 r
.1971 .08012 m
.1971 .40755 L
.19842 .40755 L
.19842 .08012 L
F
.2 .63 .79 r
.1971 .08012 m
.1971 .40755 L
.19842 .40755 L
.19842 .08012 L
s
.678 .847 .902 r
.19842 .08012 m
.19842 .40625 L
.20026 .40625 L
.20026 .08012 L
F
.2 .63 .79 r
.19842 .08012 m
.19842 .40625 L
.20026 .40625 L
.20026 .08012 L
s
.678 .847 .902 r
.20026 .08012 m
.20026 .4051 L
.20192 .4051 L
.20192 .08012 L
F
.2 .63 .79 r
.20026 .08012 m
.20026 .4051 L
.20192 .4051 L
.20192 .08012 L
s
.678 .847 .902 r
.20192 .08012 m
.20192 .40248 L
.20324 .40248 L
.20324 .08012 L
F
.2 .63 .79 r
.20192 .08012 m
.20192 .40248 L
.20324 .40248 L
.20324 .08012 L
s
.678 .847 .902 r
.20324 .08012 m
.20324 .40212 L
.20484 .40212 L
.20484 .08012 L
F
.2 .63 .79 r
.20324 .08012 m
.20324 .40212 L
.20484 .40212 L
.20484 .08012 L
s
.678 .847 .902 r
.20484 .08012 m
.20484 .40031 L
.20585 .40031 L
.20585 .08012 L
F
.2 .63 .79 r
.20484 .08012 m
.20484 .40031 L
.20585 .40031 L
.20585 .08012 L
s
.678 .847 .902 r
.20585 .08012 m
.20585 .39865 L
.20741 .39865 L
.20741 .08012 L
F
.2 .63 .79 r
.20585 .08012 m
.20585 .39865 L
.20741 .39865 L
.20741 .08012 L
s
.678 .847 .902 r
.20741 .08012 m
.20741 .39817 L
.20942 .39817 L
.20942 .08012 L
F
.2 .63 .79 r
.20741 .08012 m
.20741 .39817 L
.20942 .39817 L
.20942 .08012 L
s
.678 .847 .902 r
.20942 .08012 m
.20942 .39563 L
.21029 .39563 L
.21029 .08012 L
F
.2 .63 .79 r
.20942 .08012 m
.20942 .39563 L
.21029 .39563 L
.21029 .08012 L
s
.678 .847 .902 r
.21029 .08012 m
.21029 .39455 L
.21144 .39455 L
.21144 .08012 L
F
.2 .63 .79 r
.21029 .08012 m
.21029 .39455 L
.21144 .39455 L
.21144 .08012 L
s
.678 .847 .902 r
.21144 .08012 m
.21144 .39409 L
.21244 .39409 L
.21244 .08012 L
F
.2 .63 .79 r
.21144 .08012 m
.21144 .39409 L
.21244 .39409 L
.21244 .08012 L
s
.678 .847 .902 r
.21244 .08012 m
.21244 .39262 L
.21418 .39262 L
.21418 .08012 L
F
.2 .63 .79 r
.21244 .08012 m
.21244 .39262 L
.21418 .39262 L
.21418 .08012 L
s
.678 .847 .902 r
.21418 .08012 m
.21418 .39123 L
.21514 .39123 L
.21514 .08012 L
F
.2 .63 .79 r
.21418 .08012 m
.21418 .39123 L
.21514 .39123 L
.21514 .08012 L
s
.678 .847 .902 r
.21514 .08012 m
.21514 .39001 L
.2159 .39001 L
.2159 .08012 L
F
.2 .63 .79 r
.21514 .08012 m
.21514 .39001 L
.2159 .39001 L
.2159 .08012 L
s
.678 .847 .902 r
.2159 .08012 m
.2159 .38955 L
.21706 .38955 L
.21706 .08012 L
F
.2 .63 .79 r
.2159 .08012 m
.2159 .38955 L
.21706 .38955 L
.21706 .08012 L
s
.678 .847 .902 r
.21706 .08012 m
.21706 .38806 L
.21915 .38806 L
.21915 .08012 L
F
.2 .63 .79 r
.21706 .08012 m
.21706 .38806 L
.21915 .38806 L
.21915 .08012 L
s
.678 .847 .902 r
.21915 .08012 m
.21915 .38633 L
.22024 .38633 L
.22024 .08012 L
F
.2 .63 .79 r
.21915 .08012 m
.21915 .38633 L
.22024 .38633 L
.22024 .08012 L
s
.678 .847 .902 r
.22024 .08012 m
.22024 .3846 L
.22127 .3846 L
.22127 .08012 L
F
.2 .63 .79 r
.22024 .08012 m
.22024 .3846 L
.22127 .3846 L
.22127 .08012 L
s
.678 .847 .902 r
.22127 .08012 m
.22127 .38397 L
.22197 .38397 L
.22197 .08012 L
F
.2 .63 .79 r
.22127 .08012 m
.22127 .38397 L
.22197 .38397 L
.22197 .08012 L
s
.678 .847 .902 r
.22197 .08012 m
.22197 .38237 L
.2237 .38237 L
.2237 .08012 L
F
.2 .63 .79 r
.22197 .08012 m
.22197 .38237 L
.2237 .38237 L
.2237 .08012 L
s
.678 .847 .902 r
.2237 .08012 m
.2237 .38111 L
.22573 .38111 L
.22573 .08012 L
F
.2 .63 .79 r
.2237 .08012 m
.2237 .38111 L
.22573 .38111 L
.22573 .08012 L
s
.678 .847 .902 r
.22573 .08012 m
.22573 .37965 L
.2276 .37965 L
.2276 .08012 L
F
.2 .63 .79 r
.22573 .08012 m
.22573 .37965 L
.2276 .37965 L
.2276 .08012 L
s
.678 .847 .902 r
.2276 .08012 m
.2276 .37779 L
.22827 .37779 L
.22827 .08012 L
F
.2 .63 .79 r
.2276 .08012 m
.2276 .37779 L
.22827 .37779 L
.22827 .08012 L
s
.678 .847 .902 r
.22827 .08012 m
.22827 .37712 L
.22971 .37712 L
.22971 .08012 L
F
.2 .63 .79 r
.22827 .08012 m
.22827 .37712 L
.22971 .37712 L
.22971 .08012 L
s
.678 .847 .902 r
.22971 .08012 m
.22971 .37537 L
.23104 .37537 L
.23104 .08012 L
F
.2 .63 .79 r
.22971 .08012 m
.22971 .37537 L
.23104 .37537 L
.23104 .08012 L
s
.678 .847 .902 r
.23104 .08012 m
.23104 .37457 L
.2317 .37457 L
.2317 .08012 L
F
.2 .63 .79 r
.23104 .08012 m
.23104 .37457 L
.2317 .37457 L
.2317 .08012 L
s
.678 .847 .902 r
.2317 .08012 m
.2317 .37366 L
.2328 .37366 L
.2328 .08012 L
F
.2 .63 .79 r
.2317 .08012 m
.2317 .37366 L
.2328 .37366 L
.2328 .08012 L
s
.678 .847 .902 r
.2328 .08012 m
.2328 .37299 L
.23355 .37299 L
.23355 .08012 L
F
.2 .63 .79 r
.2328 .08012 m
.2328 .37299 L
.23355 .37299 L
.23355 .08012 L
s
.678 .847 .902 r
.23355 .08012 m
.23355 .37165 L
.23537 .37165 L
.23537 .08012 L
F
.2 .63 .79 r
.23355 .08012 m
.23355 .37165 L
.23537 .37165 L
.23537 .08012 L
s
.678 .847 .902 r
.23537 .08012 m
.23537 .37047 L
.2371 .37047 L
.2371 .08012 L
F
.2 .63 .79 r
.23537 .08012 m
.23537 .37047 L
.2371 .37047 L
.2371 .08012 L
s
.678 .847 .902 r
.2371 .08012 m
.2371 .3677 L
.23873 .3677 L
.23873 .08012 L
F
.2 .63 .79 r
.2371 .08012 m
.2371 .3677 L
.23873 .3677 L
.23873 .08012 L
s
.678 .847 .902 r
.23873 .08012 m
.23873 .36729 L
.23957 .36729 L
.23957 .08012 L
F
.2 .63 .79 r
.23873 .08012 m
.23873 .36729 L
.23957 .36729 L
.23957 .08012 L
s
.678 .847 .902 r
.23957 .08012 m
.23957 .36557 L
.24114 .36557 L
.24114 .08012 L
F
.2 .63 .79 r
.23957 .08012 m
.23957 .36557 L
.24114 .36557 L
.24114 .08012 L
s
.678 .847 .902 r
.24114 .08012 m
.24114 .36474 L
.24236 .36474 L
.24236 .08012 L
F
.2 .63 .79 r
.24114 .08012 m
.24114 .36474 L
.24236 .36474 L
.24236 .08012 L
s
.678 .847 .902 r
.24236 .08012 m
.24236 .36321 L
.24361 .36321 L
.24361 .08012 L
F
.2 .63 .79 r
.24236 .08012 m
.24236 .36321 L
.24361 .36321 L
.24361 .08012 L
s
.678 .847 .902 r
.24361 .08012 m
.24361 .3629 L
.2448 .3629 L
.2448 .08012 L
F
.2 .63 .79 r
.24361 .08012 m
.24361 .3629 L
.2448 .3629 L
.2448 .08012 L
s
.678 .847 .902 r
.2448 .08012 m
.2448 .36124 L
.24604 .36124 L
.24604 .08012 L
F
.2 .63 .79 r
.2448 .08012 m
.2448 .36124 L
.24604 .36124 L
.24604 .08012 L
s
.678 .847 .902 r
.24604 .08012 m
.24604 .35991 L
.24712 .35991 L
.24712 .08012 L
F
.2 .63 .79 r
.24604 .08012 m
.24604 .35991 L
.24712 .35991 L
.24712 .08012 L
s
.678 .847 .902 r
.24712 .08012 m
.24712 .35927 L
.24784 .35927 L
.24784 .08012 L
F
.2 .63 .79 r
.24712 .08012 m
.24712 .35927 L
.24784 .35927 L
.24784 .08012 L
s
.678 .847 .902 r
.24784 .08012 m
.24784 .35811 L
.24903 .35811 L
.24903 .08012 L
F
.2 .63 .79 r
.24784 .08012 m
.24784 .35811 L
.24903 .35811 L
.24903 .08012 L
s
.678 .847 .902 r
.24903 .08012 m
.24903 .35766 L
.2498 .35766 L
.2498 .08012 L
F
.2 .63 .79 r
.24903 .08012 m
.24903 .35766 L
.2498 .35766 L
.2498 .08012 L
s
.678 .847 .902 r
.2498 .08012 m
.2498 .3566 L
.25048 .3566 L
.25048 .08012 L
F
.2 .63 .79 r
.2498 .08012 m
.2498 .3566 L
.25048 .3566 L
.25048 .08012 L
s
.678 .847 .902 r
.25048 .08012 m
.25048 .35603 L
.25114 .35603 L
.25114 .08012 L
F
.2 .63 .79 r
.25048 .08012 m
.25048 .35603 L
.25114 .35603 L
.25114 .08012 L
s
.678 .847 .902 r
.25114 .08012 m
.25114 .35457 L
.25268 .35457 L
.25268 .08012 L
F
.2 .63 .79 r
.25114 .08012 m
.25114 .35457 L
.25268 .35457 L
.25268 .08012 L
s
.678 .847 .902 r
.25268 .08012 m
.25268 .35384 L
.25352 .35384 L
.25352 .08012 L
F
.2 .63 .79 r
.25268 .08012 m
.25268 .35384 L
.25352 .35384 L
.25352 .08012 L
s
.678 .847 .902 r
.25352 .08012 m
.25352 .3532 L
.25442 .3532 L
.25442 .08012 L
F
.2 .63 .79 r
.25352 .08012 m
.25352 .3532 L
.25442 .3532 L
.25442 .08012 L
s
.678 .847 .902 r
.25442 .08012 m
.25442 .35116 L
.25649 .35116 L
.25649 .08012 L
F
.2 .63 .79 r
.25442 .08012 m
.25442 .35116 L
.25649 .35116 L
.25649 .08012 L
s
.678 .847 .902 r
.25649 .08012 m
.25649 .35053 L
.25722 .35053 L
.25722 .08012 L
F
.2 .63 .79 r
.25649 .08012 m
.25649 .35053 L
.25722 .35053 L
.25722 .08012 L
s
.678 .847 .902 r
.25722 .08012 m
.25722 .3487 L
.25882 .3487 L
.25882 .08012 L
F
.2 .63 .79 r
.25722 .08012 m
.25722 .3487 L
.25882 .3487 L
.25882 .08012 L
s
.678 .847 .902 r
.25882 .08012 m
.25882 .34805 L
.25969 .34805 L
.25969 .08012 L
F
.2 .63 .79 r
.25882 .08012 m
.25882 .34805 L
.25969 .34805 L
.25969 .08012 L
s
.678 .847 .902 r
.25969 .08012 m
.25969 .34765 L
.26129 .34765 L
.26129 .08012 L
F
.2 .63 .79 r
.25969 .08012 m
.25969 .34765 L
.26129 .34765 L
.26129 .08012 L
s
.678 .847 .902 r
.26129 .08012 m
.26129 .34449 L
.26336 .34449 L
.26336 .08012 L
F
.2 .63 .79 r
.26129 .08012 m
.26129 .34449 L
.26336 .34449 L
.26336 .08012 L
s
.678 .847 .902 r
.26336 .08012 m
.26336 .34371 L
.26523 .34371 L
.26523 .08012 L
F
.2 .63 .79 r
.26336 .08012 m
.26336 .34371 L
.26523 .34371 L
.26523 .08012 L
s
.678 .847 .902 r
.26523 .08012 m
.26523 .34213 L
.26646 .34213 L
.26646 .08012 L
F
.2 .63 .79 r
.26523 .08012 m
.26523 .34213 L
.26646 .34213 L
.26646 .08012 L
s
.678 .847 .902 r
.26646 .08012 m
.26646 .34126 L
.26852 .34126 L
.26852 .08012 L
F
.2 .63 .79 r
.26646 .08012 m
.26646 .34126 L
.26852 .34126 L
.26852 .08012 L
s
.678 .847 .902 r
.26852 .08012 m
.26852 .33876 L
.27038 .33876 L
.27038 .08012 L
F
.2 .63 .79 r
.26852 .08012 m
.26852 .33876 L
.27038 .33876 L
.27038 .08012 L
s
.678 .847 .902 r
.27038 .08012 m
.27038 .33749 L
.27131 .33749 L
.27131 .08012 L
F
.2 .63 .79 r
.27038 .08012 m
.27038 .33749 L
.27131 .33749 L
.27131 .08012 L
s
.678 .847 .902 r
.27131 .08012 m
.27131 .33714 L
.27195 .33714 L
.27195 .08012 L
F
.2 .63 .79 r
.27131 .08012 m
.27131 .33714 L
.27195 .33714 L
.27195 .08012 L
s
.678 .847 .902 r
.27195 .08012 m
.27195 .33608 L
.27338 .33608 L
.27338 .08012 L
F
.2 .63 .79 r
.27195 .08012 m
.27195 .33608 L
.27338 .33608 L
.27338 .08012 L
s
.678 .847 .902 r
.27338 .08012 m
.27338 .33469 L
.27468 .33469 L
.27468 .08012 L
F
.2 .63 .79 r
.27338 .08012 m
.27338 .33469 L
.27468 .33469 L
.27468 .08012 L
s
.678 .847 .902 r
.27468 .08012 m
.27468 .33396 L
.27645 .33396 L
.27645 .08012 L
F
.2 .63 .79 r
.27468 .08012 m
.27468 .33396 L
.27645 .33396 L
.27645 .08012 L
s
.678 .847 .902 r
.27645 .08012 m
.27645 .33206 L
.27811 .33206 L
.27811 .08012 L
F
.2 .63 .79 r
.27645 .08012 m
.27645 .33206 L
.27811 .33206 L
.27811 .08012 L
s
.678 .847 .902 r
.27811 .08012 m
.27811 .32999 L
.27944 .32999 L
.27944 .08012 L
F
.2 .63 .79 r
.27811 .08012 m
.27811 .32999 L
.27944 .32999 L
.27944 .08012 L
s
.678 .847 .902 r
.27944 .08012 m
.27944 .32927 L
.28018 .32927 L
.28018 .08012 L
F
.2 .63 .79 r
.27944 .08012 m
.27944 .32927 L
.28018 .32927 L
.28018 .08012 L
s
.678 .847 .902 r
.28018 .08012 m
.28018 .32788 L
.28181 .32788 L
.28181 .08012 L
F
.2 .63 .79 r
.28018 .08012 m
.28018 .32788 L
.28181 .32788 L
.28181 .08012 L
s
.678 .847 .902 r
.28181 .08012 m
.28181 .32694 L
.28341 .32694 L
.28341 .08012 L
F
.2 .63 .79 r
.28181 .08012 m
.28181 .32694 L
.28341 .32694 L
.28341 .08012 L
s
.678 .847 .902 r
.28341 .08012 m
.28341 .32609 L
.28471 .32609 L
.28471 .08012 L
F
.2 .63 .79 r
.28341 .08012 m
.28341 .32609 L
.28471 .32609 L
.28471 .08012 L
s
.678 .847 .902 r
.28471 .08012 m
.28471 .32404 L
.286 .32404 L
.286 .08012 L
F
.2 .63 .79 r
.28471 .08012 m
.28471 .32404 L
.286 .32404 L
.286 .08012 L
s
.678 .847 .902 r
.286 .08012 m
.286 .32372 L
.28742 .32372 L
.28742 .08012 L
F
.2 .63 .79 r
.286 .08012 m
.286 .32372 L
.28742 .32372 L
.28742 .08012 L
s
.678 .847 .902 r
.28742 .08012 m
.28742 .32144 L
.28875 .32144 L
.28875 .08012 L
F
.2 .63 .79 r
.28742 .08012 m
.28742 .32144 L
.28875 .32144 L
.28875 .08012 L
s
.678 .847 .902 r
.28875 .08012 m
.28875 .32111 L
.29007 .32111 L
.29007 .08012 L
F
.2 .63 .79 r
.28875 .08012 m
.28875 .32111 L
.29007 .32111 L
.29007 .08012 L
s
.678 .847 .902 r
.29007 .08012 m
.29007 .31982 L
.29126 .31982 L
.29126 .08012 L
F
.2 .63 .79 r
.29007 .08012 m
.29007 .31982 L
.29126 .31982 L
.29126 .08012 L
s
.678 .847 .902 r
.29126 .08012 m
.29126 .31896 L
.29316 .31896 L
.29316 .08012 L
F
.2 .63 .79 r
.29126 .08012 m
.29126 .31896 L
.29316 .31896 L
.29316 .08012 L
s
.678 .847 .902 r
.29316 .08012 m
.29316 .31728 L
.29425 .31728 L
.29425 .08012 L
F
.2 .63 .79 r
.29316 .08012 m
.29316 .31728 L
.29425 .31728 L
.29425 .08012 L
s
.678 .847 .902 r
.29425 .08012 m
.29425 .31634 L
.29606 .31634 L
.29606 .08012 L
F
.2 .63 .79 r
.29425 .08012 m
.29425 .31634 L
.29606 .31634 L
.29606 .08012 L
s
.678 .847 .902 r
.29606 .08012 m
.29606 .31448 L
.29727 .31448 L
.29727 .08012 L
F
.2 .63 .79 r
.29606 .08012 m
.29606 .31448 L
.29727 .31448 L
.29727 .08012 L
s
.678 .847 .902 r
.29727 .08012 m
.29727 .31343 L
.29793 .31343 L
.29793 .08012 L
F
.2 .63 .79 r
.29727 .08012 m
.29727 .31343 L
.29793 .31343 L
.29793 .08012 L
s
.678 .847 .902 r
.29793 .08012 m
.29793 .31211 L
.29988 .31211 L
.29988 .08012 L
F
.2 .63 .79 r
.29793 .08012 m
.29793 .31211 L
.29988 .31211 L
.29988 .08012 L
s
.678 .847 .902 r
.29988 .08012 m
.29988 .31004 L
.30172 .31004 L
.30172 .08012 L
F
.2 .63 .79 r
.29988 .08012 m
.29988 .31004 L
.30172 .31004 L
.30172 .08012 L
s
.678 .847 .902 r
.30172 .08012 m
.30172 .30886 L
.30316 .30886 L
.30316 .08012 L
F
.2 .63 .79 r
.30172 .08012 m
.30172 .30886 L
.30316 .30886 L
.30316 .08012 L
s
.678 .847 .902 r
.30316 .08012 m
.30316 .30852 L
.30499 .30852 L
.30499 .08012 L
F
.2 .63 .79 r
.30316 .08012 m
.30316 .30852 L
.30499 .30852 L
.30499 .08012 L
s
.678 .847 .902 r
.30499 .08012 m
.30499 .30598 L
.30692 .30598 L
.30692 .08012 L
F
.2 .63 .79 r
.30499 .08012 m
.30499 .30598 L
.30692 .30598 L
.30692 .08012 L
s
.678 .847 .902 r
.30692 .08012 m
.30692 .30489 L
.30797 .30489 L
.30797 .08012 L
F
.2 .63 .79 r
.30692 .08012 m
.30692 .30489 L
.30797 .30489 L
.30797 .08012 L
s
.678 .847 .902 r
.30797 .08012 m
.30797 .30424 L
.30872 .30424 L
.30872 .08012 L
F
.2 .63 .79 r
.30797 .08012 m
.30797 .30424 L
.30872 .30424 L
.30872 .08012 L
s
.678 .847 .902 r
.30872 .08012 m
.30872 .30381 L
.30941 .30381 L
.30941 .08012 L
F
.2 .63 .79 r
.30872 .08012 m
.30872 .30381 L
.30941 .30381 L
.30941 .08012 L
s
.678 .847 .902 r
.30941 .08012 m
.30941 .30293 L
.31032 .30293 L
.31032 .08012 L
F
.2 .63 .79 r
.30941 .08012 m
.30941 .30293 L
.31032 .30293 L
.31032 .08012 L
s
.678 .847 .902 r
.31032 .08012 m
.31032 .30128 L
.31212 .30128 L
.31212 .08012 L
F
.2 .63 .79 r
.31032 .08012 m
.31032 .30128 L
.31212 .30128 L
.31212 .08012 L
s
.678 .847 .902 r
.31212 .08012 m
.31212 .30053 L
.31276 .30053 L
.31276 .08012 L
F
.2 .63 .79 r
.31212 .08012 m
.31212 .30053 L
.31276 .30053 L
.31276 .08012 L
s
.678 .847 .902 r
.31276 .08012 m
.31276 .30013 L
.31391 .30013 L
.31391 .08012 L
F
.2 .63 .79 r
.31276 .08012 m
.31276 .30013 L
.31391 .30013 L
.31391 .08012 L
s
.678 .847 .902 r
.31391 .08012 m
.31391 .29825 L
.31531 .29825 L
.31531 .08012 L
F
.2 .63 .79 r
.31391 .08012 m
.31391 .29825 L
.31531 .29825 L
.31531 .08012 L
s
.678 .847 .902 r
.31531 .08012 m
.31531 .2975 L
.31643 .2975 L
.31643 .08012 L
F
.2 .63 .79 r
.31531 .08012 m
.31531 .2975 L
.31643 .2975 L
.31643 .08012 L
s
.678 .847 .902 r
.31643 .08012 m
.31643 .29617 L
.31787 .29617 L
.31787 .08012 L
F
.2 .63 .79 r
.31643 .08012 m
.31643 .29617 L
.31787 .29617 L
.31787 .08012 L
s
.678 .847 .902 r
.31787 .08012 m
.31787 .29578 L
.3197 .29578 L
.3197 .08012 L
F
.2 .63 .79 r
.31787 .08012 m
.31787 .29578 L
.3197 .29578 L
.3197 .08012 L
s
.678 .847 .902 r
.3197 .08012 m
.3197 .29382 L
.3204 .29382 L
.3204 .08012 L
F
.2 .63 .79 r
.3197 .08012 m
.3197 .29382 L
.3204 .29382 L
.3204 .08012 L
s
.678 .847 .902 r
.3204 .08012 m
.3204 .29309 L
.32229 .29309 L
.32229 .08012 L
F
.2 .63 .79 r
.3204 .08012 m
.3204 .29309 L
.32229 .29309 L
.32229 .08012 L
s
.678 .847 .902 r
.32229 .08012 m
.32229 .29185 L
.32317 .29185 L
.32317 .08012 L
F
.2 .63 .79 r
.32229 .08012 m
.32229 .29185 L
.32317 .29185 L
.32317 .08012 L
s
.678 .847 .902 r
.32317 .08012 m
.32317 .28975 L
.32518 .28975 L
.32518 .08012 L
F
.2 .63 .79 r
.32317 .08012 m
.32317 .28975 L
.32518 .28975 L
.32518 .08012 L
s
.678 .847 .902 r
.32518 .08012 m
.32518 .28864 L
.32688 .28864 L
.32688 .08012 L
F
.2 .63 .79 r
.32518 .08012 m
.32518 .28864 L
.32688 .28864 L
.32688 .08012 L
s
.678 .847 .902 r
.32688 .08012 m
.32688 .2881 L
.32759 .2881 L
.32759 .08012 L
F
.2 .63 .79 r
.32688 .08012 m
.32688 .2881 L
.32759 .2881 L
.32759 .08012 L
s
.678 .847 .902 r
.32759 .08012 m
.32759 .28762 L
.32935 .28762 L
.32935 .08012 L
F
.2 .63 .79 r
.32759 .08012 m
.32759 .28762 L
.32935 .28762 L
.32935 .08012 L
s
.678 .847 .902 r
.32935 .08012 m
.32935 .28571 L
.33132 .28571 L
.33132 .08012 L
F
.2 .63 .79 r
.32935 .08012 m
.32935 .28571 L
.33132 .28571 L
.33132 .08012 L
s
.678 .847 .902 r
.33132 .08012 m
.33132 .28442 L
.33318 .28442 L
.33318 .08012 L
F
.2 .63 .79 r
.33132 .08012 m
.33132 .28442 L
.33318 .28442 L
.33318 .08012 L
s
.678 .847 .902 r
.33318 .08012 m
.33318 .2827 L
.33412 .2827 L
.33412 .08012 L
F
.2 .63 .79 r
.33318 .08012 m
.33318 .2827 L
.33412 .2827 L
.33412 .08012 L
s
.678 .847 .902 r
.33412 .08012 m
.33412 .28206 L
.33508 .28206 L
.33508 .08012 L
F
.2 .63 .79 r
.33412 .08012 m
.33412 .28206 L
.33508 .28206 L
.33508 .08012 L
s
.678 .847 .902 r
.33508 .08012 m
.33508 .2813 L
.33585 .2813 L
.33585 .08012 L
F
.2 .63 .79 r
.33508 .08012 m
.33508 .2813 L
.33585 .2813 L
.33585 .08012 L
s
.678 .847 .902 r
.33585 .08012 m
.33585 .28004 L
.33786 .28004 L
.33786 .08012 L
F
.2 .63 .79 r
.33585 .08012 m
.33585 .28004 L
.33786 .28004 L
.33786 .08012 L
s
.678 .847 .902 r
.33786 .08012 m
.33786 .27771 L
.33985 .27771 L
.33985 .08012 L
F
.2 .63 .79 r
.33786 .08012 m
.33786 .27771 L
.33985 .27771 L
.33985 .08012 L
s
.678 .847 .902 r
.33985 .08012 m
.33985 .2769 L
.34068 .2769 L
.34068 .08012 L
F
.2 .63 .79 r
.33985 .08012 m
.33985 .2769 L
.34068 .2769 L
.34068 .08012 L
s
.678 .847 .902 r
.34068 .08012 m
.34068 .27669 L
.34139 .27669 L
.34139 .08012 L
F
.2 .63 .79 r
.34068 .08012 m
.34068 .27669 L
.34139 .27669 L
.34139 .08012 L
s
.678 .847 .902 r
.34139 .08012 m
.34139 .27611 L
.34312 .27611 L
.34312 .08012 L
F
.2 .63 .79 r
.34139 .08012 m
.34139 .27611 L
.34312 .27611 L
.34312 .08012 L
s
.678 .847 .902 r
.34312 .08012 m
.34312 .27472 L
.34394 .27472 L
.34394 .08012 L
F
.2 .63 .79 r
.34312 .08012 m
.34312 .27472 L
.34394 .27472 L
.34394 .08012 L
s
.678 .847 .902 r
.34394 .08012 m
.34394 .27398 L
.34475 .27398 L
.34475 .08012 L
F
.2 .63 .79 r
.34394 .08012 m
.34394 .27398 L
.34475 .27398 L
.34475 .08012 L
s
.678 .847 .902 r
.34475 .08012 m
.34475 .27213 L
.3464 .27213 L
.3464 .08012 L
F
.2 .63 .79 r
.34475 .08012 m
.34475 .27213 L
.3464 .27213 L
.3464 .08012 L
s
.678 .847 .902 r
.3464 .08012 m
.3464 .27198 L
.34736 .27198 L
.34736 .08012 L
F
.2 .63 .79 r
.3464 .08012 m
.3464 .27198 L
.34736 .27198 L
.34736 .08012 L
s
.678 .847 .902 r
.34736 .08012 m
.34736 .27068 L
.34915 .27068 L
.34915 .08012 L
F
.2 .63 .79 r
.34736 .08012 m
.34736 .27068 L
.34915 .27068 L
.34915 .08012 L
s
.678 .847 .902 r
.34915 .08012 m
.34915 .26941 L
.35061 .26941 L
.35061 .08012 L
F
.2 .63 .79 r
.34915 .08012 m
.34915 .26941 L
.35061 .26941 L
.35061 .08012 L
s
.678 .847 .902 r
.35061 .08012 m
.35061 .26733 L
.35252 .26733 L
.35252 .08012 L
F
.2 .63 .79 r
.35061 .08012 m
.35061 .26733 L
.35252 .26733 L
.35252 .08012 L
s
.678 .847 .902 r
.35252 .08012 m
.35252 .26698 L
.35341 .26698 L
.35341 .08012 L
F
.2 .63 .79 r
.35252 .08012 m
.35252 .26698 L
.35341 .26698 L
.35341 .08012 L
s
.678 .847 .902 r
.35341 .08012 m
.35341 .26481 L
.3554 .26481 L
.3554 .08012 L
F
.2 .63 .79 r
.35341 .08012 m
.35341 .26481 L
.3554 .26481 L
.3554 .08012 L
s
.678 .847 .902 r
.3554 .08012 m
.3554 .2639 L
.3566 .2639 L
.3566 .08012 L
F
.2 .63 .79 r
.3554 .08012 m
.3554 .2639 L
.3566 .2639 L
.3566 .08012 L
s
.678 .847 .902 r
.3566 .08012 m
.3566 .26244 L
.3586 .26244 L
.3586 .08012 L
F
.2 .63 .79 r
.3566 .08012 m
.3566 .26244 L
.3586 .26244 L
.3586 .08012 L
s
.678 .847 .902 r
.3586 .08012 m
.3586 .26179 L
.35987 .26179 L
.35987 .08012 L
F
.2 .63 .79 r
.3586 .08012 m
.3586 .26179 L
.35987 .26179 L
.35987 .08012 L
s
.678 .847 .902 r
.35987 .08012 m
.35987 .26021 L
.36178 .26021 L
.36178 .08012 L
F
.2 .63 .79 r
.35987 .08012 m
.35987 .26021 L
.36178 .26021 L
.36178 .08012 L
s
.678 .847 .902 r
.36178 .08012 m
.36178 .25863 L
.36332 .25863 L
.36332 .08012 L
F
.2 .63 .79 r
.36178 .08012 m
.36178 .25863 L
.36332 .25863 L
.36332 .08012 L
s
.678 .847 .902 r
.36332 .08012 m
.36332 .25817 L
.36397 .25817 L
.36397 .08012 L
F
.2 .63 .79 r
.36332 .08012 m
.36332 .25817 L
.36397 .25817 L
.36397 .08012 L
s
.678 .847 .902 r
.36397 .08012 m
.36397 .25755 L
.36547 .25755 L
.36547 .08012 L
F
.2 .63 .79 r
.36397 .08012 m
.36397 .25755 L
.36547 .25755 L
.36547 .08012 L
s
.678 .847 .902 r
.36547 .08012 m
.36547 .25646 L
.36707 .25646 L
.36707 .08012 L
F
.2 .63 .79 r
.36547 .08012 m
.36547 .25646 L
.36707 .25646 L
.36707 .08012 L
s
.678 .847 .902 r
.36707 .08012 m
.36707 .25488 L
.36827 .25488 L
.36827 .08012 L
F
.2 .63 .79 r
.36707 .08012 m
.36707 .25488 L
.36827 .25488 L
.36827 .08012 L
s
.678 .847 .902 r
.36827 .08012 m
.36827 .25401 L
.37025 .25401 L
.37025 .08012 L
F
.2 .63 .79 r
.36827 .08012 m
.36827 .25401 L
.37025 .25401 L
.37025 .08012 L
s
.678 .847 .902 r
.37025 .08012 m
.37025 .2519 L
.37183 .2519 L
.37183 .08012 L
F
.2 .63 .79 r
.37025 .08012 m
.37025 .2519 L
.37183 .2519 L
.37183 .08012 L
s
.678 .847 .902 r
.37183 .08012 m
.37183 .25125 L
.37353 .25125 L
.37353 .08012 L
F
.2 .63 .79 r
.37183 .08012 m
.37183 .25125 L
.37353 .25125 L
.37353 .08012 L
s
.678 .847 .902 r
.37353 .08012 m
.37353 .2498 L
.37453 .2498 L
.37453 .08012 L
F
.2 .63 .79 r
.37353 .08012 m
.37353 .2498 L
.37453 .2498 L
.37453 .08012 L
s
.678 .847 .902 r
.37453 .08012 m
.37453 .24941 L
.37643 .24941 L
.37643 .08012 L
F
.2 .63 .79 r
.37453 .08012 m
.37453 .24941 L
.37643 .24941 L
.37643 .08012 L
s
.678 .847 .902 r
.37643 .08012 m
.37643 .24695 L
.37837 .24695 L
.37837 .08012 L
F
.2 .63 .79 r
.37643 .08012 m
.37643 .24695 L
.37837 .24695 L
.37837 .08012 L
s
.678 .847 .902 r
.37837 .08012 m
.37837 .24635 L
.37987 .24635 L
.37987 .08012 L
F
.2 .63 .79 r
.37837 .08012 m
.37837 .24635 L
.37987 .24635 L
.37987 .08012 L
s
.678 .847 .902 r
.37987 .08012 m
.37987 .24512 L
.38068 .24512 L
.38068 .08012 L
F
.2 .63 .79 r
.37987 .08012 m
.37987 .24512 L
.38068 .24512 L
.38068 .08012 L
s
.678 .847 .902 r
.38068 .08012 m
.38068 .24473 L
.38156 .24473 L
.38156 .08012 L
F
.2 .63 .79 r
.38068 .08012 m
.38068 .24473 L
.38156 .24473 L
.38156 .08012 L
s
.678 .847 .902 r
.38156 .08012 m
.38156 .24338 L
.38317 .24338 L
.38317 .08012 L
F
.2 .63 .79 r
.38156 .08012 m
.38156 .24338 L
.38317 .24338 L
.38317 .08012 L
s
.678 .847 .902 r
.38317 .08012 m
.38317 .2418 L
.38498 .2418 L
.38498 .08012 L
F
.2 .63 .79 r
.38317 .08012 m
.38317 .2418 L
.38498 .2418 L
.38498 .08012 L
s
.678 .847 .902 r
.38498 .08012 m
.38498 .24134 L
.38642 .24134 L
.38642 .08012 L
F
.2 .63 .79 r
.38498 .08012 m
.38498 .24134 L
.38642 .24134 L
.38642 .08012 L
s
.678 .847 .902 r
.38642 .08012 m
.38642 .24019 L
.38747 .24019 L
.38747 .08012 L
F
.2 .63 .79 r
.38642 .08012 m
.38642 .24019 L
.38747 .24019 L
.38747 .08012 L
s
.678 .847 .902 r
.38747 .08012 m
.38747 .23919 L
.38882 .23919 L
.38882 .08012 L
F
.2 .63 .79 r
.38747 .08012 m
.38747 .23919 L
.38882 .23919 L
.38882 .08012 L
s
.678 .847 .902 r
.38882 .08012 m
.38882 .23742 L
.39073 .23742 L
.39073 .08012 L
F
.2 .63 .79 r
.38882 .08012 m
.38882 .23742 L
.39073 .23742 L
.39073 .08012 L
s
.678 .847 .902 r
.39073 .08012 m
.39073 .23698 L
.39159 .23698 L
.39159 .08012 L
F
.2 .63 .79 r
.39073 .08012 m
.39073 .23698 L
.39159 .23698 L
.39159 .08012 L
s
.678 .847 .902 r
.39159 .08012 m
.39159 .23612 L
.39274 .23612 L
.39274 .08012 L
F
.2 .63 .79 r
.39159 .08012 m
.39159 .23612 L
.39274 .23612 L
.39274 .08012 L
s
.678 .847 .902 r
.39274 .08012 m
.39274 .23509 L
.39345 .23509 L
.39345 .08012 L
F
.2 .63 .79 r
.39274 .08012 m
.39274 .23509 L
.39345 .23509 L
.39345 .08012 L
s
.678 .847 .902 r
.39345 .08012 m
.39345 .23483 L
.39553 .23483 L
.39553 .08012 L
F
.2 .63 .79 r
.39345 .08012 m
.39345 .23483 L
.39553 .23483 L
.39553 .08012 L
s
.678 .847 .902 r
.39553 .08012 m
.39553 .2331 L
.39695 .2331 L
.39695 .08012 L
F
.2 .63 .79 r
.39553 .08012 m
.39553 .2331 L
.39695 .2331 L
.39695 .08012 L
s
.678 .847 .902 r
.39695 .08012 m
.39695 .23171 L
.39807 .23171 L
.39807 .08012 L
F
.2 .63 .79 r
.39695 .08012 m
.39695 .23171 L
.39807 .23171 L
.39807 .08012 L
s
.678 .847 .902 r
.39807 .08012 m
.39807 .23095 L
.39937 .23095 L
.39937 .08012 L
F
.2 .63 .79 r
.39807 .08012 m
.39807 .23095 L
.39937 .23095 L
.39937 .08012 L
s
.678 .847 .902 r
.39937 .08012 m
.39937 .22986 L
.40048 .22986 L
.40048 .08012 L
F
.2 .63 .79 r
.39937 .08012 m
.39937 .22986 L
.40048 .22986 L
.40048 .08012 L
s
.678 .847 .902 r
.40048 .08012 m
.40048 .22933 L
.40133 .22933 L
.40133 .08012 L
F
.2 .63 .79 r
.40048 .08012 m
.40048 .22933 L
.40133 .22933 L
.40133 .08012 L
s
.678 .847 .902 r
.40133 .08012 m
.40133 .22868 L
.40256 .22868 L
.40256 .08012 L
F
.2 .63 .79 r
.40133 .08012 m
.40133 .22868 L
.40256 .22868 L
.40256 .08012 L
s
.678 .847 .902 r
.40256 .08012 m
.40256 .22718 L
.40437 .22718 L
.40437 .08012 L
F
.2 .63 .79 r
.40256 .08012 m
.40256 .22718 L
.40437 .22718 L
.40437 .08012 L
s
.678 .847 .902 r
.40437 .08012 m
.40437 .22628 L
.40588 .22628 L
.40588 .08012 L
F
.2 .63 .79 r
.40437 .08012 m
.40437 .22628 L
.40588 .22628 L
.40588 .08012 L
s
.678 .847 .902 r
.40588 .08012 m
.40588 .2244 L
.40781 .2244 L
.40781 .08012 L
F
.2 .63 .79 r
.40588 .08012 m
.40588 .2244 L
.40781 .2244 L
.40781 .08012 L
s
.678 .847 .902 r
.40781 .08012 m
.40781 .22396 L
.40924 .22396 L
.40924 .08012 L
F
.2 .63 .79 r
.40781 .08012 m
.40781 .22396 L
.40924 .22396 L
.40924 .08012 L
s
.678 .847 .902 r
.40924 .08012 m
.40924 .2233 L
.41119 .2233 L
.41119 .08012 L
F
.2 .63 .79 r
.40924 .08012 m
.40924 .2233 L
.41119 .2233 L
.41119 .08012 L
s
.678 .847 .902 r
.41119 .08012 m
.41119 .22173 L
.41183 .22173 L
.41183 .08012 L
F
.2 .63 .79 r
.41119 .08012 m
.41119 .22173 L
.41183 .22173 L
.41183 .08012 L
s
.678 .847 .902 r
.41183 .08012 m
.41183 .22089 L
.41357 .22089 L
.41357 .08012 L
F
.2 .63 .79 r
.41183 .08012 m
.41183 .22089 L
.41357 .22089 L
.41357 .08012 L
s
.678 .847 .902 r
.41357 .08012 m
.41357 .21994 L
.41475 .21994 L
.41475 .08012 L
F
.2 .63 .79 r
.41357 .08012 m
.41357 .21994 L
.41475 .21994 L
.41475 .08012 L
s
.678 .847 .902 r
.41475 .08012 m
.41475 .21901 L
.41572 .21901 L
.41572 .08012 L
F
.2 .63 .79 r
.41475 .08012 m
.41475 .21901 L
.41572 .21901 L
.41572 .08012 L
s
.678 .847 .902 r
.41572 .08012 m
.41572 .21823 L
.41664 .21823 L
.41664 .08012 L
F
.2 .63 .79 r
.41572 .08012 m
.41572 .21823 L
.41664 .21823 L
.41664 .08012 L
s
.678 .847 .902 r
.41664 .08012 m
.41664 .21774 L
.41757 .21774 L
.41757 .08012 L
F
.2 .63 .79 r
.41664 .08012 m
.41664 .21774 L
.41757 .21774 L
.41757 .08012 L
s
.678 .847 .902 r
.41757 .08012 m
.41757 .21672 L
.41833 .21672 L
.41833 .08012 L
F
.2 .63 .79 r
.41757 .08012 m
.41757 .21672 L
.41833 .21672 L
.41833 .08012 L
s
.678 .847 .902 r
.41833 .08012 m
.41833 .21552 L
.42003 .21552 L
.42003 .08012 L
F
.2 .63 .79 r
.41833 .08012 m
.41833 .21552 L
.42003 .21552 L
.42003 .08012 L
s
.678 .847 .902 r
.42003 .08012 m
.42003 .21489 L
.42114 .21489 L
.42114 .08012 L
F
.2 .63 .79 r
.42003 .08012 m
.42003 .21489 L
.42114 .21489 L
.42114 .08012 L
s
.678 .847 .902 r
.42114 .08012 m
.42114 .21415 L
.42183 .21415 L
.42183 .08012 L
F
.2 .63 .79 r
.42114 .08012 m
.42114 .21415 L
.42183 .21415 L
.42183 .08012 L
s
.678 .847 .902 r
.42183 .08012 m
.42183 .21355 L
.42353 .21355 L
.42353 .08012 L
F
.2 .63 .79 r
.42183 .08012 m
.42183 .21355 L
.42353 .21355 L
.42353 .08012 L
s
.678 .847 .902 r
.42353 .08012 m
.42353 .21183 L
.42515 .21183 L
.42515 .08012 L
F
.2 .63 .79 r
.42353 .08012 m
.42353 .21183 L
.42515 .21183 L
.42515 .08012 L
s
.678 .847 .902 r
.42515 .08012 m
.42515 .21134 L
.42627 .21134 L
.42627 .08012 L
F
.2 .63 .79 r
.42515 .08012 m
.42515 .21134 L
.42627 .21134 L
.42627 .08012 L
s
.678 .847 .902 r
.42627 .08012 m
.42627 .21038 L
.42763 .21038 L
.42763 .08012 L
F
.2 .63 .79 r
.42627 .08012 m
.42627 .21038 L
.42763 .21038 L
.42763 .08012 L
s
.678 .847 .902 r
.42763 .08012 m
.42763 .20946 L
.42884 .20946 L
.42884 .08012 L
F
.2 .63 .79 r
.42763 .08012 m
.42763 .20946 L
.42884 .20946 L
.42884 .08012 L
s
.678 .847 .902 r
.42884 .08012 m
.42884 .20895 L
.42979 .20895 L
.42979 .08012 L
F
.2 .63 .79 r
.42884 .08012 m
.42884 .20895 L
.42979 .20895 L
.42979 .08012 L
s
.678 .847 .902 r
.42979 .08012 m
.42979 .20819 L
.43042 .20819 L
.43042 .08012 L
F
.2 .63 .79 r
.42979 .08012 m
.42979 .20819 L
.43042 .20819 L
.43042 .08012 L
s
.678 .847 .902 r
.43042 .08012 m
.43042 .20732 L
.43157 .20732 L
.43157 .08012 L
F
.2 .63 .79 r
.43042 .08012 m
.43042 .20732 L
.43157 .20732 L
.43157 .08012 L
s
.678 .847 .902 r
.43157 .08012 m
.43157 .20707 L
.43363 .20707 L
.43363 .08012 L
F
.2 .63 .79 r
.43157 .08012 m
.43157 .20707 L
.43363 .20707 L
.43363 .08012 L
s
.678 .847 .902 r
.43363 .08012 m
.43363 .20533 L
.43486 .20533 L
.43486 .08012 L
F
.2 .63 .79 r
.43363 .08012 m
.43363 .20533 L
.43486 .20533 L
.43486 .08012 L
s
.678 .847 .902 r
.43486 .08012 m
.43486 .20484 L
.43608 .20484 L
.43608 .08012 L
F
.2 .63 .79 r
.43486 .08012 m
.43486 .20484 L
.43608 .20484 L
.43608 .08012 L
s
.678 .847 .902 r
.43608 .08012 m
.43608 .20322 L
.43738 .20322 L
.43738 .08012 L
F
.2 .63 .79 r
.43608 .08012 m
.43608 .20322 L
.43738 .20322 L
.43738 .08012 L
s
.678 .847 .902 r
.43738 .08012 m
.43738 .20249 L
.43864 .20249 L
.43864 .08012 L
F
.2 .63 .79 r
.43738 .08012 m
.43738 .20249 L
.43864 .20249 L
.43864 .08012 L
s
.678 .847 .902 r
.43864 .08012 m
.43864 .20177 L
.44001 .20177 L
.44001 .08012 L
F
.2 .63 .79 r
.43864 .08012 m
.43864 .20177 L
.44001 .20177 L
.44001 .08012 L
s
.678 .847 .902 r
.44001 .08012 m
.44001 .20066 L
.44122 .20066 L
.44122 .08012 L
F
.2 .63 .79 r
.44001 .08012 m
.44001 .20066 L
.44122 .20066 L
.44122 .08012 L
s
.678 .847 .902 r
.44122 .08012 m
.44122 .1999 L
.44287 .1999 L
.44287 .08012 L
F
.2 .63 .79 r
.44122 .08012 m
.44122 .1999 L
.44287 .1999 L
.44287 .08012 L
s
.678 .847 .902 r
.44287 .08012 m
.44287 .19905 L
.44358 .19905 L
.44358 .08012 L
F
.2 .63 .79 r
.44287 .08012 m
.44287 .19905 L
.44358 .19905 L
.44358 .08012 L
s
.678 .847 .902 r
.44358 .08012 m
.44358 .19872 L
.44461 .19872 L
.44461 .08012 L
F
.2 .63 .79 r
.44358 .08012 m
.44358 .19872 L
.44461 .19872 L
.44461 .08012 L
s
.678 .847 .902 r
.44461 .08012 m
.44461 .19795 L
.44551 .19795 L
.44551 .08012 L
F
.2 .63 .79 r
.44461 .08012 m
.44461 .19795 L
.44551 .19795 L
.44551 .08012 L
s
.678 .847 .902 r
.44551 .08012 m
.44551 .19724 L
.44687 .19724 L
.44687 .08012 L
F
.2 .63 .79 r
.44551 .08012 m
.44551 .19724 L
.44687 .19724 L
.44687 .08012 L
s
.678 .847 .902 r
.44687 .08012 m
.44687 .19573 L
.44891 .19573 L
.44891 .08012 L
F
.2 .63 .79 r
.44687 .08012 m
.44687 .19573 L
.44891 .19573 L
.44891 .08012 L
s
.678 .847 .902 r
.44891 .08012 m
.44891 .19497 L
.45032 .19497 L
.45032 .08012 L
F
.2 .63 .79 r
.44891 .08012 m
.44891 .19497 L
.45032 .19497 L
.45032 .08012 L
s
.678 .847 .902 r
.45032 .08012 m
.45032 .19347 L
.45221 .19347 L
.45221 .08012 L
F
.2 .63 .79 r
.45032 .08012 m
.45032 .19347 L
.45221 .19347 L
.45221 .08012 L
s
.678 .847 .902 r
.45221 .08012 m
.45221 .19265 L
.4535 .19265 L
.4535 .08012 L
F
.2 .63 .79 r
.45221 .08012 m
.45221 .19265 L
.4535 .19265 L
.4535 .08012 L
s
.678 .847 .902 r
.4535 .08012 m
.4535 .19195 L
.45447 .19195 L
.45447 .08012 L
F
.2 .63 .79 r
.4535 .08012 m
.4535 .19195 L
.45447 .19195 L
.45447 .08012 L
s
.678 .847 .902 r
.45447 .08012 m
.45447 .19105 L
.45636 .19105 L
.45636 .08012 L
F
.2 .63 .79 r
.45447 .08012 m
.45447 .19105 L
.45636 .19105 L
.45636 .08012 L
s
.678 .847 .902 r
.45636 .08012 m
.45636 .19006 L
.45775 .19006 L
.45775 .08012 L
F
.2 .63 .79 r
.45636 .08012 m
.45636 .19006 L
.45775 .19006 L
.45775 .08012 L
s
.678 .847 .902 r
.45775 .08012 m
.45775 .18822 L
.45977 .18822 L
.45977 .08012 L
F
.2 .63 .79 r
.45775 .08012 m
.45775 .18822 L
.45977 .18822 L
.45977 .08012 L
s
.678 .847 .902 r
.45977 .08012 m
.45977 .1872 L
.46162 .1872 L
.46162 .08012 L
F
.2 .63 .79 r
.45977 .08012 m
.45977 .1872 L
.46162 .1872 L
.46162 .08012 L
s
.678 .847 .902 r
.46162 .08012 m
.46162 .18554 L
.46319 .18554 L
.46319 .08012 L
F
.2 .63 .79 r
.46162 .08012 m
.46162 .18554 L
.46319 .18554 L
.46319 .08012 L
s
.678 .847 .902 r
.46319 .08012 m
.46319 .18512 L
.46458 .18512 L
.46458 .08012 L
F
.2 .63 .79 r
.46319 .08012 m
.46319 .18512 L
.46458 .18512 L
.46458 .08012 L
s
.678 .847 .902 r
.46458 .08012 m
.46458 .18375 L
.46608 .18375 L
.46608 .08012 L
F
.2 .63 .79 r
.46458 .08012 m
.46458 .18375 L
.46608 .18375 L
.46608 .08012 L
s
.678 .847 .902 r
.46608 .08012 m
.46608 .1831 L
.46796 .1831 L
.46796 .08012 L
F
.2 .63 .79 r
.46608 .08012 m
.46608 .1831 L
.46796 .1831 L
.46796 .08012 L
s
.678 .847 .902 r
.46796 .08012 m
.46796 .18203 L
.46892 .18203 L
.46892 .08012 L
F
.2 .63 .79 r
.46796 .08012 m
.46796 .18203 L
.46892 .18203 L
.46892 .08012 L
s
.678 .847 .902 r
.46892 .08012 m
.46892 .18151 L
.46972 .18151 L
.46972 .08012 L
F
.2 .63 .79 r
.46892 .08012 m
.46892 .18151 L
.46972 .18151 L
.46972 .08012 L
s
.678 .847 .902 r
.46972 .08012 m
.46972 .18066 L
.47054 .18066 L
.47054 .08012 L
F
.2 .63 .79 r
.46972 .08012 m
.46972 .18066 L
.47054 .18066 L
.47054 .08012 L
s
.678 .847 .902 r
.47054 .08012 m
.47054 .18008 L
.47179 .18008 L
.47179 .08012 L
F
.2 .63 .79 r
.47054 .08012 m
.47054 .18008 L
.47179 .18008 L
.47179 .08012 L
s
.678 .847 .902 r
.47179 .08012 m
.47179 .17872 L
.47347 .17872 L
.47347 .08012 L
F
.2 .63 .79 r
.47179 .08012 m
.47179 .17872 L
.47347 .17872 L
.47347 .08012 L
s
.678 .847 .902 r
.47347 .08012 m
.47347 .17802 L
.47516 .17802 L
.47516 .08012 L
F
.2 .63 .79 r
.47347 .08012 m
.47347 .17802 L
.47516 .17802 L
.47516 .08012 L
s
.678 .847 .902 r
.47516 .08012 m
.47516 .17723 L
.47641 .17723 L
.47641 .08012 L
F
.2 .63 .79 r
.47516 .08012 m
.47516 .17723 L
.47641 .17723 L
.47641 .08012 L
s
.678 .847 .902 r
.47641 .08012 m
.47641 .17667 L
.47759 .17667 L
.47759 .08012 L
F
.2 .63 .79 r
.47641 .08012 m
.47641 .17667 L
.47759 .17667 L
.47759 .08012 L
s
.678 .847 .902 r
.47759 .08012 m
.47759 .17532 L
.47887 .17532 L
.47887 .08012 L
F
.2 .63 .79 r
.47759 .08012 m
.47759 .17532 L
.47887 .17532 L
.47887 .08012 L
s
.678 .847 .902 r
.47887 .08012 m
.47887 .17485 L
.48027 .17485 L
.48027 .08012 L
F
.2 .63 .79 r
.47887 .08012 m
.47887 .17485 L
.48027 .17485 L
.48027 .08012 L
s
.678 .847 .902 r
.48027 .08012 m
.48027 .17402 L
.48226 .17402 L
.48226 .08012 L
F
.2 .63 .79 r
.48027 .08012 m
.48027 .17402 L
.48226 .17402 L
.48226 .08012 L
s
.678 .847 .902 r
.48226 .08012 m
.48226 .17256 L
.48349 .17256 L
.48349 .08012 L
F
.2 .63 .79 r
.48226 .08012 m
.48226 .17256 L
.48349 .17256 L
.48349 .08012 L
s
.678 .847 .902 r
.48349 .08012 m
.48349 .17137 L
.48544 .17137 L
.48544 .08012 L
F
.2 .63 .79 r
.48349 .08012 m
.48349 .17137 L
.48544 .17137 L
.48544 .08012 L
s
.678 .847 .902 r
.48544 .08012 m
.48544 .17012 L
.48705 .17012 L
.48705 .08012 L
F
.2 .63 .79 r
.48544 .08012 m
.48544 .17012 L
.48705 .17012 L
.48705 .08012 L
s
.678 .847 .902 r
.48705 .08012 m
.48705 .16917 L
.48837 .16917 L
.48837 .08012 L
F
.2 .63 .79 r
.48705 .08012 m
.48705 .16917 L
.48837 .16917 L
.48837 .08012 L
s
.678 .847 .902 r
.48837 .08012 m
.48837 .16885 L
.48926 .16885 L
.48926 .08012 L
F
.2 .63 .79 r
.48837 .08012 m
.48837 .16885 L
.48926 .16885 L
.48926 .08012 L
s
.678 .847 .902 r
.48926 .08012 m
.48926 .16837 L
.48995 .16837 L
.48995 .08012 L
F
.2 .63 .79 r
.48926 .08012 m
.48926 .16837 L
.48995 .16837 L
.48995 .08012 L
s
.678 .847 .902 r
.48995 .08012 m
.48995 .16769 L
.4908 .16769 L
.4908 .08012 L
F
.2 .63 .79 r
.48995 .08012 m
.48995 .16769 L
.4908 .16769 L
.4908 .08012 L
s
.678 .847 .902 r
.4908 .08012 m
.4908 .16736 L
.49219 .16736 L
.49219 .08012 L
F
.2 .63 .79 r
.4908 .08012 m
.4908 .16736 L
.49219 .16736 L
.49219 .08012 L
s
.678 .847 .902 r
.49219 .08012 m
.49219 .1667 L
.49332 .1667 L
.49332 .08012 L
F
.2 .63 .79 r
.49219 .08012 m
.49219 .1667 L
.49332 .1667 L
.49332 .08012 L
s
.678 .847 .902 r
.49332 .08012 m
.49332 .16563 L
.49453 .16563 L
.49453 .08012 L
F
.2 .63 .79 r
.49332 .08012 m
.49332 .16563 L
.49453 .16563 L
.49453 .08012 L
s
.678 .847 .902 r
.49453 .08012 m
.49453 .16484 L
.49608 .16484 L
.49608 .08012 L
F
.2 .63 .79 r
.49453 .08012 m
.49453 .16484 L
.49608 .16484 L
.49608 .08012 L
s
.678 .847 .902 r
.49608 .08012 m
.49608 .16373 L
.49806 .16373 L
.49806 .08012 L
F
.2 .63 .79 r
.49608 .08012 m
.49608 .16373 L
.49806 .16373 L
.49806 .08012 L
s
.678 .847 .902 r
.49806 .08012 m
.49806 .16252 L
.4994 .16252 L
.4994 .08012 L
F
.2 .63 .79 r
.49806 .08012 m
.49806 .16252 L
.4994 .16252 L
.4994 .08012 L
s
.678 .847 .902 r
.4994 .08012 m
.4994 .16221 L
.50028 .16221 L
.50028 .08012 L
F
.2 .63 .79 r
.4994 .08012 m
.4994 .16221 L
.50028 .16221 L
.50028 .08012 L
s
.678 .847 .902 r
.50028 .08012 m
.50028 .16163 L
.50165 .16163 L
.50165 .08012 L
F
.2 .63 .79 r
.50028 .08012 m
.50028 .16163 L
.50165 .16163 L
.50165 .08012 L
s
.678 .847 .902 r
.50165 .08012 m
.50165 .16028 L
.50344 .16028 L
.50344 .08012 L
F
.2 .63 .79 r
.50165 .08012 m
.50165 .16028 L
.50344 .16028 L
.50344 .08012 L
s
.678 .847 .902 r
.50344 .08012 m
.50344 .15931 L
.50416 .15931 L
.50416 .08012 L
F
.2 .63 .79 r
.50344 .08012 m
.50344 .15931 L
.50416 .15931 L
.50416 .08012 L
s
.678 .847 .902 r
.50416 .08012 m
.50416 .15927 L
.50545 .15927 L
.50545 .08012 L
F
.2 .63 .79 r
.50416 .08012 m
.50416 .15927 L
.50545 .15927 L
.50545 .08012 L
s
.678 .847 .902 r
.50545 .08012 m
.50545 .15804 L
.50723 .15804 L
.50723 .08012 L
F
.2 .63 .79 r
.50545 .08012 m
.50545 .15804 L
.50723 .15804 L
.50723 .08012 L
s
.678 .847 .902 r
.50723 .08012 m
.50723 .15741 L
.50839 .15741 L
.50839 .08012 L
F
.2 .63 .79 r
.50723 .08012 m
.50723 .15741 L
.50839 .15741 L
.50839 .08012 L
s
.678 .847 .902 r
.50839 .08012 m
.50839 .15593 L
.51002 .15593 L
.51002 .08012 L
F
.2 .63 .79 r
.50839 .08012 m
.50839 .15593 L
.51002 .15593 L
.51002 .08012 L
s
.678 .847 .902 r
.51002 .08012 m
.51002 .15567 L
.51066 .15567 L
.51066 .08012 L
F
.2 .63 .79 r
.51002 .08012 m
.51002 .15567 L
.51066 .15567 L
.51066 .08012 L
s
.678 .847 .902 r
.51066 .08012 m
.51066 .15533 L
.51166 .15533 L
.51166 .08012 L
F
.2 .63 .79 r
.51066 .08012 m
.51066 .15533 L
.51166 .15533 L
.51166 .08012 L
s
.678 .847 .902 r
.51166 .08012 m
.51166 .15413 L
.51293 .15413 L
.51293 .08012 L
F
.2 .63 .79 r
.51166 .08012 m
.51166 .15413 L
.51293 .15413 L
.51293 .08012 L
s
.678 .847 .902 r
.51293 .08012 m
.51293 .15386 L
.51396 .15386 L
.51396 .08012 L
F
.2 .63 .79 r
.51293 .08012 m
.51293 .15386 L
.51396 .15386 L
.51396 .08012 L
s
.678 .847 .902 r
.51396 .08012 m
.51396 .15316 L
.51473 .15316 L
.51473 .08012 L
F
.2 .63 .79 r
.51396 .08012 m
.51396 .15316 L
.51473 .15316 L
.51473 .08012 L
s
.678 .847 .902 r
.51473 .08012 m
.51473 .15275 L
.51621 .15275 L
.51621 .08012 L
F
.2 .63 .79 r
.51473 .08012 m
.51473 .15275 L
.51621 .15275 L
.51621 .08012 L
s
.678 .847 .902 r
.51621 .08012 m
.51621 .151 L
.51825 .151 L
.51825 .08012 L
F
.2 .63 .79 r
.51621 .08012 m
.51621 .151 L
.51825 .151 L
.51825 .08012 L
s
.678 .847 .902 r
.51825 .08012 m
.51825 .15049 L
.51901 .15049 L
.51901 .08012 L
F
.2 .63 .79 r
.51825 .08012 m
.51825 .15049 L
.51901 .15049 L
.51901 .08012 L
s
.678 .847 .902 r
.51901 .08012 m
.51901 .14994 L
.51972 .14994 L
.51972 .08012 L
F
.2 .63 .79 r
.51901 .08012 m
.51901 .14994 L
.51972 .14994 L
.51972 .08012 L
s
.678 .847 .902 r
.51972 .08012 m
.51972 .14969 L
.52099 .14969 L
.52099 .08012 L
F
.2 .63 .79 r
.51972 .08012 m
.51972 .14969 L
.52099 .14969 L
.52099 .08012 L
s
.678 .847 .902 r
.52099 .08012 m
.52099 .14877 L
.52227 .14877 L
.52227 .08012 L
F
.2 .63 .79 r
.52099 .08012 m
.52099 .14877 L
.52227 .14877 L
.52227 .08012 L
s
.678 .847 .902 r
.52227 .08012 m
.52227 .14778 L
.52399 .14778 L
.52399 .08012 L
F
.2 .63 .79 r
.52227 .08012 m
.52227 .14778 L
.52399 .14778 L
.52399 .08012 L
s
.678 .847 .902 r
.52399 .08012 m
.52399 .14698 L
.52557 .14698 L
.52557 .08012 L
F
.2 .63 .79 r
.52399 .08012 m
.52399 .14698 L
.52557 .14698 L
.52557 .08012 L
s
.678 .847 .902 r
.52557 .08012 m
.52557 .14555 L
.52738 .14555 L
.52738 .08012 L
F
.2 .63 .79 r
.52557 .08012 m
.52557 .14555 L
.52738 .14555 L
.52738 .08012 L
s
.678 .847 .902 r
.52738 .08012 m
.52738 .14536 L
.52877 .14536 L
.52877 .08012 L
F
.2 .63 .79 r
.52738 .08012 m
.52738 .14536 L
.52877 .14536 L
.52877 .08012 L
s
.678 .847 .902 r
.52877 .08012 m
.52877 .14406 L
.52978 .14406 L
.52978 .08012 L
F
.2 .63 .79 r
.52877 .08012 m
.52877 .14406 L
.52978 .14406 L
.52978 .08012 L
s
.678 .847 .902 r
.52978 .08012 m
.52978 .14371 L
.53111 .14371 L
.53111 .08012 L
F
.2 .63 .79 r
.52978 .08012 m
.52978 .14371 L
.53111 .14371 L
.53111 .08012 L
s
.678 .847 .902 r
.53111 .08012 m
.53111 .14277 L
.53217 .14277 L
.53217 .08012 L
F
.2 .63 .79 r
.53111 .08012 m
.53111 .14277 L
.53217 .14277 L
.53217 .08012 L
s
.678 .847 .902 r
.53217 .08012 m
.53217 .14209 L
.53386 .14209 L
.53386 .08012 L
F
.2 .63 .79 r
.53217 .08012 m
.53217 .14209 L
.53386 .14209 L
.53386 .08012 L
s
.678 .847 .902 r
.53386 .08012 m
.53386 .14117 L
.53478 .14117 L
.53478 .08012 L
F
.2 .63 .79 r
.53386 .08012 m
.53386 .14117 L
.53478 .14117 L
.53478 .08012 L
s
.678 .847 .902 r
.53478 .08012 m
.53478 .14101 L
.53545 .14101 L
.53545 .08012 L
F
.2 .63 .79 r
.53478 .08012 m
.53478 .14101 L
.53545 .14101 L
.53545 .08012 L
s
.678 .847 .902 r
.53545 .08012 m
.53545 .14048 L
.53683 .14048 L
.53683 .08012 L
F
.2 .63 .79 r
.53545 .08012 m
.53545 .14048 L
.53683 .14048 L
.53683 .08012 L
s
.678 .847 .902 r
.53683 .08012 m
.53683 .13963 L
.53798 .13963 L
.53798 .08012 L
F
.2 .63 .79 r
.53683 .08012 m
.53683 .13963 L
.53798 .13963 L
.53798 .08012 L
s
.678 .847 .902 r
.53798 .08012 m
.53798 .13919 L
.53935 .13919 L
.53935 .08012 L
F
.2 .63 .79 r
.53798 .08012 m
.53798 .13919 L
.53935 .13919 L
.53935 .08012 L
s
.678 .847 .902 r
.53935 .08012 m
.53935 .13847 L
.54002 .13847 L
.54002 .08012 L
F
.2 .63 .79 r
.53935 .08012 m
.53935 .13847 L
.54002 .13847 L
.54002 .08012 L
s
.678 .847 .902 r
.54002 .08012 m
.54002 .13799 L
.54102 .13799 L
.54102 .08012 L
F
.2 .63 .79 r
.54002 .08012 m
.54002 .13799 L
.54102 .13799 L
.54102 .08012 L
s
.678 .847 .902 r
.54102 .08012 m
.54102 .13679 L
.54299 .13679 L
.54299 .08012 L
F
.2 .63 .79 r
.54102 .08012 m
.54102 .13679 L
.54299 .13679 L
.54299 .08012 L
s
.678 .847 .902 r
.54299 .08012 m
.54299 .13596 L
.54397 .13596 L
.54397 .08012 L
F
.2 .63 .79 r
.54299 .08012 m
.54299 .13596 L
.54397 .13596 L
.54397 .08012 L
s
.678 .847 .902 r
.54397 .08012 m
.54397 .1351 L
.54595 .1351 L
.54595 .08012 L
F
.2 .63 .79 r
.54397 .08012 m
.54397 .1351 L
.54595 .1351 L
.54595 .08012 L
s
.678 .847 .902 r
.54595 .08012 m
.54595 .1347 L
.54757 .1347 L
.54757 .08012 L
F
.2 .63 .79 r
.54595 .08012 m
.54595 .1347 L
.54757 .1347 L
.54757 .08012 L
s
.678 .847 .902 r
.54757 .08012 m
.54757 .13293 L
.54958 .13293 L
.54958 .08012 L
F
.2 .63 .79 r
.54757 .08012 m
.54757 .13293 L
.54958 .13293 L
.54958 .08012 L
s
.678 .847 .902 r
.54958 .08012 m
.54958 .13268 L
.55042 .13268 L
.55042 .08012 L
F
.2 .63 .79 r
.54958 .08012 m
.54958 .13268 L
.55042 .13268 L
.55042 .08012 L
s
.678 .847 .902 r
.55042 .08012 m
.55042 .13154 L
.55233 .13154 L
.55233 .08012 L
F
.2 .63 .79 r
.55042 .08012 m
.55042 .13154 L
.55233 .13154 L
.55233 .08012 L
s
.678 .847 .902 r
.55233 .08012 m
.55233 .13086 L
.5533 .13086 L
.5533 .08012 L
F
.2 .63 .79 r
.55233 .08012 m
.55233 .13086 L
.5533 .13086 L
.5533 .08012 L
s
.678 .847 .902 r
.5533 .08012 m
.5533 .13051 L
.55466 .13051 L
.55466 .08012 L
F
.2 .63 .79 r
.5533 .08012 m
.5533 .13051 L
.55466 .13051 L
.55466 .08012 L
s
.678 .847 .902 r
.55466 .08012 m
.55466 .12958 L
.55588 .12958 L
.55588 .08012 L
F
.2 .63 .79 r
.55466 .08012 m
.55466 .12958 L
.55588 .12958 L
.55588 .08012 L
s
.678 .847 .902 r
.55588 .08012 m
.55588 .1292 L
.55682 .1292 L
.55682 .08012 L
F
.2 .63 .79 r
.55588 .08012 m
.55588 .1292 L
.55682 .1292 L
.55682 .08012 L
s
.678 .847 .902 r
.55682 .08012 m
.55682 .1282 L
.55808 .1282 L
.55808 .08012 L
F
.2 .63 .79 r
.55682 .08012 m
.55682 .1282 L
.55808 .1282 L
.55808 .08012 L
s
.678 .847 .902 r
.55808 .08012 m
.55808 .12787 L
.56014 .12787 L
.56014 .08012 L
F
.2 .63 .79 r
.55808 .08012 m
.55808 .12787 L
.56014 .12787 L
.56014 .08012 L
s
.678 .847 .902 r
.56014 .08012 m
.56014 .12673 L
.56098 .12673 L
.56098 .08012 L
F
.2 .63 .79 r
.56014 .08012 m
.56014 .12673 L
.56098 .12673 L
.56098 .08012 L
s
.678 .847 .902 r
.56098 .08012 m
.56098 .12579 L
.56269 .12579 L
.56269 .08012 L
F
.2 .63 .79 r
.56098 .08012 m
.56098 .12579 L
.56269 .12579 L
.56269 .08012 L
s
.678 .847 .902 r
.56269 .08012 m
.56269 .12562 L
.5635 .12562 L
.5635 .08012 L
F
.2 .63 .79 r
.56269 .08012 m
.56269 .12562 L
.5635 .12562 L
.5635 .08012 L
s
.678 .847 .902 r
.5635 .08012 m
.5635 .12487 L
.5645 .12487 L
.5645 .08012 L
F
.2 .63 .79 r
.5635 .08012 m
.5635 .12487 L
.5645 .12487 L
.5645 .08012 L
s
.678 .847 .902 r
.5645 .08012 m
.5645 .12394 L
.56651 .12394 L
.56651 .08012 L
F
.2 .63 .79 r
.5645 .08012 m
.5645 .12394 L
.56651 .12394 L
.56651 .08012 L
s
.678 .847 .902 r
.56651 .08012 m
.56651 .12319 L
.56818 .12319 L
.56818 .08012 L
F
.2 .63 .79 r
.56651 .08012 m
.56651 .12319 L
.56818 .12319 L
.56818 .08012 L
s
.678 .847 .902 r
.56818 .08012 m
.56818 .12213 L
.5697 .12213 L
.5697 .08012 L
F
.2 .63 .79 r
.56818 .08012 m
.56818 .12213 L
.5697 .12213 L
.5697 .08012 L
s
.678 .847 .902 r
.5697 .08012 m
.5697 .12179 L
.57164 .12179 L
.57164 .08012 L
F
.2 .63 .79 r
.5697 .08012 m
.5697 .12179 L
.57164 .12179 L
.57164 .08012 L
s
.678 .847 .902 r
.57164 .08012 m
.57164 .12057 L
.5729 .12057 L
.5729 .08012 L
F
.2 .63 .79 r
.57164 .08012 m
.57164 .12057 L
.5729 .12057 L
.5729 .08012 L
s
.678 .847 .902 r
.5729 .08012 m
.5729 .12002 L
.57454 .12002 L
.57454 .08012 L
F
.2 .63 .79 r
.5729 .08012 m
.5729 .12002 L
.57454 .12002 L
.57454 .08012 L
s
.678 .847 .902 r
.57454 .08012 m
.57454 .11915 L
.57568 .11915 L
.57568 .08012 L
F
.2 .63 .79 r
.57454 .08012 m
.57454 .11915 L
.57568 .11915 L
.57568 .08012 L
s
.678 .847 .902 r
.57568 .08012 m
.57568 .11837 L
.57774 .11837 L
.57774 .08012 L
F
.2 .63 .79 r
.57568 .08012 m
.57568 .11837 L
.57774 .11837 L
.57774 .08012 L
s
.678 .847 .902 r
.57774 .08012 m
.57774 .11748 L
.57866 .11748 L
.57866 .08012 L
F
.2 .63 .79 r
.57774 .08012 m
.57774 .11748 L
.57866 .11748 L
.57866 .08012 L
s
.678 .847 .902 r
.57866 .08012 m
.57866 .11681 L
.5804 .11681 L
.5804 .08012 L
F
.2 .63 .79 r
.57866 .08012 m
.57866 .11681 L
.5804 .11681 L
.5804 .08012 L
s
.678 .847 .902 r
.5804 .08012 m
.5804 .11614 L
.58201 .11614 L
.58201 .08012 L
F
.2 .63 .79 r
.5804 .08012 m
.5804 .11614 L
.58201 .11614 L
.58201 .08012 L
s
.678 .847 .902 r
.58201 .08012 m
.58201 .11537 L
.58269 .11537 L
.58269 .08012 L
F
.2 .63 .79 r
.58201 .08012 m
.58201 .11537 L
.58269 .11537 L
.58269 .08012 L
s
.678 .847 .902 r
.58269 .08012 m
.58269 .11511 L
.58339 .11511 L
.58339 .08012 L
F
.2 .63 .79 r
.58269 .08012 m
.58269 .11511 L
.58339 .11511 L
.58339 .08012 L
s
.678 .847 .902 r
.58339 .08012 m
.58339 .11412 L
.58532 .11412 L
.58532 .08012 L
F
.2 .63 .79 r
.58339 .08012 m
.58339 .11412 L
.58532 .11412 L
.58532 .08012 L
s
.678 .847 .902 r
.58532 .08012 m
.58532 .11356 L
.58658 .11356 L
.58658 .08012 L
F
.2 .63 .79 r
.58532 .08012 m
.58532 .11356 L
.58658 .11356 L
.58658 .08012 L
s
.678 .847 .902 r
.58658 .08012 m
.58658 .1131 L
.58799 .1131 L
.58799 .08012 L
F
.2 .63 .79 r
.58658 .08012 m
.58658 .1131 L
.58799 .1131 L
.58799 .08012 L
s
.678 .847 .902 r
.58799 .08012 m
.58799 .11204 L
.58957 .11204 L
.58957 .08012 L
F
.2 .63 .79 r
.58799 .08012 m
.58799 .11204 L
.58957 .11204 L
.58957 .08012 L
s
.678 .847 .902 r
.58957 .08012 m
.58957 .11137 L
.59117 .11137 L
.59117 .08012 L
F
.2 .63 .79 r
.58957 .08012 m
.58957 .11137 L
.59117 .11137 L
.59117 .08012 L
s
.678 .847 .902 r
.59117 .08012 m
.59117 .11074 L
.59181 .11074 L
.59181 .08012 L
F
.2 .63 .79 r
.59117 .08012 m
.59117 .11074 L
.59181 .11074 L
.59181 .08012 L
s
.678 .847 .902 r
.59181 .08012 m
.59181 .10995 L
.59325 .10995 L
.59325 .08012 L
F
.2 .63 .79 r
.59181 .08012 m
.59181 .10995 L
.59325 .10995 L
.59325 .08012 L
s
.678 .847 .902 r
.59325 .08012 m
.59325 .10927 L
.59462 .10927 L
.59462 .08012 L
F
.2 .63 .79 r
.59325 .08012 m
.59325 .10927 L
.59462 .10927 L
.59462 .08012 L
s
.678 .847 .902 r
.59462 .08012 m
.59462 .10866 L
.59661 .10866 L
.59661 .08012 L
F
.2 .63 .79 r
.59462 .08012 m
.59462 .10866 L
.59661 .10866 L
.59661 .08012 L
s
.678 .847 .902 r
.59661 .08012 m
.59661 .10784 L
.59852 .10784 L
.59852 .08012 L
F
.2 .63 .79 r
.59661 .08012 m
.59661 .10784 L
.59852 .10784 L
.59852 .08012 L
s
.678 .847 .902 r
.59852 .08012 m
.59852 .10716 L
.59958 .10716 L
.59958 .08012 L
F
.2 .63 .79 r
.59852 .08012 m
.59852 .10716 L
.59958 .10716 L
.59958 .08012 L
s
.678 .847 .902 r
.59958 .08012 m
.59958 .10663 L
.60103 .10663 L
.60103 .08012 L
F
.2 .63 .79 r
.59958 .08012 m
.59958 .10663 L
.60103 .10663 L
.60103 .08012 L
s
.678 .847 .902 r
.60103 .08012 m
.60103 .10602 L
.60198 .10602 L
.60198 .08012 L
F
.2 .63 .79 r
.60103 .08012 m
.60103 .10602 L
.60198 .10602 L
.60198 .08012 L
s
.678 .847 .902 r
.60198 .08012 m
.60198 .10527 L
.603 .10527 L
.603 .08012 L
F
.2 .63 .79 r
.60198 .08012 m
.60198 .10527 L
.603 .10527 L
.603 .08012 L
s
.678 .847 .902 r
.603 .08012 m
.603 .10505 L
.60421 .10505 L
.60421 .08012 L
F
.2 .63 .79 r
.603 .08012 m
.603 .10505 L
.60421 .10505 L
.60421 .08012 L
s
.678 .847 .902 r
.60421 .08012 m
.60421 .10425 L
.60502 .10425 L
.60502 .08012 L
F
.2 .63 .79 r
.60421 .08012 m
.60421 .10425 L
.60502 .10425 L
.60502 .08012 L
s
.678 .847 .902 r
.60502 .08012 m
.60502 .10359 L
.60643 .10359 L
.60643 .08012 L
F
.2 .63 .79 r
.60502 .08012 m
.60502 .10359 L
.60643 .10359 L
.60643 .08012 L
s
.678 .847 .902 r
.60643 .08012 m
.60643 .10325 L
.60841 .10325 L
.60841 .08012 L
F
.2 .63 .79 r
.60643 .08012 m
.60643 .10325 L
.60841 .10325 L
.60841 .08012 L
s
.678 .847 .902 r
.60841 .08012 m
.60841 .10211 L
.60964 .10211 L
.60964 .08012 L
F
.2 .63 .79 r
.60841 .08012 m
.60841 .10211 L
.60964 .10211 L
.60964 .08012 L
s
.678 .847 .902 r
.60964 .08012 m
.60964 .10181 L
.61163 .10181 L
.61163 .08012 L
F
.2 .63 .79 r
.60964 .08012 m
.60964 .10181 L
.61163 .10181 L
.61163 .08012 L
s
.678 .847 .902 r
.61163 .08012 m
.61163 .10074 L
.61338 .10074 L
.61338 .08012 L
F
.2 .63 .79 r
.61163 .08012 m
.61163 .10074 L
.61338 .10074 L
.61338 .08012 L
s
.678 .847 .902 r
.61338 .08012 m
.61338 .09971 L
.61437 .09971 L
.61437 .08012 L
F
.2 .63 .79 r
.61338 .08012 m
.61338 .09971 L
.61437 .09971 L
.61437 .08012 L
s
.678 .847 .902 r
.61437 .08012 m
.61437 .09959 L
.61555 .09959 L
.61555 .08012 L
F
.2 .63 .79 r
.61437 .08012 m
.61437 .09959 L
.61555 .09959 L
.61555 .08012 L
s
.678 .847 .902 r
.61555 .08012 m
.61555 .09835 L
.61747 .09835 L
.61747 .08012 L
F
.2 .63 .79 r
.61555 .08012 m
.61555 .09835 L
.61747 .09835 L
.61747 .08012 L
s
.678 .847 .902 r
.61747 .08012 m
.61747 .09775 L
.61939 .09775 L
.61939 .08012 L
F
.2 .63 .79 r
.61747 .08012 m
.61747 .09775 L
.61939 .09775 L
.61939 .08012 L
s
.678 .847 .902 r
.61939 .08012 m
.61939 .09695 L
.6212 .09695 L
.6212 .08012 L
F
.2 .63 .79 r
.61939 .08012 m
.61939 .09695 L
.6212 .09695 L
.6212 .08012 L
s
.678 .847 .902 r
.6212 .08012 m
.6212 .09566 L
.62306 .09566 L
.62306 .08012 L
F
.2 .63 .79 r
.6212 .08012 m
.6212 .09566 L
.62306 .09566 L
.62306 .08012 L
s
.678 .847 .902 r
.62306 .08012 m
.62306 .09552 L
.62403 .09552 L
.62403 .08012 L
F
.2 .63 .79 r
.62306 .08012 m
.62306 .09552 L
.62403 .09552 L
.62403 .08012 L
s
.678 .847 .902 r
.62403 .08012 m
.62403 .09515 L
.62497 .09515 L
.62497 .08012 L
F
.2 .63 .79 r
.62403 .08012 m
.62403 .09515 L
.62497 .09515 L
.62497 .08012 L
s
.678 .847 .902 r
.62497 .08012 m
.62497 .094 L
.62677 .094 L
.62677 .08012 L
F
.2 .63 .79 r
.62497 .08012 m
.62497 .094 L
.62677 .094 L
.62677 .08012 L
s
.678 .847 .902 r
.62677 .08012 m
.62677 .09391 L
.62783 .09391 L
.62783 .08012 L
F
.2 .63 .79 r
.62677 .08012 m
.62677 .09391 L
.62783 .09391 L
.62783 .08012 L
s
.678 .847 .902 r
.62783 .08012 m
.62783 .09319 L
.62952 .09319 L
.62952 .08012 L
F
.2 .63 .79 r
.62783 .08012 m
.62783 .09319 L
.62952 .09319 L
.62952 .08012 L
s
.678 .847 .902 r
.62952 .08012 m
.62952 .09245 L
.63056 .09245 L
.63056 .08012 L
F
.2 .63 .79 r
.62952 .08012 m
.62952 .09245 L
.63056 .09245 L
.63056 .08012 L
s
.678 .847 .902 r
.63056 .08012 m
.63056 .09177 L
.63253 .09177 L
.63253 .08012 L
F
.2 .63 .79 r
.63056 .08012 m
.63056 .09177 L
.63253 .09177 L
.63253 .08012 L
s
.678 .847 .902 r
.63253 .08012 m
.63253 .09055 L
.63462 .09055 L
.63462 .08012 L
F
.2 .63 .79 r
.63253 .08012 m
.63253 .09055 L
.63462 .09055 L
.63462 .08012 L
s
.678 .847 .902 r
.63462 .08012 m
.63462 .09036 L
.63548 .09036 L
.63548 .08012 L
F
.2 .63 .79 r
.63462 .08012 m
.63462 .09036 L
.63548 .09036 L
.63548 .08012 L
s
.678 .847 .902 r
.63548 .08012 m
.63548 .08989 L
.63621 .08989 L
.63621 .08012 L
F
.2 .63 .79 r
.63548 .08012 m
.63548 .08989 L
.63621 .08989 L
.63621 .08012 L
s
.678 .847 .902 r
.63621 .08012 m
.63621 .0891 L
.63778 .0891 L
.63778 .08012 L
F
.2 .63 .79 r
.63621 .08012 m
.63621 .0891 L
.63778 .0891 L
.63778 .08012 L
s
.678 .847 .902 r
.63778 .08012 m
.63778 .0885 L
.63929 .0885 L
.63929 .08012 L
F
.2 .63 .79 r
.63778 .08012 m
.63778 .0885 L
.63929 .0885 L
.63929 .08012 L
s
.678 .847 .902 r
.63929 .08012 m
.63929 .08821 L
.63997 .08821 L
.63997 .08012 L
F
.2 .63 .79 r
.63929 .08012 m
.63929 .08821 L
.63997 .08821 L
.63997 .08012 L
s
.678 .847 .902 r
.63997 .08012 m
.63997 .08763 L
.64137 .08763 L
.64137 .08012 L
F
.2 .63 .79 r
.63997 .08012 m
.63997 .08763 L
.64137 .08763 L
.64137 .08012 L
s
.678 .847 .902 r
.64137 .08012 m
.64137 .08695 L
.64307 .08695 L
.64307 .08012 L
F
.2 .63 .79 r
.64137 .08012 m
.64137 .08695 L
.64307 .08695 L
.64307 .08012 L
s
.678 .847 .902 r
.64307 .08012 m
.64307 .08667 L
.64398 .08667 L
.64398 .08012 L
F
.2 .63 .79 r
.64307 .08012 m
.64307 .08667 L
.64398 .08667 L
.64398 .08012 L
s
.678 .847 .902 r
.64398 .08012 m
.64398 .08619 L
.64475 .08619 L
.64475 .08012 L
F
.2 .63 .79 r
.64398 .08012 m
.64398 .08619 L
.64475 .08619 L
.64475 .08012 L
s
.678 .847 .902 r
.64475 .08012 m
.64475 .08566 L
.64649 .08566 L
.64649 .08012 L
F
.2 .63 .79 r
.64475 .08012 m
.64475 .08566 L
.64649 .08566 L
.64649 .08012 L
s
.678 .847 .902 r
.64649 .08012 m
.64649 .08481 L
.64782 .08481 L
.64782 .08012 L
F
.2 .63 .79 r
.64649 .08012 m
.64649 .08481 L
.64782 .08481 L
.64782 .08012 L
s
.678 .847 .902 r
.64782 .08012 m
.64782 .08468 L
.64964 .08468 L
.64964 .08012 L
F
.2 .63 .79 r
.64782 .08012 m
.64782 .08468 L
.64964 .08468 L
.64964 .08012 L
s
.678 .847 .902 r
.64964 .08012 m
.64964 .08368 L
.65059 .08368 L
.65059 .08012 L
F
.2 .63 .79 r
.64964 .08012 m
.64964 .08368 L
.65059 .08368 L
.65059 .08012 L
s
.678 .847 .902 r
.65059 .08012 m
.65059 .08277 L
.6525 .08277 L
.6525 .08012 L
F
.2 .63 .79 r
.65059 .08012 m
.65059 .08277 L
.6525 .08277 L
.6525 .08012 L
s
.678 .847 .902 r
.6525 .08012 m
.6525 .08248 L
.65411 .08248 L
.65411 .08012 L
F
.2 .63 .79 r
.6525 .08012 m
.6525 .08248 L
.65411 .08248 L
.65411 .08012 L
s
.678 .847 .902 r
.65411 .08012 m
.65411 .08201 L
.65616 .08201 L
.65616 .08012 L
F
.2 .63 .79 r
.65411 .08012 m
.65411 .08201 L
.65616 .08201 L
.65616 .08012 L
s
.678 .847 .902 r
.65616 .08012 m
.65616 .08091 L
.65823 .08091 L
.65823 .08012 L
F
.2 .63 .79 r
.65616 .08012 m
.65616 .08091 L
.65823 .08091 L
.65823 .08012 L
s
1 .894 .882 r
.65823 .08012 m
.65823 .07978 L
.65982 .07978 L
.65982 .08012 L
F
.804 .522 .247 r
.65823 .08012 m
.65823 .07978 L
.65982 .07978 L
.65982 .08012 L
s
1 .894 .882 r
.65982 .08012 m
.65982 .07935 L
.66172 .07935 L
.66172 .08012 L
F
.804 .522 .247 r
.65982 .08012 m
.65982 .07935 L
.66172 .07935 L
.66172 .08012 L
s
1 .894 .882 r
.66172 .08012 m
.66172 .07826 L
.66335 .07826 L
.66335 .08012 L
F
.804 .522 .247 r
.66172 .08012 m
.66172 .07826 L
.66335 .07826 L
.66335 .08012 L
s
1 .894 .882 r
.66335 .08012 m
.66335 .07784 L
.66436 .07784 L
.66436 .08012 L
F
.804 .522 .247 r
.66335 .08012 m
.66335 .07784 L
.66436 .07784 L
.66436 .08012 L
s
1 .894 .882 r
.66436 .08012 m
.66436 .07769 L
.66553 .07769 L
.66553 .08012 L
F
.804 .522 .247 r
.66436 .08012 m
.66436 .07769 L
.66553 .07769 L
.66553 .08012 L
s
1 .894 .882 r
.66553 .08012 m
.66553 .07664 L
.66755 .07664 L
.66755 .08012 L
F
.804 .522 .247 r
.66553 .08012 m
.66553 .07664 L
.66755 .07664 L
.66755 .08012 L
s
1 .894 .882 r
.66755 .08012 m
.66755 .07647 L
.66918 .07647 L
.66918 .08012 L
F
.804 .522 .247 r
.66755 .08012 m
.66755 .07647 L
.66918 .07647 L
.66918 .08012 L
s
1 .894 .882 r
.66918 .08012 m
.66918 .07565 L
.66995 .07565 L
.66995 .08012 L
F
.804 .522 .247 r
.66918 .08012 m
.66918 .07565 L
.66995 .07565 L
.66995 .08012 L
s
1 .894 .882 r
.66995 .08012 m
.66995 .07524 L
.67103 .07524 L
.67103 .08012 L
F
.804 .522 .247 r
.66995 .08012 m
.66995 .07524 L
.67103 .07524 L
.67103 .08012 L
s
1 .894 .882 r
.67103 .08012 m
.67103 .07474 L
.6721 .07474 L
.6721 .08012 L
F
.804 .522 .247 r
.67103 .08012 m
.67103 .07474 L
.6721 .07474 L
.6721 .08012 L
s
1 .894 .882 r
.6721 .08012 m
.6721 .07464 L
.67284 .07464 L
.67284 .08012 L
F
.804 .522 .247 r
.6721 .08012 m
.6721 .07464 L
.67284 .07464 L
.67284 .08012 L
s
1 .894 .882 r
.67284 .08012 m
.67284 .07437 L
.67356 .07437 L
.67356 .08012 L
F
.804 .522 .247 r
.67284 .08012 m
.67284 .07437 L
.67356 .07437 L
.67356 .08012 L
s
1 .894 .882 r
.67356 .08012 m
.67356 .0741 L
.67533 .0741 L
.67533 .08012 L
F
.804 .522 .247 r
.67356 .08012 m
.67356 .0741 L
.67533 .0741 L
.67533 .08012 L
s
1 .894 .882 r
.67533 .08012 m
.67533 .0733 L
.6768 .0733 L
.6768 .08012 L
F
.804 .522 .247 r
.67533 .08012 m
.67533 .0733 L
.6768 .0733 L
.6768 .08012 L
s
1 .894 .882 r
.6768 .08012 m
.6768 .07278 L
.67872 .07278 L
.67872 .08012 L
F
.804 .522 .247 r
.6768 .08012 m
.6768 .07278 L
.67872 .07278 L
.67872 .08012 L
s
1 .894 .882 r
.67872 .08012 m
.67872 .07151 L
.68076 .07151 L
.68076 .08012 L
F
.804 .522 .247 r
.67872 .08012 m
.67872 .07151 L
.68076 .07151 L
.68076 .08012 L
s
1 .894 .882 r
.68076 .08012 m
.68076 .0712 L
.68142 .0712 L
.68142 .08012 L
F
.804 .522 .247 r
.68076 .08012 m
.68076 .0712 L
.68142 .0712 L
.68142 .08012 L
s
1 .894 .882 r
.68142 .08012 m
.68142 .07096 L
.68218 .07096 L
.68218 .08012 L
F
.804 .522 .247 r
.68142 .08012 m
.68142 .07096 L
.68218 .07096 L
.68218 .08012 L
s
1 .894 .882 r
.68218 .08012 m
.68218 .07078 L
.68291 .07078 L
.68291 .08012 L
F
.804 .522 .247 r
.68218 .08012 m
.68218 .07078 L
.68291 .07078 L
.68291 .08012 L
s
1 .894 .882 r
.68291 .08012 m
.68291 .07039 L
.68463 .07039 L
.68463 .08012 L
F
.804 .522 .247 r
.68291 .08012 m
.68291 .07039 L
.68463 .07039 L
.68463 .08012 L
s
1 .894 .882 r
.68463 .08012 m
.68463 .06966 L
.68547 .06966 L
.68547 .08012 L
F
.804 .522 .247 r
.68463 .08012 m
.68463 .06966 L
.68547 .06966 L
.68547 .08012 L
s
1 .894 .882 r
.68547 .08012 m
.68547 .06949 L
.68671 .06949 L
.68671 .08012 L
F
.804 .522 .247 r
.68547 .08012 m
.68547 .06949 L
.68671 .06949 L
.68671 .08012 L
s
1 .894 .882 r
.68671 .08012 m
.68671 .06907 L
.68748 .06907 L
.68748 .08012 L
F
.804 .522 .247 r
.68671 .08012 m
.68671 .06907 L
.68748 .06907 L
.68748 .08012 L
s
1 .894 .882 r
.68748 .08012 m
.68748 .06822 L
.68922 .06822 L
.68922 .08012 L
F
.804 .522 .247 r
.68748 .08012 m
.68748 .06822 L
.68922 .06822 L
.68922 .08012 L
s
1 .894 .882 r
.68922 .08012 m
.68922 .06773 L
.69056 .06773 L
.69056 .08012 L
F
.804 .522 .247 r
.68922 .08012 m
.68922 .06773 L
.69056 .06773 L
.69056 .08012 L
s
1 .894 .882 r
.69056 .08012 m
.69056 .06726 L
.69198 .06726 L
.69198 .08012 L
F
.804 .522 .247 r
.69056 .08012 m
.69056 .06726 L
.69198 .06726 L
.69198 .08012 L
s
1 .894 .882 r
.69198 .08012 m
.69198 .06706 L
.69323 .06706 L
.69323 .08012 L
F
.804 .522 .247 r
.69198 .08012 m
.69198 .06706 L
.69323 .06706 L
.69323 .08012 L
s
1 .894 .882 r
.69323 .08012 m
.69323 .06619 L
.69458 .06619 L
.69458 .08012 L
F
.804 .522 .247 r
.69323 .08012 m
.69323 .06619 L
.69458 .06619 L
.69458 .08012 L
s
1 .894 .882 r
.69458 .08012 m
.69458 .06601 L
.69537 .06601 L
.69537 .08012 L
F
.804 .522 .247 r
.69458 .08012 m
.69458 .06601 L
.69537 .06601 L
.69537 .08012 L
s
1 .894 .882 r
.69537 .08012 m
.69537 .06541 L
.69687 .06541 L
.69687 .08012 L
F
.804 .522 .247 r
.69537 .08012 m
.69537 .06541 L
.69687 .06541 L
.69687 .08012 L
s
1 .894 .882 r
.69687 .08012 m
.69687 .06531 L
.69858 .06531 L
.69858 .08012 L
F
.804 .522 .247 r
.69687 .08012 m
.69687 .06531 L
.69858 .06531 L
.69858 .08012 L
s
1 .894 .882 r
.69858 .08012 m
.69858 .06463 L
.69979 .06463 L
.69979 .08012 L
F
.804 .522 .247 r
.69858 .08012 m
.69858 .06463 L
.69979 .06463 L
.69979 .08012 L
s
1 .894 .882 r
.69979 .08012 m
.69979 .06378 L
.70158 .06378 L
.70158 .08012 L
F
.804 .522 .247 r
.69979 .08012 m
.69979 .06378 L
.70158 .06378 L
.70158 .08012 L
s
1 .894 .882 r
.70158 .08012 m
.70158 .06331 L
.70264 .06331 L
.70264 .08012 L
F
.804 .522 .247 r
.70158 .08012 m
.70158 .06331 L
.70264 .06331 L
.70264 .08012 L
s
1 .894 .882 r
.70264 .08012 m
.70264 .06284 L
.70423 .06284 L
.70423 .08012 L
F
.804 .522 .247 r
.70264 .08012 m
.70264 .06284 L
.70423 .06284 L
.70423 .08012 L
s
1 .894 .882 r
.70423 .08012 m
.70423 .06232 L
.70535 .06232 L
.70535 .08012 L
F
.804 .522 .247 r
.70423 .08012 m
.70423 .06232 L
.70535 .06232 L
.70535 .08012 L
s
1 .894 .882 r
.70535 .08012 m
.70535 .06215 L
.706 .06215 L
.706 .08012 L
F
.804 .522 .247 r
.70535 .08012 m
.70535 .06215 L
.706 .06215 L
.706 .08012 L
s
1 .894 .882 r
.706 .08012 m
.706 .06171 L
.70769 .06171 L
.70769 .08012 L
F
.804 .522 .247 r
.706 .08012 m
.706 .06171 L
.70769 .06171 L
.70769 .08012 L
s
1 .894 .882 r
.70769 .08012 m
.70769 .06111 L
.70945 .06111 L
.70945 .08012 L
F
.804 .522 .247 r
.70769 .08012 m
.70769 .06111 L
.70945 .06111 L
.70945 .08012 L
s
1 .894 .882 r
.70945 .08012 m
.70945 .06081 L
.71061 .06081 L
.71061 .08012 L
F
.804 .522 .247 r
.70945 .08012 m
.70945 .06081 L
.71061 .06081 L
.71061 .08012 L
s
1 .894 .882 r
.71061 .08012 m
.71061 .06039 L
.71269 .06039 L
.71269 .08012 L
F
.804 .522 .247 r
.71061 .08012 m
.71061 .06039 L
.71269 .06039 L
.71269 .08012 L
s
1 .894 .882 r
.71269 .08012 m
.71269 .05969 L
.71426 .05969 L
.71426 .08012 L
F
.804 .522 .247 r
.71269 .08012 m
.71269 .05969 L
.71426 .05969 L
.71426 .08012 L
s
1 .894 .882 r
.71426 .08012 m
.71426 .05896 L
.71591 .05896 L
.71591 .08012 L
F
.804 .522 .247 r
.71426 .08012 m
.71426 .05896 L
.71591 .05896 L
.71591 .08012 L
s
1 .894 .882 r
.71591 .08012 m
.71591 .05817 L
.71744 .05817 L
.71744 .08012 L
F
.804 .522 .247 r
.71591 .08012 m
.71591 .05817 L
.71744 .05817 L
.71744 .08012 L
s
1 .894 .882 r
.71744 .08012 m
.71744 .05788 L
.71931 .05788 L
.71931 .08012 L
F
.804 .522 .247 r
.71744 .08012 m
.71744 .05788 L
.71931 .05788 L
.71931 .08012 L
s
1 .894 .882 r
.71931 .08012 m
.71931 .05753 L
.72027 .05753 L
.72027 .08012 L
F
.804 .522 .247 r
.71931 .08012 m
.71931 .05753 L
.72027 .05753 L
.72027 .08012 L
s
1 .894 .882 r
.72027 .08012 m
.72027 .05702 L
.72177 .05702 L
.72177 .08012 L
F
.804 .522 .247 r
.72027 .08012 m
.72027 .05702 L
.72177 .05702 L
.72177 .08012 L
s
1 .894 .882 r
.72177 .08012 m
.72177 .05668 L
.72365 .05668 L
.72365 .08012 L
F
.804 .522 .247 r
.72177 .08012 m
.72177 .05668 L
.72365 .05668 L
.72365 .08012 L
s
1 .894 .882 r
.72365 .08012 m
.72365 .05588 L
.72481 .05588 L
.72481 .08012 L
F
.804 .522 .247 r
.72365 .08012 m
.72365 .05588 L
.72481 .05588 L
.72481 .08012 L
s
1 .894 .882 r
.72481 .08012 m
.72481 .05559 L
.72643 .05559 L
.72643 .08012 L
F
.804 .522 .247 r
.72481 .08012 m
.72481 .05559 L
.72643 .05559 L
.72643 .08012 L
s
1 .894 .882 r
.72643 .08012 m
.72643 .05512 L
.72732 .05512 L
.72732 .08012 L
F
.804 .522 .247 r
.72643 .08012 m
.72643 .05512 L
.72732 .05512 L
.72732 .08012 L
s
1 .894 .882 r
.72732 .08012 m
.72732 .05487 L
.72848 .05487 L
.72848 .08012 L
F
.804 .522 .247 r
.72732 .08012 m
.72732 .05487 L
.72848 .05487 L
.72848 .08012 L
s
1 .894 .882 r
.72848 .08012 m
.72848 .05453 L
.72948 .05453 L
.72948 .08012 L
F
.804 .522 .247 r
.72848 .08012 m
.72848 .05453 L
.72948 .05453 L
.72948 .08012 L
s
1 .894 .882 r
.72948 .08012 m
.72948 .05413 L
.73022 .05413 L
.73022 .08012 L
F
.804 .522 .247 r
.72948 .08012 m
.72948 .05413 L
.73022 .05413 L
.73022 .08012 L
s
1 .894 .882 r
.73022 .08012 m
.73022 .0539 L
.73149 .0539 L
.73149 .08012 L
F
.804 .522 .247 r
.73022 .08012 m
.73022 .0539 L
.73149 .0539 L
.73149 .08012 L
s
1 .894 .882 r
.73149 .08012 m
.73149 .053 L
.73353 .053 L
.73353 .08012 L
F
.804 .522 .247 r
.73149 .08012 m
.73149 .053 L
.73353 .053 L
.73353 .08012 L
s
1 .894 .882 r
.73353 .08012 m
.73353 .05284 L
.73483 .05284 L
.73483 .08012 L
F
.804 .522 .247 r
.73353 .08012 m
.73353 .05284 L
.73483 .05284 L
.73483 .08012 L
s
1 .894 .882 r
.73483 .08012 m
.73483 .05226 L
.7366 .05226 L
.7366 .08012 L
F
.804 .522 .247 r
.73483 .08012 m
.73483 .05226 L
.7366 .05226 L
.7366 .08012 L
s
1 .894 .882 r
.7366 .08012 m
.7366 .05174 L
.73837 .05174 L
.73837 .08012 L
F
.804 .522 .247 r
.7366 .08012 m
.7366 .05174 L
.73837 .05174 L
.73837 .08012 L
s
1 .894 .882 r
.73837 .08012 m
.73837 .05099 L
.73992 .05099 L
.73992 .08012 L
F
.804 .522 .247 r
.73837 .08012 m
.73837 .05099 L
.73992 .05099 L
.73992 .08012 L
s
1 .894 .882 r
.73992 .08012 m
.73992 .05076 L
.7412 .05076 L
.7412 .08012 L
F
.804 .522 .247 r
.73992 .08012 m
.73992 .05076 L
.7412 .05076 L
.7412 .08012 L
s
1 .894 .882 r
.7412 .08012 m
.7412 .05038 L
.7419 .05038 L
.7419 .08012 L
F
.804 .522 .247 r
.7412 .08012 m
.7412 .05038 L
.7419 .05038 L
.7419 .08012 L
s
1 .894 .882 r
.7419 .08012 m
.7419 .05018 L
.74254 .05018 L
.74254 .08012 L
F
.804 .522 .247 r
.7419 .08012 m
.7419 .05018 L
.74254 .05018 L
.74254 .08012 L
s
1 .894 .882 r
.74254 .08012 m
.74254 .04993 L
.74356 .04993 L
.74356 .08012 L
F
.804 .522 .247 r
.74254 .08012 m
.74254 .04993 L
.74356 .04993 L
.74356 .08012 L
s
1 .894 .882 r
.74356 .08012 m
.74356 .0497 L
.74484 .0497 L
.74484 .08012 L
F
.804 .522 .247 r
.74356 .08012 m
.74356 .0497 L
.74484 .0497 L
.74484 .08012 L
s
1 .894 .882 r
.74484 .08012 m
.74484 .04921 L
.74608 .04921 L
.74608 .08012 L
F
.804 .522 .247 r
.74484 .08012 m
.74484 .04921 L
.74608 .04921 L
.74608 .08012 L
s
1 .894 .882 r
.74608 .08012 m
.74608 .04899 L
.74715 .04899 L
.74715 .08012 L
F
.804 .522 .247 r
.74608 .08012 m
.74608 .04899 L
.74715 .04899 L
.74715 .08012 L
s
1 .894 .882 r
.74715 .08012 m
.74715 .04842 L
.74873 .04842 L
.74873 .08012 L
F
.804 .522 .247 r
.74715 .08012 m
.74715 .04842 L
.74873 .04842 L
.74873 .08012 L
s
1 .894 .882 r
.74873 .08012 m
.74873 .0479 L
.75023 .0479 L
.75023 .08012 L
F
.804 .522 .247 r
.74873 .08012 m
.74873 .0479 L
.75023 .0479 L
.75023 .08012 L
s
1 .894 .882 r
.75023 .08012 m
.75023 .04768 L
.75114 .04768 L
.75114 .08012 L
F
.804 .522 .247 r
.75023 .08012 m
.75023 .04768 L
.75114 .04768 L
.75114 .08012 L
s
1 .894 .882 r
.75114 .08012 m
.75114 .04716 L
.7528 .04716 L
.7528 .08012 L
F
.804 .522 .247 r
.75114 .08012 m
.75114 .04716 L
.7528 .04716 L
.7528 .08012 L
s
1 .894 .882 r
.7528 .08012 m
.7528 .04677 L
.75458 .04677 L
.75458 .08012 L
F
.804 .522 .247 r
.7528 .08012 m
.7528 .04677 L
.75458 .04677 L
.75458 .08012 L
s
1 .894 .882 r
.75458 .08012 m
.75458 .0465 L
.75556 .0465 L
.75556 .08012 L
F
.804 .522 .247 r
.75458 .08012 m
.75458 .0465 L
.75556 .0465 L
.75556 .08012 L
s
1 .894 .882 r
.75556 .08012 m
.75556 .04615 L
.75693 .04615 L
.75693 .08012 L
F
.804 .522 .247 r
.75556 .08012 m
.75556 .04615 L
.75693 .04615 L
.75693 .08012 L
s
1 .894 .882 r
.75693 .08012 m
.75693 .04566 L
.75834 .04566 L
.75834 .08012 L
F
.804 .522 .247 r
.75693 .08012 m
.75693 .04566 L
.75834 .04566 L
.75834 .08012 L
s
1 .894 .882 r
.75834 .08012 m
.75834 .04532 L
.75959 .04532 L
.75959 .08012 L
F
.804 .522 .247 r
.75834 .08012 m
.75834 .04532 L
.75959 .04532 L
.75959 .08012 L
s
1 .894 .882 r
.75959 .08012 m
.75959 .04499 L
.76165 .04499 L
.76165 .08012 L
F
.804 .522 .247 r
.75959 .08012 m
.75959 .04499 L
.76165 .04499 L
.76165 .08012 L
s
1 .894 .882 r
.76165 .08012 m
.76165 .04458 L
.76291 .04458 L
.76291 .08012 L
F
.804 .522 .247 r
.76165 .08012 m
.76165 .04458 L
.76291 .04458 L
.76291 .08012 L
s
1 .894 .882 r
.76291 .08012 m
.76291 .04414 L
.76368 .04414 L
.76368 .08012 L
F
.804 .522 .247 r
.76291 .08012 m
.76291 .04414 L
.76368 .04414 L
.76368 .08012 L
s
1 .894 .882 r
.76368 .08012 m
.76368 .04379 L
.76497 .04379 L
.76497 .08012 L
F
.804 .522 .247 r
.76368 .08012 m
.76368 .04379 L
.76497 .04379 L
.76497 .08012 L
s
1 .894 .882 r
.76497 .08012 m
.76497 .04363 L
.76637 .04363 L
.76637 .08012 L
F
.804 .522 .247 r
.76497 .08012 m
.76497 .04363 L
.76637 .04363 L
.76637 .08012 L
s
1 .894 .882 r
.76637 .08012 m
.76637 .04305 L
.76794 .04305 L
.76794 .08012 L
F
.804 .522 .247 r
.76637 .08012 m
.76637 .04305 L
.76794 .04305 L
.76794 .08012 L
s
1 .894 .882 r
.76794 .08012 m
.76794 .04285 L
.76904 .04285 L
.76904 .08012 L
F
.804 .522 .247 r
.76794 .08012 m
.76794 .04285 L
.76904 .04285 L
.76904 .08012 L
s
1 .894 .882 r
.76904 .08012 m
.76904 .04219 L
.77086 .04219 L
.77086 .08012 L
F
.804 .522 .247 r
.76904 .08012 m
.76904 .04219 L
.77086 .04219 L
.77086 .08012 L
s
1 .894 .882 r
.77086 .08012 m
.77086 .04195 L
.77161 .04195 L
.77161 .08012 L
F
.804 .522 .247 r
.77086 .08012 m
.77086 .04195 L
.77161 .04195 L
.77161 .08012 L
s
1 .894 .882 r
.77161 .08012 m
.77161 .04158 L
.7731 .04158 L
.7731 .08012 L
F
.804 .522 .247 r
.77161 .08012 m
.77161 .04158 L
.7731 .04158 L
.7731 .08012 L
s
1 .894 .882 r
.7731 .08012 m
.7731 .04141 L
.77419 .04141 L
.77419 .08012 L
F
.804 .522 .247 r
.7731 .08012 m
.7731 .04141 L
.77419 .04141 L
.77419 .08012 L
s
1 .894 .882 r
.77419 .08012 m
.77419 .04117 L
.77563 .04117 L
.77563 .08012 L
F
.804 .522 .247 r
.77419 .08012 m
.77419 .04117 L
.77563 .04117 L
.77563 .08012 L
s
1 .894 .882 r
.77563 .08012 m
.77563 .0407 L
.77719 .0407 L
.77719 .08012 L
F
.804 .522 .247 r
.77563 .08012 m
.77563 .0407 L
.77719 .0407 L
.77719 .08012 L
s
1 .894 .882 r
.77719 .08012 m
.77719 .04039 L
.77807 .04039 L
.77807 .08012 L
F
.804 .522 .247 r
.77719 .08012 m
.77719 .04039 L
.77807 .04039 L
.77807 .08012 L
s
1 .894 .882 r
.77807 .08012 m
.77807 .04003 L
.77871 .04003 L
.77871 .08012 L
F
.804 .522 .247 r
.77807 .08012 m
.77807 .04003 L
.77871 .04003 L
.77871 .08012 L
s
1 .894 .882 r
.77871 .08012 m
.77871 .03985 L
.78065 .03985 L
.78065 .08012 L
F
.804 .522 .247 r
.77871 .08012 m
.77871 .03985 L
.78065 .03985 L
.78065 .08012 L
s
1 .894 .882 r
.78065 .08012 m
.78065 .03946 L
.78134 .03946 L
.78134 .08012 L
F
.804 .522 .247 r
.78065 .08012 m
.78065 .03946 L
.78134 .03946 L
.78134 .08012 L
s
1 .894 .882 r
.78134 .08012 m
.78134 .03912 L
.78341 .03912 L
.78341 .08012 L
F
.804 .522 .247 r
.78134 .08012 m
.78134 .03912 L
.78341 .03912 L
.78341 .08012 L
s
1 .894 .882 r
.78341 .08012 m
.78341 .03881 L
.78447 .03881 L
.78447 .08012 L
F
.804 .522 .247 r
.78341 .08012 m
.78341 .03881 L
.78447 .03881 L
.78447 .08012 L
s
1 .894 .882 r
.78447 .08012 m
.78447 .03843 L
.78527 .03843 L
.78527 .08012 L
F
.804 .522 .247 r
.78447 .08012 m
.78447 .03843 L
.78527 .03843 L
.78527 .08012 L
s
1 .894 .882 r
.78527 .08012 m
.78527 .03832 L
.78707 .03832 L
.78707 .08012 L
F
.804 .522 .247 r
.78527 .08012 m
.78527 .03832 L
.78707 .03832 L
.78707 .08012 L
s
1 .894 .882 r
.78707 .08012 m
.78707 .03791 L
.78839 .03791 L
.78839 .08012 L
F
.804 .522 .247 r
.78707 .08012 m
.78707 .03791 L
.78839 .03791 L
.78839 .08012 L
s
1 .894 .882 r
.78839 .08012 m
.78839 .03741 L
.79013 .03741 L
.79013 .08012 L
F
.804 .522 .247 r
.78839 .08012 m
.78839 .03741 L
.79013 .03741 L
.79013 .08012 L
s
1 .894 .882 r
.79013 .08012 m
.79013 .03711 L
.79177 .03711 L
.79177 .08012 L
F
.804 .522 .247 r
.79013 .08012 m
.79013 .03711 L
.79177 .03711 L
.79177 .08012 L
s
1 .894 .882 r
.79177 .08012 m
.79177 .03643 L
.7936 .03643 L
.7936 .08012 L
F
.804 .522 .247 r
.79177 .08012 m
.79177 .03643 L
.7936 .03643 L
.7936 .08012 L
s
1 .894 .882 r
.7936 .08012 m
.7936 .03634 L
.79429 .03634 L
.79429 .08012 L
F
.804 .522 .247 r
.7936 .08012 m
.7936 .03634 L
.79429 .03634 L
.79429 .08012 L
s
1 .894 .882 r
.79429 .08012 m
.79429 .03618 L
.79589 .03618 L
.79589 .08012 L
F
.804 .522 .247 r
.79429 .08012 m
.79429 .03618 L
.79589 .03618 L
.79589 .08012 L
s
1 .894 .882 r
.79589 .08012 m
.79589 .03569 L
.79687 .03569 L
.79687 .08012 L
F
.804 .522 .247 r
.79589 .08012 m
.79589 .03569 L
.79687 .03569 L
.79687 .08012 L
s
1 .894 .882 r
.79687 .08012 m
.79687 .0354 L
.79793 .0354 L
.79793 .08012 L
F
.804 .522 .247 r
.79687 .08012 m
.79687 .0354 L
.79793 .0354 L
.79793 .08012 L
s
1 .894 .882 r
.79793 .08012 m
.79793 .0352 L
.79914 .0352 L
.79914 .08012 L
F
.804 .522 .247 r
.79793 .08012 m
.79793 .0352 L
.79914 .0352 L
.79914 .08012 L
s
1 .894 .882 r
.79914 .08012 m
.79914 .0348 L
.80027 .0348 L
.80027 .08012 L
F
.804 .522 .247 r
.79914 .08012 m
.79914 .0348 L
.80027 .0348 L
.80027 .08012 L
s
1 .894 .882 r
.80027 .08012 m
.80027 .03458 L
.8015 .03458 L
.8015 .08012 L
F
.804 .522 .247 r
.80027 .08012 m
.80027 .03458 L
.8015 .03458 L
.8015 .08012 L
s
1 .894 .882 r
.8015 .08012 m
.8015 .03449 L
.80244 .03449 L
.80244 .08012 L
F
.804 .522 .247 r
.8015 .08012 m
.8015 .03449 L
.80244 .03449 L
.80244 .08012 L
s
1 .894 .882 r
.80244 .08012 m
.80244 .03401 L
.80425 .03401 L
.80425 .08012 L
F
.804 .522 .247 r
.80244 .08012 m
.80244 .03401 L
.80425 .03401 L
.80425 .08012 L
s
1 .894 .882 r
.80425 .08012 m
.80425 .03379 L
.80492 .03379 L
.80492 .08012 L
F
.804 .522 .247 r
.80425 .08012 m
.80425 .03379 L
.80492 .03379 L
.80492 .08012 L
s
1 .894 .882 r
.80492 .08012 m
.80492 .03346 L
.80682 .03346 L
.80682 .08012 L
F
.804 .522 .247 r
.80492 .08012 m
.80492 .03346 L
.80682 .03346 L
.80682 .08012 L
s
1 .894 .882 r
.80682 .08012 m
.80682 .03306 L
.80828 .03306 L
.80828 .08012 L
F
.804 .522 .247 r
.80682 .08012 m
.80682 .03306 L
.80828 .03306 L
.80828 .08012 L
s
1 .894 .882 r
.80828 .08012 m
.80828 .03279 L
.80984 .03279 L
.80984 .08012 L
F
.804 .522 .247 r
.80828 .08012 m
.80828 .03279 L
.80984 .03279 L
.80984 .08012 L
s
1 .894 .882 r
.80984 .08012 m
.80984 .03256 L
.81049 .03256 L
.81049 .08012 L
F
.804 .522 .247 r
.80984 .08012 m
.80984 .03256 L
.81049 .03256 L
.81049 .08012 L
s
1 .894 .882 r
.81049 .08012 m
.81049 .03238 L
.81253 .03238 L
.81253 .08012 L
F
.804 .522 .247 r
.81049 .08012 m
.81049 .03238 L
.81253 .03238 L
.81253 .08012 L
s
1 .894 .882 r
.81253 .08012 m
.81253 .03197 L
.81394 .03197 L
.81394 .08012 L
F
.804 .522 .247 r
.81253 .08012 m
.81253 .03197 L
.81394 .03197 L
.81394 .08012 L
s
1 .894 .882 r
.81394 .08012 m
.81394 .03173 L
.81552 .03173 L
.81552 .08012 L
F
.804 .522 .247 r
.81394 .08012 m
.81394 .03173 L
.81552 .03173 L
.81552 .08012 L
s
1 .894 .882 r
.81552 .08012 m
.81552 .03122 L
.8172 .03122 L
.8172 .08012 L
F
.804 .522 .247 r
.81552 .08012 m
.81552 .03122 L
.8172 .03122 L
.8172 .08012 L
s
1 .894 .882 r
.8172 .08012 m
.8172 .03088 L
.81907 .03088 L
.81907 .08012 L
F
.804 .522 .247 r
.8172 .08012 m
.8172 .03088 L
.81907 .03088 L
.81907 .08012 L
s
1 .894 .882 r
.81907 .08012 m
.81907 .03062 L
.82077 .03062 L
.82077 .08012 L
F
.804 .522 .247 r
.81907 .08012 m
.81907 .03062 L
.82077 .03062 L
.82077 .08012 L
s
1 .894 .882 r
.82077 .08012 m
.82077 .03036 L
.82166 .03036 L
.82166 .08012 L
F
.804 .522 .247 r
.82077 .08012 m
.82077 .03036 L
.82166 .03036 L
.82166 .08012 L
s
1 .894 .882 r
.82166 .08012 m
.82166 .0301 L
.82368 .0301 L
.82368 .08012 L
F
.804 .522 .247 r
.82166 .08012 m
.82166 .0301 L
.82368 .0301 L
.82368 .08012 L
s
1 .894 .882 r
.82368 .08012 m
.82368 .02973 L
.82454 .02973 L
.82454 .08012 L
F
.804 .522 .247 r
.82368 .08012 m
.82368 .02973 L
.82454 .02973 L
.82454 .08012 L
s
1 .894 .882 r
.82454 .08012 m
.82454 .02945 L
.8265 .02945 L
.8265 .08012 L
F
.804 .522 .247 r
.82454 .08012 m
.82454 .02945 L
.8265 .02945 L
.8265 .08012 L
s
1 .894 .882 r
.8265 .08012 m
.8265 .02924 L
.82733 .02924 L
.82733 .08012 L
F
.804 .522 .247 r
.8265 .08012 m
.8265 .02924 L
.82733 .02924 L
.82733 .08012 L
s
1 .894 .882 r
.82733 .08012 m
.82733 .02904 L
.82838 .02904 L
.82838 .08012 L
F
.804 .522 .247 r
.82733 .08012 m
.82733 .02904 L
.82838 .02904 L
.82838 .08012 L
s
1 .894 .882 r
.82838 .08012 m
.82838 .02855 L
.83036 .02855 L
.83036 .08012 L
F
.804 .522 .247 r
.82838 .08012 m
.82838 .02855 L
.83036 .02855 L
.83036 .08012 L
s
1 .894 .882 r
.83036 .08012 m
.83036 .0283 L
.83188 .0283 L
.83188 .08012 L
F
.804 .522 .247 r
.83036 .08012 m
.83036 .0283 L
.83188 .0283 L
.83188 .08012 L
s
1 .894 .882 r
.83188 .08012 m
.83188 .02803 L
.83358 .02803 L
.83358 .08012 L
F
.804 .522 .247 r
.83188 .08012 m
.83188 .02803 L
.83358 .02803 L
.83358 .08012 L
s
1 .894 .882 r
.83358 .08012 m
.83358 .02781 L
.8356 .02781 L
.8356 .08012 L
F
.804 .522 .247 r
.83358 .08012 m
.83358 .02781 L
.8356 .02781 L
.8356 .08012 L
s
1 .894 .882 r
.8356 .08012 m
.8356 .02751 L
.83697 .02751 L
.83697 .08012 L
F
.804 .522 .247 r
.8356 .08012 m
.8356 .02751 L
.83697 .02751 L
.83697 .08012 L
s
1 .894 .882 r
.83697 .08012 m
.83697 .02715 L
.83818 .02715 L
.83818 .08012 L
F
.804 .522 .247 r
.83697 .08012 m
.83697 .02715 L
.83818 .02715 L
.83818 .08012 L
s
1 .894 .882 r
.83818 .08012 m
.83818 .02676 L
.84016 .02676 L
.84016 .08012 L
F
.804 .522 .247 r
.83818 .08012 m
.83818 .02676 L
.84016 .02676 L
.84016 .08012 L
s
1 .894 .882 r
.84016 .08012 m
.84016 .02654 L
.84213 .02654 L
.84213 .08012 L
F
.804 .522 .247 r
.84016 .08012 m
.84016 .02654 L
.84213 .02654 L
.84213 .08012 L
s
1 .894 .882 r
.84213 .08012 m
.84213 .02626 L
.8437 .02626 L
.8437 .08012 L
F
.804 .522 .247 r
.84213 .08012 m
.84213 .02626 L
.8437 .02626 L
.8437 .08012 L
s
1 .894 .882 r
.8437 .08012 m
.8437 .02585 L
.84554 .02585 L
.84554 .08012 L
F
.804 .522 .247 r
.8437 .08012 m
.8437 .02585 L
.84554 .02585 L
.84554 .08012 L
s
1 .894 .882 r
.84554 .08012 m
.84554 .02575 L
.84659 .02575 L
.84659 .08012 L
F
.804 .522 .247 r
.84554 .08012 m
.84554 .02575 L
.84659 .02575 L
.84659 .08012 L
s
1 .894 .882 r
.84659 .08012 m
.84659 .02537 L
.84853 .02537 L
.84853 .08012 L
F
.804 .522 .247 r
.84659 .08012 m
.84659 .02537 L
.84853 .02537 L
.84853 .08012 L
s
1 .894 .882 r
.84853 .08012 m
.84853 .02527 L
.85015 .02527 L
.85015 .08012 L
F
.804 .522 .247 r
.84853 .08012 m
.84853 .02527 L
.85015 .02527 L
.85015 .08012 L
s
1 .894 .882 r
.85015 .08012 m
.85015 .02496 L
.85121 .02496 L
.85121 .08012 L
F
.804 .522 .247 r
.85015 .08012 m
.85015 .02496 L
.85121 .02496 L
.85121 .08012 L
s
1 .894 .882 r
.85121 .08012 m
.85121 .02484 L
.85276 .02484 L
.85276 .08012 L
F
.804 .522 .247 r
.85121 .08012 m
.85121 .02484 L
.85276 .02484 L
.85276 .08012 L
s
1 .894 .882 r
.85276 .08012 m
.85276 .0246 L
.85366 .0246 L
.85366 .08012 L
F
.804 .522 .247 r
.85276 .08012 m
.85276 .0246 L
.85366 .0246 L
.85366 .08012 L
s
1 .894 .882 r
.85366 .08012 m
.85366 .02432 L
.8555 .02432 L
.8555 .08012 L
F
.804 .522 .247 r
.85366 .08012 m
.85366 .02432 L
.8555 .02432 L
.8555 .08012 L
s
1 .894 .882 r
.8555 .08012 m
.8555 .02415 L
.85695 .02415 L
.85695 .08012 L
F
.804 .522 .247 r
.8555 .08012 m
.8555 .02415 L
.85695 .02415 L
.85695 .08012 L
s
1 .894 .882 r
.85695 .08012 m
.85695 .02377 L
.85824 .02377 L
.85824 .08012 L
F
.804 .522 .247 r
.85695 .08012 m
.85695 .02377 L
.85824 .02377 L
.85824 .08012 L
s
1 .894 .882 r
.85824 .08012 m
.85824 .02363 L
.8592 .02363 L
.8592 .08012 L
F
.804 .522 .247 r
.85824 .08012 m
.85824 .02363 L
.8592 .02363 L
.8592 .08012 L
s
1 .894 .882 r
.8592 .08012 m
.8592 .02359 L
.86081 .02359 L
.86081 .08012 L
F
.804 .522 .247 r
.8592 .08012 m
.8592 .02359 L
.86081 .02359 L
.86081 .08012 L
s
1 .894 .882 r
.86081 .08012 m
.86081 .02322 L
.8624 .02322 L
.8624 .08012 L
F
.804 .522 .247 r
.86081 .08012 m
.86081 .02322 L
.8624 .02322 L
.8624 .08012 L
s
1 .894 .882 r
.8624 .08012 m
.8624 .02299 L
.86349 .02299 L
.86349 .08012 L
F
.804 .522 .247 r
.8624 .08012 m
.8624 .02299 L
.86349 .02299 L
.86349 .08012 L
s
1 .894 .882 r
.86349 .08012 m
.86349 .02281 L
.86549 .02281 L
.86549 .08012 L
F
.804 .522 .247 r
.86349 .08012 m
.86349 .02281 L
.86549 .02281 L
.86549 .08012 L
s
1 .894 .882 r
.86549 .08012 m
.86549 .02264 L
.86721 .02264 L
.86721 .08012 L
F
.804 .522 .247 r
.86549 .08012 m
.86549 .02264 L
.86721 .02264 L
.86721 .08012 L
s
1 .894 .882 r
.86721 .08012 m
.86721 .02235 L
.8679 .02235 L
.8679 .08012 L
F
.804 .522 .247 r
.86721 .08012 m
.86721 .02235 L
.8679 .02235 L
.8679 .08012 L
s
1 .894 .882 r
.8679 .08012 m
.8679 .0223 L
.86938 .0223 L
.86938 .08012 L
F
.804 .522 .247 r
.8679 .08012 m
.8679 .0223 L
.86938 .0223 L
.86938 .08012 L
s
1 .894 .882 r
.86938 .08012 m
.86938 .02205 L
.87146 .02205 L
.87146 .08012 L
F
.804 .522 .247 r
.86938 .08012 m
.86938 .02205 L
.87146 .02205 L
.87146 .08012 L
s
1 .894 .882 r
.87146 .08012 m
.87146 .02171 L
.87243 .02171 L
.87243 .08012 L
F
.804 .522 .247 r
.87146 .08012 m
.87146 .02171 L
.87243 .02171 L
.87243 .08012 L
s
1 .894 .882 r
.87243 .08012 m
.87243 .02167 L
.874 .02167 L
.874 .08012 L
F
.804 .522 .247 r
.87243 .08012 m
.87243 .02167 L
.874 .02167 L
.874 .08012 L
s
1 .894 .882 r
.874 .08012 m
.874 .02144 L
.87559 .02144 L
.87559 .08012 L
F
.804 .522 .247 r
.874 .08012 m
.874 .02144 L
.87559 .02144 L
.87559 .08012 L
s
1 .894 .882 r
.87559 .08012 m
.87559 .02122 L
.87632 .02122 L
.87632 .08012 L
F
.804 .522 .247 r
.87559 .08012 m
.87559 .02122 L
.87632 .02122 L
.87632 .08012 L
s
1 .894 .882 r
.87632 .08012 m
.87632 .02109 L
.87782 .02109 L
.87782 .08012 L
F
.804 .522 .247 r
.87632 .08012 m
.87632 .02109 L
.87782 .02109 L
.87782 .08012 L
s
1 .894 .882 r
.87782 .08012 m
.87782 .02092 L
.87964 .02092 L
.87964 .08012 L
F
.804 .522 .247 r
.87782 .08012 m
.87782 .02092 L
.87964 .02092 L
.87964 .08012 L
s
1 .894 .882 r
.87964 .08012 m
.87964 .02062 L
.88081 .02062 L
.88081 .08012 L
F
.804 .522 .247 r
.87964 .08012 m
.87964 .02062 L
.88081 .02062 L
.88081 .08012 L
s
1 .894 .882 r
.88081 .08012 m
.88081 .02052 L
.88169 .02052 L
.88169 .08012 L
F
.804 .522 .247 r
.88081 .08012 m
.88081 .02052 L
.88169 .02052 L
.88169 .08012 L
s
1 .894 .882 r
.88169 .08012 m
.88169 .02041 L
.88366 .02041 L
.88366 .08012 L
F
.804 .522 .247 r
.88169 .08012 m
.88169 .02041 L
.88366 .02041 L
.88366 .08012 L
s
1 .894 .882 r
.88366 .08012 m
.88366 .02011 L
.88504 .02011 L
.88504 .08012 L
F
.804 .522 .247 r
.88366 .08012 m
.88366 .02011 L
.88504 .02011 L
.88504 .08012 L
s
1 .894 .882 r
.88504 .08012 m
.88504 .01992 L
.88675 .01992 L
.88675 .08012 L
F
.804 .522 .247 r
.88504 .08012 m
.88504 .01992 L
.88675 .01992 L
.88675 .08012 L
s
1 .894 .882 r
.88675 .08012 m
.88675 .01969 L
.88882 .01969 L
.88882 .08012 L
F
.804 .522 .247 r
.88675 .08012 m
.88675 .01969 L
.88882 .01969 L
.88882 .08012 L
s
1 .894 .882 r
.88882 .08012 m
.88882 .01959 L
.88958 .01959 L
.88958 .08012 L
F
.804 .522 .247 r
.88882 .08012 m
.88882 .01959 L
.88958 .01959 L
.88958 .08012 L
s
1 .894 .882 r
.88958 .08012 m
.88958 .01938 L
.8916 .01938 L
.8916 .08012 L
F
.804 .522 .247 r
.88958 .08012 m
.88958 .01938 L
.8916 .01938 L
.8916 .08012 L
s
1 .894 .882 r
.8916 .08012 m
.8916 .01935 L
.89265 .01935 L
.89265 .08012 L
F
.804 .522 .247 r
.8916 .08012 m
.8916 .01935 L
.89265 .01935 L
.89265 .08012 L
s
1 .894 .882 r
.89265 .08012 m
.89265 .01922 L
.89439 .01922 L
.89439 .08012 L
F
.804 .522 .247 r
.89265 .08012 m
.89265 .01922 L
.89439 .01922 L
.89439 .08012 L
s
1 .894 .882 r
.89439 .08012 m
.89439 .01893 L
.89563 .01893 L
.89563 .08012 L
F
.804 .522 .247 r
.89439 .08012 m
.89439 .01893 L
.89563 .01893 L
.89563 .08012 L
s
1 .894 .882 r
.89563 .08012 m
.89563 .01889 L
.89669 .01889 L
.89669 .08012 L
F
.804 .522 .247 r
.89563 .08012 m
.89563 .01889 L
.89669 .01889 L
.89669 .08012 L
s
1 .894 .882 r
.89669 .08012 m
.89669 .01876 L
.89874 .01876 L
.89874 .08012 L
F
.804 .522 .247 r
.89669 .08012 m
.89669 .01876 L
.89874 .01876 L
.89874 .08012 L
s
1 .894 .882 r
.89874 .08012 m
.89874 .01849 L
.90056 .01849 L
.90056 .08012 L
F
.804 .522 .247 r
.89874 .08012 m
.89874 .01849 L
.90056 .01849 L
.90056 .08012 L
s
1 .894 .882 r
.90056 .08012 m
.90056 .01829 L
.90219 .01829 L
.90219 .08012 L
F
.804 .522 .247 r
.90056 .08012 m
.90056 .01829 L
.90219 .01829 L
.90219 .08012 L
s
1 .894 .882 r
.90219 .08012 m
.90219 .01822 L
.90317 .01822 L
.90317 .08012 L
F
.804 .522 .247 r
.90219 .08012 m
.90219 .01822 L
.90317 .01822 L
.90317 .08012 L
s
1 .894 .882 r
.90317 .08012 m
.90317 .01816 L
.90437 .01816 L
.90437 .08012 L
F
.804 .522 .247 r
.90317 .08012 m
.90317 .01816 L
.90437 .01816 L
.90437 .08012 L
s
1 .894 .882 r
.90437 .08012 m
.90437 .01799 L
.90621 .01799 L
.90621 .08012 L
F
.804 .522 .247 r
.90437 .08012 m
.90437 .01799 L
.90621 .01799 L
.90621 .08012 L
s
1 .894 .882 r
.90621 .08012 m
.90621 .01779 L
.90749 .01779 L
.90749 .08012 L
F
.804 .522 .247 r
.90621 .08012 m
.90621 .01779 L
.90749 .01779 L
.90749 .08012 L
s
1 .894 .882 r
.90749 .08012 m
.90749 .01772 L
.90899 .01772 L
.90899 .08012 L
F
.804 .522 .247 r
.90749 .08012 m
.90749 .01772 L
.90899 .01772 L
.90899 .08012 L
s
1 .894 .882 r
.90899 .08012 m
.90899 .01751 L
.91069 .01751 L
.91069 .08012 L
F
.804 .522 .247 r
.90899 .08012 m
.90899 .01751 L
.91069 .01751 L
.91069 .08012 L
s
1 .894 .882 r
.91069 .08012 m
.91069 .0174 L
.91242 .0174 L
.91242 .08012 L
F
.804 .522 .247 r
.91069 .08012 m
.91069 .0174 L
.91242 .0174 L
.91242 .08012 L
s
1 .894 .882 r
.91242 .08012 m
.91242 .0173 L
.91429 .0173 L
.91429 .08012 L
F
.804 .522 .247 r
.91242 .08012 m
.91242 .0173 L
.91429 .0173 L
.91429 .08012 L
s
1 .894 .882 r
.91429 .08012 m
.91429 .01719 L
.91607 .01719 L
.91607 .08012 L
F
.804 .522 .247 r
.91429 .08012 m
.91429 .01719 L
.91607 .01719 L
.91607 .08012 L
s
1 .894 .882 r
.91607 .08012 m
.91607 .01698 L
.91722 .01698 L
.91722 .08012 L
F
.804 .522 .247 r
.91607 .08012 m
.91607 .01698 L
.91722 .01698 L
.91722 .08012 L
s
1 .894 .882 r
.91722 .08012 m
.91722 .01689 L
.91871 .01689 L
.91871 .08012 L
F
.804 .522 .247 r
.91722 .08012 m
.91722 .01689 L
.91871 .01689 L
.91871 .08012 L
s
1 .894 .882 r
.91871 .08012 m
.91871 .01672 L
.9207 .01672 L
.9207 .08012 L
F
.804 .522 .247 r
.91871 .08012 m
.91871 .01672 L
.9207 .01672 L
.9207 .08012 L
s
1 .894 .882 r
.9207 .08012 m
.9207 .01671 L
.92172 .01671 L
.92172 .08012 L
F
.804 .522 .247 r
.9207 .08012 m
.9207 .01671 L
.92172 .01671 L
.92172 .08012 L
s
1 .894 .882 r
.92172 .08012 m
.92172 .01653 L
.92325 .01653 L
.92325 .08012 L
F
.804 .522 .247 r
.92172 .08012 m
.92172 .01653 L
.92325 .01653 L
.92325 .08012 L
s
1 .894 .882 r
.92325 .08012 m
.92325 .01645 L
.92476 .01645 L
.92476 .08012 L
F
.804 .522 .247 r
.92325 .08012 m
.92325 .01645 L
.92476 .01645 L
.92476 .08012 L
s
1 .894 .882 r
.92476 .08012 m
.92476 .01631 L
.92662 .01631 L
.92662 .08012 L
F
.804 .522 .247 r
.92476 .08012 m
.92476 .01631 L
.92662 .01631 L
.92662 .08012 L
s
1 .894 .882 r
.92662 .08012 m
.92662 .01629 L
.92771 .01629 L
.92771 .08012 L
F
.804 .522 .247 r
.92662 .08012 m
.92662 .01629 L
.92771 .01629 L
.92771 .08012 L
s
1 .894 .882 r
.92771 .08012 m
.92771 .01618 L
.92882 .01618 L
.92882 .08012 L
F
.804 .522 .247 r
.92771 .08012 m
.92771 .01618 L
.92882 .01618 L
.92882 .08012 L
s
1 .894 .882 r
.92882 .08012 m
.92882 .01609 L
.93068 .01609 L
.93068 .08012 L
F
.804 .522 .247 r
.92882 .08012 m
.92882 .01609 L
.93068 .01609 L
.93068 .08012 L
s
1 .894 .882 r
.93068 .08012 m
.93068 .01606 L
.93192 .01606 L
.93192 .08012 L
F
.804 .522 .247 r
.93068 .08012 m
.93068 .01606 L
.93192 .01606 L
.93192 .08012 L
s
1 .894 .882 r
.93192 .08012 m
.93192 .01595 L
.93258 .01595 L
.93258 .08012 L
F
.804 .522 .247 r
.93192 .08012 m
.93192 .01595 L
.93258 .01595 L
.93258 .08012 L
s
1 .894 .882 r
.93258 .08012 m
.93258 .01591 L
.93373 .01591 L
.93373 .08012 L
F
.804 .522 .247 r
.93258 .08012 m
.93258 .01591 L
.93373 .01591 L
.93373 .08012 L
s
1 .894 .882 r
.93373 .08012 m
.93373 .01588 L
.93439 .01588 L
.93439 .08012 L
F
.804 .522 .247 r
.93373 .08012 m
.93373 .01588 L
.93439 .01588 L
.93439 .08012 L
s
1 .894 .882 r
.93439 .08012 m
.93439 .01583 L
.9361 .01583 L
.9361 .08012 L
F
.804 .522 .247 r
.93439 .08012 m
.93439 .01583 L
.9361 .01583 L
.9361 .08012 L
s
1 .894 .882 r
.9361 .08012 m
.9361 .01573 L
.93787 .01573 L
.93787 .08012 L
F
.804 .522 .247 r
.9361 .08012 m
.9361 .01573 L
.93787 .01573 L
.93787 .08012 L
s
1 .894 .882 r
.93787 .08012 m
.93787 .01562 L
.93992 .01562 L
.93992 .08012 L
F
.804 .522 .247 r
.93787 .08012 m
.93787 .01562 L
.93992 .01562 L
.93992 .08012 L
s
1 .894 .882 r
.93992 .08012 m
.93992 .01554 L
.94083 .01554 L
.94083 .08012 L
F
.804 .522 .247 r
.93992 .08012 m
.93992 .01554 L
.94083 .01554 L
.94083 .08012 L
s
1 .894 .882 r
.94083 .08012 m
.94083 .01551 L
.94189 .01551 L
.94189 .08012 L
F
.804 .522 .247 r
.94083 .08012 m
.94083 .01551 L
.94189 .01551 L
.94189 .08012 L
s
1 .894 .882 r
.94189 .08012 m
.94189 .01544 L
.94277 .01544 L
.94277 .08012 L
F
.804 .522 .247 r
.94189 .08012 m
.94189 .01544 L
.94277 .01544 L
.94277 .08012 L
s
1 .894 .882 r
.94277 .08012 m
.94277 .01542 L
.94375 .01542 L
.94375 .08012 L
F
.804 .522 .247 r
.94277 .08012 m
.94277 .01542 L
.94375 .01542 L
.94375 .08012 L
s
1 .894 .882 r
.94375 .08012 m
.94375 .01535 L
.94502 .01535 L
.94502 .08012 L
F
.804 .522 .247 r
.94375 .08012 m
.94375 .01535 L
.94502 .01535 L
.94502 .08012 L
s
1 .894 .882 r
.94502 .08012 m
.94502 .0153 L
.9463 .0153 L
.9463 .08012 L
F
.804 .522 .247 r
.94502 .08012 m
.94502 .0153 L
.9463 .0153 L
.9463 .08012 L
s
1 .894 .882 r
.9463 .08012 m
.9463 .01526 L
.9475 .01526 L
.9475 .08012 L
F
.804 .522 .247 r
.9463 .08012 m
.9463 .01526 L
.9475 .01526 L
.9475 .08012 L
s
1 .894 .882 r
.9475 .08012 m
.9475 .0152 L
.94942 .0152 L
.94942 .08012 L
F
.804 .522 .247 r
.9475 .08012 m
.9475 .0152 L
.94942 .0152 L
.94942 .08012 L
s
1 .894 .882 r
.94942 .08012 m
.94942 .01517 L
.95129 .01517 L
.95129 .08012 L
F
.804 .522 .247 r
.94942 .08012 m
.94942 .01517 L
.95129 .01517 L
.95129 .08012 L
s
1 .894 .882 r
.95129 .08012 m
.95129 .01508 L
.95266 .01508 L
.95266 .08012 L
F
.804 .522 .247 r
.95129 .08012 m
.95129 .01508 L
.95266 .01508 L
.95266 .08012 L
s
1 .894 .882 r
.95266 .08012 m
.95266 .01506 L
.95347 .01506 L
.95347 .08012 L
F
.804 .522 .247 r
.95266 .08012 m
.95266 .01506 L
.95347 .01506 L
.95347 .08012 L
s
1 .894 .882 r
.95347 .08012 m
.95347 .01503 L
.95449 .01503 L
.95449 .08012 L
F
.804 .522 .247 r
.95347 .08012 m
.95347 .01503 L
.95449 .01503 L
.95449 .08012 L
s
1 .894 .882 r
.95449 .08012 m
.95449 .01501 L
.95548 .01501 L
.95548 .08012 L
F
.804 .522 .247 r
.95449 .08012 m
.95449 .01501 L
.95548 .01501 L
.95548 .08012 L
s
1 .894 .882 r
.95548 .08012 m
.95548 .01499 L
.95708 .01499 L
.95708 .08012 L
F
.804 .522 .247 r
.95548 .08012 m
.95548 .01499 L
.95708 .01499 L
.95708 .08012 L
s
1 .894 .882 r
.95708 .08012 m
.95708 .01493 L
.95888 .01493 L
.95888 .08012 L
F
.804 .522 .247 r
.95708 .08012 m
.95708 .01493 L
.95888 .01493 L
.95888 .08012 L
s
1 .894 .882 r
.95888 .08012 m
.95888 .01488 L
.96089 .01488 L
.96089 .08012 L
F
.804 .522 .247 r
.95888 .08012 m
.95888 .01488 L
.96089 .01488 L
.96089 .08012 L
s
1 .894 .882 r
.96089 .08012 m
.96089 .01485 L
.96212 .01485 L
.96212 .08012 L
F
.804 .522 .247 r
.96089 .08012 m
.96089 .01485 L
.96212 .01485 L
.96212 .08012 L
s
1 .894 .882 r
.96212 .08012 m
.96212 .01484 L
.9631 .01484 L
.9631 .08012 L
F
.804 .522 .247 r
.96212 .08012 m
.96212 .01484 L
.9631 .01484 L
.9631 .08012 L
s
1 .894 .882 r
.9631 .08012 m
.9631 .01481 L
.96486 .01481 L
.96486 .08012 L
F
.804 .522 .247 r
.9631 .08012 m
.9631 .01481 L
.96486 .01481 L
.96486 .08012 L
s
1 .894 .882 r
.96486 .08012 m
.96486 .0148 L
.96635 .0148 L
.96635 .08012 L
F
.804 .522 .247 r
.96486 .08012 m
.96486 .0148 L
.96635 .0148 L
.96635 .08012 L
s
1 .894 .882 r
.96635 .08012 m
.96635 .01477 L
.96754 .01477 L
.96754 .08012 L
F
.804 .522 .247 r
.96635 .08012 m
.96635 .01477 L
.96754 .01477 L
.96754 .08012 L
s
1 .894 .882 r
.96754 .08012 m
.96754 .01475 L
.96891 .01475 L
.96891 .08012 L
F
.804 .522 .247 r
.96754 .08012 m
.96754 .01475 L
.96891 .01475 L
.96891 .08012 L
s
1 .894 .882 r
.96891 .08012 m
.96891 .01474 L
.97099 .01474 L
.97099 .08012 L
F
.804 .522 .247 r
.96891 .08012 m
.96891 .01474 L
.97099 .01474 L
.97099 .08012 L
s
1 .894 .882 r
.97099 .08012 m
.97099 .01473 L
.97253 .01473 L
.97253 .08012 L
F
.804 .522 .247 r
.97099 .08012 m
.97099 .01473 L
.97253 .01473 L
.97253 .08012 L
s
1 .894 .882 r
.97253 .08012 m
.97253 .01472 L
.97343 .01472 L
.97343 .08012 L
F
.804 .522 .247 r
.97253 .08012 m
.97253 .01472 L
.97343 .01472 L
.97343 .08012 L
s
1 .894 .882 r
.97343 .08012 m
.97343 .01472 L
.97437 .01472 L
.97437 .08012 L
F
.804 .522 .247 r
.97343 .08012 m
.97343 .01472 L
.97437 .01472 L
.97437 .08012 L
s
1 .894 .882 r
.97437 .08012 m
.97437 .01472 L
.97619 .01472 L
.97619 .08012 L
F
.804 .522 .247 r
.97437 .08012 m
.97437 .01472 L
.97619 .01472 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.02437 .60262 Mdot
.02639 .60014 Mdot
.02832 .59776 Mdot
.02939 .59645 Mdot
.03102 .59444 Mdot
.03284 .59221 Mdot
.03337 .59156 Mdot
.03516 .58937 Mdot
.03682 .58735 Mdot
.03858 .5852 Mdot
.04016 .58328 Mdot
.04177 .58133 Mdot
.04289 .57997 Mdot
.04394 .5787 Mdot
.04498 .57744 Mdot
.04638 .57575 Mdot
.04796 .57384 Mdot
.04929 .57225 Mdot
.05047 .57083 Mdot
.05113 .57003 Mdot
.05139 .56972 Mdot
.05374 .56691 Mdot
.05549 .56481 Mdot
.05681 .56323 Mdot
.05812 .56167 Mdot
.05962 .55989 Mdot
.06129 .5579 Mdot
.06223 .55679 Mdot
.06311 .55574 Mdot
.06374 .55499 Mdot
.06626 .55201 Mdot
.06688 .55129 Mdot
.06968 .54799 Mdot
.07025 .54731 Mdot
.07119 .54621 Mdot
.07353 .54347 Mdot
.07494 .54182 Mdot
.0754 .54127 Mdot
.07692 .5395 Mdot
.07847 .53769 Mdot
.07854 .53761 Mdot
.08017 .53571 Mdot
.08218 .53338 Mdot
.08281 .53265 Mdot
.0846 .53057 Mdot
.08524 .52984 Mdot
.08574 .52926 Mdot
.08664 .52821 Mdot
.08772 .52697 Mdot
.08998 .52437 Mdot
.09091 .5233 Mdot
.09303 .52086 Mdot
.09341 .52044 Mdot
.09579 .51771 Mdot
.09698 .51635 Mdot
.09776 .51546 Mdot
.0982 .51496 Mdot
.10001 .5129 Mdot
.10213 .51049 Mdot
.10363 .50879 Mdot
.10408 .50828 Mdot
.10489 .50736 Mdot
.10565 .50651 Mdot
.1071 .50487 Mdot
.10952 .50214 Mdot
.11129 .50015 Mdot
.11173 .49966 Mdot
.11401 .49711 Mdot
.11491 .4961 Mdot
.11632 .49452 Mdot
.11768 .493 Mdot
.11963 .49083 Mdot
.12015 .49025 Mdot
.12213 .48806 Mdot
.12389 .48612 Mdot
.12486 .48504 Mdot
.12548 .48435 Mdot
.12906 .48042 Mdot
.12917 .48029 Mdot
.13044 .47889 Mdot
.1312 .47806 Mdot
.13305 .47604 Mdot
.13407 .47492 Mdot
.13518 .47371 Mdot
.13832 .47029 Mdot
.13949 .46902 Mdot
.14029 .46814 Mdot
.14082 .46757 Mdot
.14175 .46657 Mdot
.14296 .46526 Mdot
.14349 .46468 Mdot
.14487 .46319 Mdot
.14744 .46042 Mdot
.14794 .45989 Mdot
.1489 .45885 Mdot
.1515 .45606 Mdot
.1527 .45478 Mdot
.15392 .45348 Mdot
.15464 .45271 Mdot
.15527 .45203 Mdot
.15711 .45009 Mdot
.1587 .44839 Mdot
.15963 .4474 Mdot
.16081 .44615 Mdot
.16231 .44457 Mdot
.16357 .44324 Mdot
.1654 .44131 Mdot
.16566 .44104 Mdot
.16783 .43876 Mdot
.16892 .43762 Mdot
.17088 .43557 Mdot
.17167 .43474 Mdot
.17338 .43296 Mdot
.17506 .4312 Mdot
.17583 .43041 Mdot
.17805 .4281 Mdot
.17919 .42693 Mdot
.18029 .42579 Mdot
.18137 .42468 Mdot
.18356 .42242 Mdot
.18536 .42057 Mdot
.18563 .42029 Mdot
.18734 .41853 Mdot
.1907 .41511 Mdot
.19148 .41431 Mdot
.19255 .41322 Mdot
.19397 .41178 Mdot
.19509 .41064 Mdot
.19614 .40958 Mdot
.19659 .40913 Mdot
.19815 .40755 Mdot
.19944 .40625 Mdot
.20058 .4051 Mdot
.20318 .40248 Mdot
.20354 .40212 Mdot
.20535 .40031 Mdot
.20701 .39865 Mdot
.20749 .39817 Mdot
.21004 .39563 Mdot
.21113 .39455 Mdot
.21159 .39409 Mdot
.21307 .39262 Mdot
.21448 .39123 Mdot
.21572 .39001 Mdot
.21618 .38955 Mdot
.21769 .38806 Mdot
.21945 .38633 Mdot
.22122 .3846 Mdot
.22186 .38397 Mdot
.22349 .38237 Mdot
.22478 .38111 Mdot
.22628 .37965 Mdot
.2282 .37779 Mdot
.22889 .37712 Mdot
.23069 .37537 Mdot
.23153 .37457 Mdot
.23247 .37366 Mdot
.23315 .37299 Mdot
.23455 .37165 Mdot
.23578 .37047 Mdot
.23867 .3677 Mdot
.23909 .36729 Mdot
.24089 .36557 Mdot
.24176 .36474 Mdot
.24337 .36321 Mdot
.24369 .3629 Mdot
.24545 .36124 Mdot
.24685 .35991 Mdot
.24753 .35927 Mdot
.24875 .35811 Mdot
.24923 .35766 Mdot
.25035 .3566 Mdot
.25096 .35603 Mdot
.25251 .35457 Mdot
.25328 .35384 Mdot
.25398 .3532 Mdot
.25616 .35116 Mdot
.25683 .35053 Mdot
.25879 .3487 Mdot
.25949 .34805 Mdot
.25991 .34765 Mdot
.26332 .34449 Mdot
.26417 .34371 Mdot
.26588 .34213 Mdot
.26682 .34126 Mdot
.26954 .33876 Mdot
.27093 .33749 Mdot
.27132 .33714 Mdot
.27248 .33608 Mdot
.274 .33469 Mdot
.2748 .33396 Mdot
.27689 .33206 Mdot
.27917 .32999 Mdot
.27997 .32927 Mdot
.28151 .32788 Mdot
.28255 .32694 Mdot
.2835 .32609 Mdot
.28578 .32404 Mdot
.28614 .32372 Mdot
.28869 .32144 Mdot
.28906 .32111 Mdot
.29051 .31982 Mdot
.29148 .31896 Mdot
.29337 .31728 Mdot
.29442 .31634 Mdot
.29653 .31448 Mdot
.29772 .31343 Mdot
.29922 .31211 Mdot
.30158 .31004 Mdot
.30293 .30886 Mdot
.30333 .30852 Mdot
.30624 .30598 Mdot
.3075 .30489 Mdot
.30824 .30424 Mdot
.30874 .30381 Mdot
.30975 .30293 Mdot
.31167 .30128 Mdot
.31253 .30053 Mdot
.313 .30013 Mdot
.31519 .29825 Mdot
.31607 .2975 Mdot
.31762 .29617 Mdot
.31808 .29578 Mdot
.32037 .29382 Mdot
.32123 .29309 Mdot
.32269 .29185 Mdot
.32517 .28975 Mdot
.32649 .28864 Mdot
.32713 .2881 Mdot
.3277 .28762 Mdot
.32997 .28571 Mdot
.33152 .28442 Mdot
.33357 .2827 Mdot
.33434 .28206 Mdot
.33525 .2813 Mdot
.33677 .28004 Mdot
.33959 .27771 Mdot
.34056 .2769 Mdot
.34081 .27669 Mdot
.34152 .27611 Mdot
.34321 .27472 Mdot
.34411 .27398 Mdot
.34637 .27213 Mdot
.34655 .27198 Mdot
.34814 .27068 Mdot
.34971 .26941 Mdot
.35227 .26733 Mdot
.3527 .26698 Mdot
.35539 .26481 Mdot
.35652 .2639 Mdot
.35834 .26244 Mdot
.35915 .26179 Mdot
.36112 .26021 Mdot
.36311 .25863 Mdot
.36368 .25817 Mdot
.36447 .25755 Mdot
.36585 .25646 Mdot
.36784 .25488 Mdot
.36895 .25401 Mdot
.37163 .2519 Mdot
.37245 .25125 Mdot
.3743 .2498 Mdot
.37481 .24941 Mdot
.37797 .24695 Mdot
.37874 .24635 Mdot
.38033 .24512 Mdot
.38083 .24473 Mdot
.38258 .24338 Mdot
.38463 .2418 Mdot
.38523 .24134 Mdot
.38673 .24019 Mdot
.38805 .23919 Mdot
.39037 .23742 Mdot
.39094 .23698 Mdot
.39208 .23612 Mdot
.39345 .23509 Mdot
.39378 .23483 Mdot
.39608 .2331 Mdot
.39793 .23171 Mdot
.39894 .23095 Mdot
.4004 .22986 Mdot
.40111 .22933 Mdot
.40198 .22868 Mdot
.404 .22718 Mdot
.40521 .22628 Mdot
.40775 .2244 Mdot
.40835 .22396 Mdot
.40924 .2233 Mdot
.41139 .22173 Mdot
.41253 .22089 Mdot
.41382 .21994 Mdot
.41511 .21901 Mdot
.41618 .21823 Mdot
.41685 .21774 Mdot
.41826 .21672 Mdot
.41992 .21552 Mdot
.4208 .21489 Mdot
.42182 .21415 Mdot
.42266 .21355 Mdot
.42506 .21183 Mdot
.42574 .21134 Mdot
.42708 .21038 Mdot
.42838 .20946 Mdot
.4291 .20895 Mdot
.43017 .20819 Mdot
.43139 .20732 Mdot
.43175 .20707 Mdot
.43422 .20533 Mdot
.43491 .20484 Mdot
.43722 .20322 Mdot
.43827 .20249 Mdot
.4393 .20177 Mdot
.44089 .20066 Mdot
.442 .1999 Mdot
.44322 .19905 Mdot
.44369 .19872 Mdot
.44481 .19795 Mdot
.44585 .19724 Mdot
.44805 .19573 Mdot
.44916 .19497 Mdot
.45135 .19347 Mdot
.45256 .19265 Mdot
.45359 .19195 Mdot
.45491 .19105 Mdot
.45637 .19006 Mdot
.45911 .18822 Mdot
.46064 .1872 Mdot
.46312 .18554 Mdot
.46376 .18512 Mdot
.46582 .18375 Mdot
.4668 .1831 Mdot
.46842 .18203 Mdot
.46921 .18151 Mdot
.4705 .18066 Mdot
.47138 .18008 Mdot
.47346 .17872 Mdot
.47454 .17802 Mdot
.47576 .17723 Mdot
.47663 .17667 Mdot
.47871 .17532 Mdot
.47943 .17485 Mdot
.48073 .17402 Mdot
.483 .17256 Mdot
.48487 .17137 Mdot
.48683 .17012 Mdot
.48832 .16917 Mdot
.48883 .16885 Mdot
.48959 .16837 Mdot
.49067 .16769 Mdot
.4912 .16736 Mdot
.49224 .1667 Mdot
.49394 .16563 Mdot
.49522 .16484 Mdot
.49699 .16373 Mdot
.49895 .16252 Mdot
.49944 .16221 Mdot
.50039 .16163 Mdot
.50257 .16028 Mdot
.50415 .15931 Mdot
.50422 .15927 Mdot
.50624 .15804 Mdot
.50727 .15741 Mdot
.5097 .15593 Mdot
.51013 .15567 Mdot
.5107 .15533 Mdot
.51268 .15413 Mdot
.51313 .15386 Mdot
.51431 .15316 Mdot
.51499 .15275 Mdot
.51792 .151 Mdot
.51877 .15049 Mdot
.51971 .14994 Mdot
.52013 .14969 Mdot
.52169 .14877 Mdot
.52336 .14778 Mdot
.52473 .14698 Mdot
.52717 .14555 Mdot
.5275 .14536 Mdot
.52975 .14406 Mdot
.53035 .14371 Mdot
.53197 .14277 Mdot
.53314 .14209 Mdot
.53476 .14117 Mdot
.53503 .14101 Mdot
.53595 .14048 Mdot
.53745 .13963 Mdot
.53822 .13919 Mdot
.5395 .13847 Mdot
.54035 .13799 Mdot
.54247 .13679 Mdot
.54395 .13596 Mdot
.54548 .1351 Mdot
.54619 .1347 Mdot
.54938 .13293 Mdot
.54983 .13268 Mdot
.5519 .13154 Mdot
.55313 .13086 Mdot
.55378 .13051 Mdot
.55547 .12958 Mdot
.55617 .1292 Mdot
.558 .1282 Mdot
.55862 .12787 Mdot
.56072 .12673 Mdot
.56248 .12579 Mdot
.56279 .12562 Mdot
.56419 .12487 Mdot
.56593 .12394 Mdot
.56734 .12319 Mdot
.56934 .12213 Mdot
.56999 .12179 Mdot
.57231 .12057 Mdot
.57335 .12002 Mdot
.57503 .11915 Mdot
.57653 .11837 Mdot
.57825 .11748 Mdot
.57955 .11681 Mdot
.58086 .11614 Mdot
.58236 .11537 Mdot
.58287 .11511 Mdot
.58481 .11412 Mdot
.5859 .11356 Mdot
.58681 .1131 Mdot
.58892 .11204 Mdot
.59026 .11137 Mdot
.59151 .11074 Mdot
.5931 .10995 Mdot
.59447 .10927 Mdot
.59571 .10866 Mdot
.59736 .10784 Mdot
.59875 .10716 Mdot
.59985 .10663 Mdot
.60108 .10602 Mdot
.60263 .10527 Mdot
.60308 .10505 Mdot
.60474 .10425 Mdot
.60612 .10359 Mdot
.60683 .10325 Mdot
.60921 .10211 Mdot
.60984 .10181 Mdot
.61209 .10074 Mdot
.61429 .09971 Mdot
.61454 .09959 Mdot
.61719 .09835 Mdot
.61848 .09775 Mdot
.62021 .09695 Mdot
.62302 .09566 Mdot
.62332 .09552 Mdot
.62412 .09515 Mdot
.62665 .094 Mdot
.62685 .09391 Mdot
.62845 .09319 Mdot
.63009 .09245 Mdot
.63161 .09177 Mdot
.63434 .09055 Mdot
.63478 .09036 Mdot
.63584 .08989 Mdot
.63763 .0891 Mdot
.63899 .0885 Mdot
.63965 .08821 Mdot
.64098 .08763 Mdot
.64256 .08695 Mdot
.6432 .08667 Mdot
.64431 .08619 Mdot
.64554 .08566 Mdot
.64754 .08481 Mdot
.64784 .08468 Mdot
.65019 .08368 Mdot
.65236 .08277 Mdot
.65303 .08248 Mdot
.65417 .08201 Mdot
.6568 .08091 Mdot
.65955 .07978 Mdot
.66059 .07935 Mdot
.66327 .07826 Mdot
.66429 .07784 Mdot
.66468 .07769 Mdot
.66728 .07664 Mdot
.66769 .07647 Mdot
.66976 .07565 Mdot
.67079 .07524 Mdot
.67206 .07474 Mdot
.67231 .07464 Mdot
.673 .07437 Mdot
.67367 .0741 Mdot
.67573 .0733 Mdot
.67706 .07278 Mdot
.68034 .07151 Mdot
.68116 .0712 Mdot
.68179 .07096 Mdot
.68227 .07078 Mdot
.68329 .07039 Mdot
.6852 .06966 Mdot
.68566 .06949 Mdot
.68678 .06907 Mdot
.68906 .06822 Mdot
.69037 .06773 Mdot
.69163 .06726 Mdot
.69217 .06706 Mdot
.69454 .06619 Mdot
.69504 .06601 Mdot
.69669 .06541 Mdot
.69697 .06531 Mdot
.69884 .06463 Mdot
.70123 .06378 Mdot
.70255 .06331 Mdot
.70387 .06284 Mdot
.70534 .06232 Mdot
.70583 .06215 Mdot
.70709 .06171 Mdot
.7088 .06111 Mdot
.70968 .06081 Mdot
.71088 .06039 Mdot
.71294 .05969 Mdot
.71508 .05896 Mdot
.71741 .05817 Mdot
.71828 .05788 Mdot
.71932 .05753 Mdot
.72087 .05702 Mdot
.7219 .05668 Mdot
.72434 .05588 Mdot
.72523 .05559 Mdot
.72666 .05512 Mdot
.72744 .05487 Mdot
.72848 .05453 Mdot
.72975 .05413 Mdot
.73046 .0539 Mdot
.7333 .053 Mdot
.7338 .05284 Mdot
.73564 .05226 Mdot
.73734 .05174 Mdot
.73975 .05099 Mdot
.74051 .05076 Mdot
.74177 .05038 Mdot
.7424 .05018 Mdot
.74325 .04993 Mdot
.74399 .0497 Mdot
.74565 .04921 Mdot
.74638 .04899 Mdot
.74827 .04842 Mdot
.75006 .0479 Mdot
.75082 .04768 Mdot
.75261 .04716 Mdot
.75394 .04677 Mdot
.75487 .0465 Mdot
.75609 .04615 Mdot
.75782 .04566 Mdot
.75901 .04532 Mdot
.76018 .04499 Mdot
.76167 .04458 Mdot
.76324 .04414 Mdot
.76452 .04379 Mdot
.76509 .04363 Mdot
.76724 .04305 Mdot
.76796 .04285 Mdot
.77042 .04219 Mdot
.77133 .04195 Mdot
.77272 .04158 Mdot
.77336 .04141 Mdot
.77429 .04117 Mdot
.77607 .0407 Mdot
.77726 .04039 Mdot
.77868 .04003 Mdot
.7794 .03985 Mdot
.78093 .03946 Mdot
.78225 .03912 Mdot
.78349 .03881 Mdot
.78504 .03843 Mdot
.78546 .03832 Mdot
.78714 .03791 Mdot
.78917 .03741 Mdot
.79043 .03711 Mdot
.79327 .03643 Mdot
.79363 .03634 Mdot
.7943 .03618 Mdot
.79641 .03569 Mdot
.79765 .0354 Mdot
.79851 .0352 Mdot
.80025 .0348 Mdot
.80122 .03458 Mdot
.80162 .03449 Mdot
.80378 .03401 Mdot
.80475 .03379 Mdot
.80626 .03346 Mdot
.80804 .03306 Mdot
.80929 .03279 Mdot
.81035 .03256 Mdot
.8112 .03238 Mdot
.81314 .03197 Mdot
.81427 .03173 Mdot
.81672 .03122 Mdot
.81838 .03088 Mdot
.81962 .03062 Mdot
.82091 .03036 Mdot
.8222 .0301 Mdot
.82407 .02973 Mdot
.82553 .02945 Mdot
.8266 .02924 Mdot
.8276 .02904 Mdot
.83019 .02855 Mdot
.83152 .0283 Mdot
.83296 .02803 Mdot
.83414 .02781 Mdot
.83579 .02751 Mdot
.83775 .02715 Mdot
.83996 .02676 Mdot
.84121 .02654 Mdot
.84282 .02626 Mdot
.84519 .02585 Mdot
.8458 .02575 Mdot
.84804 .02537 Mdot
.84868 .02527 Mdot
.85056 .02496 Mdot
.85128 .02484 Mdot
.8528 .0246 Mdot
.85451 .02432 Mdot
.85558 .02415 Mdot
.8581 .02377 Mdot
.85898 .02363 Mdot
.85923 .02359 Mdot
.86169 .02322 Mdot
.86324 .02299 Mdot
.86451 .02281 Mdot
.86567 .02264 Mdot
.86776 .02235 Mdot
.8681 .0223 Mdot
.86986 .02205 Mdot
.87239 .02171 Mdot
.87266 .02167 Mdot
.87437 .02144 Mdot
.8761 .02122 Mdot
.87711 .02109 Mdot
.87843 .02092 Mdot
.88079 .02062 Mdot
.88164 .02052 Mdot
.88254 .02041 Mdot
.88498 .02011 Mdot
.88666 .01992 Mdot
.88865 .01969 Mdot
.88956 .01959 Mdot
.89139 .01938 Mdot
.89166 .01935 Mdot
.8929 .01922 Mdot
.89558 .01893 Mdot
.89599 .01889 Mdot
.89727 .01876 Mdot
.8999 .01849 Mdot
.90194 .01829 Mdot
.90273 .01822 Mdot
.90336 .01816 Mdot
.90512 .01799 Mdot
.90734 .01779 Mdot
.90809 .01772 Mdot
.91055 .01751 Mdot
.91192 .0174 Mdot
.9131 .0173 Mdot
.91441 .01719 Mdot
.91715 .01698 Mdot
.91836 .01689 Mdot
.92056 .01672 Mdot
.92081 .01671 Mdot
.92324 .01653 Mdot
.92453 .01645 Mdot
.92654 .01631 Mdot
.92685 .01629 Mdot
.92874 .01618 Mdot
.93012 .01609 Mdot
.93068 .01606 Mdot
.9325 .01595 Mdot
.93333 .01591 Mdot
.93378 .01588 Mdot
.93466 .01583 Mdot
.93668 .01573 Mdot
.93889 .01562 Mdot
.94051 .01554 Mdot
.94111 .01551 Mdot
.94271 .01544 Mdot
.94334 .01542 Mdot
.94495 .01535 Mdot
.94617 .0153 Mdot
.94733 .01526 Mdot
.94873 .0152 Mdot
.94975 .01517 Mdot
.95262 .01508 Mdot
.95327 .01506 Mdot
.95413 .01503 Mdot
.95481 .01501 Mdot
.95551 .01499 Mdot
.95806 .01493 Mdot
.96032 .01488 Mdot
.96166 .01485 Mdot
.96213 .01484 Mdot
.96428 .01481 Mdot
.96496 .0148 Mdot
.96702 .01477 Mdot
.96871 .01475 Mdot
.96963 .01474 Mdot
.97187 .01473 Mdot
.97335 .01472 Mdot
.97398 .01472 Mdot
.97514 .01472 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(700) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00658132) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.99953) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000@0n_3V0`0000040?[`iP<00000103jl>H3000000D0n_3V0`0000040?[`iP<0
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000060?[`iP8000001@3j
l>H2000000D0n_3V0P0000030?[`iP030000003jl>H0n_3V008000000P3jl>H00`000000n_3V0?[`
iP0200000?l0n_3VX`3jl>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P000003
0?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000
103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000006`3jl>H2000000`0n_3V0P00
00050?[`iP8000001@3jl>H2000000D0n_3V0P0000050?[`iP800000o`3jl>JS0?[`iP40oooo000P
0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP800000
00<0n_3V0000000000000`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000T0n_3V1@00000=0?[`iP8000002P3jl>H4000000<0n_3V100000030?[`iP@0
00001@3jl>H2000000D0n_3V0P00003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP800000
0`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H20000
00@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02
000001P0n_3V00<000000?[`iP3jl>H00P0000090?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0
n_3V008000000`3jl>H300000?l0n_3VY03jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3j
l>H0000000000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`
iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`
iP@000002P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H4000000H0n_3V0P00003o0?[`iZ<0n_3V0@3oool00200
n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000`0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000050?[`iP030000003jl>H0n_3V00800000o`3jl>JS0?[`iP40
oooo000O0?[`iPH00000103jl>H2000002l0n_3V1@00000W0?[`iPD000002P3jl>H3000000@0n_3V
0`0000040?[`iP<000000`3jl>H5000000<0n_3V0`00003o0?[`iZ@0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00?@3jl>H400000?l0
n_3Vo`3jl>HH0?[`iP40oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V0@3oool00200n_3V1P00
00001@3jl>H00000000000000000n_3V00<000000P3jl>H3000000<0n_3V100000030?[`iP800000
00@0n_3V000000000000n_3V1@0000030?[`iP`00000;`3jl>H3000000@0n_3V0P00003o0?[`i/T0
n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H200000080n_3V
00@000000?[`iP00000000000`3jl>H01@000000n_3V000000000000n_3V00<000000P3jl>H20000
00@0n_3V0P0000020?[`iP8000000`3jl>H200000280n_3V1@0000090?[`iP80000000<0n_3V0000
000000000`3jl>H200000?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H0
0000000000020?[`iP800000103jl>H2000000D0n_3V0P0000020?[`iP8000000P3jl>H2000000@0
n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H000000000003o0?[`i/h0
n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V
1P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000D0n_3V1@0000030?[`iP800000
8P3jl>H5000000T0n_3V0P0000000`3jl>H000000000003o0?[`i/h0n_3V0@3oool00280n_3V0P00
00040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P0000020?[`iP80000000@0
n_3V000000000000n_3V0`0000020?[`iP<0000000<0n_3V0000003jl>H0103jl>H2000000<0n_3V
0P00000`0?[`iP@00000o`3jl>K?0?[`iP40oooo000R0?[`iP8000000`3jl>H500000080n_3V1@00
00030?[`iP@000000`3jl>H2000000030?[`iP000000000000@0000000<0n_3V0000000000000P3j
l>H4000000@0n_3V0P00000`0?[`iP800000o`3jl>KA0?[`iP40oooo000R0?[`iP8000002`3jl>H2
00000280n_3V0P00000a0?[`iP800000o`3jl>K@0?[`iP40oooo000P0?[`iPH000002@3jl>H20000
0200n_3V1000000b0?[`iP<00000o`3jl>K>0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3j
l>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP04
0000003jl>H000000?[`iP8000000P3jl>H00`000000n_3V0?[`iP0300000?l0n_3Vo`3jl>HT0?[`
iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P0000001@3jl>H000000?[`iP000000n_3V
00<000000P3jl>H00`000000n_3V0000000I0?[`iP<00000g03jl>H4000000@0n_3V2`0000040?[`
iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V0`000000103j
l>H000000000000000080?[`iP@0000000<0n_3V0000000000000P3jl>H400000080n_3V1@000000
1`3jl>H00000000000000000n_3V0000003jl>H00`00000H0?[`iP<00000103jl>H2000000D0n_3V
0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<000000`3jl>H600000080n_3V
0`0000030?[`iPD00000JP3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000@0
n_3V00000000000000000P3jl>H2000000030?[`iP000000000000T0n_3V1@0000090?[`iP030000
003jl>H0n_3V00800000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V
0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080n_3V00@000000?[`iP3j
l>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`
iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`iP800000103jl>H20000
00030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`
iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3j
l>H00000000000040?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V0P00001]0?[`
iP40oooo000R0?[`iP<00000:`3jl>H200000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080
n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP00000000000000
003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP020000
01P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H20000
00030?[`iP000000000000@0n_3V0P0000060?[`iP8000000`3jl>H2000006`0n_3V0@3oool00280
n_3V0`00000J0?[`iPD00000303jl>H200000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0
n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP020000
0080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H50000
00X0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000050?[`iP8000000P3jl>H20000
00030?[`iP000000000000@0n_3V0P0000060?[`iP800000103jl>H2000006/0n_3V0@3oool00240
n_3V0P0000000`3jl>H000000000000X0?[`iP<00000g@3jl>H2000000030?[`iP000000000000D0
n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`iP800000103jl>H20000
00H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`
iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H3000000030?[`iP000000
n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V0000000000002@3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP@000000`3jl>H0
0`000000n_3V0?[`iP02000000<0n_3V0`0000050?[`iP800000103jl>H3000000H0n_3V0P00001Z
0?[`iP40oooo000P0?[`iP<0000000@0n_3V0000000000000000:@3jl>H200000=`0n_3V0P000000
0`3jl>H00000000000020?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3j
l>H4000000<0n_3V1@0000020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0
n_3V0000000000000P3jl>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P00
00000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000050?[`iP@000000`3jl>H2000000030?[`iP000000000000@0n_3V0P00
00060?[`iP8000000P3jl>H2000000030?[`iP000000000006X0n_3V0@3oool004d0n_3V00<00000
0?[`iP3jl>H00P00003L0?[`iP80000000<0n_3V000000000000403jl>H2000000`0n_3V0P00000R
0?[`iP8000000P3jl>H2000002h0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP8000001@3jl>H2
000000030?[`iP00000000000080n_3V100000030?[`iP030000003jl>H0n_3V008000000P3jl>H2
000000030?[`iP000000000006X0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H20000
00H0n_3V0P0000040?[`iP8000001P3jl>H2000001T0n_3V0`0000000`3jl>H00000000000020000
02h0n_3V0`00000;0?[`iP<00000103jl>H3000000D0n_3V0`0000020?[`iPD000000`3jl>H30000
00D0n_3V0P0000040?[`iP<00000103jl>H3000006/0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000
n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00D000000?[`
iP000000n_3V000000020?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H0o`3j
l>Ko0?[`iR80n_3V0@3oool00200n_3V0`0000000`3jl>H0000000000002000000040?[`iP000000
n_3V00000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP0G0?[`iP<00000
g03jl>H4000000@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH00000
0P3jl>H400000080n_3V0`0000000`3jl>H0000000000006000001`0n_3V0P0000040?[`iP<00000
103jl>H300000;X0n_3V0@3oool00240n_3V0P0000000`3jl>H0000000000005000000050?[`iP00
000000000000003jl>H01000000;0?[`iPD000002@3jl>H2000000030?[`iP00000000000=`0n_3V
0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000000P3jl>H010000000n_3V
0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`iP8000002`3jl>H5
000000/0n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
00000;T0n_3V0@3oool00280n_3V0`00000X0?[`iP80000000<0n_3V000000000000g03jl>H20000
00@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H20000
00H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000030?[`
iP@000006`3jl>H2000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
00000000^@3jl>H10?ooo`008P3jl>H3000000T0n_3V00<000000?[`iP3jl>H03P3jl>H5000000T0
n_3V0P0000000`3jl>H000000000003L0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP80
00001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80
000000@0n_3V000000000000n_3V1000000=0?[`iPD000002`3jl>H2000000<0n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V000000000000^@3jl>H10?ooo`008@3jl>H200000003
0?[`iP000000000002L0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V00000000
00001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P0000040?[`
iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP0000000000
0?[`iP8000000P3jl>H2000001`0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000;T0n_3V0@3oool00200n_3V0`000000103jl>H0000000000000000V
0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000080n_3V10000002
0?[`iP<0000000@0n_3V000000000000n_3V1@0000020?[`iP@000000`3jl>H500000080n_3V1000
00040?[`iP@000000P3jl>H5000000<0n_3V1@00000L0?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H000000000002i0?[`iP40oooo001=0?[`iP80000000<0n_3V
000000000000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`iP800000>03jl>H0
0`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
000000000000^@3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP8000001P3jl>H20000
00@0n_3V0P0000060?[`iP800000<03jl>H5000000<0n_3V0`0000040?[`iP<00000^P3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0n_3V8`3oon02
000004D0oooP0P0000040?ooh0800000103oon02000004@0oooP1@0000130?ooh0D000000P3oon02
000000@0oooP0P0000140?ooh0@00000A03oon04000000<0oooP0P0000040?ooh0800000A@3oon02
000002L0oooP7P3jl>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@00000
0?ooh03oon000000203oon0010000000oooP0?ooh00000150?ooh0030000003oon00oooP04D0oooP
00<000000?ooh03oon001`3oon0010000000oooP0?ooh00000130?ooh0030000003oon00oooP04D0
oooP00<000000?ooh03oon002@3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP
000002H0oooP7P3jl>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@00000
0?ooh03oon0000002`3oon000`000000oooP0?ooh0130?ooh0030000003oon00oooP04D0oooP00<0
00000?ooh03oon002P3oon000`000000oooP0?ooh0120?ooh0030000003oon00oooP04D0oooP00<0
00000?ooh03oon002`3oon000`000000oooP0?ooh0130?ooh0030000003oon00oooP02D0oooP7P3j
l>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon000000
2@3oon02000004H0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0800000
AP3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00P0oooP0P0000170?ooh0030000
003oon00oooP02@0oooP7P3jl>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP
00@000000?ooh03oon0000002@3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP04D0
oooP00<000000?ooh03oon00203oon000`000000oooP0?ooh0130?ooh0040000003oon00oooP0000
04@0oooP00@000000?ooh03oon0000002@3oon000`000000oooP0?ooh0130?ooh0040000003oon00
oooP000002H0oooP7P3jl>H10?ooo`007@3jl>HS0?ooh0800000A@3oon02000000X0oooP0`000014
0?ooh0800000AP3oon02000000X0oooP0`0000140?ooh0800000AP3oon02000000X0oooP0`000014
0?ooh08000009`3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0
n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo
000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H1
0?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0
n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh?l00000jP00
000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00
oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00
oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00BP3oon000`000000
oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000
oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh>H0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3o
on3V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPb03oon0C000000/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon00o`3oon2i0?ooh2<000002P3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon0300000?l0oooP[`3oon0B000001X0003o00<000000?ooh03o
on001P3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
Y`3oon0B000000P0003o6P00000;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP0?l0oooPX03oon0@000000T0003o4000000B0<f5?`/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2J
0?ooh0`000002P000?l:00000240cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh03o0?ooh9@0oooP2P0000080000o`/00000:P3=QCl;0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0
oooPS`3oon09000000H0003o2P00000c0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2:0?ooh0L000001`000?l9000003X0cHDo
2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh8D0oooP1`0000050000o`/00000?`3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPPP3oon06000000@0003o2P000015
0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00o`3oon1m0?ooh0L0000010000?l8000004/0cHDo2`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh7T0oooP1`0000040000o`L0
0000D03=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPM@3oon07000000@0003o1P00001E0<f5?`/0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1b0?ooh0H000001000
0?l7000005P0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh03o0?ooh6h0oooP1P0000040000o`H00000G@3=QCl;0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPJ`3oon050000
00@0003o1P00001Q0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00o`3oon1W0?ooh0D0000010000?l6000006D0cHDo2`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon0300000?l0oooPI03oon04000000@0003o
1`00001X0<f5?`T0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h03o0?ooh640oooP100000030000o`P00000J`3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPG`3oon03000000<0003o1`00001_
0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon00o`3oon1K0?ooh0@000000`000?l700000780cHDo2`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5P0oooP1@0000020000o`H0
0000MP3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP0?l0oooPE@3oon05000000<0003o1@00001i0<f5?`/0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1B0?ooh0D000000`00
0?l6000007/0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh03o0?ooh500oooP100000030000o`D00000O`3=QCl;0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPCP3oon030000
00<0003o1P0000210<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon00o`3oon1:0?ooh0D000000P000?l6000008@0cHDo2`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh4P0oooP
100000030000o`@00000R03=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP0?l0oooPA@3oon0500000080003o1@00002:0<f5?`/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon13
0?ooh0@000000`000?l4000008d0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon00o`3oon110?ooh0<000000`000?l50000
08l0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000
oooP0?ooh00000070?ooh0030000003oon00oooP0?l0oooP?P3oon0400000080003o1@00002B0<f5
?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03o
on0000001`3oon04000000P0oooPo`00000f000000<0003oV@0000080?ooh0@000006`3oon0N0?[`
iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?oo
h?l0<j7:<00cXLX400000080003o1@00002R0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon3o03>Q
bRh0<j7:100000020000o`D00000Y03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V3P3oon02000000P0oooP00<000000?ooh03oon002@3oon3o03>QbR/0<j7:1@0000020000o`@0
0000Y`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh?l0<j7::P0cXLX400000080003o1000002Y0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLXW03>QbP@000000`00
0?l300000:`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon3o03>QbR@0<j7:1@0000020000o`@00000[P3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:8`0cXLX40000
0080003o1000002`0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooPo`0cXLXP03>QbPD000000P000?l400000;80oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbQl0<j7:
100000020000o`<00000]@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh?l0<j7:700cXLX500000080003o0`00002g0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLXJ
03>QbPD000000P000?l300000;T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon3o03>QbQP0<j7:1@0000020000o`<00000^`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0
<j7:5P0cXLX500000080003o0`00002m0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLXD03>QbPD000000P000?l200000<00oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on3o03>QbQ80<j7:1@0000020000o`<00000`@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon03000000T0oooPo`0cXLXA03>QbP@000000P000?l200000<80oooP0`00000K
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:3P0cXLX50000
0080003o0P0000360?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooPo`0cXLX<03>QbPD000000P000?l300000<L0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbPX0<j7:
1@0000020000o`<00000b@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh?l0<j7:200cXLX500000080003o0`00003;0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLX7
03>QbP@000000P000?l300000<d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon3o03>QbPD0<j7:100000020000o`<00000c`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0
<j7:0`0cXLX400000080003o0P00003B0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLX203>QbP<000000P000?l300000=<0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on3o03>QbP<000000P000?l300000=D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon3m03>QbP<000000P000?l300000=L0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3k03>Q
bP<000000P000?l400000=P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon3i03>QbP<000000P000?l400000=X0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3g03>QbP@00000
00<0003o0000000000000P00003L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooPmP0cXLX300000080003o0`00003N0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPm@0cXLX2
00000080003o0`00003P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0<000002@3oon3b03>QbP<000000P000?l300000>00oooP0`00000K0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh?00<j7:1000000010000?l0000000000000003T0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooPk`0cXLX300000080003o0`00003U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPkP0cXLX200000080003o0`00003W0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPk00c
XLX3000000040000o`000000000000000>T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3Z03>QbP<000000P000?l200000>/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3Y
03>QbP8000000P000?l300000>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon3W03>QbP8000000P000?l400000>d0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3U03>QbP<0
000000<0003o0000000000000P00003_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPh`0cXLX300000080003o0`00003a0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPhP0c
XLX3000000030000o`000000000000800000lP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh>00<j7:0`0000020000o`<00000m03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h=l0<j7:0P0000020000o`<00000mP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh=d0<j7:0`0000000`000?l000000000000200000?L0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon3L03>QbP8000000P000?l300000?T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3J03>QbP<0000000@0003o0000000000000000
n`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooPf00c
XLX300000080003o0`00003j0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon3G03>QbP8000000P000?l300000?h0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3E03>QbP<0000000<0003o0000
000000000P00003o0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooPe00cXLX200000080003o0`00003o0?ooh080oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3C03>QbP800000
00<0003o0000000000000P00003o0?ooh0<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3A03>QbP8000000P000?l300000?l0oooP1@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh=00<j7:0P00000010000?l0000000000000003o0?ooh0L0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3>03>QbP<0000000@0003o
0000000000000000o`3oon080?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooPc00cXLX300000080003o0`00003o0?ooh0T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3;03>Q
bP<0000000@0003o0000000000000000o`3oon0;0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPbP0cXLX3000000040000o`0000000000
00000?l0oooP303oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh<T0<j7:0P0000020000o`800000o`3oon0>0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPa`0cXLX300000004
0000o`000000000000000?l0oooP3`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh<D0<j7:1000000010000?l0000000000000003o0?oo
h100oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP100000070?ooh003
0000003oon00oooP00T0oooPa00cXLX300000080003o0P00003o0?ooh180oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00<000000?ooh03oon00203oon000`000000oooP
0?ooh0090?ooh<<0<j7:0`00000010000?l0000000000000003o0?ooh1<0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<000000?ooh03oon001`3oon04000000P0oooP
`@0cXLX4000000030000o`00000000000?l0oooP4P3oon04000001/0oooP7P3jl>H10?ooo`007@3j
l>H?0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon3003>QbP<000000P00
0?l200000?l0oooP5P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon00
10000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP_`0cXLX3000000030000o`00
000000000?l0oooP603oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02
000000P0oooP00<000000?ooh03oon002@3oon2m03>QbP<000000P000?l200000?l0oooP6@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h;`0<j7:0`00000010000?l0000000000000003o0?ooh1X0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2j03>QbP@0000000@0003o0000
000000000000o`3oon0K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP^@0cXLX300000080003o0P00003o0?ooh1d0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2h03>QbP<0
000000@0003o0000000000000000o`3oon0N0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP]P0cXLX300000080003o0P00003o0?ooh200
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon2e03>QbP<0000000@0003o0000000000000000o`3oon0Q0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP/`0cXLX300000080003o
0`00003o0?ooh280oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon2b03>QbP<0000000@0003o0000000000000000o`3oon0T0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP/@0c
XLX3000000040000o`000000000000000?l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh;00<j7:0P0000020000o`<00000o`3o
on0V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP[`0cXLX2000000040000o`000000000000000?l0oooP:03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:d0<j7:0P000002
0000o`<00000o`3oon0Y0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0<000002@3oon2/03>QbP80000000@0003o0000000000000000o`3oon0Y0?ooh0<000006`3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2Z03>QbP<0000000@0003o0000
000000000000o`3oon0/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooPZ@0cXLX200000080003o0`00003o0?ooh2d0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2X03>QbP80
000000@0003o0000000000000000o`3oon0_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPY`0cXLX2000000040000o`00000000000000
0?l0oooP<03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh:D0<j7:0`00000010000?l0000000000000003o0?ooh340oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2T03>QbP80
00000P000?l300000?l0oooP<P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh:<0<j7:0P00000010000?l0000000000000003o0?ooh3@0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon2R03>QbP80000000@0003o0000000000000000o`3oon0e0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPX@0cXLX00`000000003o
0000o`0300000?l0oooP=P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh9l0<j7:0P0000000`000?l000000000000200000?l0oooP=`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh9h0<j7:0P00000010000?l0000000000000003o0?ooh3T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2M03>QbP80000000@0003o
0000000000000000o`3oon0j0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooPV`0cXLX200000080003o0`00003o0?ooh3/0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2J03>Q
bP80000000@0003o0000000000000000o`3oon0m0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPV@0cXLX2000000040000o`0000000000
00000?l0oooP?P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon030000
00T0oooPV00cXLX2000000040000o`000000000000000?l0oooP?@3oon03000001/0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPU`0cXLX2000000040000o`0000000000
00000?l0oooP@03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh9H0<j7:0P00000010000?l0000000000000003o0?ooh440oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2D03>Q
bP8000000P000?l200000?l0oooP@`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh9<0<j7:0P00000010000?l0000000000000003o0?oo
h4@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2B03>QbP80000000@0003o0000000000000000o`3oon150?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPT@0cXLX200000004
0000o`000000000000000?l0oooPAP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh900<j7:0P00000010000?l0000000000000003o0?oo
h4L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2>03>QbP<0000000@0003o0000000000000000o`3oon180?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPS@0cXLX300000003
0000o`00000000000?l0oooPBP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh8`0<j7:0`0000000`000?l000000000003o0?ooh4/0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on2;03>QbP<0000000<0003o000000000000o`3oon1<0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPRP0cXLX200000080003o0P00003o
0?ooh4d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon2903>QbP80000000@0003o0000000000000000o`3oon1>0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPQ`0cXLX30000
00040000o`000000000000000?l0oooPC`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh8H0<j7:0`00000010000?l0000000000000003o
0?ooh500oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?oo
h8H0<j7:0P00000010000?l0000000000000003o0?ooh4l0oooP0`00000K0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh8@0<j7:0`0000000`000?l000000000003o0?oo
h5<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2303>QbP<0000000<0003o000000000000o`3oon1D0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPPP0cXLX3000000030000
o`00000000000?l0oooPE@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh840<j7:0`0000000`000?l000000000003o0?ooh5H0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon20
03>QbP8000000P000?l200000?l0oooPE`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh7l0<j7:0P00000010000?l0000000000000003o
0?ooh5P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1m03>QbP<0000000<0003o000000000000o`3oon1J0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPO00cXLX300000003
0000o`00000000000?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh7/0<j7:0`0000000`000?l000000000003o0?ooh5`0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on1k03>QbP80000000<0003o000000000000o`3oon1M0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPN@0cXLX3000000030000o`000000
00000?l0oooPGP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh7P0<j7:0`0000000`000?l000000000003o0?ooh5l0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1g03>QbP<0
000000<0003o000000000000o`3oon1P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>H?0?ooh0<000001P3oon000`000000oooP0?ooh0090?ooh7H0<j7:0P0000020000o`800000
o`3oon1Q0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0030000003o
on00oooP00D0oooP00<000000?ooh03oon002@3oon1d03>QbP<0000000<0003o000000000000o`3o
on1S0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0D000001P3oon04
000000P0oooPL`0cXLX3000000030000o`00000000000?l0oooPH@3oon04000001/0oooP7P3jl>H1
0?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon1b
03>QbP<0000000<0003o000000000000o`3oon1U0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>H>0?ooh0030000003oon00000000L0oooP00<000000?ooh03oon002@3oon1a03>Q
bP<0000000<0003o000000000000o`3oon1V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H?0?ooh08000001`3oon000`000000oooP0?ooh0090?ooh740<j7:0P0000000`000?l0
00000000003o0?ooh6L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon1_03>QbP<0000000<0003o000000000000o`3oon1X0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPKP0c
XLX3000000030000o`00000000000?l0oooPJ@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh6d0<j7:0`0000000`000?l000000000003o
0?ooh6X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1/03>QbP<0000000<0003o000000000000o`3oon1[0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPJ`0cXLX300000003
0000o`00000000000?l0oooPK03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh6X0<j7:0`0000000`000?l000000000003o0?ooh6d0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on1Y03>QbP<0000000<0003o0000003oon00o`3oon1^0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPJ00cXLX200000080003o00<00000
0?ooh03oon00o`3oon1^0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooPI`0cXLX2000000030000o`00000000000?l0oooPL@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh6H0
<j7:0P0000000`000?l000000000003o0?ooh780oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1U03>QbP80000000<0003o000000000000
o`3oon1c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPI00cXLX2000000030000o`00000000000?l0oooPM03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooPH`0cXLX2000000030000o`000000
00000?l0oooPL`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooPHP0cXLX2000000030000o`00000000000?l0oooPMP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh640<j7:0P0000000`000?l0
00000000003o0?ooh7L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon1O03>QbP<0000000<0003o000000000000o`3oon1h0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPGP0c
XLX3000000030000o`00000000000?l0oooPN@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh5h0<j7:0P0000000`000?l000000000003o
0?ooh7X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1M03>QbP80000000<0003o000000000000o`3oon1k0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPG00cXLX200000003
0000o`00000000000?l0oooPO03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh5/0<j7:0P0000000`000?l000000000003o0?ooh7d0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on1J03>QbP80000000<0003o000000000000o`3oon1n0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPF@0cXLX2000000030000o`000000
00000?l0oooPO`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh5P0<j7:0P0000000`000?l000000000003o0?ooh800oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1G03>QbP80
000000<0003o000000000000o`3oon210?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPE@0cXLX3000000030000o`00000000000?l0oooP
PP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh5@0<j7:0`0000000`000?l000000000003o0?ooh8<0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1C03>QbP<0000000<0003o
000000000000o`3oon240?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0<000002@3oon1B03>QbP<0000000<0003o000000000000o`3oon230?ooh0<000006`3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1B03>QbP80000000<0003o00000000
0000o`3oon260?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooPD@0cXLX2000000030000o`00000000000?l0oooPQ`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh500<j7:0P00
00000`000?l000000000003o0?ooh8P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon1?03>QbP80000000<0003o000000000000o`3oon29
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooPCP0cXLX2000000030000o`00000000000?l0oooPRP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh4d0<j7:0P0000000`000?l0
00000000003o0?ooh8/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon1<03>QbP80000000<0003o000000000000o`3oon2<0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPB`0c
XLX2000000030000o`00000000000?l0oooPS@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh4X0<j7:0P0000000`000?l000000000003o
0?ooh8h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1903>QbP80000000<0003o000000000000o`3oon2?0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPB00cXLX200000003
0000o`00000000000?l0oooPT03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh4L0<j7:0P0000000`000?l000000000003o0?ooh940oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on1603>QbP80000000<0003o000000000000o`3oon2B0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPA@0cXLX2000000030000o`000000
00000?l0oooPT`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh4@0<j7:0P0000000`000?l000000000003o0?ooh9@0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh4<0<j7:0P0000000`000?l0
00000000003o0?ooh9<0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh480<j7:0P0000000`000?l000000000003o0?ooh9H0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1103>QbP80000000<0
003o000000000000o`3oon2G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP@00cXLX3000000030000o`00000000000?l0oooPU`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h3l0<j7:0`0000000`000?l000000000003o0?ooh9P0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0n03>QbP<0000000<0003o0000003o
on00o`3oon2I0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP?P0cXLX2000000030000o`000000oooP0?l0oooPVP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh3d0<j7:0P00
00000`000?l000000000003o0?ooh9/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon0l03>QbP80000000<0003o000000000000o`3oon2L
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP>`0cXLX2000000030000o`00000000000?l0oooPW@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh3X0<j7:0P0000000`000?l0
00000000003o0?ooh9h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon0i03>QbP80000000<0003o000000000000o`3oon2O0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP>00c
XLX2000000030000o`00000000000?l0oooPX03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh3L0<j7:0P0000000`000?l000000000003o
0?ooh:40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP0`0000080?oo
h0030000003oon00oooP00T0oooP=P0cXLX2000000030000o`00000000000?l0oooPXP3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?oo
h0030000003oon00oooP00T0oooP=@0cXLX2000000030000o`00000000000?l0oooPX`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?oo
h0@00000203oon0d03>QbP80000000<0003o000000000000o`3oon2Q0?ooh0@000006`3oon0N0?[`
iP40oooo000M0?[`iPd0oooP0`0000080?ooh0030000003oon00oooP00T0oooP<`0cXLX200000004
0000o`000000000000000?l0oooPY03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V3P3oon000`000000oooP0?ooh0070?ooh0030000003oon00oooP00T0oooP<P0cXLX300000003
0000o`00000000000?l0oooPY@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
3P3oon03000000L0oooP00<000000?ooh03oon002@3oon0b03>QbP80000000<0003o000000000000
o`3oon2V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP<@0cXLX2000000030000o`00000000000?l0oooPY`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh300<j7:0P000000
0`000?l000000000003o0?ooh:P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon0_03>QbP80000000<0003o000000000000o`3oon2Y0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP;P0cXLX2000000030000o`00000000000?l0oooPZP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh2d0<j7:0P0000000`000?l00000
0000003o0?ooh:/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon0/03>QbP80000000<0003o000000000000o`3oon2/0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP:`0cXLX2
000000030000o`00000000000?l0oooP[@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh2X0<j7:0P0000000`000?l000000000003o0?oo
h:h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon0Y03>QbP<0000000<0003o000000000000o`3oon2^0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP:@0cXLX2000000030000
o`00000000000?l0oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh2P0<j7:0P0000000`000?l000000000003o0?ooh;00oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0W
03>QbP80000000<0003o000000000000o`3oon2a0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0<000002@3oon0V03>QbP80000000<0003o000000000000o`3oon2`0?oo
h0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0U03>QbP80
000000<0003o000000000000o`3oon2c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP900cXLX2000000030000o`00000000000?l0oooP
]03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh2<0<j7:0P0000000`000?l000000000003o0?ooh;D0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0R03>QbP80000000<0003o
000000000000o`3oon2f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP8@0cXLX3000000030000o`00000000000?l0oooP]P3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh240
<j7:0P0000000`000?l000000000003o0?ooh;L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0P03>QbP80000000<0003o000000000000
o`3oon2h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP7`0cXLX2000000030000o`00000000000?l0oooP^@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh1h0<j7:0P000000
0`000?l000000000003o0?ooh;X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon0M03>QbP80000000<0003o000000000000o`3oon2k0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP700cXLX3000000030000o`000000oooP0?l0oooP^`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh1`0<j7:0P0000000`000?l00000
0?ooh03o0?ooh;`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon0K03>QbP80000000<0003o0000003oon00o`3oon2m0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP6P0cXLX2
000000030000o`00000000000?l0oooP_P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh1T0<j7:0P0000000`000?l000000000003o0?oo
h;l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh1P0
<j7:0P0000000`000?l000000000003o0?ooh;h0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh1L0<j7:0`0000000`000?l000000?ooh03o0?ooh<00oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on0F03>QbP<0000000<0003o0000003oon00o`3oon310?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP5@0cXLX3000000030000o`000000
00000?l0oooP`P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh1D0<j7:0P0000000`000?l000000000003o0?ooh<<0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0D03>QbP80
000000<0003o000000000000o`3oon340?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP4`0cXLX2000000030000o`00000000000?l0oooP
a@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh180<j7:0`0000000`000?l000000?ooh03o0?ooh<D0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0A03>QbP<0000000<0003o
0000003oon00o`3oon360?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP4@0cXLX2000000030000o`000000oooP0?l0oooPa`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0l0
<j7:0`0000000`000?l000000000003o0?ooh<P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0>03>QbP<0000000<0003o000000000000
o`3oon390?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP3P0cXLX2000000030000o`00000000000?l0oooPbP3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0d0<j7:0`000000
0`000?l000000?ooh03o0?ooh<X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon0<03>QbP<0000000<0003o0000003oon00o`3oon3;0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP2`0cXLX3000000030000o`000000oooP0?l0oooPc03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon03000000T0oooP2`0cXLX2000000030000o`00000000000?l0oooP
b`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP2P0c
XLX2000000030000o`00000000000?l0oooPcP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0T0<j7:0P0000000`000?l000000000003o
0?ooh<l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon0803>QbP80000000<0003o000000000000o`3oon3@0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP1`0cXLX200000003
0000o`00000000000?l0oooPd@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh0H0<j7:0`0000000`000?l000000000003o0?ooh=40oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on0503>QbP<0000000<0003o000000000000o`3oon3B0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP1@0cXLX2000000030000o`000000
oooP0?l0oooPd`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh0@0<j7:0P0000000`000?l000000000003o0?ooh=@0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0303>QbP80
000000<0003o000000000000o`3oon3E0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP0`0cXLX010000000003o00000000003o0?ooh=H0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon00100cXLX00000000000000?l300000?l0oooPeP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0<0000000<0003o000000000000
o`3oon3G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0800000203o
on000`000000oooP0?ooh0090?ooh080000000<0003o000000000000o`3oon3H0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<0
00000?ooh03oon002@3oon0010000000003o00000000003o0?ooh=T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon04000000L0oooP
00@000000000o`0000000000o`3oon3G0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPh0oooP
0P0000080?ooh0030000003oon00oooP00P0oooP1000003o0?ooh=X0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP
0?ooh0090?ooh0800000o`3oon3K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H>0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon00BP3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?oo
h03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<000000?oo
h03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000
003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh?l00000jP00000K0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3o
ool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00d@3jl>H400000080n_3V2000
00020?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V00000000
000010000000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V
00<00000203jl>H500000080n_3V100000020?[`iPD00000303jl>H300000140n_3V0`0000060?[`
iP<0000000@0n_3V00000000000000001P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V
0000000000000000f03jl>H10?ooo`00dP3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H2
000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H200000080n_3V
0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H010000000n_3V
0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V
008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V0P0000000`3j
l>H000000000000?0?[`iP80000000<0n_3V0000000000001P3jl>H2000000030?[`iP0000000000
00L0n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000=T0n_3V0@3oool00=80
n_3V0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H0
00000?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP000000000000d0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3j
l>H000000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`
iP80000000<0n_3V0000000000001@3jl>H5000000D0n_3V0P0000000`3jl>H00000000000070?[`
iP<000001P3jl>H5000000H0n_3V0`00003J0?[`iP40oooo003B0?[`iPD00000103jl>H2000000<0
n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`000003
0?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V0P00
00030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80000000<0n_3V0000000000003`3j
l>H2000000030?[`iP000000000000L0n_3V0`0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00
003J0?[`iP40oooo003B0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H2
000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`
iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`
iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP<0000000<0n_3V0000003jl>H02P3jl>H300000100n_3V100000070?[`iP80
000000<0n_3V0000000000001`3jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V00000000
0000f@3jl>H10?ooo`00dP3jl>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V
100000000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V
0P0000050?[`iP<0000000<0n_3V0000000000001`00000:0?[`iPD000000P3jl>H400000080n_3V
0`0000000`3jl>H000000000000:0?[`iP80000000<0n_3V0000000000003`3jl>H2000000P0n_3V
0`000000103jl>H0000000000000000=0?[`iP<0000000<0n_3V0000000000001@00003D0?[`iP40
oooo003B0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V01L0n_3V
0P00000J0?[`iP80000000<0n_3V000000000000403jl>H2000002<0n_3V00<000000?[`iP3jl>H0
e03jl>H10?ooo`00d@3jl>H6000000@0n_3V0P00000_0?[`iPD000006P3jl>H3000001T0n_3V0`00
000B0?[`iP<000008P3jl>H00`000000n_3V0?[`iP3C0?[`iP40oooo003o0?[`iX<0n_3V00<00000
0?[`iP3jl>H0dP3jl>H10?ooo`00o`3jl>J00?[`iP040000003jl>H0n_3V00000=@0n_3V0@3oool0
0?l0n_3VP@3jl>H200000=D0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .60328 L
.02526 .60328 L
.02526 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .60328 L
.02526 .60328 L
.02526 .08012 L
s
.678 .847 .902 r
.02526 .08012 m
.02526 .60047 L
.02668 .60047 L
.02668 .08012 L
F
.2 .63 .79 r
.02526 .08012 m
.02526 .60047 L
.02668 .60047 L
.02668 .08012 L
s
.678 .847 .902 r
.02668 .08012 m
.02668 .59893 L
.02782 .59893 L
.02782 .08012 L
F
.2 .63 .79 r
.02668 .08012 m
.02668 .59893 L
.02782 .59893 L
.02782 .08012 L
s
.678 .847 .902 r
.02782 .08012 m
.02782 .59812 L
.02883 .59812 L
.02883 .08012 L
F
.2 .63 .79 r
.02782 .08012 m
.02782 .59812 L
.02883 .59812 L
.02883 .08012 L
s
.678 .847 .902 r
.02883 .08012 m
.02883 .5963 L
.02962 .5963 L
.02962 .08012 L
F
.2 .63 .79 r
.02883 .08012 m
.02883 .5963 L
.02962 .5963 L
.02962 .08012 L
s
.678 .847 .902 r
.02962 .08012 m
.02962 .59514 L
.03087 .59514 L
.03087 .08012 L
F
.2 .63 .79 r
.02962 .08012 m
.02962 .59514 L
.03087 .59514 L
.03087 .08012 L
s
.678 .847 .902 r
.03087 .08012 m
.03087 .59355 L
.03203 .59355 L
.03203 .08012 L
F
.2 .63 .79 r
.03087 .08012 m
.03087 .59355 L
.03203 .59355 L
.03203 .08012 L
s
.678 .847 .902 r
.03203 .08012 m
.03203 .59204 L
.03329 .59204 L
.03329 .08012 L
F
.2 .63 .79 r
.03203 .08012 m
.03203 .59204 L
.03329 .59204 L
.03329 .08012 L
s
.678 .847 .902 r
.03329 .08012 m
.03329 .59081 L
.03445 .59081 L
.03445 .08012 L
F
.2 .63 .79 r
.03329 .08012 m
.03329 .59081 L
.03445 .59081 L
.03445 .08012 L
s
.678 .847 .902 r
.03445 .08012 m
.03445 .58929 L
.03536 .58929 L
.03536 .08012 L
F
.2 .63 .79 r
.03445 .08012 m
.03445 .58929 L
.03536 .58929 L
.03536 .08012 L
s
.678 .847 .902 r
.03536 .08012 m
.03536 .5882 L
.03651 .5882 L
.03651 .08012 L
F
.2 .63 .79 r
.03536 .08012 m
.03536 .5882 L
.03651 .5882 L
.03651 .08012 L
s
.678 .847 .902 r
.03651 .08012 m
.03651 .58689 L
.03722 .58689 L
.03722 .08012 L
F
.2 .63 .79 r
.03651 .08012 m
.03651 .58689 L
.03722 .58689 L
.03722 .08012 L
s
.678 .847 .902 r
.03722 .08012 m
.03722 .58538 L
.03866 .58538 L
.03866 .08012 L
F
.2 .63 .79 r
.03722 .08012 m
.03722 .58538 L
.03866 .58538 L
.03866 .08012 L
s
.678 .847 .902 r
.03866 .08012 m
.03866 .58509 L
.03996 .58509 L
.03996 .08012 L
F
.2 .63 .79 r
.03866 .08012 m
.03866 .58509 L
.03996 .58509 L
.03996 .08012 L
s
.678 .847 .902 r
.03996 .08012 m
.03996 .5823 L
.0411 .5823 L
.0411 .08012 L
F
.2 .63 .79 r
.03996 .08012 m
.03996 .5823 L
.0411 .5823 L
.0411 .08012 L
s
.678 .847 .902 r
.0411 .08012 m
.0411 .58167 L
.04214 .58167 L
.04214 .08012 L
F
.2 .63 .79 r
.0411 .08012 m
.0411 .58167 L
.04214 .58167 L
.04214 .08012 L
s
.678 .847 .902 r
.04214 .08012 m
.04214 .5803 L
.04352 .5803 L
.04352 .08012 L
F
.2 .63 .79 r
.04214 .08012 m
.04214 .5803 L
.04352 .5803 L
.04352 .08012 L
s
.678 .847 .902 r
.04352 .08012 m
.04352 .57842 L
.04424 .57842 L
.04424 .08012 L
F
.2 .63 .79 r
.04352 .08012 m
.04352 .57842 L
.04424 .57842 L
.04424 .08012 L
s
.678 .847 .902 r
.04424 .08012 m
.04424 .57726 L
.04553 .57726 L
.04553 .08012 L
F
.2 .63 .79 r
.04424 .08012 m
.04424 .57726 L
.04553 .57726 L
.04553 .08012 L
s
.678 .847 .902 r
.04553 .08012 m
.04553 .57609 L
.04622 .57609 L
.04622 .08012 L
F
.2 .63 .79 r
.04553 .08012 m
.04553 .57609 L
.04622 .57609 L
.04622 .08012 L
s
.678 .847 .902 r
.04622 .08012 m
.04622 .5752 L
.04702 .5752 L
.04702 .08012 L
F
.2 .63 .79 r
.04622 .08012 m
.04622 .5752 L
.04702 .5752 L
.04702 .08012 L
s
.678 .847 .902 r
.04702 .08012 m
.04702 .57408 L
.04784 .57408 L
.04784 .08012 L
F
.2 .63 .79 r
.04702 .08012 m
.04702 .57408 L
.04784 .57408 L
.04784 .08012 L
s
.678 .847 .902 r
.04784 .08012 m
.04784 .57364 L
.04853 .57364 L
.04853 .08012 L
F
.2 .63 .79 r
.04784 .08012 m
.04784 .57364 L
.04853 .57364 L
.04853 .08012 L
s
.678 .847 .902 r
.04853 .08012 m
.04853 .57167 L
.04981 .57167 L
.04981 .08012 L
F
.2 .63 .79 r
.04853 .08012 m
.04853 .57167 L
.04981 .57167 L
.04981 .08012 L
s
.678 .847 .902 r
.04981 .08012 m
.04981 .5709 L
.05061 .5709 L
.05061 .08012 L
F
.2 .63 .79 r
.04981 .08012 m
.04981 .5709 L
.05061 .5709 L
.05061 .08012 L
s
.678 .847 .902 r
.05061 .08012 m
.05061 .57035 L
.05147 .57035 L
.05147 .08012 L
F
.2 .63 .79 r
.05061 .08012 m
.05061 .57035 L
.05147 .57035 L
.05147 .08012 L
s
.678 .847 .902 r
.05147 .08012 m
.05147 .56863 L
.05247 .56863 L
.05247 .08012 L
F
.2 .63 .79 r
.05147 .08012 m
.05147 .56863 L
.05247 .56863 L
.05247 .08012 L
s
.678 .847 .902 r
.05247 .08012 m
.05247 .56777 L
.05318 .56777 L
.05318 .08012 L
F
.2 .63 .79 r
.05247 .08012 m
.05247 .56777 L
.05318 .56777 L
.05318 .08012 L
s
.678 .847 .902 r
.05318 .08012 m
.05318 .5671 L
.05362 .5671 L
.05362 .08012 L
F
.2 .63 .79 r
.05318 .08012 m
.05318 .5671 L
.05362 .5671 L
.05362 .08012 L
s
.678 .847 .902 r
.05362 .08012 m
.05362 .56623 L
.05469 .56623 L
.05469 .08012 L
F
.2 .63 .79 r
.05362 .08012 m
.05362 .56623 L
.05469 .56623 L
.05469 .08012 L
s
.678 .847 .902 r
.05469 .08012 m
.05469 .56565 L
.05599 .56565 L
.05599 .08012 L
F
.2 .63 .79 r
.05469 .08012 m
.05469 .56565 L
.05599 .56565 L
.05599 .08012 L
s
.678 .847 .902 r
.05599 .08012 m
.05599 .5642 L
.05689 .5642 L
.05689 .08012 L
F
.2 .63 .79 r
.05599 .08012 m
.05599 .5642 L
.05689 .5642 L
.05689 .08012 L
s
.678 .847 .902 r
.05689 .08012 m
.05689 .56288 L
.05764 .56288 L
.05764 .08012 L
F
.2 .63 .79 r
.05689 .08012 m
.05689 .56288 L
.05764 .56288 L
.05764 .08012 L
s
.678 .847 .902 r
.05764 .08012 m
.05764 .56169 L
.05823 .56169 L
.05823 .08012 L
F
.2 .63 .79 r
.05764 .08012 m
.05764 .56169 L
.05823 .56169 L
.05823 .08012 L
s
.678 .847 .902 r
.05823 .08012 m
.05823 .56125 L
.05882 .56125 L
.05882 .08012 L
F
.2 .63 .79 r
.05823 .08012 m
.05823 .56125 L
.05882 .56125 L
.05882 .08012 L
s
.678 .847 .902 r
.05882 .08012 m
.05882 .56081 L
.05945 .56081 L
.05945 .08012 L
F
.2 .63 .79 r
.05882 .08012 m
.05882 .56081 L
.05945 .56081 L
.05945 .08012 L
s
.678 .847 .902 r
.05945 .08012 m
.05945 .55969 L
.0602 .55969 L
.0602 .08012 L
F
.2 .63 .79 r
.05945 .08012 m
.05945 .55969 L
.0602 .55969 L
.0602 .08012 L
s
.678 .847 .902 r
.0602 .08012 m
.0602 .5585 L
.06096 .5585 L
.06096 .08012 L
F
.2 .63 .79 r
.0602 .08012 m
.0602 .5585 L
.06096 .5585 L
.06096 .08012 L
s
.678 .847 .902 r
.06096 .08012 m
.06096 .55773 L
.06186 .55773 L
.06186 .08012 L
F
.2 .63 .79 r
.06096 .08012 m
.06096 .55773 L
.06186 .55773 L
.06186 .08012 L
s
.678 .847 .902 r
.06186 .08012 m
.06186 .5564 L
.0629 .5564 L
.0629 .08012 L
F
.2 .63 .79 r
.06186 .08012 m
.06186 .5564 L
.0629 .5564 L
.0629 .08012 L
s
.678 .847 .902 r
.0629 .08012 m
.0629 .55589 L
.06374 .55589 L
.06374 .08012 L
F
.2 .63 .79 r
.0629 .08012 m
.0629 .55589 L
.06374 .55589 L
.06374 .08012 L
s
.678 .847 .902 r
.06374 .08012 m
.06374 .55452 L
.06421 .55452 L
.06421 .08012 L
F
.2 .63 .79 r
.06374 .08012 m
.06374 .55452 L
.06421 .55452 L
.06421 .08012 L
s
.678 .847 .902 r
.06421 .08012 m
.06421 .55339 L
.06527 .55339 L
.06527 .08012 L
F
.2 .63 .79 r
.06421 .08012 m
.06421 .55339 L
.06527 .55339 L
.06527 .08012 L
s
.678 .847 .902 r
.06527 .08012 m
.06527 .5524 L
.06606 .5524 L
.06606 .08012 L
F
.2 .63 .79 r
.06527 .08012 m
.06527 .5524 L
.06606 .5524 L
.06606 .08012 L
s
.678 .847 .902 r
.06606 .08012 m
.06606 .55206 L
.06654 .55206 L
.06654 .08012 L
F
.2 .63 .79 r
.06606 .08012 m
.06606 .55206 L
.06654 .55206 L
.06654 .08012 L
s
.678 .847 .902 r
.06654 .08012 m
.06654 .55043 L
.06764 .55043 L
.06764 .08012 L
F
.2 .63 .79 r
.06654 .08012 m
.06654 .55043 L
.06764 .55043 L
.06764 .08012 L
s
.678 .847 .902 r
.06764 .08012 m
.06764 .54999 L
.06846 .54999 L
.06846 .08012 L
F
.2 .63 .79 r
.06764 .08012 m
.06764 .54999 L
.06846 .54999 L
.06846 .08012 L
s
.678 .847 .902 r
.06846 .08012 m
.06846 .54843 L
.06942 .54843 L
.06942 .08012 L
F
.2 .63 .79 r
.06846 .08012 m
.06846 .54843 L
.06942 .54843 L
.06942 .08012 L
s
.678 .847 .902 r
.06942 .08012 m
.06942 .5475 L
.07055 .5475 L
.07055 .08012 L
F
.2 .63 .79 r
.06942 .08012 m
.06942 .5475 L
.07055 .5475 L
.07055 .08012 L
s
.678 .847 .902 r
.07055 .08012 m
.07055 .54643 L
.07124 .54643 L
.07124 .08012 L
F
.2 .63 .79 r
.07055 .08012 m
.07055 .54643 L
.07124 .54643 L
.07124 .08012 L
s
.678 .847 .902 r
.07124 .08012 m
.07124 .54529 L
.0725 .54529 L
.0725 .08012 L
F
.2 .63 .79 r
.07124 .08012 m
.07124 .54529 L
.0725 .54529 L
.0725 .08012 L
s
.678 .847 .902 r
.0725 .08012 m
.0725 .54458 L
.07319 .54458 L
.07319 .08012 L
F
.2 .63 .79 r
.0725 .08012 m
.0725 .54458 L
.07319 .54458 L
.07319 .08012 L
s
.678 .847 .902 r
.07319 .08012 m
.07319 .54293 L
.07432 .54293 L
.07432 .08012 L
F
.2 .63 .79 r
.07319 .08012 m
.07319 .54293 L
.07432 .54293 L
.07432 .08012 L
s
.678 .847 .902 r
.07432 .08012 m
.07432 .54251 L
.0754 .54251 L
.0754 .08012 L
F
.2 .63 .79 r
.07432 .08012 m
.07432 .54251 L
.0754 .54251 L
.0754 .08012 L
s
.678 .847 .902 r
.0754 .08012 m
.0754 .54044 L
.07682 .54044 L
.07682 .08012 L
F
.2 .63 .79 r
.0754 .08012 m
.0754 .54044 L
.07682 .54044 L
.07682 .08012 L
s
.678 .847 .902 r
.07682 .08012 m
.07682 .53948 L
.07806 .53948 L
.07806 .08012 L
F
.2 .63 .79 r
.07682 .08012 m
.07682 .53948 L
.07806 .53948 L
.07806 .08012 L
s
.678 .847 .902 r
.07806 .08012 m
.07806 .53778 L
.07888 .53778 L
.07888 .08012 L
F
.2 .63 .79 r
.07806 .08012 m
.07806 .53778 L
.07888 .53778 L
.07888 .08012 L
s
.678 .847 .902 r
.07888 .08012 m
.07888 .53695 L
.0798 .53695 L
.0798 .08012 L
F
.2 .63 .79 r
.07888 .08012 m
.07888 .53695 L
.0798 .53695 L
.0798 .08012 L
s
.678 .847 .902 r
.0798 .08012 m
.0798 .53601 L
.08107 .53601 L
.08107 .08012 L
F
.2 .63 .79 r
.0798 .08012 m
.0798 .53601 L
.08107 .53601 L
.08107 .08012 L
s
.678 .847 .902 r
.08107 .08012 m
.08107 .5346 L
.08212 .5346 L
.08212 .08012 L
F
.2 .63 .79 r
.08107 .08012 m
.08107 .5346 L
.08212 .5346 L
.08212 .08012 L
s
.678 .847 .902 r
.08212 .08012 m
.08212 .53288 L
.08263 .53288 L
.08263 .08012 L
F
.2 .63 .79 r
.08212 .08012 m
.08212 .53288 L
.08263 .53288 L
.08263 .08012 L
s
.678 .847 .902 r
.08263 .08012 m
.08263 .53254 L
.08322 .53254 L
.08322 .08012 L
F
.2 .63 .79 r
.08263 .08012 m
.08263 .53254 L
.08322 .53254 L
.08322 .08012 L
s
.678 .847 .902 r
.08322 .08012 m
.08322 .53164 L
.08403 .53164 L
.08403 .08012 L
F
.2 .63 .79 r
.08322 .08012 m
.08322 .53164 L
.08403 .53164 L
.08403 .08012 L
s
.678 .847 .902 r
.08403 .08012 m
.08403 .53103 L
.08448 .53103 L
.08448 .08012 L
F
.2 .63 .79 r
.08403 .08012 m
.08403 .53103 L
.08448 .53103 L
.08448 .08012 L
s
.678 .847 .902 r
.08448 .08012 m
.08448 .5296 L
.0856 .5296 L
.0856 .08012 L
F
.2 .63 .79 r
.08448 .08012 m
.08448 .5296 L
.0856 .5296 L
.0856 .08012 L
s
.678 .847 .902 r
.0856 .08012 m
.0856 .52903 L
.08616 .52903 L
.08616 .08012 L
F
.2 .63 .79 r
.0856 .08012 m
.0856 .52903 L
.08616 .52903 L
.08616 .08012 L
s
.678 .847 .902 r
.08616 .08012 m
.08616 .52775 L
.08737 .52775 L
.08737 .08012 L
F
.2 .63 .79 r
.08616 .08012 m
.08616 .52775 L
.08737 .52775 L
.08737 .08012 L
s
.678 .847 .902 r
.08737 .08012 m
.08737 .52669 L
.08848 .52669 L
.08848 .08012 L
F
.2 .63 .79 r
.08737 .08012 m
.08737 .52669 L
.08848 .52669 L
.08848 .08012 L
s
.678 .847 .902 r
.08848 .08012 m
.08848 .52544 L
.08956 .52544 L
.08956 .08012 L
F
.2 .63 .79 r
.08848 .08012 m
.08848 .52544 L
.08956 .52544 L
.08956 .08012 L
s
.678 .847 .902 r
.08956 .08012 m
.08956 .52418 L
.09047 .52418 L
.09047 .08012 L
F
.2 .63 .79 r
.08956 .08012 m
.08956 .52418 L
.09047 .52418 L
.09047 .08012 L
s
.678 .847 .902 r
.09047 .08012 m
.09047 .52349 L
.0913 .52349 L
.0913 .08012 L
F
.2 .63 .79 r
.09047 .08012 m
.09047 .52349 L
.0913 .52349 L
.0913 .08012 L
s
.678 .847 .902 r
.0913 .08012 m
.0913 .52241 L
.09189 .52241 L
.09189 .08012 L
F
.2 .63 .79 r
.0913 .08012 m
.0913 .52241 L
.09189 .52241 L
.09189 .08012 L
s
.678 .847 .902 r
.09189 .08012 m
.09189 .52068 L
.09329 .52068 L
.09329 .08012 L
F
.2 .63 .79 r
.09189 .08012 m
.09189 .52068 L
.09329 .52068 L
.09329 .08012 L
s
.678 .847 .902 r
.09329 .08012 m
.09329 .51982 L
.09396 .51982 L
.09396 .08012 L
F
.2 .63 .79 r
.09329 .08012 m
.09329 .51982 L
.09396 .51982 L
.09396 .08012 L
s
.678 .847 .902 r
.09396 .08012 m
.09396 .51894 L
.09497 .51894 L
.09497 .08012 L
F
.2 .63 .79 r
.09396 .08012 m
.09396 .51894 L
.09497 .51894 L
.09497 .08012 L
s
.678 .847 .902 r
.09497 .08012 m
.09497 .51779 L
.09633 .51779 L
.09633 .08012 L
F
.2 .63 .79 r
.09497 .08012 m
.09497 .51779 L
.09633 .51779 L
.09633 .08012 L
s
.678 .847 .902 r
.09633 .08012 m
.09633 .51691 L
.09704 .51691 L
.09704 .08012 L
F
.2 .63 .79 r
.09633 .08012 m
.09633 .51691 L
.09704 .51691 L
.09704 .08012 L
s
.678 .847 .902 r
.09704 .08012 m
.09704 .51514 L
.09809 .51514 L
.09809 .08012 L
F
.2 .63 .79 r
.09704 .08012 m
.09704 .51514 L
.09809 .51514 L
.09809 .08012 L
s
.678 .847 .902 r
.09809 .08012 m
.09809 .5148 L
.09914 .5148 L
.09914 .08012 L
F
.2 .63 .79 r
.09809 .08012 m
.09809 .5148 L
.09914 .5148 L
.09914 .08012 L
s
.678 .847 .902 r
.09914 .08012 m
.09914 .51361 L
.09968 .51361 L
.09968 .08012 L
F
.2 .63 .79 r
.09914 .08012 m
.09914 .51361 L
.09968 .51361 L
.09968 .08012 L
s
.678 .847 .902 r
.09968 .08012 m
.09968 .51201 L
.10103 .51201 L
.10103 .08012 L
F
.2 .63 .79 r
.09968 .08012 m
.09968 .51201 L
.10103 .51201 L
.10103 .08012 L
s
.678 .847 .902 r
.10103 .08012 m
.10103 .51128 L
.1016 .51128 L
.1016 .08012 L
F
.2 .63 .79 r
.10103 .08012 m
.10103 .51128 L
.1016 .51128 L
.1016 .08012 L
s
.678 .847 .902 r
.1016 .08012 m
.1016 .51089 L
.10283 .51089 L
.10283 .08012 L
F
.2 .63 .79 r
.1016 .08012 m
.1016 .51089 L
.10283 .51089 L
.10283 .08012 L
s
.678 .847 .902 r
.10283 .08012 m
.10283 .50926 L
.10379 .50926 L
.10379 .08012 L
F
.2 .63 .79 r
.10283 .08012 m
.10283 .50926 L
.10379 .50926 L
.10379 .08012 L
s
.678 .847 .902 r
.10379 .08012 m
.10379 .50737 L
.10507 .50737 L
.10507 .08012 L
F
.2 .63 .79 r
.10379 .08012 m
.10379 .50737 L
.10507 .50737 L
.10507 .08012 L
s
.678 .847 .902 r
.10507 .08012 m
.10507 .50676 L
.10649 .50676 L
.10649 .08012 L
F
.2 .63 .79 r
.10507 .08012 m
.10507 .50676 L
.10649 .50676 L
.10649 .08012 L
s
.678 .847 .902 r
.10649 .08012 m
.10649 .50499 L
.10736 .50499 L
.10736 .08012 L
F
.2 .63 .79 r
.10649 .08012 m
.10649 .50499 L
.10736 .50499 L
.10736 .08012 L
s
.678 .847 .902 r
.10736 .08012 m
.10736 .50456 L
.1083 .50456 L
.1083 .08012 L
F
.2 .63 .79 r
.10736 .08012 m
.10736 .50456 L
.1083 .50456 L
.1083 .08012 L
s
.678 .847 .902 r
.1083 .08012 m
.1083 .50285 L
.10889 .50285 L
.10889 .08012 L
F
.2 .63 .79 r
.1083 .08012 m
.1083 .50285 L
.10889 .50285 L
.10889 .08012 L
s
.678 .847 .902 r
.10889 .08012 m
.10889 .50189 L
.1102 .50189 L
.1102 .08012 L
F
.2 .63 .79 r
.10889 .08012 m
.10889 .50189 L
.1102 .50189 L
.1102 .08012 L
s
.678 .847 .902 r
.1102 .08012 m
.1102 .50033 L
.11131 .50033 L
.11131 .08012 L
F
.2 .63 .79 r
.1102 .08012 m
.1102 .50033 L
.11131 .50033 L
.11131 .08012 L
s
.678 .847 .902 r
.11131 .08012 m
.11131 .49944 L
.1126 .49944 L
.1126 .08012 L
F
.2 .63 .79 r
.11131 .08012 m
.11131 .49944 L
.1126 .49944 L
.1126 .08012 L
s
.678 .847 .902 r
.1126 .08012 m
.1126 .49817 L
.11357 .49817 L
.11357 .08012 L
F
.2 .63 .79 r
.1126 .08012 m
.1126 .49817 L
.11357 .49817 L
.11357 .08012 L
s
.678 .847 .902 r
.11357 .08012 m
.11357 .49759 L
.11439 .49759 L
.11439 .08012 L
F
.2 .63 .79 r
.11357 .08012 m
.11357 .49759 L
.11439 .49759 L
.11439 .08012 L
s
.678 .847 .902 r
.11439 .08012 m
.11439 .49626 L
.11512 .49626 L
.11512 .08012 L
F
.2 .63 .79 r
.11439 .08012 m
.11439 .49626 L
.11512 .49626 L
.11512 .08012 L
s
.678 .847 .902 r
.11512 .08012 m
.11512 .49483 L
.11626 .49483 L
.11626 .08012 L
F
.2 .63 .79 r
.11512 .08012 m
.11512 .49483 L
.11626 .49483 L
.11626 .08012 L
s
.678 .847 .902 r
.11626 .08012 m
.11626 .49398 L
.11728 .49398 L
.11728 .08012 L
F
.2 .63 .79 r
.11626 .08012 m
.11626 .49398 L
.11728 .49398 L
.11728 .08012 L
s
.678 .847 .902 r
.11728 .08012 m
.11728 .49343 L
.11788 .49343 L
.11788 .08012 L
F
.2 .63 .79 r
.11728 .08012 m
.11728 .49343 L
.11788 .49343 L
.11788 .08012 L
s
.678 .847 .902 r
.11788 .08012 m
.11788 .49179 L
.11904 .49179 L
.11904 .08012 L
F
.2 .63 .79 r
.11788 .08012 m
.11788 .49179 L
.11904 .49179 L
.11904 .08012 L
s
.678 .847 .902 r
.11904 .08012 m
.11904 .49112 L
.12028 .49112 L
.12028 .08012 L
F
.2 .63 .79 r
.11904 .08012 m
.11904 .49112 L
.12028 .49112 L
.12028 .08012 L
s
.678 .847 .902 r
.12028 .08012 m
.12028 .48986 L
.12102 .48986 L
.12102 .08012 L
F
.2 .63 .79 r
.12028 .08012 m
.12028 .48986 L
.12102 .48986 L
.12102 .08012 L
s
.678 .847 .902 r
.12102 .08012 m
.12102 .4892 L
.12203 .4892 L
.12203 .08012 L
F
.2 .63 .79 r
.12102 .08012 m
.12102 .4892 L
.12203 .4892 L
.12203 .08012 L
s
.678 .847 .902 r
.12203 .08012 m
.12203 .48785 L
.12258 .48785 L
.12258 .08012 L
F
.2 .63 .79 r
.12203 .08012 m
.12203 .48785 L
.12258 .48785 L
.12258 .08012 L
s
.678 .847 .902 r
.12258 .08012 m
.12258 .48654 L
.12371 .48654 L
.12371 .08012 L
F
.2 .63 .79 r
.12258 .08012 m
.12258 .48654 L
.12371 .48654 L
.12371 .08012 L
s
.678 .847 .902 r
.12371 .08012 m
.12371 .48584 L
.12457 .48584 L
.12457 .08012 L
F
.2 .63 .79 r
.12371 .08012 m
.12371 .48584 L
.12457 .48584 L
.12457 .08012 L
s
.678 .847 .902 r
.12457 .08012 m
.12457 .48501 L
.12545 .48501 L
.12545 .08012 L
F
.2 .63 .79 r
.12457 .08012 m
.12457 .48501 L
.12545 .48501 L
.12545 .08012 L
s
.678 .847 .902 r
.12545 .08012 m
.12545 .48407 L
.12621 .48407 L
.12621 .08012 L
F
.2 .63 .79 r
.12545 .08012 m
.12545 .48407 L
.12621 .48407 L
.12621 .08012 L
s
.678 .847 .902 r
.12621 .08012 m
.12621 .48326 L
.12683 .48326 L
.12683 .08012 L
F
.2 .63 .79 r
.12621 .08012 m
.12621 .48326 L
.12683 .48326 L
.12683 .08012 L
s
.678 .847 .902 r
.12683 .08012 m
.12683 .48214 L
.12786 .48214 L
.12786 .08012 L
F
.2 .63 .79 r
.12683 .08012 m
.12683 .48214 L
.12786 .48214 L
.12786 .08012 L
s
.678 .847 .902 r
.12786 .08012 m
.12786 .48161 L
.12877 .48161 L
.12877 .08012 L
F
.2 .63 .79 r
.12786 .08012 m
.12786 .48161 L
.12877 .48161 L
.12877 .08012 L
s
.678 .847 .902 r
.12877 .08012 m
.12877 .47952 L
.13013 .47952 L
.13013 .08012 L
F
.2 .63 .79 r
.12877 .08012 m
.12877 .47952 L
.13013 .47952 L
.13013 .08012 L
s
.678 .847 .902 r
.13013 .08012 m
.13013 .47874 L
.13126 .47874 L
.13126 .08012 L
F
.2 .63 .79 r
.13013 .08012 m
.13013 .47874 L
.13126 .47874 L
.13126 .08012 L
s
.678 .847 .902 r
.13126 .08012 m
.13126 .47739 L
.13213 .47739 L
.13213 .08012 L
F
.2 .63 .79 r
.13126 .08012 m
.13126 .47739 L
.13213 .47739 L
.13213 .08012 L
s
.678 .847 .902 r
.13213 .08012 m
.13213 .4765 L
.13319 .4765 L
.13319 .08012 L
F
.2 .63 .79 r
.13213 .08012 m
.13213 .4765 L
.13319 .4765 L
.13319 .08012 L
s
.678 .847 .902 r
.13319 .08012 m
.13319 .47515 L
.13388 .47515 L
.13388 .08012 L
F
.2 .63 .79 r
.13319 .08012 m
.13319 .47515 L
.13388 .47515 L
.13388 .08012 L
s
.678 .847 .902 r
.13388 .08012 m
.13388 .47383 L
.13517 .47383 L
.13517 .08012 L
F
.2 .63 .79 r
.13388 .08012 m
.13388 .47383 L
.13517 .47383 L
.13517 .08012 L
s
.678 .847 .902 r
.13517 .08012 m
.13517 .47348 L
.13654 .47348 L
.13654 .08012 L
F
.2 .63 .79 r
.13517 .08012 m
.13517 .47348 L
.13654 .47348 L
.13654 .08012 L
s
.678 .847 .902 r
.13654 .08012 m
.13654 .4719 L
.1372 .4719 L
.1372 .08012 L
F
.2 .63 .79 r
.13654 .08012 m
.13654 .4719 L
.1372 .4719 L
.1372 .08012 L
s
.678 .847 .902 r
.1372 .08012 m
.1372 .47079 L
.13862 .47079 L
.13862 .08012 L
F
.2 .63 .79 r
.1372 .08012 m
.1372 .47079 L
.13862 .47079 L
.13862 .08012 L
s
.678 .847 .902 r
.13862 .08012 m
.13862 .46989 L
.13922 .46989 L
.13922 .08012 L
F
.2 .63 .79 r
.13862 .08012 m
.13862 .46989 L
.13922 .46989 L
.13922 .08012 L
s
.678 .847 .902 r
.13922 .08012 m
.13922 .46879 L
.14 .46879 L
.14 .08012 L
F
.2 .63 .79 r
.13922 .08012 m
.13922 .46879 L
.14 .46879 L
.14 .08012 L
s
.678 .847 .902 r
.14 .08012 m
.14 .46823 L
.1405 .46823 L
.1405 .08012 L
F
.2 .63 .79 r
.14 .08012 m
.14 .46823 L
.1405 .46823 L
.1405 .08012 L
s
.678 .847 .902 r
.1405 .08012 m
.1405 .4674 L
.14119 .4674 L
.14119 .08012 L
F
.2 .63 .79 r
.1405 .08012 m
.1405 .4674 L
.14119 .4674 L
.14119 .08012 L
s
.678 .847 .902 r
.14119 .08012 m
.14119 .46643 L
.14201 .46643 L
.14201 .08012 L
F
.2 .63 .79 r
.14119 .08012 m
.14119 .46643 L
.14201 .46643 L
.14201 .08012 L
s
.678 .847 .902 r
.14201 .08012 m
.14201 .46613 L
.14248 .46613 L
.14248 .08012 L
F
.2 .63 .79 r
.14201 .08012 m
.14201 .46613 L
.14248 .46613 L
.14248 .08012 L
s
.678 .847 .902 r
.14248 .08012 m
.14248 .46543 L
.14343 .46543 L
.14343 .08012 L
F
.2 .63 .79 r
.14248 .08012 m
.14248 .46543 L
.14343 .46543 L
.14343 .08012 L
s
.678 .847 .902 r
.14343 .08012 m
.14343 .46464 L
.144 .46464 L
.144 .08012 L
F
.2 .63 .79 r
.14343 .08012 m
.14343 .46464 L
.144 .46464 L
.144 .08012 L
s
.678 .847 .902 r
.144 .08012 m
.144 .4641 L
.14515 .4641 L
.14515 .08012 L
F
.2 .63 .79 r
.144 .08012 m
.144 .4641 L
.14515 .4641 L
.14515 .08012 L
s
.678 .847 .902 r
.14515 .08012 m
.14515 .46195 L
.14622 .46195 L
.14622 .08012 L
F
.2 .63 .79 r
.14515 .08012 m
.14515 .46195 L
.14622 .46195 L
.14622 .08012 L
s
.678 .847 .902 r
.14622 .08012 m
.14622 .4612 L
.14673 .4612 L
.14673 .08012 L
F
.2 .63 .79 r
.14622 .08012 m
.14622 .4612 L
.14673 .4612 L
.14673 .08012 L
s
.678 .847 .902 r
.14673 .08012 m
.14673 .46012 L
.14799 .46012 L
.14799 .08012 L
F
.2 .63 .79 r
.14673 .08012 m
.14673 .46012 L
.14799 .46012 L
.14799 .08012 L
s
.678 .847 .902 r
.14799 .08012 m
.14799 .4592 L
.14896 .4592 L
.14896 .08012 L
F
.2 .63 .79 r
.14799 .08012 m
.14799 .4592 L
.14896 .4592 L
.14896 .08012 L
s
.678 .847 .902 r
.14896 .08012 m
.14896 .4587 L
.14943 .4587 L
.14943 .08012 L
F
.2 .63 .79 r
.14896 .08012 m
.14896 .4587 L
.14943 .4587 L
.14943 .08012 L
s
.678 .847 .902 r
.14943 .08012 m
.14943 .45731 L
.1505 .45731 L
.1505 .08012 L
F
.2 .63 .79 r
.14943 .08012 m
.14943 .45731 L
.1505 .45731 L
.1505 .08012 L
s
.678 .847 .902 r
.1505 .08012 m
.1505 .45573 L
.15185 .45573 L
.15185 .08012 L
F
.2 .63 .79 r
.1505 .08012 m
.1505 .45573 L
.15185 .45573 L
.15185 .08012 L
s
.678 .847 .902 r
.15185 .08012 m
.15185 .4554 L
.15315 .4554 L
.15315 .08012 L
F
.2 .63 .79 r
.15185 .08012 m
.15185 .4554 L
.15315 .4554 L
.15315 .08012 L
s
.678 .847 .902 r
.15315 .08012 m
.15315 .4537 L
.1542 .4537 L
.1542 .08012 L
F
.2 .63 .79 r
.15315 .08012 m
.15315 .4537 L
.1542 .4537 L
.1542 .08012 L
s
.678 .847 .902 r
.1542 .08012 m
.1542 .453 L
.15464 .453 L
.15464 .08012 L
F
.2 .63 .79 r
.1542 .08012 m
.1542 .453 L
.15464 .453 L
.15464 .08012 L
s
.678 .847 .902 r
.15464 .08012 m
.15464 .45153 L
.15575 .45153 L
.15575 .08012 L
F
.2 .63 .79 r
.15464 .08012 m
.15464 .45153 L
.15575 .45153 L
.15575 .08012 L
s
.678 .847 .902 r
.15575 .08012 m
.15575 .45108 L
.1572 .45108 L
.1572 .08012 L
F
.2 .63 .79 r
.15575 .08012 m
.15575 .45108 L
.1572 .45108 L
.1572 .08012 L
s
.678 .847 .902 r
.1572 .08012 m
.1572 .44952 L
.15835 .44952 L
.15835 .08012 L
F
.2 .63 .79 r
.1572 .08012 m
.1572 .44952 L
.15835 .44952 L
.15835 .08012 L
s
.678 .847 .902 r
.15835 .08012 m
.15835 .44754 L
.15958 .44754 L
.15958 .08012 L
F
.2 .63 .79 r
.15835 .08012 m
.15835 .44754 L
.15958 .44754 L
.15958 .08012 L
s
.678 .847 .902 r
.15958 .08012 m
.15958 .4468 L
.16073 .4468 L
.16073 .08012 L
F
.2 .63 .79 r
.15958 .08012 m
.15958 .4468 L
.16073 .4468 L
.16073 .08012 L
s
.678 .847 .902 r
.16073 .08012 m
.16073 .44599 L
.16202 .44599 L
.16202 .08012 L
F
.2 .63 .79 r
.16073 .08012 m
.16073 .44599 L
.16202 .44599 L
.16202 .08012 L
s
.678 .847 .902 r
.16202 .08012 m
.16202 .44423 L
.16282 .44423 L
.16282 .08012 L
F
.2 .63 .79 r
.16202 .08012 m
.16202 .44423 L
.16282 .44423 L
.16282 .08012 L
s
.678 .847 .902 r
.16282 .08012 m
.16282 .44339 L
.16399 .44339 L
.16399 .08012 L
F
.2 .63 .79 r
.16282 .08012 m
.16282 .44339 L
.16399 .44339 L
.16399 .08012 L
s
.678 .847 .902 r
.16399 .08012 m
.16399 .44199 L
.16489 .44199 L
.16489 .08012 L
F
.2 .63 .79 r
.16399 .08012 m
.16399 .44199 L
.16489 .44199 L
.16489 .08012 L
s
.678 .847 .902 r
.16489 .08012 m
.16489 .44151 L
.1658 .44151 L
.1658 .08012 L
F
.2 .63 .79 r
.16489 .08012 m
.16489 .44151 L
.1658 .44151 L
.1658 .08012 L
s
.678 .847 .902 r
.1658 .08012 m
.1658 .44052 L
.16657 .44052 L
.16657 .08012 L
F
.2 .63 .79 r
.1658 .08012 m
.1658 .44052 L
.16657 .44052 L
.16657 .08012 L
s
.678 .847 .902 r
.16657 .08012 m
.16657 .43996 L
.16722 .43996 L
.16722 .08012 L
F
.2 .63 .79 r
.16657 .08012 m
.16657 .43996 L
.16722 .43996 L
.16722 .08012 L
s
.678 .847 .902 r
.16722 .08012 m
.16722 .43886 L
.16798 .43886 L
.16798 .08012 L
F
.2 .63 .79 r
.16722 .08012 m
.16722 .43886 L
.16798 .43886 L
.16798 .08012 L
s
.678 .847 .902 r
.16798 .08012 m
.16798 .43818 L
.16921 .43818 L
.16921 .08012 L
F
.2 .63 .79 r
.16798 .08012 m
.16798 .43818 L
.16921 .43818 L
.16921 .08012 L
s
.678 .847 .902 r
.16921 .08012 m
.16921 .43654 L
.17035 .43654 L
.17035 .08012 L
F
.2 .63 .79 r
.16921 .08012 m
.16921 .43654 L
.17035 .43654 L
.17035 .08012 L
s
.678 .847 .902 r
.17035 .08012 m
.17035 .43599 L
.17093 .43599 L
.17093 .08012 L
F
.2 .63 .79 r
.17035 .08012 m
.17035 .43599 L
.17093 .43599 L
.17093 .08012 L
s
.678 .847 .902 r
.17093 .08012 m
.17093 .43461 L
.17189 .43461 L
.17189 .08012 L
F
.2 .63 .79 r
.17093 .08012 m
.17093 .43461 L
.17189 .43461 L
.17189 .08012 L
s
.678 .847 .902 r
.17189 .08012 m
.17189 .43399 L
.17259 .43399 L
.17259 .08012 L
F
.2 .63 .79 r
.17189 .08012 m
.17189 .43399 L
.17259 .43399 L
.17259 .08012 L
s
.678 .847 .902 r
.17259 .08012 m
.17259 .43324 L
.17369 .43324 L
.17369 .08012 L
F
.2 .63 .79 r
.17259 .08012 m
.17259 .43324 L
.17369 .43324 L
.17369 .08012 L
s
.678 .847 .902 r
.17369 .08012 m
.17369 .43227 L
.17466 .43227 L
.17466 .08012 L
F
.2 .63 .79 r
.17369 .08012 m
.17369 .43227 L
.17466 .43227 L
.17466 .08012 L
s
.678 .847 .902 r
.17466 .08012 m
.17466 .4306 L
.17572 .4306 L
.17572 .08012 L
F
.2 .63 .79 r
.17466 .08012 m
.17466 .4306 L
.17572 .4306 L
.17572 .08012 L
s
.678 .847 .902 r
.17572 .08012 m
.17572 .43006 L
.17658 .43006 L
.17658 .08012 L
F
.2 .63 .79 r
.17572 .08012 m
.17572 .43006 L
.17658 .43006 L
.17658 .08012 L
s
.678 .847 .902 r
.17658 .08012 m
.17658 .42916 L
.17707 .42916 L
.17707 .08012 L
F
.2 .63 .79 r
.17658 .08012 m
.17658 .42916 L
.17707 .42916 L
.17707 .08012 L
s
.678 .847 .902 r
.17707 .08012 m
.17707 .42815 L
.17803 .42815 L
.17803 .08012 L
F
.2 .63 .79 r
.17707 .08012 m
.17707 .42815 L
.17803 .42815 L
.17803 .08012 L
s
.678 .847 .902 r
.17803 .08012 m
.17803 .42676 L
.17944 .42676 L
.17944 .08012 L
F
.2 .63 .79 r
.17803 .08012 m
.17803 .42676 L
.17944 .42676 L
.17944 .08012 L
s
.678 .847 .902 r
.17944 .08012 m
.17944 .42646 L
.1803 .42646 L
.1803 .08012 L
F
.2 .63 .79 r
.17944 .08012 m
.17944 .42646 L
.1803 .42646 L
.1803 .08012 L
s
.678 .847 .902 r
.1803 .08012 m
.1803 .42532 L
.18111 .42532 L
.18111 .08012 L
F
.2 .63 .79 r
.1803 .08012 m
.1803 .42532 L
.18111 .42532 L
.18111 .08012 L
s
.678 .847 .902 r
.18111 .08012 m
.18111 .4249 L
.18229 .4249 L
.18229 .08012 L
F
.2 .63 .79 r
.18111 .08012 m
.18111 .4249 L
.18229 .4249 L
.18229 .08012 L
s
.678 .847 .902 r
.18229 .08012 m
.18229 .42344 L
.18299 .42344 L
.18299 .08012 L
F
.2 .63 .79 r
.18229 .08012 m
.18229 .42344 L
.18299 .42344 L
.18299 .08012 L
s
.678 .847 .902 r
.18299 .08012 m
.18299 .42296 L
.18401 .42296 L
.18401 .08012 L
F
.2 .63 .79 r
.18299 .08012 m
.18299 .42296 L
.18401 .42296 L
.18401 .08012 L
s
.678 .847 .902 r
.18401 .08012 m
.18401 .4216 L
.18445 .4216 L
.18445 .08012 L
F
.2 .63 .79 r
.18401 .08012 m
.18401 .4216 L
.18445 .4216 L
.18445 .08012 L
s
.678 .847 .902 r
.18445 .08012 m
.18445 .42126 L
.18491 .42126 L
.18491 .08012 L
F
.2 .63 .79 r
.18445 .08012 m
.18445 .42126 L
.18491 .42126 L
.18491 .08012 L
s
.678 .847 .902 r
.18491 .08012 m
.18491 .42033 L
.18616 .42033 L
.18616 .08012 L
F
.2 .63 .79 r
.18491 .08012 m
.18491 .42033 L
.18616 .42033 L
.18616 .08012 L
s
.678 .847 .902 r
.18616 .08012 m
.18616 .41935 L
.18671 .41935 L
.18671 .08012 L
F
.2 .63 .79 r
.18616 .08012 m
.18616 .41935 L
.18671 .41935 L
.18671 .08012 L
s
.678 .847 .902 r
.18671 .08012 m
.18671 .4188 L
.18784 .4188 L
.18784 .08012 L
F
.2 .63 .79 r
.18671 .08012 m
.18671 .4188 L
.18784 .4188 L
.18784 .08012 L
s
.678 .847 .902 r
.18784 .08012 m
.18784 .41759 L
.1891 .41759 L
.1891 .08012 L
F
.2 .63 .79 r
.18784 .08012 m
.18784 .41759 L
.1891 .41759 L
.1891 .08012 L
s
.678 .847 .902 r
.1891 .08012 m
.1891 .41592 L
.19003 .41592 L
.19003 .08012 L
F
.2 .63 .79 r
.1891 .08012 m
.1891 .41592 L
.19003 .41592 L
.19003 .08012 L
s
.678 .847 .902 r
.19003 .08012 m
.19003 .4155 L
.19081 .4155 L
.19081 .08012 L
F
.2 .63 .79 r
.19003 .08012 m
.19003 .4155 L
.19081 .4155 L
.19081 .08012 L
s
.678 .847 .902 r
.19081 .08012 m
.19081 .41399 L
.19225 .41399 L
.19225 .08012 L
F
.2 .63 .79 r
.19081 .08012 m
.19081 .41399 L
.19225 .41399 L
.19225 .08012 L
s
.678 .847 .902 r
.19225 .08012 m
.19225 .41338 L
.19337 .41338 L
.19337 .08012 L
F
.2 .63 .79 r
.19225 .08012 m
.19225 .41338 L
.19337 .41338 L
.19337 .08012 L
s
.678 .847 .902 r
.19337 .08012 m
.19337 .411 L
.1948 .411 L
.1948 .08012 L
F
.2 .63 .79 r
.19337 .08012 m
.19337 .411 L
.1948 .411 L
.1948 .08012 L
s
.678 .847 .902 r
.1948 .08012 m
.1948 .4106 L
.19532 .4106 L
.19532 .08012 L
F
.2 .63 .79 r
.1948 .08012 m
.1948 .4106 L
.19532 .4106 L
.19532 .08012 L
s
.678 .847 .902 r
.19532 .08012 m
.19532 .41024 L
.19609 .41024 L
.19609 .08012 L
F
.2 .63 .79 r
.19532 .08012 m
.19532 .41024 L
.19609 .41024 L
.19609 .08012 L
s
.678 .847 .902 r
.19609 .08012 m
.19609 .40917 L
.19668 .40917 L
.19668 .08012 L
F
.2 .63 .79 r
.19609 .08012 m
.19609 .40917 L
.19668 .40917 L
.19668 .08012 L
s
.678 .847 .902 r
.19668 .08012 m
.19668 .40901 L
.19748 .40901 L
.19748 .08012 L
F
.2 .63 .79 r
.19668 .08012 m
.19668 .40901 L
.19748 .40901 L
.19748 .08012 L
s
.678 .847 .902 r
.19748 .08012 m
.19748 .40808 L
.1986 .40808 L
.1986 .08012 L
F
.2 .63 .79 r
.19748 .08012 m
.19748 .40808 L
.1986 .40808 L
.1986 .08012 L
s
.678 .847 .902 r
.1986 .08012 m
.1986 .40689 L
.19931 .40689 L
.19931 .08012 L
F
.2 .63 .79 r
.1986 .08012 m
.1986 .40689 L
.19931 .40689 L
.19931 .08012 L
s
.678 .847 .902 r
.19931 .08012 m
.19931 .4055 L
.2004 .4055 L
.2004 .08012 L
F
.2 .63 .79 r
.19931 .08012 m
.19931 .4055 L
.2004 .4055 L
.2004 .08012 L
s
.678 .847 .902 r
.2004 .08012 m
.2004 .4052 L
.20125 .4052 L
.20125 .08012 L
F
.2 .63 .79 r
.2004 .08012 m
.2004 .4052 L
.20125 .4052 L
.20125 .08012 L
s
.678 .847 .902 r
.20125 .08012 m
.20125 .4038 L
.20194 .4038 L
.20194 .08012 L
F
.2 .63 .79 r
.20125 .08012 m
.20125 .4038 L
.20194 .4038 L
.20194 .08012 L
s
.678 .847 .902 r
.20194 .08012 m
.20194 .40272 L
.20331 .40272 L
.20331 .08012 L
F
.2 .63 .79 r
.20194 .08012 m
.20194 .40272 L
.20331 .40272 L
.20331 .08012 L
s
.678 .847 .902 r
.20331 .08012 m
.20331 .40132 L
.20467 .40132 L
.20467 .08012 L
F
.2 .63 .79 r
.20331 .08012 m
.20331 .40132 L
.20467 .40132 L
.20467 .08012 L
s
.678 .847 .902 r
.20467 .08012 m
.20467 .40058 L
.20526 .40058 L
.20526 .08012 L
F
.2 .63 .79 r
.20467 .08012 m
.20467 .40058 L
.20526 .40058 L
.20526 .08012 L
s
.678 .847 .902 r
.20526 .08012 m
.20526 .39946 L
.20638 .39946 L
.20638 .08012 L
F
.2 .63 .79 r
.20526 .08012 m
.20526 .39946 L
.20638 .39946 L
.20638 .08012 L
s
.678 .847 .902 r
.20638 .08012 m
.20638 .39799 L
.20774 .39799 L
.20774 .08012 L
F
.2 .63 .79 r
.20638 .08012 m
.20638 .39799 L
.20774 .39799 L
.20774 .08012 L
s
.678 .847 .902 r
.20774 .08012 m
.20774 .3976 L
.20908 .3976 L
.20908 .08012 L
F
.2 .63 .79 r
.20774 .08012 m
.20774 .3976 L
.20908 .3976 L
.20908 .08012 L
s
.678 .847 .902 r
.20908 .08012 m
.20908 .39646 L
.20988 .39646 L
.20988 .08012 L
F
.2 .63 .79 r
.20908 .08012 m
.20908 .39646 L
.20988 .39646 L
.20988 .08012 L
s
.678 .847 .902 r
.20988 .08012 m
.20988 .39564 L
.21088 .39564 L
.21088 .08012 L
F
.2 .63 .79 r
.20988 .08012 m
.20988 .39564 L
.21088 .39564 L
.21088 .08012 L
s
.678 .847 .902 r
.21088 .08012 m
.21088 .39438 L
.21156 .39438 L
.21156 .08012 L
F
.2 .63 .79 r
.21088 .08012 m
.21088 .39438 L
.21156 .39438 L
.21156 .08012 L
s
.678 .847 .902 r
.21156 .08012 m
.21156 .39367 L
.21207 .39367 L
.21207 .08012 L
F
.2 .63 .79 r
.21156 .08012 m
.21156 .39367 L
.21207 .39367 L
.21207 .08012 L
s
.678 .847 .902 r
.21207 .08012 m
.21207 .39323 L
.2134 .39323 L
.2134 .08012 L
F
.2 .63 .79 r
.21207 .08012 m
.21207 .39323 L
.2134 .39323 L
.2134 .08012 L
s
.678 .847 .902 r
.2134 .08012 m
.2134 .39179 L
.21405 .39179 L
.21405 .08012 L
F
.2 .63 .79 r
.2134 .08012 m
.2134 .39179 L
.21405 .39179 L
.21405 .08012 L
s
.678 .847 .902 r
.21405 .08012 m
.21405 .39101 L
.21475 .39101 L
.21475 .08012 L
F
.2 .63 .79 r
.21405 .08012 m
.21405 .39101 L
.21475 .39101 L
.21475 .08012 L
s
.678 .847 .902 r
.21475 .08012 m
.21475 .39032 L
.21559 .39032 L
.21559 .08012 L
F
.2 .63 .79 r
.21475 .08012 m
.21475 .39032 L
.21559 .39032 L
.21559 .08012 L
s
.678 .847 .902 r
.21559 .08012 m
.21559 .38968 L
.21695 .38968 L
.21695 .08012 L
F
.2 .63 .79 r
.21559 .08012 m
.21559 .38968 L
.21695 .38968 L
.21695 .08012 L
s
.678 .847 .902 r
.21695 .08012 m
.21695 .38871 L
.21752 .38871 L
.21752 .08012 L
F
.2 .63 .79 r
.21695 .08012 m
.21695 .38871 L
.21752 .38871 L
.21752 .08012 L
s
.678 .847 .902 r
.21752 .08012 m
.21752 .38725 L
.2189 .38725 L
.2189 .08012 L
F
.2 .63 .79 r
.21752 .08012 m
.21752 .38725 L
.2189 .38725 L
.2189 .08012 L
s
.678 .847 .902 r
.2189 .08012 m
.2189 .38686 L
.2196 .38686 L
.2196 .08012 L
F
.2 .63 .79 r
.2189 .08012 m
.2189 .38686 L
.2196 .38686 L
.2196 .08012 L
s
.678 .847 .902 r
.2196 .08012 m
.2196 .38588 L
.22059 .38588 L
.22059 .08012 L
F
.2 .63 .79 r
.2196 .08012 m
.2196 .38588 L
.22059 .38588 L
.22059 .08012 L
s
.678 .847 .902 r
.22059 .08012 m
.22059 .38519 L
.2215 .38519 L
.2215 .08012 L
F
.2 .63 .79 r
.22059 .08012 m
.22059 .38519 L
.2215 .38519 L
.2215 .08012 L
s
.678 .847 .902 r
.2215 .08012 m
.2215 .38385 L
.2226 .38385 L
.2226 .08012 L
F
.2 .63 .79 r
.2215 .08012 m
.2215 .38385 L
.2226 .38385 L
.2226 .08012 L
s
.678 .847 .902 r
.2226 .08012 m
.2226 .38302 L
.22367 .38302 L
.22367 .08012 L
F
.2 .63 .79 r
.2226 .08012 m
.2226 .38302 L
.22367 .38302 L
.22367 .08012 L
s
.678 .847 .902 r
.22367 .08012 m
.22367 .38208 L
.22424 .38208 L
.22424 .08012 L
F
.2 .63 .79 r
.22367 .08012 m
.22367 .38208 L
.22424 .38208 L
.22424 .08012 L
s
.678 .847 .902 r
.22424 .08012 m
.22424 .38155 L
.2249 .38155 L
.2249 .08012 L
F
.2 .63 .79 r
.22424 .08012 m
.22424 .38155 L
.2249 .38155 L
.2249 .08012 L
s
.678 .847 .902 r
.2249 .08012 m
.2249 .38018 L
.22609 .38018 L
.22609 .08012 L
F
.2 .63 .79 r
.2249 .08012 m
.2249 .38018 L
.22609 .38018 L
.22609 .08012 L
s
.678 .847 .902 r
.22609 .08012 m
.22609 .37932 L
.22726 .37932 L
.22726 .08012 L
F
.2 .63 .79 r
.22609 .08012 m
.22609 .37932 L
.22726 .37932 L
.22726 .08012 L
s
.678 .847 .902 r
.22726 .08012 m
.22726 .37797 L
.2287 .37797 L
.2287 .08012 L
F
.2 .63 .79 r
.22726 .08012 m
.22726 .37797 L
.2287 .37797 L
.2287 .08012 L
s
.678 .847 .902 r
.2287 .08012 m
.2287 .37703 L
.2297 .37703 L
.2297 .08012 L
F
.2 .63 .79 r
.2287 .08012 m
.2287 .37703 L
.2297 .37703 L
.2297 .08012 L
s
.678 .847 .902 r
.2297 .08012 m
.2297 .3754 L
.23097 .3754 L
.23097 .08012 L
F
.2 .63 .79 r
.2297 .08012 m
.2297 .3754 L
.23097 .3754 L
.23097 .08012 L
s
.678 .847 .902 r
.23097 .08012 m
.23097 .37484 L
.23225 .37484 L
.23225 .08012 L
F
.2 .63 .79 r
.23097 .08012 m
.23097 .37484 L
.23225 .37484 L
.23225 .08012 L
s
.678 .847 .902 r
.23225 .08012 m
.23225 .37347 L
.23334 .37347 L
.23334 .08012 L
F
.2 .63 .79 r
.23225 .08012 m
.23225 .37347 L
.23334 .37347 L
.23334 .08012 L
s
.678 .847 .902 r
.23334 .08012 m
.23334 .37263 L
.23479 .37263 L
.23479 .08012 L
F
.2 .63 .79 r
.23334 .08012 m
.23334 .37263 L
.23479 .37263 L
.23479 .08012 L
s
.678 .847 .902 r
.23479 .08012 m
.23479 .37128 L
.23583 .37128 L
.23583 .08012 L
F
.2 .63 .79 r
.23479 .08012 m
.23479 .37128 L
.23583 .37128 L
.23583 .08012 L
s
.678 .847 .902 r
.23583 .08012 m
.23583 .37006 L
.23703 .37006 L
.23703 .08012 L
F
.2 .63 .79 r
.23583 .08012 m
.23583 .37006 L
.23703 .37006 L
.23703 .08012 L
s
.678 .847 .902 r
.23703 .08012 m
.23703 .36917 L
.23824 .36917 L
.23824 .08012 L
F
.2 .63 .79 r
.23703 .08012 m
.23703 .36917 L
.23824 .36917 L
.23824 .08012 L
s
.678 .847 .902 r
.23824 .08012 m
.23824 .36769 L
.23948 .36769 L
.23948 .08012 L
F
.2 .63 .79 r
.23824 .08012 m
.23824 .36769 L
.23948 .36769 L
.23948 .08012 L
s
.678 .847 .902 r
.23948 .08012 m
.23948 .36677 L
.24026 .36677 L
.24026 .08012 L
F
.2 .63 .79 r
.23948 .08012 m
.23948 .36677 L
.24026 .36677 L
.24026 .08012 L
s
.678 .847 .902 r
.24026 .08012 m
.24026 .36577 L
.24105 .36577 L
.24105 .08012 L
F
.2 .63 .79 r
.24026 .08012 m
.24026 .36577 L
.24105 .36577 L
.24105 .08012 L
s
.678 .847 .902 r
.24105 .08012 m
.24105 .36449 L
.24236 .36449 L
.24236 .08012 L
F
.2 .63 .79 r
.24105 .08012 m
.24105 .36449 L
.24236 .36449 L
.24236 .08012 L
s
.678 .847 .902 r
.24236 .08012 m
.24236 .36396 L
.24346 .36396 L
.24346 .08012 L
F
.2 .63 .79 r
.24236 .08012 m
.24236 .36396 L
.24346 .36396 L
.24346 .08012 L
s
.678 .847 .902 r
.24346 .08012 m
.24346 .36273 L
.24432 .36273 L
.24432 .08012 L
F
.2 .63 .79 r
.24346 .08012 m
.24346 .36273 L
.24432 .36273 L
.24432 .08012 L
s
.678 .847 .902 r
.24432 .08012 m
.24432 .36204 L
.24486 .36204 L
.24486 .08012 L
F
.2 .63 .79 r
.24432 .08012 m
.24432 .36204 L
.24486 .36204 L
.24486 .08012 L
s
.678 .847 .902 r
.24486 .08012 m
.24486 .36149 L
.24561 .36149 L
.24561 .08012 L
F
.2 .63 .79 r
.24486 .08012 m
.24486 .36149 L
.24561 .36149 L
.24561 .08012 L
s
.678 .847 .902 r
.24561 .08012 m
.24561 .36098 L
.24624 .36098 L
.24624 .08012 L
F
.2 .63 .79 r
.24561 .08012 m
.24561 .36098 L
.24624 .36098 L
.24624 .08012 L
s
.678 .847 .902 r
.24624 .08012 m
.24624 .36044 L
.24744 .36044 L
.24744 .08012 L
F
.2 .63 .79 r
.24624 .08012 m
.24624 .36044 L
.24744 .36044 L
.24744 .08012 L
s
.678 .847 .902 r
.24744 .08012 m
.24744 .35906 L
.24837 .35906 L
.24837 .08012 L
F
.2 .63 .79 r
.24744 .08012 m
.24744 .35906 L
.24837 .35906 L
.24837 .08012 L
s
.678 .847 .902 r
.24837 .08012 m
.24837 .35835 L
.24899 .35835 L
.24899 .08012 L
F
.2 .63 .79 r
.24837 .08012 m
.24837 .35835 L
.24899 .35835 L
.24899 .08012 L
s
.678 .847 .902 r
.24899 .08012 m
.24899 .35783 L
.25041 .35783 L
.25041 .08012 L
F
.2 .63 .79 r
.24899 .08012 m
.24899 .35783 L
.25041 .35783 L
.25041 .08012 L
s
.678 .847 .902 r
.25041 .08012 m
.25041 .3564 L
.25087 .3564 L
.25087 .08012 L
F
.2 .63 .79 r
.25041 .08012 m
.25041 .3564 L
.25087 .3564 L
.25087 .08012 L
s
.678 .847 .902 r
.25087 .08012 m
.25087 .35511 L
.25209 .35511 L
.25209 .08012 L
F
.2 .63 .79 r
.25087 .08012 m
.25087 .35511 L
.25209 .35511 L
.25209 .08012 L
s
.678 .847 .902 r
.25209 .08012 m
.25209 .35456 L
.25272 .35456 L
.25272 .08012 L
F
.2 .63 .79 r
.25209 .08012 m
.25209 .35456 L
.25272 .35456 L
.25272 .08012 L
s
.678 .847 .902 r
.25272 .08012 m
.25272 .35377 L
.25358 .35377 L
.25358 .08012 L
F
.2 .63 .79 r
.25272 .08012 m
.25272 .35377 L
.25358 .35377 L
.25358 .08012 L
s
.678 .847 .902 r
.25358 .08012 m
.25358 .35322 L
.25422 .35322 L
.25422 .08012 L
F
.2 .63 .79 r
.25358 .08012 m
.25358 .35322 L
.25422 .35322 L
.25422 .08012 L
s
.678 .847 .902 r
.25422 .08012 m
.25422 .35211 L
.25562 .35211 L
.25562 .08012 L
F
.2 .63 .79 r
.25422 .08012 m
.25422 .35211 L
.25562 .35211 L
.25562 .08012 L
s
.678 .847 .902 r
.25562 .08012 m
.25562 .35137 L
.25662 .35137 L
.25662 .08012 L
F
.2 .63 .79 r
.25562 .08012 m
.25562 .35137 L
.25662 .35137 L
.25662 .08012 L
s
.678 .847 .902 r
.25662 .08012 m
.25662 .35023 L
.25748 .35023 L
.25748 .08012 L
F
.2 .63 .79 r
.25662 .08012 m
.25662 .35023 L
.25748 .35023 L
.25748 .08012 L
s
.678 .847 .902 r
.25748 .08012 m
.25748 .34948 L
.25854 .34948 L
.25854 .08012 L
F
.2 .63 .79 r
.25748 .08012 m
.25748 .34948 L
.25854 .34948 L
.25854 .08012 L
s
.678 .847 .902 r
.25854 .08012 m
.25854 .34873 L
.25917 .34873 L
.25917 .08012 L
F
.2 .63 .79 r
.25854 .08012 m
.25854 .34873 L
.25917 .34873 L
.25917 .08012 L
s
.678 .847 .902 r
.25917 .08012 m
.25917 .34809 L
.26042 .34809 L
.26042 .08012 L
F
.2 .63 .79 r
.25917 .08012 m
.25917 .34809 L
.26042 .34809 L
.26042 .08012 L
s
.678 .847 .902 r
.26042 .08012 m
.26042 .34692 L
.2615 .34692 L
.2615 .08012 L
F
.2 .63 .79 r
.26042 .08012 m
.26042 .34692 L
.2615 .34692 L
.2615 .08012 L
s
.678 .847 .902 r
.2615 .08012 m
.2615 .34602 L
.26221 .34602 L
.26221 .08012 L
F
.2 .63 .79 r
.2615 .08012 m
.2615 .34602 L
.26221 .34602 L
.26221 .08012 L
s
.678 .847 .902 r
.26221 .08012 m
.26221 .34456 L
.26351 .34456 L
.26351 .08012 L
F
.2 .63 .79 r
.26221 .08012 m
.26221 .34456 L
.26351 .34456 L
.26351 .08012 L
s
.678 .847 .902 r
.26351 .08012 m
.26351 .34371 L
.2649 .34371 L
.2649 .08012 L
F
.2 .63 .79 r
.26351 .08012 m
.26351 .34371 L
.2649 .34371 L
.2649 .08012 L
s
.678 .847 .902 r
.2649 .08012 m
.2649 .34295 L
.26634 .34295 L
.26634 .08012 L
F
.2 .63 .79 r
.2649 .08012 m
.2649 .34295 L
.26634 .34295 L
.26634 .08012 L
s
.678 .847 .902 r
.26634 .08012 m
.26634 .3408 L
.26765 .3408 L
.26765 .08012 L
F
.2 .63 .79 r
.26634 .08012 m
.26634 .3408 L
.26765 .3408 L
.26765 .08012 L
s
.678 .847 .902 r
.26765 .08012 m
.26765 .34021 L
.26885 .34021 L
.26885 .08012 L
F
.2 .63 .79 r
.26765 .08012 m
.26765 .34021 L
.26885 .34021 L
.26885 .08012 L
s
.678 .847 .902 r
.26885 .08012 m
.26885 .33936 L
.26992 .33936 L
.26992 .08012 L
F
.2 .63 .79 r
.26885 .08012 m
.26885 .33936 L
.26992 .33936 L
.26992 .08012 L
s
.678 .847 .902 r
.26992 .08012 m
.26992 .3374 L
.27118 .3374 L
.27118 .08012 L
F
.2 .63 .79 r
.26992 .08012 m
.26992 .3374 L
.27118 .3374 L
.27118 .08012 L
s
.678 .847 .902 r
.27118 .08012 m
.27118 .33692 L
.27171 .33692 L
.27171 .08012 L
F
.2 .63 .79 r
.27118 .08012 m
.27118 .33692 L
.27171 .33692 L
.27171 .08012 L
s
.678 .847 .902 r
.27171 .08012 m
.27171 .33617 L
.27242 .33617 L
.27242 .08012 L
F
.2 .63 .79 r
.27171 .08012 m
.27171 .33617 L
.27242 .33617 L
.27242 .08012 L
s
.678 .847 .902 r
.27242 .08012 m
.27242 .33545 L
.27331 .33545 L
.27331 .08012 L
F
.2 .63 .79 r
.27242 .08012 m
.27242 .33545 L
.27331 .33545 L
.27331 .08012 L
s
.678 .847 .902 r
.27331 .08012 m
.27331 .33432 L
.2746 .33432 L
.2746 .08012 L
F
.2 .63 .79 r
.27331 .08012 m
.27331 .33432 L
.2746 .33432 L
.2746 .08012 L
s
.678 .847 .902 r
.2746 .08012 m
.2746 .33397 L
.27511 .33397 L
.27511 .08012 L
F
.2 .63 .79 r
.2746 .08012 m
.2746 .33397 L
.27511 .33397 L
.27511 .08012 L
s
.678 .847 .902 r
.27511 .08012 m
.27511 .33361 L
.27605 .33361 L
.27605 .08012 L
F
.2 .63 .79 r
.27511 .08012 m
.27511 .33361 L
.27605 .33361 L
.27605 .08012 L
s
.678 .847 .902 r
.27605 .08012 m
.27605 .33272 L
.27675 .33272 L
.27675 .08012 L
F
.2 .63 .79 r
.27605 .08012 m
.27605 .33272 L
.27675 .33272 L
.27675 .08012 L
s
.678 .847 .902 r
.27675 .08012 m
.27675 .33211 L
.27762 .33211 L
.27762 .08012 L
F
.2 .63 .79 r
.27675 .08012 m
.27675 .33211 L
.27762 .33211 L
.27762 .08012 L
s
.678 .847 .902 r
.27762 .08012 m
.27762 .33046 L
.27896 .33046 L
.27896 .08012 L
F
.2 .63 .79 r
.27762 .08012 m
.27762 .33046 L
.27896 .33046 L
.27896 .08012 L
s
.678 .847 .902 r
.27896 .08012 m
.27896 .32981 L
.27995 .32981 L
.27995 .08012 L
F
.2 .63 .79 r
.27896 .08012 m
.27896 .32981 L
.27995 .32981 L
.27995 .08012 L
s
.678 .847 .902 r
.27995 .08012 m
.27995 .3284 L
.2811 .3284 L
.2811 .08012 L
F
.2 .63 .79 r
.27995 .08012 m
.27995 .3284 L
.2811 .3284 L
.2811 .08012 L
s
.678 .847 .902 r
.2811 .08012 m
.2811 .32806 L
.28154 .32806 L
.28154 .08012 L
F
.2 .63 .79 r
.2811 .08012 m
.2811 .32806 L
.28154 .32806 L
.28154 .08012 L
s
.678 .847 .902 r
.28154 .08012 m
.28154 .32764 L
.28226 .32764 L
.28226 .08012 L
F
.2 .63 .79 r
.28154 .08012 m
.28154 .32764 L
.28226 .32764 L
.28226 .08012 L
s
.678 .847 .902 r
.28226 .08012 m
.28226 .32715 L
.28306 .32715 L
.28306 .08012 L
F
.2 .63 .79 r
.28226 .08012 m
.28226 .32715 L
.28306 .32715 L
.28306 .08012 L
s
.678 .847 .902 r
.28306 .08012 m
.28306 .32571 L
.28442 .32571 L
.28442 .08012 L
F
.2 .63 .79 r
.28306 .08012 m
.28306 .32571 L
.28442 .32571 L
.28442 .08012 L
s
.678 .847 .902 r
.28442 .08012 m
.28442 .3251 L
.28523 .3251 L
.28523 .08012 L
F
.2 .63 .79 r
.28442 .08012 m
.28442 .3251 L
.28523 .3251 L
.28523 .08012 L
s
.678 .847 .902 r
.28523 .08012 m
.28523 .32449 L
.28568 .32449 L
.28568 .08012 L
F
.2 .63 .79 r
.28523 .08012 m
.28523 .32449 L
.28568 .32449 L
.28568 .08012 L
s
.678 .847 .902 r
.28568 .08012 m
.28568 .3239 L
.28663 .3239 L
.28663 .08012 L
F
.2 .63 .79 r
.28568 .08012 m
.28568 .3239 L
.28663 .3239 L
.28663 .08012 L
s
.678 .847 .902 r
.28663 .08012 m
.28663 .32308 L
.28806 .32308 L
.28806 .08012 L
F
.2 .63 .79 r
.28663 .08012 m
.28663 .32308 L
.28806 .32308 L
.28806 .08012 L
s
.678 .847 .902 r
.28806 .08012 m
.28806 .32189 L
.28889 .32189 L
.28889 .08012 L
F
.2 .63 .79 r
.28806 .08012 m
.28806 .32189 L
.28889 .32189 L
.28889 .08012 L
s
.678 .847 .902 r
.28889 .08012 m
.28889 .32108 L
.28949 .32108 L
.28949 .08012 L
F
.2 .63 .79 r
.28889 .08012 m
.28889 .32108 L
.28949 .32108 L
.28949 .08012 L
s
.678 .847 .902 r
.28949 .08012 m
.28949 .32072 L
.2907 .32072 L
.2907 .08012 L
F
.2 .63 .79 r
.28949 .08012 m
.28949 .32072 L
.2907 .32072 L
.2907 .08012 L
s
.678 .847 .902 r
.2907 .08012 m
.2907 .31957 L
.29149 .31957 L
.29149 .08012 L
F
.2 .63 .79 r
.2907 .08012 m
.2907 .31957 L
.29149 .31957 L
.29149 .08012 L
s
.678 .847 .902 r
.29149 .08012 m
.29149 .3187 L
.29251 .3187 L
.29251 .08012 L
F
.2 .63 .79 r
.29149 .08012 m
.29149 .3187 L
.29251 .3187 L
.29251 .08012 L
s
.678 .847 .902 r
.29251 .08012 m
.29251 .31775 L
.29302 .31775 L
.29302 .08012 L
F
.2 .63 .79 r
.29251 .08012 m
.29251 .31775 L
.29302 .31775 L
.29302 .08012 L
s
.678 .847 .902 r
.29302 .08012 m
.29302 .31754 L
.29396 .31754 L
.29396 .08012 L
F
.2 .63 .79 r
.29302 .08012 m
.29302 .31754 L
.29396 .31754 L
.29396 .08012 L
s
.678 .847 .902 r
.29396 .08012 m
.29396 .31642 L
.29532 .31642 L
.29532 .08012 L
F
.2 .63 .79 r
.29396 .08012 m
.29396 .31642 L
.29532 .31642 L
.29532 .08012 L
s
.678 .847 .902 r
.29532 .08012 m
.29532 .31511 L
.2965 .31511 L
.2965 .08012 L
F
.2 .63 .79 r
.29532 .08012 m
.29532 .31511 L
.2965 .31511 L
.2965 .08012 L
s
.678 .847 .902 r
.2965 .08012 m
.2965 .31417 L
.29795 .31417 L
.29795 .08012 L
F
.2 .63 .79 r
.2965 .08012 m
.2965 .31417 L
.29795 .31417 L
.29795 .08012 L
s
.678 .847 .902 r
.29795 .08012 m
.29795 .31285 L
.29839 .31285 L
.29839 .08012 L
F
.2 .63 .79 r
.29795 .08012 m
.29795 .31285 L
.29839 .31285 L
.29839 .08012 L
s
.678 .847 .902 r
.29839 .08012 m
.29839 .31273 L
.29948 .31273 L
.29948 .08012 L
F
.2 .63 .79 r
.29839 .08012 m
.29839 .31273 L
.29948 .31273 L
.29948 .08012 L
s
.678 .847 .902 r
.29948 .08012 m
.29948 .31166 L
.30024 .31166 L
.30024 .08012 L
F
.2 .63 .79 r
.29948 .08012 m
.29948 .31166 L
.30024 .31166 L
.30024 .08012 L
s
.678 .847 .902 r
.30024 .08012 m
.30024 .31098 L
.30079 .31098 L
.30079 .08012 L
F
.2 .63 .79 r
.30024 .08012 m
.30024 .31098 L
.30079 .31098 L
.30079 .08012 L
s
.678 .847 .902 r
.30079 .08012 m
.30079 .31028 L
.30169 .31028 L
.30169 .08012 L
F
.2 .63 .79 r
.30079 .08012 m
.30079 .31028 L
.30169 .31028 L
.30169 .08012 L
s
.678 .847 .902 r
.30169 .08012 m
.30169 .30962 L
.30309 .30962 L
.30309 .08012 L
F
.2 .63 .79 r
.30169 .08012 m
.30169 .30962 L
.30309 .30962 L
.30309 .08012 L
s
.678 .847 .902 r
.30309 .08012 m
.30309 .30817 L
.30384 .30817 L
.30384 .08012 L
F
.2 .63 .79 r
.30309 .08012 m
.30309 .30817 L
.30384 .30817 L
.30384 .08012 L
s
.678 .847 .902 r
.30384 .08012 m
.30384 .30789 L
.30513 .30789 L
.30513 .08012 L
F
.2 .63 .79 r
.30384 .08012 m
.30384 .30789 L
.30513 .30789 L
.30513 .08012 L
s
.678 .847 .902 r
.30513 .08012 m
.30513 .30671 L
.30567 .30671 L
.30567 .08012 L
F
.2 .63 .79 r
.30513 .08012 m
.30513 .30671 L
.30567 .30671 L
.30567 .08012 L
s
.678 .847 .902 r
.30567 .08012 m
.30567 .30621 L
.30614 .30621 L
.30614 .08012 L
F
.2 .63 .79 r
.30567 .08012 m
.30567 .30621 L
.30614 .30621 L
.30614 .08012 L
s
.678 .847 .902 r
.30614 .08012 m
.30614 .30529 L
.30753 .30529 L
.30753 .08012 L
F
.2 .63 .79 r
.30614 .08012 m
.30614 .30529 L
.30753 .30529 L
.30753 .08012 L
s
.678 .847 .902 r
.30753 .08012 m
.30753 .30477 L
.30881 .30477 L
.30881 .08012 L
F
.2 .63 .79 r
.30753 .08012 m
.30753 .30477 L
.30881 .30477 L
.30881 .08012 L
s
.678 .847 .902 r
.30881 .08012 m
.30881 .30354 L
.30986 .30354 L
.30986 .08012 L
F
.2 .63 .79 r
.30881 .08012 m
.30881 .30354 L
.30986 .30354 L
.30986 .08012 L
s
.678 .847 .902 r
.30986 .08012 m
.30986 .30263 L
.31036 .30263 L
.31036 .08012 L
F
.2 .63 .79 r
.30986 .08012 m
.30986 .30263 L
.31036 .30263 L
.31036 .08012 L
s
.678 .847 .902 r
.31036 .08012 m
.31036 .30199 L
.31136 .30199 L
.31136 .08012 L
F
.2 .63 .79 r
.31036 .08012 m
.31036 .30199 L
.31136 .30199 L
.31136 .08012 L
s
.678 .847 .902 r
.31136 .08012 m
.31136 .30083 L
.31248 .30083 L
.31248 .08012 L
F
.2 .63 .79 r
.31136 .08012 m
.31136 .30083 L
.31248 .30083 L
.31248 .08012 L
s
.678 .847 .902 r
.31248 .08012 m
.31248 .30033 L
.31377 .30033 L
.31377 .08012 L
F
.2 .63 .79 r
.31248 .08012 m
.31248 .30033 L
.31377 .30033 L
.31377 .08012 L
s
.678 .847 .902 r
.31377 .08012 m
.31377 .2991 L
.31493 .2991 L
.31493 .08012 L
F
.2 .63 .79 r
.31377 .08012 m
.31377 .2991 L
.31493 .2991 L
.31493 .08012 L
s
.678 .847 .902 r
.31493 .08012 m
.31493 .2982 L
.31637 .2982 L
.31637 .08012 L
F
.2 .63 .79 r
.31493 .08012 m
.31493 .2982 L
.31637 .2982 L
.31637 .08012 L
s
.678 .847 .902 r
.31637 .08012 m
.31637 .29714 L
.31741 .29714 L
.31741 .08012 L
F
.2 .63 .79 r
.31637 .08012 m
.31637 .29714 L
.31741 .29714 L
.31741 .08012 L
s
.678 .847 .902 r
.31741 .08012 m
.31741 .29623 L
.31821 .29623 L
.31821 .08012 L
F
.2 .63 .79 r
.31741 .08012 m
.31741 .29623 L
.31821 .29623 L
.31821 .08012 L
s
.678 .847 .902 r
.31821 .08012 m
.31821 .29557 L
.31947 .29557 L
.31947 .08012 L
F
.2 .63 .79 r
.31821 .08012 m
.31821 .29557 L
.31947 .29557 L
.31947 .08012 L
s
.678 .847 .902 r
.31947 .08012 m
.31947 .29413 L
.32015 .29413 L
.32015 .08012 L
F
.2 .63 .79 r
.31947 .08012 m
.31947 .29413 L
.32015 .29413 L
.32015 .08012 L
s
.678 .847 .902 r
.32015 .08012 m
.32015 .29325 L
.3212 .29325 L
.3212 .08012 L
F
.2 .63 .79 r
.32015 .08012 m
.32015 .29325 L
.3212 .29325 L
.3212 .08012 L
s
.678 .847 .902 r
.3212 .08012 m
.3212 .29299 L
.322 .29299 L
.322 .08012 L
F
.2 .63 .79 r
.3212 .08012 m
.3212 .29299 L
.322 .29299 L
.322 .08012 L
s
.678 .847 .902 r
.322 .08012 m
.322 .29194 L
.3226 .29194 L
.3226 .08012 L
F
.2 .63 .79 r
.322 .08012 m
.322 .29194 L
.3226 .29194 L
.3226 .08012 L
s
.678 .847 .902 r
.3226 .08012 m
.3226 .29138 L
.32399 .29138 L
.32399 .08012 L
F
.2 .63 .79 r
.3226 .08012 m
.3226 .29138 L
.32399 .29138 L
.32399 .08012 L
s
.678 .847 .902 r
.32399 .08012 m
.32399 .29047 L
.32492 .29047 L
.32492 .08012 L
F
.2 .63 .79 r
.32399 .08012 m
.32399 .29047 L
.32492 .29047 L
.32492 .08012 L
s
.678 .847 .902 r
.32492 .08012 m
.32492 .28927 L
.32627 .28927 L
.32627 .08012 L
F
.2 .63 .79 r
.32492 .08012 m
.32492 .28927 L
.32627 .28927 L
.32627 .08012 L
s
.678 .847 .902 r
.32627 .08012 m
.32627 .28843 L
.32694 .28843 L
.32694 .08012 L
F
.2 .63 .79 r
.32627 .08012 m
.32627 .28843 L
.32694 .28843 L
.32694 .08012 L
s
.678 .847 .902 r
.32694 .08012 m
.32694 .28771 L
.32801 .28771 L
.32801 .08012 L
F
.2 .63 .79 r
.32694 .08012 m
.32694 .28771 L
.32801 .28771 L
.32801 .08012 L
s
.678 .847 .902 r
.32801 .08012 m
.32801 .28718 L
.32911 .28718 L
.32911 .08012 L
F
.2 .63 .79 r
.32801 .08012 m
.32801 .28718 L
.32911 .28718 L
.32911 .08012 L
s
.678 .847 .902 r
.32911 .08012 m
.32911 .28632 L
.33035 .28632 L
.33035 .08012 L
F
.2 .63 .79 r
.32911 .08012 m
.32911 .28632 L
.33035 .28632 L
.33035 .08012 L
s
.678 .847 .902 r
.33035 .08012 m
.33035 .28536 L
.33098 .28536 L
.33098 .08012 L
F
.2 .63 .79 r
.33035 .08012 m
.33035 .28536 L
.33098 .28536 L
.33098 .08012 L
s
.678 .847 .902 r
.33098 .08012 m
.33098 .28394 L
.33212 .28394 L
.33212 .08012 L
F
.2 .63 .79 r
.33098 .08012 m
.33098 .28394 L
.33212 .28394 L
.33212 .08012 L
s
.678 .847 .902 r
.33212 .08012 m
.33212 .28379 L
.3334 .28379 L
.3334 .08012 L
F
.2 .63 .79 r
.33212 .08012 m
.33212 .28379 L
.3334 .28379 L
.3334 .08012 L
s
.678 .847 .902 r
.3334 .08012 m
.3334 .28238 L
.33403 .28238 L
.33403 .08012 L
F
.2 .63 .79 r
.3334 .08012 m
.3334 .28238 L
.33403 .28238 L
.33403 .08012 L
s
.678 .847 .902 r
.33403 .08012 m
.33403 .28204 L
.3346 .28204 L
.3346 .08012 L
F
.2 .63 .79 r
.33403 .08012 m
.33403 .28204 L
.3346 .28204 L
.3346 .08012 L
s
.678 .847 .902 r
.3346 .08012 m
.3346 .28161 L
.33517 .28161 L
.33517 .08012 L
F
.2 .63 .79 r
.3346 .08012 m
.3346 .28161 L
.33517 .28161 L
.33517 .08012 L
s
.678 .847 .902 r
.33517 .08012 m
.33517 .28118 L
.33578 .28118 L
.33578 .08012 L
F
.2 .63 .79 r
.33517 .08012 m
.33517 .28118 L
.33578 .28118 L
.33578 .08012 L
s
.678 .847 .902 r
.33578 .08012 m
.33578 .28044 L
.33656 .28044 L
.33656 .08012 L
F
.2 .63 .79 r
.33578 .08012 m
.33578 .28044 L
.33656 .28044 L
.33656 .08012 L
s
.678 .847 .902 r
.33656 .08012 m
.33656 .28005 L
.33743 .28005 L
.33743 .08012 L
F
.2 .63 .79 r
.33656 .08012 m
.33656 .28005 L
.33743 .28005 L
.33743 .08012 L
s
.678 .847 .902 r
.33743 .08012 m
.33743 .27936 L
.33802 .27936 L
.33802 .08012 L
F
.2 .63 .79 r
.33743 .08012 m
.33743 .27936 L
.33802 .27936 L
.33802 .08012 L
s
.678 .847 .902 r
.33802 .08012 m
.33802 .27878 L
.33904 .27878 L
.33904 .08012 L
F
.2 .63 .79 r
.33802 .08012 m
.33802 .27878 L
.33904 .27878 L
.33904 .08012 L
s
.678 .847 .902 r
.33904 .08012 m
.33904 .27758 L
.34048 .27758 L
.34048 .08012 L
F
.2 .63 .79 r
.33904 .08012 m
.33904 .27758 L
.34048 .27758 L
.34048 .08012 L
s
.678 .847 .902 r
.34048 .08012 m
.34048 .27685 L
.34155 .27685 L
.34155 .08012 L
F
.2 .63 .79 r
.34048 .08012 m
.34048 .27685 L
.34155 .27685 L
.34155 .08012 L
s
.678 .847 .902 r
.34155 .08012 m
.34155 .27556 L
.34291 .27556 L
.34291 .08012 L
F
.2 .63 .79 r
.34155 .08012 m
.34155 .27556 L
.34291 .27556 L
.34291 .08012 L
s
.678 .847 .902 r
.34291 .08012 m
.34291 .27447 L
.34434 .27447 L
.34434 .08012 L
F
.2 .63 .79 r
.34291 .08012 m
.34291 .27447 L
.34434 .27447 L
.34434 .08012 L
s
.678 .847 .902 r
.34434 .08012 m
.34434 .27352 L
.34542 .27352 L
.34542 .08012 L
F
.2 .63 .79 r
.34434 .08012 m
.34434 .27352 L
.34542 .27352 L
.34542 .08012 L
s
.678 .847 .902 r
.34542 .08012 m
.34542 .27278 L
.34632 .27278 L
.34632 .08012 L
F
.2 .63 .79 r
.34542 .08012 m
.34542 .27278 L
.34632 .27278 L
.34632 .08012 L
s
.678 .847 .902 r
.34632 .08012 m
.34632 .27217 L
.34776 .27217 L
.34776 .08012 L
F
.2 .63 .79 r
.34632 .08012 m
.34632 .27217 L
.34776 .27217 L
.34776 .08012 L
s
.678 .847 .902 r
.34776 .08012 m
.34776 .27095 L
.34868 .27095 L
.34868 .08012 L
F
.2 .63 .79 r
.34776 .08012 m
.34776 .27095 L
.34868 .27095 L
.34868 .08012 L
s
.678 .847 .902 r
.34868 .08012 m
.34868 .26956 L
.34988 .26956 L
.34988 .08012 L
F
.2 .63 .79 r
.34868 .08012 m
.34868 .26956 L
.34988 .26956 L
.34988 .08012 L
s
.678 .847 .902 r
.34988 .08012 m
.34988 .26902 L
.35054 .26902 L
.35054 .08012 L
F
.2 .63 .79 r
.34988 .08012 m
.34988 .26902 L
.35054 .26902 L
.35054 .08012 L
s
.678 .847 .902 r
.35054 .08012 m
.35054 .26847 L
.35134 .26847 L
.35134 .08012 L
F
.2 .63 .79 r
.35054 .08012 m
.35054 .26847 L
.35134 .26847 L
.35134 .08012 L
s
.678 .847 .902 r
.35134 .08012 m
.35134 .26718 L
.35262 .26718 L
.35262 .08012 L
F
.2 .63 .79 r
.35134 .08012 m
.35134 .26718 L
.35262 .26718 L
.35262 .08012 L
s
.678 .847 .902 r
.35262 .08012 m
.35262 .26636 L
.35404 .26636 L
.35404 .08012 L
F
.2 .63 .79 r
.35262 .08012 m
.35262 .26636 L
.35404 .26636 L
.35404 .08012 L
s
.678 .847 .902 r
.35404 .08012 m
.35404 .26575 L
.35451 .26575 L
.35451 .08012 L
F
.2 .63 .79 r
.35404 .08012 m
.35404 .26575 L
.35451 .26575 L
.35451 .08012 L
s
.678 .847 .902 r
.35451 .08012 m
.35451 .26514 L
.35563 .26514 L
.35563 .08012 L
F
.2 .63 .79 r
.35451 .08012 m
.35451 .26514 L
.35563 .26514 L
.35563 .08012 L
s
.678 .847 .902 r
.35563 .08012 m
.35563 .26373 L
.35708 .26373 L
.35708 .08012 L
F
.2 .63 .79 r
.35563 .08012 m
.35563 .26373 L
.35708 .26373 L
.35708 .08012 L
s
.678 .847 .902 r
.35708 .08012 m
.35708 .26274 L
.3583 .26274 L
.3583 .08012 L
F
.2 .63 .79 r
.35708 .08012 m
.35708 .26274 L
.3583 .26274 L
.3583 .08012 L
s
.678 .847 .902 r
.3583 .08012 m
.3583 .26158 L
.35966 .26158 L
.35966 .08012 L
F
.2 .63 .79 r
.3583 .08012 m
.3583 .26158 L
.35966 .26158 L
.35966 .08012 L
s
.678 .847 .902 r
.35966 .08012 m
.35966 .26065 L
.36064 .26065 L
.36064 .08012 L
F
.2 .63 .79 r
.35966 .08012 m
.35966 .26065 L
.36064 .26065 L
.36064 .08012 L
s
.678 .847 .902 r
.36064 .08012 m
.36064 .2602 L
.36192 .2602 L
.36192 .08012 L
F
.2 .63 .79 r
.36064 .08012 m
.36064 .2602 L
.36192 .2602 L
.36192 .08012 L
s
.678 .847 .902 r
.36192 .08012 m
.36192 .25952 L
.36281 .25952 L
.36281 .08012 L
F
.2 .63 .79 r
.36192 .08012 m
.36192 .25952 L
.36281 .25952 L
.36281 .08012 L
s
.678 .847 .902 r
.36281 .08012 m
.36281 .25844 L
.36372 .25844 L
.36372 .08012 L
F
.2 .63 .79 r
.36281 .08012 m
.36281 .25844 L
.36372 .25844 L
.36372 .08012 L
s
.678 .847 .902 r
.36372 .08012 m
.36372 .2577 L
.36455 .2577 L
.36455 .08012 L
F
.2 .63 .79 r
.36372 .08012 m
.36372 .2577 L
.36455 .2577 L
.36455 .08012 L
s
.678 .847 .902 r
.36455 .08012 m
.36455 .25741 L
.36526 .25741 L
.36526 .08012 L
F
.2 .63 .79 r
.36455 .08012 m
.36455 .25741 L
.36526 .25741 L
.36526 .08012 L
s
.678 .847 .902 r
.36526 .08012 m
.36526 .2565 L
.36615 .2565 L
.36615 .08012 L
F
.2 .63 .79 r
.36526 .08012 m
.36526 .2565 L
.36615 .2565 L
.36615 .08012 L
s
.678 .847 .902 r
.36615 .08012 m
.36615 .25574 L
.36746 .25574 L
.36746 .08012 L
F
.2 .63 .79 r
.36615 .08012 m
.36615 .25574 L
.36746 .25574 L
.36746 .08012 L
s
.678 .847 .902 r
.36746 .08012 m
.36746 .25503 L
.36838 .25503 L
.36838 .08012 L
F
.2 .63 .79 r
.36746 .08012 m
.36746 .25503 L
.36838 .25503 L
.36838 .08012 L
s
.678 .847 .902 r
.36838 .08012 m
.36838 .25404 L
.36912 .25404 L
.36912 .08012 L
F
.2 .63 .79 r
.36838 .08012 m
.36838 .25404 L
.36912 .25404 L
.36912 .08012 L
s
.678 .847 .902 r
.36912 .08012 m
.36912 .25359 L
.37038 .25359 L
.37038 .08012 L
F
.2 .63 .79 r
.36912 .08012 m
.36912 .25359 L
.37038 .25359 L
.37038 .08012 L
s
.678 .847 .902 r
.37038 .08012 m
.37038 .25268 L
.37123 .25268 L
.37123 .08012 L
F
.2 .63 .79 r
.37038 .08012 m
.37038 .25268 L
.37123 .25268 L
.37123 .08012 L
s
.678 .847 .902 r
.37123 .08012 m
.37123 .25207 L
.37217 .25207 L
.37217 .08012 L
F
.2 .63 .79 r
.37123 .08012 m
.37123 .25207 L
.37217 .25207 L
.37217 .08012 L
s
.678 .847 .902 r
.37217 .08012 m
.37217 .25084 L
.37344 .25084 L
.37344 .08012 L
F
.2 .63 .79 r
.37217 .08012 m
.37217 .25084 L
.37344 .25084 L
.37344 .08012 L
s
.678 .847 .902 r
.37344 .08012 m
.37344 .25025 L
.37395 .25025 L
.37395 .08012 L
F
.2 .63 .79 r
.37344 .08012 m
.37344 .25025 L
.37395 .25025 L
.37395 .08012 L
s
.678 .847 .902 r
.37395 .08012 m
.37395 .24969 L
.37456 .24969 L
.37456 .08012 L
F
.2 .63 .79 r
.37395 .08012 m
.37395 .24969 L
.37456 .24969 L
.37456 .08012 L
s
.678 .847 .902 r
.37456 .08012 m
.37456 .24924 L
.37514 .24924 L
.37514 .08012 L
F
.2 .63 .79 r
.37456 .08012 m
.37456 .24924 L
.37514 .24924 L
.37514 .08012 L
s
.678 .847 .902 r
.37514 .08012 m
.37514 .24829 L
.37659 .24829 L
.37659 .08012 L
F
.2 .63 .79 r
.37514 .08012 m
.37514 .24829 L
.37659 .24829 L
.37659 .08012 L
s
.678 .847 .902 r
.37659 .08012 m
.37659 .2476 L
.37714 .2476 L
.37714 .08012 L
F
.2 .63 .79 r
.37659 .08012 m
.37659 .2476 L
.37714 .2476 L
.37714 .08012 L
s
.678 .847 .902 r
.37714 .08012 m
.37714 .2474 L
.37772 .2474 L
.37772 .08012 L
F
.2 .63 .79 r
.37714 .08012 m
.37714 .2474 L
.37772 .2474 L
.37772 .08012 L
s
.678 .847 .902 r
.37772 .08012 m
.37772 .24687 L
.37863 .24687 L
.37863 .08012 L
F
.2 .63 .79 r
.37772 .08012 m
.37772 .24687 L
.37863 .24687 L
.37863 .08012 L
s
.678 .847 .902 r
.37863 .08012 m
.37863 .24643 L
.38009 .24643 L
.38009 .08012 L
F
.2 .63 .79 r
.37863 .08012 m
.37863 .24643 L
.38009 .24643 L
.38009 .08012 L
s
.678 .847 .902 r
.38009 .08012 m
.38009 .24515 L
.38086 .24515 L
.38086 .08012 L
F
.2 .63 .79 r
.38009 .08012 m
.38009 .24515 L
.38086 .24515 L
.38086 .08012 L
s
.678 .847 .902 r
.38086 .08012 m
.38086 .24439 L
.38155 .24439 L
.38155 .08012 L
F
.2 .63 .79 r
.38086 .08012 m
.38086 .24439 L
.38155 .24439 L
.38155 .08012 L
s
.678 .847 .902 r
.38155 .08012 m
.38155 .2437 L
.38294 .2437 L
.38294 .08012 L
F
.2 .63 .79 r
.38155 .08012 m
.38155 .2437 L
.38294 .2437 L
.38294 .08012 L
s
.678 .847 .902 r
.38294 .08012 m
.38294 .24282 L
.38355 .24282 L
.38355 .08012 L
F
.2 .63 .79 r
.38294 .08012 m
.38294 .24282 L
.38355 .24282 L
.38355 .08012 L
s
.678 .847 .902 r
.38355 .08012 m
.38355 .24244 L
.38489 .24244 L
.38489 .08012 L
F
.2 .63 .79 r
.38355 .08012 m
.38355 .24244 L
.38489 .24244 L
.38489 .08012 L
s
.678 .847 .902 r
.38489 .08012 m
.38489 .24159 L
.38612 .24159 L
.38612 .08012 L
F
.2 .63 .79 r
.38489 .08012 m
.38489 .24159 L
.38612 .24159 L
.38612 .08012 L
s
.678 .847 .902 r
.38612 .08012 m
.38612 .24008 L
.38711 .24008 L
.38711 .08012 L
F
.2 .63 .79 r
.38612 .08012 m
.38612 .24008 L
.38711 .24008 L
.38711 .08012 L
s
.678 .847 .902 r
.38711 .08012 m
.38711 .23939 L
.38848 .23939 L
.38848 .08012 L
F
.2 .63 .79 r
.38711 .08012 m
.38711 .23939 L
.38848 .23939 L
.38848 .08012 L
s
.678 .847 .902 r
.38848 .08012 m
.38848 .23845 L
.38936 .23845 L
.38936 .08012 L
F
.2 .63 .79 r
.38848 .08012 m
.38848 .23845 L
.38936 .23845 L
.38936 .08012 L
s
.678 .847 .902 r
.38936 .08012 m
.38936 .23761 L
.39074 .23761 L
.39074 .08012 L
F
.2 .63 .79 r
.38936 .08012 m
.38936 .23761 L
.39074 .23761 L
.39074 .08012 L
s
.678 .847 .902 r
.39074 .08012 m
.39074 .23692 L
.39125 .23692 L
.39125 .08012 L
F
.2 .63 .79 r
.39074 .08012 m
.39074 .23692 L
.39125 .23692 L
.39125 .08012 L
s
.678 .847 .902 r
.39125 .08012 m
.39125 .23612 L
.39231 .23612 L
.39231 .08012 L
F
.2 .63 .79 r
.39125 .08012 m
.39125 .23612 L
.39231 .23612 L
.39231 .08012 L
s
.678 .847 .902 r
.39231 .08012 m
.39231 .23569 L
.39339 .23569 L
.39339 .08012 L
F
.2 .63 .79 r
.39231 .08012 m
.39231 .23569 L
.39339 .23569 L
.39339 .08012 L
s
.678 .847 .902 r
.39339 .08012 m
.39339 .23494 L
.39435 .23494 L
.39435 .08012 L
F
.2 .63 .79 r
.39339 .08012 m
.39339 .23494 L
.39435 .23494 L
.39435 .08012 L
s
.678 .847 .902 r
.39435 .08012 m
.39435 .23411 L
.39538 .23411 L
.39538 .08012 L
F
.2 .63 .79 r
.39435 .08012 m
.39435 .23411 L
.39538 .23411 L
.39538 .08012 L
s
.678 .847 .902 r
.39538 .08012 m
.39538 .23349 L
.39663 .23349 L
.39663 .08012 L
F
.2 .63 .79 r
.39538 .08012 m
.39538 .23349 L
.39663 .23349 L
.39663 .08012 L
s
.678 .847 .902 r
.39663 .08012 m
.39663 .23213 L
.39764 .23213 L
.39764 .08012 L
F
.2 .63 .79 r
.39663 .08012 m
.39663 .23213 L
.39764 .23213 L
.39764 .08012 L
s
.678 .847 .902 r
.39764 .08012 m
.39764 .23167 L
.39842 .23167 L
.39842 .08012 L
F
.2 .63 .79 r
.39764 .08012 m
.39764 .23167 L
.39842 .23167 L
.39842 .08012 L
s
.678 .847 .902 r
.39842 .08012 m
.39842 .23096 L
.3993 .23096 L
.3993 .08012 L
F
.2 .63 .79 r
.39842 .08012 m
.39842 .23096 L
.3993 .23096 L
.3993 .08012 L
s
.678 .847 .902 r
.3993 .08012 m
.3993 .23031 L
.40057 .23031 L
.40057 .08012 L
F
.2 .63 .79 r
.3993 .08012 m
.3993 .23031 L
.40057 .23031 L
.40057 .08012 L
s
.678 .847 .902 r
.40057 .08012 m
.40057 .22924 L
.40146 .22924 L
.40146 .08012 L
F
.2 .63 .79 r
.40057 .08012 m
.40057 .22924 L
.40146 .22924 L
.40146 .08012 L
s
.678 .847 .902 r
.40146 .08012 m
.40146 .22906 L
.4021 .22906 L
.4021 .08012 L
F
.2 .63 .79 r
.40146 .08012 m
.40146 .22906 L
.4021 .22906 L
.4021 .08012 L
s
.678 .847 .902 r
.4021 .08012 m
.4021 .22839 L
.40353 .22839 L
.40353 .08012 L
F
.2 .63 .79 r
.4021 .08012 m
.4021 .22839 L
.40353 .22839 L
.40353 .08012 L
s
.678 .847 .902 r
.40353 .08012 m
.40353 .22717 L
.40479 .22717 L
.40479 .08012 L
F
.2 .63 .79 r
.40353 .08012 m
.40353 .22717 L
.40479 .22717 L
.40479 .08012 L
s
.678 .847 .902 r
.40479 .08012 m
.40479 .2264 L
.40534 .2264 L
.40534 .08012 L
F
.2 .63 .79 r
.40479 .08012 m
.40479 .2264 L
.40534 .2264 L
.40534 .08012 L
s
.678 .847 .902 r
.40534 .08012 m
.40534 .22576 L
.40676 .22576 L
.40676 .08012 L
F
.2 .63 .79 r
.40534 .08012 m
.40534 .22576 L
.40676 .22576 L
.40676 .08012 L
s
.678 .847 .902 r
.40676 .08012 m
.40676 .22487 L
.40723 .22487 L
.40723 .08012 L
F
.2 .63 .79 r
.40676 .08012 m
.40676 .22487 L
.40723 .22487 L
.40723 .08012 L
s
.678 .847 .902 r
.40723 .08012 m
.40723 .22416 L
.40832 .22416 L
.40832 .08012 L
F
.2 .63 .79 r
.40723 .08012 m
.40723 .22416 L
.40832 .22416 L
.40832 .08012 L
s
.678 .847 .902 r
.40832 .08012 m
.40832 .22384 L
.40898 .22384 L
.40898 .08012 L
F
.2 .63 .79 r
.40832 .08012 m
.40832 .22384 L
.40898 .22384 L
.40898 .08012 L
s
.678 .847 .902 r
.40898 .08012 m
.40898 .22331 L
.40961 .22331 L
.40961 .08012 L
F
.2 .63 .79 r
.40898 .08012 m
.40898 .22331 L
.40961 .22331 L
.40961 .08012 L
s
.678 .847 .902 r
.40961 .08012 m
.40961 .22236 L
.41055 .22236 L
.41055 .08012 L
F
.2 .63 .79 r
.40961 .08012 m
.40961 .22236 L
.41055 .22236 L
.41055 .08012 L
s
.678 .847 .902 r
.41055 .08012 m
.41055 .2221 L
.41173 .2221 L
.41173 .08012 L
F
.2 .63 .79 r
.41055 .08012 m
.41055 .2221 L
.41173 .2221 L
.41173 .08012 L
s
.678 .847 .902 r
.41173 .08012 m
.41173 .22086 L
.41296 .22086 L
.41296 .08012 L
F
.2 .63 .79 r
.41173 .08012 m
.41173 .22086 L
.41296 .22086 L
.41296 .08012 L
s
.678 .847 .902 r
.41296 .08012 m
.41296 .22014 L
.41367 .22014 L
.41367 .08012 L
F
.2 .63 .79 r
.41296 .08012 m
.41296 .22014 L
.41367 .22014 L
.41367 .08012 L
s
.678 .847 .902 r
.41367 .08012 m
.41367 .2198 L
.41453 .2198 L
.41453 .08012 L
F
.2 .63 .79 r
.41367 .08012 m
.41367 .2198 L
.41453 .2198 L
.41453 .08012 L
s
.678 .847 .902 r
.41453 .08012 m
.41453 .21923 L
.41508 .21923 L
.41508 .08012 L
F
.2 .63 .79 r
.41453 .08012 m
.41453 .21923 L
.41508 .21923 L
.41508 .08012 L
s
.678 .847 .902 r
.41508 .08012 m
.41508 .21887 L
.41568 .21887 L
.41568 .08012 L
F
.2 .63 .79 r
.41508 .08012 m
.41508 .21887 L
.41568 .21887 L
.41568 .08012 L
s
.678 .847 .902 r
.41568 .08012 m
.41568 .21808 L
.41688 .21808 L
.41688 .08012 L
F
.2 .63 .79 r
.41568 .08012 m
.41568 .21808 L
.41688 .21808 L
.41688 .08012 L
s
.678 .847 .902 r
.41688 .08012 m
.41688 .2177 L
.41818 .2177 L
.41818 .08012 L
F
.2 .63 .79 r
.41688 .08012 m
.41688 .2177 L
.41818 .2177 L
.41818 .08012 L
s
.678 .847 .902 r
.41818 .08012 m
.41818 .2166 L
.41893 .2166 L
.41893 .08012 L
F
.2 .63 .79 r
.41818 .08012 m
.41818 .2166 L
.41893 .2166 L
.41893 .08012 L
s
.678 .847 .902 r
.41893 .08012 m
.41893 .21576 L
.41997 .21576 L
.41997 .08012 L
F
.2 .63 .79 r
.41893 .08012 m
.41893 .21576 L
.41997 .21576 L
.41997 .08012 L
s
.678 .847 .902 r
.41997 .08012 m
.41997 .21539 L
.42083 .21539 L
.42083 .08012 L
F
.2 .63 .79 r
.41997 .08012 m
.41997 .21539 L
.42083 .21539 L
.42083 .08012 L
s
.678 .847 .902 r
.42083 .08012 m
.42083 .21459 L
.42168 .21459 L
.42168 .08012 L
F
.2 .63 .79 r
.42083 .08012 m
.42083 .21459 L
.42168 .21459 L
.42168 .08012 L
s
.678 .847 .902 r
.42168 .08012 m
.42168 .21361 L
.42263 .21361 L
.42263 .08012 L
F
.2 .63 .79 r
.42168 .08012 m
.42168 .21361 L
.42263 .21361 L
.42263 .08012 L
s
.678 .847 .902 r
.42263 .08012 m
.42263 .2132 L
.42321 .2132 L
.42321 .08012 L
F
.2 .63 .79 r
.42263 .08012 m
.42263 .2132 L
.42321 .2132 L
.42321 .08012 L
s
.678 .847 .902 r
.42321 .08012 m
.42321 .21309 L
.42386 .21309 L
.42386 .08012 L
F
.2 .63 .79 r
.42321 .08012 m
.42321 .21309 L
.42386 .21309 L
.42386 .08012 L
s
.678 .847 .902 r
.42386 .08012 m
.42386 .21252 L
.42474 .21252 L
.42474 .08012 L
F
.2 .63 .79 r
.42386 .08012 m
.42386 .21252 L
.42474 .21252 L
.42474 .08012 L
s
.678 .847 .902 r
.42474 .08012 m
.42474 .2116 L
.42589 .2116 L
.42589 .08012 L
F
.2 .63 .79 r
.42474 .08012 m
.42474 .2116 L
.42589 .2116 L
.42589 .08012 L
s
.678 .847 .902 r
.42589 .08012 m
.42589 .2111 L
.42635 .2111 L
.42635 .08012 L
F
.2 .63 .79 r
.42589 .08012 m
.42589 .2111 L
.42635 .2111 L
.42635 .08012 L
s
.678 .847 .902 r
.42635 .08012 m
.42635 .21054 L
.42705 .21054 L
.42705 .08012 L
F
.2 .63 .79 r
.42635 .08012 m
.42635 .21054 L
.42705 .21054 L
.42705 .08012 L
s
.678 .847 .902 r
.42705 .08012 m
.42705 .2101 L
.42789 .2101 L
.42789 .08012 L
F
.2 .63 .79 r
.42705 .08012 m
.42705 .2101 L
.42789 .2101 L
.42789 .08012 L
s
.678 .847 .902 r
.42789 .08012 m
.42789 .20953 L
.42838 .20953 L
.42838 .08012 L
F
.2 .63 .79 r
.42789 .08012 m
.42789 .20953 L
.42838 .20953 L
.42838 .08012 L
s
.678 .847 .902 r
.42838 .08012 m
.42838 .20935 L
.42964 .20935 L
.42964 .08012 L
F
.2 .63 .79 r
.42838 .08012 m
.42838 .20935 L
.42964 .20935 L
.42964 .08012 L
s
.678 .847 .902 r
.42964 .08012 m
.42964 .20844 L
.43014 .20844 L
.43014 .08012 L
F
.2 .63 .79 r
.42964 .08012 m
.42964 .20844 L
.43014 .20844 L
.43014 .08012 L
s
.678 .847 .902 r
.43014 .08012 m
.43014 .20768 L
.43151 .20768 L
.43151 .08012 L
F
.2 .63 .79 r
.43014 .08012 m
.43014 .20768 L
.43151 .20768 L
.43151 .08012 L
s
.678 .847 .902 r
.43151 .08012 m
.43151 .20697 L
.43227 .20697 L
.43227 .08012 L
F
.2 .63 .79 r
.43151 .08012 m
.43151 .20697 L
.43227 .20697 L
.43227 .08012 L
s
.678 .847 .902 r
.43227 .08012 m
.43227 .20656 L
.43274 .20656 L
.43274 .08012 L
F
.2 .63 .79 r
.43227 .08012 m
.43227 .20656 L
.43274 .20656 L
.43274 .08012 L
s
.678 .847 .902 r
.43274 .08012 m
.43274 .20594 L
.43399 .20594 L
.43399 .08012 L
F
.2 .63 .79 r
.43274 .08012 m
.43274 .20594 L
.43399 .20594 L
.43399 .08012 L
s
.678 .847 .902 r
.43399 .08012 m
.43399 .2054 L
.43492 .2054 L
.43492 .08012 L
F
.2 .63 .79 r
.43399 .08012 m
.43399 .2054 L
.43492 .2054 L
.43492 .08012 L
s
.678 .847 .902 r
.43492 .08012 m
.43492 .20483 L
.43558 .20483 L
.43558 .08012 L
F
.2 .63 .79 r
.43492 .08012 m
.43492 .20483 L
.43558 .20483 L
.43558 .08012 L
s
.678 .847 .902 r
.43558 .08012 m
.43558 .20431 L
.4369 .20431 L
.4369 .08012 L
F
.2 .63 .79 r
.43558 .08012 m
.43558 .20431 L
.4369 .20431 L
.4369 .08012 L
s
.678 .847 .902 r
.4369 .08012 m
.4369 .20314 L
.43738 .20314 L
.43738 .08012 L
F
.2 .63 .79 r
.4369 .08012 m
.4369 .20314 L
.43738 .20314 L
.43738 .08012 L
s
.678 .847 .902 r
.43738 .08012 m
.43738 .20302 L
.43848 .20302 L
.43848 .08012 L
F
.2 .63 .79 r
.43738 .08012 m
.43738 .20302 L
.43848 .20302 L
.43848 .08012 L
s
.678 .847 .902 r
.43848 .08012 m
.43848 .2017 L
.43984 .2017 L
.43984 .08012 L
F
.2 .63 .79 r
.43848 .08012 m
.43848 .2017 L
.43984 .2017 L
.43984 .08012 L
s
.678 .847 .902 r
.43984 .08012 m
.43984 .20117 L
.44056 .20117 L
.44056 .08012 L
F
.2 .63 .79 r
.43984 .08012 m
.43984 .20117 L
.44056 .20117 L
.44056 .08012 L
s
.678 .847 .902 r
.44056 .08012 m
.44056 .20033 L
.44164 .20033 L
.44164 .08012 L
F
.2 .63 .79 r
.44056 .08012 m
.44056 .20033 L
.44164 .20033 L
.44164 .08012 L
s
.678 .847 .902 r
.44164 .08012 m
.44164 .19983 L
.44232 .19983 L
.44232 .08012 L
F
.2 .63 .79 r
.44164 .08012 m
.44164 .19983 L
.44232 .19983 L
.44232 .08012 L
s
.678 .847 .902 r
.44232 .08012 m
.44232 .19924 L
.44317 .19924 L
.44317 .08012 L
F
.2 .63 .79 r
.44232 .08012 m
.44232 .19924 L
.44317 .19924 L
.44317 .08012 L
s
.678 .847 .902 r
.44317 .08012 m
.44317 .19886 L
.44375 .19886 L
.44375 .08012 L
F
.2 .63 .79 r
.44317 .08012 m
.44317 .19886 L
.44375 .19886 L
.44375 .08012 L
s
.678 .847 .902 r
.44375 .08012 m
.44375 .19832 L
.44461 .19832 L
.44461 .08012 L
F
.2 .63 .79 r
.44375 .08012 m
.44375 .19832 L
.44461 .19832 L
.44461 .08012 L
s
.678 .847 .902 r
.44461 .08012 m
.44461 .19774 L
.44587 .19774 L
.44587 .08012 L
F
.2 .63 .79 r
.44461 .08012 m
.44461 .19774 L
.44587 .19774 L
.44587 .08012 L
s
.678 .847 .902 r
.44587 .08012 m
.44587 .19708 L
.44703 .19708 L
.44703 .08012 L
F
.2 .63 .79 r
.44587 .08012 m
.44587 .19708 L
.44703 .19708 L
.44703 .08012 L
s
.678 .847 .902 r
.44703 .08012 m
.44703 .19637 L
.44758 .19637 L
.44758 .08012 L
F
.2 .63 .79 r
.44703 .08012 m
.44703 .19637 L
.44758 .19637 L
.44758 .08012 L
s
.678 .847 .902 r
.44758 .08012 m
.44758 .19568 L
.44819 .19568 L
.44819 .08012 L
F
.2 .63 .79 r
.44758 .08012 m
.44758 .19568 L
.44819 .19568 L
.44819 .08012 L
s
.678 .847 .902 r
.44819 .08012 m
.44819 .19512 L
.44903 .19512 L
.44903 .08012 L
F
.2 .63 .79 r
.44819 .08012 m
.44819 .19512 L
.44903 .19512 L
.44903 .08012 L
s
.678 .847 .902 r
.44903 .08012 m
.44903 .19476 L
.45015 .19476 L
.45015 .08012 L
F
.2 .63 .79 r
.44903 .08012 m
.44903 .19476 L
.45015 .19476 L
.45015 .08012 L
s
.678 .847 .902 r
.45015 .08012 m
.45015 .19428 L
.45089 .19428 L
.45089 .08012 L
F
.2 .63 .79 r
.45015 .08012 m
.45015 .19428 L
.45089 .19428 L
.45089 .08012 L
s
.678 .847 .902 r
.45089 .08012 m
.45089 .19358 L
.45143 .19358 L
.45143 .08012 L
F
.2 .63 .79 r
.45089 .08012 m
.45089 .19358 L
.45143 .19358 L
.45143 .08012 L
s
.678 .847 .902 r
.45143 .08012 m
.45143 .1932 L
.45237 .1932 L
.45237 .08012 L
F
.2 .63 .79 r
.45143 .08012 m
.45143 .1932 L
.45237 .1932 L
.45237 .08012 L
s
.678 .847 .902 r
.45237 .08012 m
.45237 .19231 L
.45315 .19231 L
.45315 .08012 L
F
.2 .63 .79 r
.45237 .08012 m
.45237 .19231 L
.45315 .19231 L
.45315 .08012 L
s
.678 .847 .902 r
.45315 .08012 m
.45315 .19196 L
.45386 .19196 L
.45386 .08012 L
F
.2 .63 .79 r
.45315 .08012 m
.45315 .19196 L
.45386 .19196 L
.45386 .08012 L
s
.678 .847 .902 r
.45386 .08012 m
.45386 .19174 L
.45462 .19174 L
.45462 .08012 L
F
.2 .63 .79 r
.45386 .08012 m
.45386 .19174 L
.45462 .19174 L
.45462 .08012 L
s
.678 .847 .902 r
.45462 .08012 m
.45462 .19119 L
.45506 .19119 L
.45506 .08012 L
F
.2 .63 .79 r
.45462 .08012 m
.45462 .19119 L
.45506 .19119 L
.45506 .08012 L
s
.678 .847 .902 r
.45506 .08012 m
.45506 .19063 L
.45562 .19063 L
.45562 .08012 L
F
.2 .63 .79 r
.45506 .08012 m
.45506 .19063 L
.45562 .19063 L
.45562 .08012 L
s
.678 .847 .902 r
.45562 .08012 m
.45562 .19028 L
.45646 .19028 L
.45646 .08012 L
F
.2 .63 .79 r
.45562 .08012 m
.45562 .19028 L
.45646 .19028 L
.45646 .08012 L
s
.678 .847 .902 r
.45646 .08012 m
.45646 .18994 L
.45717 .18994 L
.45717 .08012 L
F
.2 .63 .79 r
.45646 .08012 m
.45646 .18994 L
.45717 .18994 L
.45717 .08012 L
s
.678 .847 .902 r
.45717 .08012 m
.45717 .18949 L
.45797 .18949 L
.45797 .08012 L
F
.2 .63 .79 r
.45717 .08012 m
.45717 .18949 L
.45797 .18949 L
.45797 .08012 L
s
.678 .847 .902 r
.45797 .08012 m
.45797 .18891 L
.45863 .18891 L
.45863 .08012 L
F
.2 .63 .79 r
.45797 .08012 m
.45797 .18891 L
.45863 .18891 L
.45863 .08012 L
s
.678 .847 .902 r
.45863 .08012 m
.45863 .18852 L
.45919 .18852 L
.45919 .08012 L
F
.2 .63 .79 r
.45863 .08012 m
.45863 .18852 L
.45919 .18852 L
.45919 .08012 L
s
.678 .847 .902 r
.45919 .08012 m
.45919 .18789 L
.46027 .18789 L
.46027 .08012 L
F
.2 .63 .79 r
.45919 .08012 m
.45919 .18789 L
.46027 .18789 L
.46027 .08012 L
s
.678 .847 .902 r
.46027 .08012 m
.46027 .18729 L
.46083 .18729 L
.46083 .08012 L
F
.2 .63 .79 r
.46027 .08012 m
.46027 .18729 L
.46083 .18729 L
.46083 .08012 L
s
.678 .847 .902 r
.46083 .08012 m
.46083 .18669 L
.46209 .18669 L
.46209 .08012 L
F
.2 .63 .79 r
.46083 .08012 m
.46083 .18669 L
.46209 .18669 L
.46209 .08012 L
s
.678 .847 .902 r
.46209 .08012 m
.46209 .18573 L
.46353 .18573 L
.46353 .08012 L
F
.2 .63 .79 r
.46209 .08012 m
.46209 .18573 L
.46353 .18573 L
.46353 .08012 L
s
.678 .847 .902 r
.46353 .08012 m
.46353 .18493 L
.46419 .18493 L
.46419 .08012 L
F
.2 .63 .79 r
.46353 .08012 m
.46353 .18493 L
.46419 .18493 L
.46419 .08012 L
s
.678 .847 .902 r
.46419 .08012 m
.46419 .18483 L
.46494 .18483 L
.46494 .08012 L
F
.2 .63 .79 r
.46419 .08012 m
.46419 .18483 L
.46494 .18483 L
.46494 .08012 L
s
.678 .847 .902 r
.46494 .08012 m
.46494 .18423 L
.46548 .18423 L
.46548 .08012 L
F
.2 .63 .79 r
.46494 .08012 m
.46494 .18423 L
.46548 .18423 L
.46548 .08012 L
s
.678 .847 .902 r
.46548 .08012 m
.46548 .18364 L
.46681 .18364 L
.46681 .08012 L
F
.2 .63 .79 r
.46548 .08012 m
.46548 .18364 L
.46681 .18364 L
.46681 .08012 L
s
.678 .847 .902 r
.46681 .08012 m
.46681 .18281 L
.4673 .18281 L
.4673 .08012 L
F
.2 .63 .79 r
.46681 .08012 m
.46681 .18281 L
.4673 .18281 L
.4673 .08012 L
s
.678 .847 .902 r
.4673 .08012 m
.4673 .18266 L
.46866 .18266 L
.46866 .08012 L
F
.2 .63 .79 r
.4673 .08012 m
.4673 .18266 L
.46866 .18266 L
.46866 .08012 L
s
.678 .847 .902 r
.46866 .08012 m
.46866 .18135 L
.46955 .18135 L
.46955 .08012 L
F
.2 .63 .79 r
.46866 .08012 m
.46866 .18135 L
.46955 .18135 L
.46955 .08012 L
s
.678 .847 .902 r
.46955 .08012 m
.46955 .18105 L
.47057 .18105 L
.47057 .08012 L
F
.2 .63 .79 r
.46955 .08012 m
.46955 .18105 L
.47057 .18105 L
.47057 .08012 L
s
.678 .847 .902 r
.47057 .08012 m
.47057 .18029 L
.47197 .18029 L
.47197 .08012 L
F
.2 .63 .79 r
.47057 .08012 m
.47057 .18029 L
.47197 .18029 L
.47197 .08012 L
s
.678 .847 .902 r
.47197 .08012 m
.47197 .17925 L
.47283 .17925 L
.47283 .08012 L
F
.2 .63 .79 r
.47197 .08012 m
.47197 .17925 L
.47283 .17925 L
.47283 .08012 L
s
.678 .847 .902 r
.47283 .08012 m
.47283 .17913 L
.47337 .17913 L
.47337 .08012 L
F
.2 .63 .79 r
.47283 .08012 m
.47283 .17913 L
.47337 .17913 L
.47337 .08012 L
s
.678 .847 .902 r
.47337 .08012 m
.47337 .17841 L
.47412 .17841 L
.47412 .08012 L
F
.2 .63 .79 r
.47337 .08012 m
.47337 .17841 L
.47412 .17841 L
.47412 .08012 L
s
.678 .847 .902 r
.47412 .08012 m
.47412 .17808 L
.4752 .17808 L
.4752 .08012 L
F
.2 .63 .79 r
.47412 .08012 m
.47412 .17808 L
.4752 .17808 L
.4752 .08012 L
s
.678 .847 .902 r
.4752 .08012 m
.4752 .17726 L
.47606 .17726 L
.47606 .08012 L
F
.2 .63 .79 r
.4752 .08012 m
.4752 .17726 L
.47606 .17726 L
.47606 .08012 L
s
.678 .847 .902 r
.47606 .08012 m
.47606 .17689 L
.4775 .17689 L
.4775 .08012 L
F
.2 .63 .79 r
.47606 .08012 m
.47606 .17689 L
.4775 .17689 L
.4775 .08012 L
s
.678 .847 .902 r
.4775 .08012 m
.4775 .17588 L
.47886 .17588 L
.47886 .08012 L
F
.2 .63 .79 r
.4775 .08012 m
.4775 .17588 L
.47886 .17588 L
.47886 .08012 L
s
.678 .847 .902 r
.47886 .08012 m
.47886 .17513 L
.47967 .17513 L
.47967 .08012 L
F
.2 .63 .79 r
.47886 .08012 m
.47886 .17513 L
.47967 .17513 L
.47967 .08012 L
s
.678 .847 .902 r
.47967 .08012 m
.47967 .17453 L
.48017 .17453 L
.48017 .08012 L
F
.2 .63 .79 r
.47967 .08012 m
.47967 .17453 L
.48017 .17453 L
.48017 .08012 L
s
.678 .847 .902 r
.48017 .08012 m
.48017 .17362 L
.48138 .17362 L
.48138 .08012 L
F
.2 .63 .79 r
.48017 .08012 m
.48017 .17362 L
.48138 .17362 L
.48138 .08012 L
s
.678 .847 .902 r
.48138 .08012 m
.48138 .17346 L
.48262 .17346 L
.48262 .08012 L
F
.2 .63 .79 r
.48138 .08012 m
.48138 .17346 L
.48262 .17346 L
.48262 .08012 L
s
.678 .847 .902 r
.48262 .08012 m
.48262 .17221 L
.4838 .17221 L
.4838 .08012 L
F
.2 .63 .79 r
.48262 .08012 m
.48262 .17221 L
.4838 .17221 L
.4838 .08012 L
s
.678 .847 .902 r
.4838 .08012 m
.4838 .17195 L
.4852 .17195 L
.4852 .08012 L
F
.2 .63 .79 r
.4838 .08012 m
.4838 .17195 L
.4852 .17195 L
.4852 .08012 L
s
.678 .847 .902 r
.4852 .08012 m
.4852 .17069 L
.4866 .17069 L
.4866 .08012 L
F
.2 .63 .79 r
.4852 .08012 m
.4852 .17069 L
.4866 .17069 L
.4866 .08012 L
s
.678 .847 .902 r
.4866 .08012 m
.4866 .16974 L
.48786 .16974 L
.48786 .08012 L
F
.2 .63 .79 r
.4866 .08012 m
.4866 .16974 L
.48786 .16974 L
.48786 .08012 L
s
.678 .847 .902 r
.48786 .08012 m
.48786 .16946 L
.48882 .16946 L
.48882 .08012 L
F
.2 .63 .79 r
.48786 .08012 m
.48786 .16946 L
.48882 .16946 L
.48882 .08012 L
s
.678 .847 .902 r
.48882 .08012 m
.48882 .16879 L
.4899 .16879 L
.4899 .08012 L
F
.2 .63 .79 r
.48882 .08012 m
.48882 .16879 L
.4899 .16879 L
.4899 .08012 L
s
.678 .847 .902 r
.4899 .08012 m
.4899 .16798 L
.4912 .16798 L
.4912 .08012 L
F
.2 .63 .79 r
.4899 .08012 m
.4899 .16798 L
.4912 .16798 L
.4912 .08012 L
s
.678 .847 .902 r
.4912 .08012 m
.4912 .16711 L
.49258 .16711 L
.49258 .08012 L
F
.2 .63 .79 r
.4912 .08012 m
.4912 .16711 L
.49258 .16711 L
.49258 .08012 L
s
.678 .847 .902 r
.49258 .08012 m
.49258 .16641 L
.49349 .16641 L
.49349 .08012 L
F
.2 .63 .79 r
.49258 .08012 m
.49258 .16641 L
.49349 .16641 L
.49349 .08012 L
s
.678 .847 .902 r
.49349 .08012 m
.49349 .1652 L
.49467 .1652 L
.49467 .08012 L
F
.2 .63 .79 r
.49349 .08012 m
.49349 .1652 L
.49467 .1652 L
.49467 .08012 L
s
.678 .847 .902 r
.49467 .08012 m
.49467 .165 L
.49553 .165 L
.49553 .08012 L
F
.2 .63 .79 r
.49467 .08012 m
.49467 .165 L
.49553 .165 L
.49553 .08012 L
s
.678 .847 .902 r
.49553 .08012 m
.49553 .16419 L
.49631 .16419 L
.49631 .08012 L
F
.2 .63 .79 r
.49553 .08012 m
.49553 .16419 L
.49631 .16419 L
.49631 .08012 L
s
.678 .847 .902 r
.49631 .08012 m
.49631 .16368 L
.49729 .16368 L
.49729 .08012 L
F
.2 .63 .79 r
.49631 .08012 m
.49631 .16368 L
.49729 .16368 L
.49729 .08012 L
s
.678 .847 .902 r
.49729 .08012 m
.49729 .16347 L
.49803 .16347 L
.49803 .08012 L
F
.2 .63 .79 r
.49729 .08012 m
.49729 .16347 L
.49803 .16347 L
.49803 .08012 L
s
.678 .847 .902 r
.49803 .08012 m
.49803 .16293 L
.49879 .16293 L
.49879 .08012 L
F
.2 .63 .79 r
.49803 .08012 m
.49803 .16293 L
.49879 .16293 L
.49879 .08012 L
s
.678 .847 .902 r
.49879 .08012 m
.49879 .16256 L
.49926 .16256 L
.49926 .08012 L
F
.2 .63 .79 r
.49879 .08012 m
.49879 .16256 L
.49926 .16256 L
.49926 .08012 L
s
.678 .847 .902 r
.49926 .08012 m
.49926 .16193 L
.50061 .16193 L
.50061 .08012 L
F
.2 .63 .79 r
.49926 .08012 m
.49926 .16193 L
.50061 .16193 L
.50061 .08012 L
s
.678 .847 .902 r
.50061 .08012 m
.50061 .161 L
.50195 .161 L
.50195 .08012 L
F
.2 .63 .79 r
.50061 .08012 m
.50061 .161 L
.50195 .161 L
.50195 .08012 L
s
.678 .847 .902 r
.50195 .08012 m
.50195 .16058 L
.50273 .16058 L
.50273 .08012 L
F
.2 .63 .79 r
.50195 .08012 m
.50195 .16058 L
.50273 .16058 L
.50273 .08012 L
s
.678 .847 .902 r
.50273 .08012 m
.50273 .15986 L
.5033 .15986 L
.5033 .08012 L
F
.2 .63 .79 r
.50273 .08012 m
.50273 .15986 L
.5033 .15986 L
.5033 .08012 L
s
.678 .847 .902 r
.5033 .08012 m
.5033 .15965 L
.50428 .15965 L
.50428 .08012 L
F
.2 .63 .79 r
.5033 .08012 m
.5033 .15965 L
.50428 .15965 L
.50428 .08012 L
s
.678 .847 .902 r
.50428 .08012 m
.50428 .15918 L
.50556 .15918 L
.50556 .08012 L
F
.2 .63 .79 r
.50428 .08012 m
.50428 .15918 L
.50556 .15918 L
.50556 .08012 L
s
.678 .847 .902 r
.50556 .08012 m
.50556 .15833 L
.50658 .15833 L
.50658 .08012 L
F
.2 .63 .79 r
.50556 .08012 m
.50556 .15833 L
.50658 .15833 L
.50658 .08012 L
s
.678 .847 .902 r
.50658 .08012 m
.50658 .15747 L
.50736 .15747 L
.50736 .08012 L
F
.2 .63 .79 r
.50658 .08012 m
.50658 .15747 L
.50736 .15747 L
.50736 .08012 L
s
.678 .847 .902 r
.50736 .08012 m
.50736 .15695 L
.50862 .15695 L
.50862 .08012 L
F
.2 .63 .79 r
.50736 .08012 m
.50736 .15695 L
.50862 .15695 L
.50862 .08012 L
s
.678 .847 .902 r
.50862 .08012 m
.50862 .15581 L
.50995 .15581 L
.50995 .08012 L
F
.2 .63 .79 r
.50862 .08012 m
.50862 .15581 L
.50995 .15581 L
.50995 .08012 L
s
.678 .847 .902 r
.50995 .08012 m
.50995 .15534 L
.51102 .15534 L
.51102 .08012 L
F
.2 .63 .79 r
.50995 .08012 m
.50995 .15534 L
.51102 .15534 L
.51102 .08012 L
s
.678 .847 .902 r
.51102 .08012 m
.51102 .15507 L
.51201 .15507 L
.51201 .08012 L
F
.2 .63 .79 r
.51102 .08012 m
.51102 .15507 L
.51201 .15507 L
.51201 .08012 L
s
.678 .847 .902 r
.51201 .08012 m
.51201 .15431 L
.51274 .15431 L
.51274 .08012 L
F
.2 .63 .79 r
.51201 .08012 m
.51201 .15431 L
.51274 .15431 L
.51274 .08012 L
s
.678 .847 .902 r
.51274 .08012 m
.51274 .15374 L
.51344 .15374 L
.51344 .08012 L
F
.2 .63 .79 r
.51274 .08012 m
.51274 .15374 L
.51344 .15374 L
.51344 .08012 L
s
.678 .847 .902 r
.51344 .08012 m
.51344 .15336 L
.51466 .15336 L
.51466 .08012 L
F
.2 .63 .79 r
.51344 .08012 m
.51344 .15336 L
.51466 .15336 L
.51466 .08012 L
s
.678 .847 .902 r
.51466 .08012 m
.51466 .15242 L
.51573 .15242 L
.51573 .08012 L
F
.2 .63 .79 r
.51466 .08012 m
.51466 .15242 L
.51573 .15242 L
.51573 .08012 L
s
.678 .847 .902 r
.51573 .08012 m
.51573 .15202 L
.517 .15202 L
.517 .08012 L
F
.2 .63 .79 r
.51573 .08012 m
.51573 .15202 L
.517 .15202 L
.517 .08012 L
s
.678 .847 .902 r
.517 .08012 m
.517 .15103 L
.51797 .15103 L
.51797 .08012 L
F
.2 .63 .79 r
.517 .08012 m
.517 .15103 L
.51797 .15103 L
.51797 .08012 L
s
.678 .847 .902 r
.51797 .08012 m
.51797 .15092 L
.51877 .15092 L
.51877 .08012 L
F
.2 .63 .79 r
.51797 .08012 m
.51797 .15092 L
.51877 .15092 L
.51877 .08012 L
s
.678 .847 .902 r
.51877 .08012 m
.51877 .15011 L
.51949 .15011 L
.51949 .08012 L
F
.2 .63 .79 r
.51877 .08012 m
.51877 .15011 L
.51949 .15011 L
.51949 .08012 L
s
.678 .847 .902 r
.51949 .08012 m
.51949 .1498 L
.52023 .1498 L
.52023 .08012 L
F
.2 .63 .79 r
.51949 .08012 m
.51949 .1498 L
.52023 .1498 L
.52023 .08012 L
s
.678 .847 .902 r
.52023 .08012 m
.52023 .14935 L
.52089 .14935 L
.52089 .08012 L
F
.2 .63 .79 r
.52023 .08012 m
.52023 .14935 L
.52089 .14935 L
.52089 .08012 L
s
.678 .847 .902 r
.52089 .08012 m
.52089 .14901 L
.52138 .14901 L
.52138 .08012 L
F
.2 .63 .79 r
.52089 .08012 m
.52089 .14901 L
.52138 .14901 L
.52138 .08012 L
s
.678 .847 .902 r
.52138 .08012 m
.52138 .14867 L
.52206 .14867 L
.52206 .08012 L
F
.2 .63 .79 r
.52138 .08012 m
.52138 .14867 L
.52206 .14867 L
.52206 .08012 L
s
.678 .847 .902 r
.52206 .08012 m
.52206 .14848 L
.5229 .14848 L
.5229 .08012 L
F
.2 .63 .79 r
.52206 .08012 m
.52206 .14848 L
.5229 .14848 L
.5229 .08012 L
s
.678 .847 .902 r
.5229 .08012 m
.5229 .14799 L
.52368 .14799 L
.52368 .08012 L
F
.2 .63 .79 r
.5229 .08012 m
.5229 .14799 L
.52368 .14799 L
.52368 .08012 L
s
.678 .847 .902 r
.52368 .08012 m
.52368 .14718 L
.52484 .14718 L
.52484 .08012 L
F
.2 .63 .79 r
.52368 .08012 m
.52368 .14718 L
.52484 .14718 L
.52484 .08012 L
s
.678 .847 .902 r
.52484 .08012 m
.52484 .14666 L
.52539 .14666 L
.52539 .08012 L
F
.2 .63 .79 r
.52484 .08012 m
.52484 .14666 L
.52539 .14666 L
.52539 .08012 L
s
.678 .847 .902 r
.52539 .08012 m
.52539 .14595 L
.52672 .14595 L
.52672 .08012 L
F
.2 .63 .79 r
.52539 .08012 m
.52539 .14595 L
.52672 .14595 L
.52672 .08012 L
s
.678 .847 .902 r
.52672 .08012 m
.52672 .14578 L
.52767 .14578 L
.52767 .08012 L
F
.2 .63 .79 r
.52672 .08012 m
.52672 .14578 L
.52767 .14578 L
.52767 .08012 L
s
.678 .847 .902 r
.52767 .08012 m
.52767 .14513 L
.52825 .14513 L
.52825 .08012 L
F
.2 .63 .79 r
.52767 .08012 m
.52767 .14513 L
.52825 .14513 L
.52825 .08012 L
s
.678 .847 .902 r
.52825 .08012 m
.52825 .14491 L
.52947 .14491 L
.52947 .08012 L
F
.2 .63 .79 r
.52825 .08012 m
.52825 .14491 L
.52947 .14491 L
.52947 .08012 L
s
.678 .847 .902 r
.52947 .08012 m
.52947 .14413 L
.52997 .14413 L
.52997 .08012 L
F
.2 .63 .79 r
.52947 .08012 m
.52947 .14413 L
.52997 .14413 L
.52997 .08012 L
s
.678 .847 .902 r
.52997 .08012 m
.52997 .14386 L
.53104 .14386 L
.53104 .08012 L
F
.2 .63 .79 r
.52997 .08012 m
.52997 .14386 L
.53104 .14386 L
.53104 .08012 L
s
.678 .847 .902 r
.53104 .08012 m
.53104 .1429 L
.53201 .1429 L
.53201 .08012 L
F
.2 .63 .79 r
.53104 .08012 m
.53104 .1429 L
.53201 .1429 L
.53201 .08012 L
s
.678 .847 .902 r
.53201 .08012 m
.53201 .14239 L
.53268 .14239 L
.53268 .08012 L
F
.2 .63 .79 r
.53201 .08012 m
.53201 .14239 L
.53268 .14239 L
.53268 .08012 L
s
.678 .847 .902 r
.53268 .08012 m
.53268 .1418 L
.53391 .1418 L
.53391 .08012 L
F
.2 .63 .79 r
.53268 .08012 m
.53268 .1418 L
.53391 .1418 L
.53391 .08012 L
s
.678 .847 .902 r
.53391 .08012 m
.53391 .14154 L
.53473 .14154 L
.53473 .08012 L
F
.2 .63 .79 r
.53391 .08012 m
.53391 .14154 L
.53473 .14154 L
.53473 .08012 L
s
.678 .847 .902 r
.53473 .08012 m
.53473 .14099 L
.53593 .14099 L
.53593 .08012 L
F
.2 .63 .79 r
.53473 .08012 m
.53473 .14099 L
.53593 .14099 L
.53593 .08012 L
s
.678 .847 .902 r
.53593 .08012 m
.53593 .14043 L
.53698 .14043 L
.53698 .08012 L
F
.2 .63 .79 r
.53593 .08012 m
.53593 .14043 L
.53698 .14043 L
.53698 .08012 L
s
.678 .847 .902 r
.53698 .08012 m
.53698 .13956 L
.5384 .13956 L
.5384 .08012 L
F
.2 .63 .79 r
.53698 .08012 m
.53698 .13956 L
.5384 .13956 L
.5384 .08012 L
s
.678 .847 .902 r
.5384 .08012 m
.5384 .13884 L
.5397 .13884 L
.5397 .08012 L
F
.2 .63 .79 r
.5384 .08012 m
.5384 .13884 L
.5397 .13884 L
.5397 .08012 L
s
.678 .847 .902 r
.5397 .08012 m
.5397 .13826 L
.54053 .13826 L
.54053 .08012 L
F
.2 .63 .79 r
.5397 .08012 m
.5397 .13826 L
.54053 .13826 L
.54053 .08012 L
s
.678 .847 .902 r
.54053 .08012 m
.54053 .13778 L
.54131 .13778 L
.54131 .08012 L
F
.2 .63 .79 r
.54053 .08012 m
.54053 .13778 L
.54131 .13778 L
.54131 .08012 L
s
.678 .847 .902 r
.54131 .08012 m
.54131 .13693 L
.54243 .13693 L
.54243 .08012 L
F
.2 .63 .79 r
.54131 .08012 m
.54131 .13693 L
.54243 .13693 L
.54243 .08012 L
s
.678 .847 .902 r
.54243 .08012 m
.54243 .13644 L
.54349 .13644 L
.54349 .08012 L
F
.2 .63 .79 r
.54243 .08012 m
.54243 .13644 L
.54349 .13644 L
.54349 .08012 L
s
.678 .847 .902 r
.54349 .08012 m
.54349 .13603 L
.54428 .13603 L
.54428 .08012 L
F
.2 .63 .79 r
.54349 .08012 m
.54349 .13603 L
.54428 .13603 L
.54428 .08012 L
s
.678 .847 .902 r
.54428 .08012 m
.54428 .13562 L
.54481 .13562 L
.54481 .08012 L
F
.2 .63 .79 r
.54428 .08012 m
.54428 .13562 L
.54481 .13562 L
.54481 .08012 L
s
.678 .847 .902 r
.54481 .08012 m
.54481 .1352 L
.54552 .1352 L
.54552 .08012 L
F
.2 .63 .79 r
.54481 .08012 m
.54481 .1352 L
.54552 .1352 L
.54552 .08012 L
s
.678 .847 .902 r
.54552 .08012 m
.54552 .13488 L
.54625 .13488 L
.54625 .08012 L
F
.2 .63 .79 r
.54552 .08012 m
.54552 .13488 L
.54625 .13488 L
.54625 .08012 L
s
.678 .847 .902 r
.54625 .08012 m
.54625 .13418 L
.54733 .13418 L
.54733 .08012 L
F
.2 .63 .79 r
.54625 .08012 m
.54625 .13418 L
.54733 .13418 L
.54733 .08012 L
s
.678 .847 .902 r
.54733 .08012 m
.54733 .13348 L
.54877 .13348 L
.54877 .08012 L
F
.2 .63 .79 r
.54733 .08012 m
.54733 .13348 L
.54877 .13348 L
.54877 .08012 L
s
.678 .847 .902 r
.54877 .08012 m
.54877 .13287 L
.54961 .13287 L
.54961 .08012 L
F
.2 .63 .79 r
.54877 .08012 m
.54877 .13287 L
.54961 .13287 L
.54961 .08012 L
s
.678 .847 .902 r
.54961 .08012 m
.54961 .13251 L
.55085 .13251 L
.55085 .08012 L
F
.2 .63 .79 r
.54961 .08012 m
.54961 .13251 L
.55085 .13251 L
.55085 .08012 L
s
.678 .847 .902 r
.55085 .08012 m
.55085 .13191 L
.55178 .13191 L
.55178 .08012 L
F
.2 .63 .79 r
.55085 .08012 m
.55085 .13191 L
.55178 .13191 L
.55178 .08012 L
s
.678 .847 .902 r
.55178 .08012 m
.55178 .13135 L
.55244 .13135 L
.55244 .08012 L
F
.2 .63 .79 r
.55178 .08012 m
.55178 .13135 L
.55244 .13135 L
.55244 .08012 L
s
.678 .847 .902 r
.55244 .08012 m
.55244 .13101 L
.55321 .13101 L
.55321 .08012 L
F
.2 .63 .79 r
.55244 .08012 m
.55244 .13101 L
.55321 .13101 L
.55321 .08012 L
s
.678 .847 .902 r
.55321 .08012 m
.55321 .13071 L
.55381 .13071 L
.55381 .08012 L
F
.2 .63 .79 r
.55321 .08012 m
.55321 .13071 L
.55381 .13071 L
.55381 .08012 L
s
.678 .847 .902 r
.55381 .08012 m
.55381 .12997 L
.55524 .12997 L
.55524 .08012 L
F
.2 .63 .79 r
.55381 .08012 m
.55381 .12997 L
.55524 .12997 L
.55524 .08012 L
s
.678 .847 .902 r
.55524 .08012 m
.55524 .12909 L
.55668 .12909 L
.55668 .08012 L
F
.2 .63 .79 r
.55524 .08012 m
.55524 .12909 L
.55668 .12909 L
.55668 .08012 L
s
.678 .847 .902 r
.55668 .08012 m
.55668 .12852 L
.55768 .12852 L
.55768 .08012 L
F
.2 .63 .79 r
.55668 .08012 m
.55668 .12852 L
.55768 .12852 L
.55768 .08012 L
s
.678 .847 .902 r
.55768 .08012 m
.55768 .12833 L
.55892 .12833 L
.55892 .08012 L
F
.2 .63 .79 r
.55768 .08012 m
.55768 .12833 L
.55892 .12833 L
.55892 .08012 L
s
.678 .847 .902 r
.55892 .08012 m
.55892 .12757 L
.55958 .12757 L
.55958 .08012 L
F
.2 .63 .79 r
.55892 .08012 m
.55892 .12757 L
.55958 .12757 L
.55958 .08012 L
s
.678 .847 .902 r
.55958 .08012 m
.55958 .12705 L
.56041 .12705 L
.56041 .08012 L
F
.2 .63 .79 r
.55958 .08012 m
.55958 .12705 L
.56041 .12705 L
.56041 .08012 L
s
.678 .847 .902 r
.56041 .08012 m
.56041 .12672 L
.56144 .12672 L
.56144 .08012 L
F
.2 .63 .79 r
.56041 .08012 m
.56041 .12672 L
.56144 .12672 L
.56144 .08012 L
s
.678 .847 .902 r
.56144 .08012 m
.56144 .1258 L
.56284 .1258 L
.56284 .08012 L
F
.2 .63 .79 r
.56144 .08012 m
.56144 .1258 L
.56284 .1258 L
.56284 .08012 L
s
.678 .847 .902 r
.56284 .08012 m
.56284 .12546 L
.56413 .12546 L
.56413 .08012 L
F
.2 .63 .79 r
.56284 .08012 m
.56284 .12546 L
.56413 .12546 L
.56413 .08012 L
s
.678 .847 .902 r
.56413 .08012 m
.56413 .12479 L
.56461 .12479 L
.56461 .08012 L
F
.2 .63 .79 r
.56413 .08012 m
.56413 .12479 L
.56461 .12479 L
.56461 .08012 L
s
.678 .847 .902 r
.56461 .08012 m
.56461 .12426 L
.56599 .12426 L
.56599 .08012 L
F
.2 .63 .79 r
.56461 .08012 m
.56461 .12426 L
.56599 .12426 L
.56599 .08012 L
s
.678 .847 .902 r
.56599 .08012 m
.56599 .12387 L
.56676 .12387 L
.56676 .08012 L
F
.2 .63 .79 r
.56599 .08012 m
.56599 .12387 L
.56676 .12387 L
.56676 .08012 L
s
.678 .847 .902 r
.56676 .08012 m
.56676 .12312 L
.56769 .12312 L
.56769 .08012 L
F
.2 .63 .79 r
.56676 .08012 m
.56676 .12312 L
.56769 .12312 L
.56769 .08012 L
s
.678 .847 .902 r
.56769 .08012 m
.56769 .12232 L
.5691 .12232 L
.5691 .08012 L
F
.2 .63 .79 r
.56769 .08012 m
.56769 .12232 L
.5691 .12232 L
.5691 .08012 L
s
.678 .847 .902 r
.5691 .08012 m
.5691 .12177 L
.5702 .12177 L
.5702 .08012 L
F
.2 .63 .79 r
.5691 .08012 m
.5691 .12177 L
.5702 .12177 L
.5702 .08012 L
s
.678 .847 .902 r
.5702 .08012 m
.5702 .12153 L
.57068 .12153 L
.57068 .08012 L
F
.2 .63 .79 r
.5702 .08012 m
.5702 .12153 L
.57068 .12153 L
.57068 .08012 L
s
.678 .847 .902 r
.57068 .08012 m
.57068 .12076 L
.57198 .12076 L
.57198 .08012 L
F
.2 .63 .79 r
.57068 .08012 m
.57068 .12076 L
.57198 .12076 L
.57198 .08012 L
s
.678 .847 .902 r
.57198 .08012 m
.57198 .1206 L
.57342 .1206 L
.57342 .08012 L
F
.2 .63 .79 r
.57198 .08012 m
.57198 .1206 L
.57342 .1206 L
.57342 .08012 L
s
.678 .847 .902 r
.57342 .08012 m
.57342 .11963 L
.57411 .11963 L
.57411 .08012 L
F
.2 .63 .79 r
.57342 .08012 m
.57342 .11963 L
.57411 .11963 L
.57411 .08012 L
s
.678 .847 .902 r
.57411 .08012 m
.57411 .11956 L
.57481 .11956 L
.57481 .08012 L
F
.2 .63 .79 r
.57411 .08012 m
.57411 .11956 L
.57481 .11956 L
.57481 .08012 L
s
.678 .847 .902 r
.57481 .08012 m
.57481 .11902 L
.57562 .11902 L
.57562 .08012 L
F
.2 .63 .79 r
.57481 .08012 m
.57481 .11902 L
.57562 .11902 L
.57562 .08012 L
s
.678 .847 .902 r
.57562 .08012 m
.57562 .11854 L
.57684 .11854 L
.57684 .08012 L
F
.2 .63 .79 r
.57562 .08012 m
.57562 .11854 L
.57684 .11854 L
.57684 .08012 L
s
.678 .847 .902 r
.57684 .08012 m
.57684 .11789 L
.57821 .11789 L
.57821 .08012 L
F
.2 .63 .79 r
.57684 .08012 m
.57684 .11789 L
.57821 .11789 L
.57821 .08012 L
s
.678 .847 .902 r
.57821 .08012 m
.57821 .11726 L
.57874 .11726 L
.57874 .08012 L
F
.2 .63 .79 r
.57821 .08012 m
.57821 .11726 L
.57874 .11726 L
.57874 .08012 L
s
.678 .847 .902 r
.57874 .08012 m
.57874 .11683 L
.57958 .11683 L
.57958 .08012 L
F
.2 .63 .79 r
.57874 .08012 m
.57874 .11683 L
.57958 .11683 L
.57958 .08012 L
s
.678 .847 .902 r
.57958 .08012 m
.57958 .11635 L
.58081 .11635 L
.58081 .08012 L
F
.2 .63 .79 r
.57958 .08012 m
.57958 .11635 L
.58081 .11635 L
.58081 .08012 L
s
.678 .847 .902 r
.58081 .08012 m
.58081 .11587 L
.58162 .11587 L
.58162 .08012 L
F
.2 .63 .79 r
.58081 .08012 m
.58081 .11587 L
.58162 .11587 L
.58162 .08012 L
s
.678 .847 .902 r
.58162 .08012 m
.58162 .11543 L
.58237 .11543 L
.58237 .08012 L
F
.2 .63 .79 r
.58162 .08012 m
.58162 .11543 L
.58237 .11543 L
.58237 .08012 L
s
.678 .847 .902 r
.58237 .08012 m
.58237 .11519 L
.58299 .11519 L
.58299 .08012 L
F
.2 .63 .79 r
.58237 .08012 m
.58237 .11519 L
.58299 .11519 L
.58299 .08012 L
s
.678 .847 .902 r
.58299 .08012 m
.58299 .11504 L
.58383 .11504 L
.58383 .08012 L
F
.2 .63 .79 r
.58299 .08012 m
.58299 .11504 L
.58383 .11504 L
.58383 .08012 L
s
.678 .847 .902 r
.58383 .08012 m
.58383 .11438 L
.58506 .11438 L
.58506 .08012 L
F
.2 .63 .79 r
.58383 .08012 m
.58383 .11438 L
.58506 .11438 L
.58506 .08012 L
s
.678 .847 .902 r
.58506 .08012 m
.58506 .11395 L
.58587 .11395 L
.58587 .08012 L
F
.2 .63 .79 r
.58506 .08012 m
.58506 .11395 L
.58587 .11395 L
.58587 .08012 L
s
.678 .847 .902 r
.58587 .08012 m
.58587 .11345 L
.58665 .11345 L
.58665 .08012 L
F
.2 .63 .79 r
.58587 .08012 m
.58587 .11345 L
.58665 .11345 L
.58665 .08012 L
s
.678 .847 .902 r
.58665 .08012 m
.58665 .11295 L
.58745 .11295 L
.58745 .08012 L
F
.2 .63 .79 r
.58665 .08012 m
.58665 .11295 L
.58745 .11295 L
.58745 .08012 L
s
.678 .847 .902 r
.58745 .08012 m
.58745 .11221 L
.58876 .11221 L
.58876 .08012 L
F
.2 .63 .79 r
.58745 .08012 m
.58745 .11221 L
.58876 .11221 L
.58876 .08012 L
s
.678 .847 .902 r
.58876 .08012 m
.58876 .11189 L
.58923 .11189 L
.58923 .08012 L
F
.2 .63 .79 r
.58876 .08012 m
.58876 .11189 L
.58923 .11189 L
.58923 .08012 L
s
.678 .847 .902 r
.58923 .08012 m
.58923 .11151 L
.59055 .11151 L
.59055 .08012 L
F
.2 .63 .79 r
.58923 .08012 m
.58923 .11151 L
.59055 .11151 L
.59055 .08012 L
s
.678 .847 .902 r
.59055 .08012 m
.59055 .11095 L
.59139 .11095 L
.59139 .08012 L
F
.2 .63 .79 r
.59055 .08012 m
.59055 .11095 L
.59139 .11095 L
.59139 .08012 L
s
.678 .847 .902 r
.59139 .08012 m
.59139 .1108 L
.59204 .1108 L
.59204 .08012 L
F
.2 .63 .79 r
.59139 .08012 m
.59139 .1108 L
.59204 .1108 L
.59204 .08012 L
s
.678 .847 .902 r
.59204 .08012 m
.59204 .11021 L
.59349 .11021 L
.59349 .08012 L
F
.2 .63 .79 r
.59204 .08012 m
.59204 .11021 L
.59349 .11021 L
.59349 .08012 L
s
.678 .847 .902 r
.59349 .08012 m
.59349 .10963 L
.59393 .10963 L
.59393 .08012 L
F
.2 .63 .79 r
.59349 .08012 m
.59349 .10963 L
.59393 .10963 L
.59393 .08012 L
s
.678 .847 .902 r
.59393 .08012 m
.59393 .10934 L
.59479 .10934 L
.59479 .08012 L
F
.2 .63 .79 r
.59393 .08012 m
.59393 .10934 L
.59479 .10934 L
.59479 .08012 L
s
.678 .847 .902 r
.59479 .08012 m
.59479 .1091 L
.59621 .1091 L
.59621 .08012 L
F
.2 .63 .79 r
.59479 .08012 m
.59479 .1091 L
.59621 .1091 L
.59621 .08012 L
s
.678 .847 .902 r
.59621 .08012 m
.59621 .1083 L
.59739 .1083 L
.59739 .08012 L
F
.2 .63 .79 r
.59621 .08012 m
.59621 .1083 L
.59739 .1083 L
.59739 .08012 L
s
.678 .847 .902 r
.59739 .08012 m
.59739 .10781 L
.59848 .10781 L
.59848 .08012 L
F
.2 .63 .79 r
.59739 .08012 m
.59739 .10781 L
.59848 .10781 L
.59848 .08012 L
s
.678 .847 .902 r
.59848 .08012 m
.59848 .10729 L
.59958 .10729 L
.59958 .08012 L
F
.2 .63 .79 r
.59848 .08012 m
.59848 .10729 L
.59958 .10729 L
.59958 .08012 L
s
.678 .847 .902 r
.59958 .08012 m
.59958 .10662 L
.60007 .10662 L
.60007 .08012 L
F
.2 .63 .79 r
.59958 .08012 m
.59958 .10662 L
.60007 .10662 L
.60007 .08012 L
s
.678 .847 .902 r
.60007 .08012 m
.60007 .10635 L
.60115 .10635 L
.60115 .08012 L
F
.2 .63 .79 r
.60007 .08012 m
.60007 .10635 L
.60115 .10635 L
.60115 .08012 L
s
.678 .847 .902 r
.60115 .08012 m
.60115 .10595 L
.60184 .10595 L
.60184 .08012 L
F
.2 .63 .79 r
.60115 .08012 m
.60115 .10595 L
.60184 .10595 L
.60184 .08012 L
s
.678 .847 .902 r
.60184 .08012 m
.60184 .10546 L
.60316 .10546 L
.60316 .08012 L
F
.2 .63 .79 r
.60184 .08012 m
.60184 .10546 L
.60316 .10546 L
.60316 .08012 L
s
.678 .847 .902 r
.60316 .08012 m
.60316 .10454 L
.6043 .10454 L
.6043 .08012 L
F
.2 .63 .79 r
.60316 .08012 m
.60316 .10454 L
.6043 .10454 L
.6043 .08012 L
s
.678 .847 .902 r
.6043 .08012 m
.6043 .10428 L
.60507 .10428 L
.60507 .08012 L
F
.2 .63 .79 r
.6043 .08012 m
.6043 .10428 L
.60507 .10428 L
.60507 .08012 L
s
.678 .847 .902 r
.60507 .08012 m
.60507 .10395 L
.60558 .10395 L
.60558 .08012 L
F
.2 .63 .79 r
.60507 .08012 m
.60507 .10395 L
.60558 .10395 L
.60558 .08012 L
s
.678 .847 .902 r
.60558 .08012 m
.60558 .10373 L
.60649 .10373 L
.60649 .08012 L
F
.2 .63 .79 r
.60558 .08012 m
.60558 .10373 L
.60649 .10373 L
.60649 .08012 L
s
.678 .847 .902 r
.60649 .08012 m
.60649 .10309 L
.60785 .10309 L
.60785 .08012 L
F
.2 .63 .79 r
.60649 .08012 m
.60649 .10309 L
.60785 .10309 L
.60785 .08012 L
s
.678 .847 .902 r
.60785 .08012 m
.60785 .10247 L
.60928 .10247 L
.60928 .08012 L
F
.2 .63 .79 r
.60785 .08012 m
.60785 .10247 L
.60928 .10247 L
.60928 .08012 L
s
.678 .847 .902 r
.60928 .08012 m
.60928 .10194 L
.61045 .10194 L
.61045 .08012 L
F
.2 .63 .79 r
.60928 .08012 m
.60928 .10194 L
.61045 .10194 L
.61045 .08012 L
s
.678 .847 .902 r
.61045 .08012 m
.61045 .10134 L
.61101 .10134 L
.61101 .08012 L
F
.2 .63 .79 r
.61045 .08012 m
.61045 .10134 L
.61101 .10134 L
.61101 .08012 L
s
.678 .847 .902 r
.61101 .08012 m
.61101 .10111 L
.61149 .10111 L
.61149 .08012 L
F
.2 .63 .79 r
.61101 .08012 m
.61101 .10111 L
.61149 .10111 L
.61149 .08012 L
s
.678 .847 .902 r
.61149 .08012 m
.61149 .10074 L
.61288 .10074 L
.61288 .08012 L
F
.2 .63 .79 r
.61149 .08012 m
.61149 .10074 L
.61288 .10074 L
.61288 .08012 L
s
.678 .847 .902 r
.61288 .08012 m
.61288 .09994 L
.6142 .09994 L
.6142 .08012 L
F
.2 .63 .79 r
.61288 .08012 m
.61288 .09994 L
.6142 .09994 L
.6142 .08012 L
s
.678 .847 .902 r
.6142 .08012 m
.6142 .09973 L
.61537 .09973 L
.61537 .08012 L
F
.2 .63 .79 r
.6142 .08012 m
.6142 .09973 L
.61537 .09973 L
.61537 .08012 L
s
.678 .847 .902 r
.61537 .08012 m
.61537 .09882 L
.61666 .09882 L
.61666 .08012 L
F
.2 .63 .79 r
.61537 .08012 m
.61537 .09882 L
.61666 .09882 L
.61666 .08012 L
s
.678 .847 .902 r
.61666 .08012 m
.61666 .09856 L
.61806 .09856 L
.61806 .08012 L
F
.2 .63 .79 r
.61666 .08012 m
.61666 .09856 L
.61806 .09856 L
.61806 .08012 L
s
.678 .847 .902 r
.61806 .08012 m
.61806 .09789 L
.61938 .09789 L
.61938 .08012 L
F
.2 .63 .79 r
.61806 .08012 m
.61806 .09789 L
.61938 .09789 L
.61938 .08012 L
s
.678 .847 .902 r
.61938 .08012 m
.61938 .09714 L
.62012 .09714 L
.62012 .08012 L
F
.2 .63 .79 r
.61938 .08012 m
.61938 .09714 L
.62012 .09714 L
.62012 .08012 L
s
.678 .847 .902 r
.62012 .08012 m
.62012 .09662 L
.62145 .09662 L
.62145 .08012 L
F
.2 .63 .79 r
.62012 .08012 m
.62012 .09662 L
.62145 .09662 L
.62145 .08012 L
s
.678 .847 .902 r
.62145 .08012 m
.62145 .09612 L
.6221 .09612 L
.6221 .08012 L
F
.2 .63 .79 r
.62145 .08012 m
.62145 .09612 L
.6221 .09612 L
.6221 .08012 L
s
.678 .847 .902 r
.6221 .08012 m
.6221 .09606 L
.62276 .09606 L
.62276 .08012 L
F
.2 .63 .79 r
.6221 .08012 m
.6221 .09606 L
.62276 .09606 L
.62276 .08012 L
s
.678 .847 .902 r
.62276 .08012 m
.62276 .09549 L
.62387 .09549 L
.62387 .08012 L
F
.2 .63 .79 r
.62276 .08012 m
.62276 .09549 L
.62387 .09549 L
.62387 .08012 L
s
.678 .847 .902 r
.62387 .08012 m
.62387 .09525 L
.62514 .09525 L
.62514 .08012 L
F
.2 .63 .79 r
.62387 .08012 m
.62387 .09525 L
.62514 .09525 L
.62514 .08012 L
s
.678 .847 .902 r
.62514 .08012 m
.62514 .09443 L
.62617 .09443 L
.62617 .08012 L
F
.2 .63 .79 r
.62514 .08012 m
.62514 .09443 L
.62617 .09443 L
.62617 .08012 L
s
.678 .847 .902 r
.62617 .08012 m
.62617 .09362 L
.6276 .09362 L
.6276 .08012 L
F
.2 .63 .79 r
.62617 .08012 m
.62617 .09362 L
.6276 .09362 L
.6276 .08012 L
s
.678 .847 .902 r
.6276 .08012 m
.6276 .09343 L
.62884 .09343 L
.62884 .08012 L
F
.2 .63 .79 r
.6276 .08012 m
.6276 .09343 L
.62884 .09343 L
.62884 .08012 L
s
.678 .847 .902 r
.62884 .08012 m
.62884 .09297 L
.62941 .09297 L
.62941 .08012 L
F
.2 .63 .79 r
.62884 .08012 m
.62884 .09297 L
.62941 .09297 L
.62941 .08012 L
s
.678 .847 .902 r
.62941 .08012 m
.62941 .09274 L
.6301 .09274 L
.6301 .08012 L
F
.2 .63 .79 r
.62941 .08012 m
.62941 .09274 L
.6301 .09274 L
.6301 .08012 L
s
.678 .847 .902 r
.6301 .08012 m
.6301 .09224 L
.63146 .09224 L
.63146 .08012 L
F
.2 .63 .79 r
.6301 .08012 m
.6301 .09224 L
.63146 .09224 L
.63146 .08012 L
s
.678 .847 .902 r
.63146 .08012 m
.63146 .0915 L
.63223 .0915 L
.63223 .08012 L
F
.2 .63 .79 r
.63146 .08012 m
.63146 .0915 L
.63223 .0915 L
.63223 .08012 L
s
.678 .847 .902 r
.63223 .08012 m
.63223 .09129 L
.6329 .09129 L
.6329 .08012 L
F
.2 .63 .79 r
.63223 .08012 m
.63223 .09129 L
.6329 .09129 L
.6329 .08012 L
s
.678 .847 .902 r
.6329 .08012 m
.6329 .091 L
.63362 .091 L
.63362 .08012 L
F
.2 .63 .79 r
.6329 .08012 m
.6329 .091 L
.63362 .091 L
.63362 .08012 L
s
.678 .847 .902 r
.63362 .08012 m
.63362 .09085 L
.63424 .09085 L
.63424 .08012 L
F
.2 .63 .79 r
.63362 .08012 m
.63362 .09085 L
.63424 .09085 L
.63424 .08012 L
s
.678 .847 .902 r
.63424 .08012 m
.63424 .09052 L
.63489 .09052 L
.63489 .08012 L
F
.2 .63 .79 r
.63424 .08012 m
.63424 .09052 L
.63489 .09052 L
.63489 .08012 L
s
.678 .847 .902 r
.63489 .08012 m
.63489 .0903 L
.63551 .0903 L
.63551 .08012 L
F
.2 .63 .79 r
.63489 .08012 m
.63489 .0903 L
.63551 .0903 L
.63551 .08012 L
s
.678 .847 .902 r
.63551 .08012 m
.63551 .08997 L
.63629 .08997 L
.63629 .08012 L
F
.2 .63 .79 r
.63551 .08012 m
.63551 .08997 L
.63629 .08997 L
.63629 .08012 L
s
.678 .847 .902 r
.63629 .08012 m
.63629 .08956 L
.63705 .08956 L
.63705 .08012 L
F
.2 .63 .79 r
.63629 .08012 m
.63629 .08956 L
.63705 .08956 L
.63705 .08012 L
s
.678 .847 .902 r
.63705 .08012 m
.63705 .08926 L
.63798 .08926 L
.63798 .08012 L
F
.2 .63 .79 r
.63705 .08012 m
.63705 .08926 L
.63798 .08926 L
.63798 .08012 L
s
.678 .847 .902 r
.63798 .08012 m
.63798 .08881 L
.63878 .08881 L
.63878 .08012 L
F
.2 .63 .79 r
.63798 .08012 m
.63798 .08881 L
.63878 .08881 L
.63878 .08012 L
s
.678 .847 .902 r
.63878 .08012 m
.63878 .08855 L
.63961 .08855 L
.63961 .08012 L
F
.2 .63 .79 r
.63878 .08012 m
.63878 .08855 L
.63961 .08855 L
.63961 .08012 L
s
.678 .847 .902 r
.63961 .08012 m
.63961 .08811 L
.64051 .08811 L
.64051 .08012 L
F
.2 .63 .79 r
.63961 .08012 m
.63961 .08811 L
.64051 .08811 L
.64051 .08012 L
s
.678 .847 .902 r
.64051 .08012 m
.64051 .08765 L
.64113 .08765 L
.64113 .08012 L
F
.2 .63 .79 r
.64051 .08012 m
.64051 .08765 L
.64113 .08765 L
.64113 .08012 L
s
.678 .847 .902 r
.64113 .08012 m
.64113 .08725 L
.64206 .08725 L
.64206 .08012 L
F
.2 .63 .79 r
.64113 .08012 m
.64113 .08725 L
.64206 .08725 L
.64206 .08012 L
s
.678 .847 .902 r
.64206 .08012 m
.64206 .0871 L
.64267 .0871 L
.64267 .08012 L
F
.2 .63 .79 r
.64206 .08012 m
.64206 .0871 L
.64267 .0871 L
.64267 .08012 L
s
.678 .847 .902 r
.64267 .08012 m
.64267 .08682 L
.64335 .08682 L
.64335 .08012 L
F
.2 .63 .79 r
.64267 .08012 m
.64267 .08682 L
.64335 .08682 L
.64335 .08012 L
s
.678 .847 .902 r
.64335 .08012 m
.64335 .08655 L
.64433 .08655 L
.64433 .08012 L
F
.2 .63 .79 r
.64335 .08012 m
.64335 .08655 L
.64433 .08655 L
.64433 .08012 L
s
.678 .847 .902 r
.64433 .08012 m
.64433 .08582 L
.64544 .08582 L
.64544 .08012 L
F
.2 .63 .79 r
.64433 .08012 m
.64433 .08582 L
.64544 .08582 L
.64544 .08012 L
s
.678 .847 .902 r
.64544 .08012 m
.64544 .08539 L
.64648 .08539 L
.64648 .08012 L
F
.2 .63 .79 r
.64544 .08012 m
.64544 .08539 L
.64648 .08539 L
.64648 .08012 L
s
.678 .847 .902 r
.64648 .08012 m
.64648 .08516 L
.64718 .08516 L
.64718 .08012 L
F
.2 .63 .79 r
.64648 .08012 m
.64648 .08516 L
.64718 .08516 L
.64718 .08012 L
s
.678 .847 .902 r
.64718 .08012 m
.64718 .08452 L
.64837 .08452 L
.64837 .08012 L
F
.2 .63 .79 r
.64718 .08012 m
.64718 .08452 L
.64837 .08452 L
.64837 .08012 L
s
.678 .847 .902 r
.64837 .08012 m
.64837 .0842 L
.64935 .0842 L
.64935 .08012 L
F
.2 .63 .79 r
.64837 .08012 m
.64837 .0842 L
.64935 .0842 L
.64935 .08012 L
s
.678 .847 .902 r
.64935 .08012 m
.64935 .08381 L
.65014 .08381 L
.65014 .08012 L
F
.2 .63 .79 r
.64935 .08012 m
.64935 .08381 L
.65014 .08381 L
.65014 .08012 L
s
.678 .847 .902 r
.65014 .08012 m
.65014 .08337 L
.65094 .08337 L
.65094 .08012 L
F
.2 .63 .79 r
.65014 .08012 m
.65014 .08337 L
.65094 .08337 L
.65094 .08012 L
s
.678 .847 .902 r
.65094 .08012 m
.65094 .08304 L
.6518 .08304 L
.6518 .08012 L
F
.2 .63 .79 r
.65094 .08012 m
.65094 .08304 L
.6518 .08304 L
.6518 .08012 L
s
.678 .847 .902 r
.6518 .08012 m
.6518 .0827 L
.65255 .0827 L
.65255 .08012 L
F
.2 .63 .79 r
.6518 .08012 m
.6518 .0827 L
.65255 .0827 L
.65255 .08012 L
s
.678 .847 .902 r
.65255 .08012 m
.65255 .08267 L
.65305 .08267 L
.65305 .08012 L
F
.2 .63 .79 r
.65255 .08012 m
.65255 .08267 L
.65305 .08267 L
.65305 .08012 L
s
.678 .847 .902 r
.65305 .08012 m
.65305 .08224 L
.65366 .08224 L
.65366 .08012 L
F
.2 .63 .79 r
.65305 .08012 m
.65305 .08224 L
.65366 .08224 L
.65366 .08012 L
s
.678 .847 .902 r
.65366 .08012 m
.65366 .08205 L
.65432 .08205 L
.65432 .08012 L
F
.2 .63 .79 r
.65366 .08012 m
.65366 .08205 L
.65432 .08205 L
.65432 .08012 L
s
.678 .847 .902 r
.65432 .08012 m
.65432 .08173 L
.65487 .08173 L
.65487 .08012 L
F
.2 .63 .79 r
.65432 .08012 m
.65432 .08173 L
.65487 .08173 L
.65487 .08012 L
s
.678 .847 .902 r
.65487 .08012 m
.65487 .08127 L
.65605 .08127 L
.65605 .08012 L
F
.2 .63 .79 r
.65487 .08012 m
.65487 .08127 L
.65605 .08127 L
.65605 .08012 L
s
.678 .847 .902 r
.65605 .08012 m
.65605 .08093 L
.65736 .08093 L
.65736 .08012 L
F
.2 .63 .79 r
.65605 .08012 m
.65605 .08093 L
.65736 .08093 L
.65736 .08012 L
s
.678 .847 .902 r
.65736 .08012 m
.65736 .08049 L
.65854 .08049 L
.65854 .08012 L
F
.2 .63 .79 r
.65736 .08012 m
.65736 .08049 L
.65854 .08049 L
.65854 .08012 L
s
1 .894 .882 r
.65854 .08012 m
.65854 .07992 L
.65976 .07992 L
.65976 .08012 L
F
.804 .522 .247 r
.65854 .08012 m
.65854 .07992 L
.65976 .07992 L
.65976 .08012 L
s
1 .894 .882 r
.65976 .08012 m
.65976 .07944 L
.66054 .07944 L
.66054 .08012 L
F
.804 .522 .247 r
.65976 .08012 m
.65976 .07944 L
.66054 .07944 L
.66054 .08012 L
s
1 .894 .882 r
.66054 .08012 m
.66054 .07929 L
.66138 .07929 L
.66138 .08012 L
F
.804 .522 .247 r
.66054 .08012 m
.66054 .07929 L
.66138 .07929 L
.66138 .08012 L
s
1 .894 .882 r
.66138 .08012 m
.66138 .07874 L
.66238 .07874 L
.66238 .08012 L
F
.804 .522 .247 r
.66138 .08012 m
.66138 .07874 L
.66238 .07874 L
.66238 .08012 L
s
1 .894 .882 r
.66238 .08012 m
.66238 .0784 L
.6631 .0784 L
.6631 .08012 L
F
.804 .522 .247 r
.66238 .08012 m
.66238 .0784 L
.6631 .0784 L
.6631 .08012 L
s
1 .894 .882 r
.6631 .08012 m
.6631 .07819 L
.66371 .07819 L
.66371 .08012 L
F
.804 .522 .247 r
.6631 .08012 m
.6631 .07819 L
.66371 .07819 L
.66371 .08012 L
s
1 .894 .882 r
.66371 .08012 m
.66371 .07784 L
.66431 .07784 L
.66431 .08012 L
F
.804 .522 .247 r
.66371 .08012 m
.66371 .07784 L
.66431 .07784 L
.66431 .08012 L
s
1 .894 .882 r
.66431 .08012 m
.66431 .07773 L
.66478 .07773 L
.66478 .08012 L
F
.804 .522 .247 r
.66431 .08012 m
.66431 .07773 L
.66478 .07773 L
.66478 .08012 L
s
1 .894 .882 r
.66478 .08012 m
.66478 .07723 L
.66584 .07723 L
.66584 .08012 L
F
.804 .522 .247 r
.66478 .08012 m
.66478 .07723 L
.66584 .07723 L
.66584 .08012 L
s
1 .894 .882 r
.66584 .08012 m
.66584 .07688 L
.66687 .07688 L
.66687 .08012 L
F
.804 .522 .247 r
.66584 .08012 m
.66584 .07688 L
.66687 .07688 L
.66687 .08012 L
s
1 .894 .882 r
.66687 .08012 m
.66687 .07645 L
.66822 .07645 L
.66822 .08012 L
F
.804 .522 .247 r
.66687 .08012 m
.66687 .07645 L
.66822 .07645 L
.66822 .08012 L
s
1 .894 .882 r
.66822 .08012 m
.66822 .07606 L
.66895 .07606 L
.66895 .08012 L
F
.804 .522 .247 r
.66822 .08012 m
.66822 .07606 L
.66895 .07606 L
.66895 .08012 L
s
1 .894 .882 r
.66895 .08012 m
.66895 .0759 L
.66947 .0759 L
.66947 .08012 L
F
.804 .522 .247 r
.66895 .08012 m
.66895 .0759 L
.66947 .0759 L
.66947 .08012 L
s
1 .894 .882 r
.66947 .08012 m
.66947 .07573 L
.67015 .07573 L
.67015 .08012 L
F
.804 .522 .247 r
.66947 .08012 m
.66947 .07573 L
.67015 .07573 L
.67015 .08012 L
s
1 .894 .882 r
.67015 .08012 m
.67015 .07524 L
.67114 .07524 L
.67114 .08012 L
F
.804 .522 .247 r
.67015 .08012 m
.67015 .07524 L
.67114 .07524 L
.67114 .08012 L
s
1 .894 .882 r
.67114 .08012 m
.67114 .07468 L
.67246 .07468 L
.67246 .08012 L
F
.804 .522 .247 r
.67114 .08012 m
.67114 .07468 L
.67246 .07468 L
.67246 .08012 L
s
1 .894 .882 r
.67246 .08012 m
.67246 .07438 L
.67369 .07438 L
.67369 .08012 L
F
.804 .522 .247 r
.67246 .08012 m
.67246 .07438 L
.67369 .07438 L
.67369 .08012 L
s
1 .894 .882 r
.67369 .08012 m
.67369 .07408 L
.67431 .07408 L
.67431 .08012 L
F
.804 .522 .247 r
.67369 .08012 m
.67369 .07408 L
.67431 .07408 L
.67431 .08012 L
s
1 .894 .882 r
.67431 .08012 m
.67431 .07362 L
.67512 .07362 L
.67512 .08012 L
F
.804 .522 .247 r
.67431 .08012 m
.67431 .07362 L
.67512 .07362 L
.67512 .08012 L
s
1 .894 .882 r
.67512 .08012 m
.67512 .07345 L
.67622 .07345 L
.67622 .08012 L
F
.804 .522 .247 r
.67512 .08012 m
.67512 .07345 L
.67622 .07345 L
.67622 .08012 L
s
1 .894 .882 r
.67622 .08012 m
.67622 .0729 L
.67733 .0729 L
.67733 .08012 L
F
.804 .522 .247 r
.67622 .08012 m
.67622 .0729 L
.67733 .0729 L
.67733 .08012 L
s
1 .894 .882 r
.67733 .08012 m
.67733 .07262 L
.67823 .07262 L
.67823 .08012 L
F
.804 .522 .247 r
.67733 .08012 m
.67733 .07262 L
.67823 .07262 L
.67823 .08012 L
s
1 .894 .882 r
.67823 .08012 m
.67823 .07225 L
.67919 .07225 L
.67919 .08012 L
F
.804 .522 .247 r
.67823 .08012 m
.67823 .07225 L
.67919 .07225 L
.67919 .08012 L
s
1 .894 .882 r
.67919 .08012 m
.67919 .07153 L
.68057 .07153 L
.68057 .08012 L
F
.804 .522 .247 r
.67919 .08012 m
.67919 .07153 L
.68057 .07153 L
.68057 .08012 L
s
1 .894 .882 r
.68057 .08012 m
.68057 .07094 L
.68191 .07094 L
.68191 .08012 L
F
.804 .522 .247 r
.68057 .08012 m
.68057 .07094 L
.68191 .07094 L
.68191 .08012 L
s
1 .894 .882 r
.68191 .08012 m
.68191 .07083 L
.68247 .07083 L
.68247 .08012 L
F
.804 .522 .247 r
.68191 .08012 m
.68191 .07083 L
.68247 .07083 L
.68247 .08012 L
s
1 .894 .882 r
.68247 .08012 m
.68247 .0705 L
.68302 .0705 L
.68302 .08012 L
F
.804 .522 .247 r
.68247 .08012 m
.68247 .0705 L
.68302 .0705 L
.68302 .08012 L
s
1 .894 .882 r
.68302 .08012 m
.68302 .07046 L
.68384 .07046 L
.68384 .08012 L
F
.804 .522 .247 r
.68302 .08012 m
.68302 .07046 L
.68384 .07046 L
.68384 .08012 L
s
1 .894 .882 r
.68384 .08012 m
.68384 .0701 L
.6849 .0701 L
.6849 .08012 L
F
.804 .522 .247 r
.68384 .08012 m
.68384 .0701 L
.6849 .0701 L
.6849 .08012 L
s
1 .894 .882 r
.6849 .08012 m
.6849 .06934 L
.6863 .06934 L
.6863 .08012 L
F
.804 .522 .247 r
.6849 .08012 m
.6849 .06934 L
.6863 .06934 L
.6863 .08012 L
s
1 .894 .882 r
.6863 .08012 m
.6863 .06873 L
.68771 .06873 L
.68771 .08012 L
F
.804 .522 .247 r
.6863 .08012 m
.6863 .06873 L
.68771 .06873 L
.68771 .08012 L
s
1 .894 .882 r
.68771 .08012 m
.68771 .06857 L
.6885 .06857 L
.6885 .08012 L
F
.804 .522 .247 r
.68771 .08012 m
.68771 .06857 L
.6885 .06857 L
.6885 .08012 L
s
1 .894 .882 r
.6885 .08012 m
.6885 .06839 L
.68893 .06839 L
.68893 .08012 L
F
.804 .522 .247 r
.6885 .08012 m
.6885 .06839 L
.68893 .06839 L
.68893 .08012 L
s
1 .894 .882 r
.68893 .08012 m
.68893 .06796 L
.68975 .06796 L
.68975 .08012 L
F
.804 .522 .247 r
.68893 .08012 m
.68893 .06796 L
.68975 .06796 L
.68975 .08012 L
s
1 .894 .882 r
.68975 .08012 m
.68975 .0679 L
.69024 .0679 L
.69024 .08012 L
F
.804 .522 .247 r
.68975 .08012 m
.68975 .0679 L
.69024 .0679 L
.69024 .08012 L
s
1 .894 .882 r
.69024 .08012 m
.69024 .06763 L
.69073 .06763 L
.69073 .08012 L
F
.804 .522 .247 r
.69024 .08012 m
.69024 .06763 L
.69073 .06763 L
.69073 .08012 L
s
1 .894 .882 r
.69073 .08012 m
.69073 .06716 L
.69211 .06716 L
.69211 .08012 L
F
.804 .522 .247 r
.69073 .08012 m
.69073 .06716 L
.69211 .06716 L
.69211 .08012 L
s
1 .894 .882 r
.69211 .08012 m
.69211 .06691 L
.69268 .06691 L
.69268 .08012 L
F
.804 .522 .247 r
.69211 .08012 m
.69211 .06691 L
.69268 .06691 L
.69268 .08012 L
s
1 .894 .882 r
.69268 .08012 m
.69268 .06664 L
.69363 .06664 L
.69363 .08012 L
F
.804 .522 .247 r
.69268 .08012 m
.69268 .06664 L
.69363 .06664 L
.69363 .08012 L
s
1 .894 .882 r
.69363 .08012 m
.69363 .0663 L
.69426 .0663 L
.69426 .08012 L
F
.804 .522 .247 r
.69363 .08012 m
.69363 .0663 L
.69426 .0663 L
.69426 .08012 L
s
1 .894 .882 r
.69426 .08012 m
.69426 .0662 L
.69485 .0662 L
.69485 .08012 L
F
.804 .522 .247 r
.69426 .08012 m
.69426 .0662 L
.69485 .0662 L
.69485 .08012 L
s
1 .894 .882 r
.69485 .08012 m
.69485 .06569 L
.69625 .06569 L
.69625 .08012 L
F
.804 .522 .247 r
.69485 .08012 m
.69485 .06569 L
.69625 .06569 L
.69625 .08012 L
s
1 .894 .882 r
.69625 .08012 m
.69625 .06537 L
.69683 .06537 L
.69683 .08012 L
F
.804 .522 .247 r
.69625 .08012 m
.69625 .06537 L
.69683 .06537 L
.69683 .08012 L
s
1 .894 .882 r
.69683 .08012 m
.69683 .06507 L
.69782 .06507 L
.69782 .08012 L
F
.804 .522 .247 r
.69683 .08012 m
.69683 .06507 L
.69782 .06507 L
.69782 .08012 L
s
1 .894 .882 r
.69782 .08012 m
.69782 .06469 L
.69875 .06469 L
.69875 .08012 L
F
.804 .522 .247 r
.69782 .08012 m
.69782 .06469 L
.69875 .06469 L
.69875 .08012 L
s
1 .894 .882 r
.69875 .08012 m
.69875 .06446 L
.69969 .06446 L
.69969 .08012 L
F
.804 .522 .247 r
.69875 .08012 m
.69875 .06446 L
.69969 .06446 L
.69969 .08012 L
s
1 .894 .882 r
.69969 .08012 m
.69969 .06404 L
.70077 .06404 L
.70077 .08012 L
F
.804 .522 .247 r
.69969 .08012 m
.69969 .06404 L
.70077 .06404 L
.70077 .08012 L
s
1 .894 .882 r
.70077 .08012 m
.70077 .06357 L
.70184 .06357 L
.70184 .08012 L
F
.804 .522 .247 r
.70077 .08012 m
.70077 .06357 L
.70184 .06357 L
.70184 .08012 L
s
1 .894 .882 r
.70184 .08012 m
.70184 .0632 L
.70287 .0632 L
.70287 .08012 L
F
.804 .522 .247 r
.70184 .08012 m
.70184 .0632 L
.70287 .0632 L
.70287 .08012 L
s
1 .894 .882 r
.70287 .08012 m
.70287 .06313 L
.70369 .06313 L
.70369 .08012 L
F
.804 .522 .247 r
.70287 .08012 m
.70287 .06313 L
.70369 .06313 L
.70369 .08012 L
s
1 .894 .882 r
.70369 .08012 m
.70369 .06264 L
.70465 .06264 L
.70465 .08012 L
F
.804 .522 .247 r
.70369 .08012 m
.70369 .06264 L
.70465 .06264 L
.70465 .08012 L
s
1 .894 .882 r
.70465 .08012 m
.70465 .06235 L
.70535 .06235 L
.70535 .08012 L
F
.804 .522 .247 r
.70465 .08012 m
.70465 .06235 L
.70535 .06235 L
.70535 .08012 L
s
1 .894 .882 r
.70535 .08012 m
.70535 .06192 L
.70678 .06192 L
.70678 .08012 L
F
.804 .522 .247 r
.70535 .08012 m
.70535 .06192 L
.70678 .06192 L
.70678 .08012 L
s
1 .894 .882 r
.70678 .08012 m
.70678 .06169 L
.70765 .06169 L
.70765 .08012 L
F
.804 .522 .247 r
.70678 .08012 m
.70678 .06169 L
.70765 .06169 L
.70765 .08012 L
s
1 .894 .882 r
.70765 .08012 m
.70765 .06124 L
.70866 .06124 L
.70866 .08012 L
F
.804 .522 .247 r
.70765 .08012 m
.70765 .06124 L
.70866 .06124 L
.70866 .08012 L
s
1 .894 .882 r
.70866 .08012 m
.70866 .06099 L
.71003 .06099 L
.71003 .08012 L
F
.804 .522 .247 r
.70866 .08012 m
.70866 .06099 L
.71003 .06099 L
.71003 .08012 L
s
1 .894 .882 r
.71003 .08012 m
.71003 .06041 L
.71145 .06041 L
.71145 .08012 L
F
.804 .522 .247 r
.71003 .08012 m
.71003 .06041 L
.71145 .06041 L
.71145 .08012 L
s
1 .894 .882 r
.71145 .08012 m
.71145 .06013 L
.71195 .06013 L
.71195 .08012 L
F
.804 .522 .247 r
.71145 .08012 m
.71145 .06013 L
.71195 .06013 L
.71195 .08012 L
s
1 .894 .882 r
.71195 .08012 m
.71195 .05988 L
.7129 .05988 L
.7129 .08012 L
F
.804 .522 .247 r
.71195 .08012 m
.71195 .05988 L
.7129 .05988 L
.7129 .08012 L
s
1 .894 .882 r
.7129 .08012 m
.7129 .05945 L
.71421 .05945 L
.71421 .08012 L
F
.804 .522 .247 r
.7129 .08012 m
.7129 .05945 L
.71421 .05945 L
.71421 .08012 L
s
1 .894 .882 r
.71421 .08012 m
.71421 .05913 L
.7147 .05913 L
.7147 .08012 L
F
.804 .522 .247 r
.71421 .08012 m
.71421 .05913 L
.7147 .05913 L
.7147 .08012 L
s
1 .894 .882 r
.7147 .08012 m
.7147 .05882 L
.71609 .05882 L
.71609 .08012 L
F
.804 .522 .247 r
.7147 .08012 m
.7147 .05882 L
.71609 .05882 L
.71609 .08012 L
s
1 .894 .882 r
.71609 .08012 m
.71609 .05824 L
.71754 .05824 L
.71754 .08012 L
F
.804 .522 .247 r
.71609 .08012 m
.71609 .05824 L
.71754 .05824 L
.71754 .08012 L
s
1 .894 .882 r
.71754 .08012 m
.71754 .05791 L
.71866 .05791 L
.71866 .08012 L
F
.804 .522 .247 r
.71754 .08012 m
.71754 .05791 L
.71866 .05791 L
.71866 .08012 L
s
1 .894 .882 r
.71866 .08012 m
.71866 .05762 L
.72002 .05762 L
.72002 .08012 L
F
.804 .522 .247 r
.71866 .08012 m
.71866 .05762 L
.72002 .05762 L
.72002 .08012 L
s
1 .894 .882 r
.72002 .08012 m
.72002 .05692 L
.72146 .05692 L
.72146 .08012 L
F
.804 .522 .247 r
.72002 .08012 m
.72002 .05692 L
.72146 .05692 L
.72146 .08012 L
s
1 .894 .882 r
.72146 .08012 m
.72146 .05646 L
.72276 .05646 L
.72276 .08012 L
F
.804 .522 .247 r
.72146 .08012 m
.72146 .05646 L
.72276 .05646 L
.72276 .08012 L
s
1 .894 .882 r
.72276 .08012 m
.72276 .05625 L
.72333 .05625 L
.72333 .08012 L
F
.804 .522 .247 r
.72276 .08012 m
.72276 .05625 L
.72333 .05625 L
.72333 .08012 L
s
1 .894 .882 r
.72333 .08012 m
.72333 .0561 L
.7242 .0561 L
.7242 .08012 L
F
.804 .522 .247 r
.72333 .08012 m
.72333 .0561 L
.7242 .0561 L
.7242 .08012 L
s
1 .894 .882 r
.7242 .08012 m
.7242 .05586 L
.72514 .05586 L
.72514 .08012 L
F
.804 .522 .247 r
.7242 .08012 m
.7242 .05586 L
.72514 .05586 L
.72514 .08012 L
s
1 .894 .882 r
.72514 .08012 m
.72514 .05559 L
.7258 .05559 L
.7258 .08012 L
F
.804 .522 .247 r
.72514 .08012 m
.72514 .05559 L
.7258 .05559 L
.7258 .08012 L
s
1 .894 .882 r
.7258 .08012 m
.7258 .05516 L
.72675 .05516 L
.72675 .08012 L
F
.804 .522 .247 r
.7258 .08012 m
.7258 .05516 L
.72675 .05516 L
.72675 .08012 L
s
1 .894 .882 r
.72675 .08012 m
.72675 .05494 L
.72805 .05494 L
.72805 .08012 L
F
.804 .522 .247 r
.72675 .08012 m
.72675 .05494 L
.72805 .05494 L
.72805 .08012 L
s
1 .894 .882 r
.72805 .08012 m
.72805 .0545 L
.7286 .0545 L
.7286 .08012 L
F
.804 .522 .247 r
.72805 .08012 m
.72805 .0545 L
.7286 .0545 L
.7286 .08012 L
s
1 .894 .882 r
.7286 .08012 m
.7286 .05437 L
.72976 .05437 L
.72976 .08012 L
F
.804 .522 .247 r
.7286 .08012 m
.7286 .05437 L
.72976 .05437 L
.72976 .08012 L
s
1 .894 .882 r
.72976 .08012 m
.72976 .05392 L
.73045 .05392 L
.73045 .08012 L
F
.804 .522 .247 r
.72976 .08012 m
.72976 .05392 L
.73045 .05392 L
.73045 .08012 L
s
1 .894 .882 r
.73045 .08012 m
.73045 .05366 L
.73177 .05366 L
.73177 .08012 L
F
.804 .522 .247 r
.73045 .08012 m
.73045 .05366 L
.73177 .05366 L
.73177 .08012 L
s
1 .894 .882 r
.73177 .08012 m
.73177 .05328 L
.73291 .05328 L
.73291 .08012 L
F
.804 .522 .247 r
.73177 .08012 m
.73177 .05328 L
.73291 .05328 L
.73291 .08012 L
s
1 .894 .882 r
.73291 .08012 m
.73291 .05302 L
.7335 .05302 L
.7335 .08012 L
F
.804 .522 .247 r
.73291 .08012 m
.73291 .05302 L
.7335 .05302 L
.7335 .08012 L
s
1 .894 .882 r
.7335 .08012 m
.7335 .0528 L
.73428 .0528 L
.73428 .08012 L
F
.804 .522 .247 r
.7335 .08012 m
.7335 .0528 L
.73428 .0528 L
.73428 .08012 L
s
1 .894 .882 r
.73428 .08012 m
.73428 .05268 L
.73562 .05268 L
.73562 .08012 L
F
.804 .522 .247 r
.73428 .08012 m
.73428 .05268 L
.73562 .05268 L
.73562 .08012 L
s
1 .894 .882 r
.73562 .08012 m
.73562 .05222 L
.73671 .05222 L
.73671 .08012 L
F
.804 .522 .247 r
.73562 .08012 m
.73562 .05222 L
.73671 .05222 L
.73671 .08012 L
s
1 .894 .882 r
.73671 .08012 m
.73671 .0519 L
.73779 .0519 L
.73779 .08012 L
F
.804 .522 .247 r
.73671 .08012 m
.73671 .0519 L
.73779 .0519 L
.73779 .08012 L
s
1 .894 .882 r
.73779 .08012 m
.73779 .05132 L
.73872 .05132 L
.73872 .08012 L
F
.804 .522 .247 r
.73779 .08012 m
.73779 .05132 L
.73872 .05132 L
.73872 .08012 L
s
1 .894 .882 r
.73872 .08012 m
.73872 .05119 L
.74001 .05119 L
.74001 .08012 L
F
.804 .522 .247 r
.73872 .08012 m
.73872 .05119 L
.74001 .05119 L
.74001 .08012 L
s
1 .894 .882 r
.74001 .08012 m
.74001 .05071 L
.74117 .05071 L
.74117 .08012 L
F
.804 .522 .247 r
.74001 .08012 m
.74001 .05071 L
.74117 .05071 L
.74117 .08012 L
s
1 .894 .882 r
.74117 .08012 m
.74117 .05045 L
.74226 .05045 L
.74226 .08012 L
F
.804 .522 .247 r
.74117 .08012 m
.74117 .05045 L
.74226 .05045 L
.74226 .08012 L
s
1 .894 .882 r
.74226 .08012 m
.74226 .05007 L
.74352 .05007 L
.74352 .08012 L
F
.804 .522 .247 r
.74226 .08012 m
.74226 .05007 L
.74352 .05007 L
.74352 .08012 L
s
1 .894 .882 r
.74352 .08012 m
.74352 .04984 L
.74491 .04984 L
.74491 .08012 L
F
.804 .522 .247 r
.74352 .08012 m
.74352 .04984 L
.74491 .04984 L
.74491 .08012 L
s
1 .894 .882 r
.74491 .08012 m
.74491 .04915 L
.74609 .04915 L
.74609 .08012 L
F
.804 .522 .247 r
.74491 .08012 m
.74491 .04915 L
.74609 .04915 L
.74609 .08012 L
s
1 .894 .882 r
.74609 .08012 m
.74609 .0489 L
.74733 .0489 L
.74733 .08012 L
F
.804 .522 .247 r
.74609 .08012 m
.74609 .0489 L
.74733 .0489 L
.74733 .08012 L
s
1 .894 .882 r
.74733 .08012 m
.74733 .04849 L
.74846 .04849 L
.74846 .08012 L
F
.804 .522 .247 r
.74733 .08012 m
.74733 .04849 L
.74846 .04849 L
.74846 .08012 L
s
1 .894 .882 r
.74846 .08012 m
.74846 .04819 L
.74941 .04819 L
.74941 .08012 L
F
.804 .522 .247 r
.74846 .08012 m
.74846 .04819 L
.74941 .04819 L
.74941 .08012 L
s
1 .894 .882 r
.74941 .08012 m
.74941 .04797 L
.75009 .04797 L
.75009 .08012 L
F
.804 .522 .247 r
.74941 .08012 m
.74941 .04797 L
.75009 .04797 L
.75009 .08012 L
s
1 .894 .882 r
.75009 .08012 m
.75009 .04778 L
.7511 .04778 L
.7511 .08012 L
F
.804 .522 .247 r
.75009 .08012 m
.75009 .04778 L
.7511 .04778 L
.7511 .08012 L
s
1 .894 .882 r
.7511 .08012 m
.7511 .04744 L
.75172 .04744 L
.75172 .08012 L
F
.804 .522 .247 r
.7511 .08012 m
.7511 .04744 L
.75172 .04744 L
.75172 .08012 L
s
1 .894 .882 r
.75172 .08012 m
.75172 .04732 L
.75284 .04732 L
.75284 .08012 L
F
.804 .522 .247 r
.75172 .08012 m
.75172 .04732 L
.75284 .04732 L
.75284 .08012 L
s
1 .894 .882 r
.75284 .08012 m
.75284 .04698 L
.7534 .04698 L
.7534 .08012 L
F
.804 .522 .247 r
.75284 .08012 m
.75284 .04698 L
.7534 .04698 L
.7534 .08012 L
s
1 .894 .882 r
.7534 .08012 m
.7534 .04691 L
.75471 .04691 L
.75471 .08012 L
F
.804 .522 .247 r
.7534 .08012 m
.7534 .04691 L
.75471 .04691 L
.75471 .08012 L
s
1 .894 .882 r
.75471 .08012 m
.75471 .04618 L
.75609 .04618 L
.75609 .08012 L
F
.804 .522 .247 r
.75471 .08012 m
.75471 .04618 L
.75609 .04618 L
.75609 .08012 L
s
1 .894 .882 r
.75609 .08012 m
.75609 .04591 L
.75735 .04591 L
.75735 .08012 L
F
.804 .522 .247 r
.75609 .08012 m
.75609 .04591 L
.75735 .04591 L
.75735 .08012 L
s
1 .894 .882 r
.75735 .08012 m
.75735 .04577 L
.75823 .04577 L
.75823 .08012 L
F
.804 .522 .247 r
.75735 .08012 m
.75735 .04577 L
.75823 .04577 L
.75823 .08012 L
s
1 .894 .882 r
.75823 .08012 m
.75823 .04539 L
.75938 .04539 L
.75938 .08012 L
F
.804 .522 .247 r
.75823 .08012 m
.75823 .04539 L
.75938 .04539 L
.75938 .08012 L
s
1 .894 .882 r
.75938 .08012 m
.75938 .0451 L
.76042 .0451 L
.76042 .08012 L
F
.804 .522 .247 r
.75938 .08012 m
.75938 .0451 L
.76042 .0451 L
.76042 .08012 L
s
1 .894 .882 r
.76042 .08012 m
.76042 .04467 L
.76179 .04467 L
.76179 .08012 L
F
.804 .522 .247 r
.76042 .08012 m
.76042 .04467 L
.76179 .04467 L
.76179 .08012 L
s
1 .894 .882 r
.76179 .08012 m
.76179 .04422 L
.76304 .04422 L
.76304 .08012 L
F
.804 .522 .247 r
.76179 .08012 m
.76179 .04422 L
.76304 .04422 L
.76304 .08012 L
s
1 .894 .882 r
.76304 .08012 m
.76304 .04415 L
.76354 .04415 L
.76354 .08012 L
F
.804 .522 .247 r
.76304 .08012 m
.76304 .04415 L
.76354 .04415 L
.76354 .08012 L
s
1 .894 .882 r
.76354 .08012 m
.76354 .044 L
.7641 .044 L
.7641 .08012 L
F
.804 .522 .247 r
.76354 .08012 m
.76354 .044 L
.7641 .044 L
.7641 .08012 L
s
1 .894 .882 r
.7641 .08012 m
.7641 .04386 L
.7646 .04386 L
.7646 .08012 L
F
.804 .522 .247 r
.7641 .08012 m
.7641 .04386 L
.7646 .04386 L
.7646 .08012 L
s
1 .894 .882 r
.7646 .08012 m
.7646 .04371 L
.76514 .04371 L
.76514 .08012 L
F
.804 .522 .247 r
.7646 .08012 m
.7646 .04371 L
.76514 .04371 L
.76514 .08012 L
s
1 .894 .882 r
.76514 .08012 m
.76514 .04361 L
.76601 .04361 L
.76601 .08012 L
F
.804 .522 .247 r
.76514 .08012 m
.76514 .04361 L
.76601 .04361 L
.76601 .08012 L
s
1 .894 .882 r
.76601 .08012 m
.76601 .04338 L
.76675 .04338 L
.76675 .08012 L
F
.804 .522 .247 r
.76601 .08012 m
.76601 .04338 L
.76675 .04338 L
.76675 .08012 L
s
1 .894 .882 r
.76675 .08012 m
.76675 .04312 L
.76732 .04312 L
.76732 .08012 L
F
.804 .522 .247 r
.76675 .08012 m
.76675 .04312 L
.76732 .04312 L
.76732 .08012 L
s
1 .894 .882 r
.76732 .08012 m
.76732 .0429 L
.76814 .0429 L
.76814 .08012 L
F
.804 .522 .247 r
.76732 .08012 m
.76732 .0429 L
.76814 .0429 L
.76814 .08012 L
s
1 .894 .882 r
.76814 .08012 m
.76814 .04264 L
.76923 .04264 L
.76923 .08012 L
F
.804 .522 .247 r
.76814 .08012 m
.76814 .04264 L
.76923 .04264 L
.76923 .08012 L
s
1 .894 .882 r
.76923 .08012 m
.76923 .04241 L
.7703 .04241 L
.7703 .08012 L
F
.804 .522 .247 r
.76923 .08012 m
.76923 .04241 L
.7703 .04241 L
.7703 .08012 L
s
1 .894 .882 r
.7703 .08012 m
.7703 .04202 L
.77137 .04202 L
.77137 .08012 L
F
.804 .522 .247 r
.7703 .08012 m
.7703 .04202 L
.77137 .04202 L
.77137 .08012 L
s
1 .894 .882 r
.77137 .08012 m
.77137 .04179 L
.77195 .04179 L
.77195 .08012 L
F
.804 .522 .247 r
.77137 .08012 m
.77137 .04179 L
.77195 .04179 L
.77195 .08012 L
s
1 .894 .882 r
.77195 .08012 m
.77195 .04176 L
.77246 .04176 L
.77246 .08012 L
F
.804 .522 .247 r
.77195 .08012 m
.77195 .04176 L
.77246 .04176 L
.77246 .08012 L
s
1 .894 .882 r
.77246 .08012 m
.77246 .04153 L
.77334 .04153 L
.77334 .08012 L
F
.804 .522 .247 r
.77246 .08012 m
.77246 .04153 L
.77334 .04153 L
.77334 .08012 L
s
1 .894 .882 r
.77334 .08012 m
.77334 .04125 L
.77476 .04125 L
.77476 .08012 L
F
.804 .522 .247 r
.77334 .08012 m
.77334 .04125 L
.77476 .04125 L
.77476 .08012 L
s
1 .894 .882 r
.77476 .08012 m
.77476 .04101 L
.77521 .04101 L
.77521 .08012 L
F
.804 .522 .247 r
.77476 .08012 m
.77476 .04101 L
.77521 .04101 L
.77521 .08012 L
s
1 .894 .882 r
.77521 .08012 m
.77521 .0409 L
.77588 .0409 L
.77588 .08012 L
F
.804 .522 .247 r
.77521 .08012 m
.77521 .0409 L
.77588 .0409 L
.77588 .08012 L
s
1 .894 .882 r
.77588 .08012 m
.77588 .04061 L
.77683 .04061 L
.77683 .08012 L
F
.804 .522 .247 r
.77588 .08012 m
.77588 .04061 L
.77683 .04061 L
.77683 .08012 L
s
1 .894 .882 r
.77683 .08012 m
.77683 .04039 L
.77743 .04039 L
.77743 .08012 L
F
.804 .522 .247 r
.77683 .08012 m
.77683 .04039 L
.77743 .04039 L
.77743 .08012 L
s
1 .894 .882 r
.77743 .08012 m
.77743 .04029 L
.77845 .04029 L
.77845 .08012 L
F
.804 .522 .247 r
.77743 .08012 m
.77743 .04029 L
.77845 .04029 L
.77845 .08012 L
s
1 .894 .882 r
.77845 .08012 m
.77845 .03991 L
.77942 .03991 L
.77942 .08012 L
F
.804 .522 .247 r
.77845 .08012 m
.77845 .03991 L
.77942 .03991 L
.77942 .08012 L
s
1 .894 .882 r
.77942 .08012 m
.77942 .03977 L
.78079 .03977 L
.78079 .08012 L
F
.804 .522 .247 r
.77942 .08012 m
.77942 .03977 L
.78079 .03977 L
.78079 .08012 L
s
1 .894 .882 r
.78079 .08012 m
.78079 .03948 L
.78148 .03948 L
.78148 .08012 L
F
.804 .522 .247 r
.78079 .08012 m
.78079 .03948 L
.78148 .03948 L
.78148 .08012 L
s
1 .894 .882 r
.78148 .08012 m
.78148 .03923 L
.7827 .03923 L
.7827 .08012 L
F
.804 .522 .247 r
.78148 .08012 m
.78148 .03923 L
.7827 .03923 L
.7827 .08012 L
s
1 .894 .882 r
.7827 .08012 m
.7827 .03893 L
.78361 .03893 L
.78361 .08012 L
F
.804 .522 .247 r
.7827 .08012 m
.7827 .03893 L
.78361 .03893 L
.78361 .08012 L
s
1 .894 .882 r
.78361 .08012 m
.78361 .03854 L
.78486 .03854 L
.78486 .08012 L
F
.804 .522 .247 r
.78361 .08012 m
.78361 .03854 L
.78486 .03854 L
.78486 .08012 L
s
1 .894 .882 r
.78486 .08012 m
.78486 .03836 L
.78548 .03836 L
.78548 .08012 L
F
.804 .522 .247 r
.78486 .08012 m
.78486 .03836 L
.78548 .03836 L
.78548 .08012 L
s
1 .894 .882 r
.78548 .08012 m
.78548 .03806 L
.78661 .03806 L
.78661 .08012 L
F
.804 .522 .247 r
.78548 .08012 m
.78548 .03806 L
.78661 .03806 L
.78661 .08012 L
s
1 .894 .882 r
.78661 .08012 m
.78661 .038 L
.78708 .038 L
.78708 .08012 L
F
.804 .522 .247 r
.78661 .08012 m
.78661 .038 L
.78708 .038 L
.78708 .08012 L
s
1 .894 .882 r
.78708 .08012 m
.78708 .03775 L
.78802 .03775 L
.78802 .08012 L
F
.804 .522 .247 r
.78708 .08012 m
.78708 .03775 L
.78802 .03775 L
.78802 .08012 L
s
1 .894 .882 r
.78802 .08012 m
.78802 .03765 L
.78851 .03765 L
.78851 .08012 L
F
.804 .522 .247 r
.78802 .08012 m
.78802 .03765 L
.78851 .03765 L
.78851 .08012 L
s
1 .894 .882 r
.78851 .08012 m
.78851 .03751 L
.78925 .03751 L
.78925 .08012 L
F
.804 .522 .247 r
.78851 .08012 m
.78851 .03751 L
.78925 .03751 L
.78925 .08012 L
s
1 .894 .882 r
.78925 .08012 m
.78925 .03724 L
.7901 .03724 L
.7901 .08012 L
F
.804 .522 .247 r
.78925 .08012 m
.78925 .03724 L
.7901 .03724 L
.7901 .08012 L
s
1 .894 .882 r
.7901 .08012 m
.7901 .03706 L
.79143 .03706 L
.79143 .08012 L
F
.804 .522 .247 r
.7901 .08012 m
.7901 .03706 L
.79143 .03706 L
.79143 .08012 L
s
1 .894 .882 r
.79143 .08012 m
.79143 .03673 L
.7923 .03673 L
.7923 .08012 L
F
.804 .522 .247 r
.79143 .08012 m
.79143 .03673 L
.7923 .03673 L
.7923 .08012 L
s
1 .894 .882 r
.7923 .08012 m
.7923 .0366 L
.7929 .0366 L
.7929 .08012 L
F
.804 .522 .247 r
.7923 .08012 m
.7923 .0366 L
.7929 .0366 L
.7929 .08012 L
s
1 .894 .882 r
.7929 .08012 m
.7929 .03642 L
.79367 .03642 L
.79367 .08012 L
F
.804 .522 .247 r
.7929 .08012 m
.7929 .03642 L
.79367 .03642 L
.79367 .08012 L
s
1 .894 .882 r
.79367 .08012 m
.79367 .03615 L
.79455 .03615 L
.79455 .08012 L
F
.804 .522 .247 r
.79367 .08012 m
.79367 .03615 L
.79455 .03615 L
.79455 .08012 L
s
1 .894 .882 r
.79455 .08012 m
.79455 .03608 L
.79547 .03608 L
.79547 .08012 L
F
.804 .522 .247 r
.79455 .08012 m
.79455 .03608 L
.79547 .03608 L
.79547 .08012 L
s
1 .894 .882 r
.79547 .08012 m
.79547 .0359 L
.79605 .0359 L
.79605 .08012 L
F
.804 .522 .247 r
.79547 .08012 m
.79547 .0359 L
.79605 .0359 L
.79605 .08012 L
s
1 .894 .882 r
.79605 .08012 m
.79605 .03573 L
.79659 .03573 L
.79659 .08012 L
F
.804 .522 .247 r
.79605 .08012 m
.79605 .03573 L
.79659 .03573 L
.79659 .08012 L
s
1 .894 .882 r
.79659 .08012 m
.79659 .03555 L
.79798 .03555 L
.79798 .08012 L
F
.804 .522 .247 r
.79659 .08012 m
.79659 .03555 L
.79798 .03555 L
.79798 .08012 L
s
1 .894 .882 r
.79798 .08012 m
.79798 .03524 L
.79873 .03524 L
.79873 .08012 L
F
.804 .522 .247 r
.79798 .08012 m
.79798 .03524 L
.79873 .03524 L
.79873 .08012 L
s
1 .894 .882 r
.79873 .08012 m
.79873 .03496 L
.79975 .03496 L
.79975 .08012 L
F
.804 .522 .247 r
.79873 .08012 m
.79873 .03496 L
.79975 .03496 L
.79975 .08012 L
s
1 .894 .882 r
.79975 .08012 m
.79975 .03477 L
.80077 .03477 L
.80077 .08012 L
F
.804 .522 .247 r
.79975 .08012 m
.79975 .03477 L
.80077 .03477 L
.80077 .08012 L
s
1 .894 .882 r
.80077 .08012 m
.80077 .03467 L
.80123 .03467 L
.80123 .08012 L
F
.804 .522 .247 r
.80077 .08012 m
.80077 .03467 L
.80123 .03467 L
.80123 .08012 L
s
1 .894 .882 r
.80123 .08012 m
.80123 .03454 L
.80173 .03454 L
.80173 .08012 L
F
.804 .522 .247 r
.80123 .08012 m
.80123 .03454 L
.80173 .03454 L
.80173 .08012 L
s
1 .894 .882 r
.80173 .08012 m
.80173 .03432 L
.80298 .03432 L
.80298 .08012 L
F
.804 .522 .247 r
.80173 .08012 m
.80173 .03432 L
.80298 .03432 L
.80298 .08012 L
s
1 .894 .882 r
.80298 .08012 m
.80298 .03415 L
.80353 .03415 L
.80353 .08012 L
F
.804 .522 .247 r
.80298 .08012 m
.80298 .03415 L
.80353 .03415 L
.80353 .08012 L
s
1 .894 .882 r
.80353 .08012 m
.80353 .03401 L
.8042 .03401 L
.8042 .08012 L
F
.804 .522 .247 r
.80353 .08012 m
.80353 .03401 L
.8042 .03401 L
.8042 .08012 L
s
1 .894 .882 r
.8042 .08012 m
.8042 .03371 L
.80553 .03371 L
.80553 .08012 L
F
.804 .522 .247 r
.8042 .08012 m
.8042 .03371 L
.80553 .03371 L
.80553 .08012 L
s
1 .894 .882 r
.80553 .08012 m
.80553 .03354 L
.80609 .03354 L
.80609 .08012 L
F
.804 .522 .247 r
.80553 .08012 m
.80553 .03354 L
.80609 .03354 L
.80609 .08012 L
s
1 .894 .882 r
.80609 .08012 m
.80609 .03349 L
.8066 .03349 L
.8066 .08012 L
F
.804 .522 .247 r
.80609 .08012 m
.80609 .03349 L
.8066 .03349 L
.8066 .08012 L
s
1 .894 .882 r
.8066 .08012 m
.8066 .03323 L
.80779 .03323 L
.80779 .08012 L
F
.804 .522 .247 r
.8066 .08012 m
.8066 .03323 L
.80779 .03323 L
.80779 .08012 L
s
1 .894 .882 r
.80779 .08012 m
.80779 .03303 L
.80906 .03303 L
.80906 .08012 L
F
.804 .522 .247 r
.80779 .08012 m
.80779 .03303 L
.80906 .03303 L
.80906 .08012 L
s
1 .894 .882 r
.80906 .08012 m
.80906 .03278 L
.81035 .03278 L
.81035 .08012 L
F
.804 .522 .247 r
.80906 .08012 m
.80906 .03278 L
.81035 .03278 L
.81035 .08012 L
s
1 .894 .882 r
.81035 .08012 m
.81035 .0325 L
.81147 .0325 L
.81147 .08012 L
F
.804 .522 .247 r
.81035 .08012 m
.81035 .0325 L
.81147 .0325 L
.81147 .08012 L
s
1 .894 .882 r
.81147 .08012 m
.81147 .03228 L
.81279 .03228 L
.81279 .08012 L
F
.804 .522 .247 r
.81147 .08012 m
.81147 .03228 L
.81279 .03228 L
.81279 .08012 L
s
1 .894 .882 r
.81279 .08012 m
.81279 .03192 L
.81362 .03192 L
.81362 .08012 L
F
.804 .522 .247 r
.81279 .08012 m
.81279 .03192 L
.81362 .03192 L
.81362 .08012 L
s
1 .894 .882 r
.81362 .08012 m
.81362 .03167 L
.81474 .03167 L
.81474 .08012 L
F
.804 .522 .247 r
.81362 .08012 m
.81362 .03167 L
.81474 .03167 L
.81474 .08012 L
s
1 .894 .882 r
.81474 .08012 m
.81474 .03151 L
.81553 .03151 L
.81553 .08012 L
F
.804 .522 .247 r
.81474 .08012 m
.81474 .03151 L
.81553 .03151 L
.81553 .08012 L
s
1 .894 .882 r
.81553 .08012 m
.81553 .03141 L
.8164 .03141 L
.8164 .08012 L
F
.804 .522 .247 r
.81553 .08012 m
.81553 .03141 L
.8164 .03141 L
.8164 .08012 L
s
1 .894 .882 r
.8164 .08012 m
.8164 .03116 L
.81778 .03116 L
.81778 .08012 L
F
.804 .522 .247 r
.8164 .08012 m
.8164 .03116 L
.81778 .03116 L
.81778 .08012 L
s
1 .894 .882 r
.81778 .08012 m
.81778 .03085 L
.81875 .03085 L
.81875 .08012 L
F
.804 .522 .247 r
.81778 .08012 m
.81778 .03085 L
.81875 .03085 L
.81875 .08012 L
s
1 .894 .882 r
.81875 .08012 m
.81875 .03074 L
.81944 .03074 L
.81944 .08012 L
F
.804 .522 .247 r
.81875 .08012 m
.81875 .03074 L
.81944 .03074 L
.81944 .08012 L
s
1 .894 .882 r
.81944 .08012 m
.81944 .03047 L
.82038 .03047 L
.82038 .08012 L
F
.804 .522 .247 r
.81944 .08012 m
.81944 .03047 L
.82038 .03047 L
.82038 .08012 L
s
1 .894 .882 r
.82038 .08012 m
.82038 .03026 L
.82144 .03026 L
.82144 .08012 L
F
.804 .522 .247 r
.82038 .08012 m
.82038 .03026 L
.82144 .03026 L
.82144 .08012 L
s
1 .894 .882 r
.82144 .08012 m
.82144 .02999 L
.82285 .02999 L
.82285 .08012 L
F
.804 .522 .247 r
.82144 .08012 m
.82144 .02999 L
.82285 .02999 L
.82285 .08012 L
s
1 .894 .882 r
.82285 .08012 m
.82285 .0298 L
.82397 .0298 L
.82397 .08012 L
F
.804 .522 .247 r
.82285 .08012 m
.82285 .0298 L
.82397 .0298 L
.82397 .08012 L
s
1 .894 .882 r
.82397 .08012 m
.82397 .02959 L
.82488 .02959 L
.82488 .08012 L
F
.804 .522 .247 r
.82397 .08012 m
.82397 .02959 L
.82488 .02959 L
.82488 .08012 L
s
1 .894 .882 r
.82488 .08012 m
.82488 .02945 L
.82589 .02945 L
.82589 .08012 L
F
.804 .522 .247 r
.82488 .08012 m
.82488 .02945 L
.82589 .02945 L
.82589 .08012 L
s
1 .894 .882 r
.82589 .08012 m
.82589 .02933 L
.82649 .02933 L
.82649 .08012 L
F
.804 .522 .247 r
.82589 .08012 m
.82589 .02933 L
.82649 .02933 L
.82649 .08012 L
s
1 .894 .882 r
.82649 .08012 m
.82649 .02917 L
.82749 .02917 L
.82749 .08012 L
F
.804 .522 .247 r
.82649 .08012 m
.82649 .02917 L
.82749 .02917 L
.82749 .08012 L
s
1 .894 .882 r
.82749 .08012 m
.82749 .02899 L
.82817 .02899 L
.82817 .08012 L
F
.804 .522 .247 r
.82749 .08012 m
.82749 .02899 L
.82817 .02899 L
.82817 .08012 L
s
1 .894 .882 r
.82817 .08012 m
.82817 .02873 L
.8293 .02873 L
.8293 .08012 L
F
.804 .522 .247 r
.82817 .08012 m
.82817 .02873 L
.8293 .02873 L
.8293 .08012 L
s
1 .894 .882 r
.8293 .08012 m
.8293 .02864 L
.82978 .02864 L
.82978 .08012 L
F
.804 .522 .247 r
.8293 .08012 m
.8293 .02864 L
.82978 .02864 L
.82978 .08012 L
s
1 .894 .882 r
.82978 .08012 m
.82978 .02855 L
.83071 .02855 L
.83071 .08012 L
F
.804 .522 .247 r
.82978 .08012 m
.82978 .02855 L
.83071 .02855 L
.83071 .08012 L
s
1 .894 .882 r
.83071 .08012 m
.83071 .02827 L
.83165 .02827 L
.83165 .08012 L
F
.804 .522 .247 r
.83071 .08012 m
.83071 .02827 L
.83165 .02827 L
.83165 .08012 L
s
1 .894 .882 r
.83165 .08012 m
.83165 .02812 L
.83296 .02812 L
.83296 .08012 L
F
.804 .522 .247 r
.83165 .08012 m
.83165 .02812 L
.83296 .02812 L
.83296 .08012 L
s
1 .894 .882 r
.83296 .08012 m
.83296 .02795 L
.83362 .02795 L
.83362 .08012 L
F
.804 .522 .247 r
.83296 .08012 m
.83296 .02795 L
.83362 .02795 L
.83362 .08012 L
s
1 .894 .882 r
.83362 .08012 m
.83362 .02786 L
.83488 .02786 L
.83488 .08012 L
F
.804 .522 .247 r
.83362 .08012 m
.83362 .02786 L
.83488 .02786 L
.83488 .08012 L
s
1 .894 .882 r
.83488 .08012 m
.83488 .02751 L
.83596 .02751 L
.83596 .08012 L
F
.804 .522 .247 r
.83488 .08012 m
.83488 .02751 L
.83596 .02751 L
.83596 .08012 L
s
1 .894 .882 r
.83596 .08012 m
.83596 .02732 L
.83688 .02732 L
.83688 .08012 L
F
.804 .522 .247 r
.83596 .08012 m
.83596 .02732 L
.83688 .02732 L
.83688 .08012 L
s
1 .894 .882 r
.83688 .08012 m
.83688 .02717 L
.83787 .02717 L
.83787 .08012 L
F
.804 .522 .247 r
.83688 .08012 m
.83688 .02717 L
.83787 .02717 L
.83787 .08012 L
s
1 .894 .882 r
.83787 .08012 m
.83787 .02706 L
.83878 .02706 L
.83878 .08012 L
F
.804 .522 .247 r
.83787 .08012 m
.83787 .02706 L
.83878 .02706 L
.83878 .08012 L
s
1 .894 .882 r
.83878 .08012 m
.83878 .02691 L
.83942 .02691 L
.83942 .08012 L
F
.804 .522 .247 r
.83878 .08012 m
.83878 .02691 L
.83942 .02691 L
.83942 .08012 L
s
1 .894 .882 r
.83942 .08012 m
.83942 .02676 L
.84042 .02676 L
.84042 .08012 L
F
.804 .522 .247 r
.83942 .08012 m
.83942 .02676 L
.84042 .02676 L
.84042 .08012 L
s
1 .894 .882 r
.84042 .08012 m
.84042 .02668 L
.84087 .02668 L
.84087 .08012 L
F
.804 .522 .247 r
.84042 .08012 m
.84042 .02668 L
.84087 .02668 L
.84087 .08012 L
s
1 .894 .882 r
.84087 .08012 m
.84087 .0266 L
.84154 .0266 L
.84154 .08012 L
F
.804 .522 .247 r
.84087 .08012 m
.84087 .0266 L
.84154 .0266 L
.84154 .08012 L
s
1 .894 .882 r
.84154 .08012 m
.84154 .02637 L
.84269 .02637 L
.84269 .08012 L
F
.804 .522 .247 r
.84154 .08012 m
.84154 .02637 L
.84269 .02637 L
.84269 .08012 L
s
1 .894 .882 r
.84269 .08012 m
.84269 .02616 L
.84409 .02616 L
.84409 .08012 L
F
.804 .522 .247 r
.84269 .08012 m
.84269 .02616 L
.84409 .02616 L
.84409 .08012 L
s
1 .894 .882 r
.84409 .08012 m
.84409 .02603 L
.84458 .02603 L
.84458 .08012 L
F
.804 .522 .247 r
.84409 .08012 m
.84409 .02603 L
.84458 .02603 L
.84458 .08012 L
s
1 .894 .882 r
.84458 .08012 m
.84458 .02591 L
.84559 .02591 L
.84559 .08012 L
F
.804 .522 .247 r
.84458 .08012 m
.84458 .02591 L
.84559 .02591 L
.84559 .08012 L
s
1 .894 .882 r
.84559 .08012 m
.84559 .02571 L
.84626 .02571 L
.84626 .08012 L
F
.804 .522 .247 r
.84559 .08012 m
.84559 .02571 L
.84626 .02571 L
.84626 .08012 L
s
1 .894 .882 r
.84626 .08012 m
.84626 .02554 L
.8471 .02554 L
.8471 .08012 L
F
.804 .522 .247 r
.84626 .08012 m
.84626 .02554 L
.8471 .02554 L
.8471 .08012 L
s
1 .894 .882 r
.8471 .08012 m
.8471 .02539 L
.84844 .02539 L
.84844 .08012 L
F
.804 .522 .247 r
.8471 .08012 m
.8471 .02539 L
.84844 .02539 L
.84844 .08012 L
s
1 .894 .882 r
.84844 .08012 m
.84844 .02525 L
.84888 .02525 L
.84888 .08012 L
F
.804 .522 .247 r
.84844 .08012 m
.84844 .02525 L
.84888 .02525 L
.84888 .08012 L
s
1 .894 .882 r
.84888 .08012 m
.84888 .02523 L
.84932 .02523 L
.84932 .08012 L
F
.804 .522 .247 r
.84888 .08012 m
.84888 .02523 L
.84932 .02523 L
.84932 .08012 L
s
1 .894 .882 r
.84932 .08012 m
.84932 .02497 L
.85047 .02497 L
.85047 .08012 L
F
.804 .522 .247 r
.84932 .08012 m
.84932 .02497 L
.85047 .02497 L
.85047 .08012 L
s
1 .894 .882 r
.85047 .08012 m
.85047 .0248 L
.85177 .0248 L
.85177 .08012 L
F
.804 .522 .247 r
.85047 .08012 m
.85047 .0248 L
.85177 .0248 L
.85177 .08012 L
s
1 .894 .882 r
.85177 .08012 m
.85177 .02471 L
.85274 .02471 L
.85274 .08012 L
F
.804 .522 .247 r
.85177 .08012 m
.85177 .02471 L
.85274 .02471 L
.85274 .08012 L
s
1 .894 .882 r
.85274 .08012 m
.85274 .02459 L
.8537 .02459 L
.8537 .08012 L
F
.804 .522 .247 r
.85274 .08012 m
.85274 .02459 L
.8537 .02459 L
.8537 .08012 L
s
1 .894 .882 r
.8537 .08012 m
.8537 .02438 L
.85499 .02438 L
.85499 .08012 L
F
.804 .522 .247 r
.8537 .08012 m
.8537 .02438 L
.85499 .02438 L
.85499 .08012 L
s
1 .894 .882 r
.85499 .08012 m
.85499 .02422 L
.85608 .02422 L
.85608 .08012 L
F
.804 .522 .247 r
.85499 .08012 m
.85499 .02422 L
.85608 .02422 L
.85608 .08012 L
s
1 .894 .882 r
.85608 .08012 m
.85608 .02405 L
.85723 .02405 L
.85723 .08012 L
F
.804 .522 .247 r
.85608 .08012 m
.85608 .02405 L
.85723 .02405 L
.85723 .08012 L
s
1 .894 .882 r
.85723 .08012 m
.85723 .02384 L
.85858 .02384 L
.85858 .08012 L
F
.804 .522 .247 r
.85723 .08012 m
.85723 .02384 L
.85858 .02384 L
.85858 .08012 L
s
1 .894 .882 r
.85858 .08012 m
.85858 .02364 L
.85938 .02364 L
.85938 .08012 L
F
.804 .522 .247 r
.85858 .08012 m
.85858 .02364 L
.85938 .02364 L
.85938 .08012 L
s
1 .894 .882 r
.85938 .08012 m
.85938 .02354 L
.85992 .02354 L
.85992 .08012 L
F
.804 .522 .247 r
.85938 .08012 m
.85938 .02354 L
.85992 .02354 L
.85992 .08012 L
s
1 .894 .882 r
.85992 .08012 m
.85992 .02341 L
.8606 .02341 L
.8606 .08012 L
F
.804 .522 .247 r
.85992 .08012 m
.85992 .02341 L
.8606 .02341 L
.8606 .08012 L
s
1 .894 .882 r
.8606 .08012 m
.8606 .02326 L
.86174 .02326 L
.86174 .08012 L
F
.804 .522 .247 r
.8606 .08012 m
.8606 .02326 L
.86174 .02326 L
.86174 .08012 L
s
1 .894 .882 r
.86174 .08012 m
.86174 .02305 L
.863 .02305 L
.863 .08012 L
F
.804 .522 .247 r
.86174 .08012 m
.86174 .02305 L
.863 .02305 L
.863 .08012 L
s
1 .894 .882 r
.863 .08012 m
.863 .023 L
.86352 .023 L
.86352 .08012 L
F
.804 .522 .247 r
.863 .08012 m
.863 .023 L
.86352 .023 L
.86352 .08012 L
s
1 .894 .882 r
.86352 .08012 m
.86352 .02291 L
.86397 .02291 L
.86397 .08012 L
F
.804 .522 .247 r
.86352 .08012 m
.86352 .02291 L
.86397 .02291 L
.86397 .08012 L
s
1 .894 .882 r
.86397 .08012 m
.86397 .02285 L
.86541 .02285 L
.86541 .08012 L
F
.804 .522 .247 r
.86397 .08012 m
.86397 .02285 L
.86541 .02285 L
.86541 .08012 L
s
1 .894 .882 r
.86541 .08012 m
.86541 .02261 L
.86674 .02261 L
.86674 .08012 L
F
.804 .522 .247 r
.86541 .08012 m
.86541 .02261 L
.86674 .02261 L
.86674 .08012 L
s
1 .894 .882 r
.86674 .08012 m
.86674 .02247 L
.8672 .02247 L
.8672 .08012 L
F
.804 .522 .247 r
.86674 .08012 m
.86674 .02247 L
.8672 .02247 L
.8672 .08012 L
s
1 .894 .882 r
.8672 .08012 m
.8672 .02236 L
.8681 .02236 L
.8681 .08012 L
F
.804 .522 .247 r
.8672 .08012 m
.8672 .02236 L
.8681 .02236 L
.8681 .08012 L
s
1 .894 .882 r
.8681 .08012 m
.8681 .02221 L
.8693 .02221 L
.8693 .08012 L
F
.804 .522 .247 r
.8681 .08012 m
.8681 .02221 L
.8693 .02221 L
.8693 .08012 L
s
1 .894 .882 r
.8693 .08012 m
.8693 .02207 L
.87023 .02207 L
.87023 .08012 L
F
.804 .522 .247 r
.8693 .08012 m
.8693 .02207 L
.87023 .02207 L
.87023 .08012 L
s
1 .894 .882 r
.87023 .08012 m
.87023 .02195 L
.87081 .02195 L
.87081 .08012 L
F
.804 .522 .247 r
.87023 .08012 m
.87023 .02195 L
.87081 .02195 L
.87081 .08012 L
s
1 .894 .882 r
.87081 .08012 m
.87081 .02184 L
.8717 .02184 L
.8717 .08012 L
F
.804 .522 .247 r
.87081 .08012 m
.87081 .02184 L
.8717 .02184 L
.8717 .08012 L
s
1 .894 .882 r
.8717 .08012 m
.8717 .02173 L
.8729 .02173 L
.8729 .08012 L
F
.804 .522 .247 r
.8717 .08012 m
.8717 .02173 L
.8729 .02173 L
.8729 .08012 L
s
1 .894 .882 r
.8729 .08012 m
.8729 .02156 L
.87413 .02156 L
.87413 .08012 L
F
.804 .522 .247 r
.8729 .08012 m
.8729 .02156 L
.87413 .02156 L
.87413 .08012 L
s
1 .894 .882 r
.87413 .08012 m
.87413 .02139 L
.87487 .02139 L
.87487 .08012 L
F
.804 .522 .247 r
.87413 .08012 m
.87413 .02139 L
.87487 .02139 L
.87487 .08012 L
s
1 .894 .882 r
.87487 .08012 m
.87487 .02132 L
.87625 .02132 L
.87625 .08012 L
F
.804 .522 .247 r
.87487 .08012 m
.87487 .02132 L
.87625 .02132 L
.87625 .08012 L
s
1 .894 .882 r
.87625 .08012 m
.87625 .02117 L
.87693 .02117 L
.87693 .08012 L
F
.804 .522 .247 r
.87625 .08012 m
.87625 .02117 L
.87693 .02117 L
.87693 .08012 L
s
1 .894 .882 r
.87693 .08012 m
.87693 .02109 L
.87832 .02109 L
.87832 .08012 L
F
.804 .522 .247 r
.87693 .08012 m
.87693 .02109 L
.87832 .02109 L
.87832 .08012 L
s
1 .894 .882 r
.87832 .08012 m
.87832 .02083 L
.87944 .02083 L
.87944 .08012 L
F
.804 .522 .247 r
.87832 .08012 m
.87832 .02083 L
.87944 .02083 L
.87944 .08012 L
s
1 .894 .882 r
.87944 .08012 m
.87944 .02078 L
.88009 .02078 L
.88009 .08012 L
F
.804 .522 .247 r
.87944 .08012 m
.87944 .02078 L
.88009 .02078 L
.88009 .08012 L
s
1 .894 .882 r
.88009 .08012 m
.88009 .02071 L
.88089 .02071 L
.88089 .08012 L
F
.804 .522 .247 r
.88009 .08012 m
.88009 .02071 L
.88089 .02071 L
.88089 .08012 L
s
1 .894 .882 r
.88089 .08012 m
.88089 .02052 L
.88191 .02052 L
.88191 .08012 L
F
.804 .522 .247 r
.88089 .08012 m
.88089 .02052 L
.88191 .02052 L
.88191 .08012 L
s
1 .894 .882 r
.88191 .08012 m
.88191 .02045 L
.88292 .02045 L
.88292 .08012 L
F
.804 .522 .247 r
.88191 .08012 m
.88191 .02045 L
.88292 .02045 L
.88292 .08012 L
s
1 .894 .882 r
.88292 .08012 m
.88292 .02029 L
.88436 .02029 L
.88436 .08012 L
F
.804 .522 .247 r
.88292 .08012 m
.88292 .02029 L
.88436 .02029 L
.88436 .08012 L
s
1 .894 .882 r
.88436 .08012 m
.88436 .02015 L
.88547 .02015 L
.88547 .08012 L
F
.804 .522 .247 r
.88436 .08012 m
.88436 .02015 L
.88547 .02015 L
.88547 .08012 L
s
1 .894 .882 r
.88547 .08012 m
.88547 .01994 L
.88668 .01994 L
.88668 .08012 L
F
.804 .522 .247 r
.88547 .08012 m
.88547 .01994 L
.88668 .01994 L
.88668 .08012 L
s
1 .894 .882 r
.88668 .08012 m
.88668 .01982 L
.88761 .01982 L
.88761 .08012 L
F
.804 .522 .247 r
.88668 .08012 m
.88668 .01982 L
.88761 .01982 L
.88761 .08012 L
s
1 .894 .882 r
.88761 .08012 m
.88761 .01969 L
.88903 .01969 L
.88903 .08012 L
F
.804 .522 .247 r
.88761 .08012 m
.88761 .01969 L
.88903 .01969 L
.88903 .08012 L
s
1 .894 .882 r
.88903 .08012 m
.88903 .01963 L
.89016 .01963 L
.89016 .08012 L
F
.804 .522 .247 r
.88903 .08012 m
.88903 .01963 L
.89016 .01963 L
.89016 .08012 L
s
1 .894 .882 r
.89016 .08012 m
.89016 .01946 L
.8915 .01946 L
.8915 .08012 L
F
.804 .522 .247 r
.89016 .08012 m
.89016 .01946 L
.8915 .01946 L
.8915 .08012 L
s
1 .894 .882 r
.8915 .08012 m
.8915 .01931 L
.89241 .01931 L
.89241 .08012 L
F
.804 .522 .247 r
.8915 .08012 m
.8915 .01931 L
.89241 .01931 L
.89241 .08012 L
s
1 .894 .882 r
.89241 .08012 m
.89241 .01925 L
.89337 .01925 L
.89337 .08012 L
F
.804 .522 .247 r
.89241 .08012 m
.89241 .01925 L
.89337 .01925 L
.89337 .08012 L
s
1 .894 .882 r
.89337 .08012 m
.89337 .01908 L
.89474 .01908 L
.89474 .08012 L
F
.804 .522 .247 r
.89337 .08012 m
.89337 .01908 L
.89474 .01908 L
.89474 .08012 L
s
1 .894 .882 r
.89474 .08012 m
.89474 .01894 L
.89559 .01894 L
.89559 .08012 L
F
.804 .522 .247 r
.89474 .08012 m
.89474 .01894 L
.89559 .01894 L
.89559 .08012 L
s
1 .894 .882 r
.89559 .08012 m
.89559 .01886 L
.89636 .01886 L
.89636 .08012 L
F
.804 .522 .247 r
.89559 .08012 m
.89559 .01886 L
.89636 .01886 L
.89636 .08012 L
s
1 .894 .882 r
.89636 .08012 m
.89636 .01882 L
.89686 .01882 L
.89686 .08012 L
F
.804 .522 .247 r
.89636 .08012 m
.89636 .01882 L
.89686 .01882 L
.89686 .08012 L
s
1 .894 .882 r
.89686 .08012 m
.89686 .01879 L
.89748 .01879 L
.89748 .08012 L
F
.804 .522 .247 r
.89686 .08012 m
.89686 .01879 L
.89748 .01879 L
.89748 .08012 L
s
1 .894 .882 r
.89748 .08012 m
.89748 .01869 L
.89855 .01869 L
.89855 .08012 L
F
.804 .522 .247 r
.89748 .08012 m
.89748 .01869 L
.89855 .01869 L
.89855 .08012 L
s
1 .894 .882 r
.89855 .08012 m
.89855 .01863 L
.89901 .01863 L
.89901 .08012 L
F
.804 .522 .247 r
.89855 .08012 m
.89855 .01863 L
.89901 .01863 L
.89901 .08012 L
s
1 .894 .882 r
.89901 .08012 m
.89901 .01857 L
.8996 .01857 L
.8996 .08012 L
F
.804 .522 .247 r
.89901 .08012 m
.89901 .01857 L
.8996 .01857 L
.8996 .08012 L
s
1 .894 .882 r
.8996 .08012 m
.8996 .0184 L
.90099 .0184 L
.90099 .08012 L
F
.804 .522 .247 r
.8996 .08012 m
.8996 .0184 L
.90099 .0184 L
.90099 .08012 L
s
1 .894 .882 r
.90099 .08012 m
.90099 .01835 L
.90213 .01835 L
.90213 .08012 L
F
.804 .522 .247 r
.90099 .08012 m
.90099 .01835 L
.90213 .01835 L
.90213 .08012 L
s
1 .894 .882 r
.90213 .08012 m
.90213 .01825 L
.90293 .01825 L
.90293 .08012 L
F
.804 .522 .247 r
.90213 .08012 m
.90213 .01825 L
.90293 .01825 L
.90293 .08012 L
s
1 .894 .882 r
.90293 .08012 m
.90293 .01819 L
.90432 .01819 L
.90432 .08012 L
F
.804 .522 .247 r
.90293 .08012 m
.90293 .01819 L
.90432 .01819 L
.90432 .08012 L
s
1 .894 .882 r
.90432 .08012 m
.90432 .01798 L
.90535 .01798 L
.90535 .08012 L
F
.804 .522 .247 r
.90432 .08012 m
.90432 .01798 L
.90535 .01798 L
.90535 .08012 L
s
1 .894 .882 r
.90535 .08012 m
.90535 .01794 L
.90591 .01794 L
.90591 .08012 L
F
.804 .522 .247 r
.90535 .08012 m
.90535 .01794 L
.90591 .01794 L
.90591 .08012 L
s
1 .894 .882 r
.90591 .08012 m
.90591 .01792 L
.90715 .01792 L
.90715 .08012 L
F
.804 .522 .247 r
.90591 .08012 m
.90591 .01792 L
.90715 .01792 L
.90715 .08012 L
s
1 .894 .882 r
.90715 .08012 m
.90715 .01773 L
.90856 .01773 L
.90856 .08012 L
F
.804 .522 .247 r
.90715 .08012 m
.90715 .01773 L
.90856 .01773 L
.90856 .08012 L
s
1 .894 .882 r
.90856 .08012 m
.90856 .01762 L
.90994 .01762 L
.90994 .08012 L
F
.804 .522 .247 r
.90856 .08012 m
.90856 .01762 L
.90994 .01762 L
.90994 .08012 L
s
1 .894 .882 r
.90994 .08012 m
.90994 .01751 L
.91074 .01751 L
.91074 .08012 L
F
.804 .522 .247 r
.90994 .08012 m
.90994 .01751 L
.91074 .01751 L
.91074 .08012 L
s
1 .894 .882 r
.91074 .08012 m
.91074 .01749 L
.91148 .01749 L
.91148 .08012 L
F
.804 .522 .247 r
.91074 .08012 m
.91074 .01749 L
.91148 .01749 L
.91148 .08012 L
s
1 .894 .882 r
.91148 .08012 m
.91148 .01732 L
.91293 .01732 L
.91293 .08012 L
F
.804 .522 .247 r
.91148 .08012 m
.91148 .01732 L
.91293 .01732 L
.91293 .08012 L
s
1 .894 .882 r
.91293 .08012 m
.91293 .01729 L
.91362 .01729 L
.91362 .08012 L
F
.804 .522 .247 r
.91293 .08012 m
.91293 .01729 L
.91362 .01729 L
.91362 .08012 L
s
1 .894 .882 r
.91362 .08012 m
.91362 .01722 L
.91453 .01722 L
.91453 .08012 L
F
.804 .522 .247 r
.91362 .08012 m
.91362 .01722 L
.91453 .01722 L
.91453 .08012 L
s
1 .894 .882 r
.91453 .08012 m
.91453 .01713 L
.91583 .01713 L
.91583 .08012 L
F
.804 .522 .247 r
.91453 .08012 m
.91453 .01713 L
.91583 .01713 L
.91583 .08012 L
s
1 .894 .882 r
.91583 .08012 m
.91583 .01703 L
.91675 .01703 L
.91675 .08012 L
F
.804 .522 .247 r
.91583 .08012 m
.91583 .01703 L
.91675 .01703 L
.91675 .08012 L
s
1 .894 .882 r
.91675 .08012 m
.91675 .01696 L
.91752 .01696 L
.91752 .08012 L
F
.804 .522 .247 r
.91675 .08012 m
.91675 .01696 L
.91752 .01696 L
.91752 .08012 L
s
1 .894 .882 r
.91752 .08012 m
.91752 .01693 L
.91802 .01693 L
.91802 .08012 L
F
.804 .522 .247 r
.91752 .08012 m
.91752 .01693 L
.91802 .01693 L
.91802 .08012 L
s
1 .894 .882 r
.91802 .08012 m
.91802 .01686 L
.91899 .01686 L
.91899 .08012 L
F
.804 .522 .247 r
.91802 .08012 m
.91802 .01686 L
.91899 .01686 L
.91899 .08012 L
s
1 .894 .882 r
.91899 .08012 m
.91899 .01683 L
.91984 .01683 L
.91984 .08012 L
F
.804 .522 .247 r
.91899 .08012 m
.91899 .01683 L
.91984 .01683 L
.91984 .08012 L
s
1 .894 .882 r
.91984 .08012 m
.91984 .01675 L
.92044 .01675 L
.92044 .08012 L
F
.804 .522 .247 r
.91984 .08012 m
.91984 .01675 L
.92044 .01675 L
.92044 .08012 L
s
1 .894 .882 r
.92044 .08012 m
.92044 .01673 L
.92132 .01673 L
.92132 .08012 L
F
.804 .522 .247 r
.92044 .08012 m
.92044 .01673 L
.92132 .01673 L
.92132 .08012 L
s
1 .894 .882 r
.92132 .08012 m
.92132 .01663 L
.92226 .01663 L
.92226 .08012 L
F
.804 .522 .247 r
.92132 .08012 m
.92132 .01663 L
.92226 .01663 L
.92226 .08012 L
s
1 .894 .882 r
.92226 .08012 m
.92226 .01656 L
.92296 .01656 L
.92296 .08012 L
F
.804 .522 .247 r
.92226 .08012 m
.92226 .01656 L
.92296 .01656 L
.92296 .08012 L
s
1 .894 .882 r
.92296 .08012 m
.92296 .01652 L
.92363 .01652 L
.92363 .08012 L
F
.804 .522 .247 r
.92296 .08012 m
.92296 .01652 L
.92363 .01652 L
.92363 .08012 L
s
1 .894 .882 r
.92363 .08012 m
.92363 .01645 L
.92483 .01645 L
.92483 .08012 L
F
.804 .522 .247 r
.92363 .08012 m
.92363 .01645 L
.92483 .01645 L
.92483 .08012 L
s
1 .894 .882 r
.92483 .08012 m
.92483 .01642 L
.9254 .01642 L
.9254 .08012 L
F
.804 .522 .247 r
.92483 .08012 m
.92483 .01642 L
.9254 .01642 L
.9254 .08012 L
s
1 .894 .882 r
.9254 .08012 m
.9254 .01634 L
.92617 .01634 L
.92617 .08012 L
F
.804 .522 .247 r
.9254 .08012 m
.9254 .01634 L
.92617 .01634 L
.92617 .08012 L
s
1 .894 .882 r
.92617 .08012 m
.92617 .01628 L
.92726 .01628 L
.92726 .08012 L
F
.804 .522 .247 r
.92617 .08012 m
.92617 .01628 L
.92726 .01628 L
.92726 .08012 L
s
1 .894 .882 r
.92726 .08012 m
.92726 .01627 L
.92834 .01627 L
.92834 .08012 L
F
.804 .522 .247 r
.92726 .08012 m
.92726 .01627 L
.92834 .01627 L
.92834 .08012 L
s
1 .894 .882 r
.92834 .08012 m
.92834 .01619 L
.92913 .01619 L
.92913 .08012 L
F
.804 .522 .247 r
.92834 .08012 m
.92834 .01619 L
.92913 .01619 L
.92913 .08012 L
s
1 .894 .882 r
.92913 .08012 m
.92913 .01614 L
.92994 .01614 L
.92994 .08012 L
F
.804 .522 .247 r
.92913 .08012 m
.92913 .01614 L
.92994 .01614 L
.92994 .08012 L
s
1 .894 .882 r
.92994 .08012 m
.92994 .01608 L
.93111 .01608 L
.93111 .08012 L
F
.804 .522 .247 r
.92994 .08012 m
.92994 .01608 L
.93111 .01608 L
.93111 .08012 L
s
1 .894 .882 r
.93111 .08012 m
.93111 .01603 L
.93183 .01603 L
.93183 .08012 L
F
.804 .522 .247 r
.93111 .08012 m
.93111 .01603 L
.93183 .01603 L
.93183 .08012 L
s
1 .894 .882 r
.93183 .08012 m
.93183 .01599 L
.93231 .01599 L
.93231 .08012 L
F
.804 .522 .247 r
.93183 .08012 m
.93183 .01599 L
.93231 .01599 L
.93231 .08012 L
s
1 .894 .882 r
.93231 .08012 m
.93231 .01595 L
.93314 .01595 L
.93314 .08012 L
F
.804 .522 .247 r
.93231 .08012 m
.93231 .01595 L
.93314 .01595 L
.93314 .08012 L
s
1 .894 .882 r
.93314 .08012 m
.93314 .01587 L
.93404 .01587 L
.93404 .08012 L
F
.804 .522 .247 r
.93314 .08012 m
.93314 .01587 L
.93404 .01587 L
.93404 .08012 L
s
1 .894 .882 r
.93404 .08012 m
.93404 .01582 L
.9353 .01582 L
.9353 .08012 L
F
.804 .522 .247 r
.93404 .08012 m
.93404 .01582 L
.9353 .01582 L
.9353 .08012 L
s
1 .894 .882 r
.9353 .08012 m
.9353 .01578 L
.93595 .01578 L
.93595 .08012 L
F
.804 .522 .247 r
.9353 .08012 m
.9353 .01578 L
.93595 .01578 L
.93595 .08012 L
s
1 .894 .882 r
.93595 .08012 m
.93595 .01573 L
.93731 .01573 L
.93731 .08012 L
F
.804 .522 .247 r
.93595 .08012 m
.93595 .01573 L
.93731 .01573 L
.93731 .08012 L
s
1 .894 .882 r
.93731 .08012 m
.93731 .01569 L
.93788 .01569 L
.93788 .08012 L
F
.804 .522 .247 r
.93731 .08012 m
.93731 .01569 L
.93788 .01569 L
.93788 .08012 L
s
1 .894 .882 r
.93788 .08012 m
.93788 .01565 L
.93908 .01565 L
.93908 .08012 L
F
.804 .522 .247 r
.93788 .08012 m
.93788 .01565 L
.93908 .01565 L
.93908 .08012 L
s
1 .894 .882 r
.93908 .08012 m
.93908 .01556 L
.94021 .01556 L
.94021 .08012 L
F
.804 .522 .247 r
.93908 .08012 m
.93908 .01556 L
.94021 .01556 L
.94021 .08012 L
s
1 .894 .882 r
.94021 .08012 m
.94021 .01554 L
.94116 .01554 L
.94116 .08012 L
F
.804 .522 .247 r
.94021 .08012 m
.94021 .01554 L
.94116 .01554 L
.94116 .08012 L
s
1 .894 .882 r
.94116 .08012 m
.94116 .01549 L
.94258 .01549 L
.94258 .08012 L
F
.804 .522 .247 r
.94116 .08012 m
.94116 .01549 L
.94258 .01549 L
.94258 .08012 L
s
1 .894 .882 r
.94258 .08012 m
.94258 .01544 L
.94335 .01544 L
.94335 .08012 L
F
.804 .522 .247 r
.94258 .08012 m
.94258 .01544 L
.94335 .01544 L
.94335 .08012 L
s
1 .894 .882 r
.94335 .08012 m
.94335 .01541 L
.94397 .01541 L
.94397 .08012 L
F
.804 .522 .247 r
.94335 .08012 m
.94335 .01541 L
.94397 .01541 L
.94397 .08012 L
s
1 .894 .882 r
.94397 .08012 m
.94397 .01538 L
.94466 .01538 L
.94466 .08012 L
F
.804 .522 .247 r
.94397 .08012 m
.94397 .01538 L
.94466 .01538 L
.94466 .08012 L
s
1 .894 .882 r
.94466 .08012 m
.94466 .01533 L
.94585 .01533 L
.94585 .08012 L
F
.804 .522 .247 r
.94466 .08012 m
.94466 .01533 L
.94585 .01533 L
.94585 .08012 L
s
1 .894 .882 r
.94585 .08012 m
.94585 .01529 L
.94687 .01529 L
.94687 .08012 L
F
.804 .522 .247 r
.94585 .08012 m
.94585 .01529 L
.94687 .01529 L
.94687 .08012 L
s
1 .894 .882 r
.94687 .08012 m
.94687 .01527 L
.94735 .01527 L
.94735 .08012 L
F
.804 .522 .247 r
.94687 .08012 m
.94687 .01527 L
.94735 .01527 L
.94735 .08012 L
s
1 .894 .882 r
.94735 .08012 m
.94735 .01522 L
.94873 .01522 L
.94873 .08012 L
F
.804 .522 .247 r
.94735 .08012 m
.94735 .01522 L
.94873 .01522 L
.94873 .08012 L
s
1 .894 .882 r
.94873 .08012 m
.94873 .01519 L
.94928 .01519 L
.94928 .08012 L
F
.804 .522 .247 r
.94873 .08012 m
.94873 .01519 L
.94928 .01519 L
.94928 .08012 L
s
1 .894 .882 r
.94928 .08012 m
.94928 .01516 L
.95067 .01516 L
.95067 .08012 L
F
.804 .522 .247 r
.94928 .08012 m
.94928 .01516 L
.95067 .01516 L
.95067 .08012 L
s
1 .894 .882 r
.95067 .08012 m
.95067 .01511 L
.95182 .01511 L
.95182 .08012 L
F
.804 .522 .247 r
.95067 .08012 m
.95067 .01511 L
.95182 .01511 L
.95182 .08012 L
s
1 .894 .882 r
.95182 .08012 m
.95182 .01509 L
.95282 .01509 L
.95282 .08012 L
F
.804 .522 .247 r
.95182 .08012 m
.95182 .01509 L
.95282 .01509 L
.95282 .08012 L
s
1 .894 .882 r
.95282 .08012 m
.95282 .01506 L
.95366 .01506 L
.95366 .08012 L
F
.804 .522 .247 r
.95282 .08012 m
.95282 .01506 L
.95366 .01506 L
.95366 .08012 L
s
1 .894 .882 r
.95366 .08012 m
.95366 .01503 L
.95477 .01503 L
.95477 .08012 L
F
.804 .522 .247 r
.95366 .08012 m
.95366 .01503 L
.95477 .01503 L
.95477 .08012 L
s
1 .894 .882 r
.95477 .08012 m
.95477 .01499 L
.95587 .01499 L
.95587 .08012 L
F
.804 .522 .247 r
.95477 .08012 m
.95477 .01499 L
.95587 .01499 L
.95587 .08012 L
s
1 .894 .882 r
.95587 .08012 m
.95587 .01498 L
.95648 .01498 L
.95648 .08012 L
F
.804 .522 .247 r
.95587 .08012 m
.95587 .01498 L
.95648 .01498 L
.95648 .08012 L
s
1 .894 .882 r
.95648 .08012 m
.95648 .01495 L
.95787 .01495 L
.95787 .08012 L
F
.804 .522 .247 r
.95648 .08012 m
.95648 .01495 L
.95787 .01495 L
.95787 .08012 L
s
1 .894 .882 r
.95787 .08012 m
.95787 .01492 L
.95917 .01492 L
.95917 .08012 L
F
.804 .522 .247 r
.95787 .08012 m
.95787 .01492 L
.95917 .01492 L
.95917 .08012 L
s
1 .894 .882 r
.95917 .08012 m
.95917 .0149 L
.96007 .0149 L
.96007 .08012 L
F
.804 .522 .247 r
.95917 .08012 m
.95917 .0149 L
.96007 .0149 L
.96007 .08012 L
s
1 .894 .882 r
.96007 .08012 m
.96007 .01488 L
.96077 .01488 L
.96077 .08012 L
F
.804 .522 .247 r
.96007 .08012 m
.96007 .01488 L
.96077 .01488 L
.96077 .08012 L
s
1 .894 .882 r
.96077 .08012 m
.96077 .01486 L
.96204 .01486 L
.96204 .08012 L
F
.804 .522 .247 r
.96077 .08012 m
.96077 .01486 L
.96204 .01486 L
.96204 .08012 L
s
1 .894 .882 r
.96204 .08012 m
.96204 .01484 L
.96257 .01484 L
.96257 .08012 L
F
.804 .522 .247 r
.96204 .08012 m
.96204 .01484 L
.96257 .01484 L
.96257 .08012 L
s
1 .894 .882 r
.96257 .08012 m
.96257 .01483 L
.9638 .01483 L
.9638 .08012 L
F
.804 .522 .247 r
.96257 .08012 m
.96257 .01483 L
.9638 .01483 L
.9638 .08012 L
s
1 .894 .882 r
.9638 .08012 m
.9638 .01481 L
.965 .01481 L
.965 .08012 L
F
.804 .522 .247 r
.9638 .08012 m
.9638 .01481 L
.965 .01481 L
.965 .08012 L
s
1 .894 .882 r
.965 .08012 m
.965 .01479 L
.9663 .01479 L
.9663 .08012 L
F
.804 .522 .247 r
.965 .08012 m
.965 .01479 L
.9663 .01479 L
.9663 .08012 L
s
1 .894 .882 r
.9663 .08012 m
.9663 .01478 L
.96752 .01478 L
.96752 .08012 L
F
.804 .522 .247 r
.9663 .08012 m
.9663 .01478 L
.96752 .01478 L
.96752 .08012 L
s
1 .894 .882 r
.96752 .08012 m
.96752 .01476 L
.96857 .01476 L
.96857 .08012 L
F
.804 .522 .247 r
.96752 .08012 m
.96752 .01476 L
.96857 .01476 L
.96857 .08012 L
s
1 .894 .882 r
.96857 .08012 m
.96857 .01475 L
.96951 .01475 L
.96951 .08012 L
F
.804 .522 .247 r
.96857 .08012 m
.96857 .01475 L
.96951 .01475 L
.96951 .08012 L
s
1 .894 .882 r
.96951 .08012 m
.96951 .01474 L
.97006 .01474 L
.97006 .08012 L
F
.804 .522 .247 r
.96951 .08012 m
.96951 .01474 L
.97006 .01474 L
.97006 .08012 L
s
1 .894 .882 r
.97006 .08012 m
.97006 .01474 L
.9707 .01474 L
.9707 .08012 L
F
.804 .522 .247 r
.97006 .08012 m
.97006 .01474 L
.9707 .01474 L
.9707 .08012 L
s
1 .894 .882 r
.9707 .08012 m
.9707 .01473 L
.9717 .01473 L
.9717 .08012 L
F
.804 .522 .247 r
.9707 .08012 m
.9707 .01473 L
.9717 .01473 L
.9717 .08012 L
s
1 .894 .882 r
.9717 .08012 m
.9717 .01473 L
.97272 .01473 L
.97272 .08012 L
F
.804 .522 .247 r
.9717 .08012 m
.9717 .01473 L
.97272 .01473 L
.97272 .08012 L
s
1 .894 .882 r
.97272 .08012 m
.97272 .01472 L
.97418 .01472 L
.97418 .08012 L
F
.804 .522 .247 r
.97272 .08012 m
.97272 .01472 L
.97418 .01472 L
.97418 .08012 L
s
1 .894 .882 r
.97418 .08012 m
.97418 .01472 L
.97488 .01472 L
.97488 .08012 L
F
.804 .522 .247 r
.97418 .08012 m
.97418 .01472 L
.97488 .01472 L
.97488 .08012 L
s
1 .894 .882 r
.97488 .08012 m
.97488 .01472 L
.97619 .01472 L
.97619 .08012 L
F
.804 .522 .247 r
.97488 .08012 m
.97488 .01472 L
.97619 .01472 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.02384 .60328 Mdot
.02612 .60047 Mdot
.02736 .59893 Mdot
.02802 .59812 Mdot
.02951 .5963 Mdot
.03045 .59514 Mdot
.03175 .59355 Mdot
.03298 .59204 Mdot
.03398 .59081 Mdot
.03522 .58929 Mdot
.03612 .5882 Mdot
.0372 .58689 Mdot
.03844 .58538 Mdot
.03867 .58509 Mdot
.04097 .5823 Mdot
.04149 .58167 Mdot
.04262 .5803 Mdot
.04417 .57842 Mdot
.04513 .57726 Mdot
.0461 .57609 Mdot
.04683 .5752 Mdot
.04776 .57408 Mdot
.04813 .57364 Mdot
.04977 .57167 Mdot
.0504 .5709 Mdot
.05087 .57035 Mdot
.0523 .56863 Mdot
.05301 .56777 Mdot
.05357 .5671 Mdot
.0543 .56623 Mdot
.05479 .56565 Mdot
.056 .5642 Mdot
.05711 .56288 Mdot
.0581 .56169 Mdot
.05847 .56125 Mdot
.05884 .56081 Mdot
.05979 .55969 Mdot
.06079 .5585 Mdot
.06143 .55773 Mdot
.06256 .5564 Mdot
.06299 .55589 Mdot
.06415 .55452 Mdot
.0651 .55339 Mdot
.06594 .5524 Mdot
.06622 .55206 Mdot
.0676 .55043 Mdot
.06798 .54999 Mdot
.0693 .54843 Mdot
.07009 .5475 Mdot
.07101 .54643 Mdot
.07197 .54529 Mdot
.07258 .54458 Mdot
.07399 .54293 Mdot
.07435 .54251 Mdot
.07612 .54044 Mdot
.07694 .53948 Mdot
.0784 .53778 Mdot
.0791 .53695 Mdot
.07992 .53601 Mdot
.08113 .5346 Mdot
.08261 .53288 Mdot
.0829 .53254 Mdot
.08368 .53164 Mdot
.0842 .53103 Mdot
.08544 .5296 Mdot
.08594 .52903 Mdot
.08705 .52775 Mdot
.08797 .52669 Mdot
.08905 .52544 Mdot
.09014 .52418 Mdot
.09074 .52349 Mdot
.09169 .52241 Mdot
.0932 .52068 Mdot
.09394 .51982 Mdot
.09472 .51894 Mdot
.09572 .51779 Mdot
.09649 .51691 Mdot
.09804 .51514 Mdot
.09834 .5148 Mdot
.09939 .51361 Mdot
.10079 .51201 Mdot
.10144 .51128 Mdot
.10178 .51089 Mdot
.10322 .50926 Mdot
.10488 .50737 Mdot
.10542 .50676 Mdot
.10699 .50499 Mdot
.10737 .50456 Mdot
.10889 .50285 Mdot
.10974 .50189 Mdot
.11113 .50033 Mdot
.11193 .49944 Mdot
.11306 .49817 Mdot
.11358 .49759 Mdot
.11477 .49626 Mdot
.11605 .49483 Mdot
.11681 .49398 Mdot
.1173 .49343 Mdot
.11877 .49179 Mdot
.11937 .49112 Mdot
.12051 .48986 Mdot
.12111 .4892 Mdot
.12232 .48785 Mdot
.1235 .48654 Mdot
.12413 .48584 Mdot
.12489 .48501 Mdot
.12574 .48407 Mdot
.12647 .48326 Mdot
.12749 .48214 Mdot
.12797 .48161 Mdot
.12987 .47952 Mdot
.13058 .47874 Mdot
.13181 .47739 Mdot
.13263 .4765 Mdot
.13386 .47515 Mdot
.13507 .47383 Mdot
.13539 .47348 Mdot
.13684 .4719 Mdot
.13785 .47079 Mdot
.13868 .46989 Mdot
.1397 .46879 Mdot
.14021 .46823 Mdot
.14098 .4674 Mdot
.14187 .46643 Mdot
.14215 .46613 Mdot
.1428 .46543 Mdot
.14353 .46464 Mdot
.14403 .4641 Mdot
.14602 .46195 Mdot
.14672 .4612 Mdot
.14772 .46012 Mdot
.14858 .4592 Mdot
.14904 .4587 Mdot
.15034 .45731 Mdot
.15181 .45573 Mdot
.15212 .4554 Mdot
.15372 .4537 Mdot
.15437 .453 Mdot
.15575 .45153 Mdot
.15617 .45108 Mdot
.15764 .44952 Mdot
.1595 .44754 Mdot
.16021 .4468 Mdot
.16097 .44599 Mdot
.16263 .44423 Mdot
.16343 .44339 Mdot
.16475 .44199 Mdot
.16521 .44151 Mdot
.16615 .44052 Mdot
.16669 .43996 Mdot
.16774 .43886 Mdot
.16839 .43818 Mdot
.16995 .43654 Mdot
.17048 .43599 Mdot
.17179 .43461 Mdot
.17239 .43399 Mdot
.17311 .43324 Mdot
.17404 .43227 Mdot
.17565 .4306 Mdot
.17617 .43006 Mdot
.17704 .42916 Mdot
.17801 .42815 Mdot
.17935 .42676 Mdot
.17964 .42646 Mdot
.18075 .42532 Mdot
.18115 .4249 Mdot
.18256 .42344 Mdot
.18303 .42296 Mdot
.18436 .4216 Mdot
.18469 .42126 Mdot
.18559 .42033 Mdot
.18654 .41935 Mdot
.18709 .4188 Mdot
.18827 .41759 Mdot
.1899 .41592 Mdot
.19032 .4155 Mdot
.1918 .41399 Mdot
.19239 .41338 Mdot
.19474 .411 Mdot
.19513 .4106 Mdot
.19548 .41024 Mdot
.19654 .40917 Mdot
.1967 .40901 Mdot
.19762 .40808 Mdot
.1988 .40689 Mdot
.20018 .4055 Mdot
.20048 .4052 Mdot
.20186 .4038 Mdot
.20294 .40272 Mdot
.20434 .40132 Mdot
.20508 .40058 Mdot
.2062 .39946 Mdot
.20767 .39799 Mdot
.20806 .3976 Mdot
.2092 .39646 Mdot
.21003 .39564 Mdot
.2113 .39438 Mdot
.21202 .39367 Mdot
.21246 .39323 Mdot
.21391 .39179 Mdot
.2147 .39101 Mdot
.2154 .39032 Mdot
.21605 .38968 Mdot
.21703 .38871 Mdot
.21852 .38725 Mdot
.21891 .38686 Mdot
.21991 .38588 Mdot
.22061 .38519 Mdot
.22198 .38385 Mdot
.22283 .38302 Mdot
.2238 .38208 Mdot
.22433 .38155 Mdot
.22574 .38018 Mdot
.22662 .37932 Mdot
.22802 .37797 Mdot
.22899 .37703 Mdot
.23066 .3754 Mdot
.23125 .37484 Mdot
.23266 .37347 Mdot
.23354 .37263 Mdot
.23493 .37128 Mdot
.2362 .37006 Mdot
.23713 .36917 Mdot
.23867 .36769 Mdot
.23964 .36677 Mdot
.24069 .36577 Mdot
.24203 .36449 Mdot
.24258 .36396 Mdot
.24388 .36273 Mdot
.24461 .36204 Mdot
.24518 .36149 Mdot
.24572 .36098 Mdot
.24629 .36044 Mdot
.24775 .35906 Mdot
.2485 .35835 Mdot
.24905 .35783 Mdot
.25057 .3564 Mdot
.25193 .35511 Mdot
.25252 .35456 Mdot
.25337 .35377 Mdot
.25395 .35322 Mdot
.25514 .35211 Mdot
.25592 .35137 Mdot
.25715 .35023 Mdot
.25795 .34948 Mdot
.25875 .34873 Mdot
.25945 .34809 Mdot
.2607 .34692 Mdot
.26167 .34602 Mdot
.26325 .34456 Mdot
.26417 .34371 Mdot
.26499 .34295 Mdot
.26733 .3408 Mdot
.26797 .34021 Mdot
.2689 .33936 Mdot
.27103 .3374 Mdot
.27155 .33692 Mdot
.27238 .33617 Mdot
.27316 .33545 Mdot
.2744 .33432 Mdot
.27479 .33397 Mdot
.27518 .33361 Mdot
.27616 .33272 Mdot
.27683 .33211 Mdot
.27866 .33046 Mdot
.27937 .32981 Mdot
.28093 .3284 Mdot
.28131 .32806 Mdot
.28178 .32764 Mdot
.28232 .32715 Mdot
.28392 .32571 Mdot
.28459 .3251 Mdot
.28527 .32449 Mdot
.28594 .3239 Mdot
.28686 .32308 Mdot
.28819 .32189 Mdot
.28909 .32108 Mdot
.28949 .32072 Mdot
.29079 .31957 Mdot
.29176 .3187 Mdot
.29283 .31775 Mdot
.29308 .31754 Mdot
.29434 .31642 Mdot
.29582 .31511 Mdot
.29689 .31417 Mdot
.29839 .31285 Mdot
.29852 .31273 Mdot
.29973 .31166 Mdot
.30051 .31098 Mdot
.30131 .31028 Mdot
.30207 .30962 Mdot
.30373 .30817 Mdot
.30405 .30789 Mdot
.3054 .30671 Mdot
.30597 .30621 Mdot
.30703 .30529 Mdot
.30763 .30477 Mdot
.30905 .30354 Mdot
.3101 .30263 Mdot
.31085 .30199 Mdot
.31219 .30083 Mdot
.31277 .30033 Mdot
.3142 .2991 Mdot
.31525 .2982 Mdot
.31648 .29714 Mdot
.31754 .29623 Mdot
.31832 .29557 Mdot
.32001 .29413 Mdot
.32104 .29325 Mdot
.32134 .29299 Mdot
.32258 .29194 Mdot
.32325 .29138 Mdot
.32432 .29047 Mdot
.32574 .28927 Mdot
.32674 .28843 Mdot
.32759 .28771 Mdot
.32822 .28718 Mdot
.32924 .28632 Mdot
.33039 .28536 Mdot
.33209 .28394 Mdot
.33227 .28379 Mdot
.33395 .28238 Mdot
.33436 .28204 Mdot
.33488 .28161 Mdot
.3354 .28118 Mdot
.33628 .28044 Mdot
.33675 .28005 Mdot
.33759 .27936 Mdot
.33829 .27878 Mdot
.33974 .27758 Mdot
.34063 .27685 Mdot
.34219 .27556 Mdot
.34351 .27447 Mdot
.34467 .27352 Mdot
.34557 .27278 Mdot
.34633 .27217 Mdot
.34782 .27095 Mdot
.34952 .26956 Mdot
.35019 .26902 Mdot
.35086 .26847 Mdot
.35246 .26718 Mdot
.35346 .26636 Mdot
.35423 .26575 Mdot
.35498 .26514 Mdot
.35673 .26373 Mdot
.35796 .26274 Mdot
.35941 .26158 Mdot
.36058 .26065 Mdot
.36114 .2602 Mdot
.36199 .25952 Mdot
.36335 .25844 Mdot
.36428 .2577 Mdot
.36464 .25741 Mdot
.36579 .2565 Mdot
.36675 .25574 Mdot
.36765 .25503 Mdot
.3689 .25404 Mdot
.36948 .25359 Mdot
.37063 .25268 Mdot
.37142 .25207 Mdot
.37298 .25084 Mdot
.37374 .25025 Mdot
.37445 .24969 Mdot
.37503 .24924 Mdot
.37624 .24829 Mdot
.37713 .2476 Mdot
.37738 .2474 Mdot
.37807 .24687 Mdot
.37864 .24643 Mdot
.3803 .24515 Mdot
.38128 .24439 Mdot
.38217 .2437 Mdot
.38331 .24282 Mdot
.38381 .24244 Mdot
.38491 .24159 Mdot
.38689 .24008 Mdot
.38778 .23939 Mdot
.38901 .23845 Mdot
.39012 .23761 Mdot
.39103 .23692 Mdot
.39209 .23612 Mdot
.39265 .23569 Mdot
.39364 .23494 Mdot
.39474 .23411 Mdot
.39557 .23349 Mdot
.39737 .23213 Mdot
.39798 .23167 Mdot
.39893 .23096 Mdot
.3998 .23031 Mdot
.40123 .22924 Mdot
.40147 .22906 Mdot
.40237 .22839 Mdot
.40402 .22717 Mdot
.40505 .2264 Mdot
.40592 .22576 Mdot
.40711 .22487 Mdot
.40807 .22416 Mdot
.40851 .22384 Mdot
.40923 .22331 Mdot
.41052 .22236 Mdot
.41088 .2221 Mdot
.41257 .22086 Mdot
.41356 .22014 Mdot
.41402 .2198 Mdot
.4148 .21923 Mdot
.4153 .21887 Mdot
.41638 .21808 Mdot
.41691 .2177 Mdot
.41843 .2166 Mdot
.41959 .21576 Mdot
.4201 .21539 Mdot
.42121 .21459 Mdot
.42258 .21361 Mdot
.42314 .2132 Mdot
.4233 .21309 Mdot
.42409 .21252 Mdot
.42538 .2116 Mdot
.42608 .2111 Mdot
.42686 .21054 Mdot
.42748 .2101 Mdot
.42828 .20953 Mdot
.42853 .20935 Mdot
.42981 .20844 Mdot
.43089 .20768 Mdot
.4319 .20697 Mdot
.43248 .20656 Mdot
.43335 .20594 Mdot
.43412 .2054 Mdot
.43493 .20483 Mdot
.43567 .20431 Mdot
.43734 .20314 Mdot
.43751 .20302 Mdot
.4394 .2017 Mdot
.44016 .20117 Mdot
.44138 .20033 Mdot
.4421 .19983 Mdot
.44294 .19924 Mdot
.44349 .19886 Mdot
.44428 .19832 Mdot
.44512 .19774 Mdot
.44607 .19708 Mdot
.44711 .19637 Mdot
.44811 .19568 Mdot
.44894 .19512 Mdot
.44946 .19476 Mdot
.45016 .19428 Mdot
.45118 .19358 Mdot
.45175 .1932 Mdot
.45305 .19231 Mdot
.45357 .19196 Mdot
.4539 .19174 Mdot
.4547 .19119 Mdot
.45554 .19063 Mdot
.45605 .19028 Mdot
.45656 .18994 Mdot
.45723 .18949 Mdot
.45809 .18891 Mdot
.45867 .18852 Mdot
.4596 .18789 Mdot
.4605 .18729 Mdot
.4614 .18669 Mdot
.46284 .18573 Mdot
.46404 .18493 Mdot
.4642 .18483 Mdot
.4651 .18423 Mdot
.46598 .18364 Mdot
.46725 .18281 Mdot
.46747 .18266 Mdot
.46945 .18135 Mdot
.4699 .18105 Mdot
.47106 .18029 Mdot
.47265 .17925 Mdot
.47284 .17913 Mdot
.47394 .17841 Mdot
.47445 .17808 Mdot
.47571 .17726 Mdot
.47629 .17689 Mdot
.47783 .17588 Mdot
.47899 .17513 Mdot
.47993 .17453 Mdot
.48135 .17362 Mdot
.4816 .17346 Mdot
.48354 .17221 Mdot
.48395 .17195 Mdot
.48593 .17069 Mdot
.48742 .16974 Mdot
.48787 .16946 Mdot
.48892 .16879 Mdot
.49021 .16798 Mdot
.49159 .16711 Mdot
.4927 .16641 Mdot
.49463 .1652 Mdot
.49496 .165 Mdot
.49626 .16419 Mdot
.49707 .16368 Mdot
.49742 .16347 Mdot
.49828 .16293 Mdot
.49887 .16256 Mdot
.4999 .16193 Mdot
.5014 .161 Mdot
.50209 .16058 Mdot
.50326 .15986 Mdot
.5036 .15965 Mdot
.50436 .15918 Mdot
.50576 .15833 Mdot
.50717 .15747 Mdot
.50802 .15695 Mdot
.5099 .15581 Mdot
.51068 .15534 Mdot
.51112 .15507 Mdot
.51238 .15431 Mdot
.51334 .15374 Mdot
.51397 .15336 Mdot
.51553 .15242 Mdot
.51621 .15202 Mdot
.51787 .15103 Mdot
.51805 .15092 Mdot
.51941 .15011 Mdot
.51994 .1498 Mdot
.52071 .14935 Mdot
.52127 .14901 Mdot
.52186 .14867 Mdot
.52217 .14848 Mdot
.52301 .14799 Mdot
.52439 .14718 Mdot
.52527 .14666 Mdot
.52649 .14595 Mdot
.52678 .14578 Mdot
.52791 .14513 Mdot
.52828 .14491 Mdot
.52962 .14413 Mdot
.53009 .14386 Mdot
.53175 .1429 Mdot
.53263 .14239 Mdot
.53366 .1418 Mdot
.53411 .14154 Mdot
.53508 .14099 Mdot
.53605 .14043 Mdot
.53757 .13956 Mdot
.53885 .13884 Mdot
.53986 .13826 Mdot
.54071 .13778 Mdot
.54221 .13693 Mdot
.54309 .13644 Mdot
.54382 .13603 Mdot
.54456 .13562 Mdot
.54529 .1352 Mdot
.54588 .13488 Mdot
.54712 .13418 Mdot
.54839 .13348 Mdot
.54949 .13287 Mdot
.55013 .13251 Mdot
.55122 .13191 Mdot
.55225 .13135 Mdot
.55286 .13101 Mdot
.5534 .13071 Mdot
.55476 .12997 Mdot
.55636 .12909 Mdot
.55742 .12852 Mdot
.55776 .12833 Mdot
.55917 .12757 Mdot
.56013 .12705 Mdot
.56075 .12672 Mdot
.56245 .1258 Mdot
.56308 .12546 Mdot
.56434 .12479 Mdot
.56532 .12426 Mdot
.56606 .12387 Mdot
.56748 .12312 Mdot
.56899 .12232 Mdot
.57003 .12177 Mdot
.57049 .12153 Mdot
.57194 .12076 Mdot
.57225 .1206 Mdot
.5741 .11963 Mdot
.57424 .11956 Mdot
.57527 .11902 Mdot
.5762 .11854 Mdot
.57745 .11789 Mdot
.57867 .11726 Mdot
.5795 .11683 Mdot
.58044 .11635 Mdot
.58138 .11587 Mdot
.58223 .11543 Mdot
.5827 .11519 Mdot
.58301 .11504 Mdot
.58429 .11438 Mdot
.58513 .11395 Mdot
.58614 .11345 Mdot
.58712 .11295 Mdot
.58858 .11221 Mdot
.58923 .11189 Mdot
.58998 .11151 Mdot
.5911 .11095 Mdot
.5914 .1108 Mdot
.59259 .11021 Mdot
.59375 .10963 Mdot
.59434 .10934 Mdot
.59482 .1091 Mdot
.59644 .1083 Mdot
.59743 .10781 Mdot
.59848 .10729 Mdot
.59986 .10662 Mdot
.60041 .10635 Mdot
.60124 .10595 Mdot
.60224 .10546 Mdot
.60415 .10454 Mdot
.60469 .10428 Mdot
.60537 .10395 Mdot
.60583 .10373 Mdot
.60717 .10309 Mdot
.60846 .10247 Mdot
.60958 .10194 Mdot
.61084 .10134 Mdot
.61131 .10111 Mdot
.6121 .10074 Mdot
.61379 .09994 Mdot
.61424 .09973 Mdot
.61618 .09882 Mdot
.61674 .09856 Mdot
.61817 .09789 Mdot
.6198 .09714 Mdot
.62092 .09662 Mdot
.62201 .09612 Mdot
.62214 .09606 Mdot
.62338 .09549 Mdot
.6239 .09525 Mdot
.6257 .09443 Mdot
.62749 .09362 Mdot
.62791 .09343 Mdot
.62893 .09297 Mdot
.62943 .09274 Mdot
.63055 .09224 Mdot
.6322 .0915 Mdot
.63267 .09129 Mdot
.63333 .091 Mdot
.63366 .09085 Mdot
.63442 .09052 Mdot
.6349 .0903 Mdot
.63564 .08997 Mdot
.63659 .08956 Mdot
.63727 .08926 Mdot
.63829 .08881 Mdot
.63887 .08855 Mdot
.63988 .08811 Mdot
.64093 .08765 Mdot
.64187 .08725 Mdot
.64222 .0871 Mdot
.64284 .08682 Mdot
.64347 .08655 Mdot
.64518 .08582 Mdot
.64618 .08539 Mdot
.64671 .08516 Mdot
.64822 .08452 Mdot
.64897 .0842 Mdot
.64989 .08381 Mdot
.65093 .08337 Mdot
.65171 .08304 Mdot
.65251 .0827 Mdot
.65258 .08267 Mdot
.65361 .08224 Mdot
.65407 .08205 Mdot
.65484 .08173 Mdot
.65594 .08127 Mdot
.65675 .08093 Mdot
.65781 .08049 Mdot
.6592 .07992 Mdot
.66038 .07944 Mdot
.66074 .07929 Mdot
.66209 .07874 Mdot
.66292 .0784 Mdot
.66343 .07819 Mdot
.6643 .07784 Mdot
.66458 .07773 Mdot
.66582 .07723 Mdot
.66669 .07688 Mdot
.66775 .07645 Mdot
.66874 .07606 Mdot
.66914 .0759 Mdot
.66957 .07573 Mdot
.6708 .07524 Mdot
.67222 .07468 Mdot
.67298 .07438 Mdot
.67374 .07408 Mdot
.67491 .07362 Mdot
.67533 .07345 Mdot
.67676 .0729 Mdot
.67748 .07262 Mdot
.67842 .07225 Mdot
.6803 .07153 Mdot
.68185 .07094 Mdot
.68212 .07083 Mdot
.68301 .0705 Mdot
.68311 .07046 Mdot
.68405 .0701 Mdot
.68606 .06934 Mdot
.68769 .06873 Mdot
.68812 .06857 Mdot
.68859 .06839 Mdot
.68974 .06796 Mdot
.68991 .0679 Mdot
.69064 .06763 Mdot
.6919 .06716 Mdot
.69259 .06691 Mdot
.69332 .06664 Mdot
.69426 .0663 Mdot
.69451 .0662 Mdot
.69593 .06569 Mdot
.69679 .06537 Mdot
.69762 .06507 Mdot
.69869 .06469 Mdot
.69931 .06446 Mdot
.70048 .06404 Mdot
.70182 .06357 Mdot
.70286 .0632 Mdot
.70306 .06313 Mdot
.70443 .06264 Mdot
.70527 .06235 Mdot
.70647 .06192 Mdot
.70713 .06169 Mdot
.70844 .06124 Mdot
.70916 .06099 Mdot
.71083 .06041 Mdot
.71166 .06013 Mdot
.71238 .05988 Mdot
.71364 .05945 Mdot
.71457 .05913 Mdot
.71548 .05882 Mdot
.71722 .05824 Mdot
.71818 .05791 Mdot
.71906 .05762 Mdot
.72116 .05692 Mdot
.72256 .05646 Mdot
.7232 .05625 Mdot
.72364 .0561 Mdot
.72438 .05586 Mdot
.72521 .05559 Mdot
.72655 .05516 Mdot
.72724 .05494 Mdot
.72858 .0545 Mdot
.72899 .05437 Mdot
.73039 .05392 Mdot
.73123 .05366 Mdot
.7324 .05328 Mdot
.73324 .05302 Mdot
.73392 .0528 Mdot
.73431 .05268 Mdot
.73578 .05222 Mdot
.73682 .0519 Mdot
.7387 .05132 Mdot
.73911 .05119 Mdot
.74069 .05071 Mdot
.74152 .05045 Mdot
.74278 .05007 Mdot
.74353 .04984 Mdot
.74584 .04915 Mdot
.74668 .0489 Mdot
.74805 .04849 Mdot
.74908 .04819 Mdot
.74982 .04797 Mdot
.75046 .04778 Mdot
.75163 .04744 Mdot
.75203 .04732 Mdot
.7532 .04698 Mdot
.75344 .04691 Mdot
.75601 .04618 Mdot
.75695 .04591 Mdot
.75742 .04577 Mdot
.75877 .04539 Mdot
.75979 .0451 Mdot
.76133 .04467 Mdot
.76297 .04422 Mdot
.76323 .04415 Mdot
.76377 .044 Mdot
.76428 .04386 Mdot
.7648 .04371 Mdot
.76518 .04361 Mdot
.76601 .04338 Mdot
.76696 .04312 Mdot
.76779 .0429 Mdot
.76876 .04264 Mdot
.76962 .04241 Mdot
.77106 .04202 Mdot
.77193 .04179 Mdot
.77205 .04176 Mdot
.77292 .04153 Mdot
.77396 .04125 Mdot
.77491 .04101 Mdot
.77533 .0409 Mdot
.77643 .04061 Mdot
.77728 .04039 Mdot
.77767 .04029 Mdot
.77914 .03991 Mdot
.77968 .03977 Mdot
.78084 .03948 Mdot
.78184 .03923 Mdot
.78301 .03893 Mdot
.78457 .03854 Mdot
.78531 .03836 Mdot
.78653 .03806 Mdot
.78675 .038 Mdot
.7878 .03775 Mdot
.7882 .03765 Mdot
.78878 .03751 Mdot
.78987 .03724 Mdot
.79063 .03706 Mdot
.79199 .03673 Mdot
.79253 .0366 Mdot
.7933 .03642 Mdot
.79444 .03615 Mdot
.79475 .03608 Mdot
.7955 .0359 Mdot
.79624 .03573 Mdot
.79699 .03555 Mdot
.79833 .03524 Mdot
.79956 .03496 Mdot
.8004 .03477 Mdot
.80082 .03467 Mdot
.80142 .03454 Mdot
.80238 .03432 Mdot
.80314 .03415 Mdot
.80375 .03401 Mdot
.80509 .03371 Mdot
.80586 .03354 Mdot
.80609 .03349 Mdot
.80727 .03323 Mdot
.80819 .03303 Mdot
.80935 .03278 Mdot
.81066 .0325 Mdot
.81168 .03228 Mdot
.81334 .03192 Mdot
.81455 .03167 Mdot
.81533 .03151 Mdot
.81578 .03141 Mdot
.81702 .03116 Mdot
.81853 .03085 Mdot
.81903 .03074 Mdot
.82037 .03047 Mdot
.82142 .03026 Mdot
.82278 .02999 Mdot
.82371 .0298 Mdot
.82478 .02959 Mdot
.82549 .02945 Mdot
.82614 .02933 Mdot
.82695 .02917 Mdot
.82787 .02899 Mdot
.82922 .02873 Mdot
.8297 .02864 Mdot
.8302 .02855 Mdot
.83164 .02827 Mdot
.83246 .02812 Mdot
.83337 .02795 Mdot
.83384 .02786 Mdot
.83578 .02751 Mdot
.83684 .02732 Mdot
.83765 .02717 Mdot
.83825 .02706 Mdot
.83913 .02691 Mdot
.83992 .02676 Mdot
.84043 .02668 Mdot
.84088 .0266 Mdot
.84218 .02637 Mdot
.84342 .02616 Mdot
.84412 .02603 Mdot
.84484 .02591 Mdot
.84603 .02571 Mdot
.84703 .02554 Mdot
.84795 .02539 Mdot
.84879 .02525 Mdot
.84892 .02523 Mdot
.85046 .02497 Mdot
.85151 .0248 Mdot
.8521 .02471 Mdot
.85284 .02459 Mdot
.85417 .02438 Mdot
.85519 .02422 Mdot
.85627 .02405 Mdot
.8576 .02384 Mdot
.85891 .02364 Mdot
.8596 .02354 Mdot
.86042 .02341 Mdot
.86143 .02326 Mdot
.86288 .02305 Mdot
.8632 .023 Mdot
.86385 .02291 Mdot
.86422 .02285 Mdot
.86592 .02261 Mdot
.86689 .02247 Mdot
.86762 .02236 Mdot
.86872 .02221 Mdot
.86974 .02207 Mdot
.87063 .02195 Mdot
.87141 .02184 Mdot
.8722 .02173 Mdot
.8735 .02156 Mdot
.87478 .02139 Mdot
.87533 .02132 Mdot
.87646 .02117 Mdot
.87709 .02109 Mdot
.87909 .02083 Mdot
.87954 .02078 Mdot
.88011 .02071 Mdot
.8816 .02052 Mdot
.8822 .02045 Mdot
.88353 .02029 Mdot
.88469 .02015 Mdot
.88643 .01994 Mdot
.88753 .01982 Mdot
.8886 .01969 Mdot
.88917 .01963 Mdot
.89071 .01946 Mdot
.89203 .01931 Mdot
.89262 .01925 Mdot
.89421 .01908 Mdot
.89554 .01894 Mdot
.89629 .01886 Mdot
.89664 .01882 Mdot
.89699 .01879 Mdot
.89797 .01869 Mdot
.89857 .01863 Mdot
.89915 .01857 Mdot
.90084 .0184 Mdot
.90138 .01835 Mdot
.9024 .01825 Mdot
.90302 .01819 Mdot
.90521 .01798 Mdot
.90571 .01794 Mdot
.90597 .01792 Mdot
.90805 .01773 Mdot
.90934 .01762 Mdot
.91062 .01751 Mdot
.91084 .01749 Mdot
.91285 .01732 Mdot
.91324 .01729 Mdot
.91402 .01722 Mdot
.91525 .01713 Mdot
.91649 .01703 Mdot
.9174 .01696 Mdot
.91777 .01693 Mdot
.91864 .01686 Mdot
.91913 .01683 Mdot
.92022 .01675 Mdot
.92047 .01673 Mdot
.92189 .01663 Mdot
.92292 .01656 Mdot
.92346 .01652 Mdot
.92445 .01645 Mdot
.92498 .01642 Mdot
.92608 .01634 Mdot
.92713 .01628 Mdot
.92731 .01627 Mdot
.92851 .01619 Mdot
.92932 .01614 Mdot
.93031 .01608 Mdot
.93125 .01603 Mdot
.93186 .01599 Mdot
.93255 .01595 Mdot
.93392 .01587 Mdot
.93501 .01582 Mdot
.93564 .01578 Mdot
.93672 .01573 Mdot
.93733 .01569 Mdot
.9382 .01565 Mdot
.94008 .01556 Mdot
.9406 .01554 Mdot
.94174 .01549 Mdot
.94277 .01544 Mdot
.94352 .01541 Mdot
.94429 .01538 Mdot
.94544 .01533 Mdot
.94642 .01529 Mdot
.94688 .01527 Mdot
.94817 .01522 Mdot
.94916 .01519 Mdot
.94999 .01516 Mdot
.9516 .01511 Mdot
.95217 .01509 Mdot
.95321 .01506 Mdot
.954 .01503 Mdot
.95558 .01499 Mdot
.95591 .01498 Mdot
.9573 .01495 Mdot
.95858 .01492 Mdot
.95937 .0149 Mdot
.96042 .01488 Mdot
.96147 .01486 Mdot
.96218 .01484 Mdot
.96297 .01483 Mdot
.9639 .01481 Mdot
.96519 .01479 Mdot
.96634 .01478 Mdot
.96757 .01476 Mdot
.96916 .01475 Mdot
.96978 .01474 Mdot
.97037 .01474 Mdot
.97073 .01473 Mdot
.97173 .01473 Mdot
.97376 .01472 Mdot
.97487 .01472 Mdot
.97517 .01472 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00458387) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.00037) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP80
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H2000000030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0
n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000
00020?[`iP030000003jl>H0n_3V00800000103jl>H200000?l0n_3VY03jl>H10?ooo`00803jl>H2
000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000
n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H000000000
00020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000D0n_3V0P00
00040?[`iP800000o`3jl>JT0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P000000
1P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP800000
00<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP800000
00@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80
000000<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
0000000000020?[`iP80000000<0n_3V0000000000001@3jl>H2000000@0n_3V0P00003o0?[`iZ@0
n_3V0@3oool00200n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP800000
00H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V0000
00000000n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V1000000:0?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000003
0?[`iP<000001P3jl>H200000?l0n_3VX`3jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3j
l>H0000000000002000000@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`
iPD000000P3jl>H5000000X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`
iP800000303jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000001@3jl>H2000000D0n_3V0P00003o0?[`iZ<0n_3V0@3oool00200
n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09P3jl>H2000000/0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V00<000000?[`iP3jl>H00P0000020?[`iP030000003jl>H0n_3V0080
0000o`3jl>JS0?[`iP40oooo000O0?[`iPH00000103jl>H2000002l0n_3V1@00000Y0?[`iP<00000
2P3jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000<0n_3V1@00003o0?[`iZ<0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V
0@3oool00200n_3V1P0000001@3jl>H00000000000000000n_3V00<000000P3jl>H3000000<0n_3V
100000030?[`iP80000000@0n_3V000000000000n_3V1@0000030?[`iP`00000;`3jl>H3000000@0
n_3V0P00003o0?[`i/T0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V000000000000
0P3jl>H200000080n_3V00@000000?[`iP00000000000`3jl>H01@000000n_3V000000000000n_3V
00<000000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000280n_3V1@0000090?[`
iP80000000<0n_3V0000000000000`3jl>H200000?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0
n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H2000000D0n_3V0P0000020?[`iP80
00000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H0
00000000003o0?[`i/h0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V000000000000
0P3jl>H2000000@0n_3V1P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000D0n_3V
1@0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H000000000003o0?[`i/h0n_3V
0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P00
00020?[`iP80000000@0n_3V000000000000n_3V0`0000020?[`iP<0000000<0n_3V0000003jl>H0
103jl>H2000000<0n_3V0P00000`0?[`iP@00000o`3jl>K?0?[`iP40oooo000R0?[`iP8000000`3j
l>H500000080n_3V1@0000030?[`iP@000000`3jl>H2000000030?[`iP000000000000@0000000<0
n_3V0000000000000P3jl>H4000000@0n_3V0P00000`0?[`iP800000o`3jl>KA0?[`iP40oooo000R
0?[`iP8000002`3jl>H200000280n_3V0P00000a0?[`iP800000o`3jl>K@0?[`iP40oooo000P0?[`
iPH000002@3jl>H200000200n_3V1000000b0?[`iP<00000o`3jl>K>0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
02H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`
iP40oooo000W0?[`iP040000003jl>H000000?[`iP8000000P3jl>H00`000000n_3V0?[`iP030000
0?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P0000001@3jl>H0
00000?[`iP000000n_3V00<000000P3jl>H00`000000n_3V0000000I0?[`iP<00000g03jl>H40000
00@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H40000
0080n_3V0`000000103jl>H000000000000000080?[`iP@0000000<0n_3V0000000000000P3jl>H4
00000080n_3V1@0000001`3jl>H00000000000000000n_3V0000003jl>H00`00000H0?[`iP<00000
103jl>H2000000D0n_3V0`0000040?[`iP<00000103jl>H4000000<0n_3V0`0000040?[`iP<00000
103jl>H3000000@0n_3V0`0000050?[`iP800000J`3jl>H10?ooo`008@3jl>H2000000030?[`iP00
0000000000D0000000@0n_3V00000000000000000P3jl>H2000000030?[`iP000000000000T0n_3V
1@0000090?[`iP030000003jl>H0n_3V00800000g03jl>H2000000@0n_3V0P0000020?[`iP800000
0P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080
n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3j
l>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3j
l>H00000000000030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3j
l>H00000000000020?[`iP030000003jl>H0n_3V008000000P3jl>H2000000030?[`iP0000000000
00@0n_3V0P00001[0?[`iP40oooo000R0?[`iP<00000:`3jl>H200000=`0n_3V0P0000040?[`iP80
00000P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H200000005
0?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3j
l>H000000?[`iP02000001P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000
000000000P3jl>H2000000040?[`iP00000000000?[`iPH000001@3jl>H200000080n_3V0P000000
0`3jl>H00000000000050?[`iP8000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00001[
0?[`iP40oooo000R0?[`iP<000006P3jl>H5000000`0n_3V0P00003L0?[`iP@000000`3jl>H50000
0080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H20000
0080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H2000000050?[`iP0000000000
0000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3jl>H000000?[`iP02
000000T0n_3V1@00000:0?[`iP80000000<0n_3V0000000000002@3jl>H2000000030?[`iP000000
00000080n_3V0P0000001@3jl>H000000000003jl>H000000080n_3V0P0000060?[`iP8000000P3j
l>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP80000000<0n_3V000000000000103j
l>H2000006/0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000X0?[`iP<00000g@3jl>H2
000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P00
00060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00
00000`3jl>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP800000
0P3jl>H3000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP800000
00<0n_3V0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000
000000020?[`iP040000003jl>H00000000000<0n_3V00<000000?[`iP3jl>H00P0000030?[`iP<0
0000103jl>H3000000@0n_3V0`0000060?[`iP800000JP3jl>H10?ooo`00803jl>H3000000040?[`
iP0000000000000002T0n_3V0P00003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080
n_3V0`000000103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3jl>H40000
00@0n_3V100000020?[`iPD000002`3jl>H3000000030?[`iP00000000000080n_3V100000020?[`
iP<0000000<0n_3V0000000000001`00000I0?[`iP80000000<0n_3V0000000000002@3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP040000003jl>H00000
000000<0n_3V100000030?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0P000000
0`3jl>H00000000000050?[`iP800000JP3jl>H10?ooo`00C@3jl>H00`000000n_3V0?[`iP020000
0=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H200000280n_3V0P0000020?[`
iP800000;P3jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000`3jl>H3000000<0n_3V0P0000050?[`iP80000000<0n_3V0000
000000000P3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H00000000000020?[`
iP030000003jl>H0n_3V00800000JP3jl>H10?ooo`00CP3jl>H300000=`0n_3V1@00000A0?[`iP80
00001P3jl>H2000000@0n_3V0P0000060?[`iP8000006@3jl>H3000000030?[`iP00000000000080
0000;P3jl>H3000000/0n_3V0`0000040?[`iP<000001@3jl>H2000000<0n_3V1@0000030?[`iP<0
0000103jl>H3000000@0n_3V0`0000030?[`iPD00000JP3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000V0?[`iP80000000<0n_3V0000
003jl>H0200000000`3jl>H000000000003o0?[`i_l0n_3V8`3jl>H10?ooo`009`3jl>H01@000000
n_3V0000003jl>H000000080n_3V00@000000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP3o
0?[`i_l0n_3V8P3jl>H10?ooo`00803jl>H3000000030?[`iP00000000000080000000@0n_3V0000
003jl>H000000P3jl>H010000000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V01L0n_3V0`00
003L0?[`iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P00
00020?[`iP@000000P3jl>H3000000030?[`iP000000000000H000006P3jl>H600000080n_3V0`00
00040?[`iP<00000103jl>H300000;<0n_3V0@3oool00240n_3V0P0000000`3jl>H0000000000005
000000050?[`iP00000000000000003jl>H01000000;0?[`iPD000002@3jl>H2000000030?[`iP00
000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080n_3V0P0000050?[`iP8000000P3j
l>H010000000n_3V0?[`iP3jl>H2000000@0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000020?[`
iP8000002`3jl>H5000000/0n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000002b0?[`iP40oooo000R0?[`iP<0
0000:03jl>H2000000030?[`iP00000000000=`0n_3V0P0000040?[`iP8000000P3jl>H200000080
n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080
n_3V0P0000020?[`iP80000000<0n_3V0000000000000`3jl>H4000001/0n_3V0P0000030?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0
00000000002b0?[`iP40oooo000R0?[`iP<000002@3jl>H00`000000n_3V0?[`iP0>0?[`iPD00000
2@3jl>H2000000030?[`iP00000000000=`0n_3V100000030?[`iPD000000P3jl>H2000000D0n_3V
0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V
0P000000103jl>H000000000003jl>H4000000d0n_3V1@00000;0?[`iP8000000`3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V00000000
0000/P3jl>H10?ooo`008@3jl>H2000000030?[`iP000000000002L0n_3V0P0000000`3jl>H00000
0000003L0?[`iP80000000<0n_3V0000000000001@3jl>H200000080n_3V0`000000103jl>H00000
0?[`iP3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000001/0n_3V0P0000030?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H000000000002b0?[`iP40oooo000P0?[`iP<0000000@0n_3V00000000000000009P3jl>H20000
00030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H30000
00040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H4
00000080n_3V1@0000030?[`iPD000006`3jl>H2000000<0n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000;80n_3V0@3oool0
04d0n_3V0P0000000`3jl>H000000000003L0?[`iP80000000<0n_3V000000000000403jl>H20000
00`0n_3V0P00000h0?[`iP@000000`3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V000000000000/P3jl>H10?ooo`00CP3jl>H300000=`0
n_3V1@00000A0?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP800000<P3jl>H2000000@0
n_3V0`0000040?[`iP<00000103jl>H300000;<0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3j
l>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo000M0?[`iR<0oooP0P0000150?ooh0800000103oon020000
00@0oooP0P0000140?ooh0D00000@`3oon0500000080oooP0P0000040?ooh0800000A03oon040000
04@0oooP100000030?ooh0800000103oon02000004D0oooP0P00000W0?ooh1h0n_3V0@3oool001d0
n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP000000P0oooP00@00000
0?ooh03oon000000A@3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00L0oooP00@0
00000?ooh03oon000000@`3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00T0oooP
00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh000000V0?ooh1h0n_3V0@3oool001d0
n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP000000/0oooP00<00000
0?ooh03oon00@`3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00X0oooP00<00000
0?ooh03oon00@P3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00/0oooP00<00000
0?ooh03oon00@`3oon000`000000oooP0?ooh00U0?ooh1h0n_3V0@3oool001d0n_3V8P3oon001000
0000oooP0?ooh00000130?ooh0040000003oon00oooP000000T0oooP0P0000160?ooh0030000003o
on00oooP04D0oooP00<000000?ooh03oon00203oon02000004H0oooP00<000000?ooh03oon00A@3o
on000`000000oooP0?ooh0080?ooh0800000A`3oon000`000000oooP0?ooh00T0?ooh1h0n_3V0@3o
ool001d0n_3V8P3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP000000T0oooP
00<000000?ooh03oon00A@3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00P0oooP
00<000000?ooh03oon00@`3oon0010000000oooP0?ooh00000140?ooh0040000003oon00oooP0000
00T0oooP00<000000?ooh03oon00@`3oon0010000000oooP0?ooh000000V0?ooh1h0n_3V0@3oool0
01d0n_3V8`3oon02000004D0oooP0P00000:0?ooh0<00000A03oon02000004H0oooP0P00000:0?oo
h0<00000A03oon02000004H0oooP0P00000:0?ooh0<00000A03oon02000002L0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3V603oon3o00000>X000006`3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP
00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03o
on003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03o
on002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00BP3oon000`000000oooP
0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP
0?ooh01:0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh<P0oooP4`00000;0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0
oooP^@3oon0S000000X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
0`00003o0?ooh:l0oooP4P00000J0000o`030000003oon00oooP00H0oooP0`00000K0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh:L0oooP4P0000080000oaX000002`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o
0?ooh:00oooP400000090000oa0000004P3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPVP3oon0<000000X0003o2P00000Q0<f5
?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on00o`3oon2D0?ooh0X0000020000?l;000002X0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh8l0oooP2@0000060000o`X00000
<`3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP0?l0oooPRP3oon07000000L0003o2P00000i0<f5?`/0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon250?ooh0L000001@000?l:
00000400cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh840oooP1`0000040000o`X00000A@3=QCl;0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPO@3oon07000000@0
003o2@00001:0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon1i0?ooh0L0000010000?l700000500cHDo2`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh7D0oooP1`00
00040000o`L00000E03=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP0?l0oooPLP3oon06000000@0003o1`00001H0<f5?`/0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1^0?oo
h0H0000010000?l6000005d0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh03o0?ooh6/0oooP1@0000040000o`L00000H03=QCl;0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
I`3oon05000000@0003o1`00001T0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP0`00003o0?ooh6@0oooP100000040000o`L00000J03=QCl90?ooh0<000006`3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1Q0?ooh0@000000`000?l7
000006`0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh5h0oooP100000030000o`L00000K`3=QCl;0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPF`3oon04000000<0
003o1`00001b0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon00o`3oon1H0?ooh0D000000P000?l7000007D0cHDo2`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh5D0oooP1@00
00030000o`D00000N@3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP0?l0oooPDP3oon05000000<0003o1@00001l0<f5?`/0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1@0?oo
h0@000000`000?l5000007l0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh03o0?ooh4d0oooP100000030000o`D00000PP3=QCl;0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP
BP3oon0500000080003o1@0000250<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon180?ooh0@000000`000?l5000008L0cHDo2`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o
0?ooh4D0oooP1@0000020000o`D00000RP3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooP@`3oon04000000<0003o1000002=0<f5
?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh003
0000003oon00oooP0?l0oooP@03oon04000000<0003o1000002@0<f5?`/0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000
oooP0?ooh03o0?ooh3h0oooP100000020000o`D00000TP3=QCl;0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP100000080?ooh?l0
0000=P0000030000oiT00000203oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000
003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon3o03>QbS00<j7:100000020000o`D0
0000XP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP
0?ooh00000070?ooh0030000003oon00oooP00T0oooPo`0cXLX^03>QbP@000000P000?l500000:@0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000
003oon00oooP00T0oooPo`0cXLX[03>QbPD000000P000?l400000:L0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbRT0<j7:1@00
00020000o`@00000Z@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh?l0<j7:9`0cXLX4000000<0003o1000002[0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLXT03>Q
bPD000000P000?l400000:h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon3o03>QbR<0<j7:100000020000o`@00000/03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:
8@0cXLX400000080003o0`00002c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLXN03>QbPD000000P000?l300000;D0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o
03>QbQ`0<j7:1@0000020000o`<00000]`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:6P0cXLX500000080003o0`00002i0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooPo`0cXLXH03>QbPD000000P000?l300000;/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbQH0<j7:1@0000020000o`<00000
_@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh?l0<j7:500cXLX500000080003o0`00002o0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLXB03>QbPD000000P000?l3
00000<40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?oo
h?l0<j7:400cXLX500000080003o0P0000320?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon3o03>QbPh0<j7:1@0000020000o`800000aP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:
300cXLX500000080003o0`0000370?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLX:03>QbPD000000P000?l200000<X0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o
03>QbPP0<j7:1@0000020000o`<00000b`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:1`0cXLX400000080003o0P00003>0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooPo`0cXLX503>QbP@000000P000?l300000<l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbP<0<j7:100000020000o`<00000
d@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh?l0<j7:0@0cXLX400000080003o0`00003C0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPoP0cXLX400000080003o0`00003E
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooPo00cXLX400000080003o0`00003G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPn`0cXLX300000080003o0`00003I0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
n@0cXLX300000080003o0`00003K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooPm`0cXLX4000000030000o`000000000000800000g03o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh?H0<j7:0`0000020000o`<00000gP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh?@0<j7:0`0000020000o`<00000h03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooPlP0cXLX300000080
003o0`00003P0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon3`03>QbP@0000000<0003o0000000000000P00003S0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPk`0cXLX300000080003o0`00
003U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooPk@0cXLX300000080003o0`00003W0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPj`0cXLX4000000030000o`0000000000
00800000j03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh>T0<j7:100000020000o`<00000jP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh>P0<j7:0`0000020000o`<00000
k03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh>L0<j7:0P0000020000o`@00000k@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh>D0<j7:0`0000000`000?l0000000000002
00000>l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon3S03>QbP<000000P000?l300000?40oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3Q03>QbP@0000000@0003o00000000
00000000l`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh>00<j7:0`0000020000o`<00000m03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh=h0<j7:0`0000020000o`<00000
mP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh=d0<j7:0`0000000`000?l000000000000200000?L0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3L03>QbP8000000P000?l3
00000?T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon3J03>QbP<0000000<0003o0000000000000P00003j0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon3H03>QbP<000000P000?l300000?X0
oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh=L0<j7:
0P0000020000o`@00000o@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh=D0<j7:0`0000000`000?l000000000000200000?l0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3D
03>QbP8000000P000?l300000?l0oooP0P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh=80<j7:0`0000000`000?l00000000000020000
0?l0oooP0`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh=40<j7:0P0000020000o`<00000o`3oon050?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPd00cXLX2000000030000
o`000000000000800000o`3oon060?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooPcP0cXLX3000000040000o`000000000000000?l0oooP
203oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh<d0<j7:0P0000020000o`<00000o`3oon090?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPb`0cXLX3000000040000o`000000
000000000?l0oooP2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh<X0<j7:0`00000010000?l0000000000000003o0?ooh0`0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon38
03>QbP<000000P000?l300000?l0oooP3@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh<L0<j7:0`00000010000?l0000000000000003o
0?ooh0l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon3503>QbP@0000000@0003o0000000000000000o`3oon0@0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0@000001`3oon000`000000oooP0?ooh0090?oo
h<@0<j7:0`0000020000o`800000o`3oon0B0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H=0?ooh0030000003oon00oooP00P0oooP00<000000?ooh03oon002@3oon3203>QbP@0
000000@0003o0000000000000000o`3oon0C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H>0?ooh0030000003oon00oooP00L0oooP100000080?ooh<40<j7:100000000`000?l0
00000000003o0?ooh180oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3`3oon000`000000oooP
0?ooh0060?ooh0030000003oon00oooP00T0oooP`00cXLX300000080003o0P00003o0?ooh1H0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon000000
1`3oon000`000000oooP0?ooh0090?ooh;l0<j7:0`00000010000?l0000000000000003o0?ooh1L0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000
003oon00oooP00T0oooP_@0cXLX300000080003o0P00003o0?ooh1T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2l03>QbP<0000000<0
003o000000000000o`3oon0K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP^`0cXLX3000000030000o`00000000000?l0oooP703oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h;T0<j7:0`0000020000o`800000o`3oon0M0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP^00cXLX3000000040000o`00000000000000
0?l0oooP7P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh;H0<j7:0`0000020000o`800000o`3oon0P0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP]@0cXLX3000000040000
o`000000000000000?l0oooP8@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh;@0<j7:0P0000020000o`<00000o`3oon0R0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP/P0c
XLX3000000040000o`000000000000000?l0oooP903oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh;40<j7:0`00000010000?l000000000
0000003o0?ooh2D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon2`03>QbP8000000P000?l200000?l0oooP9`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:h0<j7:0`000000
10000?l0000000000000003o0?ooh2P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon2]03>QbP8000000P000?l300000?l0oooP:@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP[00cXLX20000
00030000o`000000000000800000o`3oon0X0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon2Z03>QbP<0000000@0003o0000000000000000o`3oon0/0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooPZ@0cXLX200000080003o0`00003o0?ooh2d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2X03>QbP80000000@0003o000000000000
0000o`3oon0_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooPY`0cXLX2000000040000o`000000000000000?l0oooP<03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:D0<j7:
0`00000010000?l0000000000000003o0?ooh340oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2T03>QbP8000000P000?l300000?l0oooP
<P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh:<0<j7:0P00000010000?l0000000000000003o0?ooh3@0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2R03>QbP80000000@0
003o0000000000000000o`3oon0e0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooPX00cXLX200000080003o0`00003o0?ooh3H0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2O
03>QbP80000000<0003o0000000000000P00003o0?ooh3L0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2N03>QbP80000000@0003o0000
000000000000o`3oon0i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooPW@0cXLX2000000040000o`000000000000000?l0oooP>P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h9`0<j7:00<000000000o`000?l00`00003o0?ooh3/0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2J03>QbP80000000<0003o00000000
00000P00003o0?ooh3`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon2I03>QbP80000000@0003o0000000000000000o`3oon0n0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon2H03>QbP800000
00@0003o0000000000000000o`3oon0m0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon2G03>QbP80000000@0003o0000000000000000o`3oon100?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
UP0cXLX2000000040000o`000000000000000?l0oooP@@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh9@0<j7:0P0000020000o`<00000
o`3oon120?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPT`0cXLX2000000030000o`000000000000800000o`3oon130?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPTP0cXLX2
000000040000o`000000000000000?l0oooPA@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh940<j7:0P00000010000?l0000000000000
003o0?ooh4H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon2@03>QbP80000000@0003o0000000000000000o`3oon170?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPSP0cXLX3
000000030000o`00000000000?l0oooPB@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh8d0<j7:0`0000000`000?l000000000003o0?oo
h4X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2<03>QbP<0000000<0003o000000000000o`3oon1;0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPR`0cXLX3000000030000
o`00000000000?l0oooPC03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh8X0<j7:0P0000020000o`800000o`3oon1=0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPR@0cXLX2
000000040000o`000000000000000?l0oooPCP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh8P0<j7:0P00000010000?l0000000000000
003o0?ooh4l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon2603>QbP<0000000<0003o000000000000o`3oon1A0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon2503>QbP<0000000<0003o0000
00000000o`3oon1@0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2403>QbP<0000000<0003o000000000000o`3oon1C0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPP`0cXLX3000000030000
o`00000000000?l0oooPE03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh880<j7:0`0000000`000?l000000000003o0?ooh5D0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon21
03>QbP<0000000<0003o0000003oon00o`3oon1F0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPO`0cXLX300000080003o0P00003o0?oo
h5L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon1n03>QbP<0000000@0003o0000000000000000o`3oon1H0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPO@0cXLX300000003
0000o`00000000000?l0oooPFP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh7`0<j7:0`0000000`000?l000000000003o0?ooh5/0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on1k03>QbP<0000000<0003o000000000000o`3oon1L0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPNP0cXLX3000000030000o`000000
00000?l0oooPG@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh7T0<j7:0`0000000`000?l000000000003o0?ooh5h0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1h03>QbP<0
000000<0003o000000000000o`3oon1O0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPM`0cXLX3000000030000o`00000000000?l0oooP
H03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3`3oon03000000H0oooP00<0
00000?ooh03oon002@3oon1f03>QbP8000000P000?l200000?l0oooPH@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V403oon000`000000oooP0?ooh0050?ooh0030000003oon00
oooP00T0oooPM00cXLX3000000030000o`00000000000?l0oooPH`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V3@3oon05000000H0oooP100000080?ooh7<0<j7:0`0000000`00
0?l000000000003o0?ooh640oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000
oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooPL`0cXLX2000000030000o`0000000000
0?l0oooPI@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon000`000000
oooP000000070?ooh0030000003oon00oooP00T0oooPL@0cXLX3000000030000o`00000000000?l0
oooPIP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3`3oon02000000L0oooP
00<000000?ooh03oon002@3oon1`03>QbP<0000000<0003o000000000000o`3oon1W0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPK`0c
XLX3000000030000o`00000000000?l0oooPJ03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh6h0<j7:0`0000000`000?l000000000003o
0?ooh6T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1]03>QbP<0000000<0003o000000000000o`3oon1Z0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPK00cXLX300000003
0000o`00000000000?l0oooPJ`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh6/0<j7:0`0000000`000?l000000000003o0?ooh6`0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on1Z03>QbP<0000000<0003o000000000000o`3oon1]0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPJ@0cXLX3000000030000o`000000
00000?l0oooPKP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh6P0<j7:0P0000020000o`800000o`3oon1_0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPI`0cXLX200000004
0000o`000000000000000?l0oooPL03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh6H0<j7:0P00000010000?l0000000000000003o0?oo
h740oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon1U03>QbP80000000<0003o000000000000o`3oon1c0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPI00cXLX2000000030000
o`00000000000?l0oooPM03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on03000000T0oooPH`0cXLX2000000030000o`00000000000?l0oooPL`3oon03000001/0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPHP0cXLX2000000030000o`000000
00000?l0oooPMP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh640<j7:0P0000000`000?l000000000003o0?ooh7L0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1P03>QbP80
000000<0003o000000000000o`3oon1h0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPGP0cXLX3000000030000o`00000000000?l0oooP
N@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh5d0<j7:0`0000000`000?l000000000003o0?ooh7X0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1L03>QbP<0000000<0003o
000000000000o`3oon1k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooPF`0cXLX3000000030000o`00000000000?l0oooPO03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh5/0
<j7:0P0000000`000?l000000000003o0?ooh7d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1J03>QbP80000000<0003o000000000000
o`3oon1n0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPF@0cXLX2000000030000o`00000000000?l0oooPO`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh5P0<j7:0P000000
0`000?l000000000003o0?ooh800oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon1G03>QbP80000000<0003o000000000000o`3oon210?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooPE@0cXLX3000000030000o`00000000000?l0oooPPP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh5@0<j7:0`0000000`000?l00000
0000003o0?ooh8<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon1C03>QbP<0000000<0003o000000000000o`3oon240?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon1B03>QbP<0000000<0003o
000000000000o`3oon230?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1A03>QbP<0000000<0003o000000000000o`3oon260?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPD00cXLX300000003
0000o`00000000000?l0oooPQ`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh4l0<j7:0`0000000`000?l000000000003o0?ooh8P0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on1>03>QbP<0000000<0003o000000000000o`3oon290?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPCP0cXLX2000000030000o`000000
00000?l0oooPRP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh4d0<j7:0P0000000`000?l000000000003o0?ooh8/0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1<03>QbP80
000000<0003o000000000000o`3oon2<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPB`0cXLX2000000030000o`00000000000?l0oooP
S@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh4X0<j7:0P0000000`000?l000000000003o0?ooh8h0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1903>QbP80000000<0003o
000000000000o`3oon2?0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooPB00cXLX2000000030000o`00000000000?l0oooPT03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh4L0
<j7:0P00000010000?l0000000000000003o0?ooh900oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1603>QbP80000000@0003o00000000
00000000o`3oon2A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooPA@0cXLX2000000030000o`00000000000?l0oooPT`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh4@0<j7:
0P0000000`000?l000000000003o0?ooh9@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP0`0000090?ooh4<0<j7:0P0000000`000?l000000000003o0?ooh9<0oooP0`00
000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh480<j7:0P000000
10000?l0000000000000003o0?ooh9D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon1103>QbP80000000@0003o0000000000000000o`3o
on2F0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP@00cXLX3000000030000o`000000oooP0?l0oooPU`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh400<j7:0P0000000`00
0?l000000000003o0?ooh9P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon0o03>QbP80000000<0003o000000000000o`3oon2I0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
?P0cXLX2000000030000o`00000000000?l0oooPVP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh3`0<j7:0`0000000`000?l000000000
003o0?ooh9/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0k03>QbP<0000000<0003o000000000000o`3oon2L0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP>`0cXLX20000
00030000o`00000000000?l0oooPW@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh3X0<j7:0P0000000`000?l000000000003o0?ooh9h0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon0i03>QbP80000000<0003o000000000000o`3oon2O0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP>00cXLX2000000030000o`00
000000000?l0oooPX03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh3L0<j7:0P0000000`000?l000000000003o0?ooh:40oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP0`0000080?ooh0030000003oon00oooP
00T0oooP=P0cXLX2000000030000o`00000000000?l0oooPXP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP
00T0oooP=@0cXLX2000000030000o`00000000000?l0oooPX`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0@00000203oon0d03>Q
bP80000000<0003o000000000000o`3oon2Q0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPd0
oooP0`0000080?ooh0030000003oon00oooP00T0oooP<`0cXLX2000000040000o`00000000000000
0?l0oooPY03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon000`000000
oooP0?ooh0070?ooh0030000003oon00oooP00T0oooP<P0cXLX3000000030000o`00000000000?l0
oooPY@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon03000000L0oooP
00<000000?ooh03oon002@3oon0a03>QbP<0000000<0003o000000000000o`3oon2V0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP<00c
XLX3000000030000o`00000000000?l0oooPY`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh300<j7:0P0000000`000?l000000000003o
0?ooh:P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon0_03>QbP80000000<0003o000000000000o`3oon2Y0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP;P0cXLX200000003
0000o`00000000000?l0oooPZP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh2d0<j7:0P0000000`000?l000000000003o0?ooh:/0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on0/03>QbP80000000<0003o000000000000o`3oon2/0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP:`0cXLX2000000040000o`000000
000000000?l0oooP[03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh2X0<j7:0P00000010000?l0000000000000003o0?ooh:d0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0Y
03>QbP<0000000<0003o000000000000o`3oon2^0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP:@0cXLX2000000030000o`0000000000
0?l0oooP[`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh2P0<j7:0P0000000`000?l000000000003o0?ooh;00oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0W03>QbP800000
00<0003o000000000000o`3oon2a0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0<000002@3oon0V03>QbP80000000<0003o000000000000o`3oon2`0?ooh0<000006`3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0U03>QbP80000000<0003o
000000000000o`3oon2c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP900cXLX2000000030000o`00000000000?l0oooP]03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh2<0
<j7:0P0000000`000?l000000000003o0?ooh;D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0R03>QbP80000000<0003o000000000000
o`3oon2f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP8@0cXLX3000000030000o`00000000000?l0oooP]P3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh200<j7:0`000000
0`000?l000000000003o0?ooh;L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon0P03>QbP80000000<0003o000000000000o`3oon2h0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP7`0cXLX2000000030000o`00000000000?l0oooP^@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh1h0<j7:0P0000000`000?l00000
0000003o0?ooh;X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon0M03>QbP80000000<0003o000000000000o`3oon2k0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP700cXLX3
000000030000o`00000000000?l0oooP^`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh1/0<j7:0`0000000`000?l000000000003o0?oo
h;`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon0J03>QbP<0000000<0003o000000000000o`3oon2m0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP6P0cXLX2000000030000
o`00000000000?l0oooP_P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh1T0<j7:0P0000000`000?l000000000003o0?ooh;l0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh1P0<j7:0P000000
0`000?l000000000003o0?ooh;h0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh1L0<j7:0`0000000`000?l000000?ooh03o0?ooh<00oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0F03>QbP<0
000000<0003o0000003oon00o`3oon310?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP5@0cXLX3000000030000o`00000000000?l0oooP
`P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh1@0<j7:0`0000000`000?l000000000003o0?ooh<<0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0D03>QbP80000000<0003o
000000000000o`3oon340?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP4`0cXLX2000000030000o`00000000000?l0oooPa@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh180
<j7:0`0000000`000?l000000?ooh03o0?ooh<D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0A03>QbP<0000000<0003o0000003oon00
o`3oon360?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP400cXLX3000000030000o`000000oooP0?l0oooPa`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0l0<j7:0`000000
0`000?l000000000003o0?ooh<P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon0?03>QbP80000000<0003o000000000000o`3oon390?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooP3P0cXLX2000000030000o`00000000000?l0oooPbP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0d0<j7:0`0000000`000?l00000
0?ooh03o0?ooh<X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon0<03>QbP<0000000<0003o0000003oon00o`3oon3;0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP2`0cXLX3
000000030000o`00000000000?l0oooPc03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon03000000T0oooP2P0cXLX3000000030000o`00000000000?l0oooPb`3oon030000
01/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP2@0cXLX300000003
0000o`00000000000?l0oooPcP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh0T0<j7:0P0000000`000?l000000000003o0?ooh<l0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on0803>QbP80000000<0003o000000000000o`3oon3@0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP1`0cXLX2000000030000o`000000
00000?l0oooPd@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh0H0<j7:0`0000000`000?l000000?ooh03o0?ooh=40oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0503>QbP<0
000000<0003o000000000000o`3oon3B0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP1@0cXLX2000000030000o`00000000000?l0oooP
d`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh0@0<j7:0P0000000`000?l000000000003o0?ooh=@0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0303>QbP80000000<0003o
000000000000o`3oon3E0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP0P0cXLX2000000030000o`00000000000?l0oooPeP3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh004
03>QbP00000000000000o`800000o`3oon3G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP0`0000000`000?l000000000003o0?ooh=L0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh0030000
003oon00oooP00T0oooP0P0000000`000?l000000000003o0?ooh=P0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP
0?ooh0080?ooh080000000<0003o000000000000o`3oon3I0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP100000060?ooh0800000
00<0003o000000000000o`3oon3G0?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P00
00080?ooh0030000003oon00oooP00L0oooP1000003o0?ooh=/0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?oo
h0080?ooh0800000o`3oon3L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>
0?ooh0800000203oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03o
on00BP3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03o
on00BP3oon000`000000oooP0?ooh01;0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03o
on002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP
0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP
0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh0090?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh?l00000jP00000K0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00d@3jl>H400000080n_3V20000002
0?[`iP@0000000L0n_3V00000000000000000?[`iP000000n_3V00`0000000<0n_3V000000000000
10000000103jl>H000000000000000080?[`iPD00000103jl>H7000000030?[`iP000000n_3V00<0
0000203jl>H500000080n_3V100000020?[`iPD00000303jl>H300000140n_3V0`0000060?[`iP<0
000000@0n_3V00000000000000001P3jl>H00`000000n_3V0?[`iP040?[`iP<0000000@0n_3V0000
000000000000f03jl>H10?ooo`00dP3jl>H200000080n_3V0P0000030?[`iP8000000`3jl>H20000
00<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P00
00000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H010000000n_3V0?[`
iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V0080
00002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V0P0000000`3jl>H0
00000000000?0?[`iP80000000<0n_3V0000000000001P3jl>H2000000030?[`iP000000000000L0
n_3V00<000000?[`iP3jl>H01@3jl>H2000000030?[`iP00000000000=T0n_3V0@3oool00=80n_3V
0P0000000`3jl>H00000000000040?[`iP8000000`3jl>H2000000D0n_3V0P0000000`3jl>H00000
0?[`iP0400000080n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`
iP000000000000d0n_3V0P0000020?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H0
00000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80
000000<0n_3V0000000000001@3jl>H5000000D0n_3V0P0000000`3jl>H00000000000070?[`iP<0
00001P3jl>H5000000H0n_3V0`00003J0?[`iP40oooo003B0?[`iPD00000103jl>H2000000<0n_3V
1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`
iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V0P000003
0?[`iP8000000P3jl>H200000080n_3V0P00000=0?[`iP80000000<0n_3V0000000000003`3jl>H2
000000030?[`iP000000000000L0n_3V0`0000080?[`iP030000003jl>H0n_3V00H0n_3V0`00003J
0?[`iP40oooo003B0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000P3jl>H20000
00060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H2000000030?[`iP00
000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H2000000040?[`iP00
000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3jl>H200000080n_3V
0P0000020?[`iP<0000000<0n_3V0000003jl>H02P3jl>H300000100n_3V100000070?[`iP800000
00<0n_3V0000000000001`3jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000
f@3jl>H10?ooo`00dP3jl>H200000080n_3V0P0000000`3jl>H0000000000002000000@0n_3V1000
00000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H5000000X0n_3V0P00
00050?[`iP<0000000<0n_3V0000000000001`00000:0?[`iPD000000P3jl>H400000080n_3V0`00
00000`3jl>H000000000000:0?[`iP80000000<0n_3V0000000000003`3jl>H2000000P0n_3V0`00
0000103jl>H0000000000000000=0?[`iP<0000000<0n_3V0000000000001@00003D0?[`iP40oooo
003B0?[`iP8000000P3jl>H2000003<0n_3V0P0000030?[`iP030000003jl>H0n_3V01L0n_3V0P00
000J0?[`iP80000000<0n_3V000000000000403jl>H2000002<0n_3V00<000000?[`iP3jl>H0e03j
l>H10?ooo`00d@3jl>H6000000@0n_3V0P00000_0?[`iPD000006P3jl>H3000001T0n_3V0`00000B
0?[`iP<000008P3jl>H00`000000n_3V0?[`iP3C0?[`iP40oooo003o0?[`iX<0n_3V00<000000?[`
iP3jl>H0dP3jl>H10?ooo`00o`3jl>J00?[`iP040000003jl>H0n_3V00000=@0n_3V0@3oool00?l0
n_3VP@3jl>H200000=D0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo0000
\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .60314 L
.02438 .60314 L
.02438 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .60314 L
.02438 .60314 L
.02438 .08012 L
s
.678 .847 .902 r
.02438 .08012 m
.02438 .60239 L
.02472 .60239 L
.02472 .08012 L
F
.2 .63 .79 r
.02438 .08012 m
.02438 .60239 L
.02472 .60239 L
.02472 .08012 L
s
.678 .847 .902 r
.02472 .08012 m
.02472 .60168 L
.02529 .60168 L
.02529 .08012 L
F
.2 .63 .79 r
.02472 .08012 m
.02472 .60168 L
.02529 .60168 L
.02529 .08012 L
s
.678 .847 .902 r
.02529 .08012 m
.02529 .60111 L
.02576 .60111 L
.02576 .08012 L
F
.2 .63 .79 r
.02529 .08012 m
.02529 .60111 L
.02576 .60111 L
.02576 .08012 L
s
.678 .847 .902 r
.02576 .08012 m
.02576 .60043 L
.02629 .60043 L
.02629 .08012 L
F
.2 .63 .79 r
.02576 .08012 m
.02576 .60043 L
.02629 .60043 L
.02629 .08012 L
s
.678 .847 .902 r
.02629 .08012 m
.02629 .59987 L
.02685 .59987 L
.02685 .08012 L
F
.2 .63 .79 r
.02629 .08012 m
.02629 .59987 L
.02685 .59987 L
.02685 .08012 L
s
.678 .847 .902 r
.02685 .08012 m
.02685 .59925 L
.02713 .59925 L
.02713 .08012 L
F
.2 .63 .79 r
.02685 .08012 m
.02685 .59925 L
.02713 .59925 L
.02713 .08012 L
s
.678 .847 .902 r
.02713 .08012 m
.02713 .59892 L
.02749 .59892 L
.02749 .08012 L
F
.2 .63 .79 r
.02713 .08012 m
.02713 .59892 L
.02749 .59892 L
.02749 .08012 L
s
.678 .847 .902 r
.02749 .08012 m
.02749 .59857 L
.02777 .59857 L
.02777 .08012 L
F
.2 .63 .79 r
.02749 .08012 m
.02749 .59857 L
.02777 .59857 L
.02777 .08012 L
s
.678 .847 .902 r
.02777 .08012 m
.02777 .59828 L
.02805 .59828 L
.02805 .08012 L
F
.2 .63 .79 r
.02777 .08012 m
.02777 .59828 L
.02805 .59828 L
.02805 .08012 L
s
.678 .847 .902 r
.02805 .08012 m
.02805 .59752 L
.0287 .59752 L
.0287 .08012 L
F
.2 .63 .79 r
.02805 .08012 m
.02805 .59752 L
.0287 .59752 L
.0287 .08012 L
s
.678 .847 .902 r
.0287 .08012 m
.0287 .59654 L
.02941 .59654 L
.02941 .08012 L
F
.2 .63 .79 r
.0287 .08012 m
.0287 .59654 L
.02941 .59654 L
.02941 .08012 L
s
.678 .847 .902 r
.02941 .08012 m
.02941 .59619 L
.02964 .59619 L
.02964 .08012 L
F
.2 .63 .79 r
.02941 .08012 m
.02941 .59619 L
.02964 .59619 L
.02964 .08012 L
s
.678 .847 .902 r
.02964 .08012 m
.02964 .59593 L
.03036 .59593 L
.03036 .08012 L
F
.2 .63 .79 r
.02964 .08012 m
.02964 .59593 L
.03036 .59593 L
.03036 .08012 L
s
.678 .847 .902 r
.03036 .08012 m
.03036 .59469 L
.03099 .59469 L
.03099 .08012 L
F
.2 .63 .79 r
.03036 .08012 m
.03036 .59469 L
.03099 .59469 L
.03099 .08012 L
s
.678 .847 .902 r
.03099 .08012 m
.03099 .5939 L
.03167 .5939 L
.03167 .08012 L
F
.2 .63 .79 r
.03099 .08012 m
.03099 .5939 L
.03167 .5939 L
.03167 .08012 L
s
.678 .847 .902 r
.03167 .08012 m
.03167 .59318 L
.0321 .59318 L
.0321 .08012 L
F
.2 .63 .79 r
.03167 .08012 m
.03167 .59318 L
.0321 .59318 L
.0321 .08012 L
s
.678 .847 .902 r
.0321 .08012 m
.0321 .59297 L
.03256 .59297 L
.03256 .08012 L
F
.2 .63 .79 r
.0321 .08012 m
.0321 .59297 L
.03256 .59297 L
.03256 .08012 L
s
.678 .847 .902 r
.03256 .08012 m
.03256 .59231 L
.03295 .59231 L
.03295 .08012 L
F
.2 .63 .79 r
.03256 .08012 m
.03256 .59231 L
.03295 .59231 L
.03295 .08012 L
s
.678 .847 .902 r
.03295 .08012 m
.03295 .59135 L
.03361 .59135 L
.03361 .08012 L
F
.2 .63 .79 r
.03295 .08012 m
.03295 .59135 L
.03361 .59135 L
.03361 .08012 L
s
.678 .847 .902 r
.03361 .08012 m
.03361 .59079 L
.03402 .59079 L
.03402 .08012 L
F
.2 .63 .79 r
.03361 .08012 m
.03361 .59079 L
.03402 .59079 L
.03402 .08012 L
s
.678 .847 .902 r
.03402 .08012 m
.03402 .59021 L
.03464 .59021 L
.03464 .08012 L
F
.2 .63 .79 r
.03402 .08012 m
.03402 .59021 L
.03464 .59021 L
.03464 .08012 L
s
.678 .847 .902 r
.03464 .08012 m
.03464 .58991 L
.03503 .58991 L
.03503 .08012 L
F
.2 .63 .79 r
.03464 .08012 m
.03464 .58991 L
.03503 .58991 L
.03503 .08012 L
s
.678 .847 .902 r
.03503 .08012 m
.03503 .58926 L
.03558 .58926 L
.03558 .08012 L
F
.2 .63 .79 r
.03503 .08012 m
.03503 .58926 L
.03558 .58926 L
.03558 .08012 L
s
.678 .847 .902 r
.03558 .08012 m
.03558 .58837 L
.03616 .58837 L
.03616 .08012 L
F
.2 .63 .79 r
.03558 .08012 m
.03558 .58837 L
.03616 .58837 L
.03616 .08012 L
s
.678 .847 .902 r
.03616 .08012 m
.03616 .58804 L
.03664 .58804 L
.03664 .08012 L
F
.2 .63 .79 r
.03616 .08012 m
.03616 .58804 L
.03664 .58804 L
.03664 .08012 L
s
.678 .847 .902 r
.03664 .08012 m
.03664 .58723 L
.03721 .58723 L
.03721 .08012 L
F
.2 .63 .79 r
.03664 .08012 m
.03664 .58723 L
.03721 .58723 L
.03721 .08012 L
s
.678 .847 .902 r
.03721 .08012 m
.03721 .5866 L
.03751 .5866 L
.03751 .08012 L
F
.2 .63 .79 r
.03721 .08012 m
.03721 .5866 L
.03751 .5866 L
.03751 .08012 L
s
.678 .847 .902 r
.03751 .08012 m
.03751 .5862 L
.03777 .5862 L
.03777 .08012 L
F
.2 .63 .79 r
.03751 .08012 m
.03751 .5862 L
.03777 .5862 L
.03777 .08012 L
s
.678 .847 .902 r
.03777 .08012 m
.03777 .58569 L
.03843 .58569 L
.03843 .08012 L
F
.2 .63 .79 r
.03777 .08012 m
.03777 .58569 L
.03843 .58569 L
.03843 .08012 L
s
.678 .847 .902 r
.03843 .08012 m
.03843 .58504 L
.03893 .58504 L
.03893 .08012 L
F
.2 .63 .79 r
.03843 .08012 m
.03843 .58504 L
.03893 .58504 L
.03893 .08012 L
s
.678 .847 .902 r
.03893 .08012 m
.03893 .58472 L
.0396 .58472 L
.0396 .08012 L
F
.2 .63 .79 r
.03893 .08012 m
.03893 .58472 L
.0396 .58472 L
.0396 .08012 L
s
.678 .847 .902 r
.0396 .08012 m
.0396 .58365 L
.04031 .58365 L
.04031 .08012 L
F
.2 .63 .79 r
.0396 .08012 m
.0396 .58365 L
.04031 .58365 L
.04031 .08012 L
s
.678 .847 .902 r
.04031 .08012 m
.04031 .58296 L
.04091 .58296 L
.04091 .08012 L
F
.2 .63 .79 r
.04031 .08012 m
.04031 .58296 L
.04091 .58296 L
.04091 .08012 L
s
.678 .847 .902 r
.04091 .08012 m
.04091 .58176 L
.04149 .58176 L
.04149 .08012 L
F
.2 .63 .79 r
.04091 .08012 m
.04091 .58176 L
.04149 .58176 L
.04149 .08012 L
s
.678 .847 .902 r
.04149 .08012 m
.04149 .5815 L
.04219 .5815 L
.04219 .08012 L
F
.2 .63 .79 r
.04149 .08012 m
.04149 .5815 L
.04219 .5815 L
.04219 .08012 L
s
.678 .847 .902 r
.04219 .08012 m
.04219 .58034 L
.04288 .58034 L
.04288 .08012 L
F
.2 .63 .79 r
.04219 .08012 m
.04219 .58034 L
.04288 .58034 L
.04288 .08012 L
s
.678 .847 .902 r
.04288 .08012 m
.04288 .57927 L
.0435 .57927 L
.0435 .08012 L
F
.2 .63 .79 r
.04288 .08012 m
.04288 .57927 L
.0435 .57927 L
.0435 .08012 L
s
.678 .847 .902 r
.0435 .08012 m
.0435 .57912 L
.04417 .57912 L
.04417 .08012 L
F
.2 .63 .79 r
.0435 .08012 m
.0435 .57912 L
.04417 .57912 L
.04417 .08012 L
s
.678 .847 .902 r
.04417 .08012 m
.04417 .57827 L
.04441 .57827 L
.04441 .08012 L
F
.2 .63 .79 r
.04417 .08012 m
.04417 .57827 L
.04441 .57827 L
.04441 .08012 L
s
.678 .847 .902 r
.04441 .08012 m
.04441 .57772 L
.0449 .57772 L
.0449 .08012 L
F
.2 .63 .79 r
.04441 .08012 m
.04441 .57772 L
.0449 .57772 L
.0449 .08012 L
s
.678 .847 .902 r
.0449 .08012 m
.0449 .57723 L
.04527 .57723 L
.04527 .08012 L
F
.2 .63 .79 r
.0449 .08012 m
.0449 .57723 L
.04527 .57723 L
.04527 .08012 L
s
.678 .847 .902 r
.04527 .08012 m
.04527 .5767 L
.04578 .5767 L
.04578 .08012 L
F
.2 .63 .79 r
.04527 .08012 m
.04527 .5767 L
.04578 .5767 L
.04578 .08012 L
s
.678 .847 .902 r
.04578 .08012 m
.04578 .57625 L
.04608 .57625 L
.04608 .08012 L
F
.2 .63 .79 r
.04578 .08012 m
.04578 .57625 L
.04608 .57625 L
.04608 .08012 L
s
.678 .847 .902 r
.04608 .08012 m
.04608 .57584 L
.04638 .57584 L
.04638 .08012 L
F
.2 .63 .79 r
.04608 .08012 m
.04608 .57584 L
.04638 .57584 L
.04638 .08012 L
s
.678 .847 .902 r
.04638 .08012 m
.04638 .57519 L
.04687 .57519 L
.04687 .08012 L
F
.2 .63 .79 r
.04638 .08012 m
.04638 .57519 L
.04687 .57519 L
.04687 .08012 L
s
.678 .847 .902 r
.04687 .08012 m
.04687 .57499 L
.0472 .57499 L
.0472 .08012 L
F
.2 .63 .79 r
.04687 .08012 m
.04687 .57499 L
.0472 .57499 L
.0472 .08012 L
s
.678 .847 .902 r
.0472 .08012 m
.0472 .57463 L
.04768 .57463 L
.04768 .08012 L
F
.2 .63 .79 r
.0472 .08012 m
.0472 .57463 L
.04768 .57463 L
.04768 .08012 L
s
.678 .847 .902 r
.04768 .08012 m
.04768 .57415 L
.04814 .57415 L
.04814 .08012 L
F
.2 .63 .79 r
.04768 .08012 m
.04768 .57415 L
.04814 .57415 L
.04814 .08012 L
s
.678 .847 .902 r
.04814 .08012 m
.04814 .57343 L
.04836 .57343 L
.04836 .08012 L
F
.2 .63 .79 r
.04814 .08012 m
.04814 .57343 L
.04836 .57343 L
.04836 .08012 L
s
.678 .847 .902 r
.04836 .08012 m
.04836 .57279 L
.04885 .57279 L
.04885 .08012 L
F
.2 .63 .79 r
.04836 .08012 m
.04836 .57279 L
.04885 .57279 L
.04885 .08012 L
s
.678 .847 .902 r
.04885 .08012 m
.04885 .57253 L
.04926 .57253 L
.04926 .08012 L
F
.2 .63 .79 r
.04885 .08012 m
.04885 .57253 L
.04926 .57253 L
.04926 .08012 L
s
.678 .847 .902 r
.04926 .08012 m
.04926 .57223 L
.04967 .57223 L
.04967 .08012 L
F
.2 .63 .79 r
.04926 .08012 m
.04926 .57223 L
.04967 .57223 L
.04967 .08012 L
s
.678 .847 .902 r
.04967 .08012 m
.04967 .57174 L
.04997 .57174 L
.04997 .08012 L
F
.2 .63 .79 r
.04967 .08012 m
.04967 .57174 L
.04997 .57174 L
.04997 .08012 L
s
.678 .847 .902 r
.04997 .08012 m
.04997 .57109 L
.05069 .57109 L
.05069 .08012 L
F
.2 .63 .79 r
.04997 .08012 m
.04997 .57109 L
.05069 .57109 L
.05069 .08012 L
s
.678 .847 .902 r
.05069 .08012 m
.05069 .57033 L
.05116 .57033 L
.05116 .08012 L
F
.2 .63 .79 r
.05069 .08012 m
.05069 .57033 L
.05116 .57033 L
.05116 .08012 L
s
.678 .847 .902 r
.05116 .08012 m
.05116 .56962 L
.05159 .56962 L
.05159 .08012 L
F
.2 .63 .79 r
.05116 .08012 m
.05116 .56962 L
.05159 .56962 L
.05159 .08012 L
s
.678 .847 .902 r
.05159 .08012 m
.05159 .56899 L
.05202 .56899 L
.05202 .08012 L
F
.2 .63 .79 r
.05159 .08012 m
.05159 .56899 L
.05202 .56899 L
.05202 .08012 L
s
.678 .847 .902 r
.05202 .08012 m
.05202 .56874 L
.05238 .56874 L
.05238 .08012 L
F
.2 .63 .79 r
.05202 .08012 m
.05202 .56874 L
.05238 .56874 L
.05238 .08012 L
s
.678 .847 .902 r
.05238 .08012 m
.05238 .5684 L
.05288 .5684 L
.05288 .08012 L
F
.2 .63 .79 r
.05238 .08012 m
.05238 .5684 L
.05288 .5684 L
.05288 .08012 L
s
.678 .847 .902 r
.05288 .08012 m
.05288 .56784 L
.05335 .56784 L
.05335 .08012 L
F
.2 .63 .79 r
.05288 .08012 m
.05288 .56784 L
.05335 .56784 L
.05335 .08012 L
s
.678 .847 .902 r
.05335 .08012 m
.05335 .56673 L
.05389 .56673 L
.05389 .08012 L
F
.2 .63 .79 r
.05335 .08012 m
.05335 .56673 L
.05389 .56673 L
.05389 .08012 L
s
.678 .847 .902 r
.05389 .08012 m
.05389 .56653 L
.05431 .56653 L
.05431 .08012 L
F
.2 .63 .79 r
.05389 .08012 m
.05389 .56653 L
.05431 .56653 L
.05431 .08012 L
s
.678 .847 .902 r
.05431 .08012 m
.05431 .56582 L
.05479 .56582 L
.05479 .08012 L
F
.2 .63 .79 r
.05431 .08012 m
.05431 .56582 L
.05479 .56582 L
.05479 .08012 L
s
.678 .847 .902 r
.05479 .08012 m
.05479 .56524 L
.0555 .56524 L
.0555 .08012 L
F
.2 .63 .79 r
.05479 .08012 m
.05479 .56524 L
.0555 .56524 L
.0555 .08012 L
s
.678 .847 .902 r
.0555 .08012 m
.0555 .56466 L
.0559 .56466 L
.0559 .08012 L
F
.2 .63 .79 r
.0555 .08012 m
.0555 .56466 L
.0559 .56466 L
.0559 .08012 L
s
.678 .847 .902 r
.0559 .08012 m
.0559 .56376 L
.05653 .56376 L
.05653 .08012 L
F
.2 .63 .79 r
.0559 .08012 m
.0559 .56376 L
.05653 .56376 L
.05653 .08012 L
s
.678 .847 .902 r
.05653 .08012 m
.05653 .56353 L
.05693 .56353 L
.05693 .08012 L
F
.2 .63 .79 r
.05653 .08012 m
.05653 .56353 L
.05693 .56353 L
.05693 .08012 L
s
.678 .847 .902 r
.05693 .08012 m
.05693 .56254 L
.05756 .56254 L
.05756 .08012 L
F
.2 .63 .79 r
.05693 .08012 m
.05693 .56254 L
.05756 .56254 L
.05756 .08012 L
s
.678 .847 .902 r
.05756 .08012 m
.05756 .56207 L
.05821 .56207 L
.05821 .08012 L
F
.2 .63 .79 r
.05756 .08012 m
.05756 .56207 L
.05821 .56207 L
.05821 .08012 L
s
.678 .847 .902 r
.05821 .08012 m
.05821 .56138 L
.05873 .56138 L
.05873 .08012 L
F
.2 .63 .79 r
.05821 .08012 m
.05821 .56138 L
.05873 .56138 L
.05873 .08012 L
s
.678 .847 .902 r
.05873 .08012 m
.05873 .56029 L
.05938 .56029 L
.05938 .08012 L
F
.2 .63 .79 r
.05873 .08012 m
.05873 .56029 L
.05938 .56029 L
.05938 .08012 L
s
.678 .847 .902 r
.05938 .08012 m
.05938 .55986 L
.05977 .55986 L
.05977 .08012 L
F
.2 .63 .79 r
.05938 .08012 m
.05938 .55986 L
.05977 .55986 L
.05977 .08012 L
s
.678 .847 .902 r
.05977 .08012 m
.05977 .55926 L
.06041 .55926 L
.06041 .08012 L
F
.2 .63 .79 r
.05977 .08012 m
.05977 .55926 L
.06041 .55926 L
.06041 .08012 L
s
.678 .847 .902 r
.06041 .08012 m
.06041 .55885 L
.06066 .55885 L
.06066 .08012 L
F
.2 .63 .79 r
.06041 .08012 m
.06041 .55885 L
.06066 .55885 L
.06066 .08012 L
s
.678 .847 .902 r
.06066 .08012 m
.06066 .55845 L
.06112 .55845 L
.06112 .08012 L
F
.2 .63 .79 r
.06066 .08012 m
.06066 .55845 L
.06112 .55845 L
.06112 .08012 L
s
.678 .847 .902 r
.06112 .08012 m
.06112 .55762 L
.06183 .55762 L
.06183 .08012 L
F
.2 .63 .79 r
.06112 .08012 m
.06112 .55762 L
.06183 .55762 L
.06183 .08012 L
s
.678 .847 .902 r
.06183 .08012 m
.06183 .55695 L
.06239 .55695 L
.06239 .08012 L
F
.2 .63 .79 r
.06183 .08012 m
.06183 .55695 L
.06239 .55695 L
.06239 .08012 L
s
.678 .847 .902 r
.06239 .08012 m
.06239 .5563 L
.06266 .5563 L
.06266 .08012 L
F
.2 .63 .79 r
.06239 .08012 m
.06239 .5563 L
.06266 .5563 L
.06266 .08012 L
s
.678 .847 .902 r
.06266 .08012 m
.06266 .55547 L
.06338 .55547 L
.06338 .08012 L
F
.2 .63 .79 r
.06266 .08012 m
.06266 .55547 L
.06338 .55547 L
.06338 .08012 L
s
.678 .847 .902 r
.06338 .08012 m
.06338 .55493 L
.06387 .55493 L
.06387 .08012 L
F
.2 .63 .79 r
.06338 .08012 m
.06338 .55493 L
.06387 .55493 L
.06387 .08012 L
s
.678 .847 .902 r
.06387 .08012 m
.06387 .55462 L
.06423 .55462 L
.06423 .08012 L
F
.2 .63 .79 r
.06387 .08012 m
.06387 .55462 L
.06423 .55462 L
.06423 .08012 L
s
.678 .847 .902 r
.06423 .08012 m
.06423 .55411 L
.06486 .55411 L
.06486 .08012 L
F
.2 .63 .79 r
.06423 .08012 m
.06423 .55411 L
.06486 .55411 L
.06486 .08012 L
s
.678 .847 .902 r
.06486 .08012 m
.06486 .55329 L
.0653 .55329 L
.0653 .08012 L
F
.2 .63 .79 r
.06486 .08012 m
.06486 .55329 L
.0653 .55329 L
.0653 .08012 L
s
.678 .847 .902 r
.0653 .08012 m
.0653 .55295 L
.06555 .55295 L
.06555 .08012 L
F
.2 .63 .79 r
.0653 .08012 m
.0653 .55295 L
.06555 .55295 L
.06555 .08012 L
s
.678 .847 .902 r
.06555 .08012 m
.06555 .55252 L
.06609 .55252 L
.06609 .08012 L
F
.2 .63 .79 r
.06555 .08012 m
.06555 .55252 L
.06609 .55252 L
.06609 .08012 L
s
.678 .847 .902 r
.06609 .08012 m
.06609 .55221 L
.06653 .55221 L
.06653 .08012 L
F
.2 .63 .79 r
.06609 .08012 m
.06609 .55221 L
.06653 .55221 L
.06653 .08012 L
s
.678 .847 .902 r
.06653 .08012 m
.06653 .55169 L
.06722 .55169 L
.06722 .08012 L
F
.2 .63 .79 r
.06653 .08012 m
.06653 .55169 L
.06722 .55169 L
.06722 .08012 L
s
.678 .847 .902 r
.06722 .08012 m
.06722 .55083 L
.06748 .55083 L
.06748 .08012 L
F
.2 .63 .79 r
.06722 .08012 m
.06722 .55083 L
.06748 .55083 L
.06748 .08012 L
s
.678 .847 .902 r
.06748 .08012 m
.06748 .55048 L
.06784 .55048 L
.06784 .08012 L
F
.2 .63 .79 r
.06748 .08012 m
.06748 .55048 L
.06784 .55048 L
.06784 .08012 L
s
.678 .847 .902 r
.06784 .08012 m
.06784 .54997 L
.06839 .54997 L
.06839 .08012 L
F
.2 .63 .79 r
.06784 .08012 m
.06784 .54997 L
.06839 .54997 L
.06839 .08012 L
s
.678 .847 .902 r
.06839 .08012 m
.06839 .54896 L
.06889 .54896 L
.06889 .08012 L
F
.2 .63 .79 r
.06839 .08012 m
.06839 .54896 L
.06889 .54896 L
.06889 .08012 L
s
.678 .847 .902 r
.06889 .08012 m
.06889 .54872 L
.06926 .54872 L
.06926 .08012 L
F
.2 .63 .79 r
.06889 .08012 m
.06889 .54872 L
.06926 .54872 L
.06926 .08012 L
s
.678 .847 .902 r
.06926 .08012 m
.06926 .54802 L
.06971 .54802 L
.06971 .08012 L
F
.2 .63 .79 r
.06926 .08012 m
.06926 .54802 L
.06971 .54802 L
.06971 .08012 L
s
.678 .847 .902 r
.06971 .08012 m
.06971 .54768 L
.06994 .54768 L
.06994 .08012 L
F
.2 .63 .79 r
.06971 .08012 m
.06971 .54768 L
.06994 .54768 L
.06994 .08012 L
s
.678 .847 .902 r
.06994 .08012 m
.06994 .54763 L
.07053 .54763 L
.07053 .08012 L
F
.2 .63 .79 r
.06994 .08012 m
.06994 .54763 L
.07053 .54763 L
.07053 .08012 L
s
.678 .847 .902 r
.07053 .08012 m
.07053 .54634 L
.07124 .54634 L
.07124 .08012 L
F
.2 .63 .79 r
.07053 .08012 m
.07053 .54634 L
.07124 .54634 L
.07124 .08012 L
s
.678 .847 .902 r
.07124 .08012 m
.07124 .54597 L
.07178 .54597 L
.07178 .08012 L
F
.2 .63 .79 r
.07124 .08012 m
.07124 .54597 L
.07178 .54597 L
.07178 .08012 L
s
.678 .847 .902 r
.07178 .08012 m
.07178 .54498 L
.07249 .54498 L
.07249 .08012 L
F
.2 .63 .79 r
.07178 .08012 m
.07178 .54498 L
.07249 .54498 L
.07249 .08012 L
s
.678 .847 .902 r
.07249 .08012 m
.07249 .54439 L
.07284 .54439 L
.07284 .08012 L
F
.2 .63 .79 r
.07249 .08012 m
.07249 .54439 L
.07284 .54439 L
.07284 .08012 L
s
.678 .847 .902 r
.07284 .08012 m
.07284 .5441 L
.07357 .5441 L
.07357 .08012 L
F
.2 .63 .79 r
.07284 .08012 m
.07284 .5441 L
.07357 .5441 L
.07357 .08012 L
s
.678 .847 .902 r
.07357 .08012 m
.07357 .54273 L
.07428 .54273 L
.07428 .08012 L
F
.2 .63 .79 r
.07357 .08012 m
.07357 .54273 L
.07428 .54273 L
.07428 .08012 L
s
.678 .847 .902 r
.07428 .08012 m
.07428 .54205 L
.07495 .54205 L
.07495 .08012 L
F
.2 .63 .79 r
.07428 .08012 m
.07428 .54205 L
.07495 .54205 L
.07495 .08012 L
s
.678 .847 .902 r
.07495 .08012 m
.07495 .54148 L
.07531 .54148 L
.07531 .08012 L
F
.2 .63 .79 r
.07495 .08012 m
.07495 .54148 L
.07531 .54148 L
.07531 .08012 L
s
.678 .847 .902 r
.07531 .08012 m
.07531 .54119 L
.07576 .54119 L
.07576 .08012 L
F
.2 .63 .79 r
.07531 .08012 m
.07531 .54119 L
.07576 .54119 L
.07576 .08012 L
s
.678 .847 .902 r
.07576 .08012 m
.07576 .54065 L
.07633 .54065 L
.07633 .08012 L
F
.2 .63 .79 r
.07576 .08012 m
.07576 .54065 L
.07633 .54065 L
.07633 .08012 L
s
.678 .847 .902 r
.07633 .08012 m
.07633 .54011 L
.07658 .54011 L
.07658 .08012 L
F
.2 .63 .79 r
.07633 .08012 m
.07633 .54011 L
.07658 .54011 L
.07658 .08012 L
s
.678 .847 .902 r
.07658 .08012 m
.07658 .53986 L
.07724 .53986 L
.07724 .08012 L
F
.2 .63 .79 r
.07658 .08012 m
.07658 .53986 L
.07724 .53986 L
.07724 .08012 L
s
.678 .847 .902 r
.07724 .08012 m
.07724 .53878 L
.07766 .53878 L
.07766 .08012 L
F
.2 .63 .79 r
.07724 .08012 m
.07724 .53878 L
.07766 .53878 L
.07766 .08012 L
s
.678 .847 .902 r
.07766 .08012 m
.07766 .53841 L
.07791 .53841 L
.07791 .08012 L
F
.2 .63 .79 r
.07766 .08012 m
.07766 .53841 L
.07791 .53841 L
.07791 .08012 L
s
.678 .847 .902 r
.07791 .08012 m
.07791 .53818 L
.07845 .53818 L
.07845 .08012 L
F
.2 .63 .79 r
.07791 .08012 m
.07791 .53818 L
.07845 .53818 L
.07845 .08012 L
s
.678 .847 .902 r
.07845 .08012 m
.07845 .53768 L
.07915 .53768 L
.07915 .08012 L
F
.2 .63 .79 r
.07845 .08012 m
.07845 .53768 L
.07915 .53768 L
.07915 .08012 L
s
.678 .847 .902 r
.07915 .08012 m
.07915 .53667 L
.07953 .53667 L
.07953 .08012 L
F
.2 .63 .79 r
.07915 .08012 m
.07915 .53667 L
.07953 .53667 L
.07953 .08012 L
s
.678 .847 .902 r
.07953 .08012 m
.07953 .53605 L
.08015 .53605 L
.08015 .08012 L
F
.2 .63 .79 r
.07953 .08012 m
.07953 .53605 L
.08015 .53605 L
.08015 .08012 L
s
.678 .847 .902 r
.08015 .08012 m
.08015 .53491 L
.08088 .53491 L
.08088 .08012 L
F
.2 .63 .79 r
.08015 .08012 m
.08015 .53491 L
.08088 .53491 L
.08088 .08012 L
s
.678 .847 .902 r
.08088 .08012 m
.08088 .53483 L
.0813 .53483 L
.0813 .08012 L
F
.2 .63 .79 r
.08088 .08012 m
.08088 .53483 L
.0813 .53483 L
.0813 .08012 L
s
.678 .847 .902 r
.0813 .08012 m
.0813 .53439 L
.08153 .53439 L
.08153 .08012 L
F
.2 .63 .79 r
.0813 .08012 m
.0813 .53439 L
.08153 .53439 L
.08153 .08012 L
s
.678 .847 .902 r
.08153 .08012 m
.08153 .53383 L
.08192 .53383 L
.08192 .08012 L
F
.2 .63 .79 r
.08153 .08012 m
.08153 .53383 L
.08192 .53383 L
.08192 .08012 L
s
.678 .847 .902 r
.08192 .08012 m
.08192 .53287 L
.08263 .53287 L
.08263 .08012 L
F
.2 .63 .79 r
.08192 .08012 m
.08192 .53287 L
.08263 .53287 L
.08263 .08012 L
s
.678 .847 .902 r
.08263 .08012 m
.08263 .53283 L
.08319 .53283 L
.08319 .08012 L
F
.2 .63 .79 r
.08263 .08012 m
.08263 .53283 L
.08319 .53283 L
.08319 .08012 L
s
.678 .847 .902 r
.08319 .08012 m
.08319 .53213 L
.08345 .53213 L
.08345 .08012 L
F
.2 .63 .79 r
.08319 .08012 m
.08319 .53213 L
.08345 .53213 L
.08345 .08012 L
s
.678 .847 .902 r
.08345 .08012 m
.08345 .53165 L
.08403 .53165 L
.08403 .08012 L
F
.2 .63 .79 r
.08345 .08012 m
.08345 .53165 L
.08403 .53165 L
.08403 .08012 L
s
.678 .847 .902 r
.08403 .08012 m
.08403 .53095 L
.08476 .53095 L
.08476 .08012 L
F
.2 .63 .79 r
.08403 .08012 m
.08403 .53095 L
.08476 .53095 L
.08476 .08012 L
s
.678 .847 .902 r
.08476 .08012 m
.08476 .53023 L
.08518 .53023 L
.08518 .08012 L
F
.2 .63 .79 r
.08476 .08012 m
.08476 .53023 L
.08518 .53023 L
.08518 .08012 L
s
.678 .847 .902 r
.08518 .08012 m
.08518 .52988 L
.08544 .52988 L
.08544 .08012 L
F
.2 .63 .79 r
.08518 .08012 m
.08518 .52988 L
.08544 .52988 L
.08544 .08012 L
s
.678 .847 .902 r
.08544 .08012 m
.08544 .52921 L
.08605 .52921 L
.08605 .08012 L
F
.2 .63 .79 r
.08544 .08012 m
.08544 .52921 L
.08605 .52921 L
.08605 .08012 L
s
.678 .847 .902 r
.08605 .08012 m
.08605 .52869 L
.08633 .52869 L
.08633 .08012 L
F
.2 .63 .79 r
.08605 .08012 m
.08605 .52869 L
.08633 .52869 L
.08633 .08012 L
s
.678 .847 .902 r
.08633 .08012 m
.08633 .52839 L
.08661 .52839 L
.08661 .08012 L
F
.2 .63 .79 r
.08633 .08012 m
.08633 .52839 L
.08661 .52839 L
.08661 .08012 L
s
.678 .847 .902 r
.08661 .08012 m
.08661 .52781 L
.08715 .52781 L
.08715 .08012 L
F
.2 .63 .79 r
.08661 .08012 m
.08661 .52781 L
.08715 .52781 L
.08715 .08012 L
s
.678 .847 .902 r
.08715 .08012 m
.08715 .52756 L
.0874 .52756 L
.0874 .08012 L
F
.2 .63 .79 r
.08715 .08012 m
.08715 .52756 L
.0874 .52756 L
.0874 .08012 L
s
.678 .847 .902 r
.0874 .08012 m
.0874 .52723 L
.08765 .52723 L
.08765 .08012 L
F
.2 .63 .79 r
.0874 .08012 m
.0874 .52723 L
.08765 .52723 L
.08765 .08012 L
s
.678 .847 .902 r
.08765 .08012 m
.08765 .52683 L
.08802 .52683 L
.08802 .08012 L
F
.2 .63 .79 r
.08765 .08012 m
.08765 .52683 L
.08802 .52683 L
.08802 .08012 L
s
.678 .847 .902 r
.08802 .08012 m
.08802 .52663 L
.08834 .52663 L
.08834 .08012 L
F
.2 .63 .79 r
.08802 .08012 m
.08802 .52663 L
.08834 .52663 L
.08834 .08012 L
s
.678 .847 .902 r
.08834 .08012 m
.08834 .52613 L
.08857 .52613 L
.08857 .08012 L
F
.2 .63 .79 r
.08834 .08012 m
.08834 .52613 L
.08857 .52613 L
.08857 .08012 L
s
.678 .847 .902 r
.08857 .08012 m
.08857 .52594 L
.08901 .52594 L
.08901 .08012 L
F
.2 .63 .79 r
.08857 .08012 m
.08857 .52594 L
.08901 .52594 L
.08901 .08012 L
s
.678 .847 .902 r
.08901 .08012 m
.08901 .52527 L
.0894 .52527 L
.0894 .08012 L
F
.2 .63 .79 r
.08901 .08012 m
.08901 .52527 L
.0894 .52527 L
.0894 .08012 L
s
.678 .847 .902 r
.0894 .08012 m
.0894 .52465 L
.09008 .52465 L
.09008 .08012 L
F
.2 .63 .79 r
.0894 .08012 m
.0894 .52465 L
.09008 .52465 L
.09008 .08012 L
s
.678 .847 .902 r
.09008 .08012 m
.09008 .5239 L
.09041 .5239 L
.09041 .08012 L
F
.2 .63 .79 r
.09008 .08012 m
.09008 .5239 L
.09041 .5239 L
.09041 .08012 L
s
.678 .847 .902 r
.09041 .08012 m
.09041 .52379 L
.09085 .52379 L
.09085 .08012 L
F
.2 .63 .79 r
.09041 .08012 m
.09041 .52379 L
.09085 .52379 L
.09085 .08012 L
s
.678 .847 .902 r
.09085 .08012 m
.09085 .52306 L
.09157 .52306 L
.09157 .08012 L
F
.2 .63 .79 r
.09085 .08012 m
.09085 .52306 L
.09157 .52306 L
.09157 .08012 L
s
.678 .847 .902 r
.09157 .08012 m
.09157 .52221 L
.09223 .52221 L
.09223 .08012 L
F
.2 .63 .79 r
.09157 .08012 m
.09157 .52221 L
.09223 .52221 L
.09223 .08012 L
s
.678 .847 .902 r
.09223 .08012 m
.09223 .5216 L
.09291 .5216 L
.09291 .08012 L
F
.2 .63 .79 r
.09223 .08012 m
.09223 .5216 L
.09291 .5216 L
.09291 .08012 L
s
.678 .847 .902 r
.09291 .08012 m
.09291 .52092 L
.09337 .52092 L
.09337 .08012 L
F
.2 .63 .79 r
.09291 .08012 m
.09291 .52092 L
.09337 .52092 L
.09337 .08012 L
s
.678 .847 .902 r
.09337 .08012 m
.09337 .52034 L
.09374 .52034 L
.09374 .08012 L
F
.2 .63 .79 r
.09337 .08012 m
.09337 .52034 L
.09374 .52034 L
.09374 .08012 L
s
.678 .847 .902 r
.09374 .08012 m
.09374 .51994 L
.09437 .51994 L
.09437 .08012 L
F
.2 .63 .79 r
.09374 .08012 m
.09374 .51994 L
.09437 .51994 L
.09437 .08012 L
s
.678 .847 .902 r
.09437 .08012 m
.09437 .51903 L
.09468 .51903 L
.09468 .08012 L
F
.2 .63 .79 r
.09437 .08012 m
.09437 .51903 L
.09468 .51903 L
.09468 .08012 L
s
.678 .847 .902 r
.09468 .08012 m
.09468 .51855 L
.09514 .51855 L
.09514 .08012 L
F
.2 .63 .79 r
.09468 .08012 m
.09468 .51855 L
.09514 .51855 L
.09514 .08012 L
s
.678 .847 .902 r
.09514 .08012 m
.09514 .51845 L
.09582 .51845 L
.09582 .08012 L
F
.2 .63 .79 r
.09514 .08012 m
.09514 .51845 L
.09582 .51845 L
.09582 .08012 L
s
.678 .847 .902 r
.09582 .08012 m
.09582 .51762 L
.09641 .51762 L
.09641 .08012 L
F
.2 .63 .79 r
.09582 .08012 m
.09582 .51762 L
.09641 .51762 L
.09641 .08012 L
s
.678 .847 .902 r
.09641 .08012 m
.09641 .51686 L
.09685 .51686 L
.09685 .08012 L
F
.2 .63 .79 r
.09641 .08012 m
.09641 .51686 L
.09685 .51686 L
.09685 .08012 L
s
.678 .847 .902 r
.09685 .08012 m
.09685 .51642 L
.09725 .51642 L
.09725 .08012 L
F
.2 .63 .79 r
.09685 .08012 m
.09685 .51642 L
.09725 .51642 L
.09725 .08012 L
s
.678 .847 .902 r
.09725 .08012 m
.09725 .51574 L
.09786 .51574 L
.09786 .08012 L
F
.2 .63 .79 r
.09725 .08012 m
.09725 .51574 L
.09786 .51574 L
.09786 .08012 L
s
.678 .847 .902 r
.09786 .08012 m
.09786 .51523 L
.09813 .51523 L
.09813 .08012 L
F
.2 .63 .79 r
.09786 .08012 m
.09786 .51523 L
.09813 .51523 L
.09813 .08012 L
s
.678 .847 .902 r
.09813 .08012 m
.09813 .51502 L
.09854 .51502 L
.09854 .08012 L
F
.2 .63 .79 r
.09813 .08012 m
.09813 .51502 L
.09854 .51502 L
.09854 .08012 L
s
.678 .847 .902 r
.09854 .08012 m
.09854 .51424 L
.09891 .51424 L
.09891 .08012 L
F
.2 .63 .79 r
.09854 .08012 m
.09854 .51424 L
.09891 .51424 L
.09891 .08012 L
s
.678 .847 .902 r
.09891 .08012 m
.09891 .51366 L
.09938 .51366 L
.09938 .08012 L
F
.2 .63 .79 r
.09891 .08012 m
.09891 .51366 L
.09938 .51366 L
.09938 .08012 L
s
.678 .847 .902 r
.09938 .08012 m
.09938 .51335 L
.10006 .51335 L
.10006 .08012 L
F
.2 .63 .79 r
.09938 .08012 m
.09938 .51335 L
.10006 .51335 L
.10006 .08012 L
s
.678 .847 .902 r
.10006 .08012 m
.10006 .51259 L
.10045 .51259 L
.10045 .08012 L
F
.2 .63 .79 r
.10006 .08012 m
.10006 .51259 L
.10045 .51259 L
.10045 .08012 L
s
.678 .847 .902 r
.10045 .08012 m
.10045 .51188 L
.10111 .51188 L
.10111 .08012 L
F
.2 .63 .79 r
.10045 .08012 m
.10045 .51188 L
.10111 .51188 L
.10111 .08012 L
s
.678 .847 .902 r
.10111 .08012 m
.10111 .5115 L
.1014 .5115 L
.1014 .08012 L
F
.2 .63 .79 r
.10111 .08012 m
.10111 .5115 L
.1014 .5115 L
.1014 .08012 L
s
.678 .847 .902 r
.1014 .08012 m
.1014 .51109 L
.10163 .51109 L
.10163 .08012 L
F
.2 .63 .79 r
.1014 .08012 m
.1014 .51109 L
.10163 .51109 L
.10163 .08012 L
s
.678 .847 .902 r
.10163 .08012 m
.10163 .51085 L
.10191 .51085 L
.10191 .08012 L
F
.2 .63 .79 r
.10163 .08012 m
.10163 .51085 L
.10191 .51085 L
.10191 .08012 L
s
.678 .847 .902 r
.10191 .08012 m
.10191 .51048 L
.10235 .51048 L
.10235 .08012 L
F
.2 .63 .79 r
.10191 .08012 m
.10191 .51048 L
.10235 .51048 L
.10235 .08012 L
s
.678 .847 .902 r
.10235 .08012 m
.10235 .51022 L
.10266 .51022 L
.10266 .08012 L
F
.2 .63 .79 r
.10235 .08012 m
.10235 .51022 L
.10266 .51022 L
.10266 .08012 L
s
.678 .847 .902 r
.10266 .08012 m
.10266 .50975 L
.10295 .50975 L
.10295 .08012 L
F
.2 .63 .79 r
.10266 .08012 m
.10266 .50975 L
.10295 .50975 L
.10295 .08012 L
s
.678 .847 .902 r
.10295 .08012 m
.10295 .5094 L
.10328 .5094 L
.10328 .08012 L
F
.2 .63 .79 r
.10295 .08012 m
.10295 .5094 L
.10328 .5094 L
.10328 .08012 L
s
.678 .847 .902 r
.10328 .08012 m
.10328 .50888 L
.104 .50888 L
.104 .08012 L
F
.2 .63 .79 r
.10328 .08012 m
.10328 .50888 L
.104 .50888 L
.104 .08012 L
s
.678 .847 .902 r
.104 .08012 m
.104 .50782 L
.10466 .50782 L
.10466 .08012 L
F
.2 .63 .79 r
.104 .08012 m
.104 .50782 L
.10466 .50782 L
.10466 .08012 L
s
.678 .847 .902 r
.10466 .08012 m
.10466 .5075 L
.10506 .5075 L
.10506 .08012 L
F
.2 .63 .79 r
.10466 .08012 m
.10466 .5075 L
.10506 .5075 L
.10506 .08012 L
s
.678 .847 .902 r
.10506 .08012 m
.10506 .50702 L
.10529 .50702 L
.10529 .08012 L
F
.2 .63 .79 r
.10506 .08012 m
.10506 .50702 L
.10529 .50702 L
.10529 .08012 L
s
.678 .847 .902 r
.10529 .08012 m
.10529 .50661 L
.10577 .50661 L
.10577 .08012 L
F
.2 .63 .79 r
.10529 .08012 m
.10529 .50661 L
.10577 .50661 L
.10577 .08012 L
s
.678 .847 .902 r
.10577 .08012 m
.10577 .50577 L
.10649 .50577 L
.10649 .08012 L
F
.2 .63 .79 r
.10577 .08012 m
.10577 .50577 L
.10649 .50577 L
.10649 .08012 L
s
.678 .847 .902 r
.10649 .08012 m
.10649 .50545 L
.10703 .50545 L
.10703 .08012 L
F
.2 .63 .79 r
.10649 .08012 m
.10649 .50545 L
.10703 .50545 L
.10703 .08012 L
s
.678 .847 .902 r
.10703 .08012 m
.10703 .50478 L
.10755 .50478 L
.10755 .08012 L
F
.2 .63 .79 r
.10703 .08012 m
.10703 .50478 L
.10755 .50478 L
.10755 .08012 L
s
.678 .847 .902 r
.10755 .08012 m
.10755 .50423 L
.10785 .50423 L
.10785 .08012 L
F
.2 .63 .79 r
.10755 .08012 m
.10755 .50423 L
.10785 .50423 L
.10785 .08012 L
s
.678 .847 .902 r
.10785 .08012 m
.10785 .50391 L
.10817 .50391 L
.10817 .08012 L
F
.2 .63 .79 r
.10785 .08012 m
.10785 .50391 L
.10817 .50391 L
.10817 .08012 L
s
.678 .847 .902 r
.10817 .08012 m
.10817 .50321 L
.10866 .50321 L
.10866 .08012 L
F
.2 .63 .79 r
.10817 .08012 m
.10817 .50321 L
.10866 .50321 L
.10866 .08012 L
s
.678 .847 .902 r
.10866 .08012 m
.10866 .50301 L
.109 .50301 L
.109 .08012 L
F
.2 .63 .79 r
.10866 .08012 m
.10866 .50301 L
.109 .50301 L
.109 .08012 L
s
.678 .847 .902 r
.109 .08012 m
.109 .50229 L
.10966 .50229 L
.10966 .08012 L
F
.2 .63 .79 r
.109 .08012 m
.109 .50229 L
.10966 .50229 L
.10966 .08012 L
s
.678 .847 .902 r
.10966 .08012 m
.10966 .50174 L
.11025 .50174 L
.11025 .08012 L
F
.2 .63 .79 r
.10966 .08012 m
.10966 .50174 L
.11025 .50174 L
.11025 .08012 L
s
.678 .847 .902 r
.11025 .08012 m
.11025 .50105 L
.11078 .50105 L
.11078 .08012 L
F
.2 .63 .79 r
.11025 .08012 m
.11025 .50105 L
.11078 .50105 L
.11078 .08012 L
s
.678 .847 .902 r
.11078 .08012 m
.11078 .5002 L
.11146 .5002 L
.11146 .08012 L
F
.2 .63 .79 r
.11078 .08012 m
.11078 .5002 L
.11146 .5002 L
.11146 .08012 L
s
.678 .847 .902 r
.11146 .08012 m
.11146 .49922 L
.11218 .49922 L
.11218 .08012 L
F
.2 .63 .79 r
.11146 .08012 m
.11146 .49922 L
.11218 .49922 L
.11218 .08012 L
s
.678 .847 .902 r
.11218 .08012 m
.11218 .49861 L
.1127 .49861 L
.1127 .08012 L
F
.2 .63 .79 r
.11218 .08012 m
.11218 .49861 L
.1127 .49861 L
.1127 .08012 L
s
.678 .847 .902 r
.1127 .08012 m
.1127 .49821 L
.11323 .49821 L
.11323 .08012 L
F
.2 .63 .79 r
.1127 .08012 m
.1127 .49821 L
.11323 .49821 L
.11323 .08012 L
s
.678 .847 .902 r
.11323 .08012 m
.11323 .49796 L
.11385 .49796 L
.11385 .08012 L
F
.2 .63 .79 r
.11323 .08012 m
.11323 .49796 L
.11385 .49796 L
.11385 .08012 L
s
.678 .847 .902 r
.11385 .08012 m
.11385 .49707 L
.11435 .49707 L
.11435 .08012 L
F
.2 .63 .79 r
.11385 .08012 m
.11385 .49707 L
.11435 .49707 L
.11435 .08012 L
s
.678 .847 .902 r
.11435 .08012 m
.11435 .49631 L
.11478 .49631 L
.11478 .08012 L
F
.2 .63 .79 r
.11435 .08012 m
.11435 .49631 L
.11478 .49631 L
.11478 .08012 L
s
.678 .847 .902 r
.11478 .08012 m
.11478 .49614 L
.11524 .49614 L
.11524 .08012 L
F
.2 .63 .79 r
.11478 .08012 m
.11478 .49614 L
.11524 .49614 L
.11524 .08012 L
s
.678 .847 .902 r
.11524 .08012 m
.11524 .49539 L
.11575 .49539 L
.11575 .08012 L
F
.2 .63 .79 r
.11524 .08012 m
.11524 .49539 L
.11575 .49539 L
.11575 .08012 L
s
.678 .847 .902 r
.11575 .08012 m
.11575 .49516 L
.11626 .49516 L
.11626 .08012 L
F
.2 .63 .79 r
.11575 .08012 m
.11575 .49516 L
.11626 .49516 L
.11626 .08012 L
s
.678 .847 .902 r
.11626 .08012 m
.11626 .49452 L
.11675 .49452 L
.11675 .08012 L
F
.2 .63 .79 r
.11626 .08012 m
.11626 .49452 L
.11675 .49452 L
.11675 .08012 L
s
.678 .847 .902 r
.11675 .08012 m
.11675 .49375 L
.11703 .49375 L
.11703 .08012 L
F
.2 .63 .79 r
.11675 .08012 m
.11675 .49375 L
.11703 .49375 L
.11703 .08012 L
s
.678 .847 .902 r
.11703 .08012 m
.11703 .49371 L
.11753 .49371 L
.11753 .08012 L
F
.2 .63 .79 r
.11703 .08012 m
.11703 .49371 L
.11753 .49371 L
.11753 .08012 L
s
.678 .847 .902 r
.11753 .08012 m
.11753 .49304 L
.11779 .49304 L
.11779 .08012 L
F
.2 .63 .79 r
.11753 .08012 m
.11753 .49304 L
.11779 .49304 L
.11779 .08012 L
s
.678 .847 .902 r
.11779 .08012 m
.11779 .49266 L
.11829 .49266 L
.11829 .08012 L
F
.2 .63 .79 r
.11779 .08012 m
.11779 .49266 L
.11829 .49266 L
.11829 .08012 L
s
.678 .847 .902 r
.11829 .08012 m
.11829 .49193 L
.11876 .49193 L
.11876 .08012 L
F
.2 .63 .79 r
.11829 .08012 m
.11829 .49193 L
.11876 .49193 L
.11876 .08012 L
s
.678 .847 .902 r
.11876 .08012 m
.11876 .49121 L
.11947 .49121 L
.11947 .08012 L
F
.2 .63 .79 r
.11876 .08012 m
.11876 .49121 L
.11947 .49121 L
.11947 .08012 L
s
.678 .847 .902 r
.11947 .08012 m
.11947 .49097 L
.12016 .49097 L
.12016 .08012 L
F
.2 .63 .79 r
.11947 .08012 m
.11947 .49097 L
.12016 .49097 L
.12016 .08012 L
s
.678 .847 .902 r
.12016 .08012 m
.12016 .4902 L
.12056 .4902 L
.12056 .08012 L
F
.2 .63 .79 r
.12016 .08012 m
.12016 .4902 L
.12056 .4902 L
.12056 .08012 L
s
.678 .847 .902 r
.12056 .08012 m
.12056 .48906 L
.12127 .48906 L
.12127 .08012 L
F
.2 .63 .79 r
.12056 .08012 m
.12056 .48906 L
.12127 .48906 L
.12127 .08012 L
s
.678 .847 .902 r
.12127 .08012 m
.12127 .48869 L
.12186 .48869 L
.12186 .08012 L
F
.2 .63 .79 r
.12127 .08012 m
.12127 .48869 L
.12186 .48869 L
.12186 .08012 L
s
.678 .847 .902 r
.12186 .08012 m
.12186 .48823 L
.12211 .48823 L
.12211 .08012 L
F
.2 .63 .79 r
.12186 .08012 m
.12186 .48823 L
.12211 .48823 L
.12211 .08012 L
s
.678 .847 .902 r
.12211 .08012 m
.12211 .48765 L
.12266 .48765 L
.12266 .08012 L
F
.2 .63 .79 r
.12211 .08012 m
.12211 .48765 L
.12266 .48765 L
.12266 .08012 L
s
.678 .847 .902 r
.12266 .08012 m
.12266 .48727 L
.12305 .48727 L
.12305 .08012 L
F
.2 .63 .79 r
.12266 .08012 m
.12266 .48727 L
.12305 .48727 L
.12305 .08012 L
s
.678 .847 .902 r
.12305 .08012 m
.12305 .48646 L
.1237 .48646 L
.1237 .08012 L
F
.2 .63 .79 r
.12305 .08012 m
.12305 .48646 L
.1237 .48646 L
.1237 .08012 L
s
.678 .847 .902 r
.1237 .08012 m
.1237 .48617 L
.12395 .48617 L
.12395 .08012 L
F
.2 .63 .79 r
.1237 .08012 m
.1237 .48617 L
.12395 .48617 L
.12395 .08012 L
s
.678 .847 .902 r
.12395 .08012 m
.12395 .48583 L
.1242 .48583 L
.1242 .08012 L
F
.2 .63 .79 r
.12395 .08012 m
.12395 .48583 L
.1242 .48583 L
.1242 .08012 L
s
.678 .847 .902 r
.1242 .08012 m
.1242 .48521 L
.12479 .48521 L
.12479 .08012 L
F
.2 .63 .79 r
.1242 .08012 m
.1242 .48521 L
.12479 .48521 L
.12479 .08012 L
s
.678 .847 .902 r
.12479 .08012 m
.12479 .4849 L
.12504 .4849 L
.12504 .08012 L
F
.2 .63 .79 r
.12479 .08012 m
.12479 .4849 L
.12504 .4849 L
.12504 .08012 L
s
.678 .847 .902 r
.12504 .08012 m
.12504 .48474 L
.12552 .48474 L
.12552 .08012 L
F
.2 .63 .79 r
.12504 .08012 m
.12504 .48474 L
.12552 .48474 L
.12552 .08012 L
s
.678 .847 .902 r
.12552 .08012 m
.12552 .48375 L
.12607 .48375 L
.12607 .08012 L
F
.2 .63 .79 r
.12552 .08012 m
.12552 .48375 L
.12607 .48375 L
.12607 .08012 L
s
.678 .847 .902 r
.12607 .08012 m
.12607 .48344 L
.12643 .48344 L
.12643 .08012 L
F
.2 .63 .79 r
.12607 .08012 m
.12607 .48344 L
.12643 .48344 L
.12643 .08012 L
s
.678 .847 .902 r
.12643 .08012 m
.12643 .48322 L
.1269 .48322 L
.1269 .08012 L
F
.2 .63 .79 r
.12643 .08012 m
.12643 .48322 L
.1269 .48322 L
.1269 .08012 L
s
.678 .847 .902 r
.1269 .08012 m
.1269 .48265 L
.12759 .48265 L
.12759 .08012 L
F
.2 .63 .79 r
.1269 .08012 m
.1269 .48265 L
.12759 .48265 L
.12759 .08012 L
s
.678 .847 .902 r
.12759 .08012 m
.12759 .48178 L
.12787 .48178 L
.12787 .08012 L
F
.2 .63 .79 r
.12759 .08012 m
.12759 .48178 L
.12787 .48178 L
.12787 .08012 L
s
.678 .847 .902 r
.12787 .08012 m
.12787 .48148 L
.12817 .48148 L
.12817 .08012 L
F
.2 .63 .79 r
.12787 .08012 m
.12787 .48148 L
.12817 .48148 L
.12817 .08012 L
s
.678 .847 .902 r
.12817 .08012 m
.12817 .48128 L
.12887 .48128 L
.12887 .08012 L
F
.2 .63 .79 r
.12817 .08012 m
.12817 .48128 L
.12887 .48128 L
.12887 .08012 L
s
.678 .847 .902 r
.12887 .08012 m
.12887 .48009 L
.12953 .48009 L
.12953 .08012 L
F
.2 .63 .79 r
.12887 .08012 m
.12887 .48009 L
.12953 .48009 L
.12953 .08012 L
s
.678 .847 .902 r
.12953 .08012 m
.12953 .47968 L
.13003 .47968 L
.13003 .08012 L
F
.2 .63 .79 r
.12953 .08012 m
.12953 .47968 L
.13003 .47968 L
.13003 .08012 L
s
.678 .847 .902 r
.13003 .08012 m
.13003 .47874 L
.1306 .47874 L
.1306 .08012 L
F
.2 .63 .79 r
.13003 .08012 m
.13003 .47874 L
.1306 .47874 L
.1306 .08012 L
s
.678 .847 .902 r
.1306 .08012 m
.1306 .47841 L
.13132 .47841 L
.13132 .08012 L
F
.2 .63 .79 r
.1306 .08012 m
.1306 .47841 L
.13132 .47841 L
.13132 .08012 L
s
.678 .847 .902 r
.13132 .08012 m
.13132 .47742 L
.13202 .47742 L
.13202 .08012 L
F
.2 .63 .79 r
.13132 .08012 m
.13132 .47742 L
.13202 .47742 L
.13202 .08012 L
s
.678 .847 .902 r
.13202 .08012 m
.13202 .47706 L
.13234 .47706 L
.13234 .08012 L
F
.2 .63 .79 r
.13202 .08012 m
.13202 .47706 L
.13234 .47706 L
.13234 .08012 L
s
.678 .847 .902 r
.13234 .08012 m
.13234 .47679 L
.13292 .47679 L
.13292 .08012 L
F
.2 .63 .79 r
.13234 .08012 m
.13234 .47679 L
.13292 .47679 L
.13292 .08012 L
s
.678 .847 .902 r
.13292 .08012 m
.13292 .47583 L
.13327 .47583 L
.13327 .08012 L
F
.2 .63 .79 r
.13292 .08012 m
.13292 .47583 L
.13327 .47583 L
.13327 .08012 L
s
.678 .847 .902 r
.13327 .08012 m
.13327 .47564 L
.13394 .47564 L
.13394 .08012 L
F
.2 .63 .79 r
.13327 .08012 m
.13327 .47564 L
.13394 .47564 L
.13394 .08012 L
s
.678 .847 .902 r
.13394 .08012 m
.13394 .47474 L
.13445 .47474 L
.13445 .08012 L
F
.2 .63 .79 r
.13394 .08012 m
.13394 .47474 L
.13445 .47474 L
.13445 .08012 L
s
.678 .847 .902 r
.13445 .08012 m
.13445 .47425 L
.13486 .47425 L
.13486 .08012 L
F
.2 .63 .79 r
.13445 .08012 m
.13445 .47425 L
.13486 .47425 L
.13486 .08012 L
s
.678 .847 .902 r
.13486 .08012 m
.13486 .47401 L
.13529 .47401 L
.13529 .08012 L
F
.2 .63 .79 r
.13486 .08012 m
.13486 .47401 L
.13529 .47401 L
.13529 .08012 L
s
.678 .847 .902 r
.13529 .08012 m
.13529 .47313 L
.13593 .47313 L
.13593 .08012 L
F
.2 .63 .79 r
.13529 .08012 m
.13529 .47313 L
.13593 .47313 L
.13593 .08012 L
s
.678 .847 .902 r
.13593 .08012 m
.13593 .47247 L
.13641 .47247 L
.13641 .08012 L
F
.2 .63 .79 r
.13593 .08012 m
.13593 .47247 L
.13641 .47247 L
.13641 .08012 L
s
.678 .847 .902 r
.13641 .08012 m
.13641 .47194 L
.13696 .47194 L
.13696 .08012 L
F
.2 .63 .79 r
.13641 .08012 m
.13641 .47194 L
.13696 .47194 L
.13696 .08012 L
s
.678 .847 .902 r
.13696 .08012 m
.13696 .47163 L
.13736 .47163 L
.13736 .08012 L
F
.2 .63 .79 r
.13696 .08012 m
.13696 .47163 L
.13736 .47163 L
.13736 .08012 L
s
.678 .847 .902 r
.13736 .08012 m
.13736 .47114 L
.13774 .47114 L
.13774 .08012 L
F
.2 .63 .79 r
.13736 .08012 m
.13736 .47114 L
.13774 .47114 L
.13774 .08012 L
s
.678 .847 .902 r
.13774 .08012 m
.13774 .47029 L
.1384 .47029 L
.1384 .08012 L
F
.2 .63 .79 r
.13774 .08012 m
.13774 .47029 L
.1384 .47029 L
.1384 .08012 L
s
.678 .847 .902 r
.1384 .08012 m
.1384 .47018 L
.13881 .47018 L
.13881 .08012 L
F
.2 .63 .79 r
.1384 .08012 m
.1384 .47018 L
.13881 .47018 L
.13881 .08012 L
s
.678 .847 .902 r
.13881 .08012 m
.13881 .46966 L
.13947 .46966 L
.13947 .08012 L
F
.2 .63 .79 r
.13881 .08012 m
.13881 .46966 L
.13947 .46966 L
.13947 .08012 L
s
.678 .847 .902 r
.13947 .08012 m
.13947 .4689 L
.13988 .4689 L
.13988 .08012 L
F
.2 .63 .79 r
.13947 .08012 m
.13947 .4689 L
.13988 .4689 L
.13988 .08012 L
s
.678 .847 .902 r
.13988 .08012 m
.13988 .46852 L
.14048 .46852 L
.14048 .08012 L
F
.2 .63 .79 r
.13988 .08012 m
.13988 .46852 L
.14048 .46852 L
.14048 .08012 L
s
.678 .847 .902 r
.14048 .08012 m
.14048 .46782 L
.14082 .46782 L
.14082 .08012 L
F
.2 .63 .79 r
.14048 .08012 m
.14048 .46782 L
.14082 .46782 L
.14082 .08012 L
s
.678 .847 .902 r
.14082 .08012 m
.14082 .46683 L
.14151 .46683 L
.14151 .08012 L
F
.2 .63 .79 r
.14082 .08012 m
.14082 .46683 L
.14151 .46683 L
.14151 .08012 L
s
.678 .847 .902 r
.14151 .08012 m
.14151 .46653 L
.142 .46653 L
.142 .08012 L
F
.2 .63 .79 r
.14151 .08012 m
.14151 .46653 L
.142 .46653 L
.142 .08012 L
s
.678 .847 .902 r
.142 .08012 m
.142 .46606 L
.14231 .46606 L
.14231 .08012 L
F
.2 .63 .79 r
.142 .08012 m
.142 .46606 L
.14231 .46606 L
.14231 .08012 L
s
.678 .847 .902 r
.14231 .08012 m
.14231 .46577 L
.14282 .46577 L
.14282 .08012 L
F
.2 .63 .79 r
.14231 .08012 m
.14231 .46577 L
.14282 .46577 L
.14282 .08012 L
s
.678 .847 .902 r
.14282 .08012 m
.14282 .46496 L
.14351 .46496 L
.14351 .08012 L
F
.2 .63 .79 r
.14282 .08012 m
.14282 .46496 L
.14351 .46496 L
.14351 .08012 L
s
.678 .847 .902 r
.14351 .08012 m
.14351 .46416 L
.14403 .46416 L
.14403 .08012 L
F
.2 .63 .79 r
.14351 .08012 m
.14351 .46416 L
.14403 .46416 L
.14403 .08012 L
s
.678 .847 .902 r
.14403 .08012 m
.14403 .46377 L
.14476 .46377 L
.14476 .08012 L
F
.2 .63 .79 r
.14403 .08012 m
.14403 .46377 L
.14476 .46377 L
.14476 .08012 L
s
.678 .847 .902 r
.14476 .08012 m
.14476 .46309 L
.14541 .46309 L
.14541 .08012 L
F
.2 .63 .79 r
.14476 .08012 m
.14476 .46309 L
.14541 .46309 L
.14541 .08012 L
s
.678 .847 .902 r
.14541 .08012 m
.14541 .46218 L
.14597 .46218 L
.14597 .08012 L
F
.2 .63 .79 r
.14541 .08012 m
.14541 .46218 L
.14597 .46218 L
.14597 .08012 L
s
.678 .847 .902 r
.14597 .08012 m
.14597 .46157 L
.14656 .46157 L
.14656 .08012 L
F
.2 .63 .79 r
.14597 .08012 m
.14597 .46157 L
.14656 .46157 L
.14656 .08012 L
s
.678 .847 .902 r
.14656 .08012 m
.14656 .46098 L
.14699 .46098 L
.14699 .08012 L
F
.2 .63 .79 r
.14656 .08012 m
.14656 .46098 L
.14699 .46098 L
.14699 .08012 L
s
.678 .847 .902 r
.14699 .08012 m
.14699 .46053 L
.14745 .46053 L
.14745 .08012 L
F
.2 .63 .79 r
.14699 .08012 m
.14699 .46053 L
.14745 .46053 L
.14745 .08012 L
s
.678 .847 .902 r
.14745 .08012 m
.14745 .46017 L
.1478 .46017 L
.1478 .08012 L
F
.2 .63 .79 r
.14745 .08012 m
.14745 .46017 L
.1478 .46017 L
.1478 .08012 L
s
.678 .847 .902 r
.1478 .08012 m
.1478 .46001 L
.14848 .46001 L
.14848 .08012 L
F
.2 .63 .79 r
.1478 .08012 m
.1478 .46001 L
.14848 .46001 L
.14848 .08012 L
s
.678 .847 .902 r
.14848 .08012 m
.14848 .45927 L
.14916 .45927 L
.14916 .08012 L
F
.2 .63 .79 r
.14848 .08012 m
.14848 .45927 L
.14916 .45927 L
.14916 .08012 L
s
.678 .847 .902 r
.14916 .08012 m
.14916 .45854 L
.14981 .45854 L
.14981 .08012 L
F
.2 .63 .79 r
.14916 .08012 m
.14916 .45854 L
.14981 .45854 L
.14981 .08012 L
s
.678 .847 .902 r
.14981 .08012 m
.14981 .45764 L
.15049 .45764 L
.15049 .08012 L
F
.2 .63 .79 r
.14981 .08012 m
.14981 .45764 L
.15049 .45764 L
.15049 .08012 L
s
.678 .847 .902 r
.15049 .08012 m
.15049 .45683 L
.15101 .45683 L
.15101 .08012 L
F
.2 .63 .79 r
.15049 .08012 m
.15049 .45683 L
.15101 .45683 L
.15101 .08012 L
s
.678 .847 .902 r
.15101 .08012 m
.15101 .45654 L
.15125 .45654 L
.15125 .08012 L
F
.2 .63 .79 r
.15101 .08012 m
.15101 .45654 L
.15125 .45654 L
.15125 .08012 L
s
.678 .847 .902 r
.15125 .08012 m
.15125 .45633 L
.1517 .45633 L
.1517 .08012 L
F
.2 .63 .79 r
.15125 .08012 m
.15125 .45633 L
.1517 .45633 L
.1517 .08012 L
s
.678 .847 .902 r
.1517 .08012 m
.1517 .4558 L
.15194 .4558 L
.15194 .08012 L
F
.2 .63 .79 r
.1517 .08012 m
.1517 .4558 L
.15194 .4558 L
.15194 .08012 L
s
.678 .847 .902 r
.15194 .08012 m
.15194 .4555 L
.15228 .4555 L
.15228 .08012 L
F
.2 .63 .79 r
.15194 .08012 m
.15194 .4555 L
.15228 .4555 L
.15228 .08012 L
s
.678 .847 .902 r
.15228 .08012 m
.15228 .45521 L
.15265 .45521 L
.15265 .08012 L
F
.2 .63 .79 r
.15228 .08012 m
.15228 .45521 L
.15265 .45521 L
.15265 .08012 L
s
.678 .847 .902 r
.15265 .08012 m
.15265 .4546 L
.15297 .4546 L
.15297 .08012 L
F
.2 .63 .79 r
.15265 .08012 m
.15265 .4546 L
.15297 .4546 L
.15297 .08012 L
s
.678 .847 .902 r
.15297 .08012 m
.15297 .45443 L
.15326 .45443 L
.15326 .08012 L
F
.2 .63 .79 r
.15297 .08012 m
.15297 .45443 L
.15326 .45443 L
.15326 .08012 L
s
.678 .847 .902 r
.15326 .08012 m
.15326 .45374 L
.15384 .45374 L
.15384 .08012 L
F
.2 .63 .79 r
.15326 .08012 m
.15326 .45374 L
.15384 .45374 L
.15384 .08012 L
s
.678 .847 .902 r
.15384 .08012 m
.15384 .45346 L
.15411 .45346 L
.15411 .08012 L
F
.2 .63 .79 r
.15384 .08012 m
.15384 .45346 L
.15411 .45346 L
.15411 .08012 L
s
.678 .847 .902 r
.15411 .08012 m
.15411 .45307 L
.15466 .45307 L
.15466 .08012 L
F
.2 .63 .79 r
.15411 .08012 m
.15411 .45307 L
.15466 .45307 L
.15466 .08012 L
s
.678 .847 .902 r
.15466 .08012 m
.15466 .45248 L
.15499 .45248 L
.15499 .08012 L
F
.2 .63 .79 r
.15466 .08012 m
.15466 .45248 L
.15499 .45248 L
.15499 .08012 L
s
.678 .847 .902 r
.15499 .08012 m
.15499 .4521 L
.15527 .4521 L
.15527 .08012 L
F
.2 .63 .79 r
.15499 .08012 m
.15499 .4521 L
.15527 .4521 L
.15527 .08012 L
s
.678 .847 .902 r
.15527 .08012 m
.15527 .45176 L
.15555 .45176 L
.15555 .08012 L
F
.2 .63 .79 r
.15527 .08012 m
.15527 .45176 L
.15555 .45176 L
.15555 .08012 L
s
.678 .847 .902 r
.15555 .08012 m
.15555 .45172 L
.15617 .45172 L
.15617 .08012 L
F
.2 .63 .79 r
.15555 .08012 m
.15555 .45172 L
.15617 .45172 L
.15617 .08012 L
s
.678 .847 .902 r
.15617 .08012 m
.15617 .45061 L
.15667 .45061 L
.15667 .08012 L
F
.2 .63 .79 r
.15617 .08012 m
.15617 .45061 L
.15667 .45061 L
.15667 .08012 L
s
.678 .847 .902 r
.15667 .08012 m
.15667 .45049 L
.15709 .45049 L
.15709 .08012 L
F
.2 .63 .79 r
.15667 .08012 m
.15667 .45049 L
.15709 .45049 L
.15709 .08012 L
s
.678 .847 .902 r
.15709 .08012 m
.15709 .45003 L
.15767 .45003 L
.15767 .08012 L
F
.2 .63 .79 r
.15709 .08012 m
.15709 .45003 L
.15767 .45003 L
.15767 .08012 L
s
.678 .847 .902 r
.15767 .08012 m
.15767 .44937 L
.15805 .44937 L
.15805 .08012 L
F
.2 .63 .79 r
.15767 .08012 m
.15767 .44937 L
.15805 .44937 L
.15805 .08012 L
s
.678 .847 .902 r
.15805 .08012 m
.15805 .44898 L
.15842 .44898 L
.15842 .08012 L
F
.2 .63 .79 r
.15805 .08012 m
.15805 .44898 L
.15842 .44898 L
.15842 .08012 L
s
.678 .847 .902 r
.15842 .08012 m
.15842 .44864 L
.15889 .44864 L
.15889 .08012 L
F
.2 .63 .79 r
.15842 .08012 m
.15842 .44864 L
.15889 .44864 L
.15889 .08012 L
s
.678 .847 .902 r
.15889 .08012 m
.15889 .44814 L
.15952 .44814 L
.15952 .08012 L
F
.2 .63 .79 r
.15889 .08012 m
.15889 .44814 L
.15952 .44814 L
.15952 .08012 L
s
.678 .847 .902 r
.15952 .08012 m
.15952 .4474 L
.15999 .4474 L
.15999 .08012 L
F
.2 .63 .79 r
.15952 .08012 m
.15952 .4474 L
.15999 .4474 L
.15999 .08012 L
s
.678 .847 .902 r
.15999 .08012 m
.15999 .44661 L
.16041 .44661 L
.16041 .08012 L
F
.2 .63 .79 r
.15999 .08012 m
.15999 .44661 L
.16041 .44661 L
.16041 .08012 L
s
.678 .847 .902 r
.16041 .08012 m
.16041 .44619 L
.16109 .44619 L
.16109 .08012 L
F
.2 .63 .79 r
.16041 .08012 m
.16041 .44619 L
.16109 .44619 L
.16109 .08012 L
s
.678 .847 .902 r
.16109 .08012 m
.16109 .44528 L
.16169 .44528 L
.16169 .08012 L
F
.2 .63 .79 r
.16109 .08012 m
.16109 .44528 L
.16169 .44528 L
.16169 .08012 L
s
.678 .847 .902 r
.16169 .08012 m
.16169 .44516 L
.16194 .44516 L
.16194 .08012 L
F
.2 .63 .79 r
.16169 .08012 m
.16169 .44516 L
.16194 .44516 L
.16194 .08012 L
s
.678 .847 .902 r
.16194 .08012 m
.16194 .44466 L
.16233 .44466 L
.16233 .08012 L
F
.2 .63 .79 r
.16194 .08012 m
.16194 .44466 L
.16233 .44466 L
.16233 .08012 L
s
.678 .847 .902 r
.16233 .08012 m
.16233 .44438 L
.1629 .44438 L
.1629 .08012 L
F
.2 .63 .79 r
.16233 .08012 m
.16233 .44438 L
.1629 .44438 L
.1629 .08012 L
s
.678 .847 .902 r
.1629 .08012 m
.1629 .44355 L
.16335 .44355 L
.16335 .08012 L
F
.2 .63 .79 r
.1629 .08012 m
.1629 .44355 L
.16335 .44355 L
.16335 .08012 L
s
.678 .847 .902 r
.16335 .08012 m
.16335 .44309 L
.164 .44309 L
.164 .08012 L
F
.2 .63 .79 r
.16335 .08012 m
.16335 .44309 L
.164 .44309 L
.164 .08012 L
s
.678 .847 .902 r
.164 .08012 m
.164 .4426 L
.16432 .4426 L
.16432 .08012 L
F
.2 .63 .79 r
.164 .08012 m
.164 .4426 L
.16432 .4426 L
.16432 .08012 L
s
.678 .847 .902 r
.16432 .08012 m
.16432 .44202 L
.16505 .44202 L
.16505 .08012 L
F
.2 .63 .79 r
.16432 .08012 m
.16432 .44202 L
.16505 .44202 L
.16505 .08012 L
s
.678 .847 .902 r
.16505 .08012 m
.16505 .44148 L
.16544 .44148 L
.16544 .08012 L
F
.2 .63 .79 r
.16505 .08012 m
.16505 .44148 L
.16544 .44148 L
.16544 .08012 L
s
.678 .847 .902 r
.16544 .08012 m
.16544 .4412 L
.16577 .4412 L
.16577 .08012 L
F
.2 .63 .79 r
.16544 .08012 m
.16544 .4412 L
.16577 .4412 L
.16577 .08012 L
s
.678 .847 .902 r
.16577 .08012 m
.16577 .44021 L
.16649 .44021 L
.16649 .08012 L
F
.2 .63 .79 r
.16577 .08012 m
.16577 .44021 L
.16649 .44021 L
.16649 .08012 L
s
.678 .847 .902 r
.16649 .08012 m
.16649 .43965 L
.16716 .43965 L
.16716 .08012 L
F
.2 .63 .79 r
.16649 .08012 m
.16649 .43965 L
.16716 .43965 L
.16716 .08012 L
s
.678 .847 .902 r
.16716 .08012 m
.16716 .43928 L
.16749 .43928 L
.16749 .08012 L
F
.2 .63 .79 r
.16716 .08012 m
.16716 .43928 L
.16749 .43928 L
.16749 .08012 L
s
.678 .847 .902 r
.16749 .08012 m
.16749 .43903 L
.16793 .43903 L
.16793 .08012 L
F
.2 .63 .79 r
.16749 .08012 m
.16749 .43903 L
.16793 .43903 L
.16793 .08012 L
s
.678 .847 .902 r
.16793 .08012 m
.16793 .43864 L
.16837 .43864 L
.16837 .08012 L
F
.2 .63 .79 r
.16793 .08012 m
.16793 .43864 L
.16837 .43864 L
.16837 .08012 L
s
.678 .847 .902 r
.16837 .08012 m
.16837 .43791 L
.16883 .43791 L
.16883 .08012 L
F
.2 .63 .79 r
.16837 .08012 m
.16837 .43791 L
.16883 .43791 L
.16883 .08012 L
s
.678 .847 .902 r
.16883 .08012 m
.16883 .4375 L
.16932 .4375 L
.16932 .08012 L
F
.2 .63 .79 r
.16883 .08012 m
.16883 .4375 L
.16932 .4375 L
.16932 .08012 L
s
.678 .847 .902 r
.16932 .08012 m
.16932 .43694 L
.16959 .43694 L
.16959 .08012 L
F
.2 .63 .79 r
.16932 .08012 m
.16932 .43694 L
.16959 .43694 L
.16959 .08012 L
s
.678 .847 .902 r
.16959 .08012 m
.16959 .43668 L
.16989 .43668 L
.16989 .08012 L
F
.2 .63 .79 r
.16959 .08012 m
.16959 .43668 L
.16989 .43668 L
.16989 .08012 L
s
.678 .847 .902 r
.16989 .08012 m
.16989 .43624 L
.1706 .43624 L
.1706 .08012 L
F
.2 .63 .79 r
.16989 .08012 m
.16989 .43624 L
.1706 .43624 L
.1706 .08012 L
s
.678 .847 .902 r
.1706 .08012 m
.1706 .43564 L
.17119 .43564 L
.17119 .08012 L
F
.2 .63 .79 r
.1706 .08012 m
.1706 .43564 L
.17119 .43564 L
.17119 .08012 L
s
.678 .847 .902 r
.17119 .08012 m
.17119 .43487 L
.17174 .43487 L
.17174 .08012 L
F
.2 .63 .79 r
.17119 .08012 m
.17119 .43487 L
.17174 .43487 L
.17174 .08012 L
s
.678 .847 .902 r
.17174 .08012 m
.17174 .43415 L
.17234 .43415 L
.17234 .08012 L
F
.2 .63 .79 r
.17174 .08012 m
.17174 .43415 L
.17234 .43415 L
.17234 .08012 L
s
.678 .847 .902 r
.17234 .08012 m
.17234 .4338 L
.17259 .4338 L
.17259 .08012 L
F
.2 .63 .79 r
.17234 .08012 m
.17234 .4338 L
.17259 .4338 L
.17259 .08012 L
s
.678 .847 .902 r
.17259 .08012 m
.17259 .43344 L
.17331 .43344 L
.17331 .08012 L
F
.2 .63 .79 r
.17259 .08012 m
.17259 .43344 L
.17331 .43344 L
.17331 .08012 L
s
.678 .847 .902 r
.17331 .08012 m
.17331 .43281 L
.17383 .43281 L
.17383 .08012 L
F
.2 .63 .79 r
.17331 .08012 m
.17331 .43281 L
.17383 .43281 L
.17383 .08012 L
s
.678 .847 .902 r
.17383 .08012 m
.17383 .43246 L
.17426 .43246 L
.17426 .08012 L
F
.2 .63 .79 r
.17383 .08012 m
.17383 .43246 L
.17426 .43246 L
.17426 .08012 L
s
.678 .847 .902 r
.17426 .08012 m
.17426 .43176 L
.17467 .43176 L
.17467 .08012 L
F
.2 .63 .79 r
.17426 .08012 m
.17426 .43176 L
.17467 .43176 L
.17467 .08012 L
s
.678 .847 .902 r
.17467 .08012 m
.17467 .43131 L
.17516 .43131 L
.17516 .08012 L
F
.2 .63 .79 r
.17467 .08012 m
.17467 .43131 L
.17516 .43131 L
.17516 .08012 L
s
.678 .847 .902 r
.17516 .08012 m
.17516 .43058 L
.17576 .43058 L
.17576 .08012 L
F
.2 .63 .79 r
.17516 .08012 m
.17516 .43058 L
.17576 .43058 L
.17576 .08012 L
s
.678 .847 .902 r
.17576 .08012 m
.17576 .43031 L
.17608 .43031 L
.17608 .08012 L
F
.2 .63 .79 r
.17576 .08012 m
.17576 .43031 L
.17608 .43031 L
.17608 .08012 L
s
.678 .847 .902 r
.17608 .08012 m
.17608 .4301 L
.1765 .4301 L
.1765 .08012 L
F
.2 .63 .79 r
.17608 .08012 m
.17608 .4301 L
.1765 .4301 L
.1765 .08012 L
s
.678 .847 .902 r
.1765 .08012 m
.1765 .42967 L
.17681 .42967 L
.17681 .08012 L
F
.2 .63 .79 r
.1765 .08012 m
.1765 .42967 L
.17681 .42967 L
.17681 .08012 L
s
.678 .847 .902 r
.17681 .08012 m
.17681 .42906 L
.1773 .42906 L
.1773 .08012 L
F
.2 .63 .79 r
.17681 .08012 m
.17681 .42906 L
.1773 .42906 L
.1773 .08012 L
s
.678 .847 .902 r
.1773 .08012 m
.1773 .42867 L
.17764 .42867 L
.17764 .08012 L
F
.2 .63 .79 r
.1773 .08012 m
.1773 .42867 L
.17764 .42867 L
.17764 .08012 L
s
.678 .847 .902 r
.17764 .08012 m
.17764 .42835 L
.17813 .42835 L
.17813 .08012 L
F
.2 .63 .79 r
.17764 .08012 m
.17764 .42835 L
.17813 .42835 L
.17813 .08012 L
s
.678 .847 .902 r
.17813 .08012 m
.17813 .42759 L
.17883 .42759 L
.17883 .08012 L
F
.2 .63 .79 r
.17813 .08012 m
.17813 .42759 L
.17883 .42759 L
.17883 .08012 L
s
.678 .847 .902 r
.17883 .08012 m
.17883 .42716 L
.17911 .42716 L
.17911 .08012 L
F
.2 .63 .79 r
.17883 .08012 m
.17883 .42716 L
.17911 .42716 L
.17911 .08012 L
s
.678 .847 .902 r
.17911 .08012 m
.17911 .42666 L
.17973 .42666 L
.17973 .08012 L
F
.2 .63 .79 r
.17911 .08012 m
.17911 .42666 L
.17973 .42666 L
.17973 .08012 L
s
.678 .847 .902 r
.17973 .08012 m
.17973 .42617 L
.17998 .42617 L
.17998 .08012 L
F
.2 .63 .79 r
.17973 .08012 m
.17973 .42617 L
.17998 .42617 L
.17998 .08012 L
s
.678 .847 .902 r
.17998 .08012 m
.17998 .42603 L
.18041 .42603 L
.18041 .08012 L
F
.2 .63 .79 r
.17998 .08012 m
.17998 .42603 L
.18041 .42603 L
.18041 .08012 L
s
.678 .847 .902 r
.18041 .08012 m
.18041 .42523 L
.18114 .42523 L
.18114 .08012 L
F
.2 .63 .79 r
.18041 .08012 m
.18041 .42523 L
.18114 .42523 L
.18114 .08012 L
s
.678 .847 .902 r
.18114 .08012 m
.18114 .42446 L
.1817 .42446 L
.1817 .08012 L
F
.2 .63 .79 r
.18114 .08012 m
.18114 .42446 L
.1817 .42446 L
.1817 .08012 L
s
.678 .847 .902 r
.1817 .08012 m
.1817 .42426 L
.18196 .42426 L
.18196 .08012 L
F
.2 .63 .79 r
.1817 .08012 m
.1817 .42426 L
.18196 .42426 L
.18196 .08012 L
s
.678 .847 .902 r
.18196 .08012 m
.18196 .42359 L
.18253 .42359 L
.18253 .08012 L
F
.2 .63 .79 r
.18196 .08012 m
.18196 .42359 L
.18253 .42359 L
.18253 .08012 L
s
.678 .847 .902 r
.18253 .08012 m
.18253 .42308 L
.18294 .42308 L
.18294 .08012 L
F
.2 .63 .79 r
.18253 .08012 m
.18253 .42308 L
.18294 .42308 L
.18294 .08012 L
s
.678 .847 .902 r
.18294 .08012 m
.18294 .42239 L
.18362 .42239 L
.18362 .08012 L
F
.2 .63 .79 r
.18294 .08012 m
.18294 .42239 L
.18362 .42239 L
.18362 .08012 L
s
.678 .847 .902 r
.18362 .08012 m
.18362 .42227 L
.18386 .42227 L
.18386 .08012 L
F
.2 .63 .79 r
.18362 .08012 m
.18362 .42227 L
.18386 .42227 L
.18386 .08012 L
s
.678 .847 .902 r
.18386 .08012 m
.18386 .4219 L
.18443 .4219 L
.18443 .08012 L
F
.2 .63 .79 r
.18386 .08012 m
.18386 .4219 L
.18443 .4219 L
.18443 .08012 L
s
.678 .847 .902 r
.18443 .08012 m
.18443 .42118 L
.18506 .42118 L
.18506 .08012 L
F
.2 .63 .79 r
.18443 .08012 m
.18443 .42118 L
.18506 .42118 L
.18506 .08012 L
s
.678 .847 .902 r
.18506 .08012 m
.18506 .42045 L
.18553 .42045 L
.18553 .08012 L
F
.2 .63 .79 r
.18506 .08012 m
.18506 .42045 L
.18553 .42045 L
.18553 .08012 L
s
.678 .847 .902 r
.18553 .08012 m
.18553 .42002 L
.18609 .42002 L
.18609 .08012 L
F
.2 .63 .79 r
.18553 .08012 m
.18553 .42002 L
.18609 .42002 L
.18609 .08012 L
s
.678 .847 .902 r
.18609 .08012 m
.18609 .41959 L
.18639 .41959 L
.18639 .08012 L
F
.2 .63 .79 r
.18609 .08012 m
.18609 .41959 L
.18639 .41959 L
.18639 .08012 L
s
.678 .847 .902 r
.18639 .08012 m
.18639 .41934 L
.18664 .41934 L
.18664 .08012 L
F
.2 .63 .79 r
.18639 .08012 m
.18639 .41934 L
.18664 .41934 L
.18664 .08012 L
s
.678 .847 .902 r
.18664 .08012 m
.18664 .41913 L
.187 .41913 L
.187 .08012 L
F
.2 .63 .79 r
.18664 .08012 m
.18664 .41913 L
.187 .41913 L
.187 .08012 L
s
.678 .847 .902 r
.187 .08012 m
.187 .41868 L
.18736 .41868 L
.18736 .08012 L
F
.2 .63 .79 r
.187 .08012 m
.187 .41868 L
.18736 .41868 L
.18736 .08012 L
s
.678 .847 .902 r
.18736 .08012 m
.18736 .41806 L
.18808 .41806 L
.18808 .08012 L
F
.2 .63 .79 r
.18736 .08012 m
.18736 .41806 L
.18808 .41806 L
.18808 .08012 L
s
.678 .847 .902 r
.18808 .08012 m
.18808 .41776 L
.18857 .41776 L
.18857 .08012 L
F
.2 .63 .79 r
.18808 .08012 m
.18808 .41776 L
.18857 .41776 L
.18857 .08012 L
s
.678 .847 .902 r
.18857 .08012 m
.18857 .41709 L
.18881 .41709 L
.18881 .08012 L
F
.2 .63 .79 r
.18857 .08012 m
.18857 .41709 L
.18881 .41709 L
.18881 .08012 L
s
.678 .847 .902 r
.18881 .08012 m
.18881 .4169 L
.18941 .4169 L
.18941 .08012 L
F
.2 .63 .79 r
.18881 .08012 m
.18881 .4169 L
.18941 .4169 L
.18941 .08012 L
s
.678 .847 .902 r
.18941 .08012 m
.18941 .41641 L
.18966 .41641 L
.18966 .08012 L
F
.2 .63 .79 r
.18941 .08012 m
.18941 .41641 L
.18966 .41641 L
.18966 .08012 L
s
.678 .847 .902 r
.18966 .08012 m
.18966 .41592 L
.19008 .41592 L
.19008 .08012 L
F
.2 .63 .79 r
.18966 .08012 m
.18966 .41592 L
.19008 .41592 L
.19008 .08012 L
s
.678 .847 .902 r
.19008 .08012 m
.19008 .41566 L
.19043 .41566 L
.19043 .08012 L
F
.2 .63 .79 r
.19008 .08012 m
.19008 .41566 L
.19043 .41566 L
.19043 .08012 L
s
.678 .847 .902 r
.19043 .08012 m
.19043 .41511 L
.19101 .41511 L
.19101 .08012 L
F
.2 .63 .79 r
.19043 .08012 m
.19043 .41511 L
.19101 .41511 L
.19101 .08012 L
s
.678 .847 .902 r
.19101 .08012 m
.19101 .41432 L
.19155 .41432 L
.19155 .08012 L
F
.2 .63 .79 r
.19101 .08012 m
.19101 .41432 L
.19155 .41432 L
.19155 .08012 L
s
.678 .847 .902 r
.19155 .08012 m
.19155 .41381 L
.19198 .41381 L
.19198 .08012 L
F
.2 .63 .79 r
.19155 .08012 m
.19155 .41381 L
.19198 .41381 L
.19198 .08012 L
s
.678 .847 .902 r
.19198 .08012 m
.19198 .41357 L
.1925 .41357 L
.1925 .08012 L
F
.2 .63 .79 r
.19198 .08012 m
.19198 .41357 L
.1925 .41357 L
.1925 .08012 L
s
.678 .847 .902 r
.1925 .08012 m
.1925 .41317 L
.19303 .41317 L
.19303 .08012 L
F
.2 .63 .79 r
.1925 .08012 m
.1925 .41317 L
.19303 .41317 L
.19303 .08012 L
s
.678 .847 .902 r
.19303 .08012 m
.19303 .41269 L
.19373 .41269 L
.19373 .08012 L
F
.2 .63 .79 r
.19303 .08012 m
.19303 .41269 L
.19373 .41269 L
.19373 .08012 L
s
.678 .847 .902 r
.19373 .08012 m
.19373 .412 L
.19397 .412 L
.19397 .08012 L
F
.2 .63 .79 r
.19373 .08012 m
.19373 .412 L
.19397 .412 L
.19397 .08012 L
s
.678 .847 .902 r
.19397 .08012 m
.19397 .4115 L
.19454 .4115 L
.19454 .08012 L
F
.2 .63 .79 r
.19397 .08012 m
.19397 .4115 L
.19454 .4115 L
.19454 .08012 L
s
.678 .847 .902 r
.19454 .08012 m
.19454 .41074 L
.19506 .41074 L
.19506 .08012 L
F
.2 .63 .79 r
.19454 .08012 m
.19454 .41074 L
.19506 .41074 L
.19506 .08012 L
s
.678 .847 .902 r
.19506 .08012 m
.19506 .41043 L
.19541 .41043 L
.19541 .08012 L
F
.2 .63 .79 r
.19506 .08012 m
.19506 .41043 L
.19541 .41043 L
.19541 .08012 L
s
.678 .847 .902 r
.19541 .08012 m
.19541 .41014 L
.19575 .41014 L
.19575 .08012 L
F
.2 .63 .79 r
.19541 .08012 m
.19541 .41014 L
.19575 .41014 L
.19575 .08012 L
s
.678 .847 .902 r
.19575 .08012 m
.19575 .40978 L
.19607 .40978 L
.19607 .08012 L
F
.2 .63 .79 r
.19575 .08012 m
.19575 .40978 L
.19607 .40978 L
.19607 .08012 L
s
.678 .847 .902 r
.19607 .08012 m
.19607 .4095 L
.19676 .4095 L
.19676 .08012 L
F
.2 .63 .79 r
.19607 .08012 m
.19607 .4095 L
.19676 .4095 L
.19676 .08012 L
s
.678 .847 .902 r
.19676 .08012 m
.19676 .4087 L
.19702 .4087 L
.19702 .08012 L
F
.2 .63 .79 r
.19676 .08012 m
.19676 .4087 L
.19702 .4087 L
.19702 .08012 L
s
.678 .847 .902 r
.19702 .08012 m
.19702 .40841 L
.19734 .40841 L
.19734 .08012 L
F
.2 .63 .79 r
.19702 .08012 m
.19702 .40841 L
.19734 .40841 L
.19734 .08012 L
s
.678 .847 .902 r
.19734 .08012 m
.19734 .40819 L
.19803 .40819 L
.19803 .08012 L
F
.2 .63 .79 r
.19734 .08012 m
.19734 .40819 L
.19803 .40819 L
.19803 .08012 L
s
.678 .847 .902 r
.19803 .08012 m
.19803 .40731 L
.19858 .40731 L
.19858 .08012 L
F
.2 .63 .79 r
.19803 .08012 m
.19803 .40731 L
.19858 .40731 L
.19858 .08012 L
s
.678 .847 .902 r
.19858 .08012 m
.19858 .40702 L
.19885 .40702 L
.19885 .08012 L
F
.2 .63 .79 r
.19858 .08012 m
.19858 .40702 L
.19885 .40702 L
.19885 .08012 L
s
.678 .847 .902 r
.19885 .08012 m
.19885 .40637 L
.19942 .40637 L
.19942 .08012 L
F
.2 .63 .79 r
.19885 .08012 m
.19885 .40637 L
.19942 .40637 L
.19942 .08012 L
s
.678 .847 .902 r
.19942 .08012 m
.19942 .40594 L
.20008 .40594 L
.20008 .08012 L
F
.2 .63 .79 r
.19942 .08012 m
.19942 .40594 L
.20008 .40594 L
.20008 .08012 L
s
.678 .847 .902 r
.20008 .08012 m
.20008 .4053 L
.20076 .4053 L
.20076 .08012 L
F
.2 .63 .79 r
.20008 .08012 m
.20008 .4053 L
.20076 .4053 L
.20076 .08012 L
s
.678 .847 .902 r
.20076 .08012 m
.20076 .40484 L
.201 .40484 L
.201 .08012 L
F
.2 .63 .79 r
.20076 .08012 m
.20076 .40484 L
.201 .40484 L
.201 .08012 L
s
.678 .847 .902 r
.201 .08012 m
.201 .40458 L
.20136 .40458 L
.20136 .08012 L
F
.2 .63 .79 r
.201 .08012 m
.201 .40458 L
.20136 .40458 L
.20136 .08012 L
s
.678 .847 .902 r
.20136 .08012 m
.20136 .40416 L
.2019 .40416 L
.2019 .08012 L
F
.2 .63 .79 r
.20136 .08012 m
.20136 .40416 L
.2019 .40416 L
.2019 .08012 L
s
.678 .847 .902 r
.2019 .08012 m
.2019 .40346 L
.20222 .40346 L
.20222 .08012 L
F
.2 .63 .79 r
.2019 .08012 m
.2019 .40346 L
.20222 .40346 L
.20222 .08012 L
s
.678 .847 .902 r
.20222 .08012 m
.20222 .40326 L
.20265 .40326 L
.20265 .08012 L
F
.2 .63 .79 r
.20222 .08012 m
.20222 .40326 L
.20265 .40326 L
.20265 .08012 L
s
.678 .847 .902 r
.20265 .08012 m
.20265 .40284 L
.20331 .40284 L
.20331 .08012 L
F
.2 .63 .79 r
.20265 .08012 m
.20265 .40284 L
.20331 .40284 L
.20331 .08012 L
s
.678 .847 .902 r
.20331 .08012 m
.20331 .40215 L
.20355 .40215 L
.20355 .08012 L
F
.2 .63 .79 r
.20331 .08012 m
.20331 .40215 L
.20355 .40215 L
.20355 .08012 L
s
.678 .847 .902 r
.20355 .08012 m
.20355 .40171 L
.20407 .40171 L
.20407 .08012 L
F
.2 .63 .79 r
.20355 .08012 m
.20355 .40171 L
.20407 .40171 L
.20407 .08012 L
s
.678 .847 .902 r
.20407 .08012 m
.20407 .40142 L
.20453 .40142 L
.20453 .08012 L
F
.2 .63 .79 r
.20407 .08012 m
.20407 .40142 L
.20453 .40142 L
.20453 .08012 L
s
.678 .847 .902 r
.20453 .08012 m
.20453 .40101 L
.20517 .40101 L
.20517 .08012 L
F
.2 .63 .79 r
.20453 .08012 m
.20453 .40101 L
.20517 .40101 L
.20517 .08012 L
s
.678 .847 .902 r
.20517 .08012 m
.20517 .40035 L
.20557 .40035 L
.20557 .08012 L
F
.2 .63 .79 r
.20517 .08012 m
.20517 .40035 L
.20557 .40035 L
.20557 .08012 L
s
.678 .847 .902 r
.20557 .08012 m
.20557 .39989 L
.2058 .39989 L
.2058 .08012 L
F
.2 .63 .79 r
.20557 .08012 m
.20557 .39989 L
.2058 .39989 L
.2058 .08012 L
s
.678 .847 .902 r
.2058 .08012 m
.2058 .39964 L
.20612 .39964 L
.20612 .08012 L
F
.2 .63 .79 r
.2058 .08012 m
.2058 .39964 L
.20612 .39964 L
.20612 .08012 L
s
.678 .847 .902 r
.20612 .08012 m
.20612 .39919 L
.20664 .39919 L
.20664 .08012 L
F
.2 .63 .79 r
.20612 .08012 m
.20612 .39919 L
.20664 .39919 L
.20664 .08012 L
s
.678 .847 .902 r
.20664 .08012 m
.20664 .3988 L
.20693 .3988 L
.20693 .08012 L
F
.2 .63 .79 r
.20664 .08012 m
.20664 .3988 L
.20693 .3988 L
.20693 .08012 L
s
.678 .847 .902 r
.20693 .08012 m
.20693 .39854 L
.20721 .39854 L
.20721 .08012 L
F
.2 .63 .79 r
.20693 .08012 m
.20693 .39854 L
.20721 .39854 L
.20721 .08012 L
s
.678 .847 .902 r
.20721 .08012 m
.20721 .39825 L
.20749 .39825 L
.20749 .08012 L
F
.2 .63 .79 r
.20721 .08012 m
.20721 .39825 L
.20749 .39825 L
.20749 .08012 L
s
.678 .847 .902 r
.20749 .08012 m
.20749 .39784 L
.20791 .39784 L
.20791 .08012 L
F
.2 .63 .79 r
.20749 .08012 m
.20749 .39784 L
.20791 .39784 L
.20791 .08012 L
s
.678 .847 .902 r
.20791 .08012 m
.20791 .39759 L
.20824 .39759 L
.20824 .08012 L
F
.2 .63 .79 r
.20791 .08012 m
.20791 .39759 L
.20824 .39759 L
.20824 .08012 L
s
.678 .847 .902 r
.20824 .08012 m
.20824 .39741 L
.2087 .39741 L
.2087 .08012 L
F
.2 .63 .79 r
.20824 .08012 m
.20824 .39741 L
.2087 .39741 L
.2087 .08012 L
s
.678 .847 .902 r
.2087 .08012 m
.2087 .39688 L
.20893 .39688 L
.20893 .08012 L
F
.2 .63 .79 r
.2087 .08012 m
.2087 .39688 L
.20893 .39688 L
.20893 .08012 L
s
.678 .847 .902 r
.20893 .08012 m
.20893 .39616 L
.20951 .39616 L
.20951 .08012 L
F
.2 .63 .79 r
.20893 .08012 m
.20893 .39616 L
.20951 .39616 L
.20951 .08012 L
s
.678 .847 .902 r
.20951 .08012 m
.20951 .39615 L
.20991 .39615 L
.20991 .08012 L
F
.2 .63 .79 r
.20951 .08012 m
.20951 .39615 L
.20991 .39615 L
.20991 .08012 L
s
.678 .847 .902 r
.20991 .08012 m
.20991 .39545 L
.21042 .39545 L
.21042 .08012 L
F
.2 .63 .79 r
.20991 .08012 m
.20991 .39545 L
.21042 .39545 L
.21042 .08012 L
s
.678 .847 .902 r
.21042 .08012 m
.21042 .39519 L
.21114 .39519 L
.21114 .08012 L
F
.2 .63 .79 r
.21042 .08012 m
.21042 .39519 L
.21114 .39519 L
.21114 .08012 L
s
.678 .847 .902 r
.21114 .08012 m
.21114 .39421 L
.21158 .39421 L
.21158 .08012 L
F
.2 .63 .79 r
.21114 .08012 m
.21114 .39421 L
.21158 .39421 L
.21158 .08012 L
s
.678 .847 .902 r
.21158 .08012 m
.21158 .39366 L
.21217 .39366 L
.21217 .08012 L
F
.2 .63 .79 r
.21158 .08012 m
.21158 .39366 L
.21217 .39366 L
.21217 .08012 L
s
.678 .847 .902 r
.21217 .08012 m
.21217 .39325 L
.21258 .39325 L
.21258 .08012 L
F
.2 .63 .79 r
.21217 .08012 m
.21217 .39325 L
.21258 .39325 L
.21258 .08012 L
s
.678 .847 .902 r
.21258 .08012 m
.21258 .39277 L
.21309 .39277 L
.21309 .08012 L
F
.2 .63 .79 r
.21258 .08012 m
.21258 .39277 L
.21309 .39277 L
.21309 .08012 L
s
.678 .847 .902 r
.21309 .08012 m
.21309 .39236 L
.2136 .39236 L
.2136 .08012 L
F
.2 .63 .79 r
.21309 .08012 m
.21309 .39236 L
.2136 .39236 L
.2136 .08012 L
s
.678 .847 .902 r
.2136 .08012 m
.2136 .39158 L
.21418 .39158 L
.21418 .08012 L
F
.2 .63 .79 r
.2136 .08012 m
.2136 .39158 L
.21418 .39158 L
.21418 .08012 L
s
.678 .847 .902 r
.21418 .08012 m
.21418 .391 L
.21479 .391 L
.21479 .08012 L
F
.2 .63 .79 r
.21418 .08012 m
.21418 .391 L
.21479 .391 L
.21479 .08012 L
s
.678 .847 .902 r
.21479 .08012 m
.21479 .39084 L
.21507 .39084 L
.21507 .08012 L
F
.2 .63 .79 r
.21479 .08012 m
.21479 .39084 L
.21507 .39084 L
.21507 .08012 L
s
.678 .847 .902 r
.21507 .08012 m
.21507 .39047 L
.21567 .39047 L
.21567 .08012 L
F
.2 .63 .79 r
.21507 .08012 m
.21507 .39047 L
.21567 .39047 L
.21567 .08012 L
s
.678 .847 .902 r
.21567 .08012 m
.21567 .38984 L
.21606 .38984 L
.21606 .08012 L
F
.2 .63 .79 r
.21567 .08012 m
.21567 .38984 L
.21606 .38984 L
.21606 .08012 L
s
.678 .847 .902 r
.21606 .08012 m
.21606 .38908 L
.21667 .38908 L
.21667 .08012 L
F
.2 .63 .79 r
.21606 .08012 m
.21606 .38908 L
.21667 .38908 L
.21667 .08012 L
s
.678 .847 .902 r
.21667 .08012 m
.21667 .38866 L
.21735 .38866 L
.21735 .08012 L
F
.2 .63 .79 r
.21667 .08012 m
.21667 .38866 L
.21735 .38866 L
.21735 .08012 L
s
.678 .847 .902 r
.21735 .08012 m
.21735 .38821 L
.21765 .38821 L
.21765 .08012 L
F
.2 .63 .79 r
.21735 .08012 m
.21735 .38821 L
.21765 .38821 L
.21765 .08012 L
s
.678 .847 .902 r
.21765 .08012 m
.21765 .38785 L
.21797 .38785 L
.21797 .08012 L
F
.2 .63 .79 r
.21765 .08012 m
.21765 .38785 L
.21797 .38785 L
.21797 .08012 L
s
.678 .847 .902 r
.21797 .08012 m
.21797 .38762 L
.21853 .38762 L
.21853 .08012 L
F
.2 .63 .79 r
.21797 .08012 m
.21797 .38762 L
.21853 .38762 L
.21853 .08012 L
s
.678 .847 .902 r
.21853 .08012 m
.21853 .3867 L
.21914 .3867 L
.21914 .08012 L
F
.2 .63 .79 r
.21853 .08012 m
.21853 .3867 L
.21914 .3867 L
.21914 .08012 L
s
.678 .847 .902 r
.21914 .08012 m
.21914 .38613 L
.21976 .38613 L
.21976 .08012 L
F
.2 .63 .79 r
.21914 .08012 m
.21914 .38613 L
.21976 .38613 L
.21976 .08012 L
s
.678 .847 .902 r
.21976 .08012 m
.21976 .38583 L
.22048 .38583 L
.22048 .08012 L
F
.2 .63 .79 r
.21976 .08012 m
.21976 .38583 L
.22048 .38583 L
.22048 .08012 L
s
.678 .847 .902 r
.22048 .08012 m
.22048 .38524 L
.22079 .38524 L
.22079 .08012 L
F
.2 .63 .79 r
.22048 .08012 m
.22048 .38524 L
.22079 .38524 L
.22079 .08012 L
s
.678 .847 .902 r
.22079 .08012 m
.22079 .38472 L
.2214 .38472 L
.2214 .08012 L
F
.2 .63 .79 r
.22079 .08012 m
.22079 .38472 L
.2214 .38472 L
.2214 .08012 L
s
.678 .847 .902 r
.2214 .08012 m
.2214 .38422 L
.22165 .38422 L
.22165 .08012 L
F
.2 .63 .79 r
.2214 .08012 m
.2214 .38422 L
.22165 .38422 L
.22165 .08012 L
s
.678 .847 .902 r
.22165 .08012 m
.22165 .38403 L
.22219 .38403 L
.22219 .08012 L
F
.2 .63 .79 r
.22165 .08012 m
.22165 .38403 L
.22219 .38403 L
.22219 .08012 L
s
.678 .847 .902 r
.22219 .08012 m
.22219 .3833 L
.22273 .3833 L
.22273 .08012 L
F
.2 .63 .79 r
.22219 .08012 m
.22219 .3833 L
.22273 .3833 L
.22273 .08012 L
s
.678 .847 .902 r
.22273 .08012 m
.22273 .38288 L
.22334 .38288 L
.22334 .08012 L
F
.2 .63 .79 r
.22273 .08012 m
.22273 .38288 L
.22334 .38288 L
.22334 .08012 L
s
.678 .847 .902 r
.22334 .08012 m
.22334 .38247 L
.22388 .38247 L
.22388 .08012 L
F
.2 .63 .79 r
.22334 .08012 m
.22334 .38247 L
.22388 .38247 L
.22388 .08012 L
s
.678 .847 .902 r
.22388 .08012 m
.22388 .38165 L
.22456 .38165 L
.22456 .08012 L
F
.2 .63 .79 r
.22388 .08012 m
.22388 .38165 L
.22456 .38165 L
.22456 .08012 L
s
.678 .847 .902 r
.22456 .08012 m
.22456 .38132 L
.22491 .38132 L
.22491 .08012 L
F
.2 .63 .79 r
.22456 .08012 m
.22456 .38132 L
.22491 .38132 L
.22491 .08012 L
s
.678 .847 .902 r
.22491 .08012 m
.22491 .38076 L
.22523 .38076 L
.22523 .08012 L
F
.2 .63 .79 r
.22491 .08012 m
.22491 .38076 L
.22523 .38076 L
.22523 .08012 L
s
.678 .847 .902 r
.22523 .08012 m
.22523 .38053 L
.22548 .38053 L
.22548 .08012 L
F
.2 .63 .79 r
.22523 .08012 m
.22523 .38053 L
.22548 .38053 L
.22548 .08012 L
s
.678 .847 .902 r
.22548 .08012 m
.22548 .38023 L
.22581 .38023 L
.22581 .08012 L
F
.2 .63 .79 r
.22548 .08012 m
.22548 .38023 L
.22581 .38023 L
.22581 .08012 L
s
.678 .847 .902 r
.22581 .08012 m
.22581 .38005 L
.22627 .38005 L
.22627 .08012 L
F
.2 .63 .79 r
.22581 .08012 m
.22581 .38005 L
.22627 .38005 L
.22627 .08012 L
s
.678 .847 .902 r
.22627 .08012 m
.22627 .37955 L
.22653 .37955 L
.22653 .08012 L
F
.2 .63 .79 r
.22627 .08012 m
.22627 .37955 L
.22653 .37955 L
.22653 .08012 L
s
.678 .847 .902 r
.22653 .08012 m
.22653 .37929 L
.22692 .37929 L
.22692 .08012 L
F
.2 .63 .79 r
.22653 .08012 m
.22653 .37929 L
.22692 .37929 L
.22692 .08012 L
s
.678 .847 .902 r
.22692 .08012 m
.22692 .37898 L
.22758 .37898 L
.22758 .08012 L
F
.2 .63 .79 r
.22692 .08012 m
.22692 .37898 L
.22758 .37898 L
.22758 .08012 L
s
.678 .847 .902 r
.22758 .08012 m
.22758 .37829 L
.22817 .37829 L
.22817 .08012 L
F
.2 .63 .79 r
.22758 .08012 m
.22758 .37829 L
.22817 .37829 L
.22817 .08012 L
s
.678 .847 .902 r
.22817 .08012 m
.22817 .37757 L
.22848 .37757 L
.22848 .08012 L
F
.2 .63 .79 r
.22817 .08012 m
.22817 .37757 L
.22848 .37757 L
.22848 .08012 L
s
.678 .847 .902 r
.22848 .08012 m
.22848 .37731 L
.22879 .37731 L
.22879 .08012 L
F
.2 .63 .79 r
.22848 .08012 m
.22848 .37731 L
.22879 .37731 L
.22879 .08012 L
s
.678 .847 .902 r
.22879 .08012 m
.22879 .37706 L
.22935 .37706 L
.22935 .08012 L
F
.2 .63 .79 r
.22879 .08012 m
.22879 .37706 L
.22935 .37706 L
.22935 .08012 L
s
.678 .847 .902 r
.22935 .08012 m
.22935 .37646 L
.2296 .37646 L
.2296 .08012 L
F
.2 .63 .79 r
.22935 .08012 m
.22935 .37646 L
.2296 .37646 L
.2296 .08012 L
s
.678 .847 .902 r
.2296 .08012 m
.2296 .37605 L
.23002 .37605 L
.23002 .08012 L
F
.2 .63 .79 r
.2296 .08012 m
.2296 .37605 L
.23002 .37605 L
.23002 .08012 L
s
.678 .847 .902 r
.23002 .08012 m
.23002 .37567 L
.23045 .37567 L
.23045 .08012 L
F
.2 .63 .79 r
.23002 .08012 m
.23002 .37567 L
.23045 .37567 L
.23045 .08012 L
s
.678 .847 .902 r
.23045 .08012 m
.23045 .37561 L
.23102 .37561 L
.23102 .08012 L
F
.2 .63 .79 r
.23045 .08012 m
.23045 .37561 L
.23102 .37561 L
.23102 .08012 L
s
.678 .847 .902 r
.23102 .08012 m
.23102 .37467 L
.23169 .37467 L
.23169 .08012 L
F
.2 .63 .79 r
.23102 .08012 m
.23102 .37467 L
.23169 .37467 L
.23169 .08012 L
s
.678 .847 .902 r
.23169 .08012 m
.23169 .37417 L
.23224 .37417 L
.23224 .08012 L
F
.2 .63 .79 r
.23169 .08012 m
.23169 .37417 L
.23224 .37417 L
.23224 .08012 L
s
.678 .847 .902 r
.23224 .08012 m
.23224 .37387 L
.23263 .37387 L
.23263 .08012 L
F
.2 .63 .79 r
.23224 .08012 m
.23224 .37387 L
.23263 .37387 L
.23263 .08012 L
s
.678 .847 .902 r
.23263 .08012 m
.23263 .37332 L
.23288 .37332 L
.23288 .08012 L
F
.2 .63 .79 r
.23263 .08012 m
.23263 .37332 L
.23288 .37332 L
.23288 .08012 L
s
.678 .847 .902 r
.23288 .08012 m
.23288 .37294 L
.23323 .37294 L
.23323 .08012 L
F
.2 .63 .79 r
.23288 .08012 m
.23288 .37294 L
.23323 .37294 L
.23323 .08012 L
s
.678 .847 .902 r
.23323 .08012 m
.23323 .37289 L
.2339 .37289 L
.2339 .08012 L
F
.2 .63 .79 r
.23323 .08012 m
.23323 .37289 L
.2339 .37289 L
.2339 .08012 L
s
.678 .847 .902 r
.2339 .08012 m
.2339 .37176 L
.23448 .37176 L
.23448 .08012 L
F
.2 .63 .79 r
.2339 .08012 m
.2339 .37176 L
.23448 .37176 L
.23448 .08012 L
s
.678 .847 .902 r
.23448 .08012 m
.23448 .37165 L
.23478 .37165 L
.23478 .08012 L
F
.2 .63 .79 r
.23448 .08012 m
.23448 .37165 L
.23478 .37165 L
.23478 .08012 L
s
.678 .847 .902 r
.23478 .08012 m
.23478 .37123 L
.235 .37123 L
.235 .08012 L
F
.2 .63 .79 r
.23478 .08012 m
.23478 .37123 L
.235 .37123 L
.235 .08012 L
s
.678 .847 .902 r
.235 .08012 m
.235 .37104 L
.23558 .37104 L
.23558 .08012 L
F
.2 .63 .79 r
.235 .08012 m
.235 .37104 L
.23558 .37104 L
.23558 .08012 L
s
.678 .847 .902 r
.23558 .08012 m
.23558 .3705 L
.23612 .3705 L
.23612 .08012 L
F
.2 .63 .79 r
.23558 .08012 m
.23558 .3705 L
.23612 .3705 L
.23612 .08012 L
s
.678 .847 .902 r
.23612 .08012 m
.23612 .36974 L
.23682 .36974 L
.23682 .08012 L
F
.2 .63 .79 r
.23612 .08012 m
.23612 .36974 L
.23682 .36974 L
.23682 .08012 L
s
.678 .847 .902 r
.23682 .08012 m
.23682 .3691 L
.23731 .3691 L
.23731 .08012 L
F
.2 .63 .79 r
.23682 .08012 m
.23682 .3691 L
.23731 .3691 L
.23731 .08012 L
s
.678 .847 .902 r
.23731 .08012 m
.23731 .36855 L
.23785 .36855 L
.23785 .08012 L
F
.2 .63 .79 r
.23731 .08012 m
.23731 .36855 L
.23785 .36855 L
.23785 .08012 L
s
.678 .847 .902 r
.23785 .08012 m
.23785 .36813 L
.23822 .36813 L
.23822 .08012 L
F
.2 .63 .79 r
.23785 .08012 m
.23785 .36813 L
.23822 .36813 L
.23822 .08012 L
s
.678 .847 .902 r
.23822 .08012 m
.23822 .368 L
.23848 .368 L
.23848 .08012 L
F
.2 .63 .79 r
.23822 .08012 m
.23822 .368 L
.23848 .368 L
.23848 .08012 L
s
.678 .847 .902 r
.23848 .08012 m
.23848 .36751 L
.23911 .36751 L
.23911 .08012 L
F
.2 .63 .79 r
.23848 .08012 m
.23848 .36751 L
.23911 .36751 L
.23911 .08012 L
s
.678 .847 .902 r
.23911 .08012 m
.23911 .36726 L
.23956 .36726 L
.23956 .08012 L
F
.2 .63 .79 r
.23911 .08012 m
.23911 .36726 L
.23956 .36726 L
.23956 .08012 L
s
.678 .847 .902 r
.23956 .08012 m
.23956 .36676 L
.23984 .36676 L
.23984 .08012 L
F
.2 .63 .79 r
.23956 .08012 m
.23956 .36676 L
.23984 .36676 L
.23984 .08012 L
s
.678 .847 .902 r
.23984 .08012 m
.23984 .36648 L
.24028 .36648 L
.24028 .08012 L
F
.2 .63 .79 r
.23984 .08012 m
.23984 .36648 L
.24028 .36648 L
.24028 .08012 L
s
.678 .847 .902 r
.24028 .08012 m
.24028 .36574 L
.24087 .36574 L
.24087 .08012 L
F
.2 .63 .79 r
.24028 .08012 m
.24028 .36574 L
.24087 .36574 L
.24087 .08012 L
s
.678 .847 .902 r
.24087 .08012 m
.24087 .36557 L
.24112 .36557 L
.24112 .08012 L
F
.2 .63 .79 r
.24087 .08012 m
.24087 .36557 L
.24112 .36557 L
.24112 .08012 L
s
.678 .847 .902 r
.24112 .08012 m
.24112 .3651 L
.2417 .3651 L
.2417 .08012 L
F
.2 .63 .79 r
.24112 .08012 m
.24112 .3651 L
.2417 .3651 L
.2417 .08012 L
s
.678 .847 .902 r
.2417 .08012 m
.2417 .36466 L
.2423 .36466 L
.2423 .08012 L
F
.2 .63 .79 r
.2417 .08012 m
.2417 .36466 L
.2423 .36466 L
.2423 .08012 L
s
.678 .847 .902 r
.2423 .08012 m
.2423 .36414 L
.24296 .36414 L
.24296 .08012 L
F
.2 .63 .79 r
.2423 .08012 m
.2423 .36414 L
.24296 .36414 L
.24296 .08012 L
s
.678 .847 .902 r
.24296 .08012 m
.24296 .36334 L
.24339 .36334 L
.24339 .08012 L
F
.2 .63 .79 r
.24296 .08012 m
.24296 .36334 L
.24339 .36334 L
.24339 .08012 L
s
.678 .847 .902 r
.24339 .08012 m
.24339 .36302 L
.2438 .36302 L
.2438 .08012 L
F
.2 .63 .79 r
.24339 .08012 m
.24339 .36302 L
.2438 .36302 L
.2438 .08012 L
s
.678 .847 .902 r
.2438 .08012 m
.2438 .36254 L
.24437 .36254 L
.24437 .08012 L
F
.2 .63 .79 r
.2438 .08012 m
.2438 .36254 L
.24437 .36254 L
.24437 .08012 L
s
.678 .847 .902 r
.24437 .08012 m
.24437 .36216 L
.24489 .36216 L
.24489 .08012 L
F
.2 .63 .79 r
.24437 .08012 m
.24437 .36216 L
.24489 .36216 L
.24489 .08012 L
s
.678 .847 .902 r
.24489 .08012 m
.24489 .36149 L
.24538 .36149 L
.24538 .08012 L
F
.2 .63 .79 r
.24489 .08012 m
.24489 .36149 L
.24538 .36149 L
.24538 .08012 L
s
.678 .847 .902 r
.24538 .08012 m
.24538 .36103 L
.24594 .36103 L
.24594 .08012 L
F
.2 .63 .79 r
.24538 .08012 m
.24538 .36103 L
.24594 .36103 L
.24594 .08012 L
s
.678 .847 .902 r
.24594 .08012 m
.24594 .36064 L
.24643 .36064 L
.24643 .08012 L
F
.2 .63 .79 r
.24594 .08012 m
.24594 .36064 L
.24643 .36064 L
.24643 .08012 L
s
.678 .847 .902 r
.24643 .08012 m
.24643 .36017 L
.24696 .36017 L
.24696 .08012 L
F
.2 .63 .79 r
.24643 .08012 m
.24643 .36017 L
.24696 .36017 L
.24696 .08012 L
s
.678 .847 .902 r
.24696 .08012 m
.24696 .35964 L
.2476 .35964 L
.2476 .08012 L
F
.2 .63 .79 r
.24696 .08012 m
.24696 .35964 L
.2476 .35964 L
.2476 .08012 L
s
.678 .847 .902 r
.2476 .08012 m
.2476 .35916 L
.24783 .35916 L
.24783 .08012 L
F
.2 .63 .79 r
.2476 .08012 m
.2476 .35916 L
.24783 .35916 L
.24783 .08012 L
s
.678 .847 .902 r
.24783 .08012 m
.24783 .35864 L
.24836 .35864 L
.24836 .08012 L
F
.2 .63 .79 r
.24783 .08012 m
.24783 .35864 L
.24836 .35864 L
.24836 .08012 L
s
.678 .847 .902 r
.24836 .08012 m
.24836 .35836 L
.24861 .35836 L
.24861 .08012 L
F
.2 .63 .79 r
.24836 .08012 m
.24836 .35836 L
.24861 .35836 L
.24861 .08012 L
s
.678 .847 .902 r
.24861 .08012 m
.24861 .35812 L
.24893 .35812 L
.24893 .08012 L
F
.2 .63 .79 r
.24861 .08012 m
.24861 .35812 L
.24893 .35812 L
.24893 .08012 L
s
.678 .847 .902 r
.24893 .08012 m
.24893 .35783 L
.24953 .35783 L
.24953 .08012 L
F
.2 .63 .79 r
.24893 .08012 m
.24893 .35783 L
.24953 .35783 L
.24953 .08012 L
s
.678 .847 .902 r
.24953 .08012 m
.24953 .3573 L
.25001 .3573 L
.25001 .08012 L
F
.2 .63 .79 r
.24953 .08012 m
.24953 .3573 L
.25001 .3573 L
.25001 .08012 L
s
.678 .847 .902 r
.25001 .08012 m
.25001 .35662 L
.25037 .35662 L
.25037 .08012 L
F
.2 .63 .79 r
.25001 .08012 m
.25001 .35662 L
.25037 .35662 L
.25037 .08012 L
s
.678 .847 .902 r
.25037 .08012 m
.25037 .35638 L
.25096 .35638 L
.25096 .08012 L
F
.2 .63 .79 r
.25037 .08012 m
.25037 .35638 L
.25096 .35638 L
.25096 .08012 L
s
.678 .847 .902 r
.25096 .08012 m
.25096 .35557 L
.25151 .35557 L
.25151 .08012 L
F
.2 .63 .79 r
.25096 .08012 m
.25096 .35557 L
.25151 .35557 L
.25151 .08012 L
s
.678 .847 .902 r
.25151 .08012 m
.25151 .35529 L
.25177 .35529 L
.25177 .08012 L
F
.2 .63 .79 r
.25151 .08012 m
.25151 .35529 L
.25177 .35529 L
.25177 .08012 L
s
.678 .847 .902 r
.25177 .08012 m
.25177 .3552 L
.25226 .3552 L
.25226 .08012 L
F
.2 .63 .79 r
.25177 .08012 m
.25177 .3552 L
.25226 .3552 L
.25226 .08012 L
s
.678 .847 .902 r
.25226 .08012 m
.25226 .35466 L
.25282 .35466 L
.25282 .08012 L
F
.2 .63 .79 r
.25226 .08012 m
.25226 .35466 L
.25282 .35466 L
.25282 .08012 L
s
.678 .847 .902 r
.25282 .08012 m
.25282 .354 L
.25352 .354 L
.25352 .08012 L
F
.2 .63 .79 r
.25282 .08012 m
.25282 .354 L
.25352 .354 L
.25352 .08012 L
s
.678 .847 .902 r
.25352 .08012 m
.25352 .35337 L
.25392 .35337 L
.25392 .08012 L
F
.2 .63 .79 r
.25352 .08012 m
.25352 .35337 L
.25392 .35337 L
.25392 .08012 L
s
.678 .847 .902 r
.25392 .08012 m
.25392 .35325 L
.25449 .35325 L
.25449 .08012 L
F
.2 .63 .79 r
.25392 .08012 m
.25392 .35325 L
.25449 .35325 L
.25449 .08012 L
s
.678 .847 .902 r
.25449 .08012 m
.25449 .35252 L
.25483 .35252 L
.25483 .08012 L
F
.2 .63 .79 r
.25449 .08012 m
.25449 .35252 L
.25483 .35252 L
.25483 .08012 L
s
.678 .847 .902 r
.25483 .08012 m
.25483 .35192 L
.25534 .35192 L
.25534 .08012 L
F
.2 .63 .79 r
.25483 .08012 m
.25483 .35192 L
.25534 .35192 L
.25534 .08012 L
s
.678 .847 .902 r
.25534 .08012 m
.25534 .35182 L
.2559 .35182 L
.2559 .08012 L
F
.2 .63 .79 r
.25534 .08012 m
.25534 .35182 L
.2559 .35182 L
.2559 .08012 L
s
.678 .847 .902 r
.2559 .08012 m
.2559 .3512 L
.25616 .3512 L
.25616 .08012 L
F
.2 .63 .79 r
.2559 .08012 m
.2559 .3512 L
.25616 .3512 L
.25616 .08012 L
s
.678 .847 .902 r
.25616 .08012 m
.25616 .35114 L
.25675 .35114 L
.25675 .08012 L
F
.2 .63 .79 r
.25616 .08012 m
.25616 .35114 L
.25675 .35114 L
.25675 .08012 L
s
.678 .847 .902 r
.25675 .08012 m
.25675 .3503 L
.25743 .3503 L
.25743 .08012 L
F
.2 .63 .79 r
.25675 .08012 m
.25675 .3503 L
.25743 .3503 L
.25743 .08012 L
s
.678 .847 .902 r
.25743 .08012 m
.25743 .34973 L
.25771 .34973 L
.25771 .08012 L
F
.2 .63 .79 r
.25743 .08012 m
.25743 .34973 L
.25771 .34973 L
.25771 .08012 L
s
.678 .847 .902 r
.25771 .08012 m
.25771 .34947 L
.25819 .34947 L
.25819 .08012 L
F
.2 .63 .79 r
.25771 .08012 m
.25771 .34947 L
.25819 .34947 L
.25819 .08012 L
s
.678 .847 .902 r
.25819 .08012 m
.25819 .3488 L
.25887 .3488 L
.25887 .08012 L
F
.2 .63 .79 r
.25819 .08012 m
.25819 .3488 L
.25887 .3488 L
.25887 .08012 L
s
.678 .847 .902 r
.25887 .08012 m
.25887 .34846 L
.25953 .34846 L
.25953 .08012 L
F
.2 .63 .79 r
.25887 .08012 m
.25887 .34846 L
.25953 .34846 L
.25953 .08012 L
s
.678 .847 .902 r
.25953 .08012 m
.25953 .34791 L
.26002 .34791 L
.26002 .08012 L
F
.2 .63 .79 r
.25953 .08012 m
.25953 .34791 L
.26002 .34791 L
.26002 .08012 L
s
.678 .847 .902 r
.26002 .08012 m
.26002 .34754 L
.26046 .34754 L
.26046 .08012 L
F
.2 .63 .79 r
.26002 .08012 m
.26002 .34754 L
.26046 .34754 L
.26046 .08012 L
s
.678 .847 .902 r
.26046 .08012 m
.26046 .34698 L
.26104 .34698 L
.26104 .08012 L
F
.2 .63 .79 r
.26046 .08012 m
.26046 .34698 L
.26104 .34698 L
.26104 .08012 L
s
.678 .847 .902 r
.26104 .08012 m
.26104 .34659 L
.26132 .34659 L
.26132 .08012 L
F
.2 .63 .79 r
.26104 .08012 m
.26104 .34659 L
.26132 .34659 L
.26132 .08012 L
s
.678 .847 .902 r
.26132 .08012 m
.26132 .34633 L
.26155 .34633 L
.26155 .08012 L
F
.2 .63 .79 r
.26132 .08012 m
.26132 .34633 L
.26155 .34633 L
.26155 .08012 L
s
.678 .847 .902 r
.26155 .08012 m
.26155 .3461 L
.26185 .3461 L
.26185 .08012 L
F
.2 .63 .79 r
.26155 .08012 m
.26155 .3461 L
.26185 .3461 L
.26185 .08012 L
s
.678 .847 .902 r
.26185 .08012 m
.26185 .34522 L
.26257 .34522 L
.26257 .08012 L
F
.2 .63 .79 r
.26185 .08012 m
.26185 .34522 L
.26257 .34522 L
.26257 .08012 L
s
.678 .847 .902 r
.26257 .08012 m
.26257 .34511 L
.26303 .34511 L
.26303 .08012 L
F
.2 .63 .79 r
.26257 .08012 m
.26257 .34511 L
.26303 .34511 L
.26303 .08012 L
s
.678 .847 .902 r
.26303 .08012 m
.26303 .34466 L
.26373 .34466 L
.26373 .08012 L
F
.2 .63 .79 r
.26303 .08012 m
.26303 .34466 L
.26373 .34466 L
.26373 .08012 L
s
.678 .847 .902 r
.26373 .08012 m
.26373 .34362 L
.26427 .34362 L
.26427 .08012 L
F
.2 .63 .79 r
.26373 .08012 m
.26373 .34362 L
.26427 .34362 L
.26427 .08012 L
s
.678 .847 .902 r
.26427 .08012 m
.26427 .34338 L
.26465 .34338 L
.26465 .08012 L
F
.2 .63 .79 r
.26427 .08012 m
.26427 .34338 L
.26465 .34338 L
.26465 .08012 L
s
.678 .847 .902 r
.26465 .08012 m
.26465 .34291 L
.26515 .34291 L
.26515 .08012 L
F
.2 .63 .79 r
.26465 .08012 m
.26465 .34291 L
.26515 .34291 L
.26515 .08012 L
s
.678 .847 .902 r
.26515 .08012 m
.26515 .34259 L
.26566 .34259 L
.26566 .08012 L
F
.2 .63 .79 r
.26515 .08012 m
.26515 .34259 L
.26566 .34259 L
.26566 .08012 L
s
.678 .847 .902 r
.26566 .08012 m
.26566 .34169 L
.26637 .34169 L
.26637 .08012 L
F
.2 .63 .79 r
.26566 .08012 m
.26566 .34169 L
.26637 .34169 L
.26637 .08012 L
s
.678 .847 .902 r
.26637 .08012 m
.26637 .34167 L
.26662 .34167 L
.26662 .08012 L
F
.2 .63 .79 r
.26637 .08012 m
.26637 .34167 L
.26662 .34167 L
.26662 .08012 L
s
.678 .847 .902 r
.26662 .08012 m
.26662 .34093 L
.26734 .34093 L
.26734 .08012 L
F
.2 .63 .79 r
.26662 .08012 m
.26662 .34093 L
.26734 .34093 L
.26734 .08012 L
s
.678 .847 .902 r
.26734 .08012 m
.26734 .34061 L
.26803 .34061 L
.26803 .08012 L
F
.2 .63 .79 r
.26734 .08012 m
.26734 .34061 L
.26803 .34061 L
.26803 .08012 L
s
.678 .847 .902 r
.26803 .08012 m
.26803 .34004 L
.26869 .34004 L
.26869 .08012 L
F
.2 .63 .79 r
.26803 .08012 m
.26803 .34004 L
.26869 .34004 L
.26869 .08012 L
s
.678 .847 .902 r
.26869 .08012 m
.26869 .33953 L
.26908 .33953 L
.26908 .08012 L
F
.2 .63 .79 r
.26869 .08012 m
.26869 .33953 L
.26908 .33953 L
.26908 .08012 L
s
.678 .847 .902 r
.26908 .08012 m
.26908 .33911 L
.26934 .33911 L
.26934 .08012 L
F
.2 .63 .79 r
.26908 .08012 m
.26908 .33911 L
.26934 .33911 L
.26934 .08012 L
s
.678 .847 .902 r
.26934 .08012 m
.26934 .33874 L
.26997 .33874 L
.26997 .08012 L
F
.2 .63 .79 r
.26934 .08012 m
.26934 .33874 L
.26997 .33874 L
.26997 .08012 L
s
.678 .847 .902 r
.26997 .08012 m
.26997 .33813 L
.27037 .33813 L
.27037 .08012 L
F
.2 .63 .79 r
.26997 .08012 m
.26997 .33813 L
.27037 .33813 L
.27037 .08012 L
s
.678 .847 .902 r
.27037 .08012 m
.27037 .33787 L
.27082 .33787 L
.27082 .08012 L
F
.2 .63 .79 r
.27037 .08012 m
.27037 .33787 L
.27082 .33787 L
.27082 .08012 L
s
.678 .847 .902 r
.27082 .08012 m
.27082 .33758 L
.27114 .33758 L
.27114 .08012 L
F
.2 .63 .79 r
.27082 .08012 m
.27082 .33758 L
.27114 .33758 L
.27114 .08012 L
s
.678 .847 .902 r
.27114 .08012 m
.27114 .33725 L
.27151 .33725 L
.27151 .08012 L
F
.2 .63 .79 r
.27114 .08012 m
.27114 .33725 L
.27151 .33725 L
.27151 .08012 L
s
.678 .847 .902 r
.27151 .08012 m
.27151 .33657 L
.2722 .33657 L
.2722 .08012 L
F
.2 .63 .79 r
.27151 .08012 m
.27151 .33657 L
.2722 .33657 L
.2722 .08012 L
s
.678 .847 .902 r
.2722 .08012 m
.2722 .33632 L
.2728 .33632 L
.2728 .08012 L
F
.2 .63 .79 r
.2722 .08012 m
.2722 .33632 L
.2728 .33632 L
.2728 .08012 L
s
.678 .847 .902 r
.2728 .08012 m
.2728 .33556 L
.27306 .33556 L
.27306 .08012 L
F
.2 .63 .79 r
.2728 .08012 m
.2728 .33556 L
.27306 .33556 L
.27306 .08012 L
s
.678 .847 .902 r
.27306 .08012 m
.27306 .33552 L
.27342 .33552 L
.27342 .08012 L
F
.2 .63 .79 r
.27306 .08012 m
.27306 .33552 L
.27342 .33552 L
.27342 .08012 L
s
.678 .847 .902 r
.27342 .08012 m
.27342 .33495 L
.27403 .33495 L
.27403 .08012 L
F
.2 .63 .79 r
.27342 .08012 m
.27342 .33495 L
.27403 .33495 L
.27403 .08012 L
s
.678 .847 .902 r
.27403 .08012 m
.27403 .33463 L
.27463 .33463 L
.27463 .08012 L
F
.2 .63 .79 r
.27403 .08012 m
.27403 .33463 L
.27463 .33463 L
.27463 .08012 L
s
.678 .847 .902 r
.27463 .08012 m
.27463 .33374 L
.27516 .33374 L
.27516 .08012 L
F
.2 .63 .79 r
.27463 .08012 m
.27463 .33374 L
.27516 .33374 L
.27516 .08012 L
s
.678 .847 .902 r
.27516 .08012 m
.27516 .33329 L
.27556 .33329 L
.27556 .08012 L
F
.2 .63 .79 r
.27516 .08012 m
.27516 .33329 L
.27556 .33329 L
.27556 .08012 L
s
.678 .847 .902 r
.27556 .08012 m
.27556 .33314 L
.27585 .33314 L
.27585 .08012 L
F
.2 .63 .79 r
.27556 .08012 m
.27556 .33314 L
.27585 .33314 L
.27585 .08012 L
s
.678 .847 .902 r
.27585 .08012 m
.27585 .33285 L
.2763 .33285 L
.2763 .08012 L
F
.2 .63 .79 r
.27585 .08012 m
.27585 .33285 L
.2763 .33285 L
.2763 .08012 L
s
.678 .847 .902 r
.2763 .08012 m
.2763 .33238 L
.27654 .33238 L
.27654 .08012 L
F
.2 .63 .79 r
.2763 .08012 m
.2763 .33238 L
.27654 .33238 L
.27654 .08012 L
s
.678 .847 .902 r
.27654 .08012 m
.27654 .33211 L
.27716 .33211 L
.27716 .08012 L
F
.2 .63 .79 r
.27654 .08012 m
.27654 .33211 L
.27716 .33211 L
.27716 .08012 L
s
.678 .847 .902 r
.27716 .08012 m
.27716 .33167 L
.27747 .33167 L
.27747 .08012 L
F
.2 .63 .79 r
.27716 .08012 m
.27716 .33167 L
.27747 .33167 L
.27747 .08012 L
s
.678 .847 .902 r
.27747 .08012 m
.27747 .33142 L
.27789 .33142 L
.27789 .08012 L
F
.2 .63 .79 r
.27747 .08012 m
.27747 .33142 L
.27789 .33142 L
.27789 .08012 L
s
.678 .847 .902 r
.27789 .08012 m
.27789 .33111 L
.27815 .33111 L
.27815 .08012 L
F
.2 .63 .79 r
.27789 .08012 m
.27789 .33111 L
.27815 .33111 L
.27815 .08012 L
s
.678 .847 .902 r
.27815 .08012 m
.27815 .33081 L
.2788 .33081 L
.2788 .08012 L
F
.2 .63 .79 r
.27815 .08012 m
.27815 .33081 L
.2788 .33081 L
.2788 .08012 L
s
.678 .847 .902 r
.2788 .08012 m
.2788 .33021 L
.27918 .33021 L
.27918 .08012 L
F
.2 .63 .79 r
.2788 .08012 m
.2788 .33021 L
.27918 .33021 L
.27918 .08012 L
s
.678 .847 .902 r
.27918 .08012 m
.27918 .32993 L
.27943 .32993 L
.27943 .08012 L
F
.2 .63 .79 r
.27918 .08012 m
.27918 .32993 L
.27943 .32993 L
.27943 .08012 L
s
.678 .847 .902 r
.27943 .08012 m
.27943 .32958 L
.27965 .32958 L
.27965 .08012 L
F
.2 .63 .79 r
.27943 .08012 m
.27943 .32958 L
.27965 .32958 L
.27965 .08012 L
s
.678 .847 .902 r
.27965 .08012 m
.27965 .32938 L
.27988 .32938 L
.27988 .08012 L
F
.2 .63 .79 r
.27965 .08012 m
.27965 .32938 L
.27988 .32938 L
.27988 .08012 L
s
.678 .847 .902 r
.27988 .08012 m
.27988 .3289 L
.2806 .3289 L
.2806 .08012 L
F
.2 .63 .79 r
.27988 .08012 m
.27988 .3289 L
.2806 .3289 L
.2806 .08012 L
s
.678 .847 .902 r
.2806 .08012 m
.2806 .32826 L
.28113 .32826 L
.28113 .08012 L
F
.2 .63 .79 r
.2806 .08012 m
.2806 .32826 L
.28113 .32826 L
.28113 .08012 L
s
.678 .847 .902 r
.28113 .08012 m
.28113 .32774 L
.28176 .32774 L
.28176 .08012 L
F
.2 .63 .79 r
.28113 .08012 m
.28113 .32774 L
.28176 .32774 L
.28176 .08012 L
s
.678 .847 .902 r
.28176 .08012 m
.28176 .32729 L
.28236 .32729 L
.28236 .08012 L
F
.2 .63 .79 r
.28176 .08012 m
.28176 .32729 L
.28236 .32729 L
.28236 .08012 L
s
.678 .847 .902 r
.28236 .08012 m
.28236 .3271 L
.2826 .3271 L
.2826 .08012 L
F
.2 .63 .79 r
.28236 .08012 m
.28236 .3271 L
.2826 .3271 L
.2826 .08012 L
s
.678 .847 .902 r
.2826 .08012 m
.2826 .32634 L
.28327 .32634 L
.28327 .08012 L
F
.2 .63 .79 r
.2826 .08012 m
.2826 .32634 L
.28327 .32634 L
.28327 .08012 L
s
.678 .847 .902 r
.28327 .08012 m
.28327 .32582 L
.28385 .32582 L
.28385 .08012 L
F
.2 .63 .79 r
.28327 .08012 m
.28327 .32582 L
.28385 .32582 L
.28385 .08012 L
s
.678 .847 .902 r
.28385 .08012 m
.28385 .32552 L
.28431 .32552 L
.28431 .08012 L
F
.2 .63 .79 r
.28385 .08012 m
.28385 .32552 L
.28431 .32552 L
.28431 .08012 L
s
.678 .847 .902 r
.28431 .08012 m
.28431 .32516 L
.28467 .32516 L
.28467 .08012 L
F
.2 .63 .79 r
.28431 .08012 m
.28431 .32516 L
.28467 .32516 L
.28467 .08012 L
s
.678 .847 .902 r
.28467 .08012 m
.28467 .32481 L
.28496 .32481 L
.28496 .08012 L
F
.2 .63 .79 r
.28467 .08012 m
.28467 .32481 L
.28496 .32481 L
.28496 .08012 L
s
.678 .847 .902 r
.28496 .08012 m
.28496 .32474 L
.28524 .32474 L
.28524 .08012 L
F
.2 .63 .79 r
.28496 .08012 m
.28496 .32474 L
.28524 .32474 L
.28524 .08012 L
s
.678 .847 .902 r
.28524 .08012 m
.28524 .32436 L
.28551 .32436 L
.28551 .08012 L
F
.2 .63 .79 r
.28524 .08012 m
.28524 .32436 L
.28551 .32436 L
.28551 .08012 L
s
.678 .847 .902 r
.28551 .08012 m
.28551 .32425 L
.28581 .32425 L
.28581 .08012 L
F
.2 .63 .79 r
.28551 .08012 m
.28551 .32425 L
.28581 .32425 L
.28581 .08012 L
s
.678 .847 .902 r
.28581 .08012 m
.28581 .32376 L
.28638 .32376 L
.28638 .08012 L
F
.2 .63 .79 r
.28581 .08012 m
.28581 .32376 L
.28638 .32376 L
.28638 .08012 L
s
.678 .847 .902 r
.28638 .08012 m
.28638 .32347 L
.28662 .32347 L
.28662 .08012 L
F
.2 .63 .79 r
.28638 .08012 m
.28638 .32347 L
.28662 .32347 L
.28662 .08012 L
s
.678 .847 .902 r
.28662 .08012 m
.28662 .32321 L
.28702 .32321 L
.28702 .08012 L
F
.2 .63 .79 r
.28662 .08012 m
.28662 .32321 L
.28702 .32321 L
.28702 .08012 L
s
.678 .847 .902 r
.28702 .08012 m
.28702 .32255 L
.28773 .32255 L
.28773 .08012 L
F
.2 .63 .79 r
.28702 .08012 m
.28702 .32255 L
.28773 .32255 L
.28773 .08012 L
s
.678 .847 .902 r
.28773 .08012 m
.28773 .32223 L
.2881 .32223 L
.2881 .08012 L
F
.2 .63 .79 r
.28773 .08012 m
.28773 .32223 L
.2881 .32223 L
.2881 .08012 L
s
.678 .847 .902 r
.2881 .08012 m
.2881 .32136 L
.28882 .32136 L
.28882 .08012 L
F
.2 .63 .79 r
.2881 .08012 m
.2881 .32136 L
.28882 .32136 L
.28882 .08012 L
s
.678 .847 .902 r
.28882 .08012 m
.28882 .32132 L
.28929 .32132 L
.28929 .08012 L
F
.2 .63 .79 r
.28882 .08012 m
.28882 .32132 L
.28929 .32132 L
.28929 .08012 L
s
.678 .847 .902 r
.28929 .08012 m
.28929 .32077 L
.28984 .32077 L
.28984 .08012 L
F
.2 .63 .79 r
.28929 .08012 m
.28929 .32077 L
.28984 .32077 L
.28984 .08012 L
s
.678 .847 .902 r
.28984 .08012 m
.28984 .32012 L
.29019 .32012 L
.29019 .08012 L
F
.2 .63 .79 r
.28984 .08012 m
.28984 .32012 L
.29019 .32012 L
.29019 .08012 L
s
.678 .847 .902 r
.29019 .08012 m
.29019 .32007 L
.29091 .32007 L
.29091 .08012 L
F
.2 .63 .79 r
.29019 .08012 m
.29019 .32007 L
.29091 .32007 L
.29091 .08012 L
s
.678 .847 .902 r
.29091 .08012 m
.29091 .31939 L
.29136 .31939 L
.29136 .08012 L
F
.2 .63 .79 r
.29091 .08012 m
.29091 .31939 L
.29136 .31939 L
.29136 .08012 L
s
.678 .847 .902 r
.29136 .08012 m
.29136 .31877 L
.29193 .31877 L
.29193 .08012 L
F
.2 .63 .79 r
.29136 .08012 m
.29136 .31877 L
.29193 .31877 L
.29193 .08012 L
s
.678 .847 .902 r
.29193 .08012 m
.29193 .31855 L
.29247 .31855 L
.29247 .08012 L
F
.2 .63 .79 r
.29193 .08012 m
.29193 .31855 L
.29247 .31855 L
.29247 .08012 L
s
.678 .847 .902 r
.29247 .08012 m
.29247 .31802 L
.29278 .31802 L
.29278 .08012 L
F
.2 .63 .79 r
.29247 .08012 m
.29247 .31802 L
.29278 .31802 L
.29278 .08012 L
s
.678 .847 .902 r
.29278 .08012 m
.29278 .31754 L
.29337 .31754 L
.29337 .08012 L
F
.2 .63 .79 r
.29278 .08012 m
.29278 .31754 L
.29337 .31754 L
.29337 .08012 L
s
.678 .847 .902 r
.29337 .08012 m
.29337 .31703 L
.29391 .31703 L
.29391 .08012 L
F
.2 .63 .79 r
.29337 .08012 m
.29337 .31703 L
.29391 .31703 L
.29391 .08012 L
s
.678 .847 .902 r
.29391 .08012 m
.29391 .31674 L
.29452 .31674 L
.29452 .08012 L
F
.2 .63 .79 r
.29391 .08012 m
.29391 .31674 L
.29452 .31674 L
.29452 .08012 L
s
.678 .847 .902 r
.29452 .08012 m
.29452 .31614 L
.29497 .31614 L
.29497 .08012 L
F
.2 .63 .79 r
.29452 .08012 m
.29452 .31614 L
.29497 .31614 L
.29497 .08012 L
s
.678 .847 .902 r
.29497 .08012 m
.29497 .31558 L
.29532 .31558 L
.29532 .08012 L
F
.2 .63 .79 r
.29497 .08012 m
.29497 .31558 L
.29532 .31558 L
.29532 .08012 L
s
.678 .847 .902 r
.29532 .08012 m
.29532 .31522 L
.29573 .31522 L
.29573 .08012 L
F
.2 .63 .79 r
.29532 .08012 m
.29532 .31522 L
.29573 .31522 L
.29573 .08012 L
s
.678 .847 .902 r
.29573 .08012 m
.29573 .31508 L
.29626 .31508 L
.29626 .08012 L
F
.2 .63 .79 r
.29573 .08012 m
.29573 .31508 L
.29626 .31508 L
.29626 .08012 L
s
.678 .847 .902 r
.29626 .08012 m
.29626 .31466 L
.29666 .31466 L
.29666 .08012 L
F
.2 .63 .79 r
.29626 .08012 m
.29626 .31466 L
.29666 .31466 L
.29666 .08012 L
s
.678 .847 .902 r
.29666 .08012 m
.29666 .31431 L
.29696 .31431 L
.29696 .08012 L
F
.2 .63 .79 r
.29666 .08012 m
.29666 .31431 L
.29696 .31431 L
.29696 .08012 L
s
.678 .847 .902 r
.29696 .08012 m
.29696 .31388 L
.29728 .31388 L
.29728 .08012 L
F
.2 .63 .79 r
.29696 .08012 m
.29696 .31388 L
.29728 .31388 L
.29728 .08012 L
s
.678 .847 .902 r
.29728 .08012 m
.29728 .31337 L
.29798 .31337 L
.29798 .08012 L
F
.2 .63 .79 r
.29728 .08012 m
.29728 .31337 L
.29798 .31337 L
.29798 .08012 L
s
.678 .847 .902 r
.29798 .08012 m
.29798 .3132 L
.29835 .3132 L
.29835 .08012 L
F
.2 .63 .79 r
.29798 .08012 m
.29798 .3132 L
.29835 .3132 L
.29835 .08012 L
s
.678 .847 .902 r
.29835 .08012 m
.29835 .31286 L
.29899 .31286 L
.29899 .08012 L
F
.2 .63 .79 r
.29835 .08012 m
.29835 .31286 L
.29899 .31286 L
.29899 .08012 L
s
.678 .847 .902 r
.29899 .08012 m
.29899 .31226 L
.29933 .31226 L
.29933 .08012 L
F
.2 .63 .79 r
.29899 .08012 m
.29899 .31226 L
.29933 .31226 L
.29933 .08012 L
s
.678 .847 .902 r
.29933 .08012 m
.29933 .31177 L
.29987 .31177 L
.29987 .08012 L
F
.2 .63 .79 r
.29933 .08012 m
.29933 .31177 L
.29987 .31177 L
.29987 .08012 L
s
.678 .847 .902 r
.29987 .08012 m
.29987 .31152 L
.30025 .31152 L
.30025 .08012 L
F
.2 .63 .79 r
.29987 .08012 m
.29987 .31152 L
.30025 .31152 L
.30025 .08012 L
s
.678 .847 .902 r
.30025 .08012 m
.30025 .3112 L
.30064 .3112 L
.30064 .08012 L
F
.2 .63 .79 r
.30025 .08012 m
.30025 .3112 L
.30064 .3112 L
.30064 .08012 L
s
.678 .847 .902 r
.30064 .08012 m
.30064 .31045 L
.30116 .31045 L
.30116 .08012 L
F
.2 .63 .79 r
.30064 .08012 m
.30064 .31045 L
.30116 .31045 L
.30116 .08012 L
s
.678 .847 .902 r
.30116 .08012 m
.30116 .3102 L
.30158 .3102 L
.30158 .08012 L
F
.2 .63 .79 r
.30116 .08012 m
.30116 .3102 L
.30158 .3102 L
.30158 .08012 L
s
.678 .847 .902 r
.30158 .08012 m
.30158 .31004 L
.30197 .31004 L
.30197 .08012 L
F
.2 .63 .79 r
.30158 .08012 m
.30158 .31004 L
.30197 .31004 L
.30197 .08012 L
s
.678 .847 .902 r
.30197 .08012 m
.30197 .30922 L
.30263 .30922 L
.30263 .08012 L
F
.2 .63 .79 r
.30197 .08012 m
.30197 .30922 L
.30263 .30922 L
.30263 .08012 L
s
.678 .847 .902 r
.30263 .08012 m
.30263 .30892 L
.30332 .30892 L
.30332 .08012 L
F
.2 .63 .79 r
.30263 .08012 m
.30263 .30892 L
.30332 .30892 L
.30332 .08012 L
s
.678 .847 .902 r
.30332 .08012 m
.30332 .30822 L
.30393 .30822 L
.30393 .08012 L
F
.2 .63 .79 r
.30332 .08012 m
.30332 .30822 L
.30393 .30822 L
.30393 .08012 L
s
.678 .847 .902 r
.30393 .08012 m
.30393 .30778 L
.30423 .30778 L
.30423 .08012 L
F
.2 .63 .79 r
.30393 .08012 m
.30393 .30778 L
.30423 .30778 L
.30423 .08012 L
s
.678 .847 .902 r
.30423 .08012 m
.30423 .30765 L
.30452 .30765 L
.30452 .08012 L
F
.2 .63 .79 r
.30423 .08012 m
.30423 .30765 L
.30452 .30765 L
.30452 .08012 L
s
.678 .847 .902 r
.30452 .08012 m
.30452 .30721 L
.30488 .30721 L
.30488 .08012 L
F
.2 .63 .79 r
.30452 .08012 m
.30452 .30721 L
.30488 .30721 L
.30488 .08012 L
s
.678 .847 .902 r
.30488 .08012 m
.30488 .30707 L
.30511 .30707 L
.30511 .08012 L
F
.2 .63 .79 r
.30488 .08012 m
.30488 .30707 L
.30511 .30707 L
.30511 .08012 L
s
.678 .847 .902 r
.30511 .08012 m
.30511 .30671 L
.30568 .30671 L
.30568 .08012 L
F
.2 .63 .79 r
.30511 .08012 m
.30511 .30671 L
.30568 .30671 L
.30568 .08012 L
s
.678 .847 .902 r
.30568 .08012 m
.30568 .30621 L
.30635 .30621 L
.30635 .08012 L
F
.2 .63 .79 r
.30568 .08012 m
.30568 .30621 L
.30635 .30621 L
.30635 .08012 L
s
.678 .847 .902 r
.30635 .08012 m
.30635 .30532 L
.30705 .30532 L
.30705 .08012 L
F
.2 .63 .79 r
.30635 .08012 m
.30635 .30532 L
.30705 .30532 L
.30705 .08012 L
s
.678 .847 .902 r
.30705 .08012 m
.30705 .30519 L
.30747 .30519 L
.30747 .08012 L
F
.2 .63 .79 r
.30705 .08012 m
.30705 .30519 L
.30747 .30519 L
.30747 .08012 L
s
.678 .847 .902 r
.30747 .08012 m
.30747 .30479 L
.30786 .30479 L
.30786 .08012 L
F
.2 .63 .79 r
.30747 .08012 m
.30747 .30479 L
.30786 .30479 L
.30786 .08012 L
s
.678 .847 .902 r
.30786 .08012 m
.30786 .30447 L
.30846 .30447 L
.30846 .08012 L
F
.2 .63 .79 r
.30786 .08012 m
.30786 .30447 L
.30846 .30447 L
.30846 .08012 L
s
.678 .847 .902 r
.30846 .08012 m
.30846 .30399 L
.30904 .30399 L
.30904 .08012 L
F
.2 .63 .79 r
.30846 .08012 m
.30846 .30399 L
.30904 .30399 L
.30904 .08012 L
s
.678 .847 .902 r
.30904 .08012 m
.30904 .30335 L
.3095 .30335 L
.3095 .08012 L
F
.2 .63 .79 r
.30904 .08012 m
.30904 .30335 L
.3095 .30335 L
.3095 .08012 L
s
.678 .847 .902 r
.3095 .08012 m
.3095 .30308 L
.30974 .30308 L
.30974 .08012 L
F
.2 .63 .79 r
.3095 .08012 m
.3095 .30308 L
.30974 .30308 L
.30974 .08012 L
s
.678 .847 .902 r
.30974 .08012 m
.30974 .30284 L
.31043 .30284 L
.31043 .08012 L
F
.2 .63 .79 r
.30974 .08012 m
.30974 .30284 L
.31043 .30284 L
.31043 .08012 L
s
.678 .847 .902 r
.31043 .08012 m
.31043 .30198 L
.3109 .30198 L
.3109 .08012 L
F
.2 .63 .79 r
.31043 .08012 m
.31043 .30198 L
.3109 .30198 L
.3109 .08012 L
s
.678 .847 .902 r
.3109 .08012 m
.3109 .3014 L
.31154 .3014 L
.31154 .08012 L
F
.2 .63 .79 r
.3109 .08012 m
.3109 .3014 L
.31154 .3014 L
.31154 .08012 L
s
.678 .847 .902 r
.31154 .08012 m
.31154 .30125 L
.31213 .30125 L
.31213 .08012 L
F
.2 .63 .79 r
.31154 .08012 m
.31154 .30125 L
.31213 .30125 L
.31213 .08012 L
s
.678 .847 .902 r
.31213 .08012 m
.31213 .30081 L
.31266 .30081 L
.31266 .08012 L
F
.2 .63 .79 r
.31213 .08012 m
.31213 .30081 L
.31266 .30081 L
.31266 .08012 L
s
.678 .847 .902 r
.31266 .08012 m
.31266 .29985 L
.31333 .29985 L
.31333 .08012 L
F
.2 .63 .79 r
.31266 .08012 m
.31266 .29985 L
.31333 .29985 L
.31333 .08012 L
s
.678 .847 .902 r
.31333 .08012 m
.31333 .2997 L
.31377 .2997 L
.31377 .08012 L
F
.2 .63 .79 r
.31333 .08012 m
.31333 .2997 L
.31377 .2997 L
.31377 .08012 L
s
.678 .847 .902 r
.31377 .08012 m
.31377 .29937 L
.31419 .29937 L
.31419 .08012 L
F
.2 .63 .79 r
.31377 .08012 m
.31377 .29937 L
.31419 .29937 L
.31419 .08012 L
s
.678 .847 .902 r
.31419 .08012 m
.31419 .29894 L
.31479 .29894 L
.31479 .08012 L
F
.2 .63 .79 r
.31419 .08012 m
.31419 .29894 L
.31479 .29894 L
.31479 .08012 L
s
.678 .847 .902 r
.31479 .08012 m
.31479 .2982 L
.31551 .2982 L
.31551 .08012 L
F
.2 .63 .79 r
.31479 .08012 m
.31479 .2982 L
.31551 .2982 L
.31551 .08012 L
s
.678 .847 .902 r
.31551 .08012 m
.31551 .29758 L
.31607 .29758 L
.31607 .08012 L
F
.2 .63 .79 r
.31551 .08012 m
.31551 .29758 L
.31607 .29758 L
.31607 .08012 L
s
.678 .847 .902 r
.31607 .08012 m
.31607 .29736 L
.31641 .29736 L
.31641 .08012 L
F
.2 .63 .79 r
.31607 .08012 m
.31607 .29736 L
.31641 .29736 L
.31641 .08012 L
s
.678 .847 .902 r
.31641 .08012 m
.31641 .29676 L
.31693 .29676 L
.31693 .08012 L
F
.2 .63 .79 r
.31641 .08012 m
.31641 .29676 L
.31693 .29676 L
.31693 .08012 L
s
.678 .847 .902 r
.31693 .08012 m
.31693 .29636 L
.31751 .29636 L
.31751 .08012 L
F
.2 .63 .79 r
.31693 .08012 m
.31693 .29636 L
.31751 .29636 L
.31751 .08012 L
s
.678 .847 .902 r
.31751 .08012 m
.31751 .2961 L
.31806 .2961 L
.31806 .08012 L
F
.2 .63 .79 r
.31751 .08012 m
.31751 .2961 L
.31806 .2961 L
.31806 .08012 L
s
.678 .847 .902 r
.31806 .08012 m
.31806 .29539 L
.31855 .29539 L
.31855 .08012 L
F
.2 .63 .79 r
.31806 .08012 m
.31806 .29539 L
.31855 .29539 L
.31855 .08012 L
s
.678 .847 .902 r
.31855 .08012 m
.31855 .29509 L
.31914 .29509 L
.31914 .08012 L
F
.2 .63 .79 r
.31855 .08012 m
.31855 .29509 L
.31914 .29509 L
.31914 .08012 L
s
.678 .847 .902 r
.31914 .08012 m
.31914 .29441 L
.31976 .29441 L
.31976 .08012 L
F
.2 .63 .79 r
.31914 .08012 m
.31914 .29441 L
.31976 .29441 L
.31976 .08012 L
s
.678 .847 .902 r
.31976 .08012 m
.31976 .29431 L
.32011 .29431 L
.32011 .08012 L
F
.2 .63 .79 r
.31976 .08012 m
.31976 .29431 L
.32011 .29431 L
.32011 .08012 L
s
.678 .847 .902 r
.32011 .08012 m
.32011 .29389 L
.32042 .29389 L
.32042 .08012 L
F
.2 .63 .79 r
.32011 .08012 m
.32011 .29389 L
.32042 .29389 L
.32042 .08012 L
s
.678 .847 .902 r
.32042 .08012 m
.32042 .29356 L
.32115 .29356 L
.32115 .08012 L
F
.2 .63 .79 r
.32042 .08012 m
.32042 .29356 L
.32115 .29356 L
.32115 .08012 L
s
.678 .847 .902 r
.32115 .08012 m
.32115 .293 L
.3214 .293 L
.3214 .08012 L
F
.2 .63 .79 r
.32115 .08012 m
.32115 .293 L
.3214 .293 L
.3214 .08012 L
s
.678 .847 .902 r
.3214 .08012 m
.3214 .29263 L
.32202 .29263 L
.32202 .08012 L
F
.2 .63 .79 r
.3214 .08012 m
.3214 .29263 L
.32202 .29263 L
.32202 .08012 L
s
.678 .847 .902 r
.32202 .08012 m
.32202 .29235 L
.32231 .29235 L
.32231 .08012 L
F
.2 .63 .79 r
.32202 .08012 m
.32202 .29235 L
.32231 .29235 L
.32231 .08012 L
s
.678 .847 .902 r
.32231 .08012 m
.32231 .29213 L
.32257 .29213 L
.32257 .08012 L
F
.2 .63 .79 r
.32231 .08012 m
.32231 .29213 L
.32257 .29213 L
.32257 .08012 L
s
.678 .847 .902 r
.32257 .08012 m
.32257 .29159 L
.32308 .29159 L
.32308 .08012 L
F
.2 .63 .79 r
.32257 .08012 m
.32257 .29159 L
.32308 .29159 L
.32308 .08012 L
s
.678 .847 .902 r
.32308 .08012 m
.32308 .29114 L
.3238 .29114 L
.3238 .08012 L
F
.2 .63 .79 r
.32308 .08012 m
.32308 .29114 L
.3238 .29114 L
.3238 .08012 L
s
.678 .847 .902 r
.3238 .08012 m
.3238 .29056 L
.32423 .29056 L
.32423 .08012 L
F
.2 .63 .79 r
.3238 .08012 m
.3238 .29056 L
.32423 .29056 L
.32423 .08012 L
s
.678 .847 .902 r
.32423 .08012 m
.32423 .29054 L
.32469 .29054 L
.32469 .08012 L
F
.2 .63 .79 r
.32423 .08012 m
.32423 .29054 L
.32469 .29054 L
.32469 .08012 L
s
.678 .847 .902 r
.32469 .08012 m
.32469 .28975 L
.32526 .28975 L
.32526 .08012 L
F
.2 .63 .79 r
.32469 .08012 m
.32469 .28975 L
.32526 .28975 L
.32526 .08012 L
s
.678 .847 .902 r
.32526 .08012 m
.32526 .28958 L
.32576 .28958 L
.32576 .08012 L
F
.2 .63 .79 r
.32526 .08012 m
.32526 .28958 L
.32576 .28958 L
.32576 .08012 L
s
.678 .847 .902 r
.32576 .08012 m
.32576 .28912 L
.32598 .28912 L
.32598 .08012 L
F
.2 .63 .79 r
.32576 .08012 m
.32576 .28912 L
.32598 .28912 L
.32598 .08012 L
s
.678 .847 .902 r
.32598 .08012 m
.32598 .28871 L
.32658 .28871 L
.32658 .08012 L
F
.2 .63 .79 r
.32598 .08012 m
.32598 .28871 L
.32658 .28871 L
.32658 .08012 L
s
.678 .847 .902 r
.32658 .08012 m
.32658 .28846 L
.32716 .28846 L
.32716 .08012 L
F
.2 .63 .79 r
.32658 .08012 m
.32658 .28846 L
.32716 .28846 L
.32716 .08012 L
s
.678 .847 .902 r
.32716 .08012 m
.32716 .28784 L
.32783 .28784 L
.32783 .08012 L
F
.2 .63 .79 r
.32716 .08012 m
.32716 .28784 L
.32783 .28784 L
.32783 .08012 L
s
.678 .847 .902 r
.32783 .08012 m
.32783 .28738 L
.32845 .28738 L
.32845 .08012 L
F
.2 .63 .79 r
.32783 .08012 m
.32783 .28738 L
.32845 .28738 L
.32845 .08012 L
s
.678 .847 .902 r
.32845 .08012 m
.32845 .28681 L
.32874 .28681 L
.32874 .08012 L
F
.2 .63 .79 r
.32845 .08012 m
.32845 .28681 L
.32874 .28681 L
.32874 .08012 L
s
.678 .847 .902 r
.32874 .08012 m
.32874 .28667 L
.32896 .28667 L
.32896 .08012 L
F
.2 .63 .79 r
.32874 .08012 m
.32874 .28667 L
.32896 .28667 L
.32896 .08012 L
s
.678 .847 .902 r
.32896 .08012 m
.32896 .28654 L
.3293 .28654 L
.3293 .08012 L
F
.2 .63 .79 r
.32896 .08012 m
.32896 .28654 L
.3293 .28654 L
.3293 .08012 L
s
.678 .847 .902 r
.3293 .08012 m
.3293 .28619 L
.32965 .28619 L
.32965 .08012 L
F
.2 .63 .79 r
.3293 .08012 m
.3293 .28619 L
.32965 .28619 L
.32965 .08012 L
s
.678 .847 .902 r
.32965 .08012 m
.32965 .28592 L
.33008 .28592 L
.33008 .08012 L
F
.2 .63 .79 r
.32965 .08012 m
.32965 .28592 L
.33008 .28592 L
.33008 .08012 L
s
.678 .847 .902 r
.33008 .08012 m
.33008 .28547 L
.33042 .28547 L
.33042 .08012 L
F
.2 .63 .79 r
.33008 .08012 m
.33008 .28547 L
.33042 .28547 L
.33042 .08012 L
s
.678 .847 .902 r
.33042 .08012 m
.33042 .28476 L
.33113 .28476 L
.33113 .08012 L
F
.2 .63 .79 r
.33042 .08012 m
.33042 .28476 L
.33113 .28476 L
.33113 .08012 L
s
.678 .847 .902 r
.33113 .08012 m
.33113 .28459 L
.33139 .28459 L
.33139 .08012 L
F
.2 .63 .79 r
.33113 .08012 m
.33113 .28459 L
.33139 .28459 L
.33139 .08012 L
s
.678 .847 .902 r
.33139 .08012 m
.33139 .28423 L
.33182 .28423 L
.33182 .08012 L
F
.2 .63 .79 r
.33139 .08012 m
.33139 .28423 L
.33182 .28423 L
.33182 .08012 L
s
.678 .847 .902 r
.33182 .08012 m
.33182 .28395 L
.33213 .28395 L
.33213 .08012 L
F
.2 .63 .79 r
.33182 .08012 m
.33182 .28395 L
.33213 .28395 L
.33213 .08012 L
s
.678 .847 .902 r
.33213 .08012 m
.33213 .28381 L
.33244 .28381 L
.33244 .08012 L
F
.2 .63 .79 r
.33213 .08012 m
.33213 .28381 L
.33244 .28381 L
.33244 .08012 L
s
.678 .847 .902 r
.33244 .08012 m
.33244 .28338 L
.33313 .28338 L
.33313 .08012 L
F
.2 .63 .79 r
.33244 .08012 m
.33244 .28338 L
.33313 .28338 L
.33313 .08012 L
s
.678 .847 .902 r
.33313 .08012 m
.33313 .28285 L
.33352 .28285 L
.33352 .08012 L
F
.2 .63 .79 r
.33313 .08012 m
.33313 .28285 L
.33352 .28285 L
.33352 .08012 L
s
.678 .847 .902 r
.33352 .08012 m
.33352 .2823 L
.33406 .2823 L
.33406 .08012 L
F
.2 .63 .79 r
.33352 .08012 m
.33352 .2823 L
.33406 .2823 L
.33406 .08012 L
s
.678 .847 .902 r
.33406 .08012 m
.33406 .28209 L
.33439 .28209 L
.33439 .08012 L
F
.2 .63 .79 r
.33406 .08012 m
.33406 .28209 L
.33439 .28209 L
.33439 .08012 L
s
.678 .847 .902 r
.33439 .08012 m
.33439 .28183 L
.33487 .28183 L
.33487 .08012 L
F
.2 .63 .79 r
.33439 .08012 m
.33439 .28183 L
.33487 .28183 L
.33487 .08012 L
s
.678 .847 .902 r
.33487 .08012 m
.33487 .28127 L
.33552 .28127 L
.33552 .08012 L
F
.2 .63 .79 r
.33487 .08012 m
.33487 .28127 L
.33552 .28127 L
.33552 .08012 L
s
.678 .847 .902 r
.33552 .08012 m
.33552 .28099 L
.33623 .28099 L
.33623 .08012 L
F
.2 .63 .79 r
.33552 .08012 m
.33552 .28099 L
.33623 .28099 L
.33623 .08012 L
s
.678 .847 .902 r
.33623 .08012 m
.33623 .28025 L
.33678 .28025 L
.33678 .08012 L
F
.2 .63 .79 r
.33623 .08012 m
.33623 .28025 L
.33678 .28025 L
.33678 .08012 L
s
.678 .847 .902 r
.33678 .08012 m
.33678 .27972 L
.33726 .27972 L
.33726 .08012 L
F
.2 .63 .79 r
.33678 .08012 m
.33678 .27972 L
.33726 .27972 L
.33726 .08012 L
s
.678 .847 .902 r
.33726 .08012 m
.33726 .27942 L
.33754 .27942 L
.33754 .08012 L
F
.2 .63 .79 r
.33726 .08012 m
.33726 .27942 L
.33754 .27942 L
.33754 .08012 L
s
.678 .847 .902 r
.33754 .08012 m
.33754 .27913 L
.33788 .27913 L
.33788 .08012 L
F
.2 .63 .79 r
.33754 .08012 m
.33754 .27913 L
.33788 .27913 L
.33788 .08012 L
s
.678 .847 .902 r
.33788 .08012 m
.33788 .27907 L
.3385 .27907 L
.3385 .08012 L
F
.2 .63 .79 r
.33788 .08012 m
.33788 .27907 L
.3385 .27907 L
.3385 .08012 L
s
.678 .847 .902 r
.3385 .08012 m
.3385 .27835 L
.33909 .27835 L
.33909 .08012 L
F
.2 .63 .79 r
.3385 .08012 m
.3385 .27835 L
.33909 .27835 L
.33909 .08012 L
s
.678 .847 .902 r
.33909 .08012 m
.33909 .278 L
.3398 .278 L
.3398 .08012 L
F
.2 .63 .79 r
.33909 .08012 m
.33909 .278 L
.3398 .278 L
.3398 .08012 L
s
.678 .847 .902 r
.3398 .08012 m
.3398 .27738 L
.34014 .27738 L
.34014 .08012 L
F
.2 .63 .79 r
.3398 .08012 m
.3398 .27738 L
.34014 .27738 L
.34014 .08012 L
s
.678 .847 .902 r
.34014 .08012 m
.34014 .27724 L
.34065 .27724 L
.34065 .08012 L
F
.2 .63 .79 r
.34014 .08012 m
.34014 .27724 L
.34065 .27724 L
.34065 .08012 L
s
.678 .847 .902 r
.34065 .08012 m
.34065 .27674 L
.3411 .27674 L
.3411 .08012 L
F
.2 .63 .79 r
.34065 .08012 m
.34065 .27674 L
.3411 .27674 L
.3411 .08012 L
s
.678 .847 .902 r
.3411 .08012 m
.3411 .27644 L
.34161 .27644 L
.34161 .08012 L
F
.2 .63 .79 r
.3411 .08012 m
.3411 .27644 L
.34161 .27644 L
.34161 .08012 L
s
.678 .847 .902 r
.34161 .08012 m
.34161 .27544 L
.34234 .27544 L
.34234 .08012 L
F
.2 .63 .79 r
.34161 .08012 m
.34161 .27544 L
.34234 .27544 L
.34234 .08012 L
s
.678 .847 .902 r
.34234 .08012 m
.34234 .27541 L
.34286 .27541 L
.34286 .08012 L
F
.2 .63 .79 r
.34234 .08012 m
.34234 .27541 L
.34286 .27541 L
.34286 .08012 L
s
.678 .847 .902 r
.34286 .08012 m
.34286 .27482 L
.34329 .27482 L
.34329 .08012 L
F
.2 .63 .79 r
.34286 .08012 m
.34286 .27482 L
.34329 .27482 L
.34329 .08012 L
s
.678 .847 .902 r
.34329 .08012 m
.34329 .27461 L
.34358 .27461 L
.34358 .08012 L
F
.2 .63 .79 r
.34329 .08012 m
.34329 .27461 L
.34358 .27461 L
.34358 .08012 L
s
.678 .847 .902 r
.34358 .08012 m
.34358 .27431 L
.34421 .27431 L
.34421 .08012 L
F
.2 .63 .79 r
.34358 .08012 m
.34358 .27431 L
.34421 .27431 L
.34421 .08012 L
s
.678 .847 .902 r
.34421 .08012 m
.34421 .27365 L
.34464 .27365 L
.34464 .08012 L
F
.2 .63 .79 r
.34421 .08012 m
.34421 .27365 L
.34464 .27365 L
.34464 .08012 L
s
.678 .847 .902 r
.34464 .08012 m
.34464 .27351 L
.34511 .27351 L
.34511 .08012 L
F
.2 .63 .79 r
.34464 .08012 m
.34464 .27351 L
.34511 .27351 L
.34511 .08012 L
s
.678 .847 .902 r
.34511 .08012 m
.34511 .27288 L
.34575 .27288 L
.34575 .08012 L
F
.2 .63 .79 r
.34511 .08012 m
.34511 .27288 L
.34575 .27288 L
.34575 .08012 L
s
.678 .847 .902 r
.34575 .08012 m
.34575 .27258 L
.34606 .27258 L
.34606 .08012 L
F
.2 .63 .79 r
.34575 .08012 m
.34575 .27258 L
.34606 .27258 L
.34606 .08012 L
s
.678 .847 .902 r
.34606 .08012 m
.34606 .27213 L
.34638 .27213 L
.34638 .08012 L
F
.2 .63 .79 r
.34606 .08012 m
.34606 .27213 L
.34638 .27213 L
.34638 .08012 L
s
.678 .847 .902 r
.34638 .08012 m
.34638 .27176 L
.3471 .27176 L
.3471 .08012 L
F
.2 .63 .79 r
.34638 .08012 m
.34638 .27176 L
.3471 .27176 L
.3471 .08012 L
s
.678 .847 .902 r
.3471 .08012 m
.3471 .27101 L
.34781 .27101 L
.34781 .08012 L
F
.2 .63 .79 r
.3471 .08012 m
.3471 .27101 L
.34781 .27101 L
.34781 .08012 L
s
.678 .847 .902 r
.34781 .08012 m
.34781 .27093 L
.34815 .27093 L
.34815 .08012 L
F
.2 .63 .79 r
.34781 .08012 m
.34781 .27093 L
.34815 .27093 L
.34815 .08012 L
s
.678 .847 .902 r
.34815 .08012 m
.34815 .2705 L
.34865 .2705 L
.34865 .08012 L
F
.2 .63 .79 r
.34815 .08012 m
.34815 .2705 L
.34865 .2705 L
.34865 .08012 L
s
.678 .847 .902 r
.34865 .08012 m
.34865 .26995 L
.34911 .26995 L
.34911 .08012 L
F
.2 .63 .79 r
.34865 .08012 m
.34865 .26995 L
.34911 .26995 L
.34911 .08012 L
s
.678 .847 .902 r
.34911 .08012 m
.34911 .26938 L
.34977 .26938 L
.34977 .08012 L
F
.2 .63 .79 r
.34911 .08012 m
.34911 .26938 L
.34977 .26938 L
.34977 .08012 L
s
.678 .847 .902 r
.34977 .08012 m
.34977 .26928 L
.35048 .26928 L
.35048 .08012 L
F
.2 .63 .79 r
.34977 .08012 m
.34977 .26928 L
.35048 .26928 L
.35048 .08012 L
s
.678 .847 .902 r
.35048 .08012 m
.35048 .2686 L
.3511 .2686 L
.3511 .08012 L
F
.2 .63 .79 r
.35048 .08012 m
.35048 .2686 L
.3511 .2686 L
.3511 .08012 L
s
.678 .847 .902 r
.3511 .08012 m
.3511 .26812 L
.35171 .26812 L
.35171 .08012 L
F
.2 .63 .79 r
.3511 .08012 m
.3511 .26812 L
.35171 .26812 L
.35171 .08012 L
s
.678 .847 .902 r
.35171 .08012 m
.35171 .26737 L
.35237 .26737 L
.35237 .08012 L
F
.2 .63 .79 r
.35171 .08012 m
.35171 .26737 L
.35237 .26737 L
.35237 .08012 L
s
.678 .847 .902 r
.35237 .08012 m
.35237 .26695 L
.35297 .26695 L
.35297 .08012 L
F
.2 .63 .79 r
.35237 .08012 m
.35237 .26695 L
.35297 .26695 L
.35297 .08012 L
s
.678 .847 .902 r
.35297 .08012 m
.35297 .26667 L
.35331 .26667 L
.35331 .08012 L
F
.2 .63 .79 r
.35297 .08012 m
.35297 .26667 L
.35331 .26667 L
.35331 .08012 L
s
.678 .847 .902 r
.35331 .08012 m
.35331 .26647 L
.35367 .26647 L
.35367 .08012 L
F
.2 .63 .79 r
.35331 .08012 m
.35331 .26647 L
.35367 .26647 L
.35367 .08012 L
s
.678 .847 .902 r
.35367 .08012 m
.35367 .26597 L
.35405 .26597 L
.35405 .08012 L
F
.2 .63 .79 r
.35367 .08012 m
.35367 .26597 L
.35405 .26597 L
.35405 .08012 L
s
.678 .847 .902 r
.35405 .08012 m
.35405 .26559 L
.35465 .26559 L
.35465 .08012 L
F
.2 .63 .79 r
.35405 .08012 m
.35405 .26559 L
.35465 .26559 L
.35465 .08012 L
s
.678 .847 .902 r
.35465 .08012 m
.35465 .26528 L
.3552 .26528 L
.3552 .08012 L
F
.2 .63 .79 r
.35465 .08012 m
.35465 .26528 L
.3552 .26528 L
.3552 .08012 L
s
.678 .847 .902 r
.3552 .08012 m
.3552 .26466 L
.35587 .26466 L
.35587 .08012 L
F
.2 .63 .79 r
.3552 .08012 m
.3552 .26466 L
.35587 .26466 L
.35587 .08012 L
s
.678 .847 .902 r
.35587 .08012 m
.35587 .26429 L
.35617 .26429 L
.35617 .08012 L
F
.2 .63 .79 r
.35587 .08012 m
.35587 .26429 L
.35617 .26429 L
.35617 .08012 L
s
.678 .847 .902 r
.35617 .08012 m
.35617 .26395 L
.35687 .26395 L
.35687 .08012 L
F
.2 .63 .79 r
.35617 .08012 m
.35617 .26395 L
.35687 .26395 L
.35687 .08012 L
s
.678 .847 .902 r
.35687 .08012 m
.35687 .26345 L
.35721 .26345 L
.35721 .08012 L
F
.2 .63 .79 r
.35687 .08012 m
.35687 .26345 L
.35721 .26345 L
.35721 .08012 L
s
.678 .847 .902 r
.35721 .08012 m
.35721 .26319 L
.35763 .26319 L
.35763 .08012 L
F
.2 .63 .79 r
.35721 .08012 m
.35721 .26319 L
.35763 .26319 L
.35763 .08012 L
s
.678 .847 .902 r
.35763 .08012 m
.35763 .263 L
.35802 .263 L
.35802 .08012 L
F
.2 .63 .79 r
.35763 .08012 m
.35763 .263 L
.35802 .263 L
.35802 .08012 L
s
.678 .847 .902 r
.35802 .08012 m
.35802 .2626 L
.35864 .2626 L
.35864 .08012 L
F
.2 .63 .79 r
.35802 .08012 m
.35802 .2626 L
.35864 .2626 L
.35864 .08012 L
s
.678 .847 .902 r
.35864 .08012 m
.35864 .26208 L
.35887 .26208 L
.35887 .08012 L
F
.2 .63 .79 r
.35864 .08012 m
.35864 .26208 L
.35887 .26208 L
.35887 .08012 L
s
.678 .847 .902 r
.35887 .08012 m
.35887 .26171 L
.35931 .26171 L
.35931 .08012 L
F
.2 .63 .79 r
.35887 .08012 m
.35887 .26171 L
.35931 .26171 L
.35931 .08012 L
s
.678 .847 .902 r
.35931 .08012 m
.35931 .26163 L
.35971 .26163 L
.35971 .08012 L
F
.2 .63 .79 r
.35931 .08012 m
.35931 .26163 L
.35971 .26163 L
.35971 .08012 L
s
.678 .847 .902 r
.35971 .08012 m
.35971 .26129 L
.36022 .26129 L
.36022 .08012 L
F
.2 .63 .79 r
.35971 .08012 m
.35971 .26129 L
.36022 .26129 L
.36022 .08012 L
s
.678 .847 .902 r
.36022 .08012 m
.36022 .26086 L
.36068 .26086 L
.36068 .08012 L
F
.2 .63 .79 r
.36022 .08012 m
.36022 .26086 L
.36068 .26086 L
.36068 .08012 L
s
.678 .847 .902 r
.36068 .08012 m
.36068 .26056 L
.36138 .26056 L
.36138 .08012 L
F
.2 .63 .79 r
.36068 .08012 m
.36068 .26056 L
.36138 .26056 L
.36138 .08012 L
s
.678 .847 .902 r
.36138 .08012 m
.36138 .25995 L
.36187 .25995 L
.36187 .08012 L
F
.2 .63 .79 r
.36138 .08012 m
.36138 .25995 L
.36187 .25995 L
.36187 .08012 L
s
.678 .847 .902 r
.36187 .08012 m
.36187 .25922 L
.36238 .25922 L
.36238 .08012 L
F
.2 .63 .79 r
.36187 .08012 m
.36187 .25922 L
.36238 .25922 L
.36238 .08012 L
s
.678 .847 .902 r
.36238 .08012 m
.36238 .25882 L
.36296 .25882 L
.36296 .08012 L
F
.2 .63 .79 r
.36238 .08012 m
.36238 .25882 L
.36296 .25882 L
.36296 .08012 L
s
.678 .847 .902 r
.36296 .08012 m
.36296 .25857 L
.36328 .25857 L
.36328 .08012 L
F
.2 .63 .79 r
.36296 .08012 m
.36296 .25857 L
.36328 .25857 L
.36328 .08012 L
s
.678 .847 .902 r
.36328 .08012 m
.36328 .25834 L
.36382 .25834 L
.36382 .08012 L
F
.2 .63 .79 r
.36328 .08012 m
.36328 .25834 L
.36382 .25834 L
.36382 .08012 L
s
.678 .847 .902 r
.36382 .08012 m
.36382 .25788 L
.36447 .25788 L
.36447 .08012 L
F
.2 .63 .79 r
.36382 .08012 m
.36382 .25788 L
.36447 .25788 L
.36447 .08012 L
s
.678 .847 .902 r
.36447 .08012 m
.36447 .25736 L
.36493 .25736 L
.36493 .08012 L
F
.2 .63 .79 r
.36447 .08012 m
.36447 .25736 L
.36493 .25736 L
.36493 .08012 L
s
.678 .847 .902 r
.36493 .08012 m
.36493 .25685 L
.36562 .25685 L
.36562 .08012 L
F
.2 .63 .79 r
.36493 .08012 m
.36493 .25685 L
.36562 .25685 L
.36562 .08012 L
s
.678 .847 .902 r
.36562 .08012 m
.36562 .25645 L
.366 .25645 L
.366 .08012 L
F
.2 .63 .79 r
.36562 .08012 m
.36562 .25645 L
.366 .25645 L
.366 .08012 L
s
.678 .847 .902 r
.366 .08012 m
.366 .25617 L
.36627 .25617 L
.36627 .08012 L
F
.2 .63 .79 r
.366 .08012 m
.366 .25617 L
.36627 .25617 L
.36627 .08012 L
s
.678 .847 .902 r
.36627 .08012 m
.36627 .25601 L
.36691 .25601 L
.36691 .08012 L
F
.2 .63 .79 r
.36627 .08012 m
.36627 .25601 L
.36691 .25601 L
.36691 .08012 L
s
.678 .847 .902 r
.36691 .08012 m
.36691 .25561 L
.36715 .25561 L
.36715 .08012 L
F
.2 .63 .79 r
.36691 .08012 m
.36691 .25561 L
.36715 .25561 L
.36715 .08012 L
s
.678 .847 .902 r
.36715 .08012 m
.36715 .25541 L
.36746 .25541 L
.36746 .08012 L
F
.2 .63 .79 r
.36715 .08012 m
.36715 .25541 L
.36746 .25541 L
.36746 .08012 L
s
.678 .847 .902 r
.36746 .08012 m
.36746 .25511 L
.36775 .25511 L
.36775 .08012 L
F
.2 .63 .79 r
.36746 .08012 m
.36746 .25511 L
.36775 .25511 L
.36775 .08012 L
s
.678 .847 .902 r
.36775 .08012 m
.36775 .2547 L
.36827 .2547 L
.36827 .08012 L
F
.2 .63 .79 r
.36775 .08012 m
.36775 .2547 L
.36827 .2547 L
.36827 .08012 L
s
.678 .847 .902 r
.36827 .08012 m
.36827 .25429 L
.36882 .25429 L
.36882 .08012 L
F
.2 .63 .79 r
.36827 .08012 m
.36827 .25429 L
.36882 .25429 L
.36882 .08012 L
s
.678 .847 .902 r
.36882 .08012 m
.36882 .25409 L
.36946 .25409 L
.36946 .08012 L
F
.2 .63 .79 r
.36882 .08012 m
.36882 .25409 L
.36946 .25409 L
.36946 .08012 L
s
.678 .847 .902 r
.36946 .08012 m
.36946 .25356 L
.36987 .25356 L
.36987 .08012 L
F
.2 .63 .79 r
.36946 .08012 m
.36946 .25356 L
.36987 .25356 L
.36987 .08012 L
s
.678 .847 .902 r
.36987 .08012 m
.36987 .25289 L
.37038 .25289 L
.37038 .08012 L
F
.2 .63 .79 r
.36987 .08012 m
.36987 .25289 L
.37038 .25289 L
.37038 .08012 L
s
.678 .847 .902 r
.37038 .08012 m
.37038 .25269 L
.37072 .25269 L
.37072 .08012 L
F
.2 .63 .79 r
.37038 .08012 m
.37038 .25269 L
.37072 .25269 L
.37072 .08012 L
s
.678 .847 .902 r
.37072 .08012 m
.37072 .25229 L
.37117 .25229 L
.37117 .08012 L
F
.2 .63 .79 r
.37072 .08012 m
.37072 .25229 L
.37117 .25229 L
.37117 .08012 L
s
.678 .847 .902 r
.37117 .08012 m
.37117 .25225 L
.37181 .25225 L
.37181 .08012 L
F
.2 .63 .79 r
.37117 .08012 m
.37117 .25225 L
.37181 .25225 L
.37181 .08012 L
s
.678 .847 .902 r
.37181 .08012 m
.37181 .2516 L
.37208 .2516 L
.37208 .08012 L
F
.2 .63 .79 r
.37181 .08012 m
.37181 .2516 L
.37208 .2516 L
.37208 .08012 L
s
.678 .847 .902 r
.37208 .08012 m
.37208 .25135 L
.37243 .25135 L
.37243 .08012 L
F
.2 .63 .79 r
.37208 .08012 m
.37208 .25135 L
.37243 .25135 L
.37243 .08012 L
s
.678 .847 .902 r
.37243 .08012 m
.37243 .25084 L
.37314 .25084 L
.37314 .08012 L
F
.2 .63 .79 r
.37243 .08012 m
.37243 .25084 L
.37314 .25084 L
.37314 .08012 L
s
.678 .847 .902 r
.37314 .08012 m
.37314 .2507 L
.37348 .2507 L
.37348 .08012 L
F
.2 .63 .79 r
.37314 .08012 m
.37314 .2507 L
.37348 .2507 L
.37348 .08012 L
s
.678 .847 .902 r
.37348 .08012 m
.37348 .25014 L
.3739 .25014 L
.3739 .08012 L
F
.2 .63 .79 r
.37348 .08012 m
.37348 .25014 L
.3739 .25014 L
.3739 .08012 L
s
.678 .847 .902 r
.3739 .08012 m
.3739 .25012 L
.37416 .25012 L
.37416 .08012 L
F
.2 .63 .79 r
.3739 .08012 m
.3739 .25012 L
.37416 .25012 L
.37416 .08012 L
s
.678 .847 .902 r
.37416 .08012 m
.37416 .24979 L
.37454 .24979 L
.37454 .08012 L
F
.2 .63 .79 r
.37416 .08012 m
.37416 .24979 L
.37454 .24979 L
.37454 .08012 L
s
.678 .847 .902 r
.37454 .08012 m
.37454 .24939 L
.37496 .24939 L
.37496 .08012 L
F
.2 .63 .79 r
.37454 .08012 m
.37454 .24939 L
.37496 .24939 L
.37496 .08012 L
s
.678 .847 .902 r
.37496 .08012 m
.37496 .24907 L
.37566 .24907 L
.37566 .08012 L
F
.2 .63 .79 r
.37496 .08012 m
.37496 .24907 L
.37566 .24907 L
.37566 .08012 L
s
.678 .847 .902 r
.37566 .08012 m
.37566 .24865 L
.37596 .24865 L
.37596 .08012 L
F
.2 .63 .79 r
.37566 .08012 m
.37566 .24865 L
.37596 .24865 L
.37596 .08012 L
s
.678 .847 .902 r
.37596 .08012 m
.37596 .24806 L
.37668 .24806 L
.37668 .08012 L
F
.2 .63 .79 r
.37596 .08012 m
.37596 .24806 L
.37668 .24806 L
.37668 .08012 L
s
.678 .847 .902 r
.37668 .08012 m
.37668 .24767 L
.37705 .24767 L
.37705 .08012 L
F
.2 .63 .79 r
.37668 .08012 m
.37668 .24767 L
.37705 .24767 L
.37705 .08012 L
s
.678 .847 .902 r
.37705 .08012 m
.37705 .24762 L
.37733 .24762 L
.37733 .08012 L
F
.2 .63 .79 r
.37705 .08012 m
.37705 .24762 L
.37733 .24762 L
.37733 .08012 L
s
.678 .847 .902 r
.37733 .08012 m
.37733 .24737 L
.37761 .24737 L
.37761 .08012 L
F
.2 .63 .79 r
.37733 .08012 m
.37733 .24737 L
.37761 .24737 L
.37761 .08012 L
s
.678 .847 .902 r
.37761 .08012 m
.37761 .24686 L
.37825 .24686 L
.37825 .08012 L
F
.2 .63 .79 r
.37761 .08012 m
.37761 .24686 L
.37825 .24686 L
.37825 .08012 L
s
.678 .847 .902 r
.37825 .08012 m
.37825 .24659 L
.37855 .24659 L
.37855 .08012 L
F
.2 .63 .79 r
.37825 .08012 m
.37825 .24659 L
.37855 .24659 L
.37855 .08012 L
s
.678 .847 .902 r
.37855 .08012 m
.37855 .24628 L
.37904 .24628 L
.37904 .08012 L
F
.2 .63 .79 r
.37855 .08012 m
.37855 .24628 L
.37904 .24628 L
.37904 .08012 L
s
.678 .847 .902 r
.37904 .08012 m
.37904 .24584 L
.3795 .24584 L
.3795 .08012 L
F
.2 .63 .79 r
.37904 .08012 m
.37904 .24584 L
.3795 .24584 L
.3795 .08012 L
s
.678 .847 .902 r
.3795 .08012 m
.3795 .24536 L
.38022 .24536 L
.38022 .08012 L
F
.2 .63 .79 r
.3795 .08012 m
.3795 .24536 L
.38022 .24536 L
.38022 .08012 L
s
.678 .847 .902 r
.38022 .08012 m
.38022 .24497 L
.38084 .24497 L
.38084 .08012 L
F
.2 .63 .79 r
.38022 .08012 m
.38022 .24497 L
.38084 .24497 L
.38084 .08012 L
s
.678 .847 .902 r
.38084 .08012 m
.38084 .24438 L
.38155 .24438 L
.38155 .08012 L
F
.2 .63 .79 r
.38084 .08012 m
.38084 .24438 L
.38155 .24438 L
.38155 .08012 L
s
.678 .847 .902 r
.38155 .08012 m
.38155 .24415 L
.3819 .24415 L
.3819 .08012 L
F
.2 .63 .79 r
.38155 .08012 m
.38155 .24415 L
.3819 .24415 L
.3819 .08012 L
s
.678 .847 .902 r
.3819 .08012 m
.3819 .2436 L
.38239 .2436 L
.38239 .08012 L
F
.2 .63 .79 r
.3819 .08012 m
.3819 .2436 L
.38239 .2436 L
.38239 .08012 L
s
.678 .847 .902 r
.38239 .08012 m
.38239 .24327 L
.3831 .24327 L
.3831 .08012 L
F
.2 .63 .79 r
.38239 .08012 m
.38239 .24327 L
.3831 .24327 L
.3831 .08012 L
s
.678 .847 .902 r
.3831 .08012 m
.3831 .24254 L
.38376 .24254 L
.38376 .08012 L
F
.2 .63 .79 r
.3831 .08012 m
.3831 .24254 L
.38376 .24254 L
.38376 .08012 L
s
.678 .847 .902 r
.38376 .08012 m
.38376 .24226 L
.38449 .24226 L
.38449 .08012 L
F
.2 .63 .79 r
.38376 .08012 m
.38376 .24226 L
.38449 .24226 L
.38449 .08012 L
s
.678 .847 .902 r
.38449 .08012 m
.38449 .24191 L
.385 .24191 L
.385 .08012 L
F
.2 .63 .79 r
.38449 .08012 m
.38449 .24191 L
.385 .24191 L
.385 .08012 L
s
.678 .847 .902 r
.385 .08012 m
.385 .24133 L
.3856 .24133 L
.3856 .08012 L
F
.2 .63 .79 r
.385 .08012 m
.385 .24133 L
.3856 .24133 L
.3856 .08012 L
s
.678 .847 .902 r
.3856 .08012 m
.3856 .24074 L
.38605 .24074 L
.38605 .08012 L
F
.2 .63 .79 r
.3856 .08012 m
.3856 .24074 L
.38605 .24074 L
.38605 .08012 L
s
.678 .847 .902 r
.38605 .08012 m
.38605 .24051 L
.38674 .24051 L
.38674 .08012 L
F
.2 .63 .79 r
.38605 .08012 m
.38605 .24051 L
.38674 .24051 L
.38674 .08012 L
s
.678 .847 .902 r
.38674 .08012 m
.38674 .24002 L
.38709 .24002 L
.38709 .08012 L
F
.2 .63 .79 r
.38674 .08012 m
.38674 .24002 L
.38709 .24002 L
.38709 .08012 L
s
.678 .847 .902 r
.38709 .08012 m
.38709 .2397 L
.38749 .2397 L
.38749 .08012 L
F
.2 .63 .79 r
.38709 .08012 m
.38709 .2397 L
.38749 .2397 L
.38749 .08012 L
s
.678 .847 .902 r
.38749 .08012 m
.38749 .23942 L
.38797 .23942 L
.38797 .08012 L
F
.2 .63 .79 r
.38749 .08012 m
.38749 .23942 L
.38797 .23942 L
.38797 .08012 L
s
.678 .847 .902 r
.38797 .08012 m
.38797 .23879 L
.38858 .23879 L
.38858 .08012 L
F
.2 .63 .79 r
.38797 .08012 m
.38797 .23879 L
.38858 .23879 L
.38858 .08012 L
s
.678 .847 .902 r
.38858 .08012 m
.38858 .23856 L
.38894 .23856 L
.38894 .08012 L
F
.2 .63 .79 r
.38858 .08012 m
.38858 .23856 L
.38894 .23856 L
.38894 .08012 L
s
.678 .847 .902 r
.38894 .08012 m
.38894 .23837 L
.38918 .23837 L
.38918 .08012 L
F
.2 .63 .79 r
.38894 .08012 m
.38894 .23837 L
.38918 .23837 L
.38918 .08012 L
s
.678 .847 .902 r
.38918 .08012 m
.38918 .23822 L
.3896 .23822 L
.3896 .08012 L
F
.2 .63 .79 r
.38918 .08012 m
.38918 .23822 L
.3896 .23822 L
.3896 .08012 L
s
.678 .847 .902 r
.3896 .08012 m
.3896 .23774 L
.39015 .23774 L
.39015 .08012 L
F
.2 .63 .79 r
.3896 .08012 m
.3896 .23774 L
.39015 .23774 L
.39015 .08012 L
s
.678 .847 .902 r
.39015 .08012 m
.39015 .23756 L
.39061 .23756 L
.39061 .08012 L
F
.2 .63 .79 r
.39015 .08012 m
.39015 .23756 L
.39061 .23756 L
.39061 .08012 L
s
.678 .847 .902 r
.39061 .08012 m
.39061 .23717 L
.39129 .23717 L
.39129 .08012 L
F
.2 .63 .79 r
.39061 .08012 m
.39061 .23717 L
.39129 .23717 L
.39129 .08012 L
s
.678 .847 .902 r
.39129 .08012 m
.39129 .23635 L
.39195 .23635 L
.39195 .08012 L
F
.2 .63 .79 r
.39129 .08012 m
.39129 .23635 L
.39195 .23635 L
.39195 .08012 L
s
.678 .847 .902 r
.39195 .08012 m
.39195 .23603 L
.39225 .23603 L
.39225 .08012 L
F
.2 .63 .79 r
.39195 .08012 m
.39195 .23603 L
.39225 .23603 L
.39225 .08012 L
s
.678 .847 .902 r
.39225 .08012 m
.39225 .23587 L
.39271 .23587 L
.39271 .08012 L
F
.2 .63 .79 r
.39225 .08012 m
.39225 .23587 L
.39271 .23587 L
.39271 .08012 L
s
.678 .847 .902 r
.39271 .08012 m
.39271 .23551 L
.39299 .23551 L
.39299 .08012 L
F
.2 .63 .79 r
.39271 .08012 m
.39271 .23551 L
.39299 .23551 L
.39299 .08012 L
s
.678 .847 .902 r
.39299 .08012 m
.39299 .23536 L
.39367 .23536 L
.39367 .08012 L
F
.2 .63 .79 r
.39299 .08012 m
.39299 .23536 L
.39367 .23536 L
.39367 .08012 L
s
.678 .847 .902 r
.39367 .08012 m
.39367 .23452 L
.39436 .23452 L
.39436 .08012 L
F
.2 .63 .79 r
.39367 .08012 m
.39367 .23452 L
.39436 .23452 L
.39436 .08012 L
s
.678 .847 .902 r
.39436 .08012 m
.39436 .2341 L
.39506 .2341 L
.39506 .08012 L
F
.2 .63 .79 r
.39436 .08012 m
.39436 .2341 L
.39506 .2341 L
.39506 .08012 L
s
.678 .847 .902 r
.39506 .08012 m
.39506 .23383 L
.39537 .23383 L
.39537 .08012 L
F
.2 .63 .79 r
.39506 .08012 m
.39506 .23383 L
.39537 .23383 L
.39537 .08012 L
s
.678 .847 .902 r
.39537 .08012 m
.39537 .23359 L
.3956 .23359 L
.3956 .08012 L
F
.2 .63 .79 r
.39537 .08012 m
.39537 .23359 L
.3956 .23359 L
.3956 .08012 L
s
.678 .847 .902 r
.3956 .08012 m
.3956 .23326 L
.3963 .23326 L
.3963 .08012 L
F
.2 .63 .79 r
.3956 .08012 m
.3956 .23326 L
.3963 .23326 L
.3963 .08012 L
s
.678 .847 .902 r
.3963 .08012 m
.3963 .23277 L
.3967 .23277 L
.3967 .08012 L
F
.2 .63 .79 r
.3963 .08012 m
.3963 .23277 L
.3967 .23277 L
.3967 .08012 L
s
.678 .847 .902 r
.3967 .08012 m
.3967 .23238 L
.39715 .23238 L
.39715 .08012 L
F
.2 .63 .79 r
.3967 .08012 m
.3967 .23238 L
.39715 .23238 L
.39715 .08012 L
s
.678 .847 .902 r
.39715 .08012 m
.39715 .23218 L
.39766 .23218 L
.39766 .08012 L
F
.2 .63 .79 r
.39715 .08012 m
.39715 .23218 L
.39766 .23218 L
.39766 .08012 L
s
.678 .847 .902 r
.39766 .08012 m
.39766 .23175 L
.39789 .23175 L
.39789 .08012 L
F
.2 .63 .79 r
.39766 .08012 m
.39766 .23175 L
.39789 .23175 L
.39789 .08012 L
s
.678 .847 .902 r
.39789 .08012 m
.39789 .23156 L
.39815 .23156 L
.39815 .08012 L
F
.2 .63 .79 r
.39789 .08012 m
.39789 .23156 L
.39815 .23156 L
.39815 .08012 L
s
.678 .847 .902 r
.39815 .08012 m
.39815 .23153 L
.39843 .23153 L
.39843 .08012 L
F
.2 .63 .79 r
.39815 .08012 m
.39815 .23153 L
.39843 .23153 L
.39843 .08012 L
s
.678 .847 .902 r
.39843 .08012 m
.39843 .23119 L
.39867 .23119 L
.39867 .08012 L
F
.2 .63 .79 r
.39843 .08012 m
.39843 .23119 L
.39867 .23119 L
.39867 .08012 L
s
.678 .847 .902 r
.39867 .08012 m
.39867 .23089 L
.39902 .23089 L
.39902 .08012 L
F
.2 .63 .79 r
.39867 .08012 m
.39867 .23089 L
.39902 .23089 L
.39902 .08012 L
s
.678 .847 .902 r
.39902 .08012 m
.39902 .23084 L
.39966 .23084 L
.39966 .08012 L
F
.2 .63 .79 r
.39902 .08012 m
.39902 .23084 L
.39966 .23084 L
.39966 .08012 L
s
.678 .847 .902 r
.39966 .08012 m
.39966 .23036 L
.39991 .23036 L
.39991 .08012 L
F
.2 .63 .79 r
.39966 .08012 m
.39966 .23036 L
.39991 .23036 L
.39991 .08012 L
s
.678 .847 .902 r
.39991 .08012 m
.39991 .23004 L
.40047 .23004 L
.40047 .08012 L
F
.2 .63 .79 r
.39991 .08012 m
.39991 .23004 L
.40047 .23004 L
.40047 .08012 L
s
.678 .847 .902 r
.40047 .08012 m
.40047 .22966 L
.401 .22966 L
.401 .08012 L
F
.2 .63 .79 r
.40047 .08012 m
.40047 .22966 L
.401 .22966 L
.401 .08012 L
s
.678 .847 .902 r
.401 .08012 m
.401 .2294 L
.4014 .2294 L
.4014 .08012 L
F
.2 .63 .79 r
.401 .08012 m
.401 .2294 L
.4014 .2294 L
.4014 .08012 L
s
.678 .847 .902 r
.4014 .08012 m
.4014 .22908 L
.4017 .22908 L
.4017 .08012 L
F
.2 .63 .79 r
.4014 .08012 m
.4014 .22908 L
.4017 .22908 L
.4017 .08012 L
s
.678 .847 .902 r
.4017 .08012 m
.4017 .22857 L
.40233 .22857 L
.40233 .08012 L
F
.2 .63 .79 r
.4017 .08012 m
.4017 .22857 L
.40233 .22857 L
.40233 .08012 L
s
.678 .847 .902 r
.40233 .08012 m
.40233 .22824 L
.40278 .22824 L
.40278 .08012 L
F
.2 .63 .79 r
.40233 .08012 m
.40233 .22824 L
.40278 .22824 L
.40278 .08012 L
s
.678 .847 .902 r
.40278 .08012 m
.40278 .22776 L
.40344 .22776 L
.40344 .08012 L
F
.2 .63 .79 r
.40278 .08012 m
.40278 .22776 L
.40344 .22776 L
.40344 .08012 L
s
.678 .847 .902 r
.40344 .08012 m
.40344 .2275 L
.40368 .2275 L
.40368 .08012 L
F
.2 .63 .79 r
.40344 .08012 m
.40344 .2275 L
.40368 .2275 L
.40368 .08012 L
s
.678 .847 .902 r
.40368 .08012 m
.40368 .22713 L
.40436 .22713 L
.40436 .08012 L
F
.2 .63 .79 r
.40368 .08012 m
.40368 .22713 L
.40436 .22713 L
.40436 .08012 L
s
.678 .847 .902 r
.40436 .08012 m
.40436 .22662 L
.40486 .22662 L
.40486 .08012 L
F
.2 .63 .79 r
.40436 .08012 m
.40436 .22662 L
.40486 .22662 L
.40486 .08012 L
s
.678 .847 .902 r
.40486 .08012 m
.40486 .22649 L
.40555 .22649 L
.40555 .08012 L
F
.2 .63 .79 r
.40486 .08012 m
.40486 .22649 L
.40555 .22649 L
.40555 .08012 L
s
.678 .847 .902 r
.40555 .08012 m
.40555 .22587 L
.40622 .22587 L
.40622 .08012 L
F
.2 .63 .79 r
.40555 .08012 m
.40555 .22587 L
.40622 .22587 L
.40622 .08012 L
s
.678 .847 .902 r
.40622 .08012 m
.40622 .22539 L
.40688 .22539 L
.40688 .08012 L
F
.2 .63 .79 r
.40622 .08012 m
.40622 .22539 L
.40688 .22539 L
.40688 .08012 L
s
.678 .847 .902 r
.40688 .08012 m
.40688 .22489 L
.40742 .22489 L
.40742 .08012 L
F
.2 .63 .79 r
.40688 .08012 m
.40688 .22489 L
.40742 .22489 L
.40742 .08012 L
s
.678 .847 .902 r
.40742 .08012 m
.40742 .22444 L
.40792 .22444 L
.40792 .08012 L
F
.2 .63 .79 r
.40742 .08012 m
.40742 .22444 L
.40792 .22444 L
.40792 .08012 L
s
.678 .847 .902 r
.40792 .08012 m
.40792 .22409 L
.40837 .22409 L
.40837 .08012 L
F
.2 .63 .79 r
.40792 .08012 m
.40792 .22409 L
.40837 .22409 L
.40837 .08012 L
s
.678 .847 .902 r
.40837 .08012 m
.40837 .22368 L
.40873 .22368 L
.40873 .08012 L
F
.2 .63 .79 r
.40837 .08012 m
.40837 .22368 L
.40873 .22368 L
.40873 .08012 L
s
.678 .847 .902 r
.40873 .08012 m
.40873 .22352 L
.40927 .22352 L
.40927 .08012 L
F
.2 .63 .79 r
.40873 .08012 m
.40873 .22352 L
.40927 .22352 L
.40927 .08012 L
s
.678 .847 .902 r
.40927 .08012 m
.40927 .22307 L
.40972 .22307 L
.40972 .08012 L
F
.2 .63 .79 r
.40927 .08012 m
.40927 .22307 L
.40972 .22307 L
.40972 .08012 L
s
.678 .847 .902 r
.40972 .08012 m
.40972 .2228 L
.41011 .2228 L
.41011 .08012 L
F
.2 .63 .79 r
.40972 .08012 m
.40972 .2228 L
.41011 .2228 L
.41011 .08012 L
s
.678 .847 .902 r
.41011 .08012 m
.41011 .22262 L
.41045 .22262 L
.41045 .08012 L
F
.2 .63 .79 r
.41011 .08012 m
.41011 .22262 L
.41045 .22262 L
.41045 .08012 L
s
.678 .847 .902 r
.41045 .08012 m
.41045 .2223 L
.41085 .2223 L
.41085 .08012 L
F
.2 .63 .79 r
.41045 .08012 m
.41045 .2223 L
.41085 .2223 L
.41085 .08012 L
s
.678 .847 .902 r
.41085 .08012 m
.41085 .22191 L
.4114 .22191 L
.4114 .08012 L
F
.2 .63 .79 r
.41085 .08012 m
.41085 .22191 L
.4114 .22191 L
.4114 .08012 L
s
.678 .847 .902 r
.4114 .08012 m
.4114 .22165 L
.41176 .22165 L
.41176 .08012 L
F
.2 .63 .79 r
.4114 .08012 m
.4114 .22165 L
.41176 .22165 L
.41176 .08012 L
s
.678 .847 .902 r
.41176 .08012 m
.41176 .22117 L
.41227 .22117 L
.41227 .08012 L
F
.2 .63 .79 r
.41176 .08012 m
.41176 .22117 L
.41227 .22117 L
.41227 .08012 L
s
.678 .847 .902 r
.41227 .08012 m
.41227 .22107 L
.41287 .22107 L
.41287 .08012 L
F
.2 .63 .79 r
.41227 .08012 m
.41227 .22107 L
.41287 .22107 L
.41287 .08012 L
s
.678 .847 .902 r
.41287 .08012 m
.41287 .22051 L
.41324 .22051 L
.41324 .08012 L
F
.2 .63 .79 r
.41287 .08012 m
.41287 .22051 L
.41324 .22051 L
.41324 .08012 L
s
.678 .847 .902 r
.41324 .08012 m
.41324 .22035 L
.41352 .22035 L
.41352 .08012 L
F
.2 .63 .79 r
.41324 .08012 m
.41324 .22035 L
.41352 .22035 L
.41352 .08012 L
s
.678 .847 .902 r
.41352 .08012 m
.41352 .22014 L
.41413 .22014 L
.41413 .08012 L
F
.2 .63 .79 r
.41352 .08012 m
.41352 .22014 L
.41413 .22014 L
.41413 .08012 L
s
.678 .847 .902 r
.41413 .08012 m
.41413 .21959 L
.41449 .21959 L
.41449 .08012 L
F
.2 .63 .79 r
.41413 .08012 m
.41413 .21959 L
.41449 .21959 L
.41449 .08012 L
s
.678 .847 .902 r
.41449 .08012 m
.41449 .21918 L
.41493 .21918 L
.41493 .08012 L
F
.2 .63 .79 r
.41449 .08012 m
.41449 .21918 L
.41493 .21918 L
.41493 .08012 L
s
.678 .847 .902 r
.41493 .08012 m
.41493 .21902 L
.41519 .21902 L
.41519 .08012 L
F
.2 .63 .79 r
.41493 .08012 m
.41493 .21902 L
.41519 .21902 L
.41519 .08012 L
s
.678 .847 .902 r
.41519 .08012 m
.41519 .2187 L
.41586 .2187 L
.41586 .08012 L
F
.2 .63 .79 r
.41519 .08012 m
.41519 .2187 L
.41586 .2187 L
.41586 .08012 L
s
.678 .847 .902 r
.41586 .08012 m
.41586 .21814 L
.41645 .21814 L
.41645 .08012 L
F
.2 .63 .79 r
.41586 .08012 m
.41586 .21814 L
.41645 .21814 L
.41645 .08012 L
s
.678 .847 .902 r
.41645 .08012 m
.41645 .21777 L
.41694 .21777 L
.41694 .08012 L
F
.2 .63 .79 r
.41645 .08012 m
.41645 .21777 L
.41694 .21777 L
.41694 .08012 L
s
.678 .847 .902 r
.41694 .08012 m
.41694 .21761 L
.41726 .21761 L
.41726 .08012 L
F
.2 .63 .79 r
.41694 .08012 m
.41694 .21761 L
.41726 .21761 L
.41726 .08012 L
s
.678 .847 .902 r
.41726 .08012 m
.41726 .21741 L
.41748 .21741 L
.41748 .08012 L
F
.2 .63 .79 r
.41726 .08012 m
.41726 .21741 L
.41748 .21741 L
.41748 .08012 L
s
.678 .847 .902 r
.41748 .08012 m
.41748 .21721 L
.41775 .21721 L
.41775 .08012 L
F
.2 .63 .79 r
.41748 .08012 m
.41748 .21721 L
.41775 .21721 L
.41775 .08012 L
s
.678 .847 .902 r
.41775 .08012 m
.41775 .21699 L
.41847 .21699 L
.41847 .08012 L
F
.2 .63 .79 r
.41775 .08012 m
.41775 .21699 L
.41847 .21699 L
.41847 .08012 L
s
.678 .847 .902 r
.41847 .08012 m
.41847 .21624 L
.41908 .21624 L
.41908 .08012 L
F
.2 .63 .79 r
.41847 .08012 m
.41847 .21624 L
.41908 .21624 L
.41908 .08012 L
s
.678 .847 .902 r
.41908 .08012 m
.41908 .21603 L
.41967 .21603 L
.41967 .08012 L
F
.2 .63 .79 r
.41908 .08012 m
.41908 .21603 L
.41967 .21603 L
.41967 .08012 L
s
.678 .847 .902 r
.41967 .08012 m
.41967 .21538 L
.42013 .21538 L
.42013 .08012 L
F
.2 .63 .79 r
.41967 .08012 m
.41967 .21538 L
.42013 .21538 L
.42013 .08012 L
s
.678 .847 .902 r
.42013 .08012 m
.42013 .21517 L
.42062 .21517 L
.42062 .08012 L
F
.2 .63 .79 r
.42013 .08012 m
.42013 .21517 L
.42062 .21517 L
.42062 .08012 L
s
.678 .847 .902 r
.42062 .08012 m
.42062 .21495 L
.42105 .21495 L
.42105 .08012 L
F
.2 .63 .79 r
.42062 .08012 m
.42062 .21495 L
.42105 .21495 L
.42105 .08012 L
s
.678 .847 .902 r
.42105 .08012 m
.42105 .21469 L
.42152 .21469 L
.42152 .08012 L
F
.2 .63 .79 r
.42105 .08012 m
.42105 .21469 L
.42152 .21469 L
.42152 .08012 L
s
.678 .847 .902 r
.42152 .08012 m
.42152 .21425 L
.42181 .21425 L
.42181 .08012 L
F
.2 .63 .79 r
.42152 .08012 m
.42152 .21425 L
.42181 .21425 L
.42181 .08012 L
s
.678 .847 .902 r
.42181 .08012 m
.42181 .21416 L
.42248 .21416 L
.42248 .08012 L
F
.2 .63 .79 r
.42181 .08012 m
.42181 .21416 L
.42248 .21416 L
.42248 .08012 L
s
.678 .847 .902 r
.42248 .08012 m
.42248 .21348 L
.42277 .21348 L
.42277 .08012 L
F
.2 .63 .79 r
.42248 .08012 m
.42248 .21348 L
.42277 .21348 L
.42277 .08012 L
s
.678 .847 .902 r
.42277 .08012 m
.42277 .21333 L
.42346 .21333 L
.42346 .08012 L
F
.2 .63 .79 r
.42277 .08012 m
.42277 .21333 L
.42346 .21333 L
.42346 .08012 L
s
.678 .847 .902 r
.42346 .08012 m
.42346 .21282 L
.42388 .21282 L
.42388 .08012 L
F
.2 .63 .79 r
.42346 .08012 m
.42346 .21282 L
.42388 .21282 L
.42388 .08012 L
s
.678 .847 .902 r
.42388 .08012 m
.42388 .21249 L
.4244 .21249 L
.4244 .08012 L
F
.2 .63 .79 r
.42388 .08012 m
.42388 .21249 L
.4244 .21249 L
.4244 .08012 L
s
.678 .847 .902 r
.4244 .08012 m
.4244 .21217 L
.42463 .21217 L
.42463 .08012 L
F
.2 .63 .79 r
.4244 .08012 m
.4244 .21217 L
.42463 .21217 L
.42463 .08012 L
s
.678 .847 .902 r
.42463 .08012 m
.42463 .21209 L
.42492 .21209 L
.42492 .08012 L
F
.2 .63 .79 r
.42463 .08012 m
.42463 .21209 L
.42492 .21209 L
.42492 .08012 L
s
.678 .847 .902 r
.42492 .08012 m
.42492 .21192 L
.4252 .21192 L
.4252 .08012 L
F
.2 .63 .79 r
.42492 .08012 m
.42492 .21192 L
.4252 .21192 L
.4252 .08012 L
s
.678 .847 .902 r
.4252 .08012 m
.4252 .21159 L
.4255 .21159 L
.4255 .08012 L
F
.2 .63 .79 r
.4252 .08012 m
.4252 .21159 L
.4255 .21159 L
.4255 .08012 L
s
.678 .847 .902 r
.4255 .08012 m
.4255 .21143 L
.4262 .21143 L
.4262 .08012 L
F
.2 .63 .79 r
.4255 .08012 m
.4255 .21143 L
.4262 .21143 L
.4262 .08012 L
s
.678 .847 .902 r
.4262 .08012 m
.4262 .21083 L
.42656 .21083 L
.42656 .08012 L
F
.2 .63 .79 r
.4262 .08012 m
.4262 .21083 L
.42656 .21083 L
.42656 .08012 L
s
.678 .847 .902 r
.42656 .08012 m
.42656 .21068 L
.42698 .21068 L
.42698 .08012 L
F
.2 .63 .79 r
.42656 .08012 m
.42656 .21068 L
.42698 .21068 L
.42698 .08012 L
s
.678 .847 .902 r
.42698 .08012 m
.42698 .21011 L
.42752 .21011 L
.42752 .08012 L
F
.2 .63 .79 r
.42698 .08012 m
.42698 .21011 L
.42752 .21011 L
.42752 .08012 L
s
.678 .847 .902 r
.42752 .08012 m
.42752 .2097 L
.42812 .2097 L
.42812 .08012 L
F
.2 .63 .79 r
.42752 .08012 m
.42752 .2097 L
.42812 .2097 L
.42812 .08012 L
s
.678 .847 .902 r
.42812 .08012 m
.42812 .20951 L
.42847 .20951 L
.42847 .08012 L
F
.2 .63 .79 r
.42812 .08012 m
.42812 .20951 L
.42847 .20951 L
.42847 .08012 L
s
.678 .847 .902 r
.42847 .08012 m
.42847 .20916 L
.42884 .20916 L
.42884 .08012 L
F
.2 .63 .79 r
.42847 .08012 m
.42847 .20916 L
.42884 .20916 L
.42884 .08012 L
s
.678 .847 .902 r
.42884 .08012 m
.42884 .20885 L
.4294 .20885 L
.4294 .08012 L
F
.2 .63 .79 r
.42884 .08012 m
.42884 .20885 L
.4294 .20885 L
.4294 .08012 L
s
.678 .847 .902 r
.4294 .08012 m
.4294 .20868 L
.43013 .20868 L
.43013 .08012 L
F
.2 .63 .79 r
.4294 .08012 m
.4294 .20868 L
.43013 .20868 L
.43013 .08012 L
s
.678 .847 .902 r
.43013 .08012 m
.43013 .20812 L
.43061 .20812 L
.43061 .08012 L
F
.2 .63 .79 r
.43013 .08012 m
.43013 .20812 L
.43061 .20812 L
.43061 .08012 L
s
.678 .847 .902 r
.43061 .08012 m
.43061 .20745 L
.43125 .20745 L
.43125 .08012 L
F
.2 .63 .79 r
.43061 .08012 m
.43061 .20745 L
.43125 .20745 L
.43125 .08012 L
s
.678 .847 .902 r
.43125 .08012 m
.43125 .20739 L
.43154 .20739 L
.43154 .08012 L
F
.2 .63 .79 r
.43125 .08012 m
.43125 .20739 L
.43154 .20739 L
.43154 .08012 L
s
.678 .847 .902 r
.43154 .08012 m
.43154 .20689 L
.43205 .20689 L
.43205 .08012 L
F
.2 .63 .79 r
.43154 .08012 m
.43154 .20689 L
.43205 .20689 L
.43205 .08012 L
s
.678 .847 .902 r
.43205 .08012 m
.43205 .20682 L
.43229 .20682 L
.43229 .08012 L
F
.2 .63 .79 r
.43205 .08012 m
.43205 .20682 L
.43229 .20682 L
.43229 .08012 L
s
.678 .847 .902 r
.43229 .08012 m
.43229 .20653 L
.43286 .20653 L
.43286 .08012 L
F
.2 .63 .79 r
.43229 .08012 m
.43229 .20653 L
.43286 .20653 L
.43286 .08012 L
s
.678 .847 .902 r
.43286 .08012 m
.43286 .20625 L
.43321 .20625 L
.43321 .08012 L
F
.2 .63 .79 r
.43286 .08012 m
.43286 .20625 L
.43321 .20625 L
.43321 .08012 L
s
.678 .847 .902 r
.43321 .08012 m
.43321 .20574 L
.43365 .20574 L
.43365 .08012 L
F
.2 .63 .79 r
.43321 .08012 m
.43321 .20574 L
.43365 .20574 L
.43365 .08012 L
s
.678 .847 .902 r
.43365 .08012 m
.43365 .20554 L
.43393 .20554 L
.43393 .08012 L
F
.2 .63 .79 r
.43365 .08012 m
.43365 .20554 L
.43393 .20554 L
.43393 .08012 L
s
.678 .847 .902 r
.43393 .08012 m
.43393 .20531 L
.43429 .20531 L
.43429 .08012 L
F
.2 .63 .79 r
.43393 .08012 m
.43393 .20531 L
.43429 .20531 L
.43429 .08012 L
s
.678 .847 .902 r
.43429 .08012 m
.43429 .20501 L
.43486 .20501 L
.43486 .08012 L
F
.2 .63 .79 r
.43429 .08012 m
.43429 .20501 L
.43486 .20501 L
.43486 .08012 L
s
.678 .847 .902 r
.43486 .08012 m
.43486 .20484 L
.43529 .20484 L
.43529 .08012 L
F
.2 .63 .79 r
.43486 .08012 m
.43486 .20484 L
.43529 .20484 L
.43529 .08012 L
s
.678 .847 .902 r
.43529 .08012 m
.43529 .20421 L
.43601 .20421 L
.43601 .08012 L
F
.2 .63 .79 r
.43529 .08012 m
.43529 .20421 L
.43601 .20421 L
.43601 .08012 L
s
.678 .847 .902 r
.43601 .08012 m
.43601 .20389 L
.43631 .20389 L
.43631 .08012 L
F
.2 .63 .79 r
.43601 .08012 m
.43601 .20389 L
.43631 .20389 L
.43631 .08012 L
s
.678 .847 .902 r
.43631 .08012 m
.43631 .20385 L
.4368 .20385 L
.4368 .08012 L
F
.2 .63 .79 r
.43631 .08012 m
.43631 .20385 L
.4368 .20385 L
.4368 .08012 L
s
.678 .847 .902 r
.4368 .08012 m
.4368 .20321 L
.43726 .20321 L
.43726 .08012 L
F
.2 .63 .79 r
.4368 .08012 m
.4368 .20321 L
.43726 .20321 L
.43726 .08012 L
s
.678 .847 .902 r
.43726 .08012 m
.43726 .20319 L
.43784 .20319 L
.43784 .08012 L
F
.2 .63 .79 r
.43726 .08012 m
.43726 .20319 L
.43784 .20319 L
.43784 .08012 L
s
.678 .847 .902 r
.43784 .08012 m
.43784 .20253 L
.43845 .20253 L
.43845 .08012 L
F
.2 .63 .79 r
.43784 .08012 m
.43784 .20253 L
.43845 .20253 L
.43845 .08012 L
s
.678 .847 .902 r
.43845 .08012 m
.43845 .2023 L
.43913 .2023 L
.43913 .08012 L
F
.2 .63 .79 r
.43845 .08012 m
.43845 .2023 L
.43913 .2023 L
.43913 .08012 L
s
.678 .847 .902 r
.43913 .08012 m
.43913 .20185 L
.43972 .20185 L
.43972 .08012 L
F
.2 .63 .79 r
.43913 .08012 m
.43913 .20185 L
.43972 .20185 L
.43972 .08012 L
s
.678 .847 .902 r
.43972 .08012 m
.43972 .20132 L
.44017 .20132 L
.44017 .08012 L
F
.2 .63 .79 r
.43972 .08012 m
.43972 .20132 L
.44017 .20132 L
.44017 .08012 L
s
.678 .847 .902 r
.44017 .08012 m
.44017 .20094 L
.44062 .20094 L
.44062 .08012 L
F
.2 .63 .79 r
.44017 .08012 m
.44017 .20094 L
.44062 .20094 L
.44062 .08012 L
s
.678 .847 .902 r
.44062 .08012 m
.44062 .20074 L
.44098 .20074 L
.44098 .08012 L
F
.2 .63 .79 r
.44062 .08012 m
.44062 .20074 L
.44098 .20074 L
.44098 .08012 L
s
.678 .847 .902 r
.44098 .08012 m
.44098 .2002 L
.44157 .2002 L
.44157 .08012 L
F
.2 .63 .79 r
.44098 .08012 m
.44098 .2002 L
.44157 .2002 L
.44157 .08012 L
s
.678 .847 .902 r
.44157 .08012 m
.44157 .20009 L
.44226 .20009 L
.44226 .08012 L
F
.2 .63 .79 r
.44157 .08012 m
.44157 .20009 L
.44226 .20009 L
.44226 .08012 L
s
.678 .847 .902 r
.44226 .08012 m
.44226 .19942 L
.44281 .19942 L
.44281 .08012 L
F
.2 .63 .79 r
.44226 .08012 m
.44226 .19942 L
.44281 .19942 L
.44281 .08012 L
s
.678 .847 .902 r
.44281 .08012 m
.44281 .19928 L
.44309 .19928 L
.44309 .08012 L
F
.2 .63 .79 r
.44281 .08012 m
.44281 .19928 L
.44309 .19928 L
.44309 .08012 L
s
.678 .847 .902 r
.44309 .08012 m
.44309 .19912 L
.44339 .19912 L
.44339 .08012 L
F
.2 .63 .79 r
.44309 .08012 m
.44309 .19912 L
.44339 .19912 L
.44339 .08012 L
s
.678 .847 .902 r
.44339 .08012 m
.44339 .19848 L
.44406 .19848 L
.44406 .08012 L
F
.2 .63 .79 r
.44339 .08012 m
.44339 .19848 L
.44406 .19848 L
.44406 .08012 L
s
.678 .847 .902 r
.44406 .08012 m
.44406 .19828 L
.44477 .19828 L
.44477 .08012 L
F
.2 .63 .79 r
.44406 .08012 m
.44406 .19828 L
.44477 .19828 L
.44477 .08012 L
s
.678 .847 .902 r
.44477 .08012 m
.44477 .19792 L
.44544 .19792 L
.44544 .08012 L
F
.2 .63 .79 r
.44477 .08012 m
.44477 .19792 L
.44544 .19792 L
.44544 .08012 L
s
.678 .847 .902 r
.44544 .08012 m
.44544 .19746 L
.44602 .19746 L
.44602 .08012 L
F
.2 .63 .79 r
.44544 .08012 m
.44544 .19746 L
.44602 .19746 L
.44602 .08012 L
s
.678 .847 .902 r
.44602 .08012 m
.44602 .19711 L
.44663 .19711 L
.44663 .08012 L
F
.2 .63 .79 r
.44602 .08012 m
.44602 .19711 L
.44663 .19711 L
.44663 .08012 L
s
.678 .847 .902 r
.44663 .08012 m
.44663 .1965 L
.44721 .1965 L
.44721 .08012 L
F
.2 .63 .79 r
.44663 .08012 m
.44663 .1965 L
.44721 .1965 L
.44721 .08012 L
s
.678 .847 .902 r
.44721 .08012 m
.44721 .1962 L
.44753 .1962 L
.44753 .08012 L
F
.2 .63 .79 r
.44721 .08012 m
.44721 .1962 L
.44753 .1962 L
.44753 .08012 L
s
.678 .847 .902 r
.44753 .08012 m
.44753 .19608 L
.44789 .19608 L
.44789 .08012 L
F
.2 .63 .79 r
.44753 .08012 m
.44753 .19608 L
.44789 .19608 L
.44789 .08012 L
s
.678 .847 .902 r
.44789 .08012 m
.44789 .19571 L
.44852 .19571 L
.44852 .08012 L
F
.2 .63 .79 r
.44789 .08012 m
.44789 .19571 L
.44852 .19571 L
.44852 .08012 L
s
.678 .847 .902 r
.44852 .08012 m
.44852 .19519 L
.44901 .19519 L
.44901 .08012 L
F
.2 .63 .79 r
.44852 .08012 m
.44852 .19519 L
.44901 .19519 L
.44901 .08012 L
s
.678 .847 .902 r
.44901 .08012 m
.44901 .1949 L
.44957 .1949 L
.44957 .08012 L
F
.2 .63 .79 r
.44901 .08012 m
.44901 .1949 L
.44957 .1949 L
.44957 .08012 L
s
.678 .847 .902 r
.44957 .08012 m
.44957 .19465 L
.4502 .19465 L
.4502 .08012 L
F
.2 .63 .79 r
.44957 .08012 m
.44957 .19465 L
.4502 .19465 L
.4502 .08012 L
s
.678 .847 .902 r
.4502 .08012 m
.4502 .1942 L
.45048 .1942 L
.45048 .08012 L
F
.2 .63 .79 r
.4502 .08012 m
.4502 .1942 L
.45048 .1942 L
.45048 .08012 L
s
.678 .847 .902 r
.45048 .08012 m
.45048 .19406 L
.45109 .19406 L
.45109 .08012 L
F
.2 .63 .79 r
.45048 .08012 m
.45048 .19406 L
.45109 .19406 L
.45109 .08012 L
s
.678 .847 .902 r
.45109 .08012 m
.45109 .19353 L
.4517 .19353 L
.4517 .08012 L
F
.2 .63 .79 r
.45109 .08012 m
.45109 .19353 L
.4517 .19353 L
.4517 .08012 L
s
.678 .847 .902 r
.4517 .08012 m
.4517 .19306 L
.45195 .19306 L
.45195 .08012 L
F
.2 .63 .79 r
.4517 .08012 m
.4517 .19306 L
.45195 .19306 L
.45195 .08012 L
s
.678 .847 .902 r
.45195 .08012 m
.45195 .19276 L
.45252 .19276 L
.45252 .08012 L
F
.2 .63 .79 r
.45195 .08012 m
.45195 .19276 L
.45252 .19276 L
.45252 .08012 L
s
.678 .847 .902 r
.45252 .08012 m
.45252 .1926 L
.45289 .1926 L
.45289 .08012 L
F
.2 .63 .79 r
.45252 .08012 m
.45252 .1926 L
.45289 .1926 L
.45289 .08012 L
s
.678 .847 .902 r
.45289 .08012 m
.45289 .19215 L
.45336 .19215 L
.45336 .08012 L
F
.2 .63 .79 r
.45289 .08012 m
.45289 .19215 L
.45336 .19215 L
.45336 .08012 L
s
.678 .847 .902 r
.45336 .08012 m
.45336 .19183 L
.45376 .19183 L
.45376 .08012 L
F
.2 .63 .79 r
.45336 .08012 m
.45336 .19183 L
.45376 .19183 L
.45376 .08012 L
s
.678 .847 .902 r
.45376 .08012 m
.45376 .19161 L
.45437 .19161 L
.45437 .08012 L
F
.2 .63 .79 r
.45376 .08012 m
.45376 .19161 L
.45437 .19161 L
.45437 .08012 L
s
.678 .847 .902 r
.45437 .08012 m
.45437 .19122 L
.45492 .19122 L
.45492 .08012 L
F
.2 .63 .79 r
.45437 .08012 m
.45437 .19122 L
.45492 .19122 L
.45492 .08012 L
s
.678 .847 .902 r
.45492 .08012 m
.45492 .19089 L
.45533 .19089 L
.45533 .08012 L
F
.2 .63 .79 r
.45492 .08012 m
.45492 .19089 L
.45533 .19089 L
.45533 .08012 L
s
.678 .847 .902 r
.45533 .08012 m
.45533 .19057 L
.45565 .19057 L
.45565 .08012 L
F
.2 .63 .79 r
.45533 .08012 m
.45533 .19057 L
.45565 .19057 L
.45565 .08012 L
s
.678 .847 .902 r
.45565 .08012 m
.45565 .1903 L
.45632 .1903 L
.45632 .08012 L
F
.2 .63 .79 r
.45565 .08012 m
.45565 .1903 L
.45632 .1903 L
.45632 .08012 L
s
.678 .847 .902 r
.45632 .08012 m
.45632 .19004 L
.45688 .19004 L
.45688 .08012 L
F
.2 .63 .79 r
.45632 .08012 m
.45632 .19004 L
.45688 .19004 L
.45688 .08012 L
s
.678 .847 .902 r
.45688 .08012 m
.45688 .18958 L
.45735 .18958 L
.45735 .08012 L
F
.2 .63 .79 r
.45688 .08012 m
.45688 .18958 L
.45735 .18958 L
.45735 .08012 L
s
.678 .847 .902 r
.45735 .08012 m
.45735 .18916 L
.45784 .18916 L
.45784 .08012 L
F
.2 .63 .79 r
.45735 .08012 m
.45735 .18916 L
.45784 .18916 L
.45784 .08012 L
s
.678 .847 .902 r
.45784 .08012 m
.45784 .18898 L
.45811 .18898 L
.45811 .08012 L
F
.2 .63 .79 r
.45784 .08012 m
.45784 .18898 L
.45811 .18898 L
.45811 .08012 L
s
.678 .847 .902 r
.45811 .08012 m
.45811 .18858 L
.45883 .18858 L
.45883 .08012 L
F
.2 .63 .79 r
.45811 .08012 m
.45811 .18858 L
.45883 .18858 L
.45883 .08012 L
s
.678 .847 .902 r
.45883 .08012 m
.45883 .18817 L
.4592 .18817 L
.4592 .08012 L
F
.2 .63 .79 r
.45883 .08012 m
.45883 .18817 L
.4592 .18817 L
.4592 .08012 L
s
.678 .847 .902 r
.4592 .08012 m
.4592 .188 L
.45954 .188 L
.45954 .08012 L
F
.2 .63 .79 r
.4592 .08012 m
.4592 .188 L
.45954 .188 L
.45954 .08012 L
s
.678 .847 .902 r
.45954 .08012 m
.45954 .18788 L
.4599 .18788 L
.4599 .08012 L
F
.2 .63 .79 r
.45954 .08012 m
.45954 .18788 L
.4599 .18788 L
.4599 .08012 L
s
.678 .847 .902 r
.4599 .08012 m
.4599 .18768 L
.46036 .18768 L
.46036 .08012 L
F
.2 .63 .79 r
.4599 .08012 m
.4599 .18768 L
.46036 .18768 L
.46036 .08012 L
s
.678 .847 .902 r
.46036 .08012 m
.46036 .18718 L
.4609 .18718 L
.4609 .08012 L
F
.2 .63 .79 r
.46036 .08012 m
.46036 .18718 L
.4609 .18718 L
.4609 .08012 L
s
.678 .847 .902 r
.4609 .08012 m
.4609 .18683 L
.46134 .18683 L
.46134 .08012 L
F
.2 .63 .79 r
.4609 .08012 m
.4609 .18683 L
.46134 .18683 L
.46134 .08012 L
s
.678 .847 .902 r
.46134 .08012 m
.46134 .18653 L
.46165 .18653 L
.46165 .08012 L
F
.2 .63 .79 r
.46134 .08012 m
.46134 .18653 L
.46165 .18653 L
.46165 .08012 L
s
.678 .847 .902 r
.46165 .08012 m
.46165 .18652 L
.46223 .18652 L
.46223 .08012 L
F
.2 .63 .79 r
.46165 .08012 m
.46165 .18652 L
.46223 .18652 L
.46223 .08012 L
s
.678 .847 .902 r
.46223 .08012 m
.46223 .18602 L
.46289 .18602 L
.46289 .08012 L
F
.2 .63 .79 r
.46223 .08012 m
.46223 .18602 L
.46289 .18602 L
.46289 .08012 L
s
.678 .847 .902 r
.46289 .08012 m
.46289 .18551 L
.46329 .18551 L
.46329 .08012 L
F
.2 .63 .79 r
.46289 .08012 m
.46289 .18551 L
.46329 .18551 L
.46329 .08012 L
s
.678 .847 .902 r
.46329 .08012 m
.46329 .18536 L
.46376 .18536 L
.46376 .08012 L
F
.2 .63 .79 r
.46329 .08012 m
.46329 .18536 L
.46376 .18536 L
.46376 .08012 L
s
.678 .847 .902 r
.46376 .08012 m
.46376 .18491 L
.46419 .18491 L
.46419 .08012 L
F
.2 .63 .79 r
.46376 .08012 m
.46376 .18491 L
.46419 .18491 L
.46419 .08012 L
s
.678 .847 .902 r
.46419 .08012 m
.46419 .18472 L
.46459 .18472 L
.46459 .08012 L
F
.2 .63 .79 r
.46419 .08012 m
.46419 .18472 L
.46459 .18472 L
.46459 .08012 L
s
.678 .847 .902 r
.46459 .08012 m
.46459 .18445 L
.46482 .18445 L
.46482 .08012 L
F
.2 .63 .79 r
.46459 .08012 m
.46459 .18445 L
.46482 .18445 L
.46482 .08012 L
s
.678 .847 .902 r
.46482 .08012 m
.46482 .18415 L
.46542 .18415 L
.46542 .08012 L
F
.2 .63 .79 r
.46482 .08012 m
.46482 .18415 L
.46542 .18415 L
.46542 .08012 L
s
.678 .847 .902 r
.46542 .08012 m
.46542 .18395 L
.46603 .18395 L
.46603 .08012 L
F
.2 .63 .79 r
.46542 .08012 m
.46542 .18395 L
.46603 .18395 L
.46603 .08012 L
s
.678 .847 .902 r
.46603 .08012 m
.46603 .18321 L
.46675 .18321 L
.46675 .08012 L
F
.2 .63 .79 r
.46603 .08012 m
.46603 .18321 L
.46675 .18321 L
.46675 .08012 L
s
.678 .847 .902 r
.46675 .08012 m
.46675 .18279 L
.46739 .18279 L
.46739 .08012 L
F
.2 .63 .79 r
.46675 .08012 m
.46675 .18279 L
.46739 .18279 L
.46739 .08012 L
s
.678 .847 .902 r
.46739 .08012 m
.46739 .18267 L
.46804 .18267 L
.46804 .08012 L
F
.2 .63 .79 r
.46739 .08012 m
.46739 .18267 L
.46804 .18267 L
.46804 .08012 L
s
.678 .847 .902 r
.46804 .08012 m
.46804 .18228 L
.46831 .18228 L
.46831 .08012 L
F
.2 .63 .79 r
.46804 .08012 m
.46804 .18228 L
.46831 .18228 L
.46831 .08012 L
s
.678 .847 .902 r
.46831 .08012 m
.46831 .18198 L
.46879 .18198 L
.46879 .08012 L
F
.2 .63 .79 r
.46831 .08012 m
.46831 .18198 L
.46879 .18198 L
.46879 .08012 L
s
.678 .847 .902 r
.46879 .08012 m
.46879 .18177 L
.46915 .18177 L
.46915 .08012 L
F
.2 .63 .79 r
.46879 .08012 m
.46879 .18177 L
.46915 .18177 L
.46915 .08012 L
s
.678 .847 .902 r
.46915 .08012 m
.46915 .18131 L
.46976 .18131 L
.46976 .08012 L
F
.2 .63 .79 r
.46915 .08012 m
.46915 .18131 L
.46976 .18131 L
.46976 .08012 L
s
.678 .847 .902 r
.46976 .08012 m
.46976 .18108 L
.47004 .18108 L
.47004 .08012 L
F
.2 .63 .79 r
.46976 .08012 m
.46976 .18108 L
.47004 .18108 L
.47004 .08012 L
s
.678 .847 .902 r
.47004 .08012 m
.47004 .18088 L
.47037 .18088 L
.47037 .08012 L
F
.2 .63 .79 r
.47004 .08012 m
.47004 .18088 L
.47037 .18088 L
.47037 .08012 L
s
.678 .847 .902 r
.47037 .08012 m
.47037 .18069 L
.47061 .18069 L
.47061 .08012 L
F
.2 .63 .79 r
.47037 .08012 m
.47037 .18069 L
.47061 .18069 L
.47061 .08012 L
s
.678 .847 .902 r
.47061 .08012 m
.47061 .18049 L
.47107 .18049 L
.47107 .08012 L
F
.2 .63 .79 r
.47061 .08012 m
.47061 .18049 L
.47107 .18049 L
.47107 .08012 L
s
.678 .847 .902 r
.47107 .08012 m
.47107 .18017 L
.47162 .18017 L
.47162 .08012 L
F
.2 .63 .79 r
.47107 .08012 m
.47107 .18017 L
.47162 .18017 L
.47162 .08012 L
s
.678 .847 .902 r
.47162 .08012 m
.47162 .17964 L
.47215 .17964 L
.47215 .08012 L
F
.2 .63 .79 r
.47162 .08012 m
.47162 .17964 L
.47215 .17964 L
.47215 .08012 L
s
.678 .847 .902 r
.47215 .08012 m
.47215 .17934 L
.47267 .17934 L
.47267 .08012 L
F
.2 .63 .79 r
.47215 .08012 m
.47215 .17934 L
.47267 .17934 L
.47267 .08012 L
s
.678 .847 .902 r
.47267 .08012 m
.47267 .17914 L
.47305 .17914 L
.47305 .08012 L
F
.2 .63 .79 r
.47267 .08012 m
.47267 .17914 L
.47305 .17914 L
.47305 .08012 L
s
.678 .847 .902 r
.47305 .08012 m
.47305 .17884 L
.47376 .17884 L
.47376 .08012 L
F
.2 .63 .79 r
.47305 .08012 m
.47305 .17884 L
.47376 .17884 L
.47376 .08012 L
s
.678 .847 .902 r
.47376 .08012 m
.47376 .17832 L
.47435 .17832 L
.47435 .08012 L
F
.2 .63 .79 r
.47376 .08012 m
.47376 .17832 L
.47435 .17832 L
.47435 .08012 L
s
.678 .847 .902 r
.47435 .08012 m
.47435 .17814 L
.47469 .17814 L
.47469 .08012 L
F
.2 .63 .79 r
.47435 .08012 m
.47435 .17814 L
.47469 .17814 L
.47469 .08012 L
s
.678 .847 .902 r
.47469 .08012 m
.47469 .17785 L
.47533 .17785 L
.47533 .08012 L
F
.2 .63 .79 r
.47469 .08012 m
.47469 .17785 L
.47533 .17785 L
.47533 .08012 L
s
.678 .847 .902 r
.47533 .08012 m
.47533 .17731 L
.47583 .17731 L
.47583 .08012 L
F
.2 .63 .79 r
.47533 .08012 m
.47533 .17731 L
.47583 .17731 L
.47583 .08012 L
s
.678 .847 .902 r
.47583 .08012 m
.47583 .17715 L
.47623 .17715 L
.47623 .08012 L
F
.2 .63 .79 r
.47583 .08012 m
.47583 .17715 L
.47623 .17715 L
.47623 .08012 L
s
.678 .847 .902 r
.47623 .08012 m
.47623 .17685 L
.47656 .17685 L
.47656 .08012 L
F
.2 .63 .79 r
.47623 .08012 m
.47623 .17685 L
.47656 .17685 L
.47656 .08012 L
s
.678 .847 .902 r
.47656 .08012 m
.47656 .17662 L
.47683 .17662 L
.47683 .08012 L
F
.2 .63 .79 r
.47656 .08012 m
.47656 .17662 L
.47683 .17662 L
.47683 .08012 L
s
.678 .847 .902 r
.47683 .08012 m
.47683 .17635 L
.47745 .17635 L
.47745 .08012 L
F
.2 .63 .79 r
.47683 .08012 m
.47683 .17635 L
.47745 .17635 L
.47745 .08012 L
s
.678 .847 .902 r
.47745 .08012 m
.47745 .17606 L
.47786 .17606 L
.47786 .08012 L
F
.2 .63 .79 r
.47745 .08012 m
.47745 .17606 L
.47786 .17606 L
.47786 .08012 L
s
.678 .847 .902 r
.47786 .08012 m
.47786 .17572 L
.47829 .17572 L
.47829 .08012 L
F
.2 .63 .79 r
.47786 .08012 m
.47786 .17572 L
.47829 .17572 L
.47829 .08012 L
s
.678 .847 .902 r
.47829 .08012 m
.47829 .1755 L
.47863 .1755 L
.47863 .08012 L
F
.2 .63 .79 r
.47829 .08012 m
.47829 .1755 L
.47863 .1755 L
.47863 .08012 L
s
.678 .847 .902 r
.47863 .08012 m
.47863 .17521 L
.4792 .17521 L
.4792 .08012 L
F
.2 .63 .79 r
.47863 .08012 m
.47863 .17521 L
.4792 .17521 L
.4792 .08012 L
s
.678 .847 .902 r
.4792 .08012 m
.4792 .17461 L
.47986 .17461 L
.47986 .08012 L
F
.2 .63 .79 r
.4792 .08012 m
.4792 .17461 L
.47986 .17461 L
.47986 .08012 L
s
.678 .847 .902 r
.47986 .08012 m
.47986 .1745 L
.48015 .1745 L
.48015 .08012 L
F
.2 .63 .79 r
.47986 .08012 m
.47986 .1745 L
.48015 .1745 L
.48015 .08012 L
s
.678 .847 .902 r
.48015 .08012 m
.48015 .17414 L
.48061 .17414 L
.48061 .08012 L
F
.2 .63 .79 r
.48015 .08012 m
.48015 .17414 L
.48061 .17414 L
.48061 .08012 L
s
.678 .847 .902 r
.48061 .08012 m
.48061 .17407 L
.48112 .17407 L
.48112 .08012 L
F
.2 .63 .79 r
.48061 .08012 m
.48061 .17407 L
.48112 .17407 L
.48112 .08012 L
s
.678 .847 .902 r
.48112 .08012 m
.48112 .17358 L
.48168 .17358 L
.48168 .08012 L
F
.2 .63 .79 r
.48112 .08012 m
.48112 .17358 L
.48168 .17358 L
.48168 .08012 L
s
.678 .847 .902 r
.48168 .08012 m
.48168 .1734 L
.48194 .1734 L
.48194 .08012 L
F
.2 .63 .79 r
.48168 .08012 m
.48168 .1734 L
.48194 .1734 L
.48194 .08012 L
s
.678 .847 .902 r
.48194 .08012 m
.48194 .17301 L
.48267 .17301 L
.48267 .08012 L
F
.2 .63 .79 r
.48194 .08012 m
.48194 .17301 L
.48267 .17301 L
.48267 .08012 L
s
.678 .847 .902 r
.48267 .08012 m
.48267 .17244 L
.48336 .17244 L
.48336 .08012 L
F
.2 .63 .79 r
.48267 .08012 m
.48267 .17244 L
.48336 .17244 L
.48336 .08012 L
s
.678 .847 .902 r
.48336 .08012 m
.48336 .17222 L
.48361 .17222 L
.48361 .08012 L
F
.2 .63 .79 r
.48336 .08012 m
.48336 .17222 L
.48361 .17222 L
.48361 .08012 L
s
.678 .847 .902 r
.48361 .08012 m
.48361 .17206 L
.48408 .17206 L
.48408 .08012 L
F
.2 .63 .79 r
.48361 .08012 m
.48361 .17206 L
.48408 .17206 L
.48408 .08012 L
s
.678 .847 .902 r
.48408 .08012 m
.48408 .17183 L
.48465 .17183 L
.48465 .08012 L
F
.2 .63 .79 r
.48408 .08012 m
.48408 .17183 L
.48465 .17183 L
.48465 .08012 L
s
.678 .847 .902 r
.48465 .08012 m
.48465 .17132 L
.48537 .17132 L
.48537 .08012 L
F
.2 .63 .79 r
.48465 .08012 m
.48465 .17132 L
.48537 .17132 L
.48537 .08012 L
s
.678 .847 .902 r
.48537 .08012 m
.48537 .17102 L
.48576 .17102 L
.48576 .08012 L
F
.2 .63 .79 r
.48537 .08012 m
.48537 .17102 L
.48576 .17102 L
.48576 .08012 L
s
.678 .847 .902 r
.48576 .08012 m
.48576 .17073 L
.4861 .17073 L
.4861 .08012 L
F
.2 .63 .79 r
.48576 .08012 m
.48576 .17073 L
.4861 .17073 L
.4861 .08012 L
s
.678 .847 .902 r
.4861 .08012 m
.4861 .17019 L
.48676 .17019 L
.48676 .08012 L
F
.2 .63 .79 r
.4861 .08012 m
.4861 .17019 L
.48676 .17019 L
.48676 .08012 L
s
.678 .847 .902 r
.48676 .08012 m
.48676 .16994 L
.48721 .16994 L
.48721 .08012 L
F
.2 .63 .79 r
.48676 .08012 m
.48676 .16994 L
.48721 .16994 L
.48721 .08012 L
s
.678 .847 .902 r
.48721 .08012 m
.48721 .16943 L
.48792 .16943 L
.48792 .08012 L
F
.2 .63 .79 r
.48721 .08012 m
.48721 .16943 L
.48792 .16943 L
.48792 .08012 L
s
.678 .847 .902 r
.48792 .08012 m
.48792 .16928 L
.48815 .16928 L
.48815 .08012 L
F
.2 .63 .79 r
.48792 .08012 m
.48792 .16928 L
.48815 .16928 L
.48815 .08012 L
s
.678 .847 .902 r
.48815 .08012 m
.48815 .16913 L
.48876 .16913 L
.48876 .08012 L
F
.2 .63 .79 r
.48815 .08012 m
.48815 .16913 L
.48876 .16913 L
.48876 .08012 L
s
.678 .847 .902 r
.48876 .08012 m
.48876 .16877 L
.48933 .16877 L
.48933 .08012 L
F
.2 .63 .79 r
.48876 .08012 m
.48876 .16877 L
.48933 .16877 L
.48933 .08012 L
s
.678 .847 .902 r
.48933 .08012 m
.48933 .16831 L
.48984 .16831 L
.48984 .08012 L
F
.2 .63 .79 r
.48933 .08012 m
.48933 .16831 L
.48984 .16831 L
.48984 .08012 L
s
.678 .847 .902 r
.48984 .08012 m
.48984 .16805 L
.49038 .16805 L
.49038 .08012 L
F
.2 .63 .79 r
.48984 .08012 m
.48984 .16805 L
.49038 .16805 L
.49038 .08012 L
s
.678 .847 .902 r
.49038 .08012 m
.49038 .16757 L
.49087 .16757 L
.49087 .08012 L
F
.2 .63 .79 r
.49038 .08012 m
.49038 .16757 L
.49087 .16757 L
.49087 .08012 L
s
.678 .847 .902 r
.49087 .08012 m
.49087 .16715 L
.49159 .16715 L
.49159 .08012 L
F
.2 .63 .79 r
.49087 .08012 m
.49087 .16715 L
.49159 .16715 L
.49159 .08012 L
s
.678 .847 .902 r
.49159 .08012 m
.49159 .16682 L
.49217 .16682 L
.49217 .08012 L
F
.2 .63 .79 r
.49159 .08012 m
.49159 .16682 L
.49217 .16682 L
.49217 .08012 L
s
.678 .847 .902 r
.49217 .08012 m
.49217 .16673 L
.49265 .16673 L
.49265 .08012 L
F
.2 .63 .79 r
.49217 .08012 m
.49217 .16673 L
.49265 .16673 L
.49265 .08012 L
s
.678 .847 .902 r
.49265 .08012 m
.49265 .16642 L
.4929 .16642 L
.4929 .08012 L
F
.2 .63 .79 r
.49265 .08012 m
.49265 .16642 L
.4929 .16642 L
.4929 .08012 L
s
.678 .847 .902 r
.4929 .08012 m
.4929 .16607 L
.49333 .16607 L
.49333 .08012 L
F
.2 .63 .79 r
.4929 .08012 m
.4929 .16607 L
.49333 .16607 L
.49333 .08012 L
s
.678 .847 .902 r
.49333 .08012 m
.49333 .16598 L
.49357 .16598 L
.49357 .08012 L
F
.2 .63 .79 r
.49333 .08012 m
.49333 .16598 L
.49357 .16598 L
.49357 .08012 L
s
.678 .847 .902 r
.49357 .08012 m
.49357 .1656 L
.494 .1656 L
.494 .08012 L
F
.2 .63 .79 r
.49357 .08012 m
.49357 .1656 L
.494 .1656 L
.494 .08012 L
s
.678 .847 .902 r
.494 .08012 m
.494 .16549 L
.49426 .16549 L
.49426 .08012 L
F
.2 .63 .79 r
.494 .08012 m
.494 .16549 L
.49426 .16549 L
.49426 .08012 L
s
.678 .847 .902 r
.49426 .08012 m
.49426 .16542 L
.49472 .16542 L
.49472 .08012 L
F
.2 .63 .79 r
.49426 .08012 m
.49426 .16542 L
.49472 .16542 L
.49472 .08012 L
s
.678 .847 .902 r
.49472 .08012 m
.49472 .16488 L
.49544 .16488 L
.49544 .08012 L
F
.2 .63 .79 r
.49472 .08012 m
.49472 .16488 L
.49544 .16488 L
.49544 .08012 L
s
.678 .847 .902 r
.49544 .08012 m
.49544 .16442 L
.49614 .16442 L
.49614 .08012 L
F
.2 .63 .79 r
.49544 .08012 m
.49544 .16442 L
.49614 .16442 L
.49614 .08012 L
s
.678 .847 .902 r
.49614 .08012 m
.49614 .16412 L
.49656 .16412 L
.49656 .08012 L
F
.2 .63 .79 r
.49614 .08012 m
.49614 .16412 L
.49656 .16412 L
.49656 .08012 L
s
.678 .847 .902 r
.49656 .08012 m
.49656 .16381 L
.49703 .16381 L
.49703 .08012 L
F
.2 .63 .79 r
.49656 .08012 m
.49656 .16381 L
.49703 .16381 L
.49703 .08012 L
s
.678 .847 .902 r
.49703 .08012 m
.49703 .16355 L
.49758 .16355 L
.49758 .08012 L
F
.2 .63 .79 r
.49703 .08012 m
.49703 .16355 L
.49758 .16355 L
.49758 .08012 L
s
.678 .847 .902 r
.49758 .08012 m
.49758 .16325 L
.49816 .16325 L
.49816 .08012 L
F
.2 .63 .79 r
.49758 .08012 m
.49758 .16325 L
.49816 .16325 L
.49816 .08012 L
s
.678 .847 .902 r
.49816 .08012 m
.49816 .16282 L
.49865 .16282 L
.49865 .08012 L
F
.2 .63 .79 r
.49816 .08012 m
.49816 .16282 L
.49865 .16282 L
.49865 .08012 L
s
.678 .847 .902 r
.49865 .08012 m
.49865 .16257 L
.49889 .16257 L
.49889 .08012 L
F
.2 .63 .79 r
.49865 .08012 m
.49865 .16257 L
.49889 .16257 L
.49889 .08012 L
s
.678 .847 .902 r
.49889 .08012 m
.49889 .16239 L
.49947 .16239 L
.49947 .08012 L
F
.2 .63 .79 r
.49889 .08012 m
.49889 .16239 L
.49947 .16239 L
.49947 .08012 L
s
.678 .847 .902 r
.49947 .08012 m
.49947 .16208 L
.50003 .16208 L
.50003 .08012 L
F
.2 .63 .79 r
.49947 .08012 m
.49947 .16208 L
.50003 .16208 L
.50003 .08012 L
s
.678 .847 .902 r
.50003 .08012 m
.50003 .16176 L
.50064 .16176 L
.50064 .08012 L
F
.2 .63 .79 r
.50003 .08012 m
.50003 .16176 L
.50064 .16176 L
.50064 .08012 L
s
.678 .847 .902 r
.50064 .08012 m
.50064 .16134 L
.50105 .16134 L
.50105 .08012 L
F
.2 .63 .79 r
.50064 .08012 m
.50064 .16134 L
.50105 .16134 L
.50105 .08012 L
s
.678 .847 .902 r
.50105 .08012 m
.50105 .16109 L
.50133 .16109 L
.50133 .08012 L
F
.2 .63 .79 r
.50105 .08012 m
.50105 .16109 L
.50133 .16109 L
.50133 .08012 L
s
.678 .847 .902 r
.50133 .08012 m
.50133 .16092 L
.50157 .16092 L
.50157 .08012 L
F
.2 .63 .79 r
.50133 .08012 m
.50133 .16092 L
.50157 .16092 L
.50157 .08012 L
s
.678 .847 .902 r
.50157 .08012 m
.50157 .16085 L
.50191 .16085 L
.50191 .08012 L
F
.2 .63 .79 r
.50157 .08012 m
.50157 .16085 L
.50191 .16085 L
.50191 .08012 L
s
.678 .847 .902 r
.50191 .08012 m
.50191 .16053 L
.50233 .16053 L
.50233 .08012 L
F
.2 .63 .79 r
.50191 .08012 m
.50191 .16053 L
.50233 .16053 L
.50233 .08012 L
s
.678 .847 .902 r
.50233 .08012 m
.50233 .16017 L
.50276 .16017 L
.50276 .08012 L
F
.2 .63 .79 r
.50233 .08012 m
.50233 .16017 L
.50276 .16017 L
.50276 .08012 L
s
.678 .847 .902 r
.50276 .08012 m
.50276 .15992 L
.50326 .15992 L
.50326 .08012 L
F
.2 .63 .79 r
.50276 .08012 m
.50276 .15992 L
.50326 .15992 L
.50326 .08012 L
s
.678 .847 .902 r
.50326 .08012 m
.50326 .15984 L
.50356 .15984 L
.50356 .08012 L
F
.2 .63 .79 r
.50326 .08012 m
.50326 .15984 L
.50356 .15984 L
.50356 .08012 L
s
.678 .847 .902 r
.50356 .08012 m
.50356 .15932 L
.50428 .15932 L
.50428 .08012 L
F
.2 .63 .79 r
.50356 .08012 m
.50356 .15932 L
.50428 .15932 L
.50428 .08012 L
s
.678 .847 .902 r
.50428 .08012 m
.50428 .15905 L
.50469 .15905 L
.50469 .08012 L
F
.2 .63 .79 r
.50428 .08012 m
.50428 .15905 L
.50469 .15905 L
.50469 .08012 L
s
.678 .847 .902 r
.50469 .08012 m
.50469 .15883 L
.50497 .15883 L
.50497 .08012 L
F
.2 .63 .79 r
.50469 .08012 m
.50469 .15883 L
.50497 .15883 L
.50497 .08012 L
s
.678 .847 .902 r
.50497 .08012 m
.50497 .15873 L
.50525 .15873 L
.50525 .08012 L
F
.2 .63 .79 r
.50497 .08012 m
.50497 .15873 L
.50525 .15873 L
.50525 .08012 L
s
.678 .847 .902 r
.50525 .08012 m
.50525 .15843 L
.50572 .15843 L
.50572 .08012 L
F
.2 .63 .79 r
.50525 .08012 m
.50525 .15843 L
.50572 .15843 L
.50572 .08012 L
s
.678 .847 .902 r
.50572 .08012 m
.50572 .15832 L
.50614 .15832 L
.50614 .08012 L
F
.2 .63 .79 r
.50572 .08012 m
.50572 .15832 L
.50614 .15832 L
.50614 .08012 L
s
.678 .847 .902 r
.50614 .08012 m
.50614 .15805 L
.50645 .15805 L
.50645 .08012 L
F
.2 .63 .79 r
.50614 .08012 m
.50614 .15805 L
.50645 .15805 L
.50645 .08012 L
s
.678 .847 .902 r
.50645 .08012 m
.50645 .15758 L
.50704 .15758 L
.50704 .08012 L
F
.2 .63 .79 r
.50645 .08012 m
.50645 .15758 L
.50704 .15758 L
.50704 .08012 L
s
.678 .847 .902 r
.50704 .08012 m
.50704 .15754 L
.50727 .15754 L
.50727 .08012 L
F
.2 .63 .79 r
.50704 .08012 m
.50704 .15754 L
.50727 .15754 L
.50727 .08012 L
s
.678 .847 .902 r
.50727 .08012 m
.50727 .15717 L
.50786 .15717 L
.50786 .08012 L
F
.2 .63 .79 r
.50727 .08012 m
.50727 .15717 L
.50786 .15717 L
.50786 .08012 L
s
.678 .847 .902 r
.50786 .08012 m
.50786 .15679 L
.50833 .15679 L
.50833 .08012 L
F
.2 .63 .79 r
.50786 .08012 m
.50786 .15679 L
.50833 .15679 L
.50833 .08012 L
s
.678 .847 .902 r
.50833 .08012 m
.50833 .15671 L
.50865 .15671 L
.50865 .08012 L
F
.2 .63 .79 r
.50833 .08012 m
.50833 .15671 L
.50865 .15671 L
.50865 .08012 L
s
.678 .847 .902 r
.50865 .08012 m
.50865 .15648 L
.50936 .15648 L
.50936 .08012 L
F
.2 .63 .79 r
.50865 .08012 m
.50865 .15648 L
.50936 .15648 L
.50936 .08012 L
s
.678 .847 .902 r
.50936 .08012 m
.50936 .15611 L
.5096 .15611 L
.5096 .08012 L
F
.2 .63 .79 r
.50936 .08012 m
.50936 .15611 L
.5096 .15611 L
.5096 .08012 L
s
.678 .847 .902 r
.5096 .08012 m
.5096 .15576 L
.51023 .15576 L
.51023 .08012 L
F
.2 .63 .79 r
.5096 .08012 m
.5096 .15576 L
.51023 .15576 L
.51023 .08012 L
s
.678 .847 .902 r
.51023 .08012 m
.51023 .15559 L
.51068 .15559 L
.51068 .08012 L
F
.2 .63 .79 r
.51023 .08012 m
.51023 .15559 L
.51068 .15559 L
.51068 .08012 L
s
.678 .847 .902 r
.51068 .08012 m
.51068 .15513 L
.5112 .15513 L
.5112 .08012 L
F
.2 .63 .79 r
.51068 .08012 m
.51068 .15513 L
.5112 .15513 L
.5112 .08012 L
s
.678 .847 .902 r
.5112 .08012 m
.5112 .15484 L
.51189 .15484 L
.51189 .08012 L
F
.2 .63 .79 r
.5112 .08012 m
.5112 .15484 L
.51189 .15484 L
.51189 .08012 L
s
.678 .847 .902 r
.51189 .08012 m
.51189 .15434 L
.5125 .15434 L
.5125 .08012 L
F
.2 .63 .79 r
.51189 .08012 m
.51189 .15434 L
.5125 .15434 L
.5125 .08012 L
s
.678 .847 .902 r
.5125 .08012 m
.5125 .15408 L
.51283 .15408 L
.51283 .08012 L
F
.2 .63 .79 r
.5125 .08012 m
.5125 .15408 L
.51283 .15408 L
.51283 .08012 L
s
.678 .847 .902 r
.51283 .08012 m
.51283 .15403 L
.51315 .15403 L
.51315 .08012 L
F
.2 .63 .79 r
.51283 .08012 m
.51283 .15403 L
.51315 .15403 L
.51315 .08012 L
s
.678 .847 .902 r
.51315 .08012 m
.51315 .15372 L
.51363 .15372 L
.51363 .08012 L
F
.2 .63 .79 r
.51315 .08012 m
.51315 .15372 L
.51363 .15372 L
.51363 .08012 L
s
.678 .847 .902 r
.51363 .08012 m
.51363 .15338 L
.51396 .15338 L
.51396 .08012 L
F
.2 .63 .79 r
.51363 .08012 m
.51363 .15338 L
.51396 .15338 L
.51396 .08012 L
s
.678 .847 .902 r
.51396 .08012 m
.51396 .15326 L
.5142 .15326 L
.5142 .08012 L
F
.2 .63 .79 r
.51396 .08012 m
.51396 .15326 L
.5142 .15326 L
.5142 .08012 L
s
.678 .847 .902 r
.5142 .08012 m
.5142 .15317 L
.51453 .15317 L
.51453 .08012 L
F
.2 .63 .79 r
.5142 .08012 m
.5142 .15317 L
.51453 .15317 L
.51453 .08012 L
s
.678 .847 .902 r
.51453 .08012 m
.51453 .1529 L
.51482 .1529 L
.51482 .08012 L
F
.2 .63 .79 r
.51453 .08012 m
.51453 .1529 L
.51482 .1529 L
.51482 .08012 L
s
.678 .847 .902 r
.51482 .08012 m
.51482 .15284 L
.51508 .15284 L
.51508 .08012 L
F
.2 .63 .79 r
.51482 .08012 m
.51482 .15284 L
.51508 .15284 L
.51508 .08012 L
s
.678 .847 .902 r
.51508 .08012 m
.51508 .15258 L
.51579 .15258 L
.51579 .08012 L
F
.2 .63 .79 r
.51508 .08012 m
.51508 .15258 L
.51579 .15258 L
.51579 .08012 L
s
.678 .847 .902 r
.51579 .08012 m
.51579 .15208 L
.51637 .15208 L
.51637 .08012 L
F
.2 .63 .79 r
.51579 .08012 m
.51579 .15208 L
.51637 .15208 L
.51637 .08012 L
s
.678 .847 .902 r
.51637 .08012 m
.51637 .1517 L
.51698 .1517 L
.51698 .08012 L
F
.2 .63 .79 r
.51637 .08012 m
.51637 .1517 L
.51698 .1517 L
.51698 .08012 L
s
.678 .847 .902 r
.51698 .08012 m
.51698 .15122 L
.51766 .15122 L
.51766 .08012 L
F
.2 .63 .79 r
.51698 .08012 m
.51698 .15122 L
.51766 .15122 L
.51766 .08012 L
s
.678 .847 .902 r
.51766 .08012 m
.51766 .15108 L
.518 .15108 L
.518 .08012 L
F
.2 .63 .79 r
.51766 .08012 m
.51766 .15108 L
.518 .15108 L
.518 .08012 L
s
.678 .847 .902 r
.518 .08012 m
.518 .15079 L
.51857 .15079 L
.51857 .08012 L
F
.2 .63 .79 r
.518 .08012 m
.518 .15079 L
.51857 .15079 L
.51857 .08012 L
s
.678 .847 .902 r
.51857 .08012 m
.51857 .15048 L
.5188 .15048 L
.5188 .08012 L
F
.2 .63 .79 r
.51857 .08012 m
.51857 .15048 L
.5188 .15048 L
.5188 .08012 L
s
.678 .847 .902 r
.5188 .08012 m
.5188 .15024 L
.51924 .15024 L
.51924 .08012 L
F
.2 .63 .79 r
.5188 .08012 m
.5188 .15024 L
.51924 .15024 L
.51924 .08012 L
s
.678 .847 .902 r
.51924 .08012 m
.51924 .1502 L
.51947 .1502 L
.51947 .08012 L
F
.2 .63 .79 r
.51924 .08012 m
.51924 .1502 L
.51947 .1502 L
.51947 .08012 L
s
.678 .847 .902 r
.51947 .08012 m
.51947 .14998 L
.52007 .14998 L
.52007 .08012 L
F
.2 .63 .79 r
.51947 .08012 m
.51947 .14998 L
.52007 .14998 L
.52007 .08012 L
s
.678 .847 .902 r
.52007 .08012 m
.52007 .14942 L
.52079 .14942 L
.52079 .08012 L
F
.2 .63 .79 r
.52007 .08012 m
.52007 .14942 L
.52079 .14942 L
.52079 .08012 L
s
.678 .847 .902 r
.52079 .08012 m
.52079 .14919 L
.52132 .14919 L
.52132 .08012 L
F
.2 .63 .79 r
.52079 .08012 m
.52079 .14919 L
.52132 .14919 L
.52132 .08012 L
s
.678 .847 .902 r
.52132 .08012 m
.52132 .14897 L
.52184 .14897 L
.52184 .08012 L
F
.2 .63 .79 r
.52132 .08012 m
.52132 .14897 L
.52184 .14897 L
.52184 .08012 L
s
.678 .847 .902 r
.52184 .08012 m
.52184 .14857 L
.52214 .14857 L
.52214 .08012 L
F
.2 .63 .79 r
.52184 .08012 m
.52184 .14857 L
.52214 .14857 L
.52214 .08012 L
s
.678 .847 .902 r
.52214 .08012 m
.52214 .14846 L
.52239 .14846 L
.52239 .08012 L
F
.2 .63 .79 r
.52214 .08012 m
.52214 .14846 L
.52239 .14846 L
.52239 .08012 L
s
.678 .847 .902 r
.52239 .08012 m
.52239 .14813 L
.52304 .14813 L
.52304 .08012 L
F
.2 .63 .79 r
.52239 .08012 m
.52239 .14813 L
.52304 .14813 L
.52304 .08012 L
s
.678 .847 .902 r
.52304 .08012 m
.52304 .14792 L
.52345 .14792 L
.52345 .08012 L
F
.2 .63 .79 r
.52304 .08012 m
.52304 .14792 L
.52345 .14792 L
.52345 .08012 L
s
.678 .847 .902 r
.52345 .08012 m
.52345 .14751 L
.52416 .14751 L
.52416 .08012 L
F
.2 .63 .79 r
.52345 .08012 m
.52345 .14751 L
.52416 .14751 L
.52416 .08012 L
s
.678 .847 .902 r
.52416 .08012 m
.52416 .14707 L
.52467 .14707 L
.52467 .08012 L
F
.2 .63 .79 r
.52416 .08012 m
.52416 .14707 L
.52467 .14707 L
.52467 .08012 L
s
.678 .847 .902 r
.52467 .08012 m
.52467 .14681 L
.52521 .14681 L
.52521 .08012 L
F
.2 .63 .79 r
.52467 .08012 m
.52467 .14681 L
.52521 .14681 L
.52521 .08012 L
s
.678 .847 .902 r
.52521 .08012 m
.52521 .14659 L
.52559 .14659 L
.52559 .08012 L
F
.2 .63 .79 r
.52521 .08012 m
.52521 .14659 L
.52559 .14659 L
.52559 .08012 L
s
.678 .847 .902 r
.52559 .08012 m
.52559 .14638 L
.52618 .14638 L
.52618 .08012 L
F
.2 .63 .79 r
.52559 .08012 m
.52559 .14638 L
.52618 .14638 L
.52618 .08012 L
s
.678 .847 .902 r
.52618 .08012 m
.52618 .1461 L
.52662 .1461 L
.52662 .08012 L
F
.2 .63 .79 r
.52618 .08012 m
.52618 .1461 L
.52662 .1461 L
.52662 .08012 L
s
.678 .847 .902 r
.52662 .08012 m
.52662 .1457 L
.52712 .1457 L
.52712 .08012 L
F
.2 .63 .79 r
.52662 .08012 m
.52662 .1457 L
.52712 .1457 L
.52712 .08012 L
s
.678 .847 .902 r
.52712 .08012 m
.52712 .14553 L
.52753 .14553 L
.52753 .08012 L
F
.2 .63 .79 r
.52712 .08012 m
.52712 .14553 L
.52753 .14553 L
.52753 .08012 L
s
.678 .847 .902 r
.52753 .08012 m
.52753 .14525 L
.52776 .14525 L
.52776 .08012 L
F
.2 .63 .79 r
.52753 .08012 m
.52753 .14525 L
.52776 .14525 L
.52776 .08012 L
s
.678 .847 .902 r
.52776 .08012 m
.52776 .14505 L
.52832 .14505 L
.52832 .08012 L
F
.2 .63 .79 r
.52776 .08012 m
.52776 .14505 L
.52832 .14505 L
.52832 .08012 L
s
.678 .847 .902 r
.52832 .08012 m
.52832 .14465 L
.52887 .14465 L
.52887 .08012 L
F
.2 .63 .79 r
.52832 .08012 m
.52832 .14465 L
.52887 .14465 L
.52887 .08012 L
s
.678 .847 .902 r
.52887 .08012 m
.52887 .14442 L
.52916 .14442 L
.52916 .08012 L
F
.2 .63 .79 r
.52887 .08012 m
.52887 .14442 L
.52916 .14442 L
.52916 .08012 L
s
.678 .847 .902 r
.52916 .08012 m
.52916 .14434 L
.52954 .14434 L
.52954 .08012 L
F
.2 .63 .79 r
.52916 .08012 m
.52916 .14434 L
.52954 .14434 L
.52954 .08012 L
s
.678 .847 .902 r
.52954 .08012 m
.52954 .14399 L
.5301 .14399 L
.5301 .08012 L
F
.2 .63 .79 r
.52954 .08012 m
.52954 .14399 L
.5301 .14399 L
.5301 .08012 L
s
.678 .847 .902 r
.5301 .08012 m
.5301 .1437 L
.53043 .1437 L
.53043 .08012 L
F
.2 .63 .79 r
.5301 .08012 m
.5301 .1437 L
.53043 .1437 L
.53043 .08012 L
s
.678 .847 .902 r
.53043 .08012 m
.53043 .14353 L
.53071 .14353 L
.53071 .08012 L
F
.2 .63 .79 r
.53043 .08012 m
.53043 .14353 L
.53071 .14353 L
.53071 .08012 L
s
.678 .847 .902 r
.53071 .08012 m
.53071 .14322 L
.53122 .14322 L
.53122 .08012 L
F
.2 .63 .79 r
.53071 .08012 m
.53071 .14322 L
.53122 .14322 L
.53122 .08012 L
s
.678 .847 .902 r
.53122 .08012 m
.53122 .14293 L
.53179 .14293 L
.53179 .08012 L
F
.2 .63 .79 r
.53122 .08012 m
.53122 .14293 L
.53179 .14293 L
.53179 .08012 L
s
.678 .847 .902 r
.53179 .08012 m
.53179 .14273 L
.53231 .14273 L
.53231 .08012 L
F
.2 .63 .79 r
.53179 .08012 m
.53179 .14273 L
.53231 .14273 L
.53231 .08012 L
s
.678 .847 .902 r
.53231 .08012 m
.53231 .14236 L
.53281 .14236 L
.53281 .08012 L
F
.2 .63 .79 r
.53231 .08012 m
.53231 .14236 L
.53281 .14236 L
.53281 .08012 L
s
.678 .847 .902 r
.53281 .08012 m
.53281 .1422 L
.53325 .1422 L
.53325 .08012 L
F
.2 .63 .79 r
.53281 .08012 m
.53281 .1422 L
.53325 .1422 L
.53325 .08012 L
s
.678 .847 .902 r
.53325 .08012 m
.53325 .14187 L
.53378 .14187 L
.53378 .08012 L
F
.2 .63 .79 r
.53325 .08012 m
.53325 .14187 L
.53378 .14187 L
.53378 .08012 L
s
.678 .847 .902 r
.53378 .08012 m
.53378 .14142 L
.53438 .14142 L
.53438 .08012 L
F
.2 .63 .79 r
.53378 .08012 m
.53378 .14142 L
.53438 .14142 L
.53438 .08012 L
s
.678 .847 .902 r
.53438 .08012 m
.53438 .14129 L
.53468 .14129 L
.53468 .08012 L
F
.2 .63 .79 r
.53438 .08012 m
.53438 .14129 L
.53468 .14129 L
.53468 .08012 L
s
.678 .847 .902 r
.53468 .08012 m
.53468 .14099 L
.53516 .14099 L
.53516 .08012 L
F
.2 .63 .79 r
.53468 .08012 m
.53468 .14099 L
.53516 .14099 L
.53516 .08012 L
s
.678 .847 .902 r
.53516 .08012 m
.53516 .14084 L
.5354 .14084 L
.5354 .08012 L
F
.2 .63 .79 r
.53516 .08012 m
.53516 .14084 L
.5354 .14084 L
.5354 .08012 L
s
.678 .847 .902 r
.5354 .08012 m
.5354 .14076 L
.53567 .14076 L
.53567 .08012 L
F
.2 .63 .79 r
.5354 .08012 m
.5354 .14076 L
.53567 .14076 L
.53567 .08012 L
s
.678 .847 .902 r
.53567 .08012 m
.53567 .14064 L
.53632 .14064 L
.53632 .08012 L
F
.2 .63 .79 r
.53567 .08012 m
.53567 .14064 L
.53632 .14064 L
.53632 .08012 L
s
.678 .847 .902 r
.53632 .08012 m
.53632 .14008 L
.53694 .14008 L
.53694 .08012 L
F
.2 .63 .79 r
.53632 .08012 m
.53632 .14008 L
.53694 .14008 L
.53694 .08012 L
s
.678 .847 .902 r
.53694 .08012 m
.53694 .13974 L
.53747 .13974 L
.53747 .08012 L
F
.2 .63 .79 r
.53694 .08012 m
.53694 .13974 L
.53747 .13974 L
.53747 .08012 L
s
.678 .847 .902 r
.53747 .08012 m
.53747 .13943 L
.53798 .13943 L
.53798 .08012 L
F
.2 .63 .79 r
.53747 .08012 m
.53747 .13943 L
.53798 .13943 L
.53798 .08012 L
s
.678 .847 .902 r
.53798 .08012 m
.53798 .13913 L
.53844 .13913 L
.53844 .08012 L
F
.2 .63 .79 r
.53798 .08012 m
.53798 .13913 L
.53844 .13913 L
.53844 .08012 L
s
.678 .847 .902 r
.53844 .08012 m
.53844 .13878 L
.53904 .13878 L
.53904 .08012 L
F
.2 .63 .79 r
.53844 .08012 m
.53844 .13878 L
.53904 .13878 L
.53904 .08012 L
s
.678 .847 .902 r
.53904 .08012 m
.53904 .13868 L
.53974 .13868 L
.53974 .08012 L
F
.2 .63 .79 r
.53904 .08012 m
.53904 .13868 L
.53974 .13868 L
.53974 .08012 L
s
.678 .847 .902 r
.53974 .08012 m
.53974 .13796 L
.54044 .13796 L
.54044 .08012 L
F
.2 .63 .79 r
.53974 .08012 m
.53974 .13796 L
.54044 .13796 L
.54044 .08012 L
s
.678 .847 .902 r
.54044 .08012 m
.54044 .13774 L
.54082 .13774 L
.54082 .08012 L
F
.2 .63 .79 r
.54044 .08012 m
.54044 .13774 L
.54082 .13774 L
.54082 .08012 L
s
.678 .847 .902 r
.54082 .08012 m
.54082 .13756 L
.54126 .13756 L
.54126 .08012 L
F
.2 .63 .79 r
.54082 .08012 m
.54082 .13756 L
.54126 .13756 L
.54126 .08012 L
s
.678 .847 .902 r
.54126 .08012 m
.54126 .13736 L
.54162 .13736 L
.54162 .08012 L
F
.2 .63 .79 r
.54126 .08012 m
.54126 .13736 L
.54162 .13736 L
.54162 .08012 L
s
.678 .847 .902 r
.54162 .08012 m
.54162 .13722 L
.54221 .13722 L
.54221 .08012 L
F
.2 .63 .79 r
.54162 .08012 m
.54162 .13722 L
.54221 .13722 L
.54221 .08012 L
s
.678 .847 .902 r
.54221 .08012 m
.54221 .13691 L
.54253 .13691 L
.54253 .08012 L
F
.2 .63 .79 r
.54221 .08012 m
.54221 .13691 L
.54253 .13691 L
.54253 .08012 L
s
.678 .847 .902 r
.54253 .08012 m
.54253 .1365 L
.54319 .1365 L
.54319 .08012 L
F
.2 .63 .79 r
.54253 .08012 m
.54253 .1365 L
.54319 .1365 L
.54319 .08012 L
s
.678 .847 .902 r
.54319 .08012 m
.54319 .13617 L
.54371 .13617 L
.54371 .08012 L
F
.2 .63 .79 r
.54319 .08012 m
.54319 .13617 L
.54371 .13617 L
.54371 .08012 L
s
.678 .847 .902 r
.54371 .08012 m
.54371 .13598 L
.544 .13598 L
.544 .08012 L
F
.2 .63 .79 r
.54371 .08012 m
.54371 .13598 L
.544 .13598 L
.544 .08012 L
s
.678 .847 .902 r
.544 .08012 m
.544 .13581 L
.54456 .13581 L
.54456 .08012 L
F
.2 .63 .79 r
.544 .08012 m
.544 .13581 L
.54456 .13581 L
.54456 .08012 L
s
.678 .847 .902 r
.54456 .08012 m
.54456 .13553 L
.545 .13553 L
.545 .08012 L
F
.2 .63 .79 r
.54456 .08012 m
.54456 .13553 L
.545 .13553 L
.545 .08012 L
s
.678 .847 .902 r
.545 .08012 m
.545 .1353 L
.54572 .1353 L
.54572 .08012 L
F
.2 .63 .79 r
.545 .08012 m
.545 .1353 L
.54572 .1353 L
.54572 .08012 L
s
.678 .847 .902 r
.54572 .08012 m
.54572 .13479 L
.54614 .13479 L
.54614 .08012 L
F
.2 .63 .79 r
.54572 .08012 m
.54572 .13479 L
.54614 .13479 L
.54614 .08012 L
s
.678 .847 .902 r
.54614 .08012 m
.54614 .13451 L
.54662 .13451 L
.54662 .08012 L
F
.2 .63 .79 r
.54614 .08012 m
.54614 .13451 L
.54662 .13451 L
.54662 .08012 L
s
.678 .847 .902 r
.54662 .08012 m
.54662 .13427 L
.54731 .13427 L
.54731 .08012 L
F
.2 .63 .79 r
.54662 .08012 m
.54662 .13427 L
.54731 .13427 L
.54731 .08012 L
s
.678 .847 .902 r
.54731 .08012 m
.54731 .1339 L
.54801 .1339 L
.54801 .08012 L
F
.2 .63 .79 r
.54731 .08012 m
.54731 .1339 L
.54801 .1339 L
.54801 .08012 L
s
.678 .847 .902 r
.54801 .08012 m
.54801 .13359 L
.54837 .13359 L
.54837 .08012 L
F
.2 .63 .79 r
.54801 .08012 m
.54801 .13359 L
.54837 .13359 L
.54837 .08012 L
s
.678 .847 .902 r
.54837 .08012 m
.54837 .13323 L
.54893 .13323 L
.54893 .08012 L
F
.2 .63 .79 r
.54837 .08012 m
.54837 .13323 L
.54893 .13323 L
.54893 .08012 L
s
.678 .847 .902 r
.54893 .08012 m
.54893 .13302 L
.54923 .13302 L
.54923 .08012 L
F
.2 .63 .79 r
.54893 .08012 m
.54893 .13302 L
.54923 .13302 L
.54923 .08012 L
s
.678 .847 .902 r
.54923 .08012 m
.54923 .13283 L
.54962 .13283 L
.54962 .08012 L
F
.2 .63 .79 r
.54923 .08012 m
.54923 .13283 L
.54962 .13283 L
.54962 .08012 L
s
.678 .847 .902 r
.54962 .08012 m
.54962 .13253 L
.5502 .13253 L
.5502 .08012 L
F
.2 .63 .79 r
.54962 .08012 m
.54962 .13253 L
.5502 .13253 L
.5502 .08012 L
s
.678 .847 .902 r
.5502 .08012 m
.5502 .13247 L
.55052 .13247 L
.55052 .08012 L
F
.2 .63 .79 r
.5502 .08012 m
.5502 .13247 L
.55052 .13247 L
.55052 .08012 L
s
.678 .847 .902 r
.55052 .08012 m
.55052 .13227 L
.55094 .13227 L
.55094 .08012 L
F
.2 .63 .79 r
.55052 .08012 m
.55052 .13227 L
.55094 .13227 L
.55094 .08012 L
s
.678 .847 .902 r
.55094 .08012 m
.55094 .1319 L
.55137 .1319 L
.55137 .08012 L
F
.2 .63 .79 r
.55094 .08012 m
.55094 .1319 L
.55137 .1319 L
.55137 .08012 L
s
.678 .847 .902 r
.55137 .08012 m
.55137 .13153 L
.55198 .13153 L
.55198 .08012 L
F
.2 .63 .79 r
.55137 .08012 m
.55137 .13153 L
.55198 .13153 L
.55198 .08012 L
s
.678 .847 .902 r
.55198 .08012 m
.55198 .13145 L
.55265 .13145 L
.55265 .08012 L
F
.2 .63 .79 r
.55198 .08012 m
.55198 .13145 L
.55265 .13145 L
.55265 .08012 L
s
.678 .847 .902 r
.55265 .08012 m
.55265 .13093 L
.55336 .13093 L
.55336 .08012 L
F
.2 .63 .79 r
.55265 .08012 m
.55265 .13093 L
.55336 .13093 L
.55336 .08012 L
s
.678 .847 .902 r
.55336 .08012 m
.55336 .13071 L
.55365 .13071 L
.55365 .08012 L
F
.2 .63 .79 r
.55336 .08012 m
.55336 .13071 L
.55365 .13071 L
.55365 .08012 L
s
.678 .847 .902 r
.55365 .08012 m
.55365 .13048 L
.55389 .13048 L
.55389 .08012 L
F
.2 .63 .79 r
.55365 .08012 m
.55365 .13048 L
.55389 .13048 L
.55389 .08012 L
s
.678 .847 .902 r
.55389 .08012 m
.55389 .13045 L
.55445 .13045 L
.55445 .08012 L
F
.2 .63 .79 r
.55389 .08012 m
.55389 .13045 L
.55445 .13045 L
.55445 .08012 L
s
.678 .847 .902 r
.55445 .08012 m
.55445 .13001 L
.55473 .13001 L
.55473 .08012 L
F
.2 .63 .79 r
.55445 .08012 m
.55445 .13001 L
.55473 .13001 L
.55473 .08012 L
s
.678 .847 .902 r
.55473 .08012 m
.55473 .12987 L
.55523 .12987 L
.55523 .08012 L
F
.2 .63 .79 r
.55473 .08012 m
.55473 .12987 L
.55523 .12987 L
.55523 .08012 L
s
.678 .847 .902 r
.55523 .08012 m
.55523 .12967 L
.5559 .12967 L
.5559 .08012 L
F
.2 .63 .79 r
.55523 .08012 m
.55523 .12967 L
.5559 .12967 L
.5559 .08012 L
s
.678 .847 .902 r
.5559 .08012 m
.5559 .12927 L
.55613 .12927 L
.55613 .08012 L
F
.2 .63 .79 r
.5559 .08012 m
.5559 .12927 L
.55613 .12927 L
.55613 .08012 L
s
.678 .847 .902 r
.55613 .08012 m
.55613 .12906 L
.5567 .12906 L
.5567 .08012 L
F
.2 .63 .79 r
.55613 .08012 m
.55613 .12906 L
.5567 .12906 L
.5567 .08012 L
s
.678 .847 .902 r
.5567 .08012 m
.5567 .12883 L
.55721 .12883 L
.55721 .08012 L
F
.2 .63 .79 r
.5567 .08012 m
.5567 .12883 L
.55721 .12883 L
.55721 .08012 L
s
.678 .847 .902 r
.55721 .08012 m
.55721 .12854 L
.55768 .12854 L
.55768 .08012 L
F
.2 .63 .79 r
.55721 .08012 m
.55721 .12854 L
.55768 .12854 L
.55768 .08012 L
s
.678 .847 .902 r
.55768 .08012 m
.55768 .12817 L
.55816 .12817 L
.55816 .08012 L
F
.2 .63 .79 r
.55768 .08012 m
.55768 .12817 L
.55816 .12817 L
.55816 .08012 L
s
.678 .847 .902 r
.55816 .08012 m
.55816 .12779 L
.55877 .12779 L
.55877 .08012 L
F
.2 .63 .79 r
.55816 .08012 m
.55816 .12779 L
.55877 .12779 L
.55877 .08012 L
s
.678 .847 .902 r
.55877 .08012 m
.55877 .12754 L
.55931 .12754 L
.55931 .08012 L
F
.2 .63 .79 r
.55877 .08012 m
.55877 .12754 L
.55931 .12754 L
.55931 .08012 L
s
.678 .847 .902 r
.55931 .08012 m
.55931 .12733 L
.55965 .12733 L
.55965 .08012 L
F
.2 .63 .79 r
.55931 .08012 m
.55931 .12733 L
.55965 .12733 L
.55965 .08012 L
s
.678 .847 .902 r
.55965 .08012 m
.55965 .12697 L
.5603 .12697 L
.5603 .08012 L
F
.2 .63 .79 r
.55965 .08012 m
.55965 .12697 L
.5603 .12697 L
.5603 .08012 L
s
.678 .847 .902 r
.5603 .08012 m
.5603 .12695 L
.56083 .12695 L
.56083 .08012 L
F
.2 .63 .79 r
.5603 .08012 m
.5603 .12695 L
.56083 .12695 L
.56083 .08012 L
s
.678 .847 .902 r
.56083 .08012 m
.56083 .12648 L
.5612 .12648 L
.5612 .08012 L
F
.2 .63 .79 r
.56083 .08012 m
.56083 .12648 L
.5612 .12648 L
.5612 .08012 L
s
.678 .847 .902 r
.5612 .08012 m
.5612 .12646 L
.56168 .12646 L
.56168 .08012 L
F
.2 .63 .79 r
.5612 .08012 m
.5612 .12646 L
.56168 .12646 L
.56168 .08012 L
s
.678 .847 .902 r
.56168 .08012 m
.56168 .12594 L
.56223 .12594 L
.56223 .08012 L
F
.2 .63 .79 r
.56168 .08012 m
.56168 .12594 L
.56223 .12594 L
.56223 .08012 L
s
.678 .847 .902 r
.56223 .08012 m
.56223 .12576 L
.56256 .12576 L
.56256 .08012 L
F
.2 .63 .79 r
.56223 .08012 m
.56223 .12576 L
.56256 .12576 L
.56256 .08012 L
s
.678 .847 .902 r
.56256 .08012 m
.56256 .12565 L
.56323 .12565 L
.56323 .08012 L
F
.2 .63 .79 r
.56256 .08012 m
.56256 .12565 L
.56323 .12565 L
.56323 .08012 L
s
.678 .847 .902 r
.56323 .08012 m
.56323 .12533 L
.56384 .12533 L
.56384 .08012 L
F
.2 .63 .79 r
.56323 .08012 m
.56323 .12533 L
.56384 .12533 L
.56384 .08012 L
s
.678 .847 .902 r
.56384 .08012 m
.56384 .12479 L
.56445 .12479 L
.56445 .08012 L
F
.2 .63 .79 r
.56384 .08012 m
.56384 .12479 L
.56445 .12479 L
.56445 .08012 L
s
.678 .847 .902 r
.56445 .08012 m
.56445 .12465 L
.56479 .12465 L
.56479 .08012 L
F
.2 .63 .79 r
.56445 .08012 m
.56445 .12465 L
.56479 .12465 L
.56479 .08012 L
s
.678 .847 .902 r
.56479 .08012 m
.56479 .12452 L
.5654 .12452 L
.5654 .08012 L
F
.2 .63 .79 r
.56479 .08012 m
.56479 .12452 L
.5654 .12452 L
.5654 .08012 L
s
.678 .847 .902 r
.5654 .08012 m
.5654 .1241 L
.56599 .1241 L
.56599 .08012 L
F
.2 .63 .79 r
.5654 .08012 m
.5654 .1241 L
.56599 .1241 L
.56599 .08012 L
s
.678 .847 .902 r
.56599 .08012 m
.56599 .1238 L
.56625 .1238 L
.56625 .08012 L
F
.2 .63 .79 r
.56599 .08012 m
.56599 .1238 L
.56625 .1238 L
.56625 .08012 L
s
.678 .847 .902 r
.56625 .08012 m
.56625 .12367 L
.56654 .12367 L
.56654 .08012 L
F
.2 .63 .79 r
.56625 .08012 m
.56625 .12367 L
.56654 .12367 L
.56654 .08012 L
s
.678 .847 .902 r
.56654 .08012 m
.56654 .1235 L
.56687 .1235 L
.56687 .08012 L
F
.2 .63 .79 r
.56654 .08012 m
.56654 .1235 L
.56687 .1235 L
.56687 .08012 L
s
.678 .847 .902 r
.56687 .08012 m
.56687 .12335 L
.56751 .12335 L
.56751 .08012 L
F
.2 .63 .79 r
.56687 .08012 m
.56687 .12335 L
.56751 .12335 L
.56751 .08012 L
s
.678 .847 .902 r
.56751 .08012 m
.56751 .12308 L
.56777 .12308 L
.56777 .08012 L
F
.2 .63 .79 r
.56751 .08012 m
.56751 .12308 L
.56777 .12308 L
.56777 .08012 L
s
.678 .847 .902 r
.56777 .08012 m
.56777 .12294 L
.56822 .12294 L
.56822 .08012 L
F
.2 .63 .79 r
.56777 .08012 m
.56777 .12294 L
.56822 .12294 L
.56822 .08012 L
s
.678 .847 .902 r
.56822 .08012 m
.56822 .12262 L
.56877 .12262 L
.56877 .08012 L
F
.2 .63 .79 r
.56822 .08012 m
.56822 .12262 L
.56877 .12262 L
.56877 .08012 L
s
.678 .847 .902 r
.56877 .08012 m
.56877 .12225 L
.56915 .12225 L
.56915 .08012 L
F
.2 .63 .79 r
.56877 .08012 m
.56877 .12225 L
.56915 .12225 L
.56915 .08012 L
s
.678 .847 .902 r
.56915 .08012 m
.56915 .12213 L
.56966 .12213 L
.56966 .08012 L
F
.2 .63 .79 r
.56915 .08012 m
.56915 .12213 L
.56966 .12213 L
.56966 .08012 L
s
.678 .847 .902 r
.56966 .08012 m
.56966 .12193 L
.57023 .12193 L
.57023 .08012 L
F
.2 .63 .79 r
.56966 .08012 m
.56966 .12193 L
.57023 .12193 L
.57023 .08012 L
s
.678 .847 .902 r
.57023 .08012 m
.57023 .12159 L
.57047 .12159 L
.57047 .08012 L
F
.2 .63 .79 r
.57023 .08012 m
.57023 .12159 L
.57047 .12159 L
.57047 .08012 L
s
.678 .847 .902 r
.57047 .08012 m
.57047 .12154 L
.57073 .12154 L
.57073 .08012 L
F
.2 .63 .79 r
.57047 .08012 m
.57047 .12154 L
.57073 .12154 L
.57073 .08012 L
s
.678 .847 .902 r
.57073 .08012 m
.57073 .12127 L
.57132 .12127 L
.57132 .08012 L
F
.2 .63 .79 r
.57073 .08012 m
.57073 .12127 L
.57132 .12127 L
.57132 .08012 L
s
.678 .847 .902 r
.57132 .08012 m
.57132 .12108 L
.57158 .12108 L
.57158 .08012 L
F
.2 .63 .79 r
.57132 .08012 m
.57132 .12108 L
.57158 .12108 L
.57158 .08012 L
s
.678 .847 .902 r
.57158 .08012 m
.57158 .12077 L
.57218 .12077 L
.57218 .08012 L
F
.2 .63 .79 r
.57158 .08012 m
.57158 .12077 L
.57218 .12077 L
.57218 .08012 L
s
.678 .847 .902 r
.57218 .08012 m
.57218 .12038 L
.57269 .12038 L
.57269 .08012 L
F
.2 .63 .79 r
.57218 .08012 m
.57218 .12038 L
.57269 .12038 L
.57269 .08012 L
s
.678 .847 .902 r
.57269 .08012 m
.57269 .12031 L
.57295 .12031 L
.57295 .08012 L
F
.2 .63 .79 r
.57269 .08012 m
.57269 .12031 L
.57295 .12031 L
.57295 .08012 L
s
.678 .847 .902 r
.57295 .08012 m
.57295 .12018 L
.57361 .12018 L
.57361 .08012 L
F
.2 .63 .79 r
.57295 .08012 m
.57295 .12018 L
.57361 .12018 L
.57361 .08012 L
s
.678 .847 .902 r
.57361 .08012 m
.57361 .11978 L
.57426 .11978 L
.57426 .08012 L
F
.2 .63 .79 r
.57361 .08012 m
.57361 .11978 L
.57426 .11978 L
.57426 .08012 L
s
.678 .847 .902 r
.57426 .08012 m
.57426 .11927 L
.5749 .11927 L
.5749 .08012 L
F
.2 .63 .79 r
.57426 .08012 m
.57426 .11927 L
.5749 .11927 L
.5749 .08012 L
s
.678 .847 .902 r
.5749 .08012 m
.5749 .11908 L
.57528 .11908 L
.57528 .08012 L
F
.2 .63 .79 r
.5749 .08012 m
.5749 .11908 L
.57528 .11908 L
.57528 .08012 L
s
.678 .847 .902 r
.57528 .08012 m
.57528 .11882 L
.57582 .11882 L
.57582 .08012 L
F
.2 .63 .79 r
.57528 .08012 m
.57528 .11882 L
.57582 .11882 L
.57582 .08012 L
s
.678 .847 .902 r
.57582 .08012 m
.57582 .11871 L
.57609 .11871 L
.57609 .08012 L
F
.2 .63 .79 r
.57582 .08012 m
.57582 .11871 L
.57609 .11871 L
.57609 .08012 L
s
.678 .847 .902 r
.57609 .08012 m
.57609 .11854 L
.57636 .11854 L
.57636 .08012 L
F
.2 .63 .79 r
.57609 .08012 m
.57609 .11854 L
.57636 .11854 L
.57636 .08012 L
s
.678 .847 .902 r
.57636 .08012 m
.57636 .11831 L
.57669 .11831 L
.57669 .08012 L
F
.2 .63 .79 r
.57636 .08012 m
.57636 .11831 L
.57669 .11831 L
.57669 .08012 L
s
.678 .847 .902 r
.57669 .08012 m
.57669 .11826 L
.57716 .11826 L
.57716 .08012 L
F
.2 .63 .79 r
.57669 .08012 m
.57669 .11826 L
.57716 .11826 L
.57716 .08012 L
s
.678 .847 .902 r
.57716 .08012 m
.57716 .11785 L
.57783 .11785 L
.57783 .08012 L
F
.2 .63 .79 r
.57716 .08012 m
.57716 .11785 L
.57783 .11785 L
.57783 .08012 L
s
.678 .847 .902 r
.57783 .08012 m
.57783 .11766 L
.57819 .11766 L
.57819 .08012 L
F
.2 .63 .79 r
.57783 .08012 m
.57783 .11766 L
.57819 .11766 L
.57819 .08012 L
s
.678 .847 .902 r
.57819 .08012 m
.57819 .1174 L
.57849 .1174 L
.57849 .08012 L
F
.2 .63 .79 r
.57819 .08012 m
.57819 .1174 L
.57849 .1174 L
.57849 .08012 L
s
.678 .847 .902 r
.57849 .08012 m
.57849 .11723 L
.57873 .11723 L
.57873 .08012 L
F
.2 .63 .79 r
.57849 .08012 m
.57849 .11723 L
.57873 .11723 L
.57873 .08012 L
s
.678 .847 .902 r
.57873 .08012 m
.57873 .1172 L
.57906 .1172 L
.57906 .08012 L
F
.2 .63 .79 r
.57873 .08012 m
.57873 .1172 L
.57906 .1172 L
.57906 .08012 L
s
.678 .847 .902 r
.57906 .08012 m
.57906 .11695 L
.57976 .11695 L
.57976 .08012 L
F
.2 .63 .79 r
.57906 .08012 m
.57906 .11695 L
.57976 .11695 L
.57976 .08012 L
s
.678 .847 .902 r
.57976 .08012 m
.57976 .11661 L
.58029 .11661 L
.58029 .08012 L
F
.2 .63 .79 r
.57976 .08012 m
.57976 .11661 L
.58029 .11661 L
.58029 .08012 L
s
.678 .847 .902 r
.58029 .08012 m
.58029 .11625 L
.58069 .11625 L
.58069 .08012 L
F
.2 .63 .79 r
.58029 .08012 m
.58029 .11625 L
.58069 .11625 L
.58069 .08012 L
s
.678 .847 .902 r
.58069 .08012 m
.58069 .11612 L
.581 .11612 L
.581 .08012 L
F
.2 .63 .79 r
.58069 .08012 m
.58069 .11612 L
.581 .11612 L
.581 .08012 L
s
.678 .847 .902 r
.581 .08012 m
.581 .11596 L
.58166 .11596 L
.58166 .08012 L
F
.2 .63 .79 r
.581 .08012 m
.581 .11596 L
.58166 .11596 L
.58166 .08012 L
s
.678 .847 .902 r
.58166 .08012 m
.58166 .11541 L
.58233 .11541 L
.58233 .08012 L
F
.2 .63 .79 r
.58166 .08012 m
.58166 .11541 L
.58233 .11541 L
.58233 .08012 L
s
.678 .847 .902 r
.58233 .08012 m
.58233 .11524 L
.5827 .11524 L
.5827 .08012 L
F
.2 .63 .79 r
.58233 .08012 m
.58233 .11524 L
.5827 .11524 L
.5827 .08012 L
s
.678 .847 .902 r
.5827 .08012 m
.5827 .11518 L
.58314 .11518 L
.58314 .08012 L
F
.2 .63 .79 r
.5827 .08012 m
.5827 .11518 L
.58314 .11518 L
.58314 .08012 L
s
.678 .847 .902 r
.58314 .08012 m
.58314 .11491 L
.58351 .11491 L
.58351 .08012 L
F
.2 .63 .79 r
.58314 .08012 m
.58314 .11491 L
.58351 .11491 L
.58351 .08012 L
s
.678 .847 .902 r
.58351 .08012 m
.58351 .11464 L
.58413 .11464 L
.58413 .08012 L
F
.2 .63 .79 r
.58351 .08012 m
.58351 .11464 L
.58413 .11464 L
.58413 .08012 L
s
.678 .847 .902 r
.58413 .08012 m
.58413 .11432 L
.58457 .11432 L
.58457 .08012 L
F
.2 .63 .79 r
.58413 .08012 m
.58413 .11432 L
.58457 .11432 L
.58457 .08012 L
s
.678 .847 .902 r
.58457 .08012 m
.58457 .11404 L
.58509 .11404 L
.58509 .08012 L
F
.2 .63 .79 r
.58457 .08012 m
.58457 .11404 L
.58509 .11404 L
.58509 .08012 L
s
.678 .847 .902 r
.58509 .08012 m
.58509 .11386 L
.58555 .11386 L
.58555 .08012 L
F
.2 .63 .79 r
.58509 .08012 m
.58509 .11386 L
.58555 .11386 L
.58555 .08012 L
s
.678 .847 .902 r
.58555 .08012 m
.58555 .11356 L
.58601 .11356 L
.58601 .08012 L
F
.2 .63 .79 r
.58555 .08012 m
.58555 .11356 L
.58601 .11356 L
.58601 .08012 L
s
.678 .847 .902 r
.58601 .08012 m
.58601 .11321 L
.58664 .11321 L
.58664 .08012 L
F
.2 .63 .79 r
.58601 .08012 m
.58601 .11321 L
.58664 .11321 L
.58664 .08012 L
s
.678 .847 .902 r
.58664 .08012 m
.58664 .11306 L
.58712 .11306 L
.58712 .08012 L
F
.2 .63 .79 r
.58664 .08012 m
.58664 .11306 L
.58712 .11306 L
.58712 .08012 L
s
.678 .847 .902 r
.58712 .08012 m
.58712 .11294 L
.58753 .11294 L
.58753 .08012 L
F
.2 .63 .79 r
.58712 .08012 m
.58712 .11294 L
.58753 .11294 L
.58753 .08012 L
s
.678 .847 .902 r
.58753 .08012 m
.58753 .11258 L
.58787 .11258 L
.58787 .08012 L
F
.2 .63 .79 r
.58753 .08012 m
.58753 .11258 L
.58787 .11258 L
.58787 .08012 L
s
.678 .847 .902 r
.58787 .08012 m
.58787 .11241 L
.58825 .11241 L
.58825 .08012 L
F
.2 .63 .79 r
.58787 .08012 m
.58787 .11241 L
.58825 .11241 L
.58825 .08012 L
s
.678 .847 .902 r
.58825 .08012 m
.58825 .11211 L
.5888 .11211 L
.5888 .08012 L
F
.2 .63 .79 r
.58825 .08012 m
.58825 .11211 L
.5888 .11211 L
.5888 .08012 L
s
.678 .847 .902 r
.5888 .08012 m
.5888 .11199 L
.58907 .11199 L
.58907 .08012 L
F
.2 .63 .79 r
.5888 .08012 m
.5888 .11199 L
.58907 .11199 L
.58907 .08012 L
s
.678 .847 .902 r
.58907 .08012 m
.58907 .11194 L
.58933 .11194 L
.58933 .08012 L
F
.2 .63 .79 r
.58907 .08012 m
.58907 .11194 L
.58933 .11194 L
.58933 .08012 L
s
.678 .847 .902 r
.58933 .08012 m
.58933 .11169 L
.58968 .11169 L
.58968 .08012 L
F
.2 .63 .79 r
.58933 .08012 m
.58933 .11169 L
.58968 .11169 L
.58968 .08012 L
s
.678 .847 .902 r
.58968 .08012 m
.58968 .11149 L
.59012 .11149 L
.59012 .08012 L
F
.2 .63 .79 r
.58968 .08012 m
.58968 .11149 L
.59012 .11149 L
.59012 .08012 L
s
.678 .847 .902 r
.59012 .08012 m
.59012 .11136 L
.59041 .11136 L
.59041 .08012 L
F
.2 .63 .79 r
.59012 .08012 m
.59012 .11136 L
.59041 .11136 L
.59041 .08012 L
s
.678 .847 .902 r
.59041 .08012 m
.59041 .11109 L
.59088 .11109 L
.59088 .08012 L
F
.2 .63 .79 r
.59041 .08012 m
.59041 .11109 L
.59088 .11109 L
.59088 .08012 L
s
.678 .847 .902 r
.59088 .08012 m
.59088 .11072 L
.59156 .11072 L
.59156 .08012 L
F
.2 .63 .79 r
.59088 .08012 m
.59088 .11072 L
.59156 .11072 L
.59156 .08012 L
s
.678 .847 .902 r
.59156 .08012 m
.59156 .11069 L
.59191 .11069 L
.59191 .08012 L
F
.2 .63 .79 r
.59156 .08012 m
.59156 .11069 L
.59191 .11069 L
.59191 .08012 L
s
.678 .847 .902 r
.59191 .08012 m
.59191 .1105 L
.59228 .1105 L
.59228 .08012 L
F
.2 .63 .79 r
.59191 .08012 m
.59191 .1105 L
.59228 .1105 L
.59228 .08012 L
s
.678 .847 .902 r
.59228 .08012 m
.59228 .11012 L
.59281 .11012 L
.59281 .08012 L
F
.2 .63 .79 r
.59228 .08012 m
.59228 .11012 L
.59281 .11012 L
.59281 .08012 L
s
.678 .847 .902 r
.59281 .08012 m
.59281 .11004 L
.59334 .11004 L
.59334 .08012 L
F
.2 .63 .79 r
.59281 .08012 m
.59281 .11004 L
.59334 .11004 L
.59334 .08012 L
s
.678 .847 .902 r
.59334 .08012 m
.59334 .10981 L
.59398 .10981 L
.59398 .08012 L
F
.2 .63 .79 r
.59334 .08012 m
.59334 .10981 L
.59398 .10981 L
.59398 .08012 L
s
.678 .847 .902 r
.59398 .08012 m
.59398 .10918 L
.59471 .10918 L
.59471 .08012 L
F
.2 .63 .79 r
.59398 .08012 m
.59398 .10918 L
.59471 .10918 L
.59471 .08012 L
s
.678 .847 .902 r
.59471 .08012 m
.59471 .10901 L
.59535 .10901 L
.59535 .08012 L
F
.2 .63 .79 r
.59471 .08012 m
.59471 .10901 L
.59535 .10901 L
.59535 .08012 L
s
.678 .847 .902 r
.59535 .08012 m
.59535 .10875 L
.59567 .10875 L
.59567 .08012 L
F
.2 .63 .79 r
.59535 .08012 m
.59535 .10875 L
.59567 .10875 L
.59567 .08012 L
s
.678 .847 .902 r
.59567 .08012 m
.59567 .10863 L
.59599 .10863 L
.59599 .08012 L
F
.2 .63 .79 r
.59567 .08012 m
.59567 .10863 L
.59599 .10863 L
.59599 .08012 L
s
.678 .847 .902 r
.59599 .08012 m
.59599 .10841 L
.59649 .10841 L
.59649 .08012 L
F
.2 .63 .79 r
.59599 .08012 m
.59599 .10841 L
.59649 .10841 L
.59649 .08012 L
s
.678 .847 .902 r
.59649 .08012 m
.59649 .10814 L
.59688 .10814 L
.59688 .08012 L
F
.2 .63 .79 r
.59649 .08012 m
.59649 .10814 L
.59688 .10814 L
.59688 .08012 L
s
.678 .847 .902 r
.59688 .08012 m
.59688 .10795 L
.5973 .10795 L
.5973 .08012 L
F
.2 .63 .79 r
.59688 .08012 m
.59688 .10795 L
.5973 .10795 L
.5973 .08012 L
s
.678 .847 .902 r
.5973 .08012 m
.5973 .10765 L
.59788 .10765 L
.59788 .08012 L
F
.2 .63 .79 r
.5973 .08012 m
.5973 .10765 L
.59788 .10765 L
.59788 .08012 L
s
.678 .847 .902 r
.59788 .08012 m
.59788 .10753 L
.59819 .10753 L
.59819 .08012 L
F
.2 .63 .79 r
.59788 .08012 m
.59788 .10753 L
.59819 .10753 L
.59819 .08012 L
s
.678 .847 .902 r
.59819 .08012 m
.59819 .10734 L
.59845 .10734 L
.59845 .08012 L
F
.2 .63 .79 r
.59819 .08012 m
.59819 .10734 L
.59845 .10734 L
.59845 .08012 L
s
.678 .847 .902 r
.59845 .08012 m
.59845 .1072 L
.59872 .1072 L
.59872 .08012 L
F
.2 .63 .79 r
.59845 .08012 m
.59845 .1072 L
.59872 .1072 L
.59872 .08012 L
s
.678 .847 .902 r
.59872 .08012 m
.59872 .10708 L
.59897 .10708 L
.59897 .08012 L
F
.2 .63 .79 r
.59872 .08012 m
.59872 .10708 L
.59897 .10708 L
.59897 .08012 L
s
.678 .847 .902 r
.59897 .08012 m
.59897 .10699 L
.59923 .10699 L
.59923 .08012 L
F
.2 .63 .79 r
.59897 .08012 m
.59897 .10699 L
.59923 .10699 L
.59923 .08012 L
s
.678 .847 .902 r
.59923 .08012 m
.59923 .10672 L
.59996 .10672 L
.59996 .08012 L
F
.2 .63 .79 r
.59923 .08012 m
.59923 .10672 L
.59996 .10672 L
.59996 .08012 L
s
.678 .847 .902 r
.59996 .08012 m
.59996 .10627 L
.60061 .10627 L
.60061 .08012 L
F
.2 .63 .79 r
.59996 .08012 m
.59996 .10627 L
.60061 .10627 L
.60061 .08012 L
s
.678 .847 .902 r
.60061 .08012 m
.60061 .10625 L
.60114 .10625 L
.60114 .08012 L
F
.2 .63 .79 r
.60061 .08012 m
.60061 .10625 L
.60114 .10625 L
.60114 .08012 L
s
.678 .847 .902 r
.60114 .08012 m
.60114 .10566 L
.60184 .10566 L
.60184 .08012 L
F
.2 .63 .79 r
.60114 .08012 m
.60114 .10566 L
.60184 .10566 L
.60184 .08012 L
s
.678 .847 .902 r
.60184 .08012 m
.60184 .10548 L
.60232 .10548 L
.60232 .08012 L
F
.2 .63 .79 r
.60184 .08012 m
.60184 .10548 L
.60232 .10548 L
.60232 .08012 L
s
.678 .847 .902 r
.60232 .08012 m
.60232 .1051 L
.60302 .1051 L
.60302 .08012 L
F
.2 .63 .79 r
.60232 .08012 m
.60232 .1051 L
.60302 .1051 L
.60302 .08012 L
s
.678 .847 .902 r
.60302 .08012 m
.60302 .10491 L
.60342 .10491 L
.60342 .08012 L
F
.2 .63 .79 r
.60302 .08012 m
.60302 .10491 L
.60342 .10491 L
.60342 .08012 L
s
.678 .847 .902 r
.60342 .08012 m
.60342 .10469 L
.60398 .10469 L
.60398 .08012 L
F
.2 .63 .79 r
.60342 .08012 m
.60342 .10469 L
.60398 .10469 L
.60398 .08012 L
s
.678 .847 .902 r
.60398 .08012 m
.60398 .10435 L
.60466 .10435 L
.60466 .08012 L
F
.2 .63 .79 r
.60398 .08012 m
.60398 .10435 L
.60466 .10435 L
.60466 .08012 L
s
.678 .847 .902 r
.60466 .08012 m
.60466 .10415 L
.60505 .10415 L
.60505 .08012 L
F
.2 .63 .79 r
.60466 .08012 m
.60466 .10415 L
.60505 .10415 L
.60505 .08012 L
s
.678 .847 .902 r
.60505 .08012 m
.60505 .10391 L
.60555 .10391 L
.60555 .08012 L
F
.2 .63 .79 r
.60505 .08012 m
.60505 .10391 L
.60555 .10391 L
.60555 .08012 L
s
.678 .847 .902 r
.60555 .08012 m
.60555 .10365 L
.6061 .10365 L
.6061 .08012 L
F
.2 .63 .79 r
.60555 .08012 m
.60555 .10365 L
.6061 .10365 L
.6061 .08012 L
s
.678 .847 .902 r
.6061 .08012 m
.6061 .10355 L
.60637 .10355 L
.60637 .08012 L
F
.2 .63 .79 r
.6061 .08012 m
.6061 .10355 L
.60637 .10355 L
.60637 .08012 L
s
.678 .847 .902 r
.60637 .08012 m
.60637 .10344 L
.60665 .10344 L
.60665 .08012 L
F
.2 .63 .79 r
.60637 .08012 m
.60637 .10344 L
.60665 .10344 L
.60665 .08012 L
s
.678 .847 .902 r
.60665 .08012 m
.60665 .10324 L
.60704 .10324 L
.60704 .08012 L
F
.2 .63 .79 r
.60665 .08012 m
.60665 .10324 L
.60704 .10324 L
.60704 .08012 L
s
.678 .847 .902 r
.60704 .08012 m
.60704 .10309 L
.60732 .10309 L
.60732 .08012 L
F
.2 .63 .79 r
.60704 .08012 m
.60704 .10309 L
.60732 .10309 L
.60732 .08012 L
s
.678 .847 .902 r
.60732 .08012 m
.60732 .10282 L
.60793 .10282 L
.60793 .08012 L
F
.2 .63 .79 r
.60732 .08012 m
.60732 .10282 L
.60793 .10282 L
.60793 .08012 L
s
.678 .847 .902 r
.60793 .08012 m
.60793 .10256 L
.60852 .10256 L
.60852 .08012 L
F
.2 .63 .79 r
.60793 .08012 m
.60793 .10256 L
.60852 .10256 L
.60852 .08012 L
s
.678 .847 .902 r
.60852 .08012 m
.60852 .10226 L
.60906 .10226 L
.60906 .08012 L
F
.2 .63 .79 r
.60852 .08012 m
.60852 .10226 L
.60906 .10226 L
.60906 .08012 L
s
.678 .847 .902 r
.60906 .08012 m
.60906 .10185 L
.60977 .10185 L
.60977 .08012 L
F
.2 .63 .79 r
.60906 .08012 m
.60906 .10185 L
.60977 .10185 L
.60977 .08012 L
s
.678 .847 .902 r
.60977 .08012 m
.60977 .10161 L
.61033 .10161 L
.61033 .08012 L
F
.2 .63 .79 r
.60977 .08012 m
.60977 .10161 L
.61033 .10161 L
.61033 .08012 L
s
.678 .847 .902 r
.61033 .08012 m
.61033 .10138 L
.61087 .10138 L
.61087 .08012 L
F
.2 .63 .79 r
.61033 .08012 m
.61033 .10138 L
.61087 .10138 L
.61087 .08012 L
s
.678 .847 .902 r
.61087 .08012 m
.61087 .1011 L
.61139 .1011 L
.61139 .08012 L
F
.2 .63 .79 r
.61087 .08012 m
.61087 .1011 L
.61139 .1011 L
.61139 .08012 L
s
.678 .847 .902 r
.61139 .08012 m
.61139 .10093 L
.61205 .10093 L
.61205 .08012 L
F
.2 .63 .79 r
.61139 .08012 m
.61139 .10093 L
.61205 .10093 L
.61205 .08012 L
s
.678 .847 .902 r
.61205 .08012 m
.61205 .10069 L
.61262 .10069 L
.61262 .08012 L
F
.2 .63 .79 r
.61205 .08012 m
.61205 .10069 L
.61262 .10069 L
.61262 .08012 L
s
.678 .847 .902 r
.61262 .08012 m
.61262 .10026 L
.61323 .10026 L
.61323 .08012 L
F
.2 .63 .79 r
.61262 .08012 m
.61262 .10026 L
.61323 .10026 L
.61323 .08012 L
s
.678 .847 .902 r
.61323 .08012 m
.61323 .09991 L
.61395 .09991 L
.61395 .08012 L
F
.2 .63 .79 r
.61323 .08012 m
.61323 .09991 L
.61395 .09991 L
.61395 .08012 L
s
.678 .847 .902 r
.61395 .08012 m
.61395 .09972 L
.61464 .09972 L
.61464 .08012 L
F
.2 .63 .79 r
.61395 .08012 m
.61395 .09972 L
.61464 .09972 L
.61464 .08012 L
s
.678 .847 .902 r
.61464 .08012 m
.61464 .09946 L
.61495 .09946 L
.61495 .08012 L
F
.2 .63 .79 r
.61464 .08012 m
.61464 .09946 L
.61495 .09946 L
.61495 .08012 L
s
.678 .847 .902 r
.61495 .08012 m
.61495 .09914 L
.61559 .09914 L
.61559 .08012 L
F
.2 .63 .79 r
.61495 .08012 m
.61495 .09914 L
.61559 .09914 L
.61559 .08012 L
s
.678 .847 .902 r
.61559 .08012 m
.61559 .09885 L
.61613 .09885 L
.61613 .08012 L
F
.2 .63 .79 r
.61559 .08012 m
.61559 .09885 L
.61613 .09885 L
.61613 .08012 L
s
.678 .847 .902 r
.61613 .08012 m
.61613 .09873 L
.61648 .09873 L
.61648 .08012 L
F
.2 .63 .79 r
.61613 .08012 m
.61613 .09873 L
.61648 .09873 L
.61648 .08012 L
s
.678 .847 .902 r
.61648 .08012 m
.61648 .09856 L
.61684 .09856 L
.61684 .08012 L
F
.2 .63 .79 r
.61648 .08012 m
.61648 .09856 L
.61684 .09856 L
.61684 .08012 L
s
.678 .847 .902 r
.61684 .08012 m
.61684 .09849 L
.61732 .09849 L
.61732 .08012 L
F
.2 .63 .79 r
.61684 .08012 m
.61684 .09849 L
.61732 .09849 L
.61732 .08012 L
s
.678 .847 .902 r
.61732 .08012 m
.61732 .09827 L
.61758 .09827 L
.61758 .08012 L
F
.2 .63 .79 r
.61732 .08012 m
.61732 .09827 L
.61758 .09827 L
.61758 .08012 L
s
.678 .847 .902 r
.61758 .08012 m
.61758 .09795 L
.6181 .09795 L
.6181 .08012 L
F
.2 .63 .79 r
.61758 .08012 m
.61758 .09795 L
.6181 .09795 L
.6181 .08012 L
s
.678 .847 .902 r
.6181 .08012 m
.6181 .09787 L
.61841 .09787 L
.61841 .08012 L
F
.2 .63 .79 r
.6181 .08012 m
.6181 .09787 L
.61841 .09787 L
.61841 .08012 L
s
.678 .847 .902 r
.61841 .08012 m
.61841 .09761 L
.61883 .09761 L
.61883 .08012 L
F
.2 .63 .79 r
.61841 .08012 m
.61841 .09761 L
.61883 .09761 L
.61883 .08012 L
s
.678 .847 .902 r
.61883 .08012 m
.61883 .0974 L
.61943 .0974 L
.61943 .08012 L
F
.2 .63 .79 r
.61883 .08012 m
.61883 .0974 L
.61943 .0974 L
.61943 .08012 L
s
.678 .847 .902 r
.61943 .08012 m
.61943 .0972 L
.61989 .0972 L
.61989 .08012 L
F
.2 .63 .79 r
.61943 .08012 m
.61943 .0972 L
.61989 .0972 L
.61989 .08012 L
s
.678 .847 .902 r
.61989 .08012 m
.61989 .09694 L
.62032 .09694 L
.62032 .08012 L
F
.2 .63 .79 r
.61989 .08012 m
.61989 .09694 L
.62032 .09694 L
.62032 .08012 L
s
.678 .847 .902 r
.62032 .08012 m
.62032 .09681 L
.62089 .09681 L
.62089 .08012 L
F
.2 .63 .79 r
.62032 .08012 m
.62032 .09681 L
.62089 .09681 L
.62089 .08012 L
s
.678 .847 .902 r
.62089 .08012 m
.62089 .09651 L
.62116 .09651 L
.62116 .08012 L
F
.2 .63 .79 r
.62089 .08012 m
.62089 .09651 L
.62116 .09651 L
.62116 .08012 L
s
.678 .847 .902 r
.62116 .08012 m
.62116 .09639 L
.62165 .09639 L
.62165 .08012 L
F
.2 .63 .79 r
.62116 .08012 m
.62116 .09639 L
.62165 .09639 L
.62165 .08012 L
s
.678 .847 .902 r
.62165 .08012 m
.62165 .09604 L
.62225 .09604 L
.62225 .08012 L
F
.2 .63 .79 r
.62165 .08012 m
.62165 .09604 L
.62225 .09604 L
.62225 .08012 L
s
.678 .847 .902 r
.62225 .08012 m
.62225 .09594 L
.6225 .09594 L
.6225 .08012 L
F
.2 .63 .79 r
.62225 .08012 m
.62225 .09594 L
.6225 .09594 L
.6225 .08012 L
s
.678 .847 .902 r
.6225 .08012 m
.6225 .09588 L
.62299 .09588 L
.62299 .08012 L
F
.2 .63 .79 r
.6225 .08012 m
.6225 .09588 L
.62299 .09588 L
.62299 .08012 L
s
.678 .847 .902 r
.62299 .08012 m
.62299 .09565 L
.62354 .09565 L
.62354 .08012 L
F
.2 .63 .79 r
.62299 .08012 m
.62299 .09565 L
.62354 .09565 L
.62354 .08012 L
s
.678 .847 .902 r
.62354 .08012 m
.62354 .09535 L
.62379 .09535 L
.62379 .08012 L
F
.2 .63 .79 r
.62354 .08012 m
.62354 .09535 L
.62379 .09535 L
.62379 .08012 L
s
.678 .847 .902 r
.62379 .08012 m
.62379 .09517 L
.62416 .09517 L
.62416 .08012 L
F
.2 .63 .79 r
.62379 .08012 m
.62379 .09517 L
.62416 .09517 L
.62416 .08012 L
s
.678 .847 .902 r
.62416 .08012 m
.62416 .09509 L
.62466 .09509 L
.62466 .08012 L
F
.2 .63 .79 r
.62416 .08012 m
.62416 .09509 L
.62466 .09509 L
.62466 .08012 L
s
.678 .847 .902 r
.62466 .08012 m
.62466 .09474 L
.62525 .09474 L
.62525 .08012 L
F
.2 .63 .79 r
.62466 .08012 m
.62466 .09474 L
.62525 .09474 L
.62525 .08012 L
s
.678 .847 .902 r
.62525 .08012 m
.62525 .09463 L
.62593 .09463 L
.62593 .08012 L
F
.2 .63 .79 r
.62525 .08012 m
.62525 .09463 L
.62593 .09463 L
.62593 .08012 L
s
.678 .847 .902 r
.62593 .08012 m
.62593 .09414 L
.62638 .09414 L
.62638 .08012 L
F
.2 .63 .79 r
.62593 .08012 m
.62593 .09414 L
.62638 .09414 L
.62638 .08012 L
s
.678 .847 .902 r
.62638 .08012 m
.62638 .09405 L
.62707 .09405 L
.62707 .08012 L
F
.2 .63 .79 r
.62638 .08012 m
.62638 .09405 L
.62707 .09405 L
.62707 .08012 L
s
.678 .847 .902 r
.62707 .08012 m
.62707 .09362 L
.62753 .09362 L
.62753 .08012 L
F
.2 .63 .79 r
.62707 .08012 m
.62707 .09362 L
.62753 .09362 L
.62753 .08012 L
s
.678 .847 .902 r
.62753 .08012 m
.62753 .09353 L
.62807 .09353 L
.62807 .08012 L
F
.2 .63 .79 r
.62753 .08012 m
.62753 .09353 L
.62807 .09353 L
.62807 .08012 L
s
.678 .847 .902 r
.62807 .08012 m
.62807 .09309 L
.62877 .09309 L
.62877 .08012 L
F
.2 .63 .79 r
.62807 .08012 m
.62807 .09309 L
.62877 .09309 L
.62877 .08012 L
s
.678 .847 .902 r
.62877 .08012 m
.62877 .09302 L
.62943 .09302 L
.62943 .08012 L
F
.2 .63 .79 r
.62877 .08012 m
.62877 .09302 L
.62943 .09302 L
.62943 .08012 L
s
.678 .847 .902 r
.62943 .08012 m
.62943 .09245 L
.63009 .09245 L
.63009 .08012 L
F
.2 .63 .79 r
.62943 .08012 m
.62943 .09245 L
.63009 .09245 L
.63009 .08012 L
s
.678 .847 .902 r
.63009 .08012 m
.63009 .09227 L
.63055 .09227 L
.63055 .08012 L
F
.2 .63 .79 r
.63009 .08012 m
.63009 .09227 L
.63055 .09227 L
.63055 .08012 L
s
.678 .847 .902 r
.63055 .08012 m
.63055 .09203 L
.63105 .09203 L
.63105 .08012 L
F
.2 .63 .79 r
.63055 .08012 m
.63055 .09203 L
.63105 .09203 L
.63105 .08012 L
s
.678 .847 .902 r
.63105 .08012 m
.63105 .09197 L
.63132 .09197 L
.63132 .08012 L
F
.2 .63 .79 r
.63105 .08012 m
.63105 .09197 L
.63132 .09197 L
.63132 .08012 L
s
.678 .847 .902 r
.63132 .08012 m
.63132 .09181 L
.63174 .09181 L
.63174 .08012 L
F
.2 .63 .79 r
.63132 .08012 m
.63132 .09181 L
.63174 .09181 L
.63174 .08012 L
s
.678 .847 .902 r
.63174 .08012 m
.63174 .0917 L
.63198 .0917 L
.63198 .08012 L
F
.2 .63 .79 r
.63174 .08012 m
.63174 .0917 L
.63198 .0917 L
.63198 .08012 L
s
.678 .847 .902 r
.63198 .08012 m
.63198 .09142 L
.63265 .09142 L
.63265 .08012 L
F
.2 .63 .79 r
.63198 .08012 m
.63198 .09142 L
.63265 .09142 L
.63265 .08012 L
s
.678 .847 .902 r
.63265 .08012 m
.63265 .09117 L
.63338 .09117 L
.63338 .08012 L
F
.2 .63 .79 r
.63265 .08012 m
.63265 .09117 L
.63338 .09117 L
.63338 .08012 L
s
.678 .847 .902 r
.63338 .08012 m
.63338 .09069 L
.63405 .09069 L
.63405 .08012 L
F
.2 .63 .79 r
.63338 .08012 m
.63338 .09069 L
.63405 .09069 L
.63405 .08012 L
s
.678 .847 .902 r
.63405 .08012 m
.63405 .09065 L
.63442 .09065 L
.63442 .08012 L
F
.2 .63 .79 r
.63405 .08012 m
.63405 .09065 L
.63442 .09065 L
.63442 .08012 L
s
.678 .847 .902 r
.63442 .08012 m
.63442 .09051 L
.63505 .09051 L
.63505 .08012 L
F
.2 .63 .79 r
.63442 .08012 m
.63442 .09051 L
.63505 .09051 L
.63505 .08012 L
s
.678 .847 .902 r
.63505 .08012 m
.63505 .09017 L
.63552 .09017 L
.63552 .08012 L
F
.2 .63 .79 r
.63505 .08012 m
.63505 .09017 L
.63552 .09017 L
.63552 .08012 L
s
.678 .847 .902 r
.63552 .08012 m
.63552 .0899 L
.63585 .0899 L
.63585 .08012 L
F
.2 .63 .79 r
.63552 .08012 m
.63552 .0899 L
.63585 .0899 L
.63585 .08012 L
s
.678 .847 .902 r
.63585 .08012 m
.63585 .08979 L
.63619 .08979 L
.63619 .08012 L
F
.2 .63 .79 r
.63585 .08012 m
.63585 .08979 L
.63619 .08979 L
.63619 .08012 L
s
.678 .847 .902 r
.63619 .08012 m
.63619 .08968 L
.63668 .08968 L
.63668 .08012 L
F
.2 .63 .79 r
.63619 .08012 m
.63619 .08968 L
.63668 .08968 L
.63668 .08012 L
s
.678 .847 .902 r
.63668 .08012 m
.63668 .08948 L
.63737 .08948 L
.63737 .08012 L
F
.2 .63 .79 r
.63668 .08012 m
.63668 .08948 L
.63737 .08948 L
.63737 .08012 L
s
.678 .847 .902 r
.63737 .08012 m
.63737 .08915 L
.63785 .08915 L
.63785 .08012 L
F
.2 .63 .79 r
.63737 .08012 m
.63737 .08915 L
.63785 .08915 L
.63785 .08012 L
s
.678 .847 .902 r
.63785 .08012 m
.63785 .08891 L
.63824 .08891 L
.63824 .08012 L
F
.2 .63 .79 r
.63785 .08012 m
.63785 .08891 L
.63824 .08891 L
.63824 .08012 L
s
.678 .847 .902 r
.63824 .08012 m
.63824 .0888 L
.63849 .0888 L
.63849 .08012 L
F
.2 .63 .79 r
.63824 .08012 m
.63824 .0888 L
.63849 .0888 L
.63849 .08012 L
s
.678 .847 .902 r
.63849 .08012 m
.63849 .08863 L
.63872 .08863 L
.63872 .08012 L
F
.2 .63 .79 r
.63849 .08012 m
.63849 .08863 L
.63872 .08863 L
.63872 .08012 L
s
.678 .847 .902 r
.63872 .08012 m
.63872 .08858 L
.63895 .08858 L
.63895 .08012 L
F
.2 .63 .79 r
.63872 .08012 m
.63872 .08858 L
.63895 .08858 L
.63895 .08012 L
s
.678 .847 .902 r
.63895 .08012 m
.63895 .08845 L
.63953 .08845 L
.63953 .08012 L
F
.2 .63 .79 r
.63895 .08012 m
.63895 .08845 L
.63953 .08845 L
.63953 .08012 L
s
.678 .847 .902 r
.63953 .08012 m
.63953 .0882 L
.63981 .0882 L
.63981 .08012 L
F
.2 .63 .79 r
.63953 .08012 m
.63953 .0882 L
.63981 .0882 L
.63981 .08012 L
s
.678 .847 .902 r
.63981 .08012 m
.63981 .08803 L
.64011 .08803 L
.64011 .08012 L
F
.2 .63 .79 r
.63981 .08012 m
.63981 .08803 L
.64011 .08803 L
.64011 .08012 L
s
.678 .847 .902 r
.64011 .08012 m
.64011 .08796 L
.64042 .08796 L
.64042 .08012 L
F
.2 .63 .79 r
.64011 .08012 m
.64011 .08796 L
.64042 .08796 L
.64042 .08012 L
s
.678 .847 .902 r
.64042 .08012 m
.64042 .08781 L
.64076 .08781 L
.64076 .08012 L
F
.2 .63 .79 r
.64042 .08012 m
.64042 .08781 L
.64076 .08781 L
.64076 .08012 L
s
.678 .847 .902 r
.64076 .08012 m
.64076 .0876 L
.64128 .0876 L
.64128 .08012 L
F
.2 .63 .79 r
.64076 .08012 m
.64076 .0876 L
.64128 .0876 L
.64128 .08012 L
s
.678 .847 .902 r
.64128 .08012 m
.64128 .08745 L
.64152 .08745 L
.64152 .08012 L
F
.2 .63 .79 r
.64128 .08012 m
.64128 .08745 L
.64152 .08745 L
.64152 .08012 L
s
.678 .847 .902 r
.64152 .08012 m
.64152 .08716 L
.64213 .08716 L
.64213 .08012 L
F
.2 .63 .79 r
.64152 .08012 m
.64152 .08716 L
.64213 .08716 L
.64213 .08012 L
s
.678 .847 .902 r
.64213 .08012 m
.64213 .08709 L
.64245 .08709 L
.64245 .08012 L
F
.2 .63 .79 r
.64213 .08012 m
.64213 .08709 L
.64245 .08709 L
.64245 .08012 L
s
.678 .847 .902 r
.64245 .08012 m
.64245 .08675 L
.64304 .08675 L
.64304 .08012 L
F
.2 .63 .79 r
.64245 .08012 m
.64245 .08675 L
.64304 .08675 L
.64304 .08012 L
s
.678 .847 .902 r
.64304 .08012 m
.64304 .08673 L
.64328 .08673 L
.64328 .08012 L
F
.2 .63 .79 r
.64304 .08012 m
.64304 .08673 L
.64328 .08673 L
.64328 .08012 L
s
.678 .847 .902 r
.64328 .08012 m
.64328 .08636 L
.64396 .08636 L
.64396 .08012 L
F
.2 .63 .79 r
.64328 .08012 m
.64328 .08636 L
.64396 .08636 L
.64396 .08012 L
s
.678 .847 .902 r
.64396 .08012 m
.64396 .0863 L
.64464 .0863 L
.64464 .08012 L
F
.2 .63 .79 r
.64396 .08012 m
.64396 .0863 L
.64464 .0863 L
.64464 .08012 L
s
.678 .847 .902 r
.64464 .08012 m
.64464 .08577 L
.64532 .08577 L
.64532 .08012 L
F
.2 .63 .79 r
.64464 .08012 m
.64464 .08577 L
.64532 .08577 L
.64532 .08012 L
s
.678 .847 .902 r
.64532 .08012 m
.64532 .08559 L
.64583 .08559 L
.64583 .08012 L
F
.2 .63 .79 r
.64532 .08012 m
.64532 .08559 L
.64583 .08559 L
.64583 .08012 L
s
.678 .847 .902 r
.64583 .08012 m
.64583 .08553 L
.64639 .08553 L
.64639 .08012 L
F
.2 .63 .79 r
.64583 .08012 m
.64583 .08553 L
.64639 .08553 L
.64639 .08012 L
s
.678 .847 .902 r
.64639 .08012 m
.64639 .08517 L
.64695 .08517 L
.64695 .08012 L
F
.2 .63 .79 r
.64639 .08012 m
.64639 .08517 L
.64695 .08517 L
.64695 .08012 L
s
.678 .847 .902 r
.64695 .08012 m
.64695 .08494 L
.64736 .08494 L
.64736 .08012 L
F
.2 .63 .79 r
.64695 .08012 m
.64695 .08494 L
.64736 .08494 L
.64736 .08012 L
s
.678 .847 .902 r
.64736 .08012 m
.64736 .08474 L
.64791 .08474 L
.64791 .08012 L
F
.2 .63 .79 r
.64736 .08012 m
.64736 .08474 L
.64791 .08474 L
.64791 .08012 L
s
.678 .847 .902 r
.64791 .08012 m
.64791 .08455 L
.64821 .08455 L
.64821 .08012 L
F
.2 .63 .79 r
.64791 .08012 m
.64791 .08455 L
.64821 .08455 L
.64821 .08012 L
s
.678 .847 .902 r
.64821 .08012 m
.64821 .08436 L
.64861 .08436 L
.64861 .08012 L
F
.2 .63 .79 r
.64821 .08012 m
.64821 .08436 L
.64861 .08436 L
.64861 .08012 L
s
.678 .847 .902 r
.64861 .08012 m
.64861 .08429 L
.64898 .08429 L
.64898 .08012 L
F
.2 .63 .79 r
.64861 .08012 m
.64861 .08429 L
.64898 .08429 L
.64898 .08012 L
s
.678 .847 .902 r
.64898 .08012 m
.64898 .08403 L
.64953 .08403 L
.64953 .08012 L
F
.2 .63 .79 r
.64898 .08012 m
.64898 .08403 L
.64953 .08403 L
.64953 .08012 L
s
.678 .847 .902 r
.64953 .08012 m
.64953 .08391 L
.64981 .08391 L
.64981 .08012 L
F
.2 .63 .79 r
.64953 .08012 m
.64953 .08391 L
.64981 .08391 L
.64981 .08012 L
s
.678 .847 .902 r
.64981 .08012 m
.64981 .08368 L
.65036 .08368 L
.65036 .08012 L
F
.2 .63 .79 r
.64981 .08012 m
.64981 .08368 L
.65036 .08368 L
.65036 .08012 L
s
.678 .847 .902 r
.65036 .08012 m
.65036 .0835 L
.65066 .0835 L
.65066 .08012 L
F
.2 .63 .79 r
.65036 .08012 m
.65036 .0835 L
.65066 .0835 L
.65066 .08012 L
s
.678 .847 .902 r
.65066 .08012 m
.65066 .08331 L
.65113 .08331 L
.65113 .08012 L
F
.2 .63 .79 r
.65066 .08012 m
.65066 .08331 L
.65113 .08331 L
.65113 .08012 L
s
.678 .847 .902 r
.65113 .08012 m
.65113 .08328 L
.65184 .08328 L
.65184 .08012 L
F
.2 .63 .79 r
.65113 .08012 m
.65113 .08328 L
.65184 .08328 L
.65184 .08012 L
s
.678 .847 .902 r
.65184 .08012 m
.65184 .08294 L
.65227 .08294 L
.65227 .08012 L
F
.2 .63 .79 r
.65184 .08012 m
.65184 .08294 L
.65227 .08294 L
.65227 .08012 L
s
.678 .847 .902 r
.65227 .08012 m
.65227 .08273 L
.65279 .08273 L
.65279 .08012 L
F
.2 .63 .79 r
.65227 .08012 m
.65227 .08273 L
.65279 .08273 L
.65279 .08012 L
s
.678 .847 .902 r
.65279 .08012 m
.65279 .08252 L
.65323 .08252 L
.65323 .08012 L
F
.2 .63 .79 r
.65279 .08012 m
.65279 .08252 L
.65323 .08252 L
.65323 .08012 L
s
.678 .847 .902 r
.65323 .08012 m
.65323 .08238 L
.65355 .08238 L
.65355 .08012 L
F
.2 .63 .79 r
.65323 .08012 m
.65323 .08238 L
.65355 .08238 L
.65355 .08012 L
s
.678 .847 .902 r
.65355 .08012 m
.65355 .08214 L
.65388 .08214 L
.65388 .08012 L
F
.2 .63 .79 r
.65355 .08012 m
.65355 .08214 L
.65388 .08214 L
.65388 .08012 L
s
.678 .847 .902 r
.65388 .08012 m
.65388 .08203 L
.65454 .08203 L
.65454 .08012 L
F
.2 .63 .79 r
.65388 .08012 m
.65388 .08203 L
.65454 .08203 L
.65454 .08012 L
s
.678 .847 .902 r
.65454 .08012 m
.65454 .0818 L
.65496 .0818 L
.65496 .08012 L
F
.2 .63 .79 r
.65454 .08012 m
.65454 .0818 L
.65496 .0818 L
.65496 .08012 L
s
.678 .847 .902 r
.65496 .08012 m
.65496 .08165 L
.65534 .08165 L
.65534 .08012 L
F
.2 .63 .79 r
.65496 .08012 m
.65496 .08165 L
.65534 .08165 L
.65534 .08012 L
s
.678 .847 .902 r
.65534 .08012 m
.65534 .0814 L
.65571 .0814 L
.65571 .08012 L
F
.2 .63 .79 r
.65534 .08012 m
.65534 .0814 L
.65571 .0814 L
.65571 .08012 L
s
.678 .847 .902 r
.65571 .08012 m
.65571 .08124 L
.65643 .08124 L
.65643 .08012 L
F
.2 .63 .79 r
.65571 .08012 m
.65571 .08124 L
.65643 .08124 L
.65643 .08012 L
s
.678 .847 .902 r
.65643 .08012 m
.65643 .08092 L
.65706 .08092 L
.65706 .08012 L
F
.2 .63 .79 r
.65643 .08012 m
.65643 .08092 L
.65706 .08092 L
.65706 .08012 L
s
.678 .847 .902 r
.65706 .08012 m
.65706 .08077 L
.65761 .08077 L
.65761 .08012 L
F
.2 .63 .79 r
.65706 .08012 m
.65706 .08077 L
.65761 .08077 L
.65761 .08012 L
s
.678 .847 .902 r
.65761 .08012 m
.65761 .08052 L
.65815 .08052 L
.65815 .08012 L
F
.2 .63 .79 r
.65761 .08012 m
.65761 .08052 L
.65815 .08052 L
.65815 .08012 L
s
.678 .847 .902 r
.65815 .08012 m
.65815 .0802 L
.65868 .0802 L
.65868 .08012 L
F
.2 .63 .79 r
.65815 .08012 m
.65815 .0802 L
.65868 .0802 L
.65868 .08012 L
s
1 .894 .882 r
.65868 .08012 m
.65868 .08002 L
.65898 .08002 L
.65898 .08012 L
F
.804 .522 .247 r
.65868 .08012 m
.65868 .08002 L
.65898 .08002 L
.65898 .08012 L
s
1 .894 .882 r
.65898 .08012 m
.65898 .07994 L
.65945 .07994 L
.65945 .08012 L
F
.804 .522 .247 r
.65898 .08012 m
.65898 .07994 L
.65945 .07994 L
.65945 .08012 L
s
1 .894 .882 r
.65945 .08012 m
.65945 .07978 L
.65982 .07978 L
.65982 .08012 L
F
.804 .522 .247 r
.65945 .08012 m
.65945 .07978 L
.65982 .07978 L
.65982 .08012 L
s
1 .894 .882 r
.65982 .08012 m
.65982 .07962 L
.6602 .07962 L
.6602 .08012 L
F
.804 .522 .247 r
.65982 .08012 m
.65982 .07962 L
.6602 .07962 L
.6602 .08012 L
s
1 .894 .882 r
.6602 .08012 m
.6602 .07947 L
.66067 .07947 L
.66067 .08012 L
F
.804 .522 .247 r
.6602 .08012 m
.6602 .07947 L
.66067 .07947 L
.66067 .08012 L
s
1 .894 .882 r
.66067 .08012 m
.66067 .07915 L
.66109 .07915 L
.66109 .08012 L
F
.804 .522 .247 r
.66067 .08012 m
.66067 .07915 L
.66109 .07915 L
.66109 .08012 L
s
1 .894 .882 r
.66109 .08012 m
.66109 .07901 L
.66163 .07901 L
.66163 .08012 L
F
.804 .522 .247 r
.66109 .08012 m
.66109 .07901 L
.66163 .07901 L
.66163 .08012 L
s
1 .894 .882 r
.66163 .08012 m
.66163 .07887 L
.66193 .07887 L
.66193 .08012 L
F
.804 .522 .247 r
.66163 .08012 m
.66163 .07887 L
.66193 .07887 L
.66193 .08012 L
s
1 .894 .882 r
.66193 .08012 m
.66193 .07877 L
.66215 .07877 L
.66215 .08012 L
F
.804 .522 .247 r
.66193 .08012 m
.66193 .07877 L
.66215 .07877 L
.66215 .08012 L
s
1 .894 .882 r
.66215 .08012 m
.66215 .07855 L
.66259 .07855 L
.66259 .08012 L
F
.804 .522 .247 r
.66215 .08012 m
.66215 .07855 L
.66259 .07855 L
.66259 .08012 L
s
1 .894 .882 r
.66259 .08012 m
.66259 .07849 L
.66293 .07849 L
.66293 .08012 L
F
.804 .522 .247 r
.66259 .08012 m
.66259 .07849 L
.66293 .07849 L
.66293 .08012 L
s
1 .894 .882 r
.66293 .08012 m
.66293 .07838 L
.66343 .07838 L
.66343 .08012 L
F
.804 .522 .247 r
.66293 .08012 m
.66293 .07838 L
.66343 .07838 L
.66343 .08012 L
s
1 .894 .882 r
.66343 .08012 m
.66343 .07819 L
.66394 .07819 L
.66394 .08012 L
F
.804 .522 .247 r
.66343 .08012 m
.66343 .07819 L
.66394 .07819 L
.66394 .08012 L
s
1 .894 .882 r
.66394 .08012 m
.66394 .07787 L
.66428 .07787 L
.66428 .08012 L
F
.804 .522 .247 r
.66394 .08012 m
.66394 .07787 L
.66428 .07787 L
.66428 .08012 L
s
1 .894 .882 r
.66428 .08012 m
.66428 .07781 L
.66452 .07781 L
.66452 .08012 L
F
.804 .522 .247 r
.66428 .08012 m
.66428 .07781 L
.66452 .07781 L
.66452 .08012 L
s
1 .894 .882 r
.66452 .08012 m
.66452 .07758 L
.66509 .07758 L
.66509 .08012 L
F
.804 .522 .247 r
.66452 .08012 m
.66452 .07758 L
.66509 .07758 L
.66509 .08012 L
s
1 .894 .882 r
.66509 .08012 m
.66509 .07743 L
.6654 .07743 L
.6654 .08012 L
F
.804 .522 .247 r
.66509 .08012 m
.66509 .07743 L
.6654 .07743 L
.6654 .08012 L
s
1 .894 .882 r
.6654 .08012 m
.6654 .07722 L
.66609 .07722 L
.66609 .08012 L
F
.804 .522 .247 r
.6654 .08012 m
.6654 .07722 L
.66609 .07722 L
.66609 .08012 L
s
1 .894 .882 r
.66609 .08012 m
.66609 .07696 L
.66668 .07696 L
.66668 .08012 L
F
.804 .522 .247 r
.66609 .08012 m
.66609 .07696 L
.66668 .07696 L
.66668 .08012 L
s
1 .894 .882 r
.66668 .08012 m
.66668 .07681 L
.66726 .07681 L
.66726 .08012 L
F
.804 .522 .247 r
.66668 .08012 m
.66668 .07681 L
.66726 .07681 L
.66726 .08012 L
s
1 .894 .882 r
.66726 .08012 m
.66726 .07662 L
.66768 .07662 L
.66768 .08012 L
F
.804 .522 .247 r
.66726 .08012 m
.66726 .07662 L
.66768 .07662 L
.66768 .08012 L
s
1 .894 .882 r
.66768 .08012 m
.66768 .07641 L
.66803 .07641 L
.66803 .08012 L
F
.804 .522 .247 r
.66768 .08012 m
.66768 .07641 L
.66803 .07641 L
.66803 .08012 L
s
1 .894 .882 r
.66803 .08012 m
.66803 .0763 L
.66831 .0763 L
.66831 .08012 L
F
.804 .522 .247 r
.66803 .08012 m
.66803 .0763 L
.66831 .0763 L
.66831 .08012 L
s
1 .894 .882 r
.66831 .08012 m
.66831 .07616 L
.66858 .07616 L
.66858 .08012 L
F
.804 .522 .247 r
.66831 .08012 m
.66831 .07616 L
.66858 .07616 L
.66858 .08012 L
s
1 .894 .882 r
.66858 .08012 m
.66858 .07609 L
.66892 .07609 L
.66892 .08012 L
F
.804 .522 .247 r
.66858 .08012 m
.66858 .07609 L
.66892 .07609 L
.66892 .08012 L
s
1 .894 .882 r
.66892 .08012 m
.66892 .07596 L
.66953 .07596 L
.66953 .08012 L
F
.804 .522 .247 r
.66892 .08012 m
.66892 .07596 L
.66953 .07596 L
.66953 .08012 L
s
1 .894 .882 r
.66953 .08012 m
.66953 .07571 L
.67016 .07571 L
.67016 .08012 L
F
.804 .522 .247 r
.66953 .08012 m
.66953 .07571 L
.67016 .07571 L
.67016 .08012 L
s
1 .894 .882 r
.67016 .08012 m
.67016 .07542 L
.67079 .07542 L
.67079 .08012 L
F
.804 .522 .247 r
.67016 .08012 m
.67016 .07542 L
.67079 .07542 L
.67079 .08012 L
s
1 .894 .882 r
.67079 .08012 m
.67079 .07524 L
.67139 .07524 L
.67139 .08012 L
F
.804 .522 .247 r
.67079 .08012 m
.67079 .07524 L
.67139 .07524 L
.67139 .08012 L
s
1 .894 .882 r
.67139 .08012 m
.67139 .07498 L
.6718 .07498 L
.6718 .08012 L
F
.804 .522 .247 r
.67139 .08012 m
.67139 .07498 L
.6718 .07498 L
.6718 .08012 L
s
1 .894 .882 r
.6718 .08012 m
.6718 .07478 L
.67211 .07478 L
.67211 .08012 L
F
.804 .522 .247 r
.6718 .08012 m
.6718 .07478 L
.67211 .07478 L
.67211 .08012 L
s
1 .894 .882 r
.67211 .08012 m
.67211 .07454 L
.67266 .07454 L
.67266 .08012 L
F
.804 .522 .247 r
.67211 .08012 m
.67211 .07454 L
.67266 .07454 L
.67266 .08012 L
s
1 .894 .882 r
.67266 .08012 m
.67266 .07436 L
.67325 .07436 L
.67325 .08012 L
F
.804 .522 .247 r
.67266 .08012 m
.67266 .07436 L
.67325 .07436 L
.67325 .08012 L
s
1 .894 .882 r
.67325 .08012 m
.67325 .07422 L
.67396 .07422 L
.67396 .08012 L
F
.804 .522 .247 r
.67325 .08012 m
.67325 .07422 L
.67396 .07422 L
.67396 .08012 L
s
1 .894 .882 r
.67396 .08012 m
.67396 .07394 L
.67466 .07394 L
.67466 .08012 L
F
.804 .522 .247 r
.67396 .08012 m
.67396 .07394 L
.67466 .07394 L
.67466 .08012 L
s
1 .894 .882 r
.67466 .08012 m
.67466 .07364 L
.67492 .07364 L
.67492 .08012 L
F
.804 .522 .247 r
.67466 .08012 m
.67466 .07364 L
.67492 .07364 L
.67492 .08012 L
s
1 .894 .882 r
.67492 .08012 m
.67492 .07354 L
.67523 .07354 L
.67523 .08012 L
F
.804 .522 .247 r
.67492 .08012 m
.67492 .07354 L
.67523 .07354 L
.67523 .08012 L
s
1 .894 .882 r
.67523 .08012 m
.67523 .07341 L
.67582 .07341 L
.67582 .08012 L
F
.804 .522 .247 r
.67523 .08012 m
.67523 .07341 L
.67582 .07341 L
.67582 .08012 L
s
1 .894 .882 r
.67582 .08012 m
.67582 .07306 L
.6765 .07306 L
.6765 .08012 L
F
.804 .522 .247 r
.67582 .08012 m
.67582 .07306 L
.6765 .07306 L
.6765 .08012 L
s
1 .894 .882 r
.6765 .08012 m
.6765 .073 L
.67692 .073 L
.67692 .08012 L
F
.804 .522 .247 r
.6765 .08012 m
.6765 .073 L
.67692 .073 L
.67692 .08012 L
s
1 .894 .882 r
.67692 .08012 m
.67692 .07259 L
.67765 .07259 L
.67765 .08012 L
F
.804 .522 .247 r
.67692 .08012 m
.67692 .07259 L
.67765 .07259 L
.67765 .08012 L
s
1 .894 .882 r
.67765 .08012 m
.67765 .07237 L
.67829 .07237 L
.67829 .08012 L
F
.804 .522 .247 r
.67765 .08012 m
.67765 .07237 L
.67829 .07237 L
.67829 .08012 L
s
1 .894 .882 r
.67829 .08012 m
.67829 .07229 L
.67859 .07229 L
.67859 .08012 L
F
.804 .522 .247 r
.67829 .08012 m
.67829 .07229 L
.67859 .07229 L
.67859 .08012 L
s
1 .894 .882 r
.67859 .08012 m
.67859 .07204 L
.67916 .07204 L
.67916 .08012 L
F
.804 .522 .247 r
.67859 .08012 m
.67859 .07204 L
.67916 .07204 L
.67916 .08012 L
s
1 .894 .882 r
.67916 .08012 m
.67916 .07182 L
.67968 .07182 L
.67968 .08012 L
F
.804 .522 .247 r
.67916 .08012 m
.67916 .07182 L
.67968 .07182 L
.67968 .08012 L
s
1 .894 .882 r
.67968 .08012 m
.67968 .07172 L
.68019 .07172 L
.68019 .08012 L
F
.804 .522 .247 r
.67968 .08012 m
.67968 .07172 L
.68019 .07172 L
.68019 .08012 L
s
1 .894 .882 r
.68019 .08012 m
.68019 .0715 L
.68044 .0715 L
.68044 .08012 L
F
.804 .522 .247 r
.68019 .08012 m
.68019 .0715 L
.68044 .0715 L
.68044 .08012 L
s
1 .894 .882 r
.68044 .08012 m
.68044 .07146 L
.68096 .07146 L
.68096 .08012 L
F
.804 .522 .247 r
.68044 .08012 m
.68044 .07146 L
.68096 .07146 L
.68096 .08012 L
s
1 .894 .882 r
.68096 .08012 m
.68096 .0712 L
.68136 .0712 L
.68136 .08012 L
F
.804 .522 .247 r
.68096 .08012 m
.68096 .0712 L
.68136 .0712 L
.68136 .08012 L
s
1 .894 .882 r
.68136 .08012 m
.68136 .07109 L
.68199 .07109 L
.68199 .08012 L
F
.804 .522 .247 r
.68136 .08012 m
.68136 .07109 L
.68199 .07109 L
.68199 .08012 L
s
1 .894 .882 r
.68199 .08012 m
.68199 .0708 L
.68234 .0708 L
.68234 .08012 L
F
.804 .522 .247 r
.68199 .08012 m
.68199 .0708 L
.68234 .0708 L
.68234 .08012 L
s
1 .894 .882 r
.68234 .08012 m
.68234 .07056 L
.68297 .07056 L
.68297 .08012 L
F
.804 .522 .247 r
.68234 .08012 m
.68234 .07056 L
.68297 .07056 L
.68297 .08012 L
s
1 .894 .882 r
.68297 .08012 m
.68297 .07042 L
.6835 .07042 L
.6835 .08012 L
F
.804 .522 .247 r
.68297 .08012 m
.68297 .07042 L
.6835 .07042 L
.6835 .08012 L
s
1 .894 .882 r
.6835 .08012 m
.6835 .07031 L
.68393 .07031 L
.68393 .08012 L
F
.804 .522 .247 r
.6835 .08012 m
.6835 .07031 L
.68393 .07031 L
.68393 .08012 L
s
1 .894 .882 r
.68393 .08012 m
.68393 .07014 L
.68419 .07014 L
.68419 .08012 L
F
.804 .522 .247 r
.68393 .08012 m
.68393 .07014 L
.68419 .07014 L
.68419 .08012 L
s
1 .894 .882 r
.68419 .08012 m
.68419 .06994 L
.68449 .06994 L
.68449 .08012 L
F
.804 .522 .247 r
.68419 .08012 m
.68419 .06994 L
.68449 .06994 L
.68449 .08012 L
s
1 .894 .882 r
.68449 .08012 m
.68449 .06972 L
.68515 .06972 L
.68515 .08012 L
F
.804 .522 .247 r
.68449 .08012 m
.68449 .06972 L
.68515 .06972 L
.68515 .08012 L
s
1 .894 .882 r
.68515 .08012 m
.68515 .06954 L
.68561 .06954 L
.68561 .08012 L
F
.804 .522 .247 r
.68515 .08012 m
.68515 .06954 L
.68561 .06954 L
.68561 .08012 L
s
1 .894 .882 r
.68561 .08012 m
.68561 .06941 L
.6859 .06941 L
.6859 .08012 L
F
.804 .522 .247 r
.68561 .08012 m
.68561 .06941 L
.6859 .06941 L
.6859 .08012 L
s
1 .894 .882 r
.6859 .08012 m
.6859 .06938 L
.68616 .06938 L
.68616 .08012 L
F
.804 .522 .247 r
.6859 .08012 m
.6859 .06938 L
.68616 .06938 L
.68616 .08012 L
s
1 .894 .882 r
.68616 .08012 m
.68616 .06925 L
.68674 .06925 L
.68674 .08012 L
F
.804 .522 .247 r
.68616 .08012 m
.68616 .06925 L
.68674 .06925 L
.68674 .08012 L
s
1 .894 .882 r
.68674 .08012 m
.68674 .06898 L
.68733 .06898 L
.68733 .08012 L
F
.804 .522 .247 r
.68674 .08012 m
.68674 .06898 L
.68733 .06898 L
.68733 .08012 L
s
1 .894 .882 r
.68733 .08012 m
.68733 .06884 L
.68767 .06884 L
.68767 .08012 L
F
.804 .522 .247 r
.68733 .08012 m
.68733 .06884 L
.68767 .06884 L
.68767 .08012 L
s
1 .894 .882 r
.68767 .08012 m
.68767 .0687 L
.68824 .0687 L
.68824 .08012 L
F
.804 .522 .247 r
.68767 .08012 m
.68767 .0687 L
.68824 .0687 L
.68824 .08012 L
s
1 .894 .882 r
.68824 .08012 m
.68824 .06845 L
.68883 .06845 L
.68883 .08012 L
F
.804 .522 .247 r
.68824 .08012 m
.68824 .06845 L
.68883 .06845 L
.68883 .08012 L
s
1 .894 .882 r
.68883 .08012 m
.68883 .06811 L
.68951 .06811 L
.68951 .08012 L
F
.804 .522 .247 r
.68883 .08012 m
.68883 .06811 L
.68951 .06811 L
.68951 .08012 L
s
1 .894 .882 r
.68951 .08012 m
.68951 .06804 L
.68977 .06804 L
.68977 .08012 L
F
.804 .522 .247 r
.68951 .08012 m
.68951 .06804 L
.68977 .06804 L
.68977 .08012 L
s
1 .894 .882 r
.68977 .08012 m
.68977 .06782 L
.69049 .06782 L
.69049 .08012 L
F
.804 .522 .247 r
.68977 .08012 m
.68977 .06782 L
.69049 .06782 L
.69049 .08012 L
s
1 .894 .882 r
.69049 .08012 m
.69049 .06762 L
.69078 .06762 L
.69078 .08012 L
F
.804 .522 .247 r
.69049 .08012 m
.69049 .06762 L
.69078 .06762 L
.69078 .08012 L
s
1 .894 .882 r
.69078 .08012 m
.69078 .0675 L
.69118 .0675 L
.69118 .08012 L
F
.804 .522 .247 r
.69078 .08012 m
.69078 .0675 L
.69118 .0675 L
.69118 .08012 L
s
1 .894 .882 r
.69118 .08012 m
.69118 .06733 L
.69191 .06733 L
.69191 .08012 L
F
.804 .522 .247 r
.69118 .08012 m
.69118 .06733 L
.69191 .06733 L
.69191 .08012 L
s
1 .894 .882 r
.69191 .08012 m
.69191 .06709 L
.69234 .06709 L
.69234 .08012 L
F
.804 .522 .247 r
.69191 .08012 m
.69191 .06709 L
.69234 .06709 L
.69234 .08012 L
s
1 .894 .882 r
.69234 .08012 m
.69234 .06696 L
.69296 .06696 L
.69296 .08012 L
F
.804 .522 .247 r
.69234 .08012 m
.69234 .06696 L
.69296 .06696 L
.69296 .08012 L
s
1 .894 .882 r
.69296 .08012 m
.69296 .06671 L
.69345 .06671 L
.69345 .08012 L
F
.804 .522 .247 r
.69296 .08012 m
.69296 .06671 L
.69345 .06671 L
.69345 .08012 L
s
1 .894 .882 r
.69345 .08012 m
.69345 .06642 L
.69406 .06642 L
.69406 .08012 L
F
.804 .522 .247 r
.69345 .08012 m
.69345 .06642 L
.69406 .06642 L
.69406 .08012 L
s
1 .894 .882 r
.69406 .08012 m
.69406 .06625 L
.69459 .06625 L
.69459 .08012 L
F
.804 .522 .247 r
.69406 .08012 m
.69406 .06625 L
.69459 .06625 L
.69459 .08012 L
s
1 .894 .882 r
.69459 .08012 m
.69459 .0661 L
.6949 .0661 L
.6949 .08012 L
F
.804 .522 .247 r
.69459 .08012 m
.69459 .0661 L
.6949 .0661 L
.6949 .08012 L
s
1 .894 .882 r
.6949 .08012 m
.6949 .06603 L
.69518 .06603 L
.69518 .08012 L
F
.804 .522 .247 r
.6949 .08012 m
.6949 .06603 L
.69518 .06603 L
.69518 .08012 L
s
1 .894 .882 r
.69518 .08012 m
.69518 .06582 L
.69574 .06582 L
.69574 .08012 L
F
.804 .522 .247 r
.69518 .08012 m
.69518 .06582 L
.69574 .06582 L
.69574 .08012 L
s
1 .894 .882 r
.69574 .08012 m
.69574 .06564 L
.6962 .06564 L
.6962 .08012 L
F
.804 .522 .247 r
.69574 .08012 m
.69574 .06564 L
.6962 .06564 L
.6962 .08012 L
s
1 .894 .882 r
.6962 .08012 m
.6962 .06547 L
.69658 .06547 L
.69658 .08012 L
F
.804 .522 .247 r
.6962 .08012 m
.6962 .06547 L
.69658 .06547 L
.69658 .08012 L
s
1 .894 .882 r
.69658 .08012 m
.69658 .06536 L
.69713 .06536 L
.69713 .08012 L
F
.804 .522 .247 r
.69658 .08012 m
.69658 .06536 L
.69713 .06536 L
.69713 .08012 L
s
1 .894 .882 r
.69713 .08012 m
.69713 .06511 L
.69762 .06511 L
.69762 .08012 L
F
.804 .522 .247 r
.69713 .08012 m
.69713 .06511 L
.69762 .06511 L
.69762 .08012 L
s
1 .894 .882 r
.69762 .08012 m
.69762 .065 L
.69804 .065 L
.69804 .08012 L
F
.804 .522 .247 r
.69762 .08012 m
.69762 .065 L
.69804 .065 L
.69804 .08012 L
s
1 .894 .882 r
.69804 .08012 m
.69804 .06481 L
.69857 .06481 L
.69857 .08012 L
F
.804 .522 .247 r
.69804 .08012 m
.69804 .06481 L
.69857 .06481 L
.69857 .08012 L
s
1 .894 .882 r
.69857 .08012 m
.69857 .06449 L
.69925 .06449 L
.69925 .08012 L
F
.804 .522 .247 r
.69857 .08012 m
.69857 .06449 L
.69925 .06449 L
.69925 .08012 L
s
1 .894 .882 r
.69925 .08012 m
.69925 .0644 L
.69963 .0644 L
.69963 .08012 L
F
.804 .522 .247 r
.69925 .08012 m
.69925 .0644 L
.69963 .0644 L
.69963 .08012 L
s
1 .894 .882 r
.69963 .08012 m
.69963 .06429 L
.70021 .06429 L
.70021 .08012 L
F
.804 .522 .247 r
.69963 .08012 m
.69963 .06429 L
.70021 .06429 L
.70021 .08012 L
s
1 .894 .882 r
.70021 .08012 m
.70021 .06408 L
.70088 .06408 L
.70088 .08012 L
F
.804 .522 .247 r
.70021 .08012 m
.70021 .06408 L
.70088 .06408 L
.70088 .08012 L
s
1 .894 .882 r
.70088 .08012 m
.70088 .06384 L
.70161 .06384 L
.70161 .08012 L
F
.804 .522 .247 r
.70088 .08012 m
.70088 .06384 L
.70161 .06384 L
.70161 .08012 L
s
1 .894 .882 r
.70161 .08012 m
.70161 .06357 L
.70195 .06357 L
.70195 .08012 L
F
.804 .522 .247 r
.70161 .08012 m
.70161 .06357 L
.70195 .06357 L
.70195 .08012 L
s
1 .894 .882 r
.70195 .08012 m
.70195 .06335 L
.70254 .06335 L
.70254 .08012 L
F
.804 .522 .247 r
.70195 .08012 m
.70195 .06335 L
.70254 .06335 L
.70254 .08012 L
s
1 .894 .882 r
.70254 .08012 m
.70254 .06318 L
.70314 .06318 L
.70314 .08012 L
F
.804 .522 .247 r
.70254 .08012 m
.70254 .06318 L
.70314 .06318 L
.70314 .08012 L
s
1 .894 .882 r
.70314 .08012 m
.70314 .06295 L
.70369 .06295 L
.70369 .08012 L
F
.804 .522 .247 r
.70314 .08012 m
.70314 .06295 L
.70369 .06295 L
.70369 .08012 L
s
1 .894 .882 r
.70369 .08012 m
.70369 .06287 L
.70404 .06287 L
.70404 .08012 L
F
.804 .522 .247 r
.70369 .08012 m
.70369 .06287 L
.70404 .06287 L
.70404 .08012 L
s
1 .894 .882 r
.70404 .08012 m
.70404 .06273 L
.70441 .06273 L
.70441 .08012 L
F
.804 .522 .247 r
.70404 .08012 m
.70404 .06273 L
.70441 .06273 L
.70441 .08012 L
s
1 .894 .882 r
.70441 .08012 m
.70441 .06253 L
.70513 .06253 L
.70513 .08012 L
F
.804 .522 .247 r
.70441 .08012 m
.70441 .06253 L
.70513 .06253 L
.70513 .08012 L
s
1 .894 .882 r
.70513 .08012 m
.70513 .06236 L
.7054 .06236 L
.7054 .08012 L
F
.804 .522 .247 r
.70513 .08012 m
.70513 .06236 L
.7054 .06236 L
.7054 .08012 L
s
1 .894 .882 r
.7054 .08012 m
.7054 .06222 L
.70587 .06222 L
.70587 .08012 L
F
.804 .522 .247 r
.7054 .08012 m
.7054 .06222 L
.70587 .06222 L
.70587 .08012 L
s
1 .894 .882 r
.70587 .08012 m
.70587 .06198 L
.70645 .06198 L
.70645 .08012 L
F
.804 .522 .247 r
.70587 .08012 m
.70587 .06198 L
.70645 .06198 L
.70645 .08012 L
s
1 .894 .882 r
.70645 .08012 m
.70645 .06177 L
.70707 .06177 L
.70707 .08012 L
F
.804 .522 .247 r
.70645 .08012 m
.70645 .06177 L
.70707 .06177 L
.70707 .08012 L
s
1 .894 .882 r
.70707 .08012 m
.70707 .06169 L
.7078 .06169 L
.7078 .08012 L
F
.804 .522 .247 r
.70707 .08012 m
.70707 .06169 L
.7078 .06169 L
.7078 .08012 L
s
1 .894 .882 r
.7078 .08012 m
.7078 .06129 L
.70843 .06129 L
.70843 .08012 L
F
.804 .522 .247 r
.7078 .08012 m
.7078 .06129 L
.70843 .06129 L
.70843 .08012 L
s
1 .894 .882 r
.70843 .08012 m
.70843 .06123 L
.70877 .06123 L
.70877 .08012 L
F
.804 .522 .247 r
.70843 .08012 m
.70843 .06123 L
.70877 .06123 L
.70877 .08012 L
s
1 .894 .882 r
.70877 .08012 m
.70877 .06097 L
.70924 .06097 L
.70924 .08012 L
F
.804 .522 .247 r
.70877 .08012 m
.70877 .06097 L
.70924 .06097 L
.70924 .08012 L
s
1 .894 .882 r
.70924 .08012 m
.70924 .06088 L
.70964 .06088 L
.70964 .08012 L
F
.804 .522 .247 r
.70924 .08012 m
.70924 .06088 L
.70964 .06088 L
.70964 .08012 L
s
1 .894 .882 r
.70964 .08012 m
.70964 .0607 L
.71 .0607 L
.71 .08012 L
F
.804 .522 .247 r
.70964 .08012 m
.70964 .0607 L
.71 .0607 L
.71 .08012 L
s
1 .894 .882 r
.71 .08012 m
.71 .06056 L
.71064 .06056 L
.71064 .08012 L
F
.804 .522 .247 r
.71 .08012 m
.71 .06056 L
.71064 .06056 L
.71064 .08012 L
s
1 .894 .882 r
.71064 .08012 m
.71064 .0604 L
.71132 .0604 L
.71132 .08012 L
F
.804 .522 .247 r
.71064 .08012 m
.71064 .0604 L
.71132 .0604 L
.71132 .08012 L
s
1 .894 .882 r
.71132 .08012 m
.71132 .06015 L
.71176 .06015 L
.71176 .08012 L
F
.804 .522 .247 r
.71132 .08012 m
.71132 .06015 L
.71176 .06015 L
.71176 .08012 L
s
1 .894 .882 r
.71176 .08012 m
.71176 .06001 L
.71247 .06001 L
.71247 .08012 L
F
.804 .522 .247 r
.71176 .08012 m
.71176 .06001 L
.71247 .06001 L
.71247 .08012 L
s
1 .894 .882 r
.71247 .08012 m
.71247 .05981 L
.71276 .05981 L
.71276 .08012 L
F
.804 .522 .247 r
.71247 .08012 m
.71247 .05981 L
.71276 .05981 L
.71276 .08012 L
s
1 .894 .882 r
.71276 .08012 m
.71276 .05975 L
.71298 .05975 L
.71298 .08012 L
F
.804 .522 .247 r
.71276 .08012 m
.71276 .05975 L
.71298 .05975 L
.71298 .08012 L
s
1 .894 .882 r
.71298 .08012 m
.71298 .05962 L
.71343 .05962 L
.71343 .08012 L
F
.804 .522 .247 r
.71298 .08012 m
.71298 .05962 L
.71343 .05962 L
.71343 .08012 L
s
1 .894 .882 r
.71343 .08012 m
.71343 .05937 L
.71402 .05937 L
.71402 .08012 L
F
.804 .522 .247 r
.71343 .08012 m
.71343 .05937 L
.71402 .05937 L
.71402 .08012 L
s
1 .894 .882 r
.71402 .08012 m
.71402 .05924 L
.71444 .05924 L
.71444 .08012 L
F
.804 .522 .247 r
.71402 .08012 m
.71402 .05924 L
.71444 .05924 L
.71444 .08012 L
s
1 .894 .882 r
.71444 .08012 m
.71444 .05912 L
.71479 .05912 L
.71479 .08012 L
F
.804 .522 .247 r
.71444 .08012 m
.71444 .05912 L
.71479 .05912 L
.71479 .08012 L
s
1 .894 .882 r
.71479 .08012 m
.71479 .05893 L
.71542 .05893 L
.71542 .08012 L
F
.804 .522 .247 r
.71479 .08012 m
.71479 .05893 L
.71542 .05893 L
.71542 .08012 L
s
1 .894 .882 r
.71542 .08012 m
.71542 .05876 L
.71589 .05876 L
.71589 .08012 L
F
.804 .522 .247 r
.71542 .08012 m
.71542 .05876 L
.71589 .05876 L
.71589 .08012 L
s
1 .894 .882 r
.71589 .08012 m
.71589 .05867 L
.71616 .05867 L
.71616 .08012 L
F
.804 .522 .247 r
.71589 .08012 m
.71589 .05867 L
.71616 .05867 L
.71616 .08012 L
s
1 .894 .882 r
.71616 .08012 m
.71616 .05847 L
.71652 .05847 L
.71652 .08012 L
F
.804 .522 .247 r
.71616 .08012 m
.71616 .05847 L
.71652 .05847 L
.71652 .08012 L
s
1 .894 .882 r
.71652 .08012 m
.71652 .05843 L
.7171 .05843 L
.7171 .08012 L
F
.804 .522 .247 r
.71652 .08012 m
.71652 .05843 L
.7171 .05843 L
.7171 .08012 L
s
1 .894 .882 r
.7171 .08012 m
.7171 .05826 L
.71783 .05826 L
.71783 .08012 L
F
.804 .522 .247 r
.7171 .08012 m
.7171 .05826 L
.71783 .05826 L
.71783 .08012 L
s
1 .894 .882 r
.71783 .08012 m
.71783 .05798 L
.71825 .05798 L
.71825 .08012 L
F
.804 .522 .247 r
.71783 .08012 m
.71783 .05798 L
.71825 .05798 L
.71825 .08012 L
s
1 .894 .882 r
.71825 .08012 m
.71825 .05785 L
.71872 .05785 L
.71872 .08012 L
F
.804 .522 .247 r
.71825 .08012 m
.71825 .05785 L
.71872 .05785 L
.71872 .08012 L
s
1 .894 .882 r
.71872 .08012 m
.71872 .05771 L
.7193 .05771 L
.7193 .08012 L
F
.804 .522 .247 r
.71872 .08012 m
.71872 .05771 L
.7193 .05771 L
.7193 .08012 L
s
1 .894 .882 r
.7193 .08012 m
.7193 .05751 L
.71962 .05751 L
.71962 .08012 L
F
.804 .522 .247 r
.7193 .08012 m
.7193 .05751 L
.71962 .05751 L
.71962 .08012 L
s
1 .894 .882 r
.71962 .08012 m
.71962 .05741 L
.71993 .05741 L
.71993 .08012 L
F
.804 .522 .247 r
.71962 .08012 m
.71962 .05741 L
.71993 .05741 L
.71993 .08012 L
s
1 .894 .882 r
.71993 .08012 m
.71993 .05726 L
.72066 .05726 L
.72066 .08012 L
F
.804 .522 .247 r
.71993 .08012 m
.71993 .05726 L
.72066 .05726 L
.72066 .08012 L
s
1 .894 .882 r
.72066 .08012 m
.72066 .05702 L
.72106 .05702 L
.72106 .08012 L
F
.804 .522 .247 r
.72066 .08012 m
.72066 .05702 L
.72106 .05702 L
.72106 .08012 L
s
1 .894 .882 r
.72106 .08012 m
.72106 .05688 L
.72174 .05688 L
.72174 .08012 L
F
.804 .522 .247 r
.72106 .08012 m
.72106 .05688 L
.72174 .05688 L
.72174 .08012 L
s
1 .894 .882 r
.72174 .08012 m
.72174 .05664 L
.72214 .05664 L
.72214 .08012 L
F
.804 .522 .247 r
.72174 .08012 m
.72174 .05664 L
.72214 .05664 L
.72214 .08012 L
s
1 .894 .882 r
.72214 .08012 m
.72214 .05651 L
.72241 .05651 L
.72241 .08012 L
F
.804 .522 .247 r
.72214 .08012 m
.72214 .05651 L
.72241 .05651 L
.72241 .08012 L
s
1 .894 .882 r
.72241 .08012 m
.72241 .0563 L
.7231 .0563 L
.7231 .08012 L
F
.804 .522 .247 r
.72241 .08012 m
.72241 .0563 L
.7231 .0563 L
.7231 .08012 L
s
1 .894 .882 r
.7231 .08012 m
.7231 .05605 L
.7238 .05605 L
.7238 .08012 L
F
.804 .522 .247 r
.7231 .08012 m
.7231 .05605 L
.7238 .05605 L
.7238 .08012 L
s
1 .894 .882 r
.7238 .08012 m
.7238 .05602 L
.72414 .05602 L
.72414 .08012 L
F
.804 .522 .247 r
.7238 .08012 m
.7238 .05602 L
.72414 .05602 L
.72414 .08012 L
s
1 .894 .882 r
.72414 .08012 m
.72414 .05586 L
.72441 .05586 L
.72441 .08012 L
F
.804 .522 .247 r
.72414 .08012 m
.72414 .05586 L
.72441 .05586 L
.72441 .08012 L
s
1 .894 .882 r
.72441 .08012 m
.72441 .05577 L
.72487 .05577 L
.72487 .08012 L
F
.804 .522 .247 r
.72441 .08012 m
.72441 .05577 L
.72487 .05577 L
.72487 .08012 L
s
1 .894 .882 r
.72487 .08012 m
.72487 .05568 L
.7252 .05568 L
.7252 .08012 L
F
.804 .522 .247 r
.72487 .08012 m
.72487 .05568 L
.7252 .05568 L
.7252 .08012 L
s
1 .894 .882 r
.7252 .08012 m
.7252 .05543 L
.72584 .05543 L
.72584 .08012 L
F
.804 .522 .247 r
.7252 .08012 m
.7252 .05543 L
.72584 .05543 L
.72584 .08012 L
s
1 .894 .882 r
.72584 .08012 m
.72584 .05529 L
.72649 .05529 L
.72649 .08012 L
F
.804 .522 .247 r
.72584 .08012 m
.72584 .05529 L
.72649 .05529 L
.72649 .08012 L
s
1 .894 .882 r
.72649 .08012 m
.72649 .055 L
.72706 .055 L
.72706 .08012 L
F
.804 .522 .247 r
.72649 .08012 m
.72649 .055 L
.72706 .055 L
.72706 .08012 L
s
1 .894 .882 r
.72706 .08012 m
.72706 .05486 L
.72765 .05486 L
.72765 .08012 L
F
.804 .522 .247 r
.72706 .08012 m
.72706 .05486 L
.72765 .05486 L
.72765 .08012 L
s
1 .894 .882 r
.72765 .08012 m
.72765 .05468 L
.72824 .05468 L
.72824 .08012 L
F
.804 .522 .247 r
.72765 .08012 m
.72765 .05468 L
.72824 .05468 L
.72824 .08012 L
s
1 .894 .882 r
.72824 .08012 m
.72824 .05453 L
.72875 .05453 L
.72875 .08012 L
F
.804 .522 .247 r
.72824 .08012 m
.72824 .05453 L
.72875 .05453 L
.72875 .08012 L
s
1 .894 .882 r
.72875 .08012 m
.72875 .05427 L
.72946 .05427 L
.72946 .08012 L
F
.804 .522 .247 r
.72875 .08012 m
.72875 .05427 L
.72946 .05427 L
.72946 .08012 L
s
1 .894 .882 r
.72946 .08012 m
.72946 .0541 L
.73006 .0541 L
.73006 .08012 L
F
.804 .522 .247 r
.72946 .08012 m
.72946 .0541 L
.73006 .0541 L
.73006 .08012 L
s
1 .894 .882 r
.73006 .08012 m
.73006 .054 L
.73045 .054 L
.73045 .08012 L
F
.804 .522 .247 r
.73006 .08012 m
.73006 .054 L
.73045 .054 L
.73045 .08012 L
s
1 .894 .882 r
.73045 .08012 m
.73045 .05388 L
.7307 .05388 L
.7307 .08012 L
F
.804 .522 .247 r
.73045 .08012 m
.73045 .05388 L
.7307 .05388 L
.7307 .08012 L
s
1 .894 .882 r
.7307 .08012 m
.7307 .05375 L
.73106 .05375 L
.73106 .08012 L
F
.804 .522 .247 r
.7307 .08012 m
.7307 .05375 L
.73106 .05375 L
.73106 .08012 L
s
1 .894 .882 r
.73106 .08012 m
.73106 .05366 L
.73156 .05366 L
.73156 .08012 L
F
.804 .522 .247 r
.73106 .08012 m
.73106 .05366 L
.73156 .05366 L
.73156 .08012 L
s
1 .894 .882 r
.73156 .08012 m
.73156 .05346 L
.73186 .05346 L
.73186 .08012 L
F
.804 .522 .247 r
.73156 .08012 m
.73156 .05346 L
.73186 .05346 L
.73186 .08012 L
s
1 .894 .882 r
.73186 .08012 m
.73186 .05338 L
.73211 .05338 L
.73211 .08012 L
F
.804 .522 .247 r
.73186 .08012 m
.73186 .05338 L
.73211 .05338 L
.73211 .08012 L
s
1 .894 .882 r
.73211 .08012 m
.73211 .05336 L
.7328 .05336 L
.7328 .08012 L
F
.804 .522 .247 r
.73211 .08012 m
.73211 .05336 L
.7328 .05336 L
.7328 .08012 L
s
1 .894 .882 r
.7328 .08012 m
.7328 .05299 L
.73335 .05299 L
.73335 .08012 L
F
.804 .522 .247 r
.7328 .08012 m
.7328 .05299 L
.73335 .05299 L
.73335 .08012 L
s
1 .894 .882 r
.73335 .08012 m
.73335 .05293 L
.73398 .05293 L
.73398 .08012 L
F
.804 .522 .247 r
.73335 .08012 m
.73335 .05293 L
.73398 .05293 L
.73398 .08012 L
s
1 .894 .882 r
.73398 .08012 m
.73398 .05257 L
.73469 .05257 L
.73469 .08012 L
F
.804 .522 .247 r
.73398 .08012 m
.73398 .05257 L
.73469 .05257 L
.73469 .08012 L
s
1 .894 .882 r
.73469 .08012 m
.73469 .05253 L
.73541 .05253 L
.73541 .08012 L
F
.804 .522 .247 r
.73469 .08012 m
.73469 .05253 L
.73541 .05253 L
.73541 .08012 L
s
1 .894 .882 r
.73541 .08012 m
.73541 .05216 L
.73599 .05216 L
.73599 .08012 L
F
.804 .522 .247 r
.73541 .08012 m
.73541 .05216 L
.73599 .05216 L
.73599 .08012 L
s
1 .894 .882 r
.73599 .08012 m
.73599 .052 L
.73651 .052 L
.73651 .08012 L
F
.804 .522 .247 r
.73599 .08012 m
.73599 .052 L
.73651 .052 L
.73651 .08012 L
s
1 .894 .882 r
.73651 .08012 m
.73651 .05198 L
.73717 .05198 L
.73717 .08012 L
F
.804 .522 .247 r
.73651 .08012 m
.73651 .05198 L
.73717 .05198 L
.73717 .08012 L
s
1 .894 .882 r
.73717 .08012 m
.73717 .0517 L
.73765 .0517 L
.73765 .08012 L
F
.804 .522 .247 r
.73717 .08012 m
.73717 .0517 L
.73765 .0517 L
.73765 .08012 L
s
1 .894 .882 r
.73765 .08012 m
.73765 .05153 L
.73812 .05153 L
.73812 .08012 L
F
.804 .522 .247 r
.73765 .08012 m
.73765 .05153 L
.73812 .05153 L
.73812 .08012 L
s
1 .894 .882 r
.73812 .08012 m
.73812 .05146 L
.73873 .05146 L
.73873 .08012 L
F
.804 .522 .247 r
.73812 .08012 m
.73812 .05146 L
.73873 .05146 L
.73873 .08012 L
s
1 .894 .882 r
.73873 .08012 m
.73873 .05127 L
.73896 .05127 L
.73896 .08012 L
F
.804 .522 .247 r
.73873 .08012 m
.73873 .05127 L
.73896 .05127 L
.73896 .08012 L
s
1 .894 .882 r
.73896 .08012 m
.73896 .05112 L
.73961 .05112 L
.73961 .08012 L
F
.804 .522 .247 r
.73896 .08012 m
.73896 .05112 L
.73961 .05112 L
.73961 .08012 L
s
1 .894 .882 r
.73961 .08012 m
.73961 .05103 L
.74022 .05103 L
.74022 .08012 L
F
.804 .522 .247 r
.73961 .08012 m
.73961 .05103 L
.74022 .05103 L
.74022 .08012 L
s
1 .894 .882 r
.74022 .08012 m
.74022 .05081 L
.74045 .05081 L
.74045 .08012 L
F
.804 .522 .247 r
.74022 .08012 m
.74022 .05081 L
.74045 .05081 L
.74045 .08012 L
s
1 .894 .882 r
.74045 .08012 m
.74045 .05077 L
.74091 .05077 L
.74091 .08012 L
F
.804 .522 .247 r
.74045 .08012 m
.74045 .05077 L
.74091 .05077 L
.74091 .08012 L
s
1 .894 .882 r
.74091 .08012 m
.74091 .05047 L
.74157 .05047 L
.74157 .08012 L
F
.804 .522 .247 r
.74091 .08012 m
.74091 .05047 L
.74157 .05047 L
.74157 .08012 L
s
1 .894 .882 r
.74157 .08012 m
.74157 .05041 L
.7418 .05041 L
.7418 .08012 L
F
.804 .522 .247 r
.74157 .08012 m
.74157 .05041 L
.7418 .05041 L
.7418 .08012 L
s
1 .894 .882 r
.7418 .08012 m
.7418 .05032 L
.74238 .05032 L
.74238 .08012 L
F
.804 .522 .247 r
.7418 .08012 m
.7418 .05032 L
.74238 .05032 L
.74238 .08012 L
s
1 .894 .882 r
.74238 .08012 m
.74238 .05008 L
.7428 .05008 L
.7428 .08012 L
F
.804 .522 .247 r
.74238 .08012 m
.74238 .05008 L
.7428 .05008 L
.7428 .08012 L
s
1 .894 .882 r
.7428 .08012 m
.7428 .05003 L
.74332 .05003 L
.74332 .08012 L
F
.804 .522 .247 r
.7428 .08012 m
.7428 .05003 L
.74332 .05003 L
.74332 .08012 L
s
1 .894 .882 r
.74332 .08012 m
.74332 .04989 L
.74379 .04989 L
.74379 .08012 L
F
.804 .522 .247 r
.74332 .08012 m
.74332 .04989 L
.74379 .04989 L
.74379 .08012 L
s
1 .894 .882 r
.74379 .08012 m
.74379 .04972 L
.74429 .04972 L
.74429 .08012 L
F
.804 .522 .247 r
.74379 .08012 m
.74379 .04972 L
.74429 .04972 L
.74429 .08012 L
s
1 .894 .882 r
.74429 .08012 m
.74429 .04951 L
.74467 .04951 L
.74467 .08012 L
F
.804 .522 .247 r
.74429 .08012 m
.74429 .04951 L
.74467 .04951 L
.74467 .08012 L
s
1 .894 .882 r
.74467 .08012 m
.74467 .04948 L
.74524 .04948 L
.74524 .08012 L
F
.804 .522 .247 r
.74467 .08012 m
.74467 .04948 L
.74524 .04948 L
.74524 .08012 L
s
1 .894 .882 r
.74524 .08012 m
.74524 .04931 L
.74588 .04931 L
.74588 .08012 L
F
.804 .522 .247 r
.74524 .08012 m
.74524 .04931 L
.74588 .04931 L
.74588 .08012 L
s
1 .894 .882 r
.74588 .08012 m
.74588 .04913 L
.74649 .04913 L
.74649 .08012 L
F
.804 .522 .247 r
.74588 .08012 m
.74588 .04913 L
.74649 .04913 L
.74649 .08012 L
s
1 .894 .882 r
.74649 .08012 m
.74649 .04885 L
.74689 .04885 L
.74689 .08012 L
F
.804 .522 .247 r
.74649 .08012 m
.74649 .04885 L
.74689 .04885 L
.74689 .08012 L
s
1 .894 .882 r
.74689 .08012 m
.74689 .04867 L
.74747 .04867 L
.74747 .08012 L
F
.804 .522 .247 r
.74689 .08012 m
.74689 .04867 L
.74747 .04867 L
.74747 .08012 L
s
1 .894 .882 r
.74747 .08012 m
.74747 .04865 L
.74775 .04865 L
.74775 .08012 L
F
.804 .522 .247 r
.74747 .08012 m
.74747 .04865 L
.74775 .04865 L
.74775 .08012 L
s
1 .894 .882 r
.74775 .08012 m
.74775 .04858 L
.74805 .04858 L
.74805 .08012 L
F
.804 .522 .247 r
.74775 .08012 m
.74775 .04858 L
.74805 .04858 L
.74805 .08012 L
s
1 .894 .882 r
.74805 .08012 m
.74805 .04837 L
.74852 .04837 L
.74852 .08012 L
F
.804 .522 .247 r
.74805 .08012 m
.74805 .04837 L
.74852 .04837 L
.74852 .08012 L
s
1 .894 .882 r
.74852 .08012 m
.74852 .04831 L
.74884 .04831 L
.74884 .08012 L
F
.804 .522 .247 r
.74852 .08012 m
.74852 .04831 L
.74884 .04831 L
.74884 .08012 L
s
1 .894 .882 r
.74884 .08012 m
.74884 .0482 L
.74938 .0482 L
.74938 .08012 L
F
.804 .522 .247 r
.74884 .08012 m
.74884 .0482 L
.74938 .0482 L
.74938 .08012 L
s
1 .894 .882 r
.74938 .08012 m
.74938 .04799 L
.74981 .04799 L
.74981 .08012 L
F
.804 .522 .247 r
.74938 .08012 m
.74938 .04799 L
.74981 .04799 L
.74981 .08012 L
s
1 .894 .882 r
.74981 .08012 m
.74981 .04793 L
.75027 .04793 L
.75027 .08012 L
F
.804 .522 .247 r
.74981 .08012 m
.74981 .04793 L
.75027 .04793 L
.75027 .08012 L
s
1 .894 .882 r
.75027 .08012 m
.75027 .04774 L
.75067 .04774 L
.75067 .08012 L
F
.804 .522 .247 r
.75027 .08012 m
.75027 .04774 L
.75067 .04774 L
.75067 .08012 L
s
1 .894 .882 r
.75067 .08012 m
.75067 .04766 L
.75133 .04766 L
.75133 .08012 L
F
.804 .522 .247 r
.75067 .08012 m
.75067 .04766 L
.75133 .04766 L
.75133 .08012 L
s
1 .894 .882 r
.75133 .08012 m
.75133 .04748 L
.75175 .04748 L
.75175 .08012 L
F
.804 .522 .247 r
.75133 .08012 m
.75133 .04748 L
.75175 .04748 L
.75175 .08012 L
s
1 .894 .882 r
.75175 .08012 m
.75175 .04739 L
.75197 .04739 L
.75197 .08012 L
F
.804 .522 .247 r
.75175 .08012 m
.75175 .04739 L
.75197 .04739 L
.75197 .08012 L
s
1 .894 .882 r
.75197 .08012 m
.75197 .04721 L
.75245 .04721 L
.75245 .08012 L
F
.804 .522 .247 r
.75197 .08012 m
.75197 .04721 L
.75245 .04721 L
.75245 .08012 L
s
1 .894 .882 r
.75245 .08012 m
.75245 .04704 L
.75309 .04704 L
.75309 .08012 L
F
.804 .522 .247 r
.75245 .08012 m
.75245 .04704 L
.75309 .04704 L
.75309 .08012 L
s
1 .894 .882 r
.75309 .08012 m
.75309 .04701 L
.75366 .04701 L
.75366 .08012 L
F
.804 .522 .247 r
.75309 .08012 m
.75309 .04701 L
.75366 .04701 L
.75366 .08012 L
s
1 .894 .882 r
.75366 .08012 m
.75366 .04679 L
.7542 .04679 L
.7542 .08012 L
F
.804 .522 .247 r
.75366 .08012 m
.75366 .04679 L
.7542 .04679 L
.7542 .08012 L
s
1 .894 .882 r
.7542 .08012 m
.7542 .04654 L
.75488 .04654 L
.75488 .08012 L
F
.804 .522 .247 r
.7542 .08012 m
.7542 .04654 L
.75488 .04654 L
.75488 .08012 L
s
1 .894 .882 r
.75488 .08012 m
.75488 .04641 L
.75528 .04641 L
.75528 .08012 L
F
.804 .522 .247 r
.75488 .08012 m
.75488 .04641 L
.75528 .04641 L
.75528 .08012 L
s
1 .894 .882 r
.75528 .08012 m
.75528 .04632 L
.75557 .04632 L
.75557 .08012 L
F
.804 .522 .247 r
.75528 .08012 m
.75528 .04632 L
.75557 .04632 L
.75557 .08012 L
s
1 .894 .882 r
.75557 .08012 m
.75557 .04625 L
.75594 .04625 L
.75594 .08012 L
F
.804 .522 .247 r
.75557 .08012 m
.75557 .04625 L
.75594 .04625 L
.75594 .08012 L
s
1 .894 .882 r
.75594 .08012 m
.75594 .04613 L
.75626 .04613 L
.75626 .08012 L
F
.804 .522 .247 r
.75594 .08012 m
.75594 .04613 L
.75626 .04613 L
.75626 .08012 L
s
1 .894 .882 r
.75626 .08012 m
.75626 .04601 L
.75676 .04601 L
.75676 .08012 L
F
.804 .522 .247 r
.75626 .08012 m
.75626 .04601 L
.75676 .04601 L
.75676 .08012 L
s
1 .894 .882 r
.75676 .08012 m
.75676 .04588 L
.75717 .04588 L
.75717 .08012 L
F
.804 .522 .247 r
.75676 .08012 m
.75676 .04588 L
.75717 .04588 L
.75717 .08012 L
s
1 .894 .882 r
.75717 .08012 m
.75717 .04573 L
.75787 .04573 L
.75787 .08012 L
F
.804 .522 .247 r
.75717 .08012 m
.75717 .04573 L
.75787 .04573 L
.75787 .08012 L
s
1 .894 .882 r
.75787 .08012 m
.75787 .04555 L
.75835 .04555 L
.75835 .08012 L
F
.804 .522 .247 r
.75787 .08012 m
.75787 .04555 L
.75835 .04555 L
.75835 .08012 L
s
1 .894 .882 r
.75835 .08012 m
.75835 .04544 L
.75878 .04544 L
.75878 .08012 L
F
.804 .522 .247 r
.75835 .08012 m
.75835 .04544 L
.75878 .04544 L
.75878 .08012 L
s
1 .894 .882 r
.75878 .08012 m
.75878 .04533 L
.75911 .04533 L
.75911 .08012 L
F
.804 .522 .247 r
.75878 .08012 m
.75878 .04533 L
.75911 .04533 L
.75911 .08012 L
s
1 .894 .882 r
.75911 .08012 m
.75911 .04521 L
.75957 .04521 L
.75957 .08012 L
F
.804 .522 .247 r
.75911 .08012 m
.75911 .04521 L
.75957 .04521 L
.75957 .08012 L
s
1 .894 .882 r
.75957 .08012 m
.75957 .04514 L
.75994 .04514 L
.75994 .08012 L
F
.804 .522 .247 r
.75957 .08012 m
.75957 .04514 L
.75994 .04514 L
.75994 .08012 L
s
1 .894 .882 r
.75994 .08012 m
.75994 .04503 L
.76057 .04503 L
.76057 .08012 L
F
.804 .522 .247 r
.75994 .08012 m
.75994 .04503 L
.76057 .04503 L
.76057 .08012 L
s
1 .894 .882 r
.76057 .08012 m
.76057 .04475 L
.76119 .04475 L
.76119 .08012 L
F
.804 .522 .247 r
.76057 .08012 m
.76057 .04475 L
.76119 .04475 L
.76119 .08012 L
s
1 .894 .882 r
.76119 .08012 m
.76119 .04463 L
.76192 .04463 L
.76192 .08012 L
F
.804 .522 .247 r
.76119 .08012 m
.76119 .04463 L
.76192 .04463 L
.76192 .08012 L
s
1 .894 .882 r
.76192 .08012 m
.76192 .04441 L
.76262 .04441 L
.76262 .08012 L
F
.804 .522 .247 r
.76192 .08012 m
.76192 .04441 L
.76262 .04441 L
.76262 .08012 L
s
1 .894 .882 r
.76262 .08012 m
.76262 .04414 L
.76332 .04414 L
.76332 .08012 L
F
.804 .522 .247 r
.76262 .08012 m
.76262 .04414 L
.76332 .04414 L
.76332 .08012 L
s
1 .894 .882 r
.76332 .08012 m
.76332 .04407 L
.76375 .04407 L
.76375 .08012 L
F
.804 .522 .247 r
.76332 .08012 m
.76332 .04407 L
.76375 .04407 L
.76375 .08012 L
s
1 .894 .882 r
.76375 .08012 m
.76375 .04396 L
.76447 .04396 L
.76447 .08012 L
F
.804 .522 .247 r
.76375 .08012 m
.76375 .04396 L
.76447 .04396 L
.76447 .08012 L
s
1 .894 .882 r
.76447 .08012 m
.76447 .04374 L
.76492 .04374 L
.76492 .08012 L
F
.804 .522 .247 r
.76447 .08012 m
.76447 .04374 L
.76492 .04374 L
.76492 .08012 L
s
1 .894 .882 r
.76492 .08012 m
.76492 .04368 L
.76519 .04368 L
.76519 .08012 L
F
.804 .522 .247 r
.76492 .08012 m
.76492 .04368 L
.76519 .04368 L
.76519 .08012 L
s
1 .894 .882 r
.76519 .08012 m
.76519 .04354 L
.76578 .04354 L
.76578 .08012 L
F
.804 .522 .247 r
.76519 .08012 m
.76519 .04354 L
.76578 .04354 L
.76578 .08012 L
s
1 .894 .882 r
.76578 .08012 m
.76578 .04335 L
.76619 .04335 L
.76619 .08012 L
F
.804 .522 .247 r
.76578 .08012 m
.76578 .04335 L
.76619 .04335 L
.76619 .08012 L
s
1 .894 .882 r
.76619 .08012 m
.76619 .04323 L
.76669 .04323 L
.76669 .08012 L
F
.804 .522 .247 r
.76619 .08012 m
.76619 .04323 L
.76669 .04323 L
.76669 .08012 L
s
1 .894 .882 r
.76669 .08012 m
.76669 .04316 L
.76729 .04316 L
.76729 .08012 L
F
.804 .522 .247 r
.76669 .08012 m
.76669 .04316 L
.76729 .04316 L
.76729 .08012 L
s
1 .894 .882 r
.76729 .08012 m
.76729 .04294 L
.76781 .04294 L
.76781 .08012 L
F
.804 .522 .247 r
.76729 .08012 m
.76729 .04294 L
.76781 .04294 L
.76781 .08012 L
s
1 .894 .882 r
.76781 .08012 m
.76781 .04287 L
.76807 .04287 L
.76807 .08012 L
F
.804 .522 .247 r
.76781 .08012 m
.76781 .04287 L
.76807 .04287 L
.76807 .08012 L
s
1 .894 .882 r
.76807 .08012 m
.76807 .04281 L
.76847 .04281 L
.76847 .08012 L
F
.804 .522 .247 r
.76807 .08012 m
.76807 .04281 L
.76847 .04281 L
.76847 .08012 L
s
1 .894 .882 r
.76847 .08012 m
.76847 .04267 L
.76879 .04267 L
.76879 .08012 L
F
.804 .522 .247 r
.76847 .08012 m
.76847 .04267 L
.76879 .04267 L
.76879 .08012 L
s
1 .894 .882 r
.76879 .08012 m
.76879 .04255 L
.76912 .04255 L
.76912 .08012 L
F
.804 .522 .247 r
.76879 .08012 m
.76879 .04255 L
.76912 .04255 L
.76912 .08012 L
s
1 .894 .882 r
.76912 .08012 m
.76912 .04248 L
.7694 .04248 L
.7694 .08012 L
F
.804 .522 .247 r
.76912 .08012 m
.76912 .04248 L
.7694 .04248 L
.7694 .08012 L
s
1 .894 .882 r
.7694 .08012 m
.7694 .0424 L
.77005 .0424 L
.77005 .08012 L
F
.804 .522 .247 r
.7694 .08012 m
.7694 .0424 L
.77005 .0424 L
.77005 .08012 L
s
1 .894 .882 r
.77005 .08012 m
.77005 .04229 L
.77068 .04229 L
.77068 .08012 L
F
.804 .522 .247 r
.77005 .08012 m
.77005 .04229 L
.77068 .04229 L
.77068 .08012 L
s
1 .894 .882 r
.77068 .08012 m
.77068 .04207 L
.77141 .04207 L
.77141 .08012 L
F
.804 .522 .247 r
.77068 .08012 m
.77068 .04207 L
.77141 .04207 L
.77141 .08012 L
s
1 .894 .882 r
.77141 .08012 m
.77141 .04192 L
.77197 .04192 L
.77197 .08012 L
F
.804 .522 .247 r
.77141 .08012 m
.77141 .04192 L
.77197 .04192 L
.77197 .08012 L
s
1 .894 .882 r
.77197 .08012 m
.77197 .04177 L
.77246 .04177 L
.77246 .08012 L
F
.804 .522 .247 r
.77197 .08012 m
.77197 .04177 L
.77246 .04177 L
.77246 .08012 L
s
1 .894 .882 r
.77246 .08012 m
.77246 .0416 L
.77268 .0416 L
.77268 .08012 L
F
.804 .522 .247 r
.77246 .08012 m
.77246 .0416 L
.77268 .0416 L
.77268 .08012 L
s
1 .894 .882 r
.77268 .08012 m
.77268 .04155 L
.773 .04155 L
.773 .08012 L
F
.804 .522 .247 r
.77268 .08012 m
.77268 .04155 L
.773 .04155 L
.773 .08012 L
s
1 .894 .882 r
.773 .08012 m
.773 .04141 L
.77357 .04141 L
.77357 .08012 L
F
.804 .522 .247 r
.773 .08012 m
.773 .04141 L
.77357 .04141 L
.77357 .08012 L
s
1 .894 .882 r
.77357 .08012 m
.77357 .04128 L
.77409 .04128 L
.77409 .08012 L
F
.804 .522 .247 r
.77357 .08012 m
.77357 .04128 L
.77409 .04128 L
.77409 .08012 L
s
1 .894 .882 r
.77409 .08012 m
.77409 .04116 L
.77434 .04116 L
.77434 .08012 L
F
.804 .522 .247 r
.77409 .08012 m
.77409 .04116 L
.77434 .04116 L
.77434 .08012 L
s
1 .894 .882 r
.77434 .08012 m
.77434 .04099 L
.77497 .04099 L
.77497 .08012 L
F
.804 .522 .247 r
.77434 .08012 m
.77434 .04099 L
.77497 .04099 L
.77497 .08012 L
s
1 .894 .882 r
.77497 .08012 m
.77497 .04092 L
.77553 .04092 L
.77553 .08012 L
F
.804 .522 .247 r
.77497 .08012 m
.77497 .04092 L
.77553 .04092 L
.77553 .08012 L
s
1 .894 .882 r
.77553 .08012 m
.77553 .04084 L
.77583 .04084 L
.77583 .08012 L
F
.804 .522 .247 r
.77553 .08012 m
.77553 .04084 L
.77583 .04084 L
.77583 .08012 L
s
1 .894 .882 r
.77583 .08012 m
.77583 .04059 L
.77654 .04059 L
.77654 .08012 L
F
.804 .522 .247 r
.77583 .08012 m
.77583 .04059 L
.77654 .04059 L
.77654 .08012 L
s
1 .894 .882 r
.77654 .08012 m
.77654 .04054 L
.7768 .04054 L
.7768 .08012 L
F
.804 .522 .247 r
.77654 .08012 m
.77654 .04054 L
.7768 .04054 L
.7768 .08012 L
s
1 .894 .882 r
.7768 .08012 m
.7768 .04045 L
.77717 .04045 L
.77717 .08012 L
F
.804 .522 .247 r
.7768 .08012 m
.7768 .04045 L
.77717 .04045 L
.77717 .08012 L
s
1 .894 .882 r
.77717 .08012 m
.77717 .04038 L
.7777 .04038 L
.7777 .08012 L
F
.804 .522 .247 r
.77717 .08012 m
.77717 .04038 L
.7777 .04038 L
.7777 .08012 L
s
1 .894 .882 r
.7777 .08012 m
.7777 .04022 L
.77803 .04022 L
.77803 .08012 L
F
.804 .522 .247 r
.7777 .08012 m
.7777 .04022 L
.77803 .04022 L
.77803 .08012 L
s
1 .894 .882 r
.77803 .08012 m
.77803 .04008 L
.7785 .04008 L
.7785 .08012 L
F
.804 .522 .247 r
.77803 .08012 m
.77803 .04008 L
.7785 .04008 L
.7785 .08012 L
s
1 .894 .882 r
.7785 .08012 m
.7785 .04005 L
.77883 .04005 L
.77883 .08012 L
F
.804 .522 .247 r
.7785 .08012 m
.7785 .04005 L
.77883 .04005 L
.77883 .08012 L
s
1 .894 .882 r
.77883 .08012 m
.77883 .03997 L
.77918 .03997 L
.77918 .08012 L
F
.804 .522 .247 r
.77883 .08012 m
.77883 .03997 L
.77918 .03997 L
.77918 .08012 L
s
1 .894 .882 r
.77918 .08012 m
.77918 .03989 L
.77941 .03989 L
.77941 .08012 L
F
.804 .522 .247 r
.77918 .08012 m
.77918 .03989 L
.77941 .03989 L
.77941 .08012 L
s
1 .894 .882 r
.77941 .08012 m
.77941 .03975 L
.77978 .03975 L
.77978 .08012 L
F
.804 .522 .247 r
.77941 .08012 m
.77941 .03975 L
.77978 .03975 L
.77978 .08012 L
s
1 .894 .882 r
.77978 .08012 m
.77978 .03971 L
.78004 .03971 L
.78004 .08012 L
F
.804 .522 .247 r
.77978 .08012 m
.77978 .03971 L
.78004 .03971 L
.78004 .08012 L
s
1 .894 .882 r
.78004 .08012 m
.78004 .03959 L
.78047 .03959 L
.78047 .08012 L
F
.804 .522 .247 r
.78004 .08012 m
.78004 .03959 L
.78047 .03959 L
.78047 .08012 L
s
1 .894 .882 r
.78047 .08012 m
.78047 .03956 L
.7808 .03956 L
.7808 .08012 L
F
.804 .522 .247 r
.78047 .08012 m
.78047 .03956 L
.7808 .03956 L
.7808 .08012 L
s
1 .894 .882 r
.7808 .08012 m
.7808 .03942 L
.78117 .03942 L
.78117 .08012 L
F
.804 .522 .247 r
.7808 .08012 m
.7808 .03942 L
.78117 .03942 L
.78117 .08012 L
s
1 .894 .882 r
.78117 .08012 m
.78117 .03934 L
.78161 .03934 L
.78161 .08012 L
F
.804 .522 .247 r
.78117 .08012 m
.78117 .03934 L
.78161 .03934 L
.78161 .08012 L
s
1 .894 .882 r
.78161 .08012 m
.78161 .03916 L
.78228 .03916 L
.78228 .08012 L
F
.804 .522 .247 r
.78161 .08012 m
.78161 .03916 L
.78228 .03916 L
.78228 .08012 L
s
1 .894 .882 r
.78228 .08012 m
.78228 .03909 L
.78261 .03909 L
.78261 .08012 L
F
.804 .522 .247 r
.78228 .08012 m
.78228 .03909 L
.78261 .03909 L
.78261 .08012 L
s
1 .894 .882 r
.78261 .08012 m
.78261 .03901 L
.78287 .03901 L
.78287 .08012 L
F
.804 .522 .247 r
.78261 .08012 m
.78261 .03901 L
.78287 .03901 L
.78287 .08012 L
s
1 .894 .882 r
.78287 .08012 m
.78287 .03884 L
.78348 .03884 L
.78348 .08012 L
F
.804 .522 .247 r
.78287 .08012 m
.78287 .03884 L
.78348 .03884 L
.78348 .08012 L
s
1 .894 .882 r
.78348 .08012 m
.78348 .0388 L
.78384 .0388 L
.78384 .08012 L
F
.804 .522 .247 r
.78348 .08012 m
.78348 .0388 L
.78384 .0388 L
.78384 .08012 L
s
1 .894 .882 r
.78384 .08012 m
.78384 .0387 L
.78414 .0387 L
.78414 .08012 L
F
.804 .522 .247 r
.78384 .08012 m
.78384 .0387 L
.78414 .0387 L
.78414 .08012 L
s
1 .894 .882 r
.78414 .08012 m
.78414 .03862 L
.78451 .03862 L
.78451 .08012 L
F
.804 .522 .247 r
.78414 .08012 m
.78414 .03862 L
.78451 .03862 L
.78451 .08012 L
s
1 .894 .882 r
.78451 .08012 m
.78451 .03854 L
.78477 .03854 L
.78477 .08012 L
F
.804 .522 .247 r
.78451 .08012 m
.78451 .03854 L
.78477 .03854 L
.78477 .08012 L
s
1 .894 .882 r
.78477 .08012 m
.78477 .03849 L
.78506 .03849 L
.78506 .08012 L
F
.804 .522 .247 r
.78477 .08012 m
.78477 .03849 L
.78506 .03849 L
.78506 .08012 L
s
1 .894 .882 r
.78506 .08012 m
.78506 .03839 L
.78537 .03839 L
.78537 .08012 L
F
.804 .522 .247 r
.78506 .08012 m
.78506 .03839 L
.78537 .03839 L
.78537 .08012 L
s
1 .894 .882 r
.78537 .08012 m
.78537 .03829 L
.7857 .03829 L
.7857 .08012 L
F
.804 .522 .247 r
.78537 .08012 m
.78537 .03829 L
.7857 .03829 L
.7857 .08012 L
s
1 .894 .882 r
.7857 .08012 m
.7857 .03816 L
.78632 .03816 L
.78632 .08012 L
F
.804 .522 .247 r
.7857 .08012 m
.7857 .03816 L
.78632 .03816 L
.78632 .08012 L
s
1 .894 .882 r
.78632 .08012 m
.78632 .03802 L
.78682 .03802 L
.78682 .08012 L
F
.804 .522 .247 r
.78632 .08012 m
.78632 .03802 L
.78682 .03802 L
.78682 .08012 L
s
1 .894 .882 r
.78682 .08012 m
.78682 .03786 L
.78753 .03786 L
.78753 .08012 L
F
.804 .522 .247 r
.78682 .08012 m
.78682 .03786 L
.78753 .03786 L
.78753 .08012 L
s
1 .894 .882 r
.78753 .08012 m
.78753 .0377 L
.78812 .0377 L
.78812 .08012 L
F
.804 .522 .247 r
.78753 .08012 m
.78753 .0377 L
.78812 .0377 L
.78812 .08012 L
s
1 .894 .882 r
.78812 .08012 m
.78812 .03763 L
.78863 .03763 L
.78863 .08012 L
F
.804 .522 .247 r
.78812 .08012 m
.78812 .03763 L
.78863 .03763 L
.78863 .08012 L
s
1 .894 .882 r
.78863 .08012 m
.78863 .0375 L
.78899 .0375 L
.78899 .08012 L
F
.804 .522 .247 r
.78863 .08012 m
.78863 .0375 L
.78899 .0375 L
.78899 .08012 L
s
1 .894 .882 r
.78899 .08012 m
.78899 .03736 L
.7897 .03736 L
.7897 .08012 L
F
.804 .522 .247 r
.78899 .08012 m
.78899 .03736 L
.7897 .03736 L
.7897 .08012 L
s
1 .894 .882 r
.7897 .08012 m
.7897 .0372 L
.79014 .0372 L
.79014 .08012 L
F
.804 .522 .247 r
.7897 .08012 m
.7897 .0372 L
.79014 .0372 L
.79014 .08012 L
s
1 .894 .882 r
.79014 .08012 m
.79014 .03709 L
.7906 .03709 L
.7906 .08012 L
F
.804 .522 .247 r
.79014 .08012 m
.79014 .03709 L
.7906 .03709 L
.7906 .08012 L
s
1 .894 .882 r
.7906 .08012 m
.7906 .03695 L
.79127 .03695 L
.79127 .08012 L
F
.804 .522 .247 r
.7906 .08012 m
.7906 .03695 L
.79127 .03695 L
.79127 .08012 L
s
1 .894 .882 r
.79127 .08012 m
.79127 .03685 L
.79186 .03685 L
.79186 .08012 L
F
.804 .522 .247 r
.79127 .08012 m
.79127 .03685 L
.79186 .03685 L
.79186 .08012 L
s
1 .894 .882 r
.79186 .08012 m
.79186 .03676 L
.79215 .03676 L
.79215 .08012 L
F
.804 .522 .247 r
.79186 .08012 m
.79186 .03676 L
.79215 .03676 L
.79215 .08012 L
s
1 .894 .882 r
.79215 .08012 m
.79215 .03668 L
.79239 .03668 L
.79239 .08012 L
F
.804 .522 .247 r
.79215 .08012 m
.79215 .03668 L
.79239 .03668 L
.79239 .08012 L
s
1 .894 .882 r
.79239 .08012 m
.79239 .03664 L
.79262 .03664 L
.79262 .08012 L
F
.804 .522 .247 r
.79239 .08012 m
.79239 .03664 L
.79262 .03664 L
.79262 .08012 L
s
1 .894 .882 r
.79262 .08012 m
.79262 .03658 L
.7931 .03658 L
.7931 .08012 L
F
.804 .522 .247 r
.79262 .08012 m
.79262 .03658 L
.7931 .03658 L
.7931 .08012 L
s
1 .894 .882 r
.7931 .08012 m
.7931 .03643 L
.79334 .03643 L
.79334 .08012 L
F
.804 .522 .247 r
.7931 .08012 m
.7931 .03643 L
.79334 .03643 L
.79334 .08012 L
s
1 .894 .882 r
.79334 .08012 m
.79334 .03637 L
.7937 .03637 L
.7937 .08012 L
F
.804 .522 .247 r
.79334 .08012 m
.79334 .03637 L
.7937 .03637 L
.7937 .08012 L
s
1 .894 .882 r
.7937 .08012 m
.7937 .0362 L
.7943 .0362 L
.7943 .08012 L
F
.804 .522 .247 r
.7937 .08012 m
.7937 .0362 L
.7943 .0362 L
.7943 .08012 L
s
1 .894 .882 r
.7943 .08012 m
.7943 .03612 L
.7947 .03612 L
.7947 .08012 L
F
.804 .522 .247 r
.7943 .08012 m
.7943 .03612 L
.7947 .03612 L
.7947 .08012 L
s
1 .894 .882 r
.7947 .08012 m
.7947 .03603 L
.7953 .03603 L
.7953 .08012 L
F
.804 .522 .247 r
.7947 .08012 m
.7947 .03603 L
.7953 .03603 L
.7953 .08012 L
s
1 .894 .882 r
.7953 .08012 m
.7953 .03593 L
.79563 .03593 L
.79563 .08012 L
F
.804 .522 .247 r
.7953 .08012 m
.7953 .03593 L
.79563 .03593 L
.79563 .08012 L
s
1 .894 .882 r
.79563 .08012 m
.79563 .03578 L
.79615 .03578 L
.79615 .08012 L
F
.804 .522 .247 r
.79563 .08012 m
.79563 .03578 L
.79615 .03578 L
.79615 .08012 L
s
1 .894 .882 r
.79615 .08012 m
.79615 .03573 L
.79647 .03573 L
.79647 .08012 L
F
.804 .522 .247 r
.79615 .08012 m
.79615 .03573 L
.79647 .03573 L
.79647 .08012 L
s
1 .894 .882 r
.79647 .08012 m
.79647 .03559 L
.79695 .03559 L
.79695 .08012 L
F
.804 .522 .247 r
.79647 .08012 m
.79647 .03559 L
.79695 .03559 L
.79695 .08012 L
s
1 .894 .882 r
.79695 .08012 m
.79695 .03551 L
.79739 .03551 L
.79739 .08012 L
F
.804 .522 .247 r
.79695 .08012 m
.79695 .03551 L
.79739 .03551 L
.79739 .08012 L
s
1 .894 .882 r
.79739 .08012 m
.79739 .03546 L
.79764 .03546 L
.79764 .08012 L
F
.804 .522 .247 r
.79739 .08012 m
.79739 .03546 L
.79764 .03546 L
.79764 .08012 L
s
1 .894 .882 r
.79764 .08012 m
.79764 .03536 L
.79797 .03536 L
.79797 .08012 L
F
.804 .522 .247 r
.79764 .08012 m
.79764 .03536 L
.79797 .03536 L
.79797 .08012 L
s
1 .894 .882 r
.79797 .08012 m
.79797 .03518 L
.7986 .03518 L
.7986 .08012 L
F
.804 .522 .247 r
.79797 .08012 m
.79797 .03518 L
.7986 .03518 L
.7986 .08012 L
s
1 .894 .882 r
.7986 .08012 m
.7986 .03515 L
.79926 .03515 L
.79926 .08012 L
F
.804 .522 .247 r
.7986 .08012 m
.7986 .03515 L
.79926 .03515 L
.79926 .08012 L
s
1 .894 .882 r
.79926 .08012 m
.79926 .03497 L
.79987 .03497 L
.79987 .08012 L
F
.804 .522 .247 r
.79926 .08012 m
.79926 .03497 L
.79987 .03497 L
.79987 .08012 L
s
1 .894 .882 r
.79987 .08012 m
.79987 .03489 L
.80023 .03489 L
.80023 .08012 L
F
.804 .522 .247 r
.79987 .08012 m
.79987 .03489 L
.80023 .03489 L
.80023 .08012 L
s
1 .894 .882 r
.80023 .08012 m
.80023 .03479 L
.80064 .03479 L
.80064 .08012 L
F
.804 .522 .247 r
.80023 .08012 m
.80023 .03479 L
.80064 .03479 L
.80064 .08012 L
s
1 .894 .882 r
.80064 .08012 m
.80064 .03468 L
.80106 .03468 L
.80106 .08012 L
F
.804 .522 .247 r
.80064 .08012 m
.80064 .03468 L
.80106 .03468 L
.80106 .08012 L
s
1 .894 .882 r
.80106 .08012 m
.80106 .03451 L
.80173 .03451 L
.80173 .08012 L
F
.804 .522 .247 r
.80106 .08012 m
.80106 .03451 L
.80173 .03451 L
.80173 .08012 L
s
1 .894 .882 r
.80173 .08012 m
.80173 .03439 L
.80223 .03439 L
.80223 .08012 L
F
.804 .522 .247 r
.80173 .08012 m
.80173 .03439 L
.80223 .03439 L
.80223 .08012 L
s
1 .894 .882 r
.80223 .08012 m
.80223 .03434 L
.80256 .03434 L
.80256 .08012 L
F
.804 .522 .247 r
.80223 .08012 m
.80223 .03434 L
.80256 .03434 L
.80256 .08012 L
s
1 .894 .882 r
.80256 .08012 m
.80256 .03427 L
.80296 .03427 L
.80296 .08012 L
F
.804 .522 .247 r
.80256 .08012 m
.80256 .03427 L
.80296 .03427 L
.80296 .08012 L
s
1 .894 .882 r
.80296 .08012 m
.80296 .03408 L
.80363 .03408 L
.80363 .08012 L
F
.804 .522 .247 r
.80296 .08012 m
.80296 .03408 L
.80363 .03408 L
.80363 .08012 L
s
1 .894 .882 r
.80363 .08012 m
.80363 .03401 L
.80387 .03401 L
.80387 .08012 L
F
.804 .522 .247 r
.80363 .08012 m
.80363 .03401 L
.80387 .03401 L
.80387 .08012 L
s
1 .894 .882 r
.80387 .08012 m
.80387 .03395 L
.80418 .03395 L
.80418 .08012 L
F
.804 .522 .247 r
.80387 .08012 m
.80387 .03395 L
.80418 .03395 L
.80418 .08012 L
s
1 .894 .882 r
.80418 .08012 m
.80418 .03389 L
.80444 .03389 L
.80444 .08012 L
F
.804 .522 .247 r
.80418 .08012 m
.80418 .03389 L
.80444 .03389 L
.80444 .08012 L
s
1 .894 .882 r
.80444 .08012 m
.80444 .0338 L
.80472 .0338 L
.80472 .08012 L
F
.804 .522 .247 r
.80444 .08012 m
.80444 .0338 L
.80472 .0338 L
.80472 .08012 L
s
1 .894 .882 r
.80472 .08012 m
.80472 .03368 L
.80529 .03368 L
.80529 .08012 L
F
.804 .522 .247 r
.80472 .08012 m
.80472 .03368 L
.80529 .03368 L
.80529 .08012 L
s
1 .894 .882 r
.80529 .08012 m
.80529 .03367 L
.80573 .03367 L
.80573 .08012 L
F
.804 .522 .247 r
.80529 .08012 m
.80529 .03367 L
.80573 .03367 L
.80573 .08012 L
s
1 .894 .882 r
.80573 .08012 m
.80573 .03352 L
.8064 .03352 L
.8064 .08012 L
F
.804 .522 .247 r
.80573 .08012 m
.80573 .03352 L
.8064 .03352 L
.8064 .08012 L
s
1 .894 .882 r
.8064 .08012 m
.8064 .03341 L
.80689 .03341 L
.80689 .08012 L
F
.804 .522 .247 r
.8064 .08012 m
.8064 .03341 L
.80689 .03341 L
.80689 .08012 L
s
1 .894 .882 r
.80689 .08012 m
.80689 .03325 L
.80736 .03325 L
.80736 .08012 L
F
.804 .522 .247 r
.80689 .08012 m
.80689 .03325 L
.80736 .03325 L
.80736 .08012 L
s
1 .894 .882 r
.80736 .08012 m
.80736 .03317 L
.80805 .03317 L
.80805 .08012 L
F
.804 .522 .247 r
.80736 .08012 m
.80736 .03317 L
.80805 .03317 L
.80805 .08012 L
s
1 .894 .882 r
.80805 .08012 m
.80805 .03298 L
.8085 .03298 L
.8085 .08012 L
F
.804 .522 .247 r
.80805 .08012 m
.80805 .03298 L
.8085 .03298 L
.8085 .08012 L
s
1 .894 .882 r
.8085 .08012 m
.8085 .03296 L
.80896 .03296 L
.80896 .08012 L
F
.804 .522 .247 r
.8085 .08012 m
.8085 .03296 L
.80896 .03296 L
.80896 .08012 L
s
1 .894 .882 r
.80896 .08012 m
.80896 .03286 L
.80932 .03286 L
.80932 .08012 L
F
.804 .522 .247 r
.80896 .08012 m
.80896 .03286 L
.80932 .03286 L
.80932 .08012 L
s
1 .894 .882 r
.80932 .08012 m
.80932 .03277 L
.8096 .03277 L
.8096 .08012 L
F
.804 .522 .247 r
.80932 .08012 m
.80932 .03277 L
.8096 .03277 L
.8096 .08012 L
s
1 .894 .882 r
.8096 .08012 m
.8096 .03266 L
.81012 .03266 L
.81012 .08012 L
F
.804 .522 .247 r
.8096 .08012 m
.8096 .03266 L
.81012 .03266 L
.81012 .08012 L
s
1 .894 .882 r
.81012 .08012 m
.81012 .03254 L
.81069 .03254 L
.81069 .08012 L
F
.804 .522 .247 r
.81012 .08012 m
.81012 .03254 L
.81069 .03254 L
.81069 .08012 L
s
1 .894 .882 r
.81069 .08012 m
.81069 .03248 L
.81142 .03248 L
.81142 .08012 L
F
.804 .522 .247 r
.81069 .08012 m
.81069 .03248 L
.81142 .03248 L
.81142 .08012 L
s
1 .894 .882 r
.81142 .08012 m
.81142 .03233 L
.81203 .03233 L
.81203 .08012 L
F
.804 .522 .247 r
.81142 .08012 m
.81142 .03233 L
.81203 .03233 L
.81203 .08012 L
s
1 .894 .882 r
.81203 .08012 m
.81203 .03219 L
.81235 .03219 L
.81235 .08012 L
F
.804 .522 .247 r
.81203 .08012 m
.81203 .03219 L
.81235 .03219 L
.81235 .08012 L
s
1 .894 .882 r
.81235 .08012 m
.81235 .03202 L
.81299 .03202 L
.81299 .08012 L
F
.804 .522 .247 r
.81235 .08012 m
.81235 .03202 L
.81299 .03202 L
.81299 .08012 L
s
1 .894 .882 r
.81299 .08012 m
.81299 .03196 L
.81343 .03196 L
.81343 .08012 L
F
.804 .522 .247 r
.81299 .08012 m
.81299 .03196 L
.81343 .03196 L
.81343 .08012 L
s
1 .894 .882 r
.81343 .08012 m
.81343 .03182 L
.81393 .03182 L
.81393 .08012 L
F
.804 .522 .247 r
.81343 .08012 m
.81343 .03182 L
.81393 .03182 L
.81393 .08012 L
s
1 .894 .882 r
.81393 .08012 m
.81393 .03178 L
.81458 .03178 L
.81458 .08012 L
F
.804 .522 .247 r
.81393 .08012 m
.81393 .03178 L
.81458 .03178 L
.81458 .08012 L
s
1 .894 .882 r
.81458 .08012 m
.81458 .03164 L
.81528 .03164 L
.81528 .08012 L
F
.804 .522 .247 r
.81458 .08012 m
.81458 .03164 L
.81528 .03164 L
.81528 .08012 L
s
1 .894 .882 r
.81528 .08012 m
.81528 .03144 L
.8157 .03144 L
.8157 .08012 L
F
.804 .522 .247 r
.81528 .08012 m
.81528 .03144 L
.8157 .03144 L
.8157 .08012 L
s
1 .894 .882 r
.8157 .08012 m
.8157 .0314 L
.81611 .0314 L
.81611 .08012 L
F
.804 .522 .247 r
.8157 .08012 m
.8157 .0314 L
.81611 .0314 L
.81611 .08012 L
s
1 .894 .882 r
.81611 .08012 m
.81611 .03126 L
.81672 .03126 L
.81672 .08012 L
F
.804 .522 .247 r
.81611 .08012 m
.81611 .03126 L
.81672 .03126 L
.81672 .08012 L
s
1 .894 .882 r
.81672 .08012 m
.81672 .03118 L
.81735 .03118 L
.81735 .08012 L
F
.804 .522 .247 r
.81672 .08012 m
.81672 .03118 L
.81735 .03118 L
.81735 .08012 L
s
1 .894 .882 r
.81735 .08012 m
.81735 .03097 L
.81794 .03097 L
.81794 .08012 L
F
.804 .522 .247 r
.81735 .08012 m
.81735 .03097 L
.81794 .03097 L
.81794 .08012 L
s
1 .894 .882 r
.81794 .08012 m
.81794 .03091 L
.81863 .03091 L
.81863 .08012 L
F
.804 .522 .247 r
.81794 .08012 m
.81794 .03091 L
.81863 .03091 L
.81863 .08012 L
s
1 .894 .882 r
.81863 .08012 m
.81863 .03078 L
.81932 .03078 L
.81932 .08012 L
F
.804 .522 .247 r
.81863 .08012 m
.81863 .03078 L
.81932 .03078 L
.81932 .08012 L
s
1 .894 .882 r
.81932 .08012 m
.81932 .03067 L
.81968 .03067 L
.81968 .08012 L
F
.804 .522 .247 r
.81932 .08012 m
.81932 .03067 L
.81968 .03067 L
.81968 .08012 L
s
1 .894 .882 r
.81968 .08012 m
.81968 .03059 L
.82001 .03059 L
.82001 .08012 L
F
.804 .522 .247 r
.81968 .08012 m
.81968 .03059 L
.82001 .03059 L
.82001 .08012 L
s
1 .894 .882 r
.82001 .08012 m
.82001 .03054 L
.82023 .03054 L
.82023 .08012 L
F
.804 .522 .247 r
.82001 .08012 m
.82001 .03054 L
.82023 .03054 L
.82023 .08012 L
s
1 .894 .882 r
.82023 .08012 m
.82023 .03045 L
.82069 .03045 L
.82069 .08012 L
F
.804 .522 .247 r
.82023 .08012 m
.82023 .03045 L
.82069 .03045 L
.82069 .08012 L
s
1 .894 .882 r
.82069 .08012 m
.82069 .03039 L
.82132 .03039 L
.82132 .08012 L
F
.804 .522 .247 r
.82069 .08012 m
.82069 .03039 L
.82132 .03039 L
.82132 .08012 L
s
1 .894 .882 r
.82132 .08012 m
.82132 .03024 L
.82202 .03024 L
.82202 .08012 L
F
.804 .522 .247 r
.82132 .08012 m
.82132 .03024 L
.82202 .03024 L
.82202 .08012 L
s
1 .894 .882 r
.82202 .08012 m
.82202 .03002 L
.8227 .03002 L
.8227 .08012 L
F
.804 .522 .247 r
.82202 .08012 m
.82202 .03002 L
.8227 .03002 L
.8227 .08012 L
s
1 .894 .882 r
.8227 .08012 m
.8227 .02988 L
.82337 .02988 L
.82337 .08012 L
F
.804 .522 .247 r
.8227 .08012 m
.8227 .02988 L
.82337 .02988 L
.82337 .08012 L
s
1 .894 .882 r
.82337 .08012 m
.82337 .02984 L
.82364 .02984 L
.82364 .08012 L
F
.804 .522 .247 r
.82337 .08012 m
.82337 .02984 L
.82364 .02984 L
.82364 .08012 L
s
1 .894 .882 r
.82364 .08012 m
.82364 .02978 L
.82434 .02978 L
.82434 .08012 L
F
.804 .522 .247 r
.82364 .08012 m
.82364 .02978 L
.82434 .02978 L
.82434 .08012 L
s
1 .894 .882 r
.82434 .08012 m
.82434 .02963 L
.82463 .02963 L
.82463 .08012 L
F
.804 .522 .247 r
.82434 .08012 m
.82434 .02963 L
.82463 .02963 L
.82463 .08012 L
s
1 .894 .882 r
.82463 .08012 m
.82463 .02955 L
.8252 .02955 L
.8252 .08012 L
F
.804 .522 .247 r
.82463 .08012 m
.82463 .02955 L
.8252 .02955 L
.8252 .08012 L
s
1 .894 .882 r
.8252 .08012 m
.8252 .02946 L
.82557 .02946 L
.82557 .08012 L
F
.804 .522 .247 r
.8252 .08012 m
.8252 .02946 L
.82557 .02946 L
.82557 .08012 L
s
1 .894 .882 r
.82557 .08012 m
.82557 .02936 L
.82604 .02936 L
.82604 .08012 L
F
.804 .522 .247 r
.82557 .08012 m
.82557 .02936 L
.82604 .02936 L
.82604 .08012 L
s
1 .894 .882 r
.82604 .08012 m
.82604 .02925 L
.82657 .02925 L
.82657 .08012 L
F
.804 .522 .247 r
.82604 .08012 m
.82604 .02925 L
.82657 .02925 L
.82657 .08012 L
s
1 .894 .882 r
.82657 .08012 m
.82657 .02918 L
.82722 .02918 L
.82722 .08012 L
F
.804 .522 .247 r
.82657 .08012 m
.82657 .02918 L
.82722 .02918 L
.82722 .08012 L
s
1 .894 .882 r
.82722 .08012 m
.82722 .02908 L
.82762 .02908 L
.82762 .08012 L
F
.804 .522 .247 r
.82722 .08012 m
.82722 .02908 L
.82762 .02908 L
.82762 .08012 L
s
1 .894 .882 r
.82762 .08012 m
.82762 .02904 L
.82789 .02904 L
.82789 .08012 L
F
.804 .522 .247 r
.82762 .08012 m
.82762 .02904 L
.82789 .02904 L
.82789 .08012 L
s
1 .894 .882 r
.82789 .08012 m
.82789 .02895 L
.82822 .02895 L
.82822 .08012 L
F
.804 .522 .247 r
.82789 .08012 m
.82789 .02895 L
.82822 .02895 L
.82822 .08012 L
s
1 .894 .882 r
.82822 .08012 m
.82822 .02888 L
.82848 .02888 L
.82848 .08012 L
F
.804 .522 .247 r
.82822 .08012 m
.82822 .02888 L
.82848 .02888 L
.82848 .08012 L
s
1 .894 .882 r
.82848 .08012 m
.82848 .02885 L
.82898 .02885 L
.82898 .08012 L
F
.804 .522 .247 r
.82848 .08012 m
.82848 .02885 L
.82898 .02885 L
.82898 .08012 L
s
1 .894 .882 r
.82898 .08012 m
.82898 .02877 L
.82939 .02877 L
.82939 .08012 L
F
.804 .522 .247 r
.82898 .08012 m
.82898 .02877 L
.82939 .02877 L
.82939 .08012 L
s
1 .894 .882 r
.82939 .08012 m
.82939 .02869 L
.82977 .02869 L
.82977 .08012 L
F
.804 .522 .247 r
.82939 .08012 m
.82939 .02869 L
.82977 .02869 L
.82977 .08012 L
s
1 .894 .882 r
.82977 .08012 m
.82977 .02859 L
.83008 .02859 L
.83008 .08012 L
F
.804 .522 .247 r
.82977 .08012 m
.82977 .02859 L
.83008 .02859 L
.83008 .08012 L
s
1 .894 .882 r
.83008 .08012 m
.83008 .02857 L
.83043 .02857 L
.83043 .08012 L
F
.804 .522 .247 r
.83008 .08012 m
.83008 .02857 L
.83043 .02857 L
.83043 .08012 L
s
1 .894 .882 r
.83043 .08012 m
.83043 .02846 L
.83073 .02846 L
.83073 .08012 L
F
.804 .522 .247 r
.83043 .08012 m
.83043 .02846 L
.83073 .02846 L
.83073 .08012 L
s
1 .894 .882 r
.83073 .08012 m
.83073 .02844 L
.8311 .02844 L
.8311 .08012 L
F
.804 .522 .247 r
.83073 .08012 m
.83073 .02844 L
.8311 .02844 L
.8311 .08012 L
s
1 .894 .882 r
.8311 .08012 m
.8311 .02837 L
.83169 .02837 L
.83169 .08012 L
F
.804 .522 .247 r
.8311 .08012 m
.8311 .02837 L
.83169 .02837 L
.83169 .08012 L
s
1 .894 .882 r
.83169 .08012 m
.83169 .02819 L
.83214 .02819 L
.83214 .08012 L
F
.804 .522 .247 r
.83169 .08012 m
.83169 .02819 L
.83214 .02819 L
.83214 .08012 L
s
1 .894 .882 r
.83214 .08012 m
.83214 .02816 L
.83247 .02816 L
.83247 .08012 L
F
.804 .522 .247 r
.83214 .08012 m
.83214 .02816 L
.83247 .02816 L
.83247 .08012 L
s
1 .894 .882 r
.83247 .08012 m
.83247 .0281 L
.8329 .0281 L
.8329 .08012 L
F
.804 .522 .247 r
.83247 .08012 m
.83247 .0281 L
.8329 .0281 L
.8329 .08012 L
s
1 .894 .882 r
.8329 .08012 m
.8329 .02802 L
.83354 .02802 L
.83354 .08012 L
F
.804 .522 .247 r
.8329 .08012 m
.8329 .02802 L
.83354 .02802 L
.83354 .08012 L
s
1 .894 .882 r
.83354 .08012 m
.83354 .02789 L
.83393 .02789 L
.83393 .08012 L
F
.804 .522 .247 r
.83354 .08012 m
.83354 .02789 L
.83393 .02789 L
.83393 .08012 L
s
1 .894 .882 r
.83393 .08012 m
.83393 .02784 L
.8343 .02784 L
.8343 .08012 L
F
.804 .522 .247 r
.83393 .08012 m
.83393 .02784 L
.8343 .02784 L
.8343 .08012 L
s
1 .894 .882 r
.8343 .08012 m
.8343 .02775 L
.83466 .02775 L
.83466 .08012 L
F
.804 .522 .247 r
.8343 .08012 m
.8343 .02775 L
.83466 .02775 L
.83466 .08012 L
s
1 .894 .882 r
.83466 .08012 m
.83466 .02769 L
.83495 .02769 L
.83495 .08012 L
F
.804 .522 .247 r
.83466 .08012 m
.83466 .02769 L
.83495 .02769 L
.83495 .08012 L
s
1 .894 .882 r
.83495 .08012 m
.83495 .02763 L
.83519 .02763 L
.83519 .08012 L
F
.804 .522 .247 r
.83495 .08012 m
.83495 .02763 L
.83519 .02763 L
.83519 .08012 L
s
1 .894 .882 r
.83519 .08012 m
.83519 .02758 L
.83582 .02758 L
.83582 .08012 L
F
.804 .522 .247 r
.83519 .08012 m
.83519 .02758 L
.83582 .02758 L
.83582 .08012 L
s
1 .894 .882 r
.83582 .08012 m
.83582 .02746 L
.83639 .02746 L
.83639 .08012 L
F
.804 .522 .247 r
.83582 .08012 m
.83582 .02746 L
.83639 .02746 L
.83639 .08012 L
s
1 .894 .882 r
.83639 .08012 m
.83639 .02733 L
.83676 .02733 L
.83676 .08012 L
F
.804 .522 .247 r
.83639 .08012 m
.83639 .02733 L
.83676 .02733 L
.83676 .08012 L
s
1 .894 .882 r
.83676 .08012 m
.83676 .02731 L
.83733 .02731 L
.83733 .08012 L
F
.804 .522 .247 r
.83676 .08012 m
.83676 .02731 L
.83733 .02731 L
.83733 .08012 L
s
1 .894 .882 r
.83733 .08012 m
.83733 .0272 L
.8379 .0272 L
.8379 .08012 L
F
.804 .522 .247 r
.83733 .08012 m
.83733 .0272 L
.8379 .0272 L
.8379 .08012 L
s
1 .894 .882 r
.8379 .08012 m
.8379 .02705 L
.83836 .02705 L
.83836 .08012 L
F
.804 .522 .247 r
.8379 .08012 m
.8379 .02705 L
.83836 .02705 L
.83836 .08012 L
s
1 .894 .882 r
.83836 .08012 m
.83836 .02704 L
.83869 .02704 L
.83869 .08012 L
F
.804 .522 .247 r
.83836 .08012 m
.83836 .02704 L
.83869 .02704 L
.83869 .08012 L
s
1 .894 .882 r
.83869 .08012 m
.83869 .02698 L
.83898 .02698 L
.83898 .08012 L
F
.804 .522 .247 r
.83869 .08012 m
.83869 .02698 L
.83898 .02698 L
.83898 .08012 L
s
1 .894 .882 r
.83898 .08012 m
.83898 .02692 L
.83936 .02692 L
.83936 .08012 L
F
.804 .522 .247 r
.83898 .08012 m
.83898 .02692 L
.83936 .02692 L
.83936 .08012 L
s
1 .894 .882 r
.83936 .08012 m
.83936 .02683 L
.83966 .02683 L
.83966 .08012 L
F
.804 .522 .247 r
.83936 .08012 m
.83936 .02683 L
.83966 .02683 L
.83966 .08012 L
s
1 .894 .882 r
.83966 .08012 m
.83966 .02679 L
.8399 .02679 L
.8399 .08012 L
F
.804 .522 .247 r
.83966 .08012 m
.83966 .02679 L
.8399 .02679 L
.8399 .08012 L
s
1 .894 .882 r
.8399 .08012 m
.8399 .02665 L
.84057 .02665 L
.84057 .08012 L
F
.804 .522 .247 r
.8399 .08012 m
.8399 .02665 L
.84057 .02665 L
.84057 .08012 L
s
1 .894 .882 r
.84057 .08012 m
.84057 .02663 L
.84087 .02663 L
.84087 .08012 L
F
.804 .522 .247 r
.84057 .08012 m
.84057 .02663 L
.84087 .02663 L
.84087 .08012 L
s
1 .894 .882 r
.84087 .08012 m
.84087 .02652 L
.84153 .02652 L
.84153 .08012 L
F
.804 .522 .247 r
.84087 .08012 m
.84087 .02652 L
.84153 .02652 L
.84153 .08012 L
s
1 .894 .882 r
.84153 .08012 m
.84153 .02645 L
.84191 .02645 L
.84191 .08012 L
F
.804 .522 .247 r
.84153 .08012 m
.84153 .02645 L
.84191 .02645 L
.84191 .08012 L
s
1 .894 .882 r
.84191 .08012 m
.84191 .02641 L
.84236 .02641 L
.84236 .08012 L
F
.804 .522 .247 r
.84191 .08012 m
.84191 .02641 L
.84236 .02641 L
.84236 .08012 L
s
1 .894 .882 r
.84236 .08012 m
.84236 .02633 L
.84305 .02633 L
.84305 .08012 L
F
.804 .522 .247 r
.84236 .08012 m
.84236 .02633 L
.84305 .02633 L
.84305 .08012 L
s
1 .894 .882 r
.84305 .08012 m
.84305 .02618 L
.8435 .02618 L
.8435 .08012 L
F
.804 .522 .247 r
.84305 .08012 m
.84305 .02618 L
.8435 .02618 L
.8435 .08012 L
s
1 .894 .882 r
.8435 .08012 m
.8435 .02611 L
.84398 .02611 L
.84398 .08012 L
F
.804 .522 .247 r
.8435 .08012 m
.8435 .02611 L
.84398 .02611 L
.84398 .08012 L
s
1 .894 .882 r
.84398 .08012 m
.84398 .02602 L
.84425 .02602 L
.84425 .08012 L
F
.804 .522 .247 r
.84398 .08012 m
.84398 .02602 L
.84425 .02602 L
.84425 .08012 L
s
1 .894 .882 r
.84425 .08012 m
.84425 .02593 L
.84479 .02593 L
.84479 .08012 L
F
.804 .522 .247 r
.84425 .08012 m
.84425 .02593 L
.84479 .02593 L
.84479 .08012 L
s
1 .894 .882 r
.84479 .08012 m
.84479 .02592 L
.84511 .02592 L
.84511 .08012 L
F
.804 .522 .247 r
.84479 .08012 m
.84479 .02592 L
.84511 .02592 L
.84511 .08012 L
s
1 .894 .882 r
.84511 .08012 m
.84511 .02581 L
.8455 .02581 L
.8455 .08012 L
F
.804 .522 .247 r
.84511 .08012 m
.84511 .02581 L
.8455 .02581 L
.8455 .08012 L
s
1 .894 .882 r
.8455 .08012 m
.8455 .0258 L
.84575 .0258 L
.84575 .08012 L
F
.804 .522 .247 r
.8455 .08012 m
.8455 .0258 L
.84575 .0258 L
.84575 .08012 L
s
1 .894 .882 r
.84575 .08012 m
.84575 .02569 L
.84641 .02569 L
.84641 .08012 L
F
.804 .522 .247 r
.84575 .08012 m
.84575 .02569 L
.84641 .02569 L
.84641 .08012 L
s
1 .894 .882 r
.84641 .08012 m
.84641 .0256 L
.84688 .0256 L
.84688 .08012 L
F
.804 .522 .247 r
.84641 .08012 m
.84641 .0256 L
.84688 .0256 L
.84688 .08012 L
s
1 .894 .882 r
.84688 .08012 m
.84688 .02553 L
.84713 .02553 L
.84713 .08012 L
F
.804 .522 .247 r
.84688 .08012 m
.84688 .02553 L
.84713 .02553 L
.84713 .08012 L
s
1 .894 .882 r
.84713 .08012 m
.84713 .02547 L
.84754 .02547 L
.84754 .08012 L
F
.804 .522 .247 r
.84713 .08012 m
.84713 .02547 L
.84754 .02547 L
.84754 .08012 L
s
1 .894 .882 r
.84754 .08012 m
.84754 .02544 L
.84784 .02544 L
.84784 .08012 L
F
.804 .522 .247 r
.84754 .08012 m
.84754 .02544 L
.84784 .02544 L
.84784 .08012 L
s
1 .894 .882 r
.84784 .08012 m
.84784 .02538 L
.84808 .02538 L
.84808 .08012 L
F
.804 .522 .247 r
.84784 .08012 m
.84784 .02538 L
.84808 .02538 L
.84808 .08012 L
s
1 .894 .882 r
.84808 .08012 m
.84808 .02528 L
.84872 .02528 L
.84872 .08012 L
F
.804 .522 .247 r
.84808 .08012 m
.84808 .02528 L
.84872 .02528 L
.84872 .08012 L
s
1 .894 .882 r
.84872 .08012 m
.84872 .02521 L
.84906 .02521 L
.84906 .08012 L
F
.804 .522 .247 r
.84872 .08012 m
.84872 .02521 L
.84906 .02521 L
.84906 .08012 L
s
1 .894 .882 r
.84906 .08012 m
.84906 .02519 L
.84971 .02519 L
.84971 .08012 L
F
.804 .522 .247 r
.84906 .08012 m
.84906 .02519 L
.84971 .02519 L
.84971 .08012 L
s
1 .894 .882 r
.84971 .08012 m
.84971 .02509 L
.85038 .02509 L
.85038 .08012 L
F
.804 .522 .247 r
.84971 .08012 m
.84971 .02509 L
.85038 .02509 L
.85038 .08012 L
s
1 .894 .882 r
.85038 .08012 m
.85038 .02496 L
.85101 .02496 L
.85101 .08012 L
F
.804 .522 .247 r
.85038 .08012 m
.85038 .02496 L
.85101 .02496 L
.85101 .08012 L
s
1 .894 .882 r
.85101 .08012 m
.85101 .02483 L
.8514 .02483 L
.8514 .08012 L
F
.804 .522 .247 r
.85101 .08012 m
.85101 .02483 L
.8514 .02483 L
.8514 .08012 L
s
1 .894 .882 r
.8514 .08012 m
.8514 .02476 L
.85198 .02476 L
.85198 .08012 L
F
.804 .522 .247 r
.8514 .08012 m
.8514 .02476 L
.85198 .02476 L
.85198 .08012 L
s
1 .894 .882 r
.85198 .08012 m
.85198 .02471 L
.85221 .02471 L
.85221 .08012 L
F
.804 .522 .247 r
.85198 .08012 m
.85198 .02471 L
.85221 .02471 L
.85221 .08012 L
s
1 .894 .882 r
.85221 .08012 m
.85221 .02463 L
.85267 .02463 L
.85267 .08012 L
F
.804 .522 .247 r
.85221 .08012 m
.85221 .02463 L
.85267 .02463 L
.85267 .08012 L
s
1 .894 .882 r
.85267 .08012 m
.85267 .02454 L
.85335 .02454 L
.85335 .08012 L
F
.804 .522 .247 r
.85267 .08012 m
.85267 .02454 L
.85335 .02454 L
.85335 .08012 L
s
1 .894 .882 r
.85335 .08012 m
.85335 .02445 L
.85396 .02445 L
.85396 .08012 L
F
.804 .522 .247 r
.85335 .08012 m
.85335 .02445 L
.85396 .02445 L
.85396 .08012 L
s
1 .894 .882 r
.85396 .08012 m
.85396 .02433 L
.85447 .02433 L
.85447 .08012 L
F
.804 .522 .247 r
.85396 .08012 m
.85396 .02433 L
.85447 .02433 L
.85447 .08012 L
s
1 .894 .882 r
.85447 .08012 m
.85447 .02428 L
.85519 .02428 L
.85519 .08012 L
F
.804 .522 .247 r
.85447 .08012 m
.85447 .02428 L
.85519 .02428 L
.85519 .08012 L
s
1 .894 .882 r
.85519 .08012 m
.85519 .02412 L
.85582 .02412 L
.85582 .08012 L
F
.804 .522 .247 r
.85519 .08012 m
.85519 .02412 L
.85582 .02412 L
.85582 .08012 L
s
1 .894 .882 r
.85582 .08012 m
.85582 .02409 L
.8561 .02409 L
.8561 .08012 L
F
.804 .522 .247 r
.85582 .08012 m
.85582 .02409 L
.8561 .02409 L
.8561 .08012 L
s
1 .894 .882 r
.8561 .08012 m
.8561 .02401 L
.85652 .02401 L
.85652 .08012 L
F
.804 .522 .247 r
.8561 .08012 m
.8561 .02401 L
.85652 .02401 L
.85652 .08012 L
s
1 .894 .882 r
.85652 .08012 m
.85652 .02396 L
.85706 .02396 L
.85706 .08012 L
F
.804 .522 .247 r
.85652 .08012 m
.85652 .02396 L
.85706 .02396 L
.85706 .08012 L
s
1 .894 .882 r
.85706 .08012 m
.85706 .02384 L
.85766 .02384 L
.85766 .08012 L
F
.804 .522 .247 r
.85706 .08012 m
.85706 .02384 L
.85766 .02384 L
.85766 .08012 L
s
1 .894 .882 r
.85766 .08012 m
.85766 .02383 L
.85802 .02383 L
.85802 .08012 L
F
.804 .522 .247 r
.85766 .08012 m
.85766 .02383 L
.85802 .02383 L
.85802 .08012 L
s
1 .894 .882 r
.85802 .08012 m
.85802 .02375 L
.8587 .02375 L
.8587 .08012 L
F
.804 .522 .247 r
.85802 .08012 m
.85802 .02375 L
.8587 .02375 L
.8587 .08012 L
s
1 .894 .882 r
.8587 .08012 m
.8587 .02362 L
.85921 .02362 L
.85921 .08012 L
F
.804 .522 .247 r
.8587 .08012 m
.8587 .02362 L
.85921 .02362 L
.85921 .08012 L
s
1 .894 .882 r
.85921 .08012 m
.85921 .02359 L
.85961 .02359 L
.85961 .08012 L
F
.804 .522 .247 r
.85921 .08012 m
.85921 .02359 L
.85961 .02359 L
.85961 .08012 L
s
1 .894 .882 r
.85961 .08012 m
.85961 .0235 L
.85989 .0235 L
.85989 .08012 L
F
.804 .522 .247 r
.85961 .08012 m
.85961 .0235 L
.85989 .0235 L
.85989 .08012 L
s
1 .894 .882 r
.85989 .08012 m
.85989 .02344 L
.86055 .02344 L
.86055 .08012 L
F
.804 .522 .247 r
.85989 .08012 m
.85989 .02344 L
.86055 .02344 L
.86055 .08012 L
s
1 .894 .882 r
.86055 .08012 m
.86055 .02331 L
.86115 .02331 L
.86115 .08012 L
F
.804 .522 .247 r
.86055 .08012 m
.86055 .02331 L
.86115 .02331 L
.86115 .08012 L
s
1 .894 .882 r
.86115 .08012 m
.86115 .0233 L
.86144 .0233 L
.86144 .08012 L
F
.804 .522 .247 r
.86115 .08012 m
.86115 .0233 L
.86144 .0233 L
.86144 .08012 L
s
1 .894 .882 r
.86144 .08012 m
.86144 .02323 L
.8618 .02323 L
.8618 .08012 L
F
.804 .522 .247 r
.86144 .08012 m
.86144 .02323 L
.8618 .02323 L
.8618 .08012 L
s
1 .894 .882 r
.8618 .08012 m
.8618 .02315 L
.86251 .02315 L
.86251 .08012 L
F
.804 .522 .247 r
.8618 .08012 m
.8618 .02315 L
.86251 .02315 L
.86251 .08012 L
s
1 .894 .882 r
.86251 .08012 m
.86251 .02303 L
.86322 .02303 L
.86322 .08012 L
F
.804 .522 .247 r
.86251 .08012 m
.86251 .02303 L
.86322 .02303 L
.86322 .08012 L
s
1 .894 .882 r
.86322 .08012 m
.86322 .02297 L
.86384 .02297 L
.86384 .08012 L
F
.804 .522 .247 r
.86322 .08012 m
.86322 .02297 L
.86384 .02297 L
.86384 .08012 L
s
1 .894 .882 r
.86384 .08012 m
.86384 .02284 L
.86436 .02284 L
.86436 .08012 L
F
.804 .522 .247 r
.86384 .08012 m
.86384 .02284 L
.86436 .02284 L
.86436 .08012 L
s
1 .894 .882 r
.86436 .08012 m
.86436 .02282 L
.86506 .02282 L
.86506 .08012 L
F
.804 .522 .247 r
.86436 .08012 m
.86436 .02282 L
.86506 .02282 L
.86506 .08012 L
s
1 .894 .882 r
.86506 .08012 m
.86506 .02267 L
.86553 .02267 L
.86553 .08012 L
F
.804 .522 .247 r
.86506 .08012 m
.86506 .02267 L
.86553 .02267 L
.86553 .08012 L
s
1 .894 .882 r
.86553 .08012 m
.86553 .0226 L
.86621 .0226 L
.86621 .08012 L
F
.804 .522 .247 r
.86553 .08012 m
.86553 .0226 L
.86621 .0226 L
.86621 .08012 L
s
1 .894 .882 r
.86621 .08012 m
.86621 .02254 L
.86684 .02254 L
.86684 .08012 L
F
.804 .522 .247 r
.86621 .08012 m
.86621 .02254 L
.86684 .02254 L
.86684 .08012 L
s
1 .894 .882 r
.86684 .08012 m
.86684 .02247 L
.86725 .02247 L
.86725 .08012 L
F
.804 .522 .247 r
.86684 .08012 m
.86684 .02247 L
.86725 .02247 L
.86725 .08012 L
s
1 .894 .882 r
.86725 .08012 m
.86725 .02239 L
.86773 .02239 L
.86773 .08012 L
F
.804 .522 .247 r
.86725 .08012 m
.86725 .02239 L
.86773 .02239 L
.86773 .08012 L
s
1 .894 .882 r
.86773 .08012 m
.86773 .02232 L
.868 .02232 L
.868 .08012 L
F
.804 .522 .247 r
.86773 .08012 m
.86773 .02232 L
.868 .02232 L
.868 .08012 L
s
1 .894 .882 r
.868 .08012 m
.868 .02227 L
.86856 .02227 L
.86856 .08012 L
F
.804 .522 .247 r
.868 .08012 m
.868 .02227 L
.86856 .02227 L
.86856 .08012 L
s
1 .894 .882 r
.86856 .08012 m
.86856 .02221 L
.86928 .02221 L
.86928 .08012 L
F
.804 .522 .247 r
.86856 .08012 m
.86856 .02221 L
.86928 .02221 L
.86928 .08012 L
s
1 .894 .882 r
.86928 .08012 m
.86928 .02205 L
.86996 .02205 L
.86996 .08012 L
F
.804 .522 .247 r
.86928 .08012 m
.86928 .02205 L
.86996 .02205 L
.86996 .08012 L
s
1 .894 .882 r
.86996 .08012 m
.86996 .02199 L
.87037 .02199 L
.87037 .08012 L
F
.804 .522 .247 r
.86996 .08012 m
.86996 .02199 L
.87037 .02199 L
.87037 .08012 L
s
1 .894 .882 r
.87037 .08012 m
.87037 .02195 L
.87078 .02195 L
.87078 .08012 L
F
.804 .522 .247 r
.87037 .08012 m
.87037 .02195 L
.87078 .02195 L
.87078 .08012 L
s
1 .894 .882 r
.87078 .08012 m
.87078 .02189 L
.87105 .02189 L
.87105 .08012 L
F
.804 .522 .247 r
.87078 .08012 m
.87078 .02189 L
.87105 .02189 L
.87105 .08012 L
s
1 .894 .882 r
.87105 .08012 m
.87105 .02188 L
.87143 .02188 L
.87143 .08012 L
F
.804 .522 .247 r
.87105 .08012 m
.87105 .02188 L
.87143 .02188 L
.87143 .08012 L
s
1 .894 .882 r
.87143 .08012 m
.87143 .02181 L
.87165 .02181 L
.87165 .08012 L
F
.804 .522 .247 r
.87143 .08012 m
.87143 .02181 L
.87165 .02181 L
.87165 .08012 L
s
1 .894 .882 r
.87165 .08012 m
.87165 .02177 L
.87201 .02177 L
.87201 .08012 L
F
.804 .522 .247 r
.87165 .08012 m
.87165 .02177 L
.87201 .02177 L
.87201 .08012 L
s
1 .894 .882 r
.87201 .08012 m
.87201 .02174 L
.87234 .02174 L
.87234 .08012 L
F
.804 .522 .247 r
.87201 .08012 m
.87201 .02174 L
.87234 .02174 L
.87234 .08012 L
s
1 .894 .882 r
.87234 .08012 m
.87234 .0217 L
.87286 .0217 L
.87286 .08012 L
F
.804 .522 .247 r
.87234 .08012 m
.87234 .0217 L
.87286 .0217 L
.87286 .08012 L
s
1 .894 .882 r
.87286 .08012 m
.87286 .02159 L
.87353 .02159 L
.87353 .08012 L
F
.804 .522 .247 r
.87286 .08012 m
.87286 .02159 L
.87353 .02159 L
.87353 .08012 L
s
1 .894 .882 r
.87353 .08012 m
.87353 .02153 L
.87425 .02153 L
.87425 .08012 L
F
.804 .522 .247 r
.87353 .08012 m
.87353 .02153 L
.87425 .02153 L
.87425 .08012 L
s
1 .894 .882 r
.87425 .08012 m
.87425 .02141 L
.8746 .02141 L
.8746 .08012 L
F
.804 .522 .247 r
.87425 .08012 m
.87425 .02141 L
.8746 .02141 L
.8746 .08012 L
s
1 .894 .882 r
.8746 .08012 m
.8746 .02137 L
.87515 .02137 L
.87515 .08012 L
F
.804 .522 .247 r
.8746 .08012 m
.8746 .02137 L
.87515 .02137 L
.87515 .08012 L
s
1 .894 .882 r
.87515 .08012 m
.87515 .02133 L
.87541 .02133 L
.87541 .08012 L
F
.804 .522 .247 r
.87515 .08012 m
.87515 .02133 L
.87541 .02133 L
.87541 .08012 L
s
1 .894 .882 r
.87541 .08012 m
.87541 .02128 L
.87584 .02128 L
.87584 .08012 L
F
.804 .522 .247 r
.87541 .08012 m
.87541 .02128 L
.87584 .02128 L
.87584 .08012 L
s
1 .894 .882 r
.87584 .08012 m
.87584 .02121 L
.87622 .02121 L
.87622 .08012 L
F
.804 .522 .247 r
.87584 .08012 m
.87584 .02121 L
.87622 .02121 L
.87622 .08012 L
s
1 .894 .882 r
.87622 .08012 m
.87622 .02117 L
.87652 .02117 L
.87652 .08012 L
F
.804 .522 .247 r
.87622 .08012 m
.87622 .02117 L
.87652 .02117 L
.87652 .08012 L
s
1 .894 .882 r
.87652 .08012 m
.87652 .02114 L
.87683 .02114 L
.87683 .08012 L
F
.804 .522 .247 r
.87652 .08012 m
.87652 .02114 L
.87683 .02114 L
.87683 .08012 L
s
1 .894 .882 r
.87683 .08012 m
.87683 .02111 L
.87736 .02111 L
.87736 .08012 L
F
.804 .522 .247 r
.87683 .08012 m
.87683 .02111 L
.87736 .02111 L
.87736 .08012 L
s
1 .894 .882 r
.87736 .08012 m
.87736 .02099 L
.87806 .02099 L
.87806 .08012 L
F
.804 .522 .247 r
.87736 .08012 m
.87736 .02099 L
.87806 .02099 L
.87806 .08012 L
s
1 .894 .882 r
.87806 .08012 m
.87806 .02094 L
.8786 .02094 L
.8786 .08012 L
F
.804 .522 .247 r
.87806 .08012 m
.87806 .02094 L
.8786 .02094 L
.8786 .08012 L
s
1 .894 .882 r
.8786 .08012 m
.8786 .02086 L
.87887 .02086 L
.87887 .08012 L
F
.804 .522 .247 r
.8786 .08012 m
.8786 .02086 L
.87887 .02086 L
.87887 .08012 L
s
1 .894 .882 r
.87887 .08012 m
.87887 .02081 L
.87956 .02081 L
.87956 .08012 L
F
.804 .522 .247 r
.87887 .08012 m
.87887 .02081 L
.87956 .02081 L
.87956 .08012 L
s
1 .894 .882 r
.87956 .08012 m
.87956 .02074 L
.88027 .02074 L
.88027 .08012 L
F
.804 .522 .247 r
.87956 .08012 m
.87956 .02074 L
.88027 .02074 L
.88027 .08012 L
s
1 .894 .882 r
.88027 .08012 m
.88027 .02065 L
.88087 .02065 L
.88087 .08012 L
F
.804 .522 .247 r
.88027 .08012 m
.88027 .02065 L
.88087 .02065 L
.88087 .08012 L
s
1 .894 .882 r
.88087 .08012 m
.88087 .0206 L
.88146 .0206 L
.88146 .08012 L
F
.804 .522 .247 r
.88087 .08012 m
.88087 .0206 L
.88146 .0206 L
.88146 .08012 L
s
1 .894 .882 r
.88146 .08012 m
.88146 .02053 L
.88196 .02053 L
.88196 .08012 L
F
.804 .522 .247 r
.88146 .08012 m
.88146 .02053 L
.88196 .02053 L
.88196 .08012 L
s
1 .894 .882 r
.88196 .08012 m
.88196 .02044 L
.88263 .02044 L
.88263 .08012 L
F
.804 .522 .247 r
.88196 .08012 m
.88196 .02044 L
.88263 .02044 L
.88263 .08012 L
s
1 .894 .882 r
.88263 .08012 m
.88263 .02038 L
.88306 .02038 L
.88306 .08012 L
F
.804 .522 .247 r
.88263 .08012 m
.88263 .02038 L
.88306 .02038 L
.88306 .08012 L
s
1 .894 .882 r
.88306 .08012 m
.88306 .02031 L
.88365 .02031 L
.88365 .08012 L
F
.804 .522 .247 r
.88306 .08012 m
.88306 .02031 L
.88365 .02031 L
.88365 .08012 L
s
1 .894 .882 r
.88365 .08012 m
.88365 .02026 L
.88401 .02026 L
.88401 .08012 L
F
.804 .522 .247 r
.88365 .08012 m
.88365 .02026 L
.88401 .02026 L
.88401 .08012 L
s
1 .894 .882 r
.88401 .08012 m
.88401 .02023 L
.88456 .02023 L
.88456 .08012 L
F
.804 .522 .247 r
.88401 .08012 m
.88401 .02023 L
.88456 .02023 L
.88456 .08012 L
s
1 .894 .882 r
.88456 .08012 m
.88456 .02015 L
.88521 .02015 L
.88521 .08012 L
F
.804 .522 .247 r
.88456 .08012 m
.88456 .02015 L
.88521 .02015 L
.88521 .08012 L
s
1 .894 .882 r
.88521 .08012 m
.88521 .02002 L
.88586 .02002 L
.88586 .08012 L
F
.804 .522 .247 r
.88521 .08012 m
.88521 .02002 L
.88586 .02002 L
.88586 .08012 L
s
1 .894 .882 r
.88586 .08012 m
.88586 .01997 L
.88623 .01997 L
.88623 .08012 L
F
.804 .522 .247 r
.88586 .08012 m
.88586 .01997 L
.88623 .01997 L
.88623 .08012 L
s
1 .894 .882 r
.88623 .08012 m
.88623 .01996 L
.88665 .01996 L
.88665 .08012 L
F
.804 .522 .247 r
.88623 .08012 m
.88623 .01996 L
.88665 .01996 L
.88665 .08012 L
s
1 .894 .882 r
.88665 .08012 m
.88665 .0199 L
.88697 .0199 L
.88697 .08012 L
F
.804 .522 .247 r
.88665 .08012 m
.88665 .0199 L
.88697 .0199 L
.88697 .08012 L
s
1 .894 .882 r
.88697 .08012 m
.88697 .01983 L
.88758 .01983 L
.88758 .08012 L
F
.804 .522 .247 r
.88697 .08012 m
.88697 .01983 L
.88758 .01983 L
.88758 .08012 L
s
1 .894 .882 r
.88758 .08012 m
.88758 .01977 L
.88825 .01977 L
.88825 .08012 L
F
.804 .522 .247 r
.88758 .08012 m
.88758 .01977 L
.88825 .01977 L
.88825 .08012 L
s
1 .894 .882 r
.88825 .08012 m
.88825 .01973 L
.88851 .01973 L
.88851 .08012 L
F
.804 .522 .247 r
.88825 .08012 m
.88825 .01973 L
.88851 .01973 L
.88851 .08012 L
s
1 .894 .882 r
.88851 .08012 m
.88851 .01968 L
.88875 .01968 L
.88875 .08012 L
F
.804 .522 .247 r
.88851 .08012 m
.88851 .01968 L
.88875 .01968 L
.88875 .08012 L
s
1 .894 .882 r
.88875 .08012 m
.88875 .01967 L
.88927 .01967 L
.88927 .08012 L
F
.804 .522 .247 r
.88875 .08012 m
.88875 .01967 L
.88927 .01967 L
.88927 .08012 L
s
1 .894 .882 r
.88927 .08012 m
.88927 .0196 L
.88963 .0196 L
.88963 .08012 L
F
.804 .522 .247 r
.88927 .08012 m
.88927 .0196 L
.88963 .0196 L
.88963 .08012 L
s
1 .894 .882 r
.88963 .08012 m
.88963 .01956 L
.88993 .01956 L
.88993 .08012 L
F
.804 .522 .247 r
.88963 .08012 m
.88963 .01956 L
.88993 .01956 L
.88993 .08012 L
s
1 .894 .882 r
.88993 .08012 m
.88993 .01952 L
.89035 .01952 L
.89035 .08012 L
F
.804 .522 .247 r
.88993 .08012 m
.88993 .01952 L
.89035 .01952 L
.89035 .08012 L
s
1 .894 .882 r
.89035 .08012 m
.89035 .01949 L
.89083 .01949 L
.89083 .08012 L
F
.804 .522 .247 r
.89035 .08012 m
.89035 .01949 L
.89083 .01949 L
.89083 .08012 L
s
1 .894 .882 r
.89083 .08012 m
.89083 .01941 L
.89122 .01941 L
.89122 .08012 L
F
.804 .522 .247 r
.89083 .08012 m
.89083 .01941 L
.89122 .01941 L
.89122 .08012 L
s
1 .894 .882 r
.89122 .08012 m
.89122 .0194 L
.89153 .0194 L
.89153 .08012 L
F
.804 .522 .247 r
.89122 .08012 m
.89122 .0194 L
.89153 .0194 L
.89153 .08012 L
s
1 .894 .882 r
.89153 .08012 m
.89153 .01936 L
.89209 .01936 L
.89209 .08012 L
F
.804 .522 .247 r
.89153 .08012 m
.89153 .01936 L
.89209 .01936 L
.89209 .08012 L
s
1 .894 .882 r
.89209 .08012 m
.89209 .01924 L
.89271 .01924 L
.89271 .08012 L
F
.804 .522 .247 r
.89209 .08012 m
.89209 .01924 L
.89271 .01924 L
.89271 .08012 L
s
1 .894 .882 r
.89271 .08012 m
.89271 .01919 L
.89334 .01919 L
.89334 .08012 L
F
.804 .522 .247 r
.89271 .08012 m
.89271 .01919 L
.89334 .01919 L
.89334 .08012 L
s
1 .894 .882 r
.89334 .08012 m
.89334 .01914 L
.89371 .01914 L
.89371 .08012 L
F
.804 .522 .247 r
.89334 .08012 m
.89334 .01914 L
.89371 .01914 L
.89371 .08012 L
s
1 .894 .882 r
.89371 .08012 m
.89371 .0191 L
.89405 .0191 L
.89405 .08012 L
F
.804 .522 .247 r
.89371 .08012 m
.89371 .0191 L
.89405 .0191 L
.89405 .08012 L
s
1 .894 .882 r
.89405 .08012 m
.89405 .01908 L
.8943 .01908 L
.8943 .08012 L
F
.804 .522 .247 r
.89405 .08012 m
.89405 .01908 L
.8943 .01908 L
.8943 .08012 L
s
1 .894 .882 r
.8943 .08012 m
.8943 .01905 L
.89479 .01905 L
.89479 .08012 L
F
.804 .522 .247 r
.8943 .08012 m
.8943 .01905 L
.89479 .01905 L
.89479 .08012 L
s
1 .894 .882 r
.89479 .08012 m
.89479 .01898 L
.89535 .01898 L
.89535 .08012 L
F
.804 .522 .247 r
.89479 .08012 m
.89479 .01898 L
.89535 .01898 L
.89535 .08012 L
s
1 .894 .882 r
.89535 .08012 m
.89535 .01893 L
.89577 .01893 L
.89577 .08012 L
F
.804 .522 .247 r
.89535 .08012 m
.89535 .01893 L
.89577 .01893 L
.89577 .08012 L
s
1 .894 .882 r
.89577 .08012 m
.89577 .01889 L
.8961 .01889 L
.8961 .08012 L
F
.804 .522 .247 r
.89577 .08012 m
.89577 .01889 L
.8961 .01889 L
.8961 .08012 L
s
1 .894 .882 r
.8961 .08012 m
.8961 .01886 L
.89644 .01886 L
.89644 .08012 L
F
.804 .522 .247 r
.8961 .08012 m
.8961 .01886 L
.89644 .01886 L
.89644 .08012 L
s
1 .894 .882 r
.89644 .08012 m
.89644 .01882 L
.89679 .01882 L
.89679 .08012 L
F
.804 .522 .247 r
.89644 .08012 m
.89644 .01882 L
.89679 .01882 L
.89679 .08012 L
s
1 .894 .882 r
.89679 .08012 m
.89679 .0188 L
.89711 .0188 L
.89711 .08012 L
F
.804 .522 .247 r
.89679 .08012 m
.89679 .0188 L
.89711 .0188 L
.89711 .08012 L
s
1 .894 .882 r
.89711 .08012 m
.89711 .01873 L
.89757 .01873 L
.89757 .08012 L
F
.804 .522 .247 r
.89711 .08012 m
.89711 .01873 L
.89757 .01873 L
.89757 .08012 L
s
1 .894 .882 r
.89757 .08012 m
.89757 .01869 L
.89796 .01869 L
.89796 .08012 L
F
.804 .522 .247 r
.89757 .08012 m
.89757 .01869 L
.89796 .01869 L
.89796 .08012 L
s
1 .894 .882 r
.89796 .08012 m
.89796 .01868 L
.89828 .01868 L
.89828 .08012 L
F
.804 .522 .247 r
.89796 .08012 m
.89796 .01868 L
.89828 .01868 L
.89828 .08012 L
s
1 .894 .882 r
.89828 .08012 m
.89828 .01865 L
.89857 .01865 L
.89857 .08012 L
F
.804 .522 .247 r
.89828 .08012 m
.89828 .01865 L
.89857 .01865 L
.89857 .08012 L
s
1 .894 .882 r
.89857 .08012 m
.89857 .01857 L
.89924 .01857 L
.89924 .08012 L
F
.804 .522 .247 r
.89857 .08012 m
.89857 .01857 L
.89924 .01857 L
.89924 .08012 L
s
1 .894 .882 r
.89924 .08012 m
.89924 .01854 L
.8995 .01854 L
.8995 .08012 L
F
.804 .522 .247 r
.89924 .08012 m
.89924 .01854 L
.8995 .01854 L
.8995 .08012 L
s
1 .894 .882 r
.8995 .08012 m
.8995 .01851 L
.89973 .01851 L
.89973 .08012 L
F
.804 .522 .247 r
.8995 .08012 m
.8995 .01851 L
.89973 .01851 L
.89973 .08012 L
s
1 .894 .882 r
.89973 .08012 m
.89973 .01847 L
.90034 .01847 L
.90034 .08012 L
F
.804 .522 .247 r
.89973 .08012 m
.89973 .01847 L
.90034 .01847 L
.90034 .08012 L
s
1 .894 .882 r
.90034 .08012 m
.90034 .01842 L
.90075 .01842 L
.90075 .08012 L
F
.804 .522 .247 r
.90034 .08012 m
.90034 .01842 L
.90075 .01842 L
.90075 .08012 L
s
1 .894 .882 r
.90075 .08012 m
.90075 .01836 L
.90134 .01836 L
.90134 .08012 L
F
.804 .522 .247 r
.90075 .08012 m
.90075 .01836 L
.90134 .01836 L
.90134 .08012 L
s
1 .894 .882 r
.90134 .08012 m
.90134 .0183 L
.902 .0183 L
.902 .08012 L
F
.804 .522 .247 r
.90134 .08012 m
.90134 .0183 L
.902 .0183 L
.902 .08012 L
s
1 .894 .882 r
.902 .08012 m
.902 .01827 L
.90227 .01827 L
.90227 .08012 L
F
.804 .522 .247 r
.902 .08012 m
.902 .01827 L
.90227 .01827 L
.90227 .08012 L
s
1 .894 .882 r
.90227 .08012 m
.90227 .01822 L
.90279 .01822 L
.90279 .08012 L
F
.804 .522 .247 r
.90227 .08012 m
.90227 .01822 L
.90279 .01822 L
.90279 .08012 L
s
1 .894 .882 r
.90279 .08012 m
.90279 .01819 L
.90349 .01819 L
.90349 .08012 L
F
.804 .522 .247 r
.90279 .08012 m
.90279 .01819 L
.90349 .01819 L
.90349 .08012 L
s
1 .894 .882 r
.90349 .08012 m
.90349 .01814 L
.90398 .01814 L
.90398 .08012 L
F
.804 .522 .247 r
.90349 .08012 m
.90349 .01814 L
.90398 .01814 L
.90398 .08012 L
s
1 .894 .882 r
.90398 .08012 m
.90398 .01805 L
.90465 .01805 L
.90465 .08012 L
F
.804 .522 .247 r
.90398 .08012 m
.90398 .01805 L
.90465 .01805 L
.90465 .08012 L
s
1 .894 .882 r
.90465 .08012 m
.90465 .01802 L
.90514 .01802 L
.90514 .08012 L
F
.804 .522 .247 r
.90465 .08012 m
.90465 .01802 L
.90514 .01802 L
.90514 .08012 L
s
1 .894 .882 r
.90514 .08012 m
.90514 .01796 L
.90557 .01796 L
.90557 .08012 L
F
.804 .522 .247 r
.90514 .08012 m
.90514 .01796 L
.90557 .01796 L
.90557 .08012 L
s
1 .894 .882 r
.90557 .08012 m
.90557 .01792 L
.90624 .01792 L
.90624 .08012 L
F
.804 .522 .247 r
.90557 .08012 m
.90557 .01792 L
.90624 .01792 L
.90624 .08012 L
s
1 .894 .882 r
.90624 .08012 m
.90624 .01789 L
.9067 .01789 L
.9067 .08012 L
F
.804 .522 .247 r
.90624 .08012 m
.90624 .01789 L
.9067 .01789 L
.9067 .08012 L
s
1 .894 .882 r
.9067 .08012 m
.9067 .01782 L
.90707 .01782 L
.90707 .08012 L
F
.804 .522 .247 r
.9067 .08012 m
.9067 .01782 L
.90707 .01782 L
.90707 .08012 L
s
1 .894 .882 r
.90707 .08012 m
.90707 .0178 L
.90738 .0178 L
.90738 .08012 L
F
.804 .522 .247 r
.90707 .08012 m
.90707 .0178 L
.90738 .0178 L
.90738 .08012 L
s
1 .894 .882 r
.90738 .08012 m
.90738 .01774 L
.90792 .01774 L
.90792 .08012 L
F
.804 .522 .247 r
.90738 .08012 m
.90738 .01774 L
.90792 .01774 L
.90792 .08012 L
s
1 .894 .882 r
.90792 .08012 m
.90792 .01771 L
.90829 .01771 L
.90829 .08012 L
F
.804 .522 .247 r
.90792 .08012 m
.90792 .01771 L
.90829 .01771 L
.90829 .08012 L
s
1 .894 .882 r
.90829 .08012 m
.90829 .01765 L
.90894 .01765 L
.90894 .08012 L
F
.804 .522 .247 r
.90829 .08012 m
.90829 .01765 L
.90894 .01765 L
.90894 .08012 L
s
1 .894 .882 r
.90894 .08012 m
.90894 .01763 L
.90958 .01763 L
.90958 .08012 L
F
.804 .522 .247 r
.90894 .08012 m
.90894 .01763 L
.90958 .01763 L
.90958 .08012 L
s
1 .894 .882 r
.90958 .08012 m
.90958 .01757 L
.91003 .01757 L
.91003 .08012 L
F
.804 .522 .247 r
.90958 .08012 m
.90958 .01757 L
.91003 .01757 L
.91003 .08012 L
s
1 .894 .882 r
.91003 .08012 m
.91003 .01754 L
.91031 .01754 L
.91031 .08012 L
F
.804 .522 .247 r
.91003 .08012 m
.91003 .01754 L
.91031 .01754 L
.91031 .08012 L
s
1 .894 .882 r
.91031 .08012 m
.91031 .01753 L
.91102 .01753 L
.91102 .08012 L
F
.804 .522 .247 r
.91031 .08012 m
.91031 .01753 L
.91102 .01753 L
.91102 .08012 L
s
1 .894 .882 r
.91102 .08012 m
.91102 .01743 L
.91163 .01743 L
.91163 .08012 L
F
.804 .522 .247 r
.91102 .08012 m
.91102 .01743 L
.91163 .01743 L
.91163 .08012 L
s
1 .894 .882 r
.91163 .08012 m
.91163 .01739 L
.91206 .01739 L
.91206 .08012 L
F
.804 .522 .247 r
.91163 .08012 m
.91163 .01739 L
.91206 .01739 L
.91206 .08012 L
s
1 .894 .882 r
.91206 .08012 m
.91206 .01738 L
.91247 .01738 L
.91247 .08012 L
F
.804 .522 .247 r
.91206 .08012 m
.91206 .01738 L
.91247 .01738 L
.91247 .08012 L
s
1 .894 .882 r
.91247 .08012 m
.91247 .01734 L
.91299 .01734 L
.91299 .08012 L
F
.804 .522 .247 r
.91247 .08012 m
.91247 .01734 L
.91299 .01734 L
.91299 .08012 L
s
1 .894 .882 r
.91299 .08012 m
.91299 .01729 L
.91322 .01729 L
.91322 .08012 L
F
.804 .522 .247 r
.91299 .08012 m
.91299 .01729 L
.91322 .01729 L
.91322 .08012 L
s
1 .894 .882 r
.91322 .08012 m
.91322 .01729 L
.91373 .01729 L
.91373 .08012 L
F
.804 .522 .247 r
.91322 .08012 m
.91322 .01729 L
.91373 .01729 L
.91373 .08012 L
s
1 .894 .882 r
.91373 .08012 m
.91373 .01723 L
.91409 .01723 L
.91409 .08012 L
F
.804 .522 .247 r
.91373 .08012 m
.91373 .01723 L
.91409 .01723 L
.91409 .08012 L
s
1 .894 .882 r
.91409 .08012 m
.91409 .01719 L
.91481 .01719 L
.91481 .08012 L
F
.804 .522 .247 r
.91409 .08012 m
.91409 .01719 L
.91481 .01719 L
.91481 .08012 L
s
1 .894 .882 r
.91481 .08012 m
.91481 .01715 L
.91508 .01715 L
.91508 .08012 L
F
.804 .522 .247 r
.91481 .08012 m
.91481 .01715 L
.91508 .01715 L
.91508 .08012 L
s
1 .894 .882 r
.91508 .08012 m
.91508 .01712 L
.91531 .01712 L
.91531 .08012 L
F
.804 .522 .247 r
.91508 .08012 m
.91508 .01712 L
.91531 .01712 L
.91531 .08012 L
s
1 .894 .882 r
.91531 .08012 m
.91531 .01709 L
.91574 .01709 L
.91574 .08012 L
F
.804 .522 .247 r
.91531 .08012 m
.91531 .01709 L
.91574 .01709 L
.91574 .08012 L
s
1 .894 .882 r
.91574 .08012 m
.91574 .01705 L
.9162 .01705 L
.9162 .08012 L
F
.804 .522 .247 r
.91574 .08012 m
.91574 .01705 L
.9162 .01705 L
.9162 .08012 L
s
1 .894 .882 r
.9162 .08012 m
.9162 .01702 L
.91677 .01702 L
.91677 .08012 L
F
.804 .522 .247 r
.9162 .08012 m
.9162 .01702 L
.91677 .01702 L
.91677 .08012 L
s
1 .894 .882 r
.91677 .08012 m
.91677 .017 L
.91705 .017 L
.91705 .08012 L
F
.804 .522 .247 r
.91677 .08012 m
.91677 .017 L
.91705 .017 L
.91705 .08012 L
s
1 .894 .882 r
.91705 .08012 m
.91705 .01694 L
.91775 .01694 L
.91775 .08012 L
F
.804 .522 .247 r
.91705 .08012 m
.91705 .01694 L
.91775 .01694 L
.91775 .08012 L
s
1 .894 .882 r
.91775 .08012 m
.91775 .01693 L
.91805 .01693 L
.91805 .08012 L
F
.804 .522 .247 r
.91775 .08012 m
.91775 .01693 L
.91805 .01693 L
.91805 .08012 L
s
1 .894 .882 r
.91805 .08012 m
.91805 .0169 L
.91853 .0169 L
.91853 .08012 L
F
.804 .522 .247 r
.91805 .08012 m
.91805 .0169 L
.91853 .0169 L
.91853 .08012 L
s
1 .894 .882 r
.91853 .08012 m
.91853 .01685 L
.91901 .01685 L
.91901 .08012 L
F
.804 .522 .247 r
.91853 .08012 m
.91853 .01685 L
.91901 .01685 L
.91901 .08012 L
s
1 .894 .882 r
.91901 .08012 m
.91901 .0168 L
.91957 .0168 L
.91957 .08012 L
F
.804 .522 .247 r
.91901 .08012 m
.91901 .0168 L
.91957 .0168 L
.91957 .08012 L
s
1 .894 .882 r
.91957 .08012 m
.91957 .01679 L
.91995 .01679 L
.91995 .08012 L
F
.804 .522 .247 r
.91957 .08012 m
.91957 .01679 L
.91995 .01679 L
.91995 .08012 L
s
1 .894 .882 r
.91995 .08012 m
.91995 .01673 L
.92052 .01673 L
.92052 .08012 L
F
.804 .522 .247 r
.91995 .08012 m
.91995 .01673 L
.92052 .01673 L
.92052 .08012 L
s
1 .894 .882 r
.92052 .08012 m
.92052 .01671 L
.92077 .01671 L
.92077 .08012 L
F
.804 .522 .247 r
.92052 .08012 m
.92052 .01671 L
.92077 .01671 L
.92077 .08012 L
s
1 .894 .882 r
.92077 .08012 m
.92077 .01671 L
.92126 .01671 L
.92126 .08012 L
F
.804 .522 .247 r
.92077 .08012 m
.92077 .01671 L
.92126 .01671 L
.92126 .08012 L
s
1 .894 .882 r
.92126 .08012 m
.92126 .01667 L
.92166 .01667 L
.92166 .08012 L
F
.804 .522 .247 r
.92126 .08012 m
.92126 .01667 L
.92166 .01667 L
.92166 .08012 L
s
1 .894 .882 r
.92166 .08012 m
.92166 .01664 L
.92236 .01664 L
.92236 .08012 L
F
.804 .522 .247 r
.92166 .08012 m
.92166 .01664 L
.92236 .01664 L
.92236 .08012 L
s
1 .894 .882 r
.92236 .08012 m
.92236 .01659 L
.92291 .01659 L
.92291 .08012 L
F
.804 .522 .247 r
.92236 .08012 m
.92236 .01659 L
.92291 .01659 L
.92291 .08012 L
s
1 .894 .882 r
.92291 .08012 m
.92291 .01654 L
.92321 .01654 L
.92321 .08012 L
F
.804 .522 .247 r
.92291 .08012 m
.92291 .01654 L
.92321 .01654 L
.92321 .08012 L
s
1 .894 .882 r
.92321 .08012 m
.92321 .01651 L
.92382 .01651 L
.92382 .08012 L
F
.804 .522 .247 r
.92321 .08012 m
.92321 .01651 L
.92382 .01651 L
.92382 .08012 L
s
1 .894 .882 r
.92382 .08012 m
.92382 .01648 L
.9245 .01648 L
.9245 .08012 L
F
.804 .522 .247 r
.92382 .08012 m
.92382 .01648 L
.9245 .01648 L
.9245 .08012 L
s
1 .894 .882 r
.9245 .08012 m
.9245 .01645 L
.92477 .01645 L
.92477 .08012 L
F
.804 .522 .247 r
.9245 .08012 m
.9245 .01645 L
.92477 .01645 L
.92477 .08012 L
s
1 .894 .882 r
.92477 .08012 m
.92477 .01642 L
.92543 .01642 L
.92543 .08012 L
F
.804 .522 .247 r
.92477 .08012 m
.92477 .01642 L
.92543 .01642 L
.92543 .08012 L
s
1 .894 .882 r
.92543 .08012 m
.92543 .01637 L
.92605 .01637 L
.92605 .08012 L
F
.804 .522 .247 r
.92543 .08012 m
.92543 .01637 L
.92605 .01637 L
.92605 .08012 L
s
1 .894 .882 r
.92605 .08012 m
.92605 .01632 L
.92668 .01632 L
.92668 .08012 L
F
.804 .522 .247 r
.92605 .08012 m
.92605 .01632 L
.92668 .01632 L
.92668 .08012 L
s
1 .894 .882 r
.92668 .08012 m
.92668 .0163 L
.92694 .0163 L
.92694 .08012 L
F
.804 .522 .247 r
.92668 .08012 m
.92668 .0163 L
.92694 .0163 L
.92694 .08012 L
s
1 .894 .882 r
.92694 .08012 m
.92694 .01628 L
.9274 .01628 L
.9274 .08012 L
F
.804 .522 .247 r
.92694 .08012 m
.92694 .01628 L
.9274 .01628 L
.9274 .08012 L
s
1 .894 .882 r
.9274 .08012 m
.9274 .01625 L
.92778 .01625 L
.92778 .08012 L
F
.804 .522 .247 r
.9274 .08012 m
.9274 .01625 L
.92778 .01625 L
.92778 .08012 L
s
1 .894 .882 r
.92778 .08012 m
.92778 .01622 L
.92806 .01622 L
.92806 .08012 L
F
.804 .522 .247 r
.92778 .08012 m
.92778 .01622 L
.92806 .01622 L
.92806 .08012 L
s
1 .894 .882 r
.92806 .08012 m
.92806 .01619 L
.92876 .01619 L
.92876 .08012 L
F
.804 .522 .247 r
.92806 .08012 m
.92806 .01619 L
.92876 .01619 L
.92876 .08012 L
s
1 .894 .882 r
.92876 .08012 m
.92876 .01616 L
.92925 .01616 L
.92925 .08012 L
F
.804 .522 .247 r
.92876 .08012 m
.92876 .01616 L
.92925 .01616 L
.92925 .08012 L
s
1 .894 .882 r
.92925 .08012 m
.92925 .01614 L
.92955 .01614 L
.92955 .08012 L
F
.804 .522 .247 r
.92925 .08012 m
.92925 .01614 L
.92955 .01614 L
.92955 .08012 L
s
1 .894 .882 r
.92955 .08012 m
.92955 .01611 L
.93008 .01611 L
.93008 .08012 L
F
.804 .522 .247 r
.92955 .08012 m
.92955 .01611 L
.93008 .01611 L
.93008 .08012 L
s
1 .894 .882 r
.93008 .08012 m
.93008 .01609 L
.93052 .01609 L
.93052 .08012 L
F
.804 .522 .247 r
.93008 .08012 m
.93008 .01609 L
.93052 .01609 L
.93052 .08012 L
s
1 .894 .882 r
.93052 .08012 m
.93052 .01603 L
.93118 .01603 L
.93118 .08012 L
F
.804 .522 .247 r
.93052 .08012 m
.93052 .01603 L
.93118 .01603 L
.93118 .08012 L
s
1 .894 .882 r
.93118 .08012 m
.93118 .01602 L
.93183 .01602 L
.93183 .08012 L
F
.804 .522 .247 r
.93118 .08012 m
.93118 .01602 L
.93183 .01602 L
.93183 .08012 L
s
1 .894 .882 r
.93183 .08012 m
.93183 .01597 L
.93253 .01597 L
.93253 .08012 L
F
.804 .522 .247 r
.93183 .08012 m
.93183 .01597 L
.93253 .01597 L
.93253 .08012 L
s
1 .894 .882 r
.93253 .08012 m
.93253 .01595 L
.93294 .01595 L
.93294 .08012 L
F
.804 .522 .247 r
.93253 .08012 m
.93253 .01595 L
.93294 .01595 L
.93294 .08012 L
s
1 .894 .882 r
.93294 .08012 m
.93294 .01591 L
.93333 .01591 L
.93333 .08012 L
F
.804 .522 .247 r
.93294 .08012 m
.93294 .01591 L
.93333 .01591 L
.93333 .08012 L
s
1 .894 .882 r
.93333 .08012 m
.93333 .0159 L
.9338 .0159 L
.9338 .08012 L
F
.804 .522 .247 r
.93333 .08012 m
.93333 .0159 L
.9338 .0159 L
.9338 .08012 L
s
1 .894 .882 r
.9338 .08012 m
.9338 .01588 L
.93402 .01588 L
.93402 .08012 L
F
.804 .522 .247 r
.9338 .08012 m
.9338 .01588 L
.93402 .01588 L
.93402 .08012 L
s
1 .894 .882 r
.93402 .08012 m
.93402 .01584 L
.9346 .01584 L
.9346 .08012 L
F
.804 .522 .247 r
.93402 .08012 m
.93402 .01584 L
.9346 .01584 L
.9346 .08012 L
s
1 .894 .882 r
.9346 .08012 m
.9346 .01584 L
.93492 .01584 L
.93492 .08012 L
F
.804 .522 .247 r
.9346 .08012 m
.9346 .01584 L
.93492 .01584 L
.93492 .08012 L
s
1 .894 .882 r
.93492 .08012 m
.93492 .0158 L
.93551 .0158 L
.93551 .08012 L
F
.804 .522 .247 r
.93492 .08012 m
.93492 .0158 L
.93551 .0158 L
.93551 .08012 L
s
1 .894 .882 r
.93551 .08012 m
.93551 .01579 L
.93578 .01579 L
.93578 .08012 L
F
.804 .522 .247 r
.93551 .08012 m
.93551 .01579 L
.93578 .01579 L
.93578 .08012 L
s
1 .894 .882 r
.93578 .08012 m
.93578 .01575 L
.93631 .01575 L
.93631 .08012 L
F
.804 .522 .247 r
.93578 .08012 m
.93578 .01575 L
.93631 .01575 L
.93631 .08012 L
s
1 .894 .882 r
.93631 .08012 m
.93631 .01573 L
.93669 .01573 L
.93669 .08012 L
F
.804 .522 .247 r
.93631 .08012 m
.93631 .01573 L
.93669 .01573 L
.93669 .08012 L
s
1 .894 .882 r
.93669 .08012 m
.93669 .01572 L
.93739 .01572 L
.93739 .08012 L
F
.804 .522 .247 r
.93669 .08012 m
.93669 .01572 L
.93739 .01572 L
.93739 .08012 L
s
1 .894 .882 r
.93739 .08012 m
.93739 .01568 L
.93777 .01568 L
.93777 .08012 L
F
.804 .522 .247 r
.93739 .08012 m
.93739 .01568 L
.93777 .01568 L
.93777 .08012 L
s
1 .894 .882 r
.93777 .08012 m
.93777 .01566 L
.93826 .01566 L
.93826 .08012 L
F
.804 .522 .247 r
.93777 .08012 m
.93777 .01566 L
.93826 .01566 L
.93826 .08012 L
s
1 .894 .882 r
.93826 .08012 m
.93826 .01564 L
.93892 .01564 L
.93892 .08012 L
F
.804 .522 .247 r
.93826 .08012 m
.93826 .01564 L
.93892 .01564 L
.93892 .08012 L
s
1 .894 .882 r
.93892 .08012 m
.93892 .0156 L
.93946 .0156 L
.93946 .08012 L
F
.804 .522 .247 r
.93892 .08012 m
.93892 .0156 L
.93946 .0156 L
.93946 .08012 L
s
1 .894 .882 r
.93946 .08012 m
.93946 .01558 L
.93977 .01558 L
.93977 .08012 L
F
.804 .522 .247 r
.93946 .08012 m
.93946 .01558 L
.93977 .01558 L
.93977 .08012 L
s
1 .894 .882 r
.93977 .08012 m
.93977 .01556 L
.94029 .01556 L
.94029 .08012 L
F
.804 .522 .247 r
.93977 .08012 m
.93977 .01556 L
.94029 .01556 L
.94029 .08012 L
s
1 .894 .882 r
.94029 .08012 m
.94029 .01554 L
.94068 .01554 L
.94068 .08012 L
F
.804 .522 .247 r
.94029 .08012 m
.94029 .01554 L
.94068 .01554 L
.94068 .08012 L
s
1 .894 .882 r
.94068 .08012 m
.94068 .01552 L
.94114 .01552 L
.94114 .08012 L
F
.804 .522 .247 r
.94068 .08012 m
.94068 .01552 L
.94114 .01552 L
.94114 .08012 L
s
1 .894 .882 r
.94114 .08012 m
.94114 .01549 L
.94165 .01549 L
.94165 .08012 L
F
.804 .522 .247 r
.94114 .08012 m
.94114 .01549 L
.94165 .01549 L
.94165 .08012 L
s
1 .894 .882 r
.94165 .08012 m
.94165 .01548 L
.94195 .01548 L
.94195 .08012 L
F
.804 .522 .247 r
.94165 .08012 m
.94165 .01548 L
.94195 .01548 L
.94195 .08012 L
s
1 .894 .882 r
.94195 .08012 m
.94195 .01546 L
.94241 .01546 L
.94241 .08012 L
F
.804 .522 .247 r
.94195 .08012 m
.94195 .01546 L
.94241 .01546 L
.94241 .08012 L
s
1 .894 .882 r
.94241 .08012 m
.94241 .01545 L
.94295 .01545 L
.94295 .08012 L
F
.804 .522 .247 r
.94241 .08012 m
.94241 .01545 L
.94295 .01545 L
.94295 .08012 L
s
1 .894 .882 r
.94295 .08012 m
.94295 .01542 L
.9435 .01542 L
.9435 .08012 L
F
.804 .522 .247 r
.94295 .08012 m
.94295 .01542 L
.9435 .01542 L
.9435 .08012 L
s
1 .894 .882 r
.9435 .08012 m
.9435 .01539 L
.94412 .01539 L
.94412 .08012 L
F
.804 .522 .247 r
.9435 .08012 m
.9435 .01539 L
.94412 .01539 L
.94412 .08012 L
s
1 .894 .882 r
.94412 .08012 m
.94412 .01537 L
.94441 .01537 L
.94441 .08012 L
F
.804 .522 .247 r
.94412 .08012 m
.94412 .01537 L
.94441 .01537 L
.94441 .08012 L
s
1 .894 .882 r
.94441 .08012 m
.94441 .01537 L
.94469 .01537 L
.94469 .08012 L
F
.804 .522 .247 r
.94441 .08012 m
.94441 .01537 L
.94469 .01537 L
.94469 .08012 L
s
1 .894 .882 r
.94469 .08012 m
.94469 .01534 L
.94524 .01534 L
.94524 .08012 L
F
.804 .522 .247 r
.94469 .08012 m
.94469 .01534 L
.94524 .01534 L
.94524 .08012 L
s
1 .894 .882 r
.94524 .08012 m
.94524 .01533 L
.94549 .01533 L
.94549 .08012 L
F
.804 .522 .247 r
.94524 .08012 m
.94524 .01533 L
.94549 .01533 L
.94549 .08012 L
s
1 .894 .882 r
.94549 .08012 m
.94549 .0153 L
.9462 .0153 L
.9462 .08012 L
F
.804 .522 .247 r
.94549 .08012 m
.94549 .0153 L
.9462 .0153 L
.9462 .08012 L
s
1 .894 .882 r
.9462 .08012 m
.9462 .01529 L
.94663 .01529 L
.94663 .08012 L
F
.804 .522 .247 r
.9462 .08012 m
.9462 .01529 L
.94663 .01529 L
.94663 .08012 L
s
1 .894 .882 r
.94663 .08012 m
.94663 .01527 L
.94713 .01527 L
.94713 .08012 L
F
.804 .522 .247 r
.94663 .08012 m
.94663 .01527 L
.94713 .01527 L
.94713 .08012 L
s
1 .894 .882 r
.94713 .08012 m
.94713 .01525 L
.94757 .01525 L
.94757 .08012 L
F
.804 .522 .247 r
.94713 .08012 m
.94713 .01525 L
.94757 .01525 L
.94757 .08012 L
s
1 .894 .882 r
.94757 .08012 m
.94757 .01524 L
.94813 .01524 L
.94813 .08012 L
F
.804 .522 .247 r
.94757 .08012 m
.94757 .01524 L
.94813 .01524 L
.94813 .08012 L
s
1 .894 .882 r
.94813 .08012 m
.94813 .01522 L
.94858 .01522 L
.94858 .08012 L
F
.804 .522 .247 r
.94813 .08012 m
.94813 .01522 L
.94858 .01522 L
.94858 .08012 L
s
1 .894 .882 r
.94858 .08012 m
.94858 .01521 L
.94893 .01521 L
.94893 .08012 L
F
.804 .522 .247 r
.94858 .08012 m
.94858 .01521 L
.94893 .01521 L
.94893 .08012 L
s
1 .894 .882 r
.94893 .08012 m
.94893 .01519 L
.94961 .01519 L
.94961 .08012 L
F
.804 .522 .247 r
.94893 .08012 m
.94893 .01519 L
.94961 .01519 L
.94961 .08012 L
s
1 .894 .882 r
.94961 .08012 m
.94961 .01516 L
.95024 .01516 L
.95024 .08012 L
F
.804 .522 .247 r
.94961 .08012 m
.94961 .01516 L
.95024 .01516 L
.95024 .08012 L
s
1 .894 .882 r
.95024 .08012 m
.95024 .01514 L
.95088 .01514 L
.95088 .08012 L
F
.804 .522 .247 r
.95024 .08012 m
.95024 .01514 L
.95088 .01514 L
.95088 .08012 L
s
1 .894 .882 r
.95088 .08012 m
.95088 .01513 L
.95113 .01513 L
.95113 .08012 L
F
.804 .522 .247 r
.95088 .08012 m
.95088 .01513 L
.95113 .01513 L
.95113 .08012 L
s
1 .894 .882 r
.95113 .08012 m
.95113 .01512 L
.95151 .01512 L
.95151 .08012 L
F
.804 .522 .247 r
.95113 .08012 m
.95113 .01512 L
.95151 .01512 L
.95151 .08012 L
s
1 .894 .882 r
.95151 .08012 m
.95151 .01511 L
.95197 .01511 L
.95197 .08012 L
F
.804 .522 .247 r
.95151 .08012 m
.95151 .01511 L
.95197 .01511 L
.95197 .08012 L
s
1 .894 .882 r
.95197 .08012 m
.95197 .01509 L
.95238 .01509 L
.95238 .08012 L
F
.804 .522 .247 r
.95197 .08012 m
.95197 .01509 L
.95238 .01509 L
.95238 .08012 L
s
1 .894 .882 r
.95238 .08012 m
.95238 .01507 L
.95285 .01507 L
.95285 .08012 L
F
.804 .522 .247 r
.95238 .08012 m
.95238 .01507 L
.95285 .01507 L
.95285 .08012 L
s
1 .894 .882 r
.95285 .08012 m
.95285 .01506 L
.95315 .01506 L
.95315 .08012 L
F
.804 .522 .247 r
.95285 .08012 m
.95285 .01506 L
.95315 .01506 L
.95315 .08012 L
s
1 .894 .882 r
.95315 .08012 m
.95315 .01505 L
.95388 .01505 L
.95388 .08012 L
F
.804 .522 .247 r
.95315 .08012 m
.95315 .01505 L
.95388 .01505 L
.95388 .08012 L
s
1 .894 .882 r
.95388 .08012 m
.95388 .01502 L
.95448 .01502 L
.95448 .08012 L
F
.804 .522 .247 r
.95388 .08012 m
.95388 .01502 L
.95448 .01502 L
.95448 .08012 L
s
1 .894 .882 r
.95448 .08012 m
.95448 .01502 L
.95513 .01502 L
.95513 .08012 L
F
.804 .522 .247 r
.95448 .08012 m
.95448 .01502 L
.95513 .01502 L
.95513 .08012 L
s
1 .894 .882 r
.95513 .08012 m
.95513 .015 L
.95554 .015 L
.95554 .08012 L
F
.804 .522 .247 r
.95513 .08012 m
.95513 .015 L
.95554 .015 L
.95554 .08012 L
s
1 .894 .882 r
.95554 .08012 m
.95554 .01498 L
.9562 .01498 L
.9562 .08012 L
F
.804 .522 .247 r
.95554 .08012 m
.95554 .01498 L
.9562 .01498 L
.9562 .08012 L
s
1 .894 .882 r
.9562 .08012 m
.9562 .01496 L
.95674 .01496 L
.95674 .08012 L
F
.804 .522 .247 r
.9562 .08012 m
.9562 .01496 L
.95674 .01496 L
.95674 .08012 L
s
1 .894 .882 r
.95674 .08012 m
.95674 .01496 L
.95705 .01496 L
.95705 .08012 L
F
.804 .522 .247 r
.95674 .08012 m
.95674 .01496 L
.95705 .01496 L
.95705 .08012 L
s
1 .894 .882 r
.95705 .08012 m
.95705 .01495 L
.95744 .01495 L
.95744 .08012 L
F
.804 .522 .247 r
.95705 .08012 m
.95705 .01495 L
.95744 .01495 L
.95744 .08012 L
s
1 .894 .882 r
.95744 .08012 m
.95744 .01493 L
.95812 .01493 L
.95812 .08012 L
F
.804 .522 .247 r
.95744 .08012 m
.95744 .01493 L
.95812 .01493 L
.95812 .08012 L
s
1 .894 .882 r
.95812 .08012 m
.95812 .01493 L
.95845 .01493 L
.95845 .08012 L
F
.804 .522 .247 r
.95812 .08012 m
.95812 .01493 L
.95845 .01493 L
.95845 .08012 L
s
1 .894 .882 r
.95845 .08012 m
.95845 .01491 L
.95899 .01491 L
.95899 .08012 L
F
.804 .522 .247 r
.95845 .08012 m
.95845 .01491 L
.95899 .01491 L
.95899 .08012 L
s
1 .894 .882 r
.95899 .08012 m
.95899 .0149 L
.95966 .0149 L
.95966 .08012 L
F
.804 .522 .247 r
.95899 .08012 m
.95899 .0149 L
.95966 .0149 L
.95966 .08012 L
s
1 .894 .882 r
.95966 .08012 m
.95966 .01489 L
.96001 .01489 L
.96001 .08012 L
F
.804 .522 .247 r
.95966 .08012 m
.95966 .01489 L
.96001 .01489 L
.96001 .08012 L
s
1 .894 .882 r
.96001 .08012 m
.96001 .01487 L
.96062 .01487 L
.96062 .08012 L
F
.804 .522 .247 r
.96001 .08012 m
.96001 .01487 L
.96062 .01487 L
.96062 .08012 L
s
1 .894 .882 r
.96062 .08012 m
.96062 .01487 L
.96103 .01487 L
.96103 .08012 L
F
.804 .522 .247 r
.96062 .08012 m
.96062 .01487 L
.96103 .01487 L
.96103 .08012 L
s
1 .894 .882 r
.96103 .08012 m
.96103 .01486 L
.96176 .01486 L
.96176 .08012 L
F
.804 .522 .247 r
.96103 .08012 m
.96103 .01486 L
.96176 .01486 L
.96176 .08012 L
s
1 .894 .882 r
.96176 .08012 m
.96176 .01484 L
.9622 .01484 L
.9622 .08012 L
F
.804 .522 .247 r
.96176 .08012 m
.96176 .01484 L
.9622 .01484 L
.9622 .08012 L
s
1 .894 .882 r
.9622 .08012 m
.9622 .01484 L
.9629 .01484 L
.9629 .08012 L
F
.804 .522 .247 r
.9622 .08012 m
.9622 .01484 L
.9629 .01484 L
.9629 .08012 L
s
1 .894 .882 r
.9629 .08012 m
.9629 .01482 L
.96328 .01482 L
.96328 .08012 L
F
.804 .522 .247 r
.9629 .08012 m
.9629 .01482 L
.96328 .01482 L
.96328 .08012 L
s
1 .894 .882 r
.96328 .08012 m
.96328 .01482 L
.96385 .01482 L
.96385 .08012 L
F
.804 .522 .247 r
.96328 .08012 m
.96328 .01482 L
.96385 .01482 L
.96385 .08012 L
s
1 .894 .882 r
.96385 .08012 m
.96385 .01481 L
.96457 .01481 L
.96457 .08012 L
F
.804 .522 .247 r
.96385 .08012 m
.96385 .01481 L
.96457 .01481 L
.96457 .08012 L
s
1 .894 .882 r
.96457 .08012 m
.96457 .0148 L
.96507 .0148 L
.96507 .08012 L
F
.804 .522 .247 r
.96457 .08012 m
.96457 .0148 L
.96507 .0148 L
.96507 .08012 L
s
1 .894 .882 r
.96507 .08012 m
.96507 .01479 L
.96572 .01479 L
.96572 .08012 L
F
.804 .522 .247 r
.96507 .08012 m
.96507 .01479 L
.96572 .01479 L
.96572 .08012 L
s
1 .894 .882 r
.96572 .08012 m
.96572 .01478 L
.9662 .01478 L
.9662 .08012 L
F
.804 .522 .247 r
.96572 .08012 m
.96572 .01478 L
.9662 .01478 L
.9662 .08012 L
s
1 .894 .882 r
.9662 .08012 m
.9662 .01478 L
.96692 .01478 L
.96692 .08012 L
F
.804 .522 .247 r
.9662 .08012 m
.9662 .01478 L
.96692 .01478 L
.96692 .08012 L
s
1 .894 .882 r
.96692 .08012 m
.96692 .01477 L
.96756 .01477 L
.96756 .08012 L
F
.804 .522 .247 r
.96692 .08012 m
.96692 .01477 L
.96756 .01477 L
.96756 .08012 L
s
1 .894 .882 r
.96756 .08012 m
.96756 .01476 L
.96828 .01476 L
.96828 .08012 L
F
.804 .522 .247 r
.96756 .08012 m
.96756 .01476 L
.96828 .01476 L
.96828 .08012 L
s
1 .894 .882 r
.96828 .08012 m
.96828 .01475 L
.96857 .01475 L
.96857 .08012 L
F
.804 .522 .247 r
.96828 .08012 m
.96828 .01475 L
.96857 .01475 L
.96857 .08012 L
s
1 .894 .882 r
.96857 .08012 m
.96857 .01475 L
.96885 .01475 L
.96885 .08012 L
F
.804 .522 .247 r
.96857 .08012 m
.96857 .01475 L
.96885 .01475 L
.96885 .08012 L
s
1 .894 .882 r
.96885 .08012 m
.96885 .01475 L
.96917 .01475 L
.96917 .08012 L
F
.804 .522 .247 r
.96885 .08012 m
.96885 .01475 L
.96917 .01475 L
.96917 .08012 L
s
1 .894 .882 r
.96917 .08012 m
.96917 .01474 L
.96981 .01474 L
.96981 .08012 L
F
.804 .522 .247 r
.96917 .08012 m
.96917 .01474 L
.96981 .01474 L
.96981 .08012 L
s
1 .894 .882 r
.96981 .08012 m
.96981 .01474 L
.97044 .01474 L
.97044 .08012 L
F
.804 .522 .247 r
.96981 .08012 m
.96981 .01474 L
.97044 .01474 L
.97044 .08012 L
s
1 .894 .882 r
.97044 .08012 m
.97044 .01473 L
.97077 .01473 L
.97077 .08012 L
F
.804 .522 .247 r
.97044 .08012 m
.97044 .01473 L
.97077 .01473 L
.97077 .08012 L
s
1 .894 .882 r
.97077 .08012 m
.97077 .01473 L
.97149 .01473 L
.97149 .08012 L
F
.804 .522 .247 r
.97077 .08012 m
.97077 .01473 L
.97149 .01473 L
.97149 .08012 L
s
1 .894 .882 r
.97149 .08012 m
.97149 .01473 L
.9718 .01473 L
.9718 .08012 L
F
.804 .522 .247 r
.97149 .08012 m
.97149 .01473 L
.9718 .01473 L
.9718 .08012 L
s
1 .894 .882 r
.9718 .08012 m
.9718 .01473 L
.97249 .01473 L
.97249 .08012 L
F
.804 .522 .247 r
.9718 .08012 m
.9718 .01473 L
.97249 .01473 L
.97249 .08012 L
s
1 .894 .882 r
.97249 .08012 m
.97249 .01472 L
.97321 .01472 L
.97321 .08012 L
F
.804 .522 .247 r
.97249 .08012 m
.97249 .01472 L
.97321 .01472 L
.97321 .08012 L
s
1 .894 .882 r
.97321 .08012 m
.97321 .01472 L
.97354 .01472 L
.97354 .08012 L
F
.804 .522 .247 r
.97321 .08012 m
.97321 .01472 L
.97354 .01472 L
.97354 .08012 L
s
1 .894 .882 r
.97354 .08012 m
.97354 .01472 L
.97417 .01472 L
.97417 .08012 L
F
.804 .522 .247 r
.97354 .08012 m
.97354 .01472 L
.97417 .01472 L
.97417 .08012 L
s
1 .894 .882 r
.97417 .08012 m
.97417 .01472 L
.97487 .01472 L
.97487 .08012 L
F
.804 .522 .247 r
.97417 .08012 m
.97417 .01472 L
.97487 .01472 L
.97487 .08012 L
s
1 .894 .882 r
.97487 .08012 m
.97487 .01472 L
.97535 .01472 L
.97535 .08012 L
F
.804 .522 .247 r
.97487 .08012 m
.97487 .01472 L
.97535 .01472 L
.97535 .08012 L
s
1 .894 .882 r
.97535 .08012 m
.97535 .01472 L
.97572 .01472 L
.97572 .08012 L
F
.804 .522 .247 r
.97535 .08012 m
.97535 .01472 L
.97572 .01472 L
.97572 .08012 L
s
1 .894 .882 r
.97572 .08012 m
.97572 .01472 L
.97619 .01472 L
.97619 .08012 L
F
.804 .522 .247 r
.97572 .08012 m
.97572 .01472 L
.97619 .01472 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.02395 .60314 Mdot
.02457 .60239 Mdot
.02513 .60168 Mdot
.0256 .60111 Mdot
.02615 .60043 Mdot
.0266 .59987 Mdot
.0271 .59925 Mdot
.02737 .59892 Mdot
.02766 .59857 Mdot
.02789 .59828 Mdot
.02851 .59752 Mdot
.02931 .59654 Mdot
.02959 .59619 Mdot
.02981 .59593 Mdot
.03081 .59469 Mdot
.03146 .5939 Mdot
.03204 .59318 Mdot
.03222 .59297 Mdot
.03276 .59231 Mdot
.03354 .59135 Mdot
.034 .59079 Mdot
.03448 .59021 Mdot
.03472 .58991 Mdot
.03525 .58926 Mdot
.03598 .58837 Mdot
.03625 .58804 Mdot
.03691 .58723 Mdot
.03743 .5866 Mdot
.03776 .5862 Mdot
.03818 .58569 Mdot
.03871 .58504 Mdot
.03897 .58472 Mdot
.03986 .58365 Mdot
.04042 .58296 Mdot
.04141 .58176 Mdot
.04163 .5815 Mdot
.04258 .58034 Mdot
.04347 .57927 Mdot
.04359 .57912 Mdot
.0443 .57827 Mdot
.04475 .57772 Mdot
.04516 .57723 Mdot
.0456 .5767 Mdot
.04597 .57625 Mdot
.04631 .57584 Mdot
.04684 .57519 Mdot
.04701 .57499 Mdot
.04731 .57463 Mdot
.04771 .57415 Mdot
.04831 .57343 Mdot
.04883 .57279 Mdot
.04905 .57253 Mdot
.0493 .57223 Mdot
.04971 .57174 Mdot
.05025 .57109 Mdot
.05089 .57033 Mdot
.05148 .56962 Mdot
.052 .56899 Mdot
.05221 .56874 Mdot
.05249 .5684 Mdot
.05296 .56784 Mdot
.05389 .56673 Mdot
.05405 .56653 Mdot
.05465 .56582 Mdot
.05513 .56524 Mdot
.05562 .56466 Mdot
.05637 .56376 Mdot
.05657 .56353 Mdot
.05739 .56254 Mdot
.05779 .56207 Mdot
.05837 .56138 Mdot
.05928 .56029 Mdot
.05964 .55986 Mdot
.06015 .55926 Mdot
.0605 .55885 Mdot
.06083 .55845 Mdot
.06153 .55762 Mdot
.06209 .55695 Mdot
.06264 .5563 Mdot
.06334 .55547 Mdot
.06379 .55493 Mdot
.06406 .55462 Mdot
.06449 .55411 Mdot
.06518 .55329 Mdot
.06547 .55295 Mdot
.06583 .55252 Mdot
.0661 .55221 Mdot
.06654 .55169 Mdot
.06727 .55083 Mdot
.06757 .55048 Mdot
.068 .54997 Mdot
.06885 .54896 Mdot
.06906 .54872 Mdot
.06965 .54802 Mdot
.06994 .54768 Mdot
.06998 .54763 Mdot
.07108 .54634 Mdot
.07139 .54597 Mdot
.07224 .54498 Mdot
.07274 .54439 Mdot
.07299 .5441 Mdot
.07415 .54273 Mdot
.07474 .54205 Mdot
.07522 .54148 Mdot
.07547 .54119 Mdot
.07594 .54065 Mdot
.0764 .54011 Mdot
.07661 .53986 Mdot
.07754 .53878 Mdot
.07786 .53841 Mdot
.07805 .53818 Mdot
.07848 .53768 Mdot
.07935 .53667 Mdot
.07988 .53605 Mdot
.08086 .53491 Mdot
.08093 .53483 Mdot
.08131 .53439 Mdot
.08179 .53383 Mdot
.08262 .53287 Mdot
.08265 .53283 Mdot
.08326 .53213 Mdot
.08367 .53165 Mdot
.08428 .53095 Mdot
.0849 .53023 Mdot
.0852 .52988 Mdot
.08578 .52921 Mdot
.08623 .52869 Mdot
.08649 .52839 Mdot
.08699 .52781 Mdot
.08721 .52756 Mdot
.0875 .52723 Mdot
.08784 .52683 Mdot
.08802 .52663 Mdot
.08845 .52613 Mdot
.08862 .52594 Mdot
.0892 .52527 Mdot
.08974 .52465 Mdot
.09038 .5239 Mdot
.09048 .52379 Mdot
.09112 .52306 Mdot
.09186 .52221 Mdot
.09239 .5216 Mdot
.09298 .52092 Mdot
.09349 .52034 Mdot
.09384 .51994 Mdot
.09464 .51903 Mdot
.09506 .51855 Mdot
.09514 .51845 Mdot
.09587 .51762 Mdot
.09654 .51686 Mdot
.09692 .51642 Mdot
.09752 .51574 Mdot
.09796 .51523 Mdot
.09815 .51502 Mdot
.09883 .51424 Mdot
.09934 .51366 Mdot
.09961 .51335 Mdot
.10028 .51259 Mdot
.1009 .51188 Mdot
.10124 .5115 Mdot
.1016 .51109 Mdot
.10181 .51085 Mdot
.10214 .51048 Mdot
.10237 .51022 Mdot
.10278 .50975 Mdot
.10309 .5094 Mdot
.10355 .50888 Mdot
.10449 .50782 Mdot
.10477 .5075 Mdot
.10519 .50702 Mdot
.10556 .50661 Mdot
.1063 .50577 Mdot
.10659 .50545 Mdot
.10718 .50478 Mdot
.10767 .50423 Mdot
.10795 .50391 Mdot
.10857 .50321 Mdot
.10875 .50301 Mdot
.10939 .50229 Mdot
.10988 .50174 Mdot
.1105 .50105 Mdot
.11124 .5002 Mdot
.11212 .49922 Mdot
.11267 .49861 Mdot
.11303 .49821 Mdot
.11325 .49796 Mdot
.11404 .49707 Mdot
.11472 .49631 Mdot
.11487 .49614 Mdot
.11555 .49539 Mdot
.11575 .49516 Mdot
.11633 .49452 Mdot
.11701 .49375 Mdot
.11705 .49371 Mdot
.11765 .49304 Mdot
.11799 .49266 Mdot
.11865 .49193 Mdot
.11929 .49121 Mdot
.11951 .49097 Mdot
.1202 .4902 Mdot
.12123 .48906 Mdot
.12157 .48869 Mdot
.12198 .48823 Mdot
.1225 .48765 Mdot
.12284 .48727 Mdot
.12358 .48646 Mdot
.12384 .48617 Mdot
.12414 .48583 Mdot
.12471 .48521 Mdot
.12499 .4849 Mdot
.12513 .48474 Mdot
.12603 .48375 Mdot
.12631 .48344 Mdot
.12651 .48322 Mdot
.12702 .48265 Mdot
.12781 .48178 Mdot
.12809 .48148 Mdot
.12827 .48128 Mdot
.12935 .48009 Mdot
.12973 .47968 Mdot
.13058 .47874 Mdot
.13088 .47841 Mdot
.13179 .47742 Mdot
.13211 .47706 Mdot
.13236 .47679 Mdot
.13324 .47583 Mdot
.13341 .47564 Mdot
.13424 .47474 Mdot
.13468 .47425 Mdot
.1349 .47401 Mdot
.13571 .47313 Mdot
.13631 .47247 Mdot
.1368 .47194 Mdot
.13708 .47163 Mdot
.13754 .47114 Mdot
.13832 .47029 Mdot
.13841 .47018 Mdot
.1389 .46966 Mdot
.13959 .4689 Mdot
.13994 .46852 Mdot
.14059 .46782 Mdot
.1415 .46683 Mdot
.14178 .46653 Mdot
.14222 .46606 Mdot
.14249 .46577 Mdot
.14324 .46496 Mdot
.14397 .46416 Mdot
.14433 .46377 Mdot
.14496 .46309 Mdot
.14581 .46218 Mdot
.14637 .46157 Mdot
.14692 .46098 Mdot
.14734 .46053 Mdot
.14767 .46017 Mdot
.14782 .46001 Mdot
.14851 .45927 Mdot
.14919 .45854 Mdot
.15003 .45764 Mdot
.15078 .45683 Mdot
.15105 .45654 Mdot
.15126 .45633 Mdot
.15175 .4558 Mdot
.15203 .4555 Mdot
.1523 .45521 Mdot
.15287 .4546 Mdot
.15303 .45443 Mdot
.15367 .45374 Mdot
.15394 .45346 Mdot
.1543 .45307 Mdot
.15486 .45248 Mdot
.15522 .4521 Mdot
.15553 .45176 Mdot
.15557 .45172 Mdot
.15662 .45061 Mdot
.15673 .45049 Mdot
.15716 .45003 Mdot
.15778 .44937 Mdot
.15815 .44898 Mdot
.15847 .44864 Mdot
.15894 .44814 Mdot
.15963 .4474 Mdot
.16038 .44661 Mdot
.16078 .44619 Mdot
.16164 .44528 Mdot
.16175 .44516 Mdot
.16223 .44466 Mdot
.16249 .44438 Mdot
.16328 .44355 Mdot
.16371 .44309 Mdot
.16418 .4426 Mdot
.16473 .44202 Mdot
.16524 .44148 Mdot
.16551 .4412 Mdot
.16645 .44021 Mdot
.16698 .43965 Mdot
.16734 .43928 Mdot
.16757 .43903 Mdot
.16795 .43864 Mdot
.16864 .43791 Mdot
.16904 .4375 Mdot
.16956 .43694 Mdot
.16982 .43668 Mdot
.17023 .43624 Mdot
.17081 .43564 Mdot
.17154 .43487 Mdot
.17223 .43415 Mdot
.17257 .4338 Mdot
.17291 .43344 Mdot
.17352 .43281 Mdot
.17386 .43246 Mdot
.17453 .43176 Mdot
.17497 .43131 Mdot
.17567 .43058 Mdot
.17593 .43031 Mdot
.17612 .4301 Mdot
.17654 .42967 Mdot
.17713 .42906 Mdot
.1775 .42867 Mdot
.17781 .42835 Mdot
.17854 .42759 Mdot
.17896 .42716 Mdot
.17945 .42666 Mdot
.17992 .42617 Mdot
.18005 .42603 Mdot
.18084 .42523 Mdot
.18158 .42446 Mdot
.18177 .42426 Mdot
.18242 .42359 Mdot
.18291 .42308 Mdot
.18359 .42239 Mdot
.1837 .42227 Mdot
.18406 .4219 Mdot
.18476 .42118 Mdot
.18547 .42045 Mdot
.1859 .42002 Mdot
.18631 .41959 Mdot
.18656 .41934 Mdot
.18676 .41913 Mdot
.1872 .41868 Mdot
.18781 .41806 Mdot
.1881 .41776 Mdot
.18875 .41709 Mdot
.18894 .4169 Mdot
.18942 .41641 Mdot
.1899 .41592 Mdot
.19016 .41566 Mdot
.1907 .41511 Mdot
.19148 .41432 Mdot
.19197 .41381 Mdot
.1922 .41357 Mdot
.1926 .41317 Mdot
.19307 .41269 Mdot
.19375 .412 Mdot
.19425 .4115 Mdot
.19499 .41074 Mdot
.1953 .41043 Mdot
.19559 .41014 Mdot
.19595 .40978 Mdot
.19622 .4095 Mdot
.19701 .4087 Mdot
.1973 .40841 Mdot
.19752 .40819 Mdot
.19839 .40731 Mdot
.19867 .40702 Mdot
.19931 .40637 Mdot
.19974 .40594 Mdot
.20037 .4053 Mdot
.20083 .40484 Mdot
.20109 .40458 Mdot
.20151 .40416 Mdot
.20221 .40346 Mdot
.20241 .40326 Mdot
.20282 .40284 Mdot
.20351 .40215 Mdot
.20395 .40171 Mdot
.20424 .40142 Mdot
.20465 .40101 Mdot
.20531 .40035 Mdot
.20577 .39989 Mdot
.20602 .39964 Mdot
.20646 .39919 Mdot
.20686 .3988 Mdot
.20712 .39854 Mdot
.20741 .39825 Mdot
.20783 .39784 Mdot
.20807 .39759 Mdot
.20826 .39741 Mdot
.20879 .39688 Mdot
.2095 .39616 Mdot
.20952 .39615 Mdot
.21022 .39545 Mdot
.21049 .39519 Mdot
.21147 .39421 Mdot
.21202 .39366 Mdot
.21243 .39325 Mdot
.21292 .39277 Mdot
.21334 .39236 Mdot
.21412 .39158 Mdot
.21471 .391 Mdot
.21487 .39084 Mdot
.21524 .39047 Mdot
.21588 .38984 Mdot
.21666 .38908 Mdot
.21709 .38866 Mdot
.21754 .38821 Mdot
.2179 .38785 Mdot
.21814 .38762 Mdot
.21907 .3867 Mdot
.21965 .38613 Mdot
.21996 .38583 Mdot
.22056 .38524 Mdot
.22109 .38472 Mdot
.22161 .38422 Mdot
.22179 .38403 Mdot
.22254 .3833 Mdot
.22297 .38288 Mdot
.22339 .38247 Mdot
.22424 .38165 Mdot
.22457 .38132 Mdot
.22514 .38076 Mdot
.22538 .38053 Mdot
.22568 .38023 Mdot
.22588 .38005 Mdot
.22639 .37955 Mdot
.22665 .37929 Mdot
.22697 .37898 Mdot
.22768 .37829 Mdot
.22843 .37757 Mdot
.22869 .37731 Mdot
.22895 .37706 Mdot
.22957 .37646 Mdot
.23 .37605 Mdot
.23039 .37567 Mdot
.23045 .37561 Mdot
.23142 .37467 Mdot
.23193 .37417 Mdot
.23225 .37387 Mdot
.23281 .37332 Mdot
.23321 .37294 Mdot
.23326 .37289 Mdot
.23444 .37176 Mdot
.23455 .37165 Mdot
.23498 .37123 Mdot
.23518 .37104 Mdot
.23575 .3705 Mdot
.23654 .36974 Mdot
.2372 .3691 Mdot
.23778 .36855 Mdot
.23822 .36813 Mdot
.23836 .368 Mdot
.23886 .36751 Mdot
.23913 .36726 Mdot
.23965 .36676 Mdot
.23994 .36648 Mdot
.24072 .36574 Mdot
.2409 .36557 Mdot
.24139 .3651 Mdot
.24184 .36466 Mdot
.24239 .36414 Mdot
.24324 .36334 Mdot
.24357 .36302 Mdot
.24408 .36254 Mdot
.24447 .36216 Mdot
.24518 .36149 Mdot
.24567 .36103 Mdot
.24608 .36064 Mdot
.24658 .36017 Mdot
.24714 .35964 Mdot
.24764 .35916 Mdot
.24819 .35864 Mdot
.24848 .35836 Mdot
.24874 .35812 Mdot
.24905 .35783 Mdot
.24961 .3573 Mdot
.25033 .35662 Mdot
.25059 .35638 Mdot
.25144 .35557 Mdot
.25175 .35529 Mdot
.25184 .3552 Mdot
.25241 .35466 Mdot
.25312 .354 Mdot
.25379 .35337 Mdot
.25392 .35325 Mdot
.2547 .35252 Mdot
.25534 .35192 Mdot
.25545 .35182 Mdot
.25611 .3512 Mdot
.25617 .35114 Mdot
.25708 .3503 Mdot
.25769 .34973 Mdot
.25797 .34947 Mdot
.25868 .3488 Mdot
.25905 .34846 Mdot
.25964 .34791 Mdot
.26003 .34754 Mdot
.26064 .34698 Mdot
.26106 .34659 Mdot
.26133 .34633 Mdot
.26159 .3461 Mdot
.26253 .34522 Mdot
.26266 .34511 Mdot
.26314 .34466 Mdot
.26426 .34362 Mdot
.26453 .34338 Mdot
.26503 .34291 Mdot
.26538 .34259 Mdot
.26635 .34169 Mdot
.26638 .34167 Mdot
.26718 .34093 Mdot
.26753 .34061 Mdot
.26815 .34004 Mdot
.26871 .33953 Mdot
.26916 .33911 Mdot
.26957 .33874 Mdot
.27023 .33813 Mdot
.27052 .33787 Mdot
.27083 .33758 Mdot
.27119 .33725 Mdot
.27194 .33657 Mdot
.27221 .33632 Mdot
.27305 .33556 Mdot
.27309 .33552 Mdot
.27371 .33495 Mdot
.27406 .33463 Mdot
.27504 .33374 Mdot
.27553 .33329 Mdot
.2757 .33314 Mdot
.27601 .33285 Mdot
.27654 .33238 Mdot
.27683 .33211 Mdot
.27732 .33167 Mdot
.2776 .33142 Mdot
.27794 .33111 Mdot
.27827 .33081 Mdot
.27892 .33021 Mdot
.27924 .32993 Mdot
.27962 .32958 Mdot
.27984 .32938 Mdot
.28038 .3289 Mdot
.28109 .32826 Mdot
.28167 .32774 Mdot
.28217 .32729 Mdot
.28238 .3271 Mdot
.28322 .32634 Mdot
.2838 .32582 Mdot
.28413 .32552 Mdot
.28453 .32516 Mdot
.28492 .32481 Mdot
.285 .32474 Mdot
.28542 .32436 Mdot
.28554 .32425 Mdot
.28609 .32376 Mdot
.28641 .32347 Mdot
.2867 .32321 Mdot
.28745 .32255 Mdot
.2878 .32223 Mdot
.28878 .32136 Mdot
.28883 .32132 Mdot
.28944 .32077 Mdot
.29017 .32012 Mdot
.29023 .32007 Mdot
.29099 .31939 Mdot
.29169 .31877 Mdot
.29194 .31855 Mdot
.29253 .31802 Mdot
.29308 .31754 Mdot
.29365 .31703 Mdot
.29397 .31674 Mdot
.29465 .31614 Mdot
.29529 .31558 Mdot
.29569 .31522 Mdot
.29585 .31508 Mdot
.29633 .31466 Mdot
.29673 .31431 Mdot
.29722 .31388 Mdot
.29779 .31337 Mdot
.29798 .3132 Mdot
.29837 .31286 Mdot
.29905 .31226 Mdot
.29962 .31177 Mdot
.2999 .31152 Mdot
.30026 .3112 Mdot
.30112 .31045 Mdot
.30141 .3102 Mdot
.30158 .31004 Mdot
.30252 .30922 Mdot
.30287 .30892 Mdot
.30366 .30822 Mdot
.30417 .30778 Mdot
.30433 .30765 Mdot
.30482 .30721 Mdot
.30499 .30707 Mdot
.3054 .30671 Mdot
.30597 .30621 Mdot
.307 .30532 Mdot
.30715 .30519 Mdot
.30761 .30479 Mdot
.30798 .30447 Mdot
.30853 .30399 Mdot
.30928 .30335 Mdot
.30958 .30308 Mdot
.30986 .30284 Mdot
.31086 .30198 Mdot
.31152 .3014 Mdot
.3117 .30125 Mdot
.31221 .30081 Mdot
.31332 .29985 Mdot
.3135 .2997 Mdot
.31389 .29937 Mdot
.31438 .29894 Mdot
.31525 .2982 Mdot
.31597 .29758 Mdot
.31622 .29736 Mdot
.31692 .29676 Mdot
.31739 .29636 Mdot
.3177 .2961 Mdot
.31853 .29539 Mdot
.31888 .29509 Mdot
.31968 .29441 Mdot
.3198 .29431 Mdot
.3203 .29389 Mdot
.32068 .29356 Mdot
.32133 .293 Mdot
.32177 .29263 Mdot
.3221 .29235 Mdot
.32236 .29213 Mdot
.32299 .29159 Mdot
.32353 .29114 Mdot
.32422 .29056 Mdot
.32424 .29054 Mdot
.32517 .28975 Mdot
.32538 .28958 Mdot
.32592 .28912 Mdot
.32641 .28871 Mdot
.3267 .28846 Mdot
.32744 .28784 Mdot
.32798 .28738 Mdot
.32866 .28681 Mdot
.32883 .28667 Mdot
.32899 .28654 Mdot
.3294 .28619 Mdot
.32972 .28592 Mdot
.33026 .28547 Mdot
.33111 .28476 Mdot
.33131 .28459 Mdot
.33174 .28423 Mdot
.33207 .28395 Mdot
.33225 .28381 Mdot
.33275 .28338 Mdot
.33339 .28285 Mdot
.33405 .2823 Mdot
.3343 .28209 Mdot
.33461 .28183 Mdot
.33528 .28127 Mdot
.33562 .28099 Mdot
.33651 .28025 Mdot
.33715 .27972 Mdot
.33752 .27942 Mdot
.33786 .27913 Mdot
.33793 .27907 Mdot
.33881 .27835 Mdot
.33923 .278 Mdot
.33999 .27738 Mdot
.34015 .27724 Mdot
.34075 .27674 Mdot
.34112 .27644 Mdot
.34234 .27544 Mdot
.34237 .27541 Mdot
.34309 .27482 Mdot
.34334 .27461 Mdot
.34371 .27431 Mdot
.34451 .27365 Mdot
.34468 .27351 Mdot
.34545 .27288 Mdot
.34582 .27258 Mdot
.34637 .27213 Mdot
.34682 .27176 Mdot
.34774 .27101 Mdot
.34784 .27093 Mdot
.34837 .2705 Mdot
.34904 .26995 Mdot
.34975 .26938 Mdot
.34987 .26928 Mdot
.35071 .2686 Mdot
.35129 .26812 Mdot
.35222 .26737 Mdot
.35274 .26695 Mdot
.35309 .26667 Mdot
.35334 .26647 Mdot
.35396 .26597 Mdot
.35442 .26559 Mdot
.35481 .26528 Mdot
.35557 .26466 Mdot
.35604 .26429 Mdot
.35646 .26395 Mdot
.35708 .26345 Mdot
.35741 .26319 Mdot
.35764 .263 Mdot
.35814 .2626 Mdot
.35879 .26208 Mdot
.35925 .26171 Mdot
.35935 .26163 Mdot
.35977 .26129 Mdot
.36031 .26086 Mdot
.36069 .26056 Mdot
.36145 .25995 Mdot
.36237 .25922 Mdot
.36287 .25882 Mdot
.36318 .25857 Mdot
.36348 .25834 Mdot
.36406 .25788 Mdot
.3647 .25736 Mdot
.36534 .25685 Mdot
.36585 .25645 Mdot
.3662 .25617 Mdot
.36641 .25601 Mdot
.36692 .25561 Mdot
.36717 .25541 Mdot
.36755 .25511 Mdot
.36807 .2547 Mdot
.36858 .25429 Mdot
.36884 .25409 Mdot
.36952 .25356 Mdot
.37036 .25289 Mdot
.37062 .25269 Mdot
.37113 .25229 Mdot
.37119 .25225 Mdot
.37201 .2516 Mdot
.37232 .25135 Mdot
.37298 .25084 Mdot
.37316 .2507 Mdot
.37387 .25014 Mdot
.3739 .25012 Mdot
.37431 .24979 Mdot
.37483 .24939 Mdot
.37525 .24907 Mdot
.37578 .24865 Mdot
.37654 .24806 Mdot
.37704 .24767 Mdot
.37711 .24762 Mdot
.37743 .24737 Mdot
.37809 .24686 Mdot
.37844 .24659 Mdot
.37883 .24628 Mdot
.3794 .24584 Mdot
.38002 .24536 Mdot
.38053 .24497 Mdot
.38128 .24438 Mdot
.38158 .24415 Mdot
.38229 .2436 Mdot
.38273 .24327 Mdot
.38367 .24254 Mdot
.38404 .24226 Mdot
.3845 .24191 Mdot
.38525 .24133 Mdot
.38603 .24074 Mdot
.38632 .24051 Mdot
.38696 .24002 Mdot
.38738 .2397 Mdot
.38775 .23942 Mdot
.38857 .23879 Mdot
.38887 .23856 Mdot
.38912 .23837 Mdot
.38932 .23822 Mdot
.38995 .23774 Mdot
.39018 .23756 Mdot
.3907 .23717 Mdot
.39178 .23635 Mdot
.3922 .23603 Mdot
.39242 .23587 Mdot
.39289 .23551 Mdot
.39308 .23536 Mdot
.3942 .23452 Mdot
.39476 .2341 Mdot
.39512 .23383 Mdot
.39543 .23359 Mdot
.39586 .23326 Mdot
.39652 .23277 Mdot
.39704 .23238 Mdot
.39731 .23218 Mdot
.39788 .23175 Mdot
.39813 .23156 Mdot
.39816 .23153 Mdot
.39862 .23119 Mdot
.39902 .23089 Mdot
.39909 .23084 Mdot
.39973 .23036 Mdot
.40016 .23004 Mdot
.40066 .22966 Mdot
.40101 .2294 Mdot
.40144 .22908 Mdot
.40213 .22857 Mdot
.40257 .22824 Mdot
.40322 .22776 Mdot
.40356 .2275 Mdot
.40406 .22713 Mdot
.40475 .22662 Mdot
.40493 .22649 Mdot
.40577 .22587 Mdot
.40641 .22539 Mdot
.40709 .22489 Mdot
.4077 .22444 Mdot
.40817 .22409 Mdot
.40872 .22368 Mdot
.40895 .22352 Mdot
.40955 .22307 Mdot
.40993 .2228 Mdot
.41017 .22262 Mdot
.41061 .2223 Mdot
.41114 .22191 Mdot
.41149 .22165 Mdot
.41214 .22117 Mdot
.41229 .22107 Mdot
.41306 .22051 Mdot
.41327 .22035 Mdot
.41355 .22014 Mdot
.41432 .21959 Mdot
.41487 .21918 Mdot
.4151 .21902 Mdot
.41553 .2187 Mdot
.4163 .21814 Mdot
.41681 .21777 Mdot
.41704 .21761 Mdot
.4173 .21741 Mdot
.41758 .21721 Mdot
.41789 .21699 Mdot
.41892 .21624 Mdot
.41921 .21603 Mdot
.42011 .21538 Mdot
.4204 .21517 Mdot
.42071 .21495 Mdot
.42107 .21469 Mdot
.42168 .21425 Mdot
.42181 .21416 Mdot
.42275 .21348 Mdot
.42296 .21333 Mdot
.42368 .21282 Mdot
.42413 .21249 Mdot
.42459 .21217 Mdot
.42469 .21209 Mdot
.42492 .21192 Mdot
.42539 .21159 Mdot
.42562 .21143 Mdot
.42646 .21083 Mdot
.42667 .21068 Mdot
.42746 .21011 Mdot
.42804 .2097 Mdot
.4283 .20951 Mdot
.42881 .20916 Mdot
.42923 .20885 Mdot
.42947 .20868 Mdot
.43026 .20812 Mdot
.43121 .20745 Mdot
.43129 .20739 Mdot
.432 .20689 Mdot
.43211 .20682 Mdot
.43251 .20653 Mdot
.43291 .20625 Mdot
.43363 .20574 Mdot
.43392 .20554 Mdot
.43425 .20531 Mdot
.43467 .20501 Mdot
.43491 .20484 Mdot
.43582 .20421 Mdot
.43627 .20389 Mdot
.43632 .20385 Mdot
.43724 .20321 Mdot
.43727 .20319 Mdot
.43821 .20253 Mdot
.43854 .2023 Mdot
.43919 .20185 Mdot
.43995 .20132 Mdot
.44049 .20094 Mdot
.44078 .20074 Mdot
.44156 .2002 Mdot
.44172 .20009 Mdot
.44268 .19942 Mdot
.44289 .19928 Mdot
.44312 .19912 Mdot
.44405 .19848 Mdot
.44433 .19828 Mdot
.44486 .19792 Mdot
.44553 .19746 Mdot
.44604 .19711 Mdot
.44692 .1965 Mdot
.44735 .1962 Mdot
.44754 .19608 Mdot
.44807 .19571 Mdot
.44883 .19519 Mdot
.44925 .1949 Mdot
.44961 .19465 Mdot
.45028 .1942 Mdot
.45049 .19406 Mdot
.45127 .19353 Mdot
.45195 .19306 Mdot
.45239 .19276 Mdot
.45263 .1926 Mdot
.45329 .19215 Mdot
.45376 .19183 Mdot
.45409 .19161 Mdot
.45466 .19122 Mdot
.45515 .19089 Mdot
.45562 .19057 Mdot
.45602 .1903 Mdot
.45641 .19004 Mdot
.4571 .18958 Mdot
.45771 .18916 Mdot
.45798 .18898 Mdot
.45858 .18858 Mdot
.45919 .18817 Mdot
.45944 .188 Mdot
.45963 .18788 Mdot
.45992 .18768 Mdot
.46066 .18718 Mdot
.46119 .18683 Mdot
.46164 .18653 Mdot
.46165 .18652 Mdot
.46241 .18602 Mdot
.46316 .18551 Mdot
.46339 .18536 Mdot
.46406 .18491 Mdot
.46436 .18472 Mdot
.46475 .18445 Mdot
.46521 .18415 Mdot
.46552 .18395 Mdot
.46664 .18321 Mdot
.46727 .18279 Mdot
.46746 .18267 Mdot
.46805 .18228 Mdot
.4685 .18198 Mdot
.46882 .18177 Mdot
.46951 .18131 Mdot
.46986 .18108 Mdot
.47017 .18088 Mdot
.47046 .18069 Mdot
.47077 .18049 Mdot
.47126 .18017 Mdot
.47206 .17964 Mdot
.47252 .17934 Mdot
.47282 .17914 Mdot
.47328 .17884 Mdot
.47409 .17832 Mdot
.47436 .17814 Mdot
.47481 .17785 Mdot
.47564 .17731 Mdot
.47588 .17715 Mdot
.47634 .17685 Mdot
.4767 .17662 Mdot
.47711 .17635 Mdot
.47757 .17606 Mdot
.47808 .17572 Mdot
.47843 .1755 Mdot
.47888 .17521 Mdot
.4798 .17461 Mdot
.47999 .1745 Mdot
.48053 .17414 Mdot
.48065 .17407 Mdot
.48141 .17358 Mdot
.4817 .1734 Mdot
.48229 .17301 Mdot
.48319 .17244 Mdot
.48353 .17222 Mdot
.48378 .17206 Mdot
.48414 .17183 Mdot
.48495 .17132 Mdot
.48542 .17102 Mdot
.48587 .17073 Mdot
.48671 .17019 Mdot
.48712 .16994 Mdot
.48791 .16943 Mdot
.48815 .16928 Mdot
.4884 .16913 Mdot
.48896 .16877 Mdot
.48968 .16831 Mdot
.49009 .16805 Mdot
.49086 .16757 Mdot
.49152 .16715 Mdot
.49205 .16682 Mdot
.49219 .16673 Mdot
.49268 .16642 Mdot
.49325 .16607 Mdot
.49339 .16598 Mdot
.49399 .1656 Mdot
.49417 .16549 Mdot
.49429 .16542 Mdot
.49514 .16488 Mdot
.49588 .16442 Mdot
.49637 .16412 Mdot
.49687 .16381 Mdot
.49728 .16355 Mdot
.49776 .16325 Mdot
.49846 .16282 Mdot
.49886 .16257 Mdot
.49916 .16239 Mdot
.49965 .16208 Mdot
.50016 .16176 Mdot
.50085 .16134 Mdot
.50126 .16109 Mdot
.50154 .16092 Mdot
.50165 .16085 Mdot
.50216 .16053 Mdot
.50275 .16017 Mdot
.50317 .15992 Mdot
.50329 .15984 Mdot
.50414 .15932 Mdot
.50457 .15905 Mdot
.50493 .15883 Mdot
.5051 .15873 Mdot
.50559 .15843 Mdot
.50578 .15832 Mdot
.50621 .15805 Mdot
.50698 .15758 Mdot
.50706 .15754 Mdot
.50767 .15717 Mdot
.50829 .15679 Mdot
.50842 .15671 Mdot
.50879 .15648 Mdot
.50941 .15611 Mdot
.50998 .15576 Mdot
.51026 .15559 Mdot
.51103 .15513 Mdot
.5115 .15484 Mdot
.51234 .15434 Mdot
.51277 .15408 Mdot
.51285 .15403 Mdot
.51336 .15372 Mdot
.51393 .15338 Mdot
.51413 .15326 Mdot
.51429 .15317 Mdot
.51474 .1529 Mdot
.51484 .15284 Mdot
.51527 .15258 Mdot
.51611 .15208 Mdot
.51674 .1517 Mdot
.51756 .15122 Mdot
.51778 .15108 Mdot
.51828 .15079 Mdot
.51879 .15048 Mdot
.51921 .15024 Mdot
.51926 .1502 Mdot
.51964 .14998 Mdot
.52059 .14942 Mdot
.52096 .14919 Mdot
.52134 .14897 Mdot
.52202 .14857 Mdot
.52221 .14846 Mdot
.52277 .14813 Mdot
.52313 .14792 Mdot
.52383 .14751 Mdot
.52458 .14707 Mdot
.52502 .14681 Mdot
.5254 .14659 Mdot
.52575 .14638 Mdot
.52623 .1461 Mdot
.52691 .1457 Mdot
.52722 .14553 Mdot
.52769 .14525 Mdot
.52804 .14505 Mdot
.52872 .14465 Mdot
.52913 .14442 Mdot
.52925 .14434 Mdot
.52986 .14399 Mdot
.53036 .1437 Mdot
.53065 .14353 Mdot
.5312 .14322 Mdot
.5317 .14293 Mdot
.53204 .14273 Mdot
.53268 .14236 Mdot
.53296 .1422 Mdot
.53354 .14187 Mdot
.53432 .14142 Mdot
.53454 .14129 Mdot
.53507 .14099 Mdot
.53533 .14084 Mdot
.53546 .14076 Mdot
.53569 .14064 Mdot
.53666 .14008 Mdot
.53726 .13974 Mdot
.53781 .13943 Mdot
.53834 .13913 Mdot
.53895 .13878 Mdot
.53913 .13868 Mdot
.54039 .13796 Mdot
.54079 .13774 Mdot
.54109 .13756 Mdot
.54146 .13736 Mdot
.5417 .13722 Mdot
.54225 .13691 Mdot
.54298 .1365 Mdot
.54357 .13617 Mdot
.5439 .13598 Mdot
.54421 .13581 Mdot
.5447 .13553 Mdot
.54512 .1353 Mdot
.54603 .13479 Mdot
.54654 .13451 Mdot
.54697 .13427 Mdot
.54763 .1339 Mdot
.54819 .13359 Mdot
.54883 .13323 Mdot
.54922 .13302 Mdot
.54956 .13283 Mdot
.5501 .13253 Mdot
.55021 .13247 Mdot
.55057 .13227 Mdot
.55125 .1319 Mdot
.55192 .13153 Mdot
.55207 .13145 Mdot
.553 .13093 Mdot
.55341 .13071 Mdot
.55383 .13048 Mdot
.55389 .13045 Mdot
.55468 .13001 Mdot
.55495 .12987 Mdot
.55531 .12967 Mdot
.55605 .12927 Mdot
.55642 .12906 Mdot
.55684 .12883 Mdot
.55739 .12854 Mdot
.55806 .12817 Mdot
.55877 .12779 Mdot
.55922 .12754 Mdot
.5596 .12733 Mdot
.56028 .12697 Mdot
.56032 .12695 Mdot
.56119 .12648 Mdot
.56122 .12646 Mdot
.56219 .12594 Mdot
.56253 .12576 Mdot
.56273 .12565 Mdot
.56332 .12533 Mdot
.56433 .12479 Mdot
.5646 .12465 Mdot
.56485 .12452 Mdot
.56562 .1241 Mdot
.5662 .1238 Mdot
.56643 .12367 Mdot
.56675 .1235 Mdot
.56704 .12335 Mdot
.56755 .12308 Mdot
.56782 .12294 Mdot
.56842 .12262 Mdot
.56911 .12225 Mdot
.56934 .12213 Mdot
.56973 .12193 Mdot
.57036 .12159 Mdot
.57047 .12154 Mdot
.57097 .12127 Mdot
.57134 .12108 Mdot
.57192 .12077 Mdot
.57268 .12038 Mdot
.57281 .12031 Mdot
.57305 .12018 Mdot
.57382 .11978 Mdot
.57479 .11927 Mdot
.57516 .11908 Mdot
.57567 .11882 Mdot
.57588 .11871 Mdot
.57621 .11854 Mdot
.57665 .11831 Mdot
.57674 .11826 Mdot
.57754 .11785 Mdot
.5779 .11766 Mdot
.5784 .1174 Mdot
.57872 .11723 Mdot
.57879 .1172 Mdot
.57927 .11695 Mdot
.57994 .11661 Mdot
.58064 .11625 Mdot
.58089 .11612 Mdot
.5812 .11596 Mdot
.58228 .11541 Mdot
.58262 .11524 Mdot
.58273 .11518 Mdot
.58326 .11491 Mdot
.58379 .11464 Mdot
.58441 .11432 Mdot
.58496 .11404 Mdot
.58532 .11386 Mdot
.58591 .11356 Mdot
.58659 .11321 Mdot
.5869 .11306 Mdot
.58714 .11294 Mdot
.58784 .11258 Mdot
.58819 .11241 Mdot
.58878 .11211 Mdot
.58903 .11199 Mdot
.58912 .11194 Mdot
.58963 .11169 Mdot
.59003 .11149 Mdot
.59028 .11136 Mdot
.59082 .11109 Mdot
.59156 .11072 Mdot
.59161 .11069 Mdot
.59201 .1105 Mdot
.59277 .11012 Mdot
.59292 .11004 Mdot
.59339 .10981 Mdot
.59466 .10918 Mdot
.59501 .10901 Mdot
.59553 .10875 Mdot
.59577 .10863 Mdot
.59621 .10841 Mdot
.59675 .10814 Mdot
.59715 .10795 Mdot
.59776 .10765 Mdot
.598 .10753 Mdot
.59839 .10734 Mdot
.59867 .1072 Mdot
.59892 .10708 Mdot
.59911 .10699 Mdot
.59965 .10672 Mdot
.60057 .10627 Mdot
.60062 .10625 Mdot
.60184 .10566 Mdot
.60219 .10548 Mdot
.603 .1051 Mdot
.60338 .10491 Mdot
.60384 .10469 Mdot
.60453 .10435 Mdot
.60495 .10415 Mdot
.60545 .10391 Mdot
.606 .10365 Mdot
.60619 .10355 Mdot
.60642 .10344 Mdot
.60684 .10324 Mdot
.60715 .10309 Mdot
.60772 .10282 Mdot
.60826 .10256 Mdot
.6089 .10226 Mdot
.60976 .10185 Mdot
.61026 .10161 Mdot
.61074 .10138 Mdot
.61133 .1011 Mdot
.61169 .10093 Mdot
.61221 .10069 Mdot
.61311 .10026 Mdot
.61386 .09991 Mdot
.61427 .09972 Mdot
.61481 .09946 Mdot
.61549 .09914 Mdot
.61612 .09885 Mdot
.61638 .09873 Mdot
.61675 .09856 Mdot
.61688 .09849 Mdot
.61736 .09827 Mdot
.61805 .09795 Mdot
.61823 .09787 Mdot
.61879 .09761 Mdot
.61924 .0974 Mdot
.61967 .0972 Mdot
.62022 .09694 Mdot
.62052 .09681 Mdot
.62116 .09651 Mdot
.62142 .09639 Mdot
.62218 .09604 Mdot
.62239 .09594 Mdot
.62253 .09588 Mdot
.62303 .09565 Mdot
.62369 .09535 Mdot
.62407 .09517 Mdot
.62426 .09509 Mdot
.62502 .09474 Mdot
.62527 .09463 Mdot
.62634 .09414 Mdot
.62653 .09405 Mdot
.62748 .09362 Mdot
.62768 .09353 Mdot
.62866 .09309 Mdot
.62881 .09302 Mdot
.63009 .09245 Mdot
.63048 .09227 Mdot
.63101 .09203 Mdot
.63115 .09197 Mdot
.63152 .09181 Mdot
.63176 .0917 Mdot
.63238 .09142 Mdot
.63294 .09117 Mdot
.63402 .09069 Mdot
.63412 .09065 Mdot
.63443 .09051 Mdot
.63521 .09017 Mdot
.63581 .0899 Mdot
.63606 .08979 Mdot
.63631 .08968 Mdot
.63677 .08948 Mdot
.6375 .08915 Mdot
.63807 .08891 Mdot
.63832 .0888 Mdot
.63869 .08863 Mdot
.6388 .08858 Mdot
.63912 .08845 Mdot
.63967 .0882 Mdot
.64007 .08803 Mdot
.64023 .08796 Mdot
.64056 .08781 Mdot
.64105 .0876 Mdot
.64139 .08745 Mdot
.64207 .08716 Mdot
.64224 .08709 Mdot
.64302 .08675 Mdot
.64306 .08673 Mdot
.64391 .08636 Mdot
.64405 .0863 Mdot
.64528 .08577 Mdot
.6457 .08559 Mdot
.64586 .08553 Mdot
.64669 .08517 Mdot
.64724 .08494 Mdot
.6477 .08474 Mdot
.64815 .08455 Mdot
.64859 .08436 Mdot
.64875 .08429 Mdot
.64937 .08403 Mdot
.64964 .08391 Mdot
.65019 .08368 Mdot
.65063 .0835 Mdot
.65106 .08331 Mdot
.65115 .08328 Mdot
.65195 .08294 Mdot
.65244 .08273 Mdot
.65295 .08252 Mdot
.65327 .08238 Mdot
.65385 .08214 Mdot
.65412 .08203 Mdot
.65466 .0818 Mdot
.65503 .08165 Mdot
.65563 .0814 Mdot
.65601 .08124 Mdot
.65677 .08092 Mdot
.65714 .08077 Mdot
.65775 .08052 Mdot
.65853 .0802 Mdot
.65896 .08002 Mdot
.65916 .07994 Mdot
.65956 .07978 Mdot
.65994 .07962 Mdot
.66031 .07947 Mdot
.66108 .07915 Mdot
.66141 .07901 Mdot
.66176 .07887 Mdot
.66201 .07877 Mdot
.66256 .07855 Mdot
.6627 .07849 Mdot
.66298 .07838 Mdot
.66344 .07819 Mdot
.66422 .07787 Mdot
.66438 .07781 Mdot
.66494 .07758 Mdot
.66531 .07743 Mdot
.66583 .07722 Mdot
.66647 .07696 Mdot
.66687 .07681 Mdot
.66734 .07662 Mdot
.66785 .07641 Mdot
.66814 .0763 Mdot
.66847 .07616 Mdot
.66866 .07609 Mdot
.66898 .07596 Mdot
.6696 .07571 Mdot
.67034 .07542 Mdot
.67079 .07524 Mdot
.67144 .07498 Mdot
.67196 .07478 Mdot
.67258 .07454 Mdot
.67303 .07436 Mdot
.67338 .07422 Mdot
.67408 .07394 Mdot
.67486 .07364 Mdot
.67511 .07354 Mdot
.67544 .07341 Mdot
.67633 .07306 Mdot
.67651 .073 Mdot
.67756 .07259 Mdot
.67811 .07237 Mdot
.67832 .07229 Mdot
.67899 .07204 Mdot
.67953 .07182 Mdot
.67981 .07172 Mdot
.68037 .0715 Mdot
.68049 .07146 Mdot
.68115 .0712 Mdot
.68146 .07109 Mdot
.6822 .0708 Mdot
.68284 .07056 Mdot
.68321 .07042 Mdot
.6835 .07031 Mdot
.68395 .07014 Mdot
.68447 .06994 Mdot
.68505 .06972 Mdot
.68554 .06954 Mdot
.68587 .06941 Mdot
.68595 .06938 Mdot
.6863 .06925 Mdot
.68703 .06898 Mdot
.68738 .06884 Mdot
.68778 .0687 Mdot
.68844 .06845 Mdot
.68934 .06811 Mdot
.68953 .06804 Mdot
.69013 .06782 Mdot
.69068 .06762 Mdot
.69098 .0675 Mdot
.69144 .06733 Mdot
.69209 .06709 Mdot
.69244 .06696 Mdot
.69313 .06671 Mdot
.69392 .06642 Mdot
.69439 .06625 Mdot
.69481 .0661 Mdot
.69499 .06603 Mdot
.69557 .06582 Mdot
.69605 .06564 Mdot
.69652 .06547 Mdot
.69684 .06536 Mdot
.69752 .06511 Mdot
.69782 .065 Mdot
.69836 .06481 Mdot
.69925 .06449 Mdot
.69949 .0644 Mdot
.6998 .06429 Mdot
.70038 .06408 Mdot
.70106 .06384 Mdot
.70181 .06357 Mdot
.70242 .06335 Mdot
.70291 .06318 Mdot
.70355 .06295 Mdot
.70377 .06287 Mdot
.70418 .06273 Mdot
.70474 .06253 Mdot
.70524 .06236 Mdot
.70562 .06222 Mdot
.70631 .06198 Mdot
.70693 .06177 Mdot
.70713 .06169 Mdot
.70829 .06129 Mdot
.70847 .06123 Mdot
.7092 .06097 Mdot
.70948 .06088 Mdot
.70999 .0607 Mdot
.7104 .06056 Mdot
.71086 .0604 Mdot
.71158 .06015 Mdot
.712 .06001 Mdot
.71257 .05981 Mdot
.71277 .05975 Mdot
.71314 .05962 Mdot
.71387 .05937 Mdot
.71425 .05924 Mdot
.7146 .05912 Mdot
.71518 .05893 Mdot
.71567 .05876 Mdot
.71593 .05867 Mdot
.71652 .05847 Mdot
.71664 .05843 Mdot
.71715 .05826 Mdot
.71799 .05798 Mdot
.71836 .05785 Mdot
.7188 .05771 Mdot
.7194 .05751 Mdot
.7197 .05741 Mdot
.72015 .05726 Mdot
.72087 .05702 Mdot
.72129 .05688 Mdot
.72201 .05664 Mdot
.72241 .05651 Mdot
.72306 .0563 Mdot
.7238 .05605 Mdot
.72391 .05602 Mdot
.72439 .05586 Mdot
.72468 .05577 Mdot
.72495 .05568 Mdot
.72571 .05543 Mdot
.72615 .05529 Mdot
.72704 .055 Mdot
.72747 .05486 Mdot
.72803 .05468 Mdot
.72848 .05453 Mdot
.72929 .05427 Mdot
.72984 .0541 Mdot
.73016 .054 Mdot
.73051 .05388 Mdot
.73093 .05375 Mdot
.73122 .05366 Mdot
.73185 .05346 Mdot
.7321 .05338 Mdot
.73217 .05336 Mdot
.73334 .05299 Mdot
.73353 .05293 Mdot
.73467 .05257 Mdot
.7348 .05253 Mdot
.73599 .05216 Mdot
.73649 .052 Mdot
.73654 .05198 Mdot
.73744 .0517 Mdot
.73801 .05153 Mdot
.73823 .05146 Mdot
.73886 .05127 Mdot
.73934 .05112 Mdot
.73964 .05103 Mdot
.74034 .05081 Mdot
.74049 .05077 Mdot
.74146 .05047 Mdot
.74167 .05041 Mdot
.74196 .05032 Mdot
.74273 .05008 Mdot
.7429 .05003 Mdot
.74337 .04989 Mdot
.74394 .04972 Mdot
.74463 .04951 Mdot
.74473 .04948 Mdot
.74532 .04931 Mdot
.74589 .04913 Mdot
.74685 .04885 Mdot
.74745 .04867 Mdot
.7475 .04865 Mdot
.74776 .04858 Mdot
.74846 .04837 Mdot
.74865 .04831 Mdot
.74904 .0482 Mdot
.74976 .04799 Mdot
.74995 .04793 Mdot
.75059 .04774 Mdot
.75087 .04766 Mdot
.75147 .04748 Mdot
.7518 .04739 Mdot
.75243 .04721 Mdot
.75301 .04704 Mdot
.75312 .04701 Mdot
.75386 .04679 Mdot
.75472 .04654 Mdot
.75519 .04641 Mdot
.75549 .04632 Mdot
.75575 .04625 Mdot
.75615 .04613 Mdot
.75659 .04601 Mdot
.75706 .04588 Mdot
.75757 .04573 Mdot
.75821 .04555 Mdot
.75859 .04544 Mdot
.759 .04533 Mdot
.75943 .04521 Mdot
.75968 .04514 Mdot
.76006 .04503 Mdot
.76107 .04475 Mdot
.76148 .04463 Mdot
.76227 .04441 Mdot
.76324 .04414 Mdot
.76352 .04407 Mdot
.76389 .04396 Mdot
.76471 .04374 Mdot
.76492 .04368 Mdot
.76543 .04354 Mdot
.76612 .04335 Mdot
.76657 .04323 Mdot
.76683 .04316 Mdot
.76764 .04294 Mdot
.7679 .04287 Mdot
.76811 .04281 Mdot
.76865 .04267 Mdot
.7691 .04255 Mdot
.76934 .04248 Mdot
.76966 .0424 Mdot
.77006 .04229 Mdot
.77087 .04207 Mdot
.77145 .04192 Mdot
.77201 .04177 Mdot
.77264 .0416 Mdot
.77283 .04155 Mdot
.77338 .04141 Mdot
.77387 .04128 Mdot
.77433 .04116 Mdot
.77497 .04099 Mdot
.77524 .04092 Mdot
.77555 .04084 Mdot
.7765 .04059 Mdot
.7767 .04054 Mdot
.77705 .04045 Mdot
.77734 .04038 Mdot
.77794 .04022 Mdot
.77847 .04008 Mdot
.77861 .04005 Mdot
.77891 .03997 Mdot
.77922 .03989 Mdot
.77978 .03975 Mdot
.77992 .03971 Mdot
.78039 .03959 Mdot
.78052 .03956 Mdot
.78108 .03942 Mdot
.78138 .03934 Mdot
.7821 .03916 Mdot
.78238 .03909 Mdot
.78268 .03901 Mdot
.78336 .03884 Mdot
.78353 .0388 Mdot
.78395 .0387 Mdot
.78425 .03862 Mdot
.78459 .03854 Mdot
.78479 .03849 Mdot
.78519 .03839 Mdot
.7856 .03829 Mdot
.78612 .03816 Mdot
.7867 .03802 Mdot
.78732 .03786 Mdot
.78798 .0377 Mdot
.7883 .03763 Mdot
.78883 .0375 Mdot
.78937 .03736 Mdot
.79003 .0372 Mdot
.79051 .03709 Mdot
.79109 .03695 Mdot
.7915 .03685 Mdot
.79187 .03676 Mdot
.79223 .03668 Mdot
.79239 .03664 Mdot
.79265 .03658 Mdot
.79328 .03643 Mdot
.79353 .03637 Mdot
.79422 .0362 Mdot
.79458 .03612 Mdot
.79497 .03603 Mdot
.79537 .03593 Mdot
.79604 .03578 Mdot
.79624 .03573 Mdot
.79683 .03559 Mdot
.79719 .03551 Mdot
.79739 .03546 Mdot
.79782 .03536 Mdot
.79859 .03518 Mdot
.79872 .03515 Mdot
.79954 .03497 Mdot
.79988 .03489 Mdot
.80032 .03479 Mdot
.8008 .03468 Mdot
.80155 .03451 Mdot
.80205 .03439 Mdot
.8023 .03434 Mdot
.80259 .03427 Mdot
.80345 .03408 Mdot
.80377 .03401 Mdot
.80401 .03395 Mdot
.80432 .03389 Mdot
.80468 .0338 Mdot
.80522 .03368 Mdot
.8053 .03367 Mdot
.80595 .03352 Mdot
.80644 .03341 Mdot
.80718 .03325 Mdot
.80754 .03317 Mdot
.80841 .03298 Mdot
.80853 .03296 Mdot
.80898 .03286 Mdot
.80939 .03277 Mdot
.80991 .03266 Mdot
.81047 .03254 Mdot
.81072 .03248 Mdot
.81145 .03233 Mdot
.8121 .03219 Mdot
.81291 .03202 Mdot
.81316 .03196 Mdot
.81385 .03182 Mdot
.81404 .03178 Mdot
.81468 .03164 Mdot
.81563 .03144 Mdot
.81586 .0314 Mdot
.8165 .03126 Mdot
.8169 .03118 Mdot
.81792 .03097 Mdot
.81821 .03091 Mdot
.81884 .03078 Mdot
.81939 .03067 Mdot
.81979 .03059 Mdot
.82004 .03054 Mdot
.82047 .03045 Mdot
.82077 .03039 Mdot
.82153 .03024 Mdot
.8226 .03002 Mdot
.8233 .02988 Mdot
.82351 .02984 Mdot
.82383 .02978 Mdot
.82457 .02963 Mdot
.82502 .02955 Mdot
.82544 .02946 Mdot
.82598 .02936 Mdot
.82654 .02925 Mdot
.8269 .02918 Mdot
.82742 .02908 Mdot
.82763 .02904 Mdot
.82808 .02895 Mdot
.82845 .02888 Mdot
.82859 .02885 Mdot
.82901 .02877 Mdot
.82946 .02869 Mdot
.82994 .02859 Mdot
.83008 .02857 Mdot
.83065 .02846 Mdot
.83075 .02844 Mdot
.83113 .02837 Mdot
.83208 .02819 Mdot
.83228 .02816 Mdot
.83255 .0281 Mdot
.83299 .02802 Mdot
.83368 .02789 Mdot
.83399 .02784 Mdot
.83444 .02775 Mdot
.8348 .02769 Mdot
.83512 .02763 Mdot
.83538 .02758 Mdot
.83607 .02746 Mdot
.83675 .02733 Mdot
.83688 .02731 Mdot
.83748 .0272 Mdot
.8383 .02705 Mdot
.83839 .02704 Mdot
.83869 .02698 Mdot
.83906 .02692 Mdot
.83957 .02683 Mdot
.83979 .02679 Mdot
.84057 .02665 Mdot
.84072 .02663 Mdot
.84129 .02652 Mdot
.84171 .02645 Mdot
.84197 .02641 Mdot
.84241 .02633 Mdot
.84325 .02618 Mdot
.84366 .02611 Mdot
.84419 .02602 Mdot
.84475 .02593 Mdot
.84481 .02592 Mdot
.84545 .02581 Mdot
.84552 .0258 Mdot
.84616 .02569 Mdot
.8467 .0256 Mdot
.8471 .02553 Mdot
.84748 .02547 Mdot
.84765 .02544 Mdot
.84802 .02538 Mdot
.84859 .02528 Mdot
.84901 .02521 Mdot
.84916 .02519 Mdot
.84974 .02509 Mdot
.85055 .02496 Mdot
.85134 .02483 Mdot
.85179 .02476 Mdot
.85207 .02471 Mdot
.85257 .02463 Mdot
.85316 .02454 Mdot
.85372 .02445 Mdot
.85445 .02433 Mdot
.8548 .02428 Mdot
.85578 .02412 Mdot
.85601 .02409 Mdot
.85648 .02401 Mdot
.85684 .02396 Mdot
.85759 .02384 Mdot
.85768 .02383 Mdot
.85821 .02375 Mdot
.85906 .02362 Mdot
.85922 .02359 Mdot
.85981 .0235 Mdot
.86025 .02344 Mdot
.8611 .02331 Mdot
.8612 .0233 Mdot
.86163 .02323 Mdot
.86215 .02315 Mdot
.86297 .02303 Mdot
.86343 .02297 Mdot
.86429 .02284 Mdot
.86443 .02282 Mdot
.86547 .02267 Mdot
.86594 .0226 Mdot
.86637 .02254 Mdot
.8669 .02247 Mdot
.86745 .02239 Mdot
.86791 .02232 Mdot
.86833 .02227 Mdot
.86875 .02221 Mdot
.86984 .02205 Mdot
.87027 .02199 Mdot
.87059 .02195 Mdot
.87104 .02189 Mdot
.87109 .02188 Mdot
.8716 .02181 Mdot
.87195 .02177 Mdot
.87216 .02174 Mdot
.87245 .0217 Mdot
.87324 .02159 Mdot
.87375 .02153 Mdot
.87458 .02141 Mdot
.87491 .02137 Mdot
.87521 .02133 Mdot
.8756 .02128 Mdot
.87616 .02121 Mdot
.87643 .02117 Mdot
.87671 .02114 Mdot
.87692 .02111 Mdot
.87784 .02099 Mdot
.87821 .02094 Mdot
.87885 .02086 Mdot
.87928 .02081 Mdot
.87987 .02074 Mdot
.88055 .02065 Mdot
.88098 .0206 Mdot
.8815 .02053 Mdot
.88226 .02044 Mdot
.88278 .02038 Mdot
.88332 .02031 Mdot
.88374 .02026 Mdot
.88402 .02023 Mdot
.88464 .02015 Mdot
.88578 .02002 Mdot
.88621 .01997 Mdot
.88626 .01996 Mdot
.88683 .0199 Mdot
.88737 .01983 Mdot
.88792 .01977 Mdot
.88831 .01973 Mdot
.88872 .01968 Mdot
.88877 .01967 Mdot
.88939 .0196 Mdot
.88979 .01956 Mdot
.89017 .01952 Mdot
.89039 .01949 Mdot
.89111 .01941 Mdot
.89125 .0194 Mdot
.8916 .01936 Mdot
.89264 .01924 Mdot
.89312 .01919 Mdot
.89357 .01914 Mdot
.89398 .0191 Mdot
.89417 .01908 Mdot
.8945 .01905 Mdot
.89513 .01898 Mdot
.89562 .01893 Mdot
.89596 .01889 Mdot
.89626 .01886 Mdot
.89663 .01882 Mdot
.89682 .0188 Mdot
.89753 .01873 Mdot
.89795 .01869 Mdot
.89807 .01868 Mdot
.89834 .01865 Mdot
.89916 .01857 Mdot
.89941 .01854 Mdot
.89969 .01851 Mdot
.90012 .01847 Mdot
.90067 .01842 Mdot
.90129 .01836 Mdot
.90182 .0183 Mdot
.90214 .01827 Mdot
.90274 .01822 Mdot
.90298 .01819 Mdot
.90353 .01814 Mdot
.90448 .01805 Mdot
.90487 .01802 Mdot
.9055 .01796 Mdot
.90588 .01792 Mdot
.90628 .01789 Mdot
.90703 .01782 Mdot
.90719 .0178 Mdot
.90788 .01774 Mdot
.90828 .01771 Mdot
.90891 .01765 Mdot
.90921 .01763 Mdot
.90984 .01757 Mdot
.91024 .01754 Mdot
.91037 .01753 Mdot
.9115 .01743 Mdot
.91196 .01739 Mdot
.91211 .01738 Mdot
.91262 .01734 Mdot
.91319 .01729 Mdot
.91325 .01729 Mdot
.91394 .01723 Mdot
.91437 .01719 Mdot
.91498 .01715 Mdot
.9153 .01712 Mdot
.91568 .01709 Mdot
.91617 .01705 Mdot
.91662 .01702 Mdot
.91691 .017 Mdot
.91759 .01694 Mdot
.91777 .01693 Mdot
.91823 .0169 Mdot
.91881 .01685 Mdot
.91944 .0168 Mdot
.91961 .01679 Mdot
.92048 .01673 Mdot
.92077 .01671 Mdot
.92077 .01671 Mdot
.92127 .01667 Mdot
.92177 .01664 Mdot
.92248 .01659 Mdot
.92317 .01654 Mdot
.92364 .01651 Mdot
.92402 .01648 Mdot
.92454 .01645 Mdot
.92496 .01642 Mdot
.92563 .01637 Mdot
.92648 .01632 Mdot
.92673 .0163 Mdot
.92714 .01628 Mdot
.92754 .01625 Mdot
.92804 .01622 Mdot
.92855 .01619 Mdot
.92908 .01616 Mdot
.92934 .01614 Mdot
.92985 .01611 Mdot
.93013 .01609 Mdot
.93111 .01603 Mdot
.93132 .01602 Mdot
.93228 .01597 Mdot
.93258 .01595 Mdot
.93328 .01591 Mdot
.93343 .0159 Mdot
.9339 .01588 Mdot
.93455 .01584 Mdot
.93461 .01584 Mdot
.93521 .0158 Mdot
.93556 .01579 Mdot
.93617 .01575 Mdot
.93658 .01573 Mdot
.93682 .01572 Mdot
.93758 .01568 Mdot
.93803 .01566 Mdot
.93845 .01564 Mdot
.93935 .0156 Mdot
.93963 .01558 Mdot
.9402 .01556 Mdot
.94053 .01554 Mdot
.9409 .01552 Mdot
.94165 .01549 Mdot
.94186 .01548 Mdot
.94228 .01546 Mdot
.94255 .01545 Mdot
.94314 .01542 Mdot
.94385 .01539 Mdot
.94436 .01537 Mdot
.94442 .01537 Mdot
.94518 .01534 Mdot
.94541 .01533 Mdot
.94608 .0153 Mdot
.94644 .01529 Mdot
.94697 .01527 Mdot
.94755 .01525 Mdot
.94764 .01524 Mdot
.9483 .01522 Mdot
.94864 .01521 Mdot
.94921 .01519 Mdot
.95013 .01516 Mdot
.95061 .01514 Mdot
.95103 .01513 Mdot
.95136 .01512 Mdot
.95161 .01511 Mdot
.95201 .01509 Mdot
.95267 .01507 Mdot
.95311 .01506 Mdot
.95351 .01505 Mdot
.95438 .01502 Mdot
.95465 .01502 Mdot
.95526 .015 Mdot
.95598 .01498 Mdot
.95662 .01496 Mdot
.95686 .01496 Mdot
.9573 .01495 Mdot
.958 .01493 Mdot
.95819 .01493 Mdot
.95882 .01491 Mdot
.95947 .0149 Mdot
.95991 .01489 Mdot
.96052 .01487 Mdot
.96083 .01487 Mdot
.96125 .01486 Mdot
.96215 .01484 Mdot
.96239 .01484 Mdot
.96324 .01482 Mdot
.96368 .01482 Mdot
.96432 .01481 Mdot
.96465 .0148 Mdot
.96526 .01479 Mdot
.96611 .01478 Mdot
.96631 .01478 Mdot
.96713 .01477 Mdot
.96758 .01476 Mdot
.96843 .01475 Mdot
.96871 .01475 Mdot
.96903 .01475 Mdot
.96959 .01474 Mdot
.97035 .01474 Mdot
.97066 .01473 Mdot
.97101 .01473 Mdot
.97179 .01473 Mdot
.97191 .01473 Mdot
.97318 .01472 Mdot
.97337 .01472 Mdot
.97382 .01472 Mdot
.97476 .01472 Mdot
.9749 .01472 Mdot
.97544 .01472 Mdot
.97597 .01472 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00230284) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H200000?l0n_3Vb03jl>H10?ooo`00803jl>H200000080n_3V0P0000030?[`iP800000
0`3jl>H2000000<0n_3V00L000000?[`iP00000000000?[`iP000000n_3V00@000000P3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002@3jl>H01000
0000n_3V0?[`iP3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP00
0000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000030?[`iP800000o`3j
l>K80?[`iP40oooo000P0?[`iP80000000<0n_3V000000000000103jl>H2000000<0n_3V0P000005
0?[`iP80000000<0n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H000000000000=0?[`iP8000000P3jl>H2000000040?[`iP000000
00000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V000000000000o`3j
l>K=0?[`iP40oooo000P0?[`iPD00000103jl>H2000000<0n_3V1P0000001P3jl>H000000000003j
l>H000000?[`iP80000000<0n_3V0000000000000`0000020?[`iP80000000<0n_3V000000000000
0P3jl>H2000000030?[`iP000000000000/0n_3V0`0000030?[`iP80000000@0n_3V000000000000
n_3V0P0000000`3jl>H000000?[`iP02000000T0n_3V1@00000:0?[`iP80000000<0n_3V00000000
0000o`3jl>K=0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0P3jl>H2000000060?[`iP00000000000?[`iP000000n_3V0P0000040?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000000:0?[`iP<00000103jl>H20000
00040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000H0?[`iP@00000o`3jl>K>
0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H40000
00030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H20000
00D0n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P00003o0?[`i]00n_3V0@3oool00200
n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09P3jl>H200000?l0
n_3Vc`3jl>H10?ooo`007`3jl>H6000000@0n_3V0P00000_0?[`iPD00000:@3jl>H300000?l0n_3V
c@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`
iP40oooo000m0?[`iP@00000o`3jl>Ko0?[`iQP0n_3V0@3oool00400n_3V0P00003o0?[`i_l0n_3V
5`3jl>H10?ooo`00803jl>H6000000050?[`iP00000000000000003jl>H00`0000020?[`iP<00000
0`3jl>H4000000<0n_3V0P000000103jl>H000000000003jl>H5000000<0n_3V3000000_0?[`iP<0
0000103jl>H200000?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP8000000P3jl>H010000000n_3V0000000000030?[`iP050000003jl>H000000000
003jl>H00`0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP8000008P3jl>H50000
00T0n_3V0P0000000`3jl>H00000000000030?[`iP800000o`3jl>K90?[`iP40oooo000R0?[`iP80
0000103jl>H2000000030?[`iP00000000000080n_3V0P0000040?[`iP8000001@3jl>H200000080
n_3V0P0000020?[`iP800000103jl>H200000080n_3V0P0000030?[`iP800000<03jl>H200000003
0?[`iP00000000000?l0n_3VcP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000
000000020?[`iP800000103jl>H6000000030?[`iP00000000000080n_3V0P0000020?[`iP800000
1@3jl>H5000000<0n_3V0P00000R0?[`iPD000002@3jl>H2000000030?[`iP00000000000?l0n_3V
cP3jl>H10?ooo`008P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP800000103j
l>H200000080n_3V0P000000103jl>H000000000003jl>H300000080n_3V0`0000000`3jl>H00000
0?[`iP040?[`iP8000000`3jl>H200000300n_3V1000003o0?[`i/l0n_3V0@3oool00280n_3V0P00
00030?[`iPD000000P3jl>H5000000<0n_3V100000030?[`iP80000000<0n_3V0000000000001000
00000`3jl>H00000000000020?[`iP@00000103jl>H200000300n_3V0P00003o0?[`i]40n_3V0@3o
ool00280n_3V0P00000;0?[`iP8000008P3jl>H200000340n_3V0P00003o0?[`i]00n_3V0@3oool0
0200n_3V1P0000090?[`iP800000803jl>H400000380n_3V0`00003o0?[`i/h0n_3V0@3oool00?l0
n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00
o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H1
0?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V000000000000o`3jl>Ko0?[`
iR<0n_3V0@3oool002L0n_3V00@000000?[`iP000000n_3V0P0000020?[`iP030000003jl>H0n_3V
00<00000o`3jl>Ko0?[`iR@0n_3V0@3oool00200n_3V0`0000000`3jl>H000000000000200000005
0?[`iP000000n_3V0000003jl>H00`0000020?[`iP030000003jl>H0000001T0n_3V0`00003L0?[`
iP@00000103jl>H;000000@0n_3V0`0000020?[`iPH000000`3jl>H300000080n_3V1P0000020?[`
iP@000000P3jl>H3000000040?[`iP0000000000000000P0n_3V100000000`3jl>H0000000000002
0?[`iP@000000P3jl>H5000000070?[`iP00000000000000003jl>H000000?[`iP03000001P0n_3V
0`0000040?[`iP8000001@3jl>H3000000@0n_3V0`0000030?[`iPD000000`3jl>H3000000@0n_3V
0`0000030?[`iPD000000`3jl>H3000000@0n_3V1000001Z0?[`iP40oooo000Q0?[`iP80000000<0
n_3V0000000000001@000000103jl>H000000000000000020?[`iP80000000<0n_3V000000000000
2@3jl>H5000000T0n_3V00<000000?[`iP3jl>H00P00003L0?[`iP800000103jl>H200000080n_3V
0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000040?[`iP80
00000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H20000
00030?[`iP000000000000X0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
0080n_3V0P0000040?[`iP80000000<0n_3V0000003jl>H00P0000090?[`iPD000002P3jl>H20000
00030?[`iP000000000000<0n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000050?[`iP030000003jl>H0n_3V008000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000050?[`iP80000000<0n_3V000000000000103jl>H20000
06/0n_3V0@3oool00280n_3V0`00000[0?[`iP800000g03jl>H2000000@0n_3V0P0000020?[`iP80
00000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000
000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V
00800000603jl>H2000000030?[`iP000000000000T0n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000`3jl>H2000000L0n_3V0P0000020?[`iP80000000<0n_3V0000
000000000`3jl>H2000000@0n_3V0P000000103jl>H000000000003jl>H6000006X0n_3V0@3oool0
0280n_3V0`00000J0?[`iPD00000303jl>H200000=`0n_3V100000030?[`iPD000000P3jl>H20000
00D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000000000000?[`iP02
00000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5
000000X0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP000000000000@0n_3V0P0000060?[`iP8000000P3jl>H2000000030?[`iP000000
000000@0n_3V0P0000030?[`iP80000000D0n_3V000000000000n_3V000000020?[`iP800000J`3j
l>H10?ooo`008@3jl>H2000000030?[`iP000000000002P0n_3V0`00003M0?[`iP80000000<0n_3V
0000000000001@3jl>H200000080n_3V0`000000103jl>H000000?[`iP3jl>H2000000H0n_3V0P00
00040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000030?[`iP00
0000000000X0n_3V0`000000103jl>H000000000003jl>H200000080n_3V0P0000020?[`iP<00000
00<0n_3V0000003jl>H00P0000000`3jl>H000000?[`iP02000001P0n_3V0P0000000`3jl>H00000
000000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000D0n_3V
0P0000030?[`iP<000000`3jl>H2000000030?[`iP000000000000D0n_3V0P0000030?[`iP<00000
0`3jl>H010000000n_3V00000000001[0?[`iP40oooo000P0?[`iP<0000000@0n_3V000000000000
0000:@3jl>H200000=`0n_3V0P0000000`3jl>H00000000000020?[`iP@000000P3jl>H300000004
0?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@0000020?[`iP@00000103jl>H40000
0080n_3V1@00000;0?[`iP<0000000<0n_3V0000000000000P3jl>H400000080n_3V0`0000000`3j
l>H0000000000007000001T0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000050?[`
iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H010000000n_3V00000000001[0?[`iP40oooo001=0?[`
iP030000003jl>H0n_3V00800000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<0?[`
iP8000008P3jl>H200000080n_3V0P00000^0?[`iP80000000<0n_3V0000000000002@3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000000P3jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000<0n_3V0`00001[0?[`
iP40oooo001>0?[`iP<00000g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H2000000H0
n_3V0P00000I0?[`iP<0000000<0n_3V0000000000000P00000^0?[`iP<000002`3jl>H3000000@0
n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000D0
n_3V0P00001[0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3o
ool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0
n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko
0?[`iUT0n_3V0@3oool002H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP0000000000
0?l0n_3Vo`3jl>HS0?[`iP40oooo000W0?[`iP050000003jl>H000000?[`iP0000000P3jl>H01000
0000n_3V0?[`iP0000020?[`iP030000003jl>H0n_3V0?l0n_3Vo`3jl>HR0?[`iP40oooo000P0?[`
iP<0000000<0n_3V0000000000000P000000103jl>H000000?[`iP0000020?[`iP040000003jl>H0
n_3V00000080n_3V00<000000?[`iP3jl>H05`3jl>H300000=`0n_3V100000040?[`iP/00000103j
l>H300000080n_3V1P0000030?[`iP<000000P3jl>H600000080n_3V100000020?[`iP<0000000<0
n_3V0000000000001P00000J0?[`iPD000000`3jl>H3000000@0n_3V0`0000040?[`iP<00000/`3j
l>H10?ooo`008@3jl>H2000000030?[`iP000000000000D0000000D0n_3V00000000000000000?[`
iP04000000/0n_3V1@0000090?[`iP80000000<0n_3V000000000000g03jl>H2000000@0n_3V0P00
00020?[`iP8000000P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000
103jl>H200000080n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080
n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000;0?[`iPD000002@3jl>H20000
00D0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000;80n_3V0@3oool00280n_3V0`00000X0?[`iP80000000<0n_3V00000000
0000g03jl>H2000000@0n_3V0P0000020?[`iP8000000P3jl>H2000000D0n_3V0P0000060?[`iP80
0000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3jl>H0
0000000000030?[`iP@000006P3jl>H2000000@0n_3V0P0000000`3jl>H00000000000020?[`iP80
000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000;80n_3V0@3oool00280n_3V
0`0000090?[`iP030000003jl>H0n_3V00h0n_3V1@0000090?[`iP80000000<0n_3V000000000000
g03jl>H4000000<0n_3V1@0000020?[`iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP800000
1P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP@0
00003@3jl>H5000000/0n_3V0P0000030?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H000000000002b0?[`iP40oooo000Q0?[`iP800000
00<0n_3V0000000000009`3jl>H2000000030?[`iP00000000000=`0n_3V0P0000000`3jl>H00000
000000050?[`iP8000000P3jl>H3000000040?[`iP000000n_3V0?[`iP8000001P3jl>H2000000@0
n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80000000@0n_3V00000000
0000n_3V0P0000020?[`iP800000703jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000;80n_3V0@3oool00200
n_3V0`000000103jl>H0000000000000000V0?[`iP80000000<0n_3V000000000000g03jl>H20000
00030?[`iP00000000000080n_3V100000020?[`iP<0000000@0n_3V000000000000n_3V1@000002
0?[`iP@000000`3jl>H500000080n_3V100000040?[`iP@000000P3jl>H5000000<0n_3V1@00000I
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V000000000000/P3jl>H10?ooo`00C@3jl>H20000
00030?[`iP00000000000=`0n_3V0P0000000`3jl>H000000000000@0?[`iP800000303jl>H20000
03P0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H000000000002b0?[`iP40oooo001>0?[`iP<0
0000g03jl>H500000140n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P00000a0?[`iP<0
0000103jl>H3000000@0n_3V0`0000040?[`iP<00000/`3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool001d0n_3V8`3oon02000004D0oooP0P0000040?oo
h0800000103oon02000004@0oooP1@0000130?ooh0D000000P3oon02000000@0oooP0P0000140?oo
h0@00000A03oon04000000<0oooP0P0000040?ooh0800000A@3oon02000002L0oooP7P3jl>H10?oo
o`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon000000203oon00
10000000oooP0?ooh00000150?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon001`3o
on0010000000oooP0?ooh00000130?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00
2@3oon0010000000oooP0?ooh00000130?ooh0040000003oon00oooP000002H0oooP7P3jl>H10?oo
o`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon0000002`3oon00
0`000000oooP0?ooh0130?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon002P3oon00
0`000000oooP0?ooh0120?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon002`3oon00
0`000000oooP0?ooh0130?ooh0030000003oon00oooP02D0oooP7P3jl>H10?ooo`007@3jl>HR0?oo
h0040000003oon00oooP000004<0oooP00@000000?ooh03oon0000002@3oon02000004H0oooP00<0
00000?ooh03oon00A@3oon000`000000oooP0?ooh0080?ooh0800000AP3oon000`000000oooP0?oo
h0150?ooh0030000003oon00oooP00P0oooP0P0000170?ooh0030000003oon00oooP02@0oooP7P3j
l>H10?ooo`007@3jl>HR0?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon000000
2@3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00
203oon000`000000oooP0?ooh0130?ooh0040000003oon00oooP000004@0oooP00@000000?ooh03o
on0000002@3oon000`000000oooP0?ooh0130?ooh0040000003oon00oooP000002H0oooP7P3jl>H1
0?ooo`007@3jl>HS0?ooh0800000A@3oon02000000X0oooP0`0000140?ooh0800000AP3oon020000
00X0oooP0`0000140?ooh0800000AP3oon02000000X0oooP0`0000140?ooh08000009`3oon0N0?[`
iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP
7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh?l00000jP00000K0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?oo
h03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000
oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000
oooP0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01:0?ooh0030000
003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh01;0?ooh0030000
003oon00oooP04X0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon3V0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPb03oon0C0000
00/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on00o`3oon2i0?ooh2<000002P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon0300000?l0oooP[`3oon0B000001X0003o00<000000?ooh03oon001P3oon03000001/0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPY`3oon0B000000P0003o6P00
000;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPX03oon0@000000T0003o4000000B0<f5?`/0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2J0?ooh0`000002P000?l;0000
0200cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh9@0oooP2P0000080000o`/00000:P3=QCl;0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPS`3oon09000000H0003o
2`00000b0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00o`3oon2:0?ooh0L000001`000?l:000003T0cHDo2`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh8D0oooP1`000005
0000o`X00000@03=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0?l0oooPP@3oon07000000@0003o2P0000150<f5?`/0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1m0?ooh0L0
000010000?l9000004X0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh7T0oooP1`0000040000o`P00000C`3=QCl;0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPM@3o
on07000000@0003o1`00001D0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00o`3oon1b0?ooh0H0000010000?l7000005P0cHDo2`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?oo
h6h0oooP1P0000040000o`L00000G03=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPJP3oon06000000@0003o1`00001P0<f5?`/0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon1W0?ooh0D0000010000?l7000006@0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon0300000?l0oooPI03oon04000000@0003o1`00001X0<f5?`T0oooP0`00
000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh640oooP10000003
0000o`P00000J`3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0?l0oooPGP3oon04000000<0003o1`00001_0<f5?`/0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1K0?ooh0@0
00000`000?l700000780cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh5P0oooP1@0000020000o`L00000M@3=QCl;0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPE@3o
on05000000<0003o1@00001i0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00o`3oon1B0?ooh0D000000`000?l6000007/0cHDo2`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?oo
h4l0oooP1@0000030000o`D00000O`3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPC@3oon04000000<0003o1@0000220<f5?`/0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon1:0?ooh0D000000P000?l6000008@0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh4L0oooP1@0000030000o`D00000Q`3=
QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPA@3oon0500000080003o1@00002:0<f5?`/0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon120?ooh0D000000`000?l50000
08`0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0
oooP00<000000?ooh03oon00o`3oon100?ooh0@000000`000?l5000008l0cHDo2`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh003
0000003oon00oooP0?l0oooP?@3oon0500000080003o1@00002B0<f5?`/0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon04000000P0
oooPo`00000f000000<0003oV@0000080?ooh0@000006`3oon0N0?[`iP40oooo000M0?[`iPd0oooP
00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh?l0<j7:<00cXLX400000080
003o1@00002R0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000
003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon3o03>QbRh0<j7:100000020000o`@0
0000Y@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP
00<000000?ooh03oon002@3oon3o03>QbR/0<j7:1@0000020000o`@00000Y`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7::@0c
XLX500000080003o1000002Y0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooPo`0cXLXW03>QbP@000000`000?l300000:`0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>Q
bRD0<j7:100000020000o`@00000[P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:8P0cXLX500000080003o1000002`0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
o`0cXLXP03>QbPD000000P000?l400000;80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbQh0<j7:1@0000020000o`<00000]@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh?l0<j7:700cXLX500000080003o0`00002g0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLXJ03>QbPD000000P000?l30000
0;T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon3o03>QbQP0<j7:1@0000020000o`<00000^`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:5P0cXLX500000080003o
0`00002m0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPo`0cXLXD03>QbPD000000P000?l300000;l0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbQ80<j7:1@000002
0000o`800000`P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon030000
00T0oooPo`0cXLX@03>QbPD000000P000?l300000<40oooP0`00000K0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:3P0cXLX500000080003o0`0000350?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
o`0cXLX<03>QbPD000000P000?l300000<L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbPX0<j7:1@0000020000o`<00000b@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh?l0<j7:200cXLX500000080003o0`00003;0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLX703>QbP@000000P000?l30000
0<d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon3o03>QbPD0<j7:100000020000o`<00000c`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:0`0cXLX400000080003o
0`00003A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPo`0cXLX103>QbP@000000P000?l300000=<0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3n03>QbP@000000P000?l3
00000=D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon3l03>QbP@000000P000?l300000=L0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3j03>QbP@000000P000?l300000=T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon3i03>QbP<000000P000?l400000=X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3g03>QbP@0000000<0003o0000000000000P00
003L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooPm@0cXLX400000080003o0`00003N0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPm00cXLX300000080003o0`00003P0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon3b03>QbP<0
00000P000?l400000=l0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh?00<j7:100000000`000?l000000000000200000><0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3_03>QbP<000000P00
0?l300000>D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon3]03>QbP<000000P000?l300000>L0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3[03>QbP@0000000<0003o0000
000000000P00003X0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooPjP0cXLX300000080003o0`00003Z0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPj00cXLX300000080003o
0`00003/0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPiP0cXLX300000080003o1000003]0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPi@0cXLX3000000030000o`000000
000000800000k`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh><0<j7:0`0000020000o`<00000l@3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh>40<j7:100000000`000?l0
00000000000200000?80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon3P03>QbP<000000P000?l300000?@0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3N03>QbP<000000P00
0?l400000?D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon3M03>QbP<0000000<0003o0000000000000P00003g0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPf`0cXLX30000
0080003o0`00003i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooPfP0cXLX3000000030000o`000000000000800000nP3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooPf00cXLX300000080003o
0`00003j0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on3G03>QbP8000000P000?l400000?d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon3E03>QbP<0000000<0003o0000000000000P00003o
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooPe00cXLX200000080003o0`00003o0?ooh080oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3B03>QbP<0000000<0003o00000000
00000P00003o0?ooh0<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon3A03>QbP8000000P000?l400000?l0oooP103oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh<l0<j7:0`00
00000`000?l000000000000200000?l0oooP1P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh<h0<j7:0`0000000`000?l0000000000002
00000?l0oooP1`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh<`0<j7:0`0000020000o`<00000o`3oon090?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPb`0cXLX300000003
0000o`000000000000800000o`3oon0:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPbP0cXLX3000000040000o`000000000000000?l0
oooP303oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh<P0<j7:0`0000020000o`<00000o`3oon0=0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPa`0cXLX3000000040000o`00
0000000000000?l0oooP3`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh<D0<j7:100000000`000?l000000000003o0?ooh140oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP100000070?ooh0030000003oon00
oooP00T0oooPa00cXLX300000080003o0P00003o0?ooh180oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iPd0oooP00<000000?ooh03oon00203oon000`000000oooP0?ooh0090?oo
h<80<j7:1000000010000?l0000000000000003o0?ooh1<0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iPh0oooP00<000000?ooh03oon001`3oon04000000P0oooP`@0cXLX40000
00030000o`00000000000?l0oooP4P3oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh003
0000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon3003>QbP<000000P000?l200000?l0
oooP5P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP
0?ooh00000070?ooh0030000003oon00oooP00T0oooP_P0cXLX4000000040000o`00000000000000
0?l0oooP5`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0
oooP00<000000?ooh03oon002@3oon2m03>QbP<000000P000?l200000?l0oooP6@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh;/0<j7:
1000000010000?l0000000000000003o0?ooh1X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2j03>QbP@0000000<0003o000000000000
o`3oon0L0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP^@0cXLX300000080003o0P00003o0?ooh1d0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2h03>QbP<0000000@0003o
0000000000000000o`3oon0N0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP]P0cXLX300000080003o0P00003o0?ooh200oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2e03>Q
bP<0000000@0003o0000000000000000o`3oon0Q0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP]00cXLX200000080003o0`00003o0?oo
h280oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2b03>QbP<0000000@0003o0000000000000000o`3oon0T0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP/@0cXLX300000004
0000o`000000000000000?l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh;00<j7:0P0000020000o`<00000o`3oon0V0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
[P0cXLX3000000040000o`000000000000000?l0oooP:03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:d0<j7:0P0000020000o`<00000
o`3oon0Y0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3o
on2/03>QbP80000000<0003o0000000000000P00003o0?ooh2P0oooP0`00000K0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:X0<j7:0`00000010000?l0000000000000
003o0?ooh2`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon2Y03>QbP8000000P000?l300000?l0oooP;@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:P0<j7:0P0000000`00
0?l000000000000200000?l0oooP;P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh:H0<j7:0`00000010000?l0000000000000003o0?oo
h300oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2U03>QbP<0000000@0003o0000000000000000o`3oon0a0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPY00cXLX200000080
003o0`00003o0?ooh380oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon2S03>QbP80000000@0003o0000000000000000o`3oon0d0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
XP0cXLX2000000040000o`000000000000000?l0oooP=@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:00<j7:0P0000020000o`<00000
o`3oon0f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPW`0cXLX2000000030000o`000000000000800000o`3oon0g0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPWP0cXLX2
000000030000o`000000000000800000o`3oon0h0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPW@0cXLX2000000040000o`0000000000
00000?l0oooP>P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh9`0<j7:00<000000000o`000?l00`00003o0?ooh3/0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2K03>QbP03
000000000?l0000000<00000o`3oon0l0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPV@0cXLX2000000040000o`000000000000000?l0
oooP?P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP
V00cXLX2000000040000o`000000000000000?l0oooP?@3oon03000001/0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPUP0cXLX3000000040000o`000000000000000?l0
oooP@03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh9D0<j7:0`00000010000?l0000000000000003o0?ooh440oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2D03>QbP800000
0P000?l300000?l0oooP@P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh9<0<j7:0P00000010000?l0000000000000003o0?ooh4@0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on2B03>QbP80000000@0003o0000000000000000o`3oon150?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPT@0cXLX2000000040000o`00
0000000000000?l0oooPAP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh8l0<j7:0`00000010000?l0000000000000003o0?ooh4L0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on2>03>QbP<0000000@0003o0000000000000000o`3oon180?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPS@0cXLX3000000040000o`00
0000000000000?l0oooPB@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh8`0<j7:0`0000000`000?l000000000003o0?ooh4/0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2;
03>QbP<0000000<0003o000000000000o`3oon1<0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPRP0cXLX200000080003o0P00003o0?oo
h4d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2903>QbP80000000@0003o0000000000000000o`3oon1>0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPQ`0cXLX300000004
0000o`000000000000000?l0oooPC`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh8H0<j7:0`00000010000?l0000000000000003o0?oo
h500oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh8D0
<j7:0`0000000`000?l000000000003o0?ooh500oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh8@0<j7:0`0000000`000?l000000000003o0?ooh5<0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on2303>QbP<0000000<0003o000000000000o`3oon1D0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPPP0cXLX3000000030000o`000000
00000?l0oooPE@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh840<j7:0`0000000`000?l000000000003o0?ooh5H0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1o03>QbP<0
00000P000?l200000?l0oooPE`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh7h0<j7:0`00000010000?l0000000000000003o0?ooh5P0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon1m03>QbP<0000000<0003o000000000000o`3oon1J0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPO00cXLX3000000030000o`00
000000000?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh7/0<j7:0`0000000`000?l000000000003o0?ooh5`0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1j03>Q
bP<0000000<0003o000000000000o`3oon1M0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPN@0cXLX3000000030000o`00000000000?l0
oooPGP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh7P0<j7:0`0000000`000?l000000000003o0?ooh5l0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1g03>QbP<0000000<0
003o000000000000o`3oon1P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H?
0?ooh0<000001P3oon000`000000oooP0?ooh0090?ooh7D0<j7:0`0000020000o`800000o`3oon1Q
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H@0?ooh0030000003oon00oooP
00D0oooP00<000000?ooh03oon002@3oon1d03>QbP<0000000@0003o0000000000000000o`3oon1R
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0D000001P3oon040000
00P0oooPL`0cXLX3000000040000o`000000000000000?l0oooPH03oon04000001/0oooP7P3jl>H1
0?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon1b
03>QbP<0000000<0003o000000000000o`3oon1U0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>H>0?ooh0030000003oon00000000L0oooP00<000000?ooh03oon002@3oon1a03>Q
bP<0000000<0003o000000000000o`3oon1V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>H?0?ooh08000001`3oon000`000000oooP0?ooh0090?ooh700<j7:0`0000000`000?l0
00000000003o0?ooh6L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon1_03>QbP<0000000<0003o000000000000o`3oon1X0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPKP0c
XLX3000000030000o`00000000000?l0oooPJ@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh6d0<j7:0`0000000`000?l000000000003o
0?ooh6X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1/03>QbP<0000000<0003o000000000000o`3oon1[0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPJ`0cXLX300000003
0000o`00000000000?l0oooPK03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh0090?ooh6X0<j7:0`0000000`000?l000000000003o0?ooh6d0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on1Y03>QbP<0000000<0003o000000000000o`3oon1^0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPJ00cXLX200000080003o0P00003o
0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1W03>QbP80000000@0003o0000000000000000o`3oon1`0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPIP0cXLX20000
00040000o`000000000000000?l0oooPL@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh6D0<j7:0P00000010000?l0000000000000003o
0?ooh780oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1T03>QbP80000000@0003o0000000000000000o`3oon1c0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon1S03>QbP80000000<0003o0000
00000000o`3oon1c0?ooh0<000006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon1Q03>QbP<0000000<0003o000000000000o`3oon1f0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPH00cXLX3000000030000
o`00000000000?l0oooPM`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh5l0<j7:0`0000000`000?l000000000003o0?ooh7P0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1N
03>QbP<0000000<0003o000000000000o`3oon1i0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPG@0cXLX3000000030000o`0000000000
0?l0oooPNP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh5`0<j7:0`0000000`000?l000000000003o0?ooh7/0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1K03>QbP<00000
00<0003o000000000000o`3oon1l0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooPFP0cXLX3000000030000o`00000000000?l0oooPO@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh5T0<j7:0`0000000`000?l000000000003o0?ooh7h0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1H03>QbP<0000000<0003o0000
00000000o`3oon1o0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooPE`0cXLX3000000030000o`00000000000?l0oooPP03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh5H0<j7:
0`0000000`000?l000000000003o0?ooh840oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1E03>QbP<0000000<0003o000000000000o`3o
on220?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooPE00cXLX3000000030000o`00000000000?l0oooPP`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh5<0<j7:0`0000000`00
0?l000000000003o0?ooh8@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP0`0000090?ooh580<j7:0`0000000`000?l000000000003o0?ooh8<0oooP0`00000K0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh540<j7:0`0000000`000?l00000
0000003o0?ooh8H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon1@03>QbP<0000000<0003o000000000000o`3oon270?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPC`0cXLX3
000000030000o`00000000000?l0oooPR03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh4h0<j7:0`0000000`000?l000000000003o0?oo
h8T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon1=03>QbP<0000000<0003o000000000000o`3oon2:0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPC@0cXLX2000000030000
o`00000000000?l0oooPR`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh4`0<j7:0P0000000`000?l000000000003o0?ooh8`0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1;
03>QbP80000000<0003o000000000000o`3oon2=0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPBP0cXLX2000000030000o`0000000000
0?l0oooPSP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh4T0<j7:0P0000000`000?l000000000003o0?ooh8l0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1803>QbP800000
00<0003o000000000000o`3oon2@0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooPA`0cXLX2000000040000o`000000000000000?l0oooP
T03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh4H0<j7:0P00000010000?l0000000000000003o0?ooh940oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1503>QbP80000000@0
003o0000000000000000o`3oon2B0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooPA00cXLX2000000040000o`000000000000000?l0oooP
T`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP@`0c
XLX2000000040000o`000000000000000?l0oooPTP3oon03000001/0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP@P0cXLX2000000040000o`000000000000000?l0oooP
U@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh440<j7:0P00000010000?l0000000000000003o0?ooh9H0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1003>QbP<0000000<0
003o000000000000o`3oon2G0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP?`0cXLX3000000030000o`00000000000?l0oooPV03oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h3h0<j7:0`0000000`000?l000000000003o0?ooh9T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0m03>QbP<0000000<0003o00000000
0000o`3oon2J0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP?00cXLX3000000030000o`00000000000?l0oooPV`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh3/0<j7:0`00
00000`000?l000000000003o0?ooh9`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon0j03>QbP<0000000<0003o000000000000o`3oon2M
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP>P0cXLX2000000030000o`00000000000?l0oooPWP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh3T0<j7:0P0000000`000?l0
00000000003o0?ooh9l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon0h03>QbP80000000<0003o000000000000o`3oon2P0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP=`0c
XLX2000000030000o`00000000000?l0oooPX@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V3@3oon03000000P0oooP00<000000?ooh03oon002@3oon0f03>QbP80000000<0003o
000000000000o`3oon2R0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?oo
h0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3oon0e03>QbP80000000<0003o
000000000000o`3oon2S0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?oo
h0040000003oon00oooP000000L0oooP100000080?ooh3@0<j7:0P00000010000?l0000000000000
003o0?ooh:00oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3@3oon03000000P0oooP00<00000
0?ooh03oon002@3oon0c03>QbP80000000@0003o0000000000000000o`3oon2T0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00oooP00L0oooP00<00000
0?ooh03oon002@3oon0b03>QbP<0000000<0003o000000000000o`3oon2U0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0<000001`3oon000`000000oooP0?ooh0090?oo
h340<j7:0`0000000`000?l000000000003o0?ooh:H0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0`03>QbP<0000000<0003o00000000
0000o`3oon2W0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP;`0cXLX3000000030000o`00000000000?l0oooPZ03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh2l0<j7:0P00
00000`000?l000000000003o0?ooh:T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon0^03>QbP80000000<0003o000000000000o`3oon2Z
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP;@0cXLX2000000030000o`00000000000?l0oooPZ`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh2`0<j7:0P0000000`000?l0
00000000003o0?ooh:`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon0[03>QbP80000000<0003o000000000000o`3oon2]0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP:P0c
XLX2000000040000o`000000000000000?l0oooP[@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh2T0<j7:0`0000000`000?l000000000
003o0?ooh:h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0X03>QbP<0000000<0003o000000000000o`3oon2_0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP9`0cXLX30000
00030000o`00000000000?l0oooP/03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh2H0<j7:0`0000000`000?l000000000003o0?ooh;40
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh2H0<j7:
0P0000000`000?l000000000003o0?ooh;00oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh2D0<j7:0P0000000`000?l000000000003o0?ooh;<0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0T
03>QbP80000000<0003o000000000000o`3oon2d0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP8`0cXLX2000000040000o`0000000000
00000?l0oooP]03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh280<j7:0P00000010000?l0000000000000003o0?ooh;D0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0Q03>Q
bP<0000000<0003o000000000000o`3oon2f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP800cXLX3000000030000o`00000000000?l0
oooP]`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh1l0<j7:0`0000000`000?l000000000003o0?ooh;P0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0O03>QbP80000000<0
003o000000000000o`3oon2i0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP7P0cXLX2000000030000o`00000000000?l0oooP^P3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h1d0<j7:0P0000000`000?l000000000003o0?ooh;/0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0L03>QbP<0000000<0003o00000000
0000o`3oon2k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooP6`0cXLX3000000030000o`00000000000?l0oooP_03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh1X0<j7:0`00
00000`000?l000000000003o0?ooh;d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon002@3oon0I03>QbP<0000000<0003o000000000000o`3oon2n
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooP600cXLX3000000030000o`00000000000?l0oooP_`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP600cXLX2000000030000o`00000000000?l0
oooP_P3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
5`0cXLX3000000030000o`000000oooP0?l0oooP`03oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh1H0<j7:0`0000000`000?l000000?oo
h03o0?ooh<40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0E03>QbP<0000000<0003o0000003oon00o`3oon320?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP500cXLX30000
00030000o`00000000000?l0oooP``3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh1<0<j7:0`0000000`000?l000000000003o0?ooh<@0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon0C03>QbP80000000<0003o000000000000o`3oon350?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP4P0cXLX3000000030000o`00
0000oooP0?l0oooPa@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh140<j7:0`0000000`000?l000000?ooh03o0?ooh<H0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0@03>Q
bP<0000000<0003o000000000000o`3oon370?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP400cXLX2000000030000o`00000000000?l0
oooPb03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh0l0<j7:0P0000000`000?l000000000003o0?ooh<T0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0>03>QbP80000000<0
003o000000000000o`3oon3:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP3@0cXLX3000000030000o`000000oooP0?l0oooPbP3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h0`0<j7:0`0000000`000?l000000?ooh03o0?ooh</0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0;03>QbP<0000000<0003o0000003o
on00o`3oon3<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000
2@3oon0:03>QbP<0000000<0003o000000000000o`3oon3;0?ooh0<000006`3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0903>QbP<0000000<0003o000000000000o`3o
on3>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP200cXLX3000000030000o`00000000000?l0oooPc`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0P0<j7:0P0000000`00
0?l000000000003o0?ooh=00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon0703>QbP80000000<0003o000000000000o`3oon3A0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
1P0cXLX3000000030000o`000000oooP0?l0oooPd@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0D0<j7:0`0000000`000?l000000?oo
h03o0?ooh=80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0503>QbP80000000<0003o000000000000o`3oon3C0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP100cXLX20000
00030000o`00000000000?l0oooPe03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh0<0<j7:0P0000000`000?l000000000003o0?ooh=D0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon0203>QbP80000000<0003o000000000000o`3oon3F0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00@0<j7:000000000000003o
0`00003o0?ooh=H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon03000000030000o`00000000000?l0oooPe`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?ooh03oon002@3oon02
000000030000o`00000000000?l0oooPf03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00P0oooP0P000000
0`000?l000000000003o0?ooh=T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPd0oooP00@000000?ooh03oon0000001`3oon04000000H0oooP0P0000000`000?l000000000003o
0?ooh=L0oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<000000?oo
h03oon001`3oon0400000?l0oooPf`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00P0oooP0P00003o0?oo
h=`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP0P0000080?ooh003
0000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01:0?ooh0030000003o
on00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003o
on00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh0090?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`00
0000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`00
0000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooPo`00003Z000001/0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o
0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0
oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3j
l>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool0
01d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40
oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3j
l>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?oo
h1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP
7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003A0?[`iP@000000P3jl>H800000080n_3V100000001`3jl>H0
0000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`iP000000
0000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`0000080?[`iPD000000P3j
l>H400000080n_3V1@00000<0?[`iP<000004@3jl>H3000000H0n_3V0`000000103jl>H000000000
000000060?[`iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H0000000000000003H0?[`iP40
oooo003B0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP8000000`3jl>H01`000000n_3V
000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2000000030?[`iP0000000000
0080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V0?[`iP8000000P3jl>H2
000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00000:0?[`iP8000000`3j
l>H200000080n_3V0P0000020?[`iP8000003@3jl>H2000000030?[`iP000000000000l0n_3V0P00
00000`3jl>H00000000000060?[`iP80000000<0n_3V0000000000001`3jl>H00`000000n_3V0?[`
iP050?[`iP80000000<0n_3V000000000000f@3jl>H10?ooo`00dP3jl>H2000000030?[`iP000000
000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP000000n_3V00@000000P3jl>H2
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000003@3jl>H2
00000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002P3j
l>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V0P0000000`3jl>H000000000
00050?[`iPD000001@3jl>H2000000030?[`iP000000000000L0n_3V0`0000060?[`iPD000001P3j
l>H300000=X0n_3V0@3oool00=80n_3V1@0000040?[`iP8000000`3jl>H6000000060?[`iP000000
00000?[`iP000000n_3V0P0000000`3jl>H000000000000300000080n_3V0P0000000`3jl>H00000
000000020?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0n_3V0P000000103jl>H00000
0000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H2000000<0n_3V0P0000020?[`iP80
00000P3jl>H2000000d0n_3V0P0000000`3jl>H000000000000?0?[`iP80000000<0n_3V00000000
00001`3jl>H3000000P0n_3V00<000000?[`iP3jl>H01P3jl>H300000=X0n_3V0@3oool00=80n_3V
0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80000000H0n_3V000000000000
n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3jl>H20000
00030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V000000000000n_3V0P000000
0`3jl>H000000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0`000000
0`3jl>H000000?[`iP0:0?[`iP<00000403jl>H4000000L0n_3V0P0000000`3jl>H0000000000007
0?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000003I0?[`iP40oooo003B0?[`
iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4000000030?[`iP0000000000
00D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2000000D0n_3V0`0000000`3j
l>H0000000000007000000X0n_3V1@0000020?[`iP@000000P3jl>H3000000030?[`iP0000000000
00X0n_3V0P0000000`3jl>H000000000000?0?[`iP800000203jl>H3000000040?[`iP0000000000
000000d0n_3V0`0000000`3jl>H000000000000500000=@0n_3V0@3oool00=80n_3V0P0000020?[`
iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H05`3jl>H2000001X0n_3V0P0000000`3j
l>H000000000000@0?[`iP8000008`3jl>H00`000000n_3V0?[`iP3D0?[`iP40oooo003A0?[`iPH0
0000103jl>H2000002l0n_3V1@00000J0?[`iP<000006@3jl>H300000180n_3V0`00000R0?[`iP03
0000003jl>H0n_3V0=<0n_3V0@3oool00?l0n_3VP`3jl>H00`000000n_3V0?[`iP3B0?[`iP40oooo
003o0?[`iX00n_3V00@000000?[`iP3jl>H00000e03jl>H10?ooo`00o`3jl>J10?[`iP800000e@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
%%ImageSize: 600 540 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.98 .941 .902 r
MFill
% Scaling calculations
-2.77556e-017 0.1 -0.1 0.1 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% Start of sub-graphic
p
0.05 0.2 0.95 0.756 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 .878 r
MFill
% PlotRegion
0 .97 0 .95 MPlotRegion
% Scaling calculations
0.0238095 0.31746 0.0801155 0.0654004 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -6 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .34172 -6 -4.5 ]
[-0.0125 .34172 0 4.5 ]
[-0.0125 .47252 -6 -4.5 ]
[-0.0125 .47252 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(0)] -0.0125 .08012 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .34172 m
.00625 .34172 L
s
[(4)] -0.0125 .34172 1 0 Mshowa
0 .47252 m
.00625 .47252 L
s
[(6)] -0.0125 .47252 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(8)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .11282 m
.00375 .11282 L
s
0 .14552 m
.00375 .14552 L
s
0 .17822 m
.00375 .17822 L
s
0 .24362 m
.00375 .24362 L
s
0 .27632 m
.00375 .27632 L
s
0 .30902 m
.00375 .30902 L
s
0 .37442 m
.00375 .37442 L
s
0 .40712 m
.00375 .40712 L
s
0 .43982 m
.00375 .43982 L
s
0 .50522 m
.00375 .50522 L
s
0 .53792 m
.00375 .53792 L
s
0 .57062 m
.00375 .57062 L
s
0 .04742 m
.00375 .04742 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .21092 m
1 .21092 L
s
.99375 .34172 m
1 .34172 L
s
.99375 .47252 m
1 .47252 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .11282 m
1 .11282 L
s
.99625 .14552 m
1 .14552 L
s
.99625 .17822 m
1 .17822 L
s
.99625 .24362 m
1 .24362 L
s
.99625 .27632 m
1 .27632 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .37442 m
1 .37442 L
s
.99625 .40712 m
1 .40712 L
s
.99625 .43982 m
1 .43982 L
s
.99625 .50522 m
1 .50522 L
s
.99625 .53792 m
1 .53792 L
s
.99625 .57062 m
1 .57062 L
s
.99625 .04742 m
1 .04742 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.678 .847 .902 r
.02381 .08012 m
.02381 .60327 L
.024 .60327 L
.024 .08012 L
F
.2 .63 .79 r
.5 Mabswid
.02381 .08012 m
.02381 .60327 L
.024 .60327 L
.024 .08012 L
s
.678 .847 .902 r
.024 .08012 m
.024 .60301 L
.0243 .60301 L
.0243 .08012 L
F
.2 .63 .79 r
.024 .08012 m
.024 .60301 L
.0243 .60301 L
.0243 .08012 L
s
.678 .847 .902 r
.0243 .08012 m
.0243 .60256 L
.02447 .60256 L
.02447 .08012 L
F
.2 .63 .79 r
.0243 .08012 m
.0243 .60256 L
.02447 .60256 L
.02447 .08012 L
s
.678 .847 .902 r
.02447 .08012 m
.02447 .60243 L
.0247 .60243 L
.0247 .08012 L
F
.2 .63 .79 r
.02447 .08012 m
.02447 .60243 L
.0247 .60243 L
.0247 .08012 L
s
.678 .847 .902 r
.0247 .08012 m
.0247 .60218 L
.02495 .60218 L
.02495 .08012 L
F
.2 .63 .79 r
.0247 .08012 m
.0247 .60218 L
.02495 .60218 L
.02495 .08012 L
s
.678 .847 .902 r
.02495 .08012 m
.02495 .60189 L
.02519 .60189 L
.02519 .08012 L
F
.2 .63 .79 r
.02495 .08012 m
.02495 .60189 L
.02519 .60189 L
.02519 .08012 L
s
.678 .847 .902 r
.02519 .08012 m
.02519 .60144 L
.02559 .60144 L
.02559 .08012 L
F
.2 .63 .79 r
.02519 .08012 m
.02519 .60144 L
.02559 .60144 L
.02559 .08012 L
s
.678 .847 .902 r
.02559 .08012 m
.02559 .60111 L
.02581 .60111 L
.02581 .08012 L
F
.2 .63 .79 r
.02559 .08012 m
.02559 .60111 L
.02581 .60111 L
.02581 .08012 L
s
.678 .847 .902 r
.02581 .08012 m
.02581 .60049 L
.02623 .60049 L
.02623 .08012 L
F
.2 .63 .79 r
.02581 .08012 m
.02581 .60049 L
.02623 .60049 L
.02623 .08012 L
s
.678 .847 .902 r
.02623 .08012 m
.02623 .59985 L
.02664 .59985 L
.02664 .08012 L
F
.2 .63 .79 r
.02623 .08012 m
.02623 .59985 L
.02664 .59985 L
.02664 .08012 L
s
.678 .847 .902 r
.02664 .08012 m
.02664 .59979 L
.02686 .59979 L
.02686 .08012 L
F
.2 .63 .79 r
.02664 .08012 m
.02664 .59979 L
.02686 .59979 L
.02686 .08012 L
s
.678 .847 .902 r
.02686 .08012 m
.02686 .59927 L
.02719 .59927 L
.02719 .08012 L
F
.2 .63 .79 r
.02686 .08012 m
.02686 .59927 L
.02719 .59927 L
.02719 .08012 L
s
.678 .847 .902 r
.02719 .08012 m
.02719 .5988 L
.02767 .5988 L
.02767 .08012 L
F
.2 .63 .79 r
.02719 .08012 m
.02719 .5988 L
.02767 .5988 L
.02767 .08012 L
s
.678 .847 .902 r
.02767 .08012 m
.02767 .59848 L
.02785 .59848 L
.02785 .08012 L
F
.2 .63 .79 r
.02767 .08012 m
.02767 .59848 L
.02785 .59848 L
.02785 .08012 L
s
.678 .847 .902 r
.02785 .08012 m
.02785 .59813 L
.02829 .59813 L
.02829 .08012 L
F
.2 .63 .79 r
.02785 .08012 m
.02785 .59813 L
.02829 .59813 L
.02829 .08012 L
s
.678 .847 .902 r
.02829 .08012 m
.02829 .59759 L
.02864 .59759 L
.02864 .08012 L
F
.2 .63 .79 r
.02829 .08012 m
.02829 .59759 L
.02864 .59759 L
.02864 .08012 L
s
.678 .847 .902 r
.02864 .08012 m
.02864 .59703 L
.02907 .59703 L
.02907 .08012 L
F
.2 .63 .79 r
.02864 .08012 m
.02864 .59703 L
.02907 .59703 L
.02907 .08012 L
s
.678 .847 .902 r
.02907 .08012 m
.02907 .59662 L
.02927 .59662 L
.02927 .08012 L
F
.2 .63 .79 r
.02907 .08012 m
.02907 .59662 L
.02927 .59662 L
.02927 .08012 L
s
.678 .847 .902 r
.02927 .08012 m
.02927 .59655 L
.02954 .59655 L
.02954 .08012 L
F
.2 .63 .79 r
.02927 .08012 m
.02927 .59655 L
.02954 .59655 L
.02954 .08012 L
s
.678 .847 .902 r
.02954 .08012 m
.02954 .59607 L
.02974 .59607 L
.02974 .08012 L
F
.2 .63 .79 r
.02954 .08012 m
.02954 .59607 L
.02974 .59607 L
.02974 .08012 L
s
.678 .847 .902 r
.02974 .08012 m
.02974 .59548 L
.03022 .59548 L
.03022 .08012 L
F
.2 .63 .79 r
.02974 .08012 m
.02974 .59548 L
.03022 .59548 L
.03022 .08012 L
s
.678 .847 .902 r
.03022 .08012 m
.03022 .59532 L
.03039 .59532 L
.03039 .08012 L
F
.2 .63 .79 r
.03022 .08012 m
.03022 .59532 L
.03039 .59532 L
.03039 .08012 L
s
.678 .847 .902 r
.03039 .08012 m
.03039 .59513 L
.03059 .59513 L
.03059 .08012 L
F
.2 .63 .79 r
.03039 .08012 m
.03039 .59513 L
.03059 .59513 L
.03059 .08012 L
s
.678 .847 .902 r
.03059 .08012 m
.03059 .59472 L
.03095 .59472 L
.03095 .08012 L
F
.2 .63 .79 r
.03059 .08012 m
.03059 .59472 L
.03095 .59472 L
.03095 .08012 L
s
.678 .847 .902 r
.03095 .08012 m
.03095 .59415 L
.03138 .59415 L
.03138 .08012 L
F
.2 .63 .79 r
.03095 .08012 m
.03095 .59415 L
.03138 .59415 L
.03138 .08012 L
s
.678 .847 .902 r
.03138 .08012 m
.03138 .59386 L
.03175 .59386 L
.03175 .08012 L
F
.2 .63 .79 r
.03138 .08012 m
.03138 .59386 L
.03175 .59386 L
.03175 .08012 L
s
.678 .847 .902 r
.03175 .08012 m
.03175 .59342 L
.03193 .59342 L
.03193 .08012 L
F
.2 .63 .79 r
.03175 .08012 m
.03175 .59342 L
.03193 .59342 L
.03193 .08012 L
s
.678 .847 .902 r
.03193 .08012 m
.03193 .59322 L
.03221 .59322 L
.03221 .08012 L
F
.2 .63 .79 r
.03193 .08012 m
.03193 .59322 L
.03221 .59322 L
.03221 .08012 L
s
.678 .847 .902 r
.03221 .08012 m
.03221 .59276 L
.03253 .59276 L
.03253 .08012 L
F
.2 .63 .79 r
.03221 .08012 m
.03221 .59276 L
.03253 .59276 L
.03253 .08012 L
s
.678 .847 .902 r
.03253 .08012 m
.03253 .59251 L
.03281 .59251 L
.03281 .08012 L
F
.2 .63 .79 r
.03253 .08012 m
.03253 .59251 L
.03281 .59251 L
.03281 .08012 L
s
.678 .847 .902 r
.03281 .08012 m
.03281 .59217 L
.03308 .59217 L
.03308 .08012 L
F
.2 .63 .79 r
.03281 .08012 m
.03281 .59217 L
.03308 .59217 L
.03308 .08012 L
s
.678 .847 .902 r
.03308 .08012 m
.03308 .59185 L
.03329 .59185 L
.03329 .08012 L
F
.2 .63 .79 r
.03308 .08012 m
.03308 .59185 L
.03329 .59185 L
.03329 .08012 L
s
.678 .847 .902 r
.03329 .08012 m
.03329 .59124 L
.03368 .59124 L
.03368 .08012 L
F
.2 .63 .79 r
.03329 .08012 m
.03329 .59124 L
.03368 .59124 L
.03368 .08012 L
s
.678 .847 .902 r
.03368 .08012 m
.03368 .59105 L
.03404 .59105 L
.03404 .08012 L
F
.2 .63 .79 r
.03368 .08012 m
.03368 .59105 L
.03404 .59105 L
.03404 .08012 L
s
.678 .847 .902 r
.03404 .08012 m
.03404 .59071 L
.03424 .59071 L
.03424 .08012 L
F
.2 .63 .79 r
.03404 .08012 m
.03404 .59071 L
.03424 .59071 L
.03424 .08012 L
s
.678 .847 .902 r
.03424 .08012 m
.03424 .59025 L
.03461 .59025 L
.03461 .08012 L
F
.2 .63 .79 r
.03424 .08012 m
.03424 .59025 L
.03461 .59025 L
.03461 .08012 L
s
.678 .847 .902 r
.03461 .08012 m
.03461 .5899 L
.03502 .5899 L
.03502 .08012 L
F
.2 .63 .79 r
.03461 .08012 m
.03461 .5899 L
.03502 .5899 L
.03502 .08012 L
s
.678 .847 .902 r
.03502 .08012 m
.03502 .58917 L
.03535 .58917 L
.03535 .08012 L
F
.2 .63 .79 r
.03502 .08012 m
.03502 .58917 L
.03535 .58917 L
.03535 .08012 L
s
.678 .847 .902 r
.03535 .08012 m
.03535 .58891 L
.0356 .58891 L
.0356 .08012 L
F
.2 .63 .79 r
.03535 .08012 m
.03535 .58891 L
.0356 .58891 L
.0356 .08012 L
s
.678 .847 .902 r
.0356 .08012 m
.0356 .58882 L
.03576 .58882 L
.03576 .08012 L
F
.2 .63 .79 r
.0356 .08012 m
.0356 .58882 L
.03576 .58882 L
.03576 .08012 L
s
.678 .847 .902 r
.03576 .08012 m
.03576 .58825 L
.03624 .58825 L
.03624 .08012 L
F
.2 .63 .79 r
.03576 .08012 m
.03576 .58825 L
.03624 .58825 L
.03624 .08012 L
s
.678 .847 .902 r
.03624 .08012 m
.03624 .58803 L
.03651 .58803 L
.03651 .08012 L
F
.2 .63 .79 r
.03624 .08012 m
.03624 .58803 L
.03651 .58803 L
.03651 .08012 L
s
.678 .847 .902 r
.03651 .08012 m
.03651 .58736 L
.03698 .58736 L
.03698 .08012 L
F
.2 .63 .79 r
.03651 .08012 m
.03651 .58736 L
.03698 .58736 L
.03698 .08012 L
s
.678 .847 .902 r
.03698 .08012 m
.03698 .58697 L
.03744 .58697 L
.03744 .08012 L
F
.2 .63 .79 r
.03698 .08012 m
.03698 .58697 L
.03744 .58697 L
.03744 .08012 L
s
.678 .847 .902 r
.03744 .08012 m
.03744 .58645 L
.03759 .58645 L
.03759 .08012 L
F
.2 .63 .79 r
.03744 .08012 m
.03744 .58645 L
.03759 .58645 L
.03759 .08012 L
s
.678 .847 .902 r
.03759 .08012 m
.03759 .58624 L
.03784 .58624 L
.03784 .08012 L
F
.2 .63 .79 r
.03759 .08012 m
.03759 .58624 L
.03784 .58624 L
.03784 .08012 L
s
.678 .847 .902 r
.03784 .08012 m
.03784 .58595 L
.03826 .58595 L
.03826 .08012 L
F
.2 .63 .79 r
.03784 .08012 m
.03784 .58595 L
.03826 .58595 L
.03826 .08012 L
s
.678 .847 .902 r
.03826 .08012 m
.03826 .58537 L
.0385 .58537 L
.0385 .08012 L
F
.2 .63 .79 r
.03826 .08012 m
.03826 .58537 L
.0385 .58537 L
.0385 .08012 L
s
.678 .847 .902 r
.0385 .08012 m
.0385 .58529 L
.03871 .58529 L
.03871 .08012 L
F
.2 .63 .79 r
.0385 .08012 m
.0385 .58529 L
.03871 .58529 L
.03871 .08012 L
s
.678 .847 .902 r
.03871 .08012 m
.03871 .58493 L
.03908 .58493 L
.03908 .08012 L
F
.2 .63 .79 r
.03871 .08012 m
.03871 .58493 L
.03908 .58493 L
.03908 .08012 L
s
.678 .847 .902 r
.03908 .08012 m
.03908 .58425 L
.03947 .58425 L
.03947 .08012 L
F
.2 .63 .79 r
.03908 .08012 m
.03908 .58425 L
.03947 .58425 L
.03947 .08012 L
s
.678 .847 .902 r
.03947 .08012 m
.03947 .58386 L
.03993 .58386 L
.03993 .08012 L
F
.2 .63 .79 r
.03947 .08012 m
.03947 .58386 L
.03993 .58386 L
.03993 .08012 L
s
.678 .847 .902 r
.03993 .08012 m
.03993 .58336 L
.04031 .58336 L
.04031 .08012 L
F
.2 .63 .79 r
.03993 .08012 m
.03993 .58336 L
.04031 .58336 L
.04031 .08012 L
s
.678 .847 .902 r
.04031 .08012 m
.04031 .5831 L
.04054 .5831 L
.04054 .08012 L
F
.2 .63 .79 r
.04031 .08012 m
.04031 .5831 L
.04054 .5831 L
.04054 .08012 L
s
.678 .847 .902 r
.04054 .08012 m
.04054 .58265 L
.04082 .58265 L
.04082 .08012 L
F
.2 .63 .79 r
.04054 .08012 m
.04054 .58265 L
.04082 .58265 L
.04082 .08012 L
s
.678 .847 .902 r
.04082 .08012 m
.04082 .58239 L
.04121 .58239 L
.04121 .08012 L
F
.2 .63 .79 r
.04082 .08012 m
.04082 .58239 L
.04121 .58239 L
.04121 .08012 L
s
.678 .847 .902 r
.04121 .08012 m
.04121 .58168 L
.04169 .58168 L
.04169 .08012 L
F
.2 .63 .79 r
.04121 .08012 m
.04121 .58168 L
.04169 .58168 L
.04169 .08012 L
s
.678 .847 .902 r
.04169 .08012 m
.04169 .5811 L
.04206 .5811 L
.04206 .08012 L
F
.2 .63 .79 r
.04169 .08012 m
.04169 .5811 L
.04206 .5811 L
.04206 .08012 L
s
.678 .847 .902 r
.04206 .08012 m
.04206 .58088 L
.04228 .58088 L
.04228 .08012 L
F
.2 .63 .79 r
.04206 .08012 m
.04206 .58088 L
.04228 .58088 L
.04228 .08012 L
s
.678 .847 .902 r
.04228 .08012 m
.04228 .58058 L
.04245 .58058 L
.04245 .08012 L
F
.2 .63 .79 r
.04228 .08012 m
.04228 .58058 L
.04245 .58058 L
.04245 .08012 L
s
.678 .847 .902 r
.04245 .08012 m
.04245 .58043 L
.04267 .58043 L
.04267 .08012 L
F
.2 .63 .79 r
.04245 .08012 m
.04245 .58043 L
.04267 .58043 L
.04267 .08012 L
s
.678 .847 .902 r
.04267 .08012 m
.04267 .58006 L
.04286 .58006 L
.04286 .08012 L
F
.2 .63 .79 r
.04267 .08012 m
.04267 .58006 L
.04286 .58006 L
.04286 .08012 L
s
.678 .847 .902 r
.04286 .08012 m
.04286 .57966 L
.04332 .57966 L
.04332 .08012 L
F
.2 .63 .79 r
.04286 .08012 m
.04286 .57966 L
.04332 .57966 L
.04332 .08012 L
s
.678 .847 .902 r
.04332 .08012 m
.04332 .57935 L
.04347 .57935 L
.04347 .08012 L
F
.2 .63 .79 r
.04332 .08012 m
.04332 .57935 L
.04347 .57935 L
.04347 .08012 L
s
.678 .847 .902 r
.04347 .08012 m
.04347 .57909 L
.04371 .57909 L
.04371 .08012 L
F
.2 .63 .79 r
.04347 .08012 m
.04347 .57909 L
.04371 .57909 L
.04371 .08012 L
s
.678 .847 .902 r
.04371 .08012 m
.04371 .57862 L
.04411 .57862 L
.04411 .08012 L
F
.2 .63 .79 r
.04371 .08012 m
.04371 .57862 L
.04411 .57862 L
.04411 .08012 L
s
.678 .847 .902 r
.04411 .08012 m
.04411 .5779 L
.0446 .5779 L
.0446 .08012 L
F
.2 .63 .79 r
.04411 .08012 m
.04411 .5779 L
.0446 .5779 L
.0446 .08012 L
s
.678 .847 .902 r
.0446 .08012 m
.0446 .57785 L
.04478 .57785 L
.04478 .08012 L
F
.2 .63 .79 r
.0446 .08012 m
.0446 .57785 L
.04478 .57785 L
.04478 .08012 L
s
.678 .847 .902 r
.04478 .08012 m
.04478 .57743 L
.04502 .57743 L
.04502 .08012 L
F
.2 .63 .79 r
.04478 .08012 m
.04478 .57743 L
.04502 .57743 L
.04502 .08012 L
s
.678 .847 .902 r
.04502 .08012 m
.04502 .57733 L
.04532 .57733 L
.04532 .08012 L
F
.2 .63 .79 r
.04502 .08012 m
.04502 .57733 L
.04532 .57733 L
.04532 .08012 L
s
.678 .847 .902 r
.04532 .08012 m
.04532 .57684 L
.04554 .57684 L
.04554 .08012 L
F
.2 .63 .79 r
.04532 .08012 m
.04532 .57684 L
.04554 .57684 L
.04554 .08012 L
s
.678 .847 .902 r
.04554 .08012 m
.04554 .57651 L
.04597 .57651 L
.04597 .08012 L
F
.2 .63 .79 r
.04554 .08012 m
.04554 .57651 L
.04597 .57651 L
.04597 .08012 L
s
.678 .847 .902 r
.04597 .08012 m
.04597 .57607 L
.04614 .57607 L
.04614 .08012 L
F
.2 .63 .79 r
.04597 .08012 m
.04597 .57607 L
.04614 .57607 L
.04614 .08012 L
s
.678 .847 .902 r
.04614 .08012 m
.04614 .57556 L
.04657 .57556 L
.04657 .08012 L
F
.2 .63 .79 r
.04614 .08012 m
.04614 .57556 L
.04657 .57556 L
.04657 .08012 L
s
.678 .847 .902 r
.04657 .08012 m
.04657 .57515 L
.04689 .57515 L
.04689 .08012 L
F
.2 .63 .79 r
.04657 .08012 m
.04657 .57515 L
.04689 .57515 L
.04689 .08012 L
s
.678 .847 .902 r
.04689 .08012 m
.04689 .57512 L
.04736 .57512 L
.04736 .08012 L
F
.2 .63 .79 r
.04689 .08012 m
.04689 .57512 L
.04736 .57512 L
.04736 .08012 L
s
.678 .847 .902 r
.04736 .08012 m
.04736 .57443 L
.04764 .57443 L
.04764 .08012 L
F
.2 .63 .79 r
.04736 .08012 m
.04736 .57443 L
.04764 .57443 L
.04764 .08012 L
s
.678 .847 .902 r
.04764 .08012 m
.04764 .57385 L
.04798 .57385 L
.04798 .08012 L
F
.2 .63 .79 r
.04764 .08012 m
.04764 .57385 L
.04798 .57385 L
.04798 .08012 L
s
.678 .847 .902 r
.04798 .08012 m
.04798 .57371 L
.04818 .57371 L
.04818 .08012 L
F
.2 .63 .79 r
.04798 .08012 m
.04798 .57371 L
.04818 .57371 L
.04818 .08012 L
s
.678 .847 .902 r
.04818 .08012 m
.04818 .57336 L
.0484 .57336 L
.0484 .08012 L
F
.2 .63 .79 r
.04818 .08012 m
.04818 .57336 L
.0484 .57336 L
.0484 .08012 L
s
.678 .847 .902 r
.0484 .08012 m
.0484 .57302 L
.04869 .57302 L
.04869 .08012 L
F
.2 .63 .79 r
.0484 .08012 m
.0484 .57302 L
.04869 .57302 L
.04869 .08012 L
s
.678 .847 .902 r
.04869 .08012 m
.04869 .57286 L
.04916 .57286 L
.04916 .08012 L
F
.2 .63 .79 r
.04869 .08012 m
.04869 .57286 L
.04916 .57286 L
.04916 .08012 L
s
.678 .847 .902 r
.04916 .08012 m
.04916 .57234 L
.04963 .57234 L
.04963 .08012 L
F
.2 .63 .79 r
.04916 .08012 m
.04916 .57234 L
.04963 .57234 L
.04963 .08012 L
s
.678 .847 .902 r
.04963 .08012 m
.04963 .5718 L
.04983 .5718 L
.04983 .08012 L
F
.2 .63 .79 r
.04963 .08012 m
.04963 .5718 L
.04983 .5718 L
.04983 .08012 L
s
.678 .847 .902 r
.04983 .08012 m
.04983 .57145 L
.05004 .57145 L
.05004 .08012 L
F
.2 .63 .79 r
.04983 .08012 m
.04983 .57145 L
.05004 .57145 L
.05004 .08012 L
s
.678 .847 .902 r
.05004 .08012 m
.05004 .57113 L
.05048 .57113 L
.05048 .08012 L
F
.2 .63 .79 r
.05004 .08012 m
.05004 .57113 L
.05048 .57113 L
.05048 .08012 L
s
.678 .847 .902 r
.05048 .08012 m
.05048 .57073 L
.05063 .57073 L
.05063 .08012 L
F
.2 .63 .79 r
.05048 .08012 m
.05048 .57073 L
.05063 .57073 L
.05063 .08012 L
s
.678 .847 .902 r
.05063 .08012 m
.05063 .57049 L
.05083 .57049 L
.05083 .08012 L
F
.2 .63 .79 r
.05063 .08012 m
.05063 .57049 L
.05083 .57049 L
.05083 .08012 L
s
.678 .847 .902 r
.05083 .08012 m
.05083 .56985 L
.0513 .56985 L
.0513 .08012 L
F
.2 .63 .79 r
.05083 .08012 m
.05083 .56985 L
.0513 .56985 L
.0513 .08012 L
s
.678 .847 .902 r
.0513 .08012 m
.0513 .56969 L
.05147 .56969 L
.05147 .08012 L
F
.2 .63 .79 r
.0513 .08012 m
.0513 .56969 L
.05147 .56969 L
.05147 .08012 L
s
.678 .847 .902 r
.05147 .08012 m
.05147 .56953 L
.05163 .56953 L
.05163 .08012 L
F
.2 .63 .79 r
.05147 .08012 m
.05147 .56953 L
.05163 .56953 L
.05163 .08012 L
s
.678 .847 .902 r
.05163 .08012 m
.05163 .56937 L
.05179 .56937 L
.05179 .08012 L
F
.2 .63 .79 r
.05163 .08012 m
.05163 .56937 L
.05179 .56937 L
.05179 .08012 L
s
.678 .847 .902 r
.05179 .08012 m
.05179 .5692 L
.05217 .5692 L
.05217 .08012 L
F
.2 .63 .79 r
.05179 .08012 m
.05179 .5692 L
.05217 .5692 L
.05217 .08012 L
s
.678 .847 .902 r
.05217 .08012 m
.05217 .56857 L
.05254 .56857 L
.05254 .08012 L
F
.2 .63 .79 r
.05217 .08012 m
.05217 .56857 L
.05254 .56857 L
.05254 .08012 L
s
.678 .847 .902 r
.05254 .08012 m
.05254 .56795 L
.05297 .56795 L
.05297 .08012 L
F
.2 .63 .79 r
.05254 .08012 m
.05254 .56795 L
.05297 .56795 L
.05297 .08012 L
s
.678 .847 .902 r
.05297 .08012 m
.05297 .5676 L
.05319 .5676 L
.05319 .08012 L
F
.2 .63 .79 r
.05297 .08012 m
.05297 .5676 L
.05319 .5676 L
.05319 .08012 L
s
.678 .847 .902 r
.05319 .08012 m
.05319 .56747 L
.05355 .56747 L
.05355 .08012 L
F
.2 .63 .79 r
.05319 .08012 m
.05319 .56747 L
.05355 .56747 L
.05355 .08012 L
s
.678 .847 .902 r
.05355 .08012 m
.05355 .56684 L
.05397 .56684 L
.05397 .08012 L
F
.2 .63 .79 r
.05355 .08012 m
.05355 .56684 L
.05397 .56684 L
.05397 .08012 L
s
.678 .847 .902 r
.05397 .08012 m
.05397 .56637 L
.05424 .56637 L
.05424 .08012 L
F
.2 .63 .79 r
.05397 .08012 m
.05397 .56637 L
.05424 .56637 L
.05424 .08012 L
s
.678 .847 .902 r
.05424 .08012 m
.05424 .56606 L
.05449 .56606 L
.05449 .08012 L
F
.2 .63 .79 r
.05424 .08012 m
.05424 .56606 L
.05449 .56606 L
.05449 .08012 L
s
.678 .847 .902 r
.05449 .08012 m
.05449 .5658 L
.05471 .5658 L
.05471 .08012 L
F
.2 .63 .79 r
.05449 .08012 m
.05449 .5658 L
.05471 .5658 L
.05471 .08012 L
s
.678 .847 .902 r
.05471 .08012 m
.05471 .56556 L
.05494 .56556 L
.05494 .08012 L
F
.2 .63 .79 r
.05471 .08012 m
.05471 .56556 L
.05494 .56556 L
.05494 .08012 L
s
.678 .847 .902 r
.05494 .08012 m
.05494 .56538 L
.05516 .56538 L
.05516 .08012 L
F
.2 .63 .79 r
.05494 .08012 m
.05494 .56538 L
.05516 .56538 L
.05516 .08012 L
s
.678 .847 .902 r
.05516 .08012 m
.05516 .565 L
.05533 .565 L
.05533 .08012 L
F
.2 .63 .79 r
.05516 .08012 m
.05516 .565 L
.05533 .565 L
.05533 .08012 L
s
.678 .847 .902 r
.05533 .08012 m
.05533 .56452 L
.05576 .56452 L
.05576 .08012 L
F
.2 .63 .79 r
.05533 .08012 m
.05533 .56452 L
.05576 .56452 L
.05576 .08012 L
s
.678 .847 .902 r
.05576 .08012 m
.05576 .56436 L
.056 .56436 L
.056 .08012 L
F
.2 .63 .79 r
.05576 .08012 m
.05576 .56436 L
.056 .56436 L
.056 .08012 L
s
.678 .847 .902 r
.056 .08012 m
.056 .56413 L
.05625 .56413 L
.05625 .08012 L
F
.2 .63 .79 r
.056 .08012 m
.056 .56413 L
.05625 .56413 L
.05625 .08012 L
s
.678 .847 .902 r
.05625 .08012 m
.05625 .56344 L
.05671 .56344 L
.05671 .08012 L
F
.2 .63 .79 r
.05625 .08012 m
.05625 .56344 L
.05671 .56344 L
.05671 .08012 L
s
.678 .847 .902 r
.05671 .08012 m
.05671 .56319 L
.05707 .56319 L
.05707 .08012 L
F
.2 .63 .79 r
.05671 .08012 m
.05671 .56319 L
.05707 .56319 L
.05707 .08012 L
s
.678 .847 .902 r
.05707 .08012 m
.05707 .5629 L
.05738 .5629 L
.05738 .08012 L
F
.2 .63 .79 r
.05707 .08012 m
.05707 .5629 L
.05738 .5629 L
.05738 .08012 L
s
.678 .847 .902 r
.05738 .08012 m
.05738 .56233 L
.05762 .56233 L
.05762 .08012 L
F
.2 .63 .79 r
.05738 .08012 m
.05738 .56233 L
.05762 .56233 L
.05762 .08012 L
s
.678 .847 .902 r
.05762 .08012 m
.05762 .56215 L
.05804 .56215 L
.05804 .08012 L
F
.2 .63 .79 r
.05762 .08012 m
.05762 .56215 L
.05804 .56215 L
.05804 .08012 L
s
.678 .847 .902 r
.05804 .08012 m
.05804 .56159 L
.05841 .56159 L
.05841 .08012 L
F
.2 .63 .79 r
.05804 .08012 m
.05804 .56159 L
.05841 .56159 L
.05841 .08012 L
s
.678 .847 .902 r
.05841 .08012 m
.05841 .56119 L
.05869 .56119 L
.05869 .08012 L
F
.2 .63 .79 r
.05841 .08012 m
.05841 .56119 L
.05869 .56119 L
.05869 .08012 L
s
.678 .847 .902 r
.05869 .08012 m
.05869 .56091 L
.05893 .56091 L
.05893 .08012 L
F
.2 .63 .79 r
.05869 .08012 m
.05869 .56091 L
.05893 .56091 L
.05893 .08012 L
s
.678 .847 .902 r
.05893 .08012 m
.05893 .56028 L
.05933 .56028 L
.05933 .08012 L
F
.2 .63 .79 r
.05893 .08012 m
.05893 .56028 L
.05933 .56028 L
.05933 .08012 L
s
.678 .847 .902 r
.05933 .08012 m
.05933 .56005 L
.05982 .56005 L
.05982 .08012 L
F
.2 .63 .79 r
.05933 .08012 m
.05933 .56005 L
.05982 .56005 L
.05982 .08012 L
s
.678 .847 .902 r
.05982 .08012 m
.05982 .55921 L
.06022 .55921 L
.06022 .08012 L
F
.2 .63 .79 r
.05982 .08012 m
.05982 .55921 L
.06022 .55921 L
.06022 .08012 L
s
.678 .847 .902 r
.06022 .08012 m
.06022 .55899 L
.06052 .55899 L
.06052 .08012 L
F
.2 .63 .79 r
.06022 .08012 m
.06022 .55899 L
.06052 .55899 L
.06052 .08012 L
s
.678 .847 .902 r
.06052 .08012 m
.06052 .5588 L
.06084 .5588 L
.06084 .08012 L
F
.2 .63 .79 r
.06052 .08012 m
.06052 .5588 L
.06084 .5588 L
.06084 .08012 L
s
.678 .847 .902 r
.06084 .08012 m
.06084 .5584 L
.06112 .5584 L
.06112 .08012 L
F
.2 .63 .79 r
.06084 .08012 m
.06084 .5584 L
.06112 .5584 L
.06112 .08012 L
s
.678 .847 .902 r
.06112 .08012 m
.06112 .5579 L
.0616 .5579 L
.0616 .08012 L
F
.2 .63 .79 r
.06112 .08012 m
.06112 .5579 L
.0616 .5579 L
.0616 .08012 L
s
.678 .847 .902 r
.0616 .08012 m
.0616 .55738 L
.06177 .55738 L
.06177 .08012 L
F
.2 .63 .79 r
.0616 .08012 m
.0616 .55738 L
.06177 .55738 L
.06177 .08012 L
s
.678 .847 .902 r
.06177 .08012 m
.06177 .55727 L
.062 .55727 L
.062 .08012 L
F
.2 .63 .79 r
.06177 .08012 m
.06177 .55727 L
.062 .55727 L
.062 .08012 L
s
.678 .847 .902 r
.062 .08012 m
.062 .55699 L
.0622 .55699 L
.0622 .08012 L
F
.2 .63 .79 r
.062 .08012 m
.062 .55699 L
.0622 .55699 L
.0622 .08012 L
s
.678 .847 .902 r
.0622 .08012 m
.0622 .55649 L
.0626 .55649 L
.0626 .08012 L
F
.2 .63 .79 r
.0622 .08012 m
.0622 .55649 L
.0626 .55649 L
.0626 .08012 L
s
.678 .847 .902 r
.0626 .08012 m
.0626 .55614 L
.06305 .55614 L
.06305 .08012 L
F
.2 .63 .79 r
.0626 .08012 m
.0626 .55614 L
.06305 .55614 L
.06305 .08012 L
s
.678 .847 .902 r
.06305 .08012 m
.06305 .55576 L
.06325 .55576 L
.06325 .08012 L
F
.2 .63 .79 r
.06305 .08012 m
.06305 .55576 L
.06325 .55576 L
.06325 .08012 L
s
.678 .847 .902 r
.06325 .08012 m
.06325 .55546 L
.06352 .55546 L
.06352 .08012 L
F
.2 .63 .79 r
.06325 .08012 m
.06325 .55546 L
.06352 .55546 L
.06352 .08012 L
s
.678 .847 .902 r
.06352 .08012 m
.06352 .55518 L
.06382 .55518 L
.06382 .08012 L
F
.2 .63 .79 r
.06352 .08012 m
.06352 .55518 L
.06382 .55518 L
.06382 .08012 L
s
.678 .847 .902 r
.06382 .08012 m
.06382 .55484 L
.06416 .55484 L
.06416 .08012 L
F
.2 .63 .79 r
.06382 .08012 m
.06382 .55484 L
.06416 .55484 L
.06416 .08012 L
s
.678 .847 .902 r
.06416 .08012 m
.06416 .55439 L
.0644 .55439 L
.0644 .08012 L
F
.2 .63 .79 r
.06416 .08012 m
.06416 .55439 L
.0644 .55439 L
.0644 .08012 L
s
.678 .847 .902 r
.0644 .08012 m
.0644 .55375 L
.0648 .55375 L
.0648 .08012 L
F
.2 .63 .79 r
.0644 .08012 m
.0644 .55375 L
.0648 .55375 L
.0648 .08012 L
s
.678 .847 .902 r
.0648 .08012 m
.0648 .55365 L
.06529 .55365 L
.06529 .08012 L
F
.2 .63 .79 r
.0648 .08012 m
.0648 .55365 L
.06529 .55365 L
.06529 .08012 L
s
.678 .847 .902 r
.06529 .08012 m
.06529 .55305 L
.06553 .55305 L
.06553 .08012 L
F
.2 .63 .79 r
.06529 .08012 m
.06529 .55305 L
.06553 .55305 L
.06553 .08012 L
s
.678 .847 .902 r
.06553 .08012 m
.06553 .55282 L
.06585 .55282 L
.06585 .08012 L
F
.2 .63 .79 r
.06553 .08012 m
.06553 .55282 L
.06585 .55282 L
.06585 .08012 L
s
.678 .847 .902 r
.06585 .08012 m
.06585 .55239 L
.06602 .55239 L
.06602 .08012 L
F
.2 .63 .79 r
.06585 .08012 m
.06585 .55239 L
.06602 .55239 L
.06602 .08012 L
s
.678 .847 .902 r
.06602 .08012 m
.06602 .55199 L
.06638 .55199 L
.06638 .08012 L
F
.2 .63 .79 r
.06602 .08012 m
.06602 .55199 L
.06638 .55199 L
.06638 .08012 L
s
.678 .847 .902 r
.06638 .08012 m
.06638 .55186 L
.06653 .55186 L
.06653 .08012 L
F
.2 .63 .79 r
.06638 .08012 m
.06638 .55186 L
.06653 .55186 L
.06653 .08012 L
s
.678 .847 .902 r
.06653 .08012 m
.06653 .55157 L
.06694 .55157 L
.06694 .08012 L
F
.2 .63 .79 r
.06653 .08012 m
.06653 .55157 L
.06694 .55157 L
.06694 .08012 L
s
.678 .847 .902 r
.06694 .08012 m
.06694 .55116 L
.06712 .55116 L
.06712 .08012 L
F
.2 .63 .79 r
.06694 .08012 m
.06694 .55116 L
.06712 .55116 L
.06712 .08012 L
s
.678 .847 .902 r
.06712 .08012 m
.06712 .55058 L
.06756 .55058 L
.06756 .08012 L
F
.2 .63 .79 r
.06712 .08012 m
.06712 .55058 L
.06756 .55058 L
.06756 .08012 L
s
.678 .847 .902 r
.06756 .08012 m
.06756 .55025 L
.06791 .55025 L
.06791 .08012 L
F
.2 .63 .79 r
.06756 .08012 m
.06756 .55025 L
.06791 .55025 L
.06791 .08012 L
s
.678 .847 .902 r
.06791 .08012 m
.06791 .55001 L
.06814 .55001 L
.06814 .08012 L
F
.2 .63 .79 r
.06791 .08012 m
.06791 .55001 L
.06814 .55001 L
.06814 .08012 L
s
.678 .847 .902 r
.06814 .08012 m
.06814 .54973 L
.06853 .54973 L
.06853 .08012 L
F
.2 .63 .79 r
.06814 .08012 m
.06814 .54973 L
.06853 .54973 L
.06853 .08012 L
s
.678 .847 .902 r
.06853 .08012 m
.06853 .54909 L
.06899 .54909 L
.06899 .08012 L
F
.2 .63 .79 r
.06853 .08012 m
.06853 .54909 L
.06899 .54909 L
.06899 .08012 L
s
.678 .847 .902 r
.06899 .08012 m
.06899 .54847 L
.06931 .54847 L
.06931 .08012 L
F
.2 .63 .79 r
.06899 .08012 m
.06899 .54847 L
.06931 .54847 L
.06931 .08012 L
s
.678 .847 .902 r
.06931 .08012 m
.06931 .54824 L
.06946 .54824 L
.06946 .08012 L
F
.2 .63 .79 r
.06931 .08012 m
.06931 .54824 L
.06946 .54824 L
.06946 .08012 L
s
.678 .847 .902 r
.06946 .08012 m
.06946 .5479 L
.0698 .5479 L
.0698 .08012 L
F
.2 .63 .79 r
.06946 .08012 m
.06946 .5479 L
.0698 .5479 L
.0698 .08012 L
s
.678 .847 .902 r
.0698 .08012 m
.0698 .54766 L
.07001 .54766 L
.07001 .08012 L
F
.2 .63 .79 r
.0698 .08012 m
.0698 .54766 L
.07001 .54766 L
.07001 .08012 L
s
.678 .847 .902 r
.07001 .08012 m
.07001 .5474 L
.07037 .5474 L
.07037 .08012 L
F
.2 .63 .79 r
.07001 .08012 m
.07001 .5474 L
.07037 .5474 L
.07037 .08012 L
s
.678 .847 .902 r
.07037 .08012 m
.07037 .54677 L
.07082 .54677 L
.07082 .08012 L
F
.2 .63 .79 r
.07037 .08012 m
.07037 .54677 L
.07082 .54677 L
.07082 .08012 L
s
.678 .847 .902 r
.07082 .08012 m
.07082 .54652 L
.07103 .54652 L
.07103 .08012 L
F
.2 .63 .79 r
.07082 .08012 m
.07082 .54652 L
.07103 .54652 L
.07103 .08012 L
s
.678 .847 .902 r
.07103 .08012 m
.07103 .54614 L
.07143 .54614 L
.07143 .08012 L
F
.2 .63 .79 r
.07103 .08012 m
.07103 .54614 L
.07143 .54614 L
.07143 .08012 L
s
.678 .847 .902 r
.07143 .08012 m
.07143 .54586 L
.07161 .54586 L
.07161 .08012 L
F
.2 .63 .79 r
.07143 .08012 m
.07143 .54586 L
.07161 .54586 L
.07161 .08012 L
s
.678 .847 .902 r
.07161 .08012 m
.07161 .54557 L
.07196 .54557 L
.07196 .08012 L
F
.2 .63 .79 r
.07161 .08012 m
.07161 .54557 L
.07196 .54557 L
.07196 .08012 L
s
.678 .847 .902 r
.07196 .08012 m
.07196 .54512 L
.07226 .54512 L
.07226 .08012 L
F
.2 .63 .79 r
.07196 .08012 m
.07196 .54512 L
.07226 .54512 L
.07226 .08012 L
s
.678 .847 .902 r
.07226 .08012 m
.07226 .54477 L
.07267 .54477 L
.07267 .08012 L
F
.2 .63 .79 r
.07226 .08012 m
.07226 .54477 L
.07267 .54477 L
.07267 .08012 L
s
.678 .847 .902 r
.07267 .08012 m
.07267 .54402 L
.0731 .54402 L
.0731 .08012 L
F
.2 .63 .79 r
.07267 .08012 m
.07267 .54402 L
.0731 .54402 L
.0731 .08012 L
s
.678 .847 .902 r
.0731 .08012 m
.0731 .54393 L
.07328 .54393 L
.07328 .08012 L
F
.2 .63 .79 r
.0731 .08012 m
.0731 .54393 L
.07328 .54393 L
.07328 .08012 L
s
.678 .847 .902 r
.07328 .08012 m
.07328 .54345 L
.07356 .54345 L
.07356 .08012 L
F
.2 .63 .79 r
.07328 .08012 m
.07328 .54345 L
.07356 .54345 L
.07356 .08012 L
s
.678 .847 .902 r
.07356 .08012 m
.07356 .54328 L
.07376 .54328 L
.07376 .08012 L
F
.2 .63 .79 r
.07356 .08012 m
.07356 .54328 L
.07376 .54328 L
.07376 .08012 L
s
.678 .847 .902 r
.07376 .08012 m
.07376 .54281 L
.07418 .54281 L
.07418 .08012 L
F
.2 .63 .79 r
.07376 .08012 m
.07376 .54281 L
.07418 .54281 L
.07418 .08012 L
s
.678 .847 .902 r
.07418 .08012 m
.07418 .54241 L
.07444 .54241 L
.07444 .08012 L
F
.2 .63 .79 r
.07418 .08012 m
.07418 .54241 L
.07444 .54241 L
.07444 .08012 L
s
.678 .847 .902 r
.07444 .08012 m
.07444 .5422 L
.07469 .5422 L
.07469 .08012 L
F
.2 .63 .79 r
.07444 .08012 m
.07444 .5422 L
.07469 .5422 L
.07469 .08012 L
s
.678 .847 .902 r
.07469 .08012 m
.07469 .54186 L
.07494 .54186 L
.07494 .08012 L
F
.2 .63 .79 r
.07469 .08012 m
.07469 .54186 L
.07494 .54186 L
.07494 .08012 L
s
.678 .847 .902 r
.07494 .08012 m
.07494 .54176 L
.07516 .54176 L
.07516 .08012 L
F
.2 .63 .79 r
.07494 .08012 m
.07494 .54176 L
.07516 .54176 L
.07516 .08012 L
s
.678 .847 .902 r
.07516 .08012 m
.07516 .54141 L
.07533 .54141 L
.07533 .08012 L
F
.2 .63 .79 r
.07516 .08012 m
.07516 .54141 L
.07533 .54141 L
.07533 .08012 L
s
.678 .847 .902 r
.07533 .08012 m
.07533 .54114 L
.07569 .54114 L
.07569 .08012 L
F
.2 .63 .79 r
.07533 .08012 m
.07533 .54114 L
.07569 .54114 L
.07569 .08012 L
s
.678 .847 .902 r
.07569 .08012 m
.07569 .54082 L
.07598 .54082 L
.07598 .08012 L
F
.2 .63 .79 r
.07569 .08012 m
.07569 .54082 L
.07598 .54082 L
.07598 .08012 L
s
.678 .847 .902 r
.07598 .08012 m
.07598 .54045 L
.07636 .54045 L
.07636 .08012 L
F
.2 .63 .79 r
.07598 .08012 m
.07598 .54045 L
.07636 .54045 L
.07636 .08012 L
s
.678 .847 .902 r
.07636 .08012 m
.07636 .54 L
.07653 .54 L
.07653 .08012 L
F
.2 .63 .79 r
.07636 .08012 m
.07636 .54 L
.07653 .54 L
.07653 .08012 L
s
.678 .847 .902 r
.07653 .08012 m
.07653 .53983 L
.0767 .53983 L
.0767 .08012 L
F
.2 .63 .79 r
.07653 .08012 m
.07653 .53983 L
.0767 .53983 L
.0767 .08012 L
s
.678 .847 .902 r
.0767 .08012 m
.0767 .5396 L
.07693 .5396 L
.07693 .08012 L
F
.2 .63 .79 r
.0767 .08012 m
.0767 .5396 L
.07693 .5396 L
.07693 .08012 L
s
.678 .847 .902 r
.07693 .08012 m
.07693 .53932 L
.07709 .53932 L
.07709 .08012 L
F
.2 .63 .79 r
.07693 .08012 m
.07693 .53932 L
.07709 .53932 L
.07709 .08012 L
s
.678 .847 .902 r
.07709 .08012 m
.07709 .53905 L
.07731 .53905 L
.07731 .08012 L
F
.2 .63 .79 r
.07709 .08012 m
.07709 .53905 L
.07731 .53905 L
.07731 .08012 L
s
.678 .847 .902 r
.07731 .08012 m
.07731 .53896 L
.07776 .53896 L
.07776 .08012 L
F
.2 .63 .79 r
.07731 .08012 m
.07731 .53896 L
.07776 .53896 L
.07776 .08012 L
s
.678 .847 .902 r
.07776 .08012 m
.07776 .5385 L
.07808 .5385 L
.07808 .08012 L
F
.2 .63 .79 r
.07776 .08012 m
.07776 .5385 L
.07808 .5385 L
.07808 .08012 L
s
.678 .847 .902 r
.07808 .08012 m
.07808 .53783 L
.07856 .53783 L
.07856 .08012 L
F
.2 .63 .79 r
.07808 .08012 m
.07808 .53783 L
.07856 .53783 L
.07856 .08012 L
s
.678 .847 .902 r
.07856 .08012 m
.07856 .53734 L
.07892 .53734 L
.07892 .08012 L
F
.2 .63 .79 r
.07856 .08012 m
.07856 .53734 L
.07892 .53734 L
.07892 .08012 L
s
.678 .847 .902 r
.07892 .08012 m
.07892 .53696 L
.07921 .53696 L
.07921 .08012 L
F
.2 .63 .79 r
.07892 .08012 m
.07892 .53696 L
.07921 .53696 L
.07921 .08012 L
s
.678 .847 .902 r
.07921 .08012 m
.07921 .53651 L
.07961 .53651 L
.07961 .08012 L
F
.2 .63 .79 r
.07921 .08012 m
.07921 .53651 L
.07961 .53651 L
.07961 .08012 L
s
.678 .847 .902 r
.07961 .08012 m
.07961 .5362 L
.07982 .5362 L
.07982 .08012 L
F
.2 .63 .79 r
.07961 .08012 m
.07961 .5362 L
.07982 .5362 L
.07982 .08012 L
s
.678 .847 .902 r
.07982 .08012 m
.07982 .53598 L
.08015 .53598 L
.08015 .08012 L
F
.2 .63 .79 r
.07982 .08012 m
.07982 .53598 L
.08015 .53598 L
.08015 .08012 L
s
.678 .847 .902 r
.08015 .08012 m
.08015 .53562 L
.0803 .53562 L
.0803 .08012 L
F
.2 .63 .79 r
.08015 .08012 m
.08015 .53562 L
.0803 .53562 L
.0803 .08012 L
s
.678 .847 .902 r
.0803 .08012 m
.0803 .53554 L
.08065 .53554 L
.08065 .08012 L
F
.2 .63 .79 r
.0803 .08012 m
.0803 .53554 L
.08065 .53554 L
.08065 .08012 L
s
.678 .847 .902 r
.08065 .08012 m
.08065 .53487 L
.08093 .53487 L
.08093 .08012 L
F
.2 .63 .79 r
.08065 .08012 m
.08065 .53487 L
.08093 .53487 L
.08093 .08012 L
s
.678 .847 .902 r
.08093 .08012 m
.08093 .53472 L
.08115 .53472 L
.08115 .08012 L
F
.2 .63 .79 r
.08093 .08012 m
.08093 .53472 L
.08115 .53472 L
.08115 .08012 L
s
.678 .847 .902 r
.08115 .08012 m
.08115 .53412 L
.08154 .53412 L
.08154 .08012 L
F
.2 .63 .79 r
.08115 .08012 m
.08115 .53412 L
.08154 .53412 L
.08154 .08012 L
s
.678 .847 .902 r
.08154 .08012 m
.08154 .53406 L
.08179 .53406 L
.08179 .08012 L
F
.2 .63 .79 r
.08154 .08012 m
.08154 .53406 L
.08179 .53406 L
.08179 .08012 L
s
.678 .847 .902 r
.08179 .08012 m
.08179 .53367 L
.082 .53367 L
.082 .08012 L
F
.2 .63 .79 r
.08179 .08012 m
.08179 .53367 L
.082 .53367 L
.082 .08012 L
s
.678 .847 .902 r
.082 .08012 m
.082 .53344 L
.08219 .53344 L
.08219 .08012 L
F
.2 .63 .79 r
.082 .08012 m
.082 .53344 L
.08219 .53344 L
.08219 .08012 L
s
.678 .847 .902 r
.08219 .08012 m
.08219 .53327 L
.08238 .53327 L
.08238 .08012 L
F
.2 .63 .79 r
.08219 .08012 m
.08219 .53327 L
.08238 .53327 L
.08238 .08012 L
s
.678 .847 .902 r
.08238 .08012 m
.08238 .53271 L
.08282 .53271 L
.08282 .08012 L
F
.2 .63 .79 r
.08238 .08012 m
.08238 .53271 L
.08282 .53271 L
.08282 .08012 L
s
.678 .847 .902 r
.08282 .08012 m
.08282 .53252 L
.08314 .53252 L
.08314 .08012 L
F
.2 .63 .79 r
.08282 .08012 m
.08282 .53252 L
.08314 .53252 L
.08314 .08012 L
s
.678 .847 .902 r
.08314 .08012 m
.08314 .53209 L
.08331 .53209 L
.08331 .08012 L
F
.2 .63 .79 r
.08314 .08012 m
.08314 .53209 L
.08331 .53209 L
.08331 .08012 L
s
.678 .847 .902 r
.08331 .08012 m
.08331 .53191 L
.08348 .53191 L
.08348 .08012 L
F
.2 .63 .79 r
.08331 .08012 m
.08331 .53191 L
.08348 .53191 L
.08348 .08012 L
s
.678 .847 .902 r
.08348 .08012 m
.08348 .53176 L
.08384 .53176 L
.08384 .08012 L
F
.2 .63 .79 r
.08348 .08012 m
.08348 .53176 L
.08384 .53176 L
.08384 .08012 L
s
.678 .847 .902 r
.08384 .08012 m
.08384 .5313 L
.08414 .5313 L
.08414 .08012 L
F
.2 .63 .79 r
.08384 .08012 m
.08384 .5313 L
.08414 .5313 L
.08414 .08012 L
s
.678 .847 .902 r
.08414 .08012 m
.08414 .53062 L
.08458 .53062 L
.08458 .08012 L
F
.2 .63 .79 r
.08414 .08012 m
.08414 .53062 L
.08458 .53062 L
.08458 .08012 L
s
.678 .847 .902 r
.08458 .08012 m
.08458 .53043 L
.08481 .53043 L
.08481 .08012 L
F
.2 .63 .79 r
.08458 .08012 m
.08458 .53043 L
.08481 .53043 L
.08481 .08012 L
s
.678 .847 .902 r
.08481 .08012 m
.08481 .53029 L
.085 .53029 L
.085 .08012 L
F
.2 .63 .79 r
.08481 .08012 m
.08481 .53029 L
.085 .53029 L
.085 .08012 L
s
.678 .847 .902 r
.085 .08012 m
.085 .52981 L
.0853 .52981 L
.0853 .08012 L
F
.2 .63 .79 r
.085 .08012 m
.085 .52981 L
.0853 .52981 L
.0853 .08012 L
s
.678 .847 .902 r
.0853 .08012 m
.0853 .52967 L
.08553 .52967 L
.08553 .08012 L
F
.2 .63 .79 r
.0853 .08012 m
.0853 .52967 L
.08553 .52967 L
.08553 .08012 L
s
.678 .847 .902 r
.08553 .08012 m
.08553 .52949 L
.08596 .52949 L
.08596 .08012 L
F
.2 .63 .79 r
.08553 .08012 m
.08553 .52949 L
.08596 .52949 L
.08596 .08012 L
s
.678 .847 .902 r
.08596 .08012 m
.08596 .52884 L
.08624 .52884 L
.08624 .08012 L
F
.2 .63 .79 r
.08596 .08012 m
.08596 .52884 L
.08624 .52884 L
.08624 .08012 L
s
.678 .847 .902 r
.08624 .08012 m
.08624 .52863 L
.08648 .52863 L
.08648 .08012 L
F
.2 .63 .79 r
.08624 .08012 m
.08624 .52863 L
.08648 .52863 L
.08648 .08012 L
s
.678 .847 .902 r
.08648 .08012 m
.08648 .52796 L
.08687 .52796 L
.08687 .08012 L
F
.2 .63 .79 r
.08648 .08012 m
.08648 .52796 L
.08687 .52796 L
.08687 .08012 L
s
.678 .847 .902 r
.08687 .08012 m
.08687 .52777 L
.0873 .52777 L
.0873 .08012 L
F
.2 .63 .79 r
.08687 .08012 m
.08687 .52777 L
.0873 .52777 L
.0873 .08012 L
s
.678 .847 .902 r
.0873 .08012 m
.0873 .52723 L
.08772 .52723 L
.08772 .08012 L
F
.2 .63 .79 r
.0873 .08012 m
.0873 .52723 L
.08772 .52723 L
.08772 .08012 L
s
.678 .847 .902 r
.08772 .08012 m
.08772 .5268 L
.08817 .5268 L
.08817 .08012 L
F
.2 .63 .79 r
.08772 .08012 m
.08772 .5268 L
.08817 .5268 L
.08817 .08012 L
s
.678 .847 .902 r
.08817 .08012 m
.08817 .52624 L
.0885 .52624 L
.0885 .08012 L
F
.2 .63 .79 r
.08817 .08012 m
.08817 .52624 L
.0885 .52624 L
.0885 .08012 L
s
.678 .847 .902 r
.0885 .08012 m
.0885 .526 L
.08868 .526 L
.08868 .08012 L
F
.2 .63 .79 r
.0885 .08012 m
.0885 .526 L
.08868 .526 L
.08868 .08012 L
s
.678 .847 .902 r
.08868 .08012 m
.08868 .52578 L
.089 .52578 L
.089 .08012 L
F
.2 .63 .79 r
.08868 .08012 m
.08868 .52578 L
.089 .52578 L
.089 .08012 L
s
.678 .847 .902 r
.089 .08012 m
.089 .5252 L
.08939 .5252 L
.08939 .08012 L
F
.2 .63 .79 r
.089 .08012 m
.089 .5252 L
.08939 .5252 L
.08939 .08012 L
s
.678 .847 .902 r
.08939 .08012 m
.08939 .52475 L
.08968 .52475 L
.08968 .08012 L
F
.2 .63 .79 r
.08939 .08012 m
.08939 .52475 L
.08968 .52475 L
.08968 .08012 L
s
.678 .847 .902 r
.08968 .08012 m
.08968 .52423 L
.09016 .52423 L
.09016 .08012 L
F
.2 .63 .79 r
.08968 .08012 m
.08968 .52423 L
.09016 .52423 L
.09016 .08012 L
s
.678 .847 .902 r
.09016 .08012 m
.09016 .524 L
.09052 .524 L
.09052 .08012 L
F
.2 .63 .79 r
.09016 .08012 m
.09016 .524 L
.09052 .524 L
.09052 .08012 L
s
.678 .847 .902 r
.09052 .08012 m
.09052 .52366 L
.09075 .52366 L
.09075 .08012 L
F
.2 .63 .79 r
.09052 .08012 m
.09052 .52366 L
.09075 .52366 L
.09075 .08012 L
s
.678 .847 .902 r
.09075 .08012 m
.09075 .52319 L
.09102 .52319 L
.09102 .08012 L
F
.2 .63 .79 r
.09075 .08012 m
.09075 .52319 L
.09102 .52319 L
.09102 .08012 L
s
.678 .847 .902 r
.09102 .08012 m
.09102 .52314 L
.09147 .52314 L
.09147 .08012 L
F
.2 .63 .79 r
.09102 .08012 m
.09102 .52314 L
.09147 .52314 L
.09147 .08012 L
s
.678 .847 .902 r
.09147 .08012 m
.09147 .52258 L
.09196 .52258 L
.09196 .08012 L
F
.2 .63 .79 r
.09147 .08012 m
.09147 .52258 L
.09196 .52258 L
.09196 .08012 L
s
.678 .847 .902 r
.09196 .08012 m
.09196 .52165 L
.09238 .52165 L
.09238 .08012 L
F
.2 .63 .79 r
.09196 .08012 m
.09196 .52165 L
.09238 .52165 L
.09238 .08012 L
s
.678 .847 .902 r
.09238 .08012 m
.09238 .52124 L
.09271 .52124 L
.09271 .08012 L
F
.2 .63 .79 r
.09238 .08012 m
.09238 .52124 L
.09271 .52124 L
.09271 .08012 L
s
.678 .847 .902 r
.09271 .08012 m
.09271 .52106 L
.09308 .52106 L
.09308 .08012 L
F
.2 .63 .79 r
.09271 .08012 m
.09271 .52106 L
.09308 .52106 L
.09308 .08012 L
s
.678 .847 .902 r
.09308 .08012 m
.09308 .52033 L
.09353 .52033 L
.09353 .08012 L
F
.2 .63 .79 r
.09308 .08012 m
.09308 .52033 L
.09353 .52033 L
.09353 .08012 L
s
.678 .847 .902 r
.09353 .08012 m
.09353 .52028 L
.09379 .52028 L
.09379 .08012 L
F
.2 .63 .79 r
.09353 .08012 m
.09353 .52028 L
.09379 .52028 L
.09379 .08012 L
s
.678 .847 .902 r
.09379 .08012 m
.09379 .51981 L
.09404 .51981 L
.09404 .08012 L
F
.2 .63 .79 r
.09379 .08012 m
.09379 .51981 L
.09404 .51981 L
.09404 .08012 L
s
.678 .847 .902 r
.09404 .08012 m
.09404 .51952 L
.09448 .51952 L
.09448 .08012 L
F
.2 .63 .79 r
.09404 .08012 m
.09404 .51952 L
.09448 .51952 L
.09448 .08012 L
s
.678 .847 .902 r
.09448 .08012 m
.09448 .51906 L
.0948 .51906 L
.0948 .08012 L
F
.2 .63 .79 r
.09448 .08012 m
.09448 .51906 L
.0948 .51906 L
.0948 .08012 L
s
.678 .847 .902 r
.0948 .08012 m
.0948 .51869 L
.09496 .51869 L
.09496 .08012 L
F
.2 .63 .79 r
.0948 .08012 m
.0948 .51869 L
.09496 .51869 L
.09496 .08012 L
s
.678 .847 .902 r
.09496 .08012 m
.09496 .5184 L
.09531 .5184 L
.09531 .08012 L
F
.2 .63 .79 r
.09496 .08012 m
.09496 .5184 L
.09531 .5184 L
.09531 .08012 L
s
.678 .847 .902 r
.09531 .08012 m
.09531 .51825 L
.09547 .51825 L
.09547 .08012 L
F
.2 .63 .79 r
.09531 .08012 m
.09531 .51825 L
.09547 .51825 L
.09547 .08012 L
s
.678 .847 .902 r
.09547 .08012 m
.09547 .51765 L
.09586 .51765 L
.09586 .08012 L
F
.2 .63 .79 r
.09547 .08012 m
.09547 .51765 L
.09586 .51765 L
.09586 .08012 L
s
.678 .847 .902 r
.09586 .08012 m
.09586 .51751 L
.09606 .51751 L
.09606 .08012 L
F
.2 .63 .79 r
.09586 .08012 m
.09586 .51751 L
.09606 .51751 L
.09606 .08012 L
s
.678 .847 .902 r
.09606 .08012 m
.09606 .51739 L
.09623 .51739 L
.09623 .08012 L
F
.2 .63 .79 r
.09606 .08012 m
.09606 .51739 L
.09623 .51739 L
.09623 .08012 L
s
.678 .847 .902 r
.09623 .08012 m
.09623 .51685 L
.0967 .51685 L
.0967 .08012 L
F
.2 .63 .79 r
.09623 .08012 m
.09623 .51685 L
.0967 .51685 L
.0967 .08012 L
s
.678 .847 .902 r
.0967 .08012 m
.0967 .51649 L
.09693 .51649 L
.09693 .08012 L
F
.2 .63 .79 r
.0967 .08012 m
.0967 .51649 L
.09693 .51649 L
.09693 .08012 L
s
.678 .847 .902 r
.09693 .08012 m
.09693 .51613 L
.09722 .51613 L
.09722 .08012 L
F
.2 .63 .79 r
.09693 .08012 m
.09693 .51613 L
.09722 .51613 L
.09722 .08012 L
s
.678 .847 .902 r
.09722 .08012 m
.09722 .51599 L
.0976 .51599 L
.0976 .08012 L
F
.2 .63 .79 r
.09722 .08012 m
.09722 .51599 L
.0976 .51599 L
.0976 .08012 L
s
.678 .847 .902 r
.0976 .08012 m
.0976 .51522 L
.09808 .51522 L
.09808 .08012 L
F
.2 .63 .79 r
.0976 .08012 m
.0976 .51522 L
.09808 .51522 L
.09808 .08012 L
s
.678 .847 .902 r
.09808 .08012 m
.09808 .51497 L
.09844 .51497 L
.09844 .08012 L
F
.2 .63 .79 r
.09808 .08012 m
.09808 .51497 L
.09844 .51497 L
.09844 .08012 L
s
.678 .847 .902 r
.09844 .08012 m
.09844 .51457 L
.09865 .51457 L
.09865 .08012 L
F
.2 .63 .79 r
.09844 .08012 m
.09844 .51457 L
.09865 .51457 L
.09865 .08012 L
s
.678 .847 .902 r
.09865 .08012 m
.09865 .51437 L
.09891 .51437 L
.09891 .08012 L
F
.2 .63 .79 r
.09865 .08012 m
.09865 .51437 L
.09891 .51437 L
.09891 .08012 L
s
.678 .847 .902 r
.09891 .08012 m
.09891 .51401 L
.09908 .51401 L
.09908 .08012 L
F
.2 .63 .79 r
.09891 .08012 m
.09891 .51401 L
.09908 .51401 L
.09908 .08012 L
s
.678 .847 .902 r
.09908 .08012 m
.09908 .51388 L
.09944 .51388 L
.09944 .08012 L
F
.2 .63 .79 r
.09908 .08012 m
.09908 .51388 L
.09944 .51388 L
.09944 .08012 L
s
.678 .847 .902 r
.09944 .08012 m
.09944 .51336 L
.09973 .51336 L
.09973 .08012 L
F
.2 .63 .79 r
.09944 .08012 m
.09944 .51336 L
.09973 .51336 L
.09973 .08012 L
s
.678 .847 .902 r
.09973 .08012 m
.09973 .5131 L
.10015 .5131 L
.10015 .08012 L
F
.2 .63 .79 r
.09973 .08012 m
.09973 .5131 L
.10015 .5131 L
.10015 .08012 L
s
.678 .847 .902 r
.10015 .08012 m
.10015 .51264 L
.10044 .51264 L
.10044 .08012 L
F
.2 .63 .79 r
.10015 .08012 m
.10015 .51264 L
.10044 .51264 L
.10044 .08012 L
s
.678 .847 .902 r
.10044 .08012 m
.10044 .51229 L
.10085 .51229 L
.10085 .08012 L
F
.2 .63 .79 r
.10044 .08012 m
.10044 .51229 L
.10085 .51229 L
.10085 .08012 L
s
.678 .847 .902 r
.10085 .08012 m
.10085 .51184 L
.10102 .51184 L
.10102 .08012 L
F
.2 .63 .79 r
.10085 .08012 m
.10085 .51184 L
.10102 .51184 L
.10102 .08012 L
s
.678 .847 .902 r
.10102 .08012 m
.10102 .51153 L
.10134 .51153 L
.10134 .08012 L
F
.2 .63 .79 r
.10102 .08012 m
.10102 .51153 L
.10134 .51153 L
.10134 .08012 L
s
.678 .847 .902 r
.10134 .08012 m
.10134 .51103 L
.10169 .51103 L
.10169 .08012 L
F
.2 .63 .79 r
.10134 .08012 m
.10134 .51103 L
.10169 .51103 L
.10169 .08012 L
s
.678 .847 .902 r
.10169 .08012 m
.10169 .51077 L
.10192 .51077 L
.10192 .08012 L
F
.2 .63 .79 r
.10169 .08012 m
.10169 .51077 L
.10192 .51077 L
.10192 .08012 L
s
.678 .847 .902 r
.10192 .08012 m
.10192 .5106 L
.10209 .5106 L
.10209 .08012 L
F
.2 .63 .79 r
.10192 .08012 m
.10192 .5106 L
.10209 .5106 L
.10209 .08012 L
s
.678 .847 .902 r
.10209 .08012 m
.10209 .51004 L
.10254 .51004 L
.10254 .08012 L
F
.2 .63 .79 r
.10209 .08012 m
.10209 .51004 L
.10254 .51004 L
.10254 .08012 L
s
.678 .847 .902 r
.10254 .08012 m
.10254 .50968 L
.10288 .50968 L
.10288 .08012 L
F
.2 .63 .79 r
.10254 .08012 m
.10254 .50968 L
.10288 .50968 L
.10288 .08012 L
s
.678 .847 .902 r
.10288 .08012 m
.10288 .50931 L
.10321 .50931 L
.10321 .08012 L
F
.2 .63 .79 r
.10288 .08012 m
.10288 .50931 L
.10321 .50931 L
.10321 .08012 L
s
.678 .847 .902 r
.10321 .08012 m
.10321 .50917 L
.10367 .50917 L
.10367 .08012 L
F
.2 .63 .79 r
.10321 .08012 m
.10321 .50917 L
.10367 .50917 L
.10367 .08012 L
s
.678 .847 .902 r
.10367 .08012 m
.10367 .50831 L
.10409 .50831 L
.10409 .08012 L
F
.2 .63 .79 r
.10367 .08012 m
.10367 .50831 L
.10409 .50831 L
.10409 .08012 L
s
.678 .847 .902 r
.10409 .08012 m
.10409 .50817 L
.10446 .50817 L
.10446 .08012 L
F
.2 .63 .79 r
.10409 .08012 m
.10409 .50817 L
.10446 .50817 L
.10446 .08012 L
s
.678 .847 .902 r
.10446 .08012 m
.10446 .5078 L
.10472 .5078 L
.10472 .08012 L
F
.2 .63 .79 r
.10446 .08012 m
.10446 .5078 L
.10472 .5078 L
.10472 .08012 L
s
.678 .847 .902 r
.10472 .08012 m
.10472 .50744 L
.10503 .50744 L
.10503 .08012 L
F
.2 .63 .79 r
.10472 .08012 m
.10472 .50744 L
.10503 .50744 L
.10503 .08012 L
s
.678 .847 .902 r
.10503 .08012 m
.10503 .50705 L
.10522 .50705 L
.10522 .08012 L
F
.2 .63 .79 r
.10503 .08012 m
.10503 .50705 L
.10522 .50705 L
.10522 .08012 L
s
.678 .847 .902 r
.10522 .08012 m
.10522 .50679 L
.1056 .50679 L
.1056 .08012 L
F
.2 .63 .79 r
.10522 .08012 m
.10522 .50679 L
.1056 .50679 L
.1056 .08012 L
s
.678 .847 .902 r
.1056 .08012 m
.1056 .50618 L
.10599 .50618 L
.10599 .08012 L
F
.2 .63 .79 r
.1056 .08012 m
.1056 .50618 L
.10599 .50618 L
.10599 .08012 L
s
.678 .847 .902 r
.10599 .08012 m
.10599 .50587 L
.10624 .50587 L
.10624 .08012 L
F
.2 .63 .79 r
.10599 .08012 m
.10599 .50587 L
.10624 .50587 L
.10624 .08012 L
s
.678 .847 .902 r
.10624 .08012 m
.10624 .50561 L
.10666 .50561 L
.10666 .08012 L
F
.2 .63 .79 r
.10624 .08012 m
.10624 .50561 L
.10666 .50561 L
.10666 .08012 L
s
.678 .847 .902 r
.10666 .08012 m
.10666 .50506 L
.10702 .50506 L
.10702 .08012 L
F
.2 .63 .79 r
.10666 .08012 m
.10666 .50506 L
.10702 .50506 L
.10702 .08012 L
s
.678 .847 .902 r
.10702 .08012 m
.10702 .50482 L
.10719 .50482 L
.10719 .08012 L
F
.2 .63 .79 r
.10702 .08012 m
.10702 .50482 L
.10719 .50482 L
.10719 .08012 L
s
.678 .847 .902 r
.10719 .08012 m
.10719 .5046 L
.10765 .5046 L
.10765 .08012 L
F
.2 .63 .79 r
.10719 .08012 m
.10719 .5046 L
.10765 .5046 L
.10765 .08012 L
s
.678 .847 .902 r
.10765 .08012 m
.10765 .50421 L
.1078 .50421 L
.1078 .08012 L
F
.2 .63 .79 r
.10765 .08012 m
.10765 .50421 L
.1078 .50421 L
.1078 .08012 L
s
.678 .847 .902 r
.1078 .08012 m
.1078 .50396 L
.10802 .50396 L
.10802 .08012 L
F
.2 .63 .79 r
.1078 .08012 m
.1078 .50396 L
.10802 .50396 L
.10802 .08012 L
s
.678 .847 .902 r
.10802 .08012 m
.10802 .50371 L
.10827 .50371 L
.10827 .08012 L
F
.2 .63 .79 r
.10802 .08012 m
.10802 .50371 L
.10827 .50371 L
.10827 .08012 L
s
.678 .847 .902 r
.10827 .08012 m
.10827 .50316 L
.1087 .50316 L
.1087 .08012 L
F
.2 .63 .79 r
.10827 .08012 m
.10827 .50316 L
.1087 .50316 L
.1087 .08012 L
s
.678 .847 .902 r
.1087 .08012 m
.1087 .50284 L
.10903 .50284 L
.10903 .08012 L
F
.2 .63 .79 r
.1087 .08012 m
.1087 .50284 L
.10903 .50284 L
.10903 .08012 L
s
.678 .847 .902 r
.10903 .08012 m
.10903 .50247 L
.10939 .50247 L
.10939 .08012 L
F
.2 .63 .79 r
.10903 .08012 m
.10903 .50247 L
.10939 .50247 L
.10939 .08012 L
s
.678 .847 .902 r
.10939 .08012 m
.10939 .50217 L
.10956 .50217 L
.10956 .08012 L
F
.2 .63 .79 r
.10939 .08012 m
.10939 .50217 L
.10956 .50217 L
.10956 .08012 L
s
.678 .847 .902 r
.10956 .08012 m
.10956 .50204 L
.10997 .50204 L
.10997 .08012 L
F
.2 .63 .79 r
.10956 .08012 m
.10956 .50204 L
.10997 .50204 L
.10997 .08012 L
s
.678 .847 .902 r
.10997 .08012 m
.10997 .50137 L
.11034 .50137 L
.11034 .08012 L
F
.2 .63 .79 r
.10997 .08012 m
.10997 .50137 L
.11034 .50137 L
.11034 .08012 L
s
.678 .847 .902 r
.11034 .08012 m
.11034 .50109 L
.11051 .50109 L
.11051 .08012 L
F
.2 .63 .79 r
.11034 .08012 m
.11034 .50109 L
.11051 .50109 L
.11051 .08012 L
s
.678 .847 .902 r
.11051 .08012 m
.11051 .50077 L
.11083 .50077 L
.11083 .08012 L
F
.2 .63 .79 r
.11051 .08012 m
.11051 .50077 L
.11083 .50077 L
.11083 .08012 L
s
.678 .847 .902 r
.11083 .08012 m
.11083 .50019 L
.11127 .50019 L
.11127 .08012 L
F
.2 .63 .79 r
.11083 .08012 m
.11083 .50019 L
.11127 .50019 L
.11127 .08012 L
s
.678 .847 .902 r
.11127 .08012 m
.11127 .4998 L
.11172 .4998 L
.11172 .08012 L
F
.2 .63 .79 r
.11127 .08012 m
.11127 .4998 L
.11172 .4998 L
.11172 .08012 L
s
.678 .847 .902 r
.11172 .08012 m
.11172 .49953 L
.11201 .49953 L
.11201 .08012 L
F
.2 .63 .79 r
.11172 .08012 m
.11172 .49953 L
.11201 .49953 L
.11201 .08012 L
s
.678 .847 .902 r
.11201 .08012 m
.11201 .49921 L
.11223 .49921 L
.11223 .08012 L
F
.2 .63 .79 r
.11201 .08012 m
.11201 .49921 L
.11223 .49921 L
.11223 .08012 L
s
.678 .847 .902 r
.11223 .08012 m
.11223 .49891 L
.1125 .49891 L
.1125 .08012 L
F
.2 .63 .79 r
.11223 .08012 m
.11223 .49891 L
.1125 .49891 L
.1125 .08012 L
s
.678 .847 .902 r
.1125 .08012 m
.1125 .49878 L
.11291 .49878 L
.11291 .08012 L
F
.2 .63 .79 r
.1125 .08012 m
.1125 .49878 L
.11291 .49878 L
.11291 .08012 L
s
.678 .847 .902 r
.11291 .08012 m
.11291 .4979 L
.1133 .4979 L
.1133 .08012 L
F
.2 .63 .79 r
.11291 .08012 m
.11291 .4979 L
.1133 .4979 L
.1133 .08012 L
s
.678 .847 .902 r
.1133 .08012 m
.1133 .49764 L
.11363 .49764 L
.11363 .08012 L
F
.2 .63 .79 r
.1133 .08012 m
.1133 .49764 L
.11363 .49764 L
.11363 .08012 L
s
.678 .847 .902 r
.11363 .08012 m
.11363 .49739 L
.1138 .49739 L
.1138 .08012 L
F
.2 .63 .79 r
.11363 .08012 m
.11363 .49739 L
.1138 .49739 L
.1138 .08012 L
s
.678 .847 .902 r
.1138 .08012 m
.1138 .49704 L
.11428 .49704 L
.11428 .08012 L
F
.2 .63 .79 r
.1138 .08012 m
.1138 .49704 L
.11428 .49704 L
.11428 .08012 L
s
.678 .847 .902 r
.11428 .08012 m
.11428 .49676 L
.11446 .49676 L
.11446 .08012 L
F
.2 .63 .79 r
.11428 .08012 m
.11428 .49676 L
.11446 .49676 L
.11446 .08012 L
s
.678 .847 .902 r
.11446 .08012 m
.11446 .4966 L
.11477 .4966 L
.11477 .08012 L
F
.2 .63 .79 r
.11446 .08012 m
.11446 .4966 L
.11477 .4966 L
.11477 .08012 L
s
.678 .847 .902 r
.11477 .08012 m
.11477 .49616 L
.11498 .49616 L
.11498 .08012 L
F
.2 .63 .79 r
.11477 .08012 m
.11477 .49616 L
.11498 .49616 L
.11498 .08012 L
s
.678 .847 .902 r
.11498 .08012 m
.11498 .49584 L
.11545 .49584 L
.11545 .08012 L
F
.2 .63 .79 r
.11498 .08012 m
.11498 .49584 L
.11545 .49584 L
.11545 .08012 L
s
.678 .847 .902 r
.11545 .08012 m
.11545 .49511 L
.1159 .49511 L
.1159 .08012 L
F
.2 .63 .79 r
.11545 .08012 m
.11545 .49511 L
.1159 .49511 L
.1159 .08012 L
s
.678 .847 .902 r
.1159 .08012 m
.1159 .49486 L
.1161 .49486 L
.1161 .08012 L
F
.2 .63 .79 r
.1159 .08012 m
.1159 .49486 L
.1161 .49486 L
.1161 .08012 L
s
.678 .847 .902 r
.1161 .08012 m
.1161 .49458 L
.11638 .49458 L
.11638 .08012 L
F
.2 .63 .79 r
.1161 .08012 m
.1161 .49458 L
.11638 .49458 L
.11638 .08012 L
s
.678 .847 .902 r
.11638 .08012 m
.11638 .49423 L
.11666 .49423 L
.11666 .08012 L
F
.2 .63 .79 r
.11638 .08012 m
.11638 .49423 L
.11666 .49423 L
.11666 .08012 L
s
.678 .847 .902 r
.11666 .08012 m
.11666 .49408 L
.11691 .49408 L
.11691 .08012 L
F
.2 .63 .79 r
.11666 .08012 m
.11666 .49408 L
.11691 .49408 L
.11691 .08012 L
s
.678 .847 .902 r
.11691 .08012 m
.11691 .49367 L
.11709 .49367 L
.11709 .08012 L
F
.2 .63 .79 r
.11691 .08012 m
.11691 .49367 L
.11709 .49367 L
.11709 .08012 L
s
.678 .847 .902 r
.11709 .08012 m
.11709 .49348 L
.11745 .49348 L
.11745 .08012 L
F
.2 .63 .79 r
.11709 .08012 m
.11709 .49348 L
.11745 .49348 L
.11745 .08012 L
s
.678 .847 .902 r
.11745 .08012 m
.11745 .49322 L
.11785 .49322 L
.11785 .08012 L
F
.2 .63 .79 r
.11745 .08012 m
.11745 .49322 L
.11785 .49322 L
.11785 .08012 L
s
.678 .847 .902 r
.11785 .08012 m
.11785 .49268 L
.11808 .49268 L
.11808 .08012 L
F
.2 .63 .79 r
.11785 .08012 m
.11785 .49268 L
.11808 .49268 L
.11808 .08012 L
s
.678 .847 .902 r
.11808 .08012 m
.11808 .49247 L
.11842 .49247 L
.11842 .08012 L
F
.2 .63 .79 r
.11808 .08012 m
.11808 .49247 L
.11842 .49247 L
.11842 .08012 L
s
.678 .847 .902 r
.11842 .08012 m
.11842 .49195 L
.11884 .49195 L
.11884 .08012 L
F
.2 .63 .79 r
.11842 .08012 m
.11842 .49195 L
.11884 .49195 L
.11884 .08012 L
s
.678 .847 .902 r
.11884 .08012 m
.11884 .49154 L
.11928 .49154 L
.11928 .08012 L
F
.2 .63 .79 r
.11884 .08012 m
.11884 .49154 L
.11928 .49154 L
.11928 .08012 L
s
.678 .847 .902 r
.11928 .08012 m
.11928 .49116 L
.11971 .49116 L
.11971 .08012 L
F
.2 .63 .79 r
.11928 .08012 m
.11928 .49116 L
.11971 .49116 L
.11971 .08012 L
s
.678 .847 .902 r
.11971 .08012 m
.11971 .49053 L
.11999 .49053 L
.11999 .08012 L
F
.2 .63 .79 r
.11971 .08012 m
.11971 .49053 L
.11999 .49053 L
.11999 .08012 L
s
.678 .847 .902 r
.11999 .08012 m
.11999 .49015 L
.12028 .49015 L
.12028 .08012 L
F
.2 .63 .79 r
.11999 .08012 m
.11999 .49015 L
.12028 .49015 L
.12028 .08012 L
s
.678 .847 .902 r
.12028 .08012 m
.12028 .49005 L
.12046 .49005 L
.12046 .08012 L
F
.2 .63 .79 r
.12028 .08012 m
.12028 .49005 L
.12046 .49005 L
.12046 .08012 L
s
.678 .847 .902 r
.12046 .08012 m
.12046 .48988 L
.12065 .48988 L
.12065 .08012 L
F
.2 .63 .79 r
.12046 .08012 m
.12046 .48988 L
.12065 .48988 L
.12065 .08012 L
s
.678 .847 .902 r
.12065 .08012 m
.12065 .48969 L
.12108 .48969 L
.12108 .08012 L
F
.2 .63 .79 r
.12065 .08012 m
.12065 .48969 L
.12108 .48969 L
.12108 .08012 L
s
.678 .847 .902 r
.12108 .08012 m
.12108 .48918 L
.12136 .48918 L
.12136 .08012 L
F
.2 .63 .79 r
.12108 .08012 m
.12108 .48918 L
.12136 .48918 L
.12136 .08012 L
s
.678 .847 .902 r
.12136 .08012 m
.12136 .48876 L
.12155 .48876 L
.12155 .08012 L
F
.2 .63 .79 r
.12136 .08012 m
.12136 .48876 L
.12155 .48876 L
.12155 .08012 L
s
.678 .847 .902 r
.12155 .08012 m
.12155 .48855 L
.1217 .48855 L
.1217 .08012 L
F
.2 .63 .79 r
.12155 .08012 m
.12155 .48855 L
.1217 .48855 L
.1217 .08012 L
s
.678 .847 .902 r
.1217 .08012 m
.1217 .48853 L
.12198 .48853 L
.12198 .08012 L
F
.2 .63 .79 r
.1217 .08012 m
.1217 .48853 L
.12198 .48853 L
.12198 .08012 L
s
.678 .847 .902 r
.12198 .08012 m
.12198 .48806 L
.12219 .48806 L
.12219 .08012 L
F
.2 .63 .79 r
.12198 .08012 m
.12198 .48806 L
.12219 .48806 L
.12219 .08012 L
s
.678 .847 .902 r
.12219 .08012 m
.12219 .4879 L
.12241 .4879 L
.12241 .08012 L
F
.2 .63 .79 r
.12219 .08012 m
.12219 .4879 L
.12241 .4879 L
.12241 .08012 L
s
.678 .847 .902 r
.12241 .08012 m
.12241 .48772 L
.1226 .48772 L
.1226 .08012 L
F
.2 .63 .79 r
.12241 .08012 m
.12241 .48772 L
.1226 .48772 L
.1226 .08012 L
s
.678 .847 .902 r
.1226 .08012 m
.1226 .48743 L
.12282 .48743 L
.12282 .08012 L
F
.2 .63 .79 r
.1226 .08012 m
.1226 .48743 L
.12282 .48743 L
.12282 .08012 L
s
.678 .847 .902 r
.12282 .08012 m
.12282 .48723 L
.12325 .48723 L
.12325 .08012 L
F
.2 .63 .79 r
.12282 .08012 m
.12282 .48723 L
.12325 .48723 L
.12325 .08012 L
s
.678 .847 .902 r
.12325 .08012 m
.12325 .4865 L
.12367 .4865 L
.12367 .08012 L
F
.2 .63 .79 r
.12325 .08012 m
.12325 .4865 L
.12367 .4865 L
.12367 .08012 L
s
.678 .847 .902 r
.12367 .08012 m
.12367 .4859 L
.12411 .4859 L
.12411 .08012 L
F
.2 .63 .79 r
.12367 .08012 m
.12367 .4859 L
.12411 .4859 L
.12411 .08012 L
s
.678 .847 .902 r
.12411 .08012 m
.12411 .48576 L
.12431 .48576 L
.12431 .08012 L
F
.2 .63 .79 r
.12411 .08012 m
.12411 .48576 L
.12431 .48576 L
.12431 .08012 L
s
.678 .847 .902 r
.12431 .08012 m
.12431 .4855 L
.12451 .4855 L
.12451 .08012 L
F
.2 .63 .79 r
.12431 .08012 m
.12431 .4855 L
.12451 .4855 L
.12451 .08012 L
s
.678 .847 .902 r
.12451 .08012 m
.12451 .48531 L
.12469 .48531 L
.12469 .08012 L
F
.2 .63 .79 r
.12451 .08012 m
.12451 .48531 L
.12469 .48531 L
.12469 .08012 L
s
.678 .847 .902 r
.12469 .08012 m
.12469 .48508 L
.12505 .48508 L
.12505 .08012 L
F
.2 .63 .79 r
.12469 .08012 m
.12469 .48508 L
.12505 .48508 L
.12505 .08012 L
s
.678 .847 .902 r
.12505 .08012 m
.12505 .48475 L
.12539 .48475 L
.12539 .08012 L
F
.2 .63 .79 r
.12505 .08012 m
.12505 .48475 L
.12539 .48475 L
.12539 .08012 L
s
.678 .847 .902 r
.12539 .08012 m
.12539 .4844 L
.12566 .4844 L
.12566 .08012 L
F
.2 .63 .79 r
.12539 .08012 m
.12539 .4844 L
.12566 .4844 L
.12566 .08012 L
s
.678 .847 .902 r
.12566 .08012 m
.12566 .48409 L
.1259 .48409 L
.1259 .08012 L
F
.2 .63 .79 r
.12566 .08012 m
.12566 .48409 L
.1259 .48409 L
.1259 .08012 L
s
.678 .847 .902 r
.1259 .08012 m
.1259 .48378 L
.12632 .48378 L
.12632 .08012 L
F
.2 .63 .79 r
.1259 .08012 m
.1259 .48378 L
.12632 .48378 L
.12632 .08012 L
s
.678 .847 .902 r
.12632 .08012 m
.12632 .48331 L
.12654 .48331 L
.12654 .08012 L
F
.2 .63 .79 r
.12632 .08012 m
.12632 .48331 L
.12654 .48331 L
.12654 .08012 L
s
.678 .847 .902 r
.12654 .08012 m
.12654 .48303 L
.127 .48303 L
.127 .08012 L
F
.2 .63 .79 r
.12654 .08012 m
.12654 .48303 L
.127 .48303 L
.127 .08012 L
s
.678 .847 .902 r
.127 .08012 m
.127 .48246 L
.12722 .48246 L
.12722 .08012 L
F
.2 .63 .79 r
.127 .08012 m
.127 .48246 L
.12722 .48246 L
.12722 .08012 L
s
.678 .847 .902 r
.12722 .08012 m
.12722 .48241 L
.12759 .48241 L
.12759 .08012 L
F
.2 .63 .79 r
.12722 .08012 m
.12722 .48241 L
.12759 .48241 L
.12759 .08012 L
s
.678 .847 .902 r
.12759 .08012 m
.12759 .48189 L
.12786 .48189 L
.12786 .08012 L
F
.2 .63 .79 r
.12759 .08012 m
.12759 .48189 L
.12786 .48189 L
.12786 .08012 L
s
.678 .847 .902 r
.12786 .08012 m
.12786 .48167 L
.12821 .48167 L
.12821 .08012 L
F
.2 .63 .79 r
.12786 .08012 m
.12786 .48167 L
.12821 .48167 L
.12821 .08012 L
s
.678 .847 .902 r
.12821 .08012 m
.12821 .48132 L
.12838 .48132 L
.12838 .08012 L
F
.2 .63 .79 r
.12821 .08012 m
.12821 .48132 L
.12838 .48132 L
.12838 .08012 L
s
.678 .847 .902 r
.12838 .08012 m
.12838 .48111 L
.12874 .48111 L
.12874 .08012 L
F
.2 .63 .79 r
.12838 .08012 m
.12838 .48111 L
.12874 .48111 L
.12874 .08012 L
s
.678 .847 .902 r
.12874 .08012 m
.12874 .48053 L
.12923 .48053 L
.12923 .08012 L
F
.2 .63 .79 r
.12874 .08012 m
.12874 .48053 L
.12923 .48053 L
.12923 .08012 L
s
.678 .847 .902 r
.12923 .08012 m
.12923 .48009 L
.12951 .48009 L
.12951 .08012 L
F
.2 .63 .79 r
.12923 .08012 m
.12923 .48009 L
.12951 .48009 L
.12951 .08012 L
s
.678 .847 .902 r
.12951 .08012 m
.12951 .47954 L
.12996 .47954 L
.12996 .08012 L
F
.2 .63 .79 r
.12951 .08012 m
.12951 .47954 L
.12996 .47954 L
.12996 .08012 L
s
.678 .847 .902 r
.12996 .08012 m
.12996 .47908 L
.13028 .47908 L
.13028 .08012 L
F
.2 .63 .79 r
.12996 .08012 m
.12996 .47908 L
.13028 .47908 L
.13028 .08012 L
s
.678 .847 .902 r
.13028 .08012 m
.13028 .47864 L
.13069 .47864 L
.13069 .08012 L
F
.2 .63 .79 r
.13028 .08012 m
.13028 .47864 L
.13069 .47864 L
.13069 .08012 L
s
.678 .847 .902 r
.13069 .08012 m
.13069 .47851 L
.13104 .47851 L
.13104 .08012 L
F
.2 .63 .79 r
.13069 .08012 m
.13069 .47851 L
.13104 .47851 L
.13104 .08012 L
s
.678 .847 .902 r
.13104 .08012 m
.13104 .47823 L
.1312 .47823 L
.1312 .08012 L
F
.2 .63 .79 r
.13104 .08012 m
.13104 .47823 L
.1312 .47823 L
.1312 .08012 L
s
.678 .847 .902 r
.1312 .08012 m
.1312 .47804 L
.13158 .47804 L
.13158 .08012 L
F
.2 .63 .79 r
.1312 .08012 m
.1312 .47804 L
.13158 .47804 L
.13158 .08012 L
s
.678 .847 .902 r
.13158 .08012 m
.13158 .47745 L
.13194 .47745 L
.13194 .08012 L
F
.2 .63 .79 r
.13158 .08012 m
.13158 .47745 L
.13194 .47745 L
.13194 .08012 L
s
.678 .847 .902 r
.13194 .08012 m
.13194 .47705 L
.13224 .47705 L
.13224 .08012 L
F
.2 .63 .79 r
.13194 .08012 m
.13194 .47705 L
.13224 .47705 L
.13224 .08012 L
s
.678 .847 .902 r
.13224 .08012 m
.13224 .47667 L
.13271 .47667 L
.13271 .08012 L
F
.2 .63 .79 r
.13224 .08012 m
.13224 .47667 L
.13271 .47667 L
.13271 .08012 L
s
.678 .847 .902 r
.13271 .08012 m
.13271 .47628 L
.13288 .47628 L
.13288 .08012 L
F
.2 .63 .79 r
.13271 .08012 m
.13271 .47628 L
.13288 .47628 L
.13288 .08012 L
s
.678 .847 .902 r
.13288 .08012 m
.13288 .47617 L
.13305 .47617 L
.13305 .08012 L
F
.2 .63 .79 r
.13288 .08012 m
.13288 .47617 L
.13305 .47617 L
.13305 .08012 L
s
.678 .847 .902 r
.13305 .08012 m
.13305 .47596 L
.13322 .47596 L
.13322 .08012 L
F
.2 .63 .79 r
.13305 .08012 m
.13305 .47596 L
.13322 .47596 L
.13322 .08012 L
s
.678 .847 .902 r
.13322 .08012 m
.13322 .47575 L
.1336 .47575 L
.1336 .08012 L
F
.2 .63 .79 r
.13322 .08012 m
.13322 .47575 L
.1336 .47575 L
.1336 .08012 L
s
.678 .847 .902 r
.1336 .08012 m
.1336 .47531 L
.13385 .47531 L
.13385 .08012 L
F
.2 .63 .79 r
.1336 .08012 m
.1336 .47531 L
.13385 .47531 L
.13385 .08012 L
s
.678 .847 .902 r
.13385 .08012 m
.13385 .47479 L
.13429 .47479 L
.13429 .08012 L
F
.2 .63 .79 r
.13385 .08012 m
.13385 .47479 L
.13429 .47479 L
.13429 .08012 L
s
.678 .847 .902 r
.13429 .08012 m
.13429 .47465 L
.13448 .47465 L
.13448 .08012 L
F
.2 .63 .79 r
.13429 .08012 m
.13429 .47465 L
.13448 .47465 L
.13448 .08012 L
s
.678 .847 .902 r
.13448 .08012 m
.13448 .47436 L
.1348 .47436 L
.1348 .08012 L
F
.2 .63 .79 r
.13448 .08012 m
.13448 .47436 L
.1348 .47436 L
.1348 .08012 L
s
.678 .847 .902 r
.1348 .08012 m
.1348 .47397 L
.13517 .47397 L
.13517 .08012 L
F
.2 .63 .79 r
.1348 .08012 m
.1348 .47397 L
.13517 .47397 L
.13517 .08012 L
s
.678 .847 .902 r
.13517 .08012 m
.13517 .47361 L
.13549 .47361 L
.13549 .08012 L
F
.2 .63 .79 r
.13517 .08012 m
.13517 .47361 L
.13549 .47361 L
.13549 .08012 L
s
.678 .847 .902 r
.13549 .08012 m
.13549 .47301 L
.13583 .47301 L
.13583 .08012 L
F
.2 .63 .79 r
.13549 .08012 m
.13549 .47301 L
.13583 .47301 L
.13583 .08012 L
s
.678 .847 .902 r
.13583 .08012 m
.13583 .47295 L
.13612 .47295 L
.13612 .08012 L
F
.2 .63 .79 r
.13583 .08012 m
.13583 .47295 L
.13612 .47295 L
.13612 .08012 L
s
.678 .847 .902 r
.13612 .08012 m
.13612 .47255 L
.13661 .47255 L
.13661 .08012 L
F
.2 .63 .79 r
.13612 .08012 m
.13612 .47255 L
.13661 .47255 L
.13661 .08012 L
s
.678 .847 .902 r
.13661 .08012 m
.13661 .47183 L
.13694 .47183 L
.13694 .08012 L
F
.2 .63 .79 r
.13661 .08012 m
.13661 .47183 L
.13694 .47183 L
.13694 .08012 L
s
.678 .847 .902 r
.13694 .08012 m
.13694 .47167 L
.13715 .47167 L
.13715 .08012 L
F
.2 .63 .79 r
.13694 .08012 m
.13694 .47167 L
.13715 .47167 L
.13715 .08012 L
s
.678 .847 .902 r
.13715 .08012 m
.13715 .47141 L
.13749 .47141 L
.13749 .08012 L
F
.2 .63 .79 r
.13715 .08012 m
.13715 .47141 L
.13749 .47141 L
.13749 .08012 L
s
.678 .847 .902 r
.13749 .08012 m
.13749 .4711 L
.1378 .4711 L
.1378 .08012 L
F
.2 .63 .79 r
.13749 .08012 m
.13749 .4711 L
.1378 .4711 L
.1378 .08012 L
s
.678 .847 .902 r
.1378 .08012 m
.1378 .47043 L
.13821 .47043 L
.13821 .08012 L
F
.2 .63 .79 r
.1378 .08012 m
.1378 .47043 L
.13821 .47043 L
.13821 .08012 L
s
.678 .847 .902 r
.13821 .08012 m
.13821 .47031 L
.13857 .47031 L
.13857 .08012 L
F
.2 .63 .79 r
.13821 .08012 m
.13821 .47031 L
.13857 .47031 L
.13857 .08012 L
s
.678 .847 .902 r
.13857 .08012 m
.13857 .46991 L
.13889 .46991 L
.13889 .08012 L
F
.2 .63 .79 r
.13857 .08012 m
.13857 .46991 L
.13889 .46991 L
.13889 .08012 L
s
.678 .847 .902 r
.13889 .08012 m
.13889 .46956 L
.13931 .46956 L
.13931 .08012 L
F
.2 .63 .79 r
.13889 .08012 m
.13889 .46956 L
.13931 .46956 L
.13931 .08012 L
s
.678 .847 .902 r
.13931 .08012 m
.13931 .46911 L
.13952 .46911 L
.13952 .08012 L
F
.2 .63 .79 r
.13931 .08012 m
.13931 .46911 L
.13952 .46911 L
.13952 .08012 L
s
.678 .847 .902 r
.13952 .08012 m
.13952 .46885 L
.13972 .46885 L
.13972 .08012 L
F
.2 .63 .79 r
.13952 .08012 m
.13952 .46885 L
.13972 .46885 L
.13972 .08012 L
s
.678 .847 .902 r
.13972 .08012 m
.13972 .46846 L
.14006 .46846 L
.14006 .08012 L
F
.2 .63 .79 r
.13972 .08012 m
.13972 .46846 L
.14006 .46846 L
.14006 .08012 L
s
.678 .847 .902 r
.14006 .08012 m
.14006 .46815 L
.14046 .46815 L
.14046 .08012 L
F
.2 .63 .79 r
.14006 .08012 m
.14006 .46815 L
.14046 .46815 L
.14046 .08012 L
s
.678 .847 .902 r
.14046 .08012 m
.14046 .46793 L
.14064 .46793 L
.14064 .08012 L
F
.2 .63 .79 r
.14046 .08012 m
.14046 .46793 L
.14064 .46793 L
.14064 .08012 L
s
.678 .847 .902 r
.14064 .08012 m
.14064 .46772 L
.14083 .46772 L
.14083 .08012 L
F
.2 .63 .79 r
.14064 .08012 m
.14064 .46772 L
.14083 .46772 L
.14083 .08012 L
s
.678 .847 .902 r
.14083 .08012 m
.14083 .46728 L
.14128 .46728 L
.14128 .08012 L
F
.2 .63 .79 r
.14083 .08012 m
.14083 .46728 L
.14128 .46728 L
.14128 .08012 L
s
.678 .847 .902 r
.14128 .08012 m
.14128 .46703 L
.14157 .46703 L
.14157 .08012 L
F
.2 .63 .79 r
.14128 .08012 m
.14128 .46703 L
.14157 .46703 L
.14157 .08012 L
s
.678 .847 .902 r
.14157 .08012 m
.14157 .46665 L
.14181 .46665 L
.14181 .08012 L
F
.2 .63 .79 r
.14157 .08012 m
.14157 .46665 L
.14181 .46665 L
.14181 .08012 L
s
.678 .847 .902 r
.14181 .08012 m
.14181 .46646 L
.1423 .46646 L
.1423 .08012 L
F
.2 .63 .79 r
.14181 .08012 m
.14181 .46646 L
.1423 .46646 L
.1423 .08012 L
s
.678 .847 .902 r
.1423 .08012 m
.1423 .46589 L
.14258 .46589 L
.14258 .08012 L
F
.2 .63 .79 r
.1423 .08012 m
.1423 .46589 L
.14258 .46589 L
.14258 .08012 L
s
.678 .847 .902 r
.14258 .08012 m
.14258 .46532 L
.143 .46532 L
.143 .08012 L
F
.2 .63 .79 r
.14258 .08012 m
.14258 .46532 L
.143 .46532 L
.143 .08012 L
s
.678 .847 .902 r
.143 .08012 m
.143 .46518 L
.14341 .46518 L
.14341 .08012 L
F
.2 .63 .79 r
.143 .08012 m
.143 .46518 L
.14341 .46518 L
.14341 .08012 L
s
.678 .847 .902 r
.14341 .08012 m
.14341 .46474 L
.1437 .46474 L
.1437 .08012 L
F
.2 .63 .79 r
.14341 .08012 m
.14341 .46474 L
.1437 .46474 L
.1437 .08012 L
s
.678 .847 .902 r
.1437 .08012 m
.1437 .4644 L
.14418 .4644 L
.14418 .08012 L
F
.2 .63 .79 r
.1437 .08012 m
.1437 .4644 L
.14418 .4644 L
.14418 .08012 L
s
.678 .847 .902 r
.14418 .08012 m
.14418 .4637 L
.1446 .4637 L
.1446 .08012 L
F
.2 .63 .79 r
.14418 .08012 m
.14418 .4637 L
.1446 .4637 L
.1446 .08012 L
s
.678 .847 .902 r
.1446 .08012 m
.1446 .46343 L
.14483 .46343 L
.14483 .08012 L
F
.2 .63 .79 r
.1446 .08012 m
.1446 .46343 L
.14483 .46343 L
.14483 .08012 L
s
.678 .847 .902 r
.14483 .08012 m
.14483 .46309 L
.14506 .46309 L
.14506 .08012 L
F
.2 .63 .79 r
.14483 .08012 m
.14483 .46309 L
.14506 .46309 L
.14506 .08012 L
s
.678 .847 .902 r
.14506 .08012 m
.14506 .46276 L
.14535 .46276 L
.14535 .08012 L
F
.2 .63 .79 r
.14506 .08012 m
.14506 .46276 L
.14535 .46276 L
.14535 .08012 L
s
.678 .847 .902 r
.14535 .08012 m
.14535 .4626 L
.14561 .4626 L
.14561 .08012 L
F
.2 .63 .79 r
.14535 .08012 m
.14535 .4626 L
.14561 .4626 L
.14561 .08012 L
s
.678 .847 .902 r
.14561 .08012 m
.14561 .46231 L
.14592 .46231 L
.14592 .08012 L
F
.2 .63 .79 r
.14561 .08012 m
.14561 .46231 L
.14592 .46231 L
.14592 .08012 L
s
.678 .847 .902 r
.14592 .08012 m
.14592 .46193 L
.14628 .46193 L
.14628 .08012 L
F
.2 .63 .79 r
.14592 .08012 m
.14592 .46193 L
.14628 .46193 L
.14628 .08012 L
s
.678 .847 .902 r
.14628 .08012 m
.14628 .46147 L
.14675 .46147 L
.14675 .08012 L
F
.2 .63 .79 r
.14628 .08012 m
.14628 .46147 L
.14675 .46147 L
.14675 .08012 L
s
.678 .847 .902 r
.14675 .08012 m
.14675 .46116 L
.14707 .46116 L
.14707 .08012 L
F
.2 .63 .79 r
.14675 .08012 m
.14675 .46116 L
.14707 .46116 L
.14707 .08012 L
s
.678 .847 .902 r
.14707 .08012 m
.14707 .46059 L
.14733 .46059 L
.14733 .08012 L
F
.2 .63 .79 r
.14707 .08012 m
.14707 .46059 L
.14733 .46059 L
.14733 .08012 L
s
.678 .847 .902 r
.14733 .08012 m
.14733 .46031 L
.14763 .46031 L
.14763 .08012 L
F
.2 .63 .79 r
.14733 .08012 m
.14733 .46031 L
.14763 .46031 L
.14763 .08012 L
s
.678 .847 .902 r
.14763 .08012 m
.14763 .46004 L
.14791 .46004 L
.14791 .08012 L
F
.2 .63 .79 r
.14763 .08012 m
.14763 .46004 L
.14791 .46004 L
.14791 .08012 L
s
.678 .847 .902 r
.14791 .08012 m
.14791 .45972 L
.14833 .45972 L
.14833 .08012 L
F
.2 .63 .79 r
.14791 .08012 m
.14791 .45972 L
.14833 .45972 L
.14833 .08012 L
s
.678 .847 .902 r
.14833 .08012 m
.14833 .45932 L
.14854 .45932 L
.14854 .08012 L
F
.2 .63 .79 r
.14833 .08012 m
.14833 .45932 L
.14854 .45932 L
.14854 .08012 L
s
.678 .847 .902 r
.14854 .08012 m
.14854 .45909 L
.14881 .45909 L
.14881 .08012 L
F
.2 .63 .79 r
.14854 .08012 m
.14854 .45909 L
.14881 .45909 L
.14881 .08012 L
s
.678 .847 .902 r
.14881 .08012 m
.14881 .45861 L
.14913 .45861 L
.14913 .08012 L
F
.2 .63 .79 r
.14881 .08012 m
.14881 .45861 L
.14913 .45861 L
.14913 .08012 L
s
.678 .847 .902 r
.14913 .08012 m
.14913 .45851 L
.1494 .45851 L
.1494 .08012 L
F
.2 .63 .79 r
.14913 .08012 m
.14913 .45851 L
.1494 .45851 L
.1494 .08012 L
s
.678 .847 .902 r
.1494 .08012 m
.1494 .45819 L
.14987 .45819 L
.14987 .08012 L
F
.2 .63 .79 r
.1494 .08012 m
.1494 .45819 L
.14987 .45819 L
.14987 .08012 L
s
.678 .847 .902 r
.14987 .08012 m
.14987 .45768 L
.15015 .45768 L
.15015 .08012 L
F
.2 .63 .79 r
.14987 .08012 m
.14987 .45768 L
.15015 .45768 L
.15015 .08012 L
s
.678 .847 .902 r
.15015 .08012 m
.15015 .45737 L
.15033 .45737 L
.15033 .08012 L
F
.2 .63 .79 r
.15015 .08012 m
.15015 .45737 L
.15033 .45737 L
.15033 .08012 L
s
.678 .847 .902 r
.15033 .08012 m
.15033 .45711 L
.15067 .45711 L
.15067 .08012 L
F
.2 .63 .79 r
.15033 .08012 m
.15033 .45711 L
.15067 .45711 L
.15067 .08012 L
s
.678 .847 .902 r
.15067 .08012 m
.15067 .45691 L
.15088 .45691 L
.15088 .08012 L
F
.2 .63 .79 r
.15067 .08012 m
.15067 .45691 L
.15088 .45691 L
.15088 .08012 L
s
.678 .847 .902 r
.15088 .08012 m
.15088 .45655 L
.15136 .45655 L
.15136 .08012 L
F
.2 .63 .79 r
.15088 .08012 m
.15088 .45655 L
.15136 .45655 L
.15136 .08012 L
s
.678 .847 .902 r
.15136 .08012 m
.15136 .45608 L
.15156 .45608 L
.15156 .08012 L
F
.2 .63 .79 r
.15136 .08012 m
.15136 .45608 L
.15156 .45608 L
.15156 .08012 L
s
.678 .847 .902 r
.15156 .08012 m
.15156 .45598 L
.15197 .45598 L
.15197 .08012 L
F
.2 .63 .79 r
.15156 .08012 m
.15156 .45598 L
.15197 .45598 L
.15197 .08012 L
s
.678 .847 .902 r
.15197 .08012 m
.15197 .45556 L
.15244 .45556 L
.15244 .08012 L
F
.2 .63 .79 r
.15197 .08012 m
.15197 .45556 L
.15244 .45556 L
.15244 .08012 L
s
.678 .847 .902 r
.15244 .08012 m
.15244 .45473 L
.15284 .45473 L
.15284 .08012 L
F
.2 .63 .79 r
.15244 .08012 m
.15244 .45473 L
.15284 .45473 L
.15284 .08012 L
s
.678 .847 .902 r
.15284 .08012 m
.15284 .45424 L
.15323 .45424 L
.15323 .08012 L
F
.2 .63 .79 r
.15284 .08012 m
.15284 .45424 L
.15323 .45424 L
.15323 .08012 L
s
.678 .847 .902 r
.15323 .08012 m
.15323 .45395 L
.15354 .45395 L
.15354 .08012 L
F
.2 .63 .79 r
.15323 .08012 m
.15323 .45395 L
.15354 .45395 L
.15354 .08012 L
s
.678 .847 .902 r
.15354 .08012 m
.15354 .45365 L
.15384 .45365 L
.15384 .08012 L
F
.2 .63 .79 r
.15354 .08012 m
.15354 .45365 L
.15384 .45365 L
.15384 .08012 L
s
.678 .847 .902 r
.15384 .08012 m
.15384 .45347 L
.15403 .45347 L
.15403 .08012 L
F
.2 .63 .79 r
.15384 .08012 m
.15384 .45347 L
.15403 .45347 L
.15403 .08012 L
s
.678 .847 .902 r
.15403 .08012 m
.15403 .45313 L
.15445 .45313 L
.15445 .08012 L
F
.2 .63 .79 r
.15403 .08012 m
.15403 .45313 L
.15445 .45313 L
.15445 .08012 L
s
.678 .847 .902 r
.15445 .08012 m
.15445 .45251 L
.15492 .45251 L
.15492 .08012 L
F
.2 .63 .79 r
.15445 .08012 m
.15445 .45251 L
.15492 .45251 L
.15492 .08012 L
s
.678 .847 .902 r
.15492 .08012 m
.15492 .45222 L
.15512 .45222 L
.15512 .08012 L
F
.2 .63 .79 r
.15492 .08012 m
.15492 .45222 L
.15512 .45222 L
.15512 .08012 L
s
.678 .847 .902 r
.15512 .08012 m
.15512 .4519 L
.15549 .4519 L
.15549 .08012 L
F
.2 .63 .79 r
.15512 .08012 m
.15512 .4519 L
.15549 .4519 L
.15549 .08012 L
s
.678 .847 .902 r
.15549 .08012 m
.15549 .4515 L
.15579 .4515 L
.15579 .08012 L
F
.2 .63 .79 r
.15549 .08012 m
.15549 .4515 L
.15579 .4515 L
.15579 .08012 L
s
.678 .847 .902 r
.15579 .08012 m
.15579 .45141 L
.15599 .45141 L
.15599 .08012 L
F
.2 .63 .79 r
.15579 .08012 m
.15579 .45141 L
.15599 .45141 L
.15599 .08012 L
s
.678 .847 .902 r
.15599 .08012 m
.15599 .45114 L
.15646 .45114 L
.15646 .08012 L
F
.2 .63 .79 r
.15599 .08012 m
.15599 .45114 L
.15646 .45114 L
.15646 .08012 L
s
.678 .847 .902 r
.15646 .08012 m
.15646 .4507 L
.15671 .4507 L
.15671 .08012 L
F
.2 .63 .79 r
.15646 .08012 m
.15646 .4507 L
.15671 .4507 L
.15671 .08012 L
s
.678 .847 .902 r
.15671 .08012 m
.15671 .45003 L
.15719 .45003 L
.15719 .08012 L
F
.2 .63 .79 r
.15671 .08012 m
.15671 .45003 L
.15719 .45003 L
.15719 .08012 L
s
.678 .847 .902 r
.15719 .08012 m
.15719 .44999 L
.15761 .44999 L
.15761 .08012 L
F
.2 .63 .79 r
.15719 .08012 m
.15719 .44999 L
.15761 .44999 L
.15761 .08012 L
s
.678 .847 .902 r
.15761 .08012 m
.15761 .44955 L
.15776 .44955 L
.15776 .08012 L
F
.2 .63 .79 r
.15761 .08012 m
.15761 .44955 L
.15776 .44955 L
.15776 .08012 L
s
.678 .847 .902 r
.15776 .08012 m
.15776 .44899 L
.15822 .44899 L
.15822 .08012 L
F
.2 .63 .79 r
.15776 .08012 m
.15776 .44899 L
.15822 .44899 L
.15822 .08012 L
s
.678 .847 .902 r
.15822 .08012 m
.15822 .4488 L
.15866 .4488 L
.15866 .08012 L
F
.2 .63 .79 r
.15822 .08012 m
.15822 .4488 L
.15866 .4488 L
.15866 .08012 L
s
.678 .847 .902 r
.15866 .08012 m
.15866 .44832 L
.15889 .44832 L
.15889 .08012 L
F
.2 .63 .79 r
.15866 .08012 m
.15866 .44832 L
.15889 .44832 L
.15889 .08012 L
s
.678 .847 .902 r
.15889 .08012 m
.15889 .44781 L
.15932 .44781 L
.15932 .08012 L
F
.2 .63 .79 r
.15889 .08012 m
.15889 .44781 L
.15932 .44781 L
.15932 .08012 L
s
.678 .847 .902 r
.15932 .08012 m
.15932 .44749 L
.1598 .44749 L
.1598 .08012 L
F
.2 .63 .79 r
.15932 .08012 m
.15932 .44749 L
.1598 .44749 L
.1598 .08012 L
s
.678 .847 .902 r
.1598 .08012 m
.1598 .44699 L
.16019 .44699 L
.16019 .08012 L
F
.2 .63 .79 r
.1598 .08012 m
.1598 .44699 L
.16019 .44699 L
.16019 .08012 L
s
.678 .847 .902 r
.16019 .08012 m
.16019 .44668 L
.1605 .44668 L
.1605 .08012 L
F
.2 .63 .79 r
.16019 .08012 m
.16019 .44668 L
.1605 .44668 L
.1605 .08012 L
s
.678 .847 .902 r
.1605 .08012 m
.1605 .44608 L
.16096 .44608 L
.16096 .08012 L
F
.2 .63 .79 r
.1605 .08012 m
.1605 .44608 L
.16096 .44608 L
.16096 .08012 L
s
.678 .847 .902 r
.16096 .08012 m
.16096 .44584 L
.16118 .44584 L
.16118 .08012 L
F
.2 .63 .79 r
.16096 .08012 m
.16096 .44584 L
.16118 .44584 L
.16118 .08012 L
s
.678 .847 .902 r
.16118 .08012 m
.16118 .44543 L
.16167 .44543 L
.16167 .08012 L
F
.2 .63 .79 r
.16118 .08012 m
.16118 .44543 L
.16167 .44543 L
.16167 .08012 L
s
.678 .847 .902 r
.16167 .08012 m
.16167 .44515 L
.16182 .44515 L
.16182 .08012 L
F
.2 .63 .79 r
.16167 .08012 m
.16167 .44515 L
.16182 .44515 L
.16182 .08012 L
s
.678 .847 .902 r
.16182 .08012 m
.16182 .44507 L
.16212 .44507 L
.16212 .08012 L
F
.2 .63 .79 r
.16182 .08012 m
.16182 .44507 L
.16212 .44507 L
.16212 .08012 L
s
.678 .847 .902 r
.16212 .08012 m
.16212 .44472 L
.16231 .44472 L
.16231 .08012 L
F
.2 .63 .79 r
.16212 .08012 m
.16212 .44472 L
.16231 .44472 L
.16231 .08012 L
s
.678 .847 .902 r
.16231 .08012 m
.16231 .44454 L
.16252 .44454 L
.16252 .08012 L
F
.2 .63 .79 r
.16231 .08012 m
.16231 .44454 L
.16252 .44454 L
.16252 .08012 L
s
.678 .847 .902 r
.16252 .08012 m
.16252 .44421 L
.16269 .44421 L
.16269 .08012 L
F
.2 .63 .79 r
.16252 .08012 m
.16252 .44421 L
.16269 .44421 L
.16269 .08012 L
s
.678 .847 .902 r
.16269 .08012 m
.16269 .44413 L
.16295 .44413 L
.16295 .08012 L
F
.2 .63 .79 r
.16269 .08012 m
.16269 .44413 L
.16295 .44413 L
.16295 .08012 L
s
.678 .847 .902 r
.16295 .08012 m
.16295 .44375 L
.16325 .44375 L
.16325 .08012 L
F
.2 .63 .79 r
.16295 .08012 m
.16295 .44375 L
.16325 .44375 L
.16325 .08012 L
s
.678 .847 .902 r
.16325 .08012 m
.16325 .4435 L
.16365 .4435 L
.16365 .08012 L
F
.2 .63 .79 r
.16325 .08012 m
.16325 .4435 L
.16365 .4435 L
.16365 .08012 L
s
.678 .847 .902 r
.16365 .08012 m
.16365 .44292 L
.16412 .44292 L
.16412 .08012 L
F
.2 .63 .79 r
.16365 .08012 m
.16365 .44292 L
.16412 .44292 L
.16412 .08012 L
s
.678 .847 .902 r
.16412 .08012 m
.16412 .44241 L
.1644 .44241 L
.1644 .08012 L
F
.2 .63 .79 r
.16412 .08012 m
.16412 .44241 L
.1644 .44241 L
.1644 .08012 L
s
.678 .847 .902 r
.1644 .08012 m
.1644 .44232 L
.1646 .44232 L
.1646 .08012 L
F
.2 .63 .79 r
.1644 .08012 m
.1644 .44232 L
.1646 .44232 L
.1646 .08012 L
s
.678 .847 .902 r
.1646 .08012 m
.1646 .44205 L
.16502 .44205 L
.16502 .08012 L
F
.2 .63 .79 r
.1646 .08012 m
.1646 .44205 L
.16502 .44205 L
.16502 .08012 L
s
.678 .847 .902 r
.16502 .08012 m
.16502 .44163 L
.16521 .44163 L
.16521 .08012 L
F
.2 .63 .79 r
.16502 .08012 m
.16502 .44163 L
.16521 .44163 L
.16521 .08012 L
s
.678 .847 .902 r
.16521 .08012 m
.16521 .44126 L
.16548 .44126 L
.16548 .08012 L
F
.2 .63 .79 r
.16521 .08012 m
.16521 .44126 L
.16548 .44126 L
.16548 .08012 L
s
.678 .847 .902 r
.16548 .08012 m
.16548 .44113 L
.16572 .44113 L
.16572 .08012 L
F
.2 .63 .79 r
.16548 .08012 m
.16548 .44113 L
.16572 .44113 L
.16572 .08012 L
s
.678 .847 .902 r
.16572 .08012 m
.16572 .44096 L
.16618 .44096 L
.16618 .08012 L
F
.2 .63 .79 r
.16572 .08012 m
.16572 .44096 L
.16618 .44096 L
.16618 .08012 L
s
.678 .847 .902 r
.16618 .08012 m
.16618 .44001 L
.16664 .44001 L
.16664 .08012 L
F
.2 .63 .79 r
.16618 .08012 m
.16618 .44001 L
.16664 .44001 L
.16664 .08012 L
s
.678 .847 .902 r
.16664 .08012 m
.16664 .43999 L
.16698 .43999 L
.16698 .08012 L
F
.2 .63 .79 r
.16664 .08012 m
.16664 .43999 L
.16698 .43999 L
.16698 .08012 L
s
.678 .847 .902 r
.16698 .08012 m
.16698 .43941 L
.16723 .43941 L
.16723 .08012 L
F
.2 .63 .79 r
.16698 .08012 m
.16698 .43941 L
.16723 .43941 L
.16723 .08012 L
s
.678 .847 .902 r
.16723 .08012 m
.16723 .43928 L
.16745 .43928 L
.16745 .08012 L
F
.2 .63 .79 r
.16723 .08012 m
.16723 .43928 L
.16745 .43928 L
.16745 .08012 L
s
.678 .847 .902 r
.16745 .08012 m
.16745 .43897 L
.16775 .43897 L
.16775 .08012 L
F
.2 .63 .79 r
.16745 .08012 m
.16745 .43897 L
.16775 .43897 L
.16775 .08012 L
s
.678 .847 .902 r
.16775 .08012 m
.16775 .43876 L
.16811 .43876 L
.16811 .08012 L
F
.2 .63 .79 r
.16775 .08012 m
.16775 .43876 L
.16811 .43876 L
.16811 .08012 L
s
.678 .847 .902 r
.16811 .08012 m
.16811 .43842 L
.16829 .43842 L
.16829 .08012 L
F
.2 .63 .79 r
.16811 .08012 m
.16811 .43842 L
.16829 .43842 L
.16829 .08012 L
s
.678 .847 .902 r
.16829 .08012 m
.16829 .43808 L
.16852 .43808 L
.16852 .08012 L
F
.2 .63 .79 r
.16829 .08012 m
.16829 .43808 L
.16852 .43808 L
.16852 .08012 L
s
.678 .847 .902 r
.16852 .08012 m
.16852 .43773 L
.16881 .43773 L
.16881 .08012 L
F
.2 .63 .79 r
.16852 .08012 m
.16852 .43773 L
.16881 .43773 L
.16881 .08012 L
s
.678 .847 .902 r
.16881 .08012 m
.16881 .4377 L
.16902 .4377 L
.16902 .08012 L
F
.2 .63 .79 r
.16881 .08012 m
.16881 .4377 L
.16902 .4377 L
.16902 .08012 L
s
.678 .847 .902 r
.16902 .08012 m
.16902 .43751 L
.1695 .43751 L
.1695 .08012 L
F
.2 .63 .79 r
.16902 .08012 m
.16902 .43751 L
.1695 .43751 L
.1695 .08012 L
s
.678 .847 .902 r
.1695 .08012 m
.1695 .43689 L
.16967 .43689 L
.16967 .08012 L
F
.2 .63 .79 r
.1695 .08012 m
.1695 .43689 L
.16967 .43689 L
.16967 .08012 L
s
.678 .847 .902 r
.16967 .08012 m
.16967 .43678 L
.16995 .43678 L
.16995 .08012 L
F
.2 .63 .79 r
.16967 .08012 m
.16967 .43678 L
.16995 .43678 L
.16995 .08012 L
s
.678 .847 .902 r
.16995 .08012 m
.16995 .43609 L
.17039 .43609 L
.17039 .08012 L
F
.2 .63 .79 r
.16995 .08012 m
.16995 .43609 L
.17039 .43609 L
.17039 .08012 L
s
.678 .847 .902 r
.17039 .08012 m
.17039 .4359 L
.17071 .4359 L
.17071 .08012 L
F
.2 .63 .79 r
.17039 .08012 m
.17039 .4359 L
.17071 .4359 L
.17071 .08012 L
s
.678 .847 .902 r
.17071 .08012 m
.17071 .43561 L
.17097 .43561 L
.17097 .08012 L
F
.2 .63 .79 r
.17071 .08012 m
.17071 .43561 L
.17097 .43561 L
.17097 .08012 L
s
.678 .847 .902 r
.17097 .08012 m
.17097 .43525 L
.17128 .43525 L
.17128 .08012 L
F
.2 .63 .79 r
.17097 .08012 m
.17097 .43525 L
.17128 .43525 L
.17128 .08012 L
s
.678 .847 .902 r
.17128 .08012 m
.17128 .43512 L
.17158 .43512 L
.17158 .08012 L
F
.2 .63 .79 r
.17128 .08012 m
.17128 .43512 L
.17158 .43512 L
.17158 .08012 L
s
.678 .847 .902 r
.17158 .08012 m
.17158 .43474 L
.17185 .43474 L
.17185 .08012 L
F
.2 .63 .79 r
.17158 .08012 m
.17158 .43474 L
.17185 .43474 L
.17185 .08012 L
s
.678 .847 .902 r
.17185 .08012 m
.17185 .43446 L
.17219 .43446 L
.17219 .08012 L
F
.2 .63 .79 r
.17185 .08012 m
.17185 .43446 L
.17219 .43446 L
.17219 .08012 L
s
.678 .847 .902 r
.17219 .08012 m
.17219 .43413 L
.17245 .43413 L
.17245 .08012 L
F
.2 .63 .79 r
.17219 .08012 m
.17219 .43413 L
.17245 .43413 L
.17245 .08012 L
s
.678 .847 .902 r
.17245 .08012 m
.17245 .43388 L
.17263 .43388 L
.17263 .08012 L
F
.2 .63 .79 r
.17245 .08012 m
.17245 .43388 L
.17263 .43388 L
.17263 .08012 L
s
.678 .847 .902 r
.17263 .08012 m
.17263 .43357 L
.17281 .43357 L
.17281 .08012 L
F
.2 .63 .79 r
.17263 .08012 m
.17263 .43357 L
.17281 .43357 L
.17281 .08012 L
s
.678 .847 .902 r
.17281 .08012 m
.17281 .43347 L
.17317 .43347 L
.17317 .08012 L
F
.2 .63 .79 r
.17281 .08012 m
.17281 .43347 L
.17317 .43347 L
.17317 .08012 L
s
.678 .847 .902 r
.17317 .08012 m
.17317 .43309 L
.17347 .43309 L
.17347 .08012 L
F
.2 .63 .79 r
.17317 .08012 m
.17317 .43309 L
.17347 .43309 L
.17347 .08012 L
s
.678 .847 .902 r
.17347 .08012 m
.17347 .4328 L
.1738 .4328 L
.1738 .08012 L
F
.2 .63 .79 r
.17347 .08012 m
.17347 .4328 L
.1738 .4328 L
.1738 .08012 L
s
.678 .847 .902 r
.1738 .08012 m
.1738 .43208 L
.17423 .43208 L
.17423 .08012 L
F
.2 .63 .79 r
.1738 .08012 m
.1738 .43208 L
.17423 .43208 L
.17423 .08012 L
s
.678 .847 .902 r
.17423 .08012 m
.17423 .43185 L
.17452 .43185 L
.17452 .08012 L
F
.2 .63 .79 r
.17423 .08012 m
.17423 .43185 L
.17452 .43185 L
.17452 .08012 L
s
.678 .847 .902 r
.17452 .08012 m
.17452 .43143 L
.175 .43143 L
.175 .08012 L
F
.2 .63 .79 r
.17452 .08012 m
.17452 .43143 L
.175 .43143 L
.175 .08012 L
s
.678 .847 .902 r
.175 .08012 m
.175 .43079 L
.17547 .43079 L
.17547 .08012 L
F
.2 .63 .79 r
.175 .08012 m
.175 .43079 L
.17547 .43079 L
.17547 .08012 L
s
.678 .847 .902 r
.17547 .08012 m
.17547 .43048 L
.17587 .43048 L
.17587 .08012 L
F
.2 .63 .79 r
.17547 .08012 m
.17547 .43048 L
.17587 .43048 L
.17587 .08012 L
s
.678 .847 .902 r
.17587 .08012 m
.17587 .43017 L
.17607 .43017 L
.17607 .08012 L
F
.2 .63 .79 r
.17587 .08012 m
.17587 .43017 L
.17607 .43017 L
.17607 .08012 L
s
.678 .847 .902 r
.17607 .08012 m
.17607 .42992 L
.17641 .42992 L
.17641 .08012 L
F
.2 .63 .79 r
.17607 .08012 m
.17607 .42992 L
.17641 .42992 L
.17641 .08012 L
s
.678 .847 .902 r
.17641 .08012 m
.17641 .42945 L
.17682 .42945 L
.17682 .08012 L
F
.2 .63 .79 r
.17641 .08012 m
.17641 .42945 L
.17682 .42945 L
.17682 .08012 L
s
.678 .847 .902 r
.17682 .08012 m
.17682 .42908 L
.17723 .42908 L
.17723 .08012 L
F
.2 .63 .79 r
.17682 .08012 m
.17682 .42908 L
.17723 .42908 L
.17723 .08012 L
s
.678 .847 .902 r
.17723 .08012 m
.17723 .42892 L
.17741 .42892 L
.17741 .08012 L
F
.2 .63 .79 r
.17723 .08012 m
.17723 .42892 L
.17741 .42892 L
.17741 .08012 L
s
.678 .847 .902 r
.17741 .08012 m
.17741 .42866 L
.17762 .42866 L
.17762 .08012 L
F
.2 .63 .79 r
.17741 .08012 m
.17741 .42866 L
.17762 .42866 L
.17762 .08012 L
s
.678 .847 .902 r
.17762 .08012 m
.17762 .42814 L
.17808 .42814 L
.17808 .08012 L
F
.2 .63 .79 r
.17762 .08012 m
.17762 .42814 L
.17808 .42814 L
.17808 .08012 L
s
.678 .847 .902 r
.17808 .08012 m
.17808 .42803 L
.17831 .42803 L
.17831 .08012 L
F
.2 .63 .79 r
.17808 .08012 m
.17808 .42803 L
.17831 .42803 L
.17831 .08012 L
s
.678 .847 .902 r
.17831 .08012 m
.17831 .42752 L
.17873 .42752 L
.17873 .08012 L
F
.2 .63 .79 r
.17831 .08012 m
.17831 .42752 L
.17873 .42752 L
.17873 .08012 L
s
.678 .847 .902 r
.17873 .08012 m
.17873 .42708 L
.17912 .42708 L
.17912 .08012 L
F
.2 .63 .79 r
.17873 .08012 m
.17873 .42708 L
.17912 .42708 L
.17912 .08012 L
s
.678 .847 .902 r
.17912 .08012 m
.17912 .42676 L
.17942 .42676 L
.17942 .08012 L
F
.2 .63 .79 r
.17912 .08012 m
.17912 .42676 L
.17942 .42676 L
.17942 .08012 L
s
.678 .847 .902 r
.17942 .08012 m
.17942 .42628 L
.17988 .42628 L
.17988 .08012 L
F
.2 .63 .79 r
.17942 .08012 m
.17942 .42628 L
.17988 .42628 L
.17988 .08012 L
s
.678 .847 .902 r
.17988 .08012 m
.17988 .4261 L
.18011 .4261 L
.18011 .08012 L
F
.2 .63 .79 r
.17988 .08012 m
.17988 .4261 L
.18011 .4261 L
.18011 .08012 L
s
.678 .847 .902 r
.18011 .08012 m
.18011 .42582 L
.18039 .42582 L
.18039 .08012 L
F
.2 .63 .79 r
.18011 .08012 m
.18011 .42582 L
.18039 .42582 L
.18039 .08012 L
s
.678 .847 .902 r
.18039 .08012 m
.18039 .42554 L
.18066 .42554 L
.18066 .08012 L
F
.2 .63 .79 r
.18039 .08012 m
.18039 .42554 L
.18066 .42554 L
.18066 .08012 L
s
.678 .847 .902 r
.18066 .08012 m
.18066 .425 L
.18108 .425 L
.18108 .08012 L
F
.2 .63 .79 r
.18066 .08012 m
.18066 .425 L
.18108 .425 L
.18108 .08012 L
s
.678 .847 .902 r
.18108 .08012 m
.18108 .42487 L
.18144 .42487 L
.18144 .08012 L
F
.2 .63 .79 r
.18108 .08012 m
.18108 .42487 L
.18144 .42487 L
.18144 .08012 L
s
.678 .847 .902 r
.18144 .08012 m
.18144 .42447 L
.18192 .42447 L
.18192 .08012 L
F
.2 .63 .79 r
.18144 .08012 m
.18144 .42447 L
.18192 .42447 L
.18192 .08012 L
s
.678 .847 .902 r
.18192 .08012 m
.18192 .42396 L
.18234 .42396 L
.18234 .08012 L
F
.2 .63 .79 r
.18192 .08012 m
.18192 .42396 L
.18234 .42396 L
.18234 .08012 L
s
.678 .847 .902 r
.18234 .08012 m
.18234 .42319 L
.18282 .42319 L
.18282 .08012 L
F
.2 .63 .79 r
.18234 .08012 m
.18234 .42319 L
.18282 .42319 L
.18282 .08012 L
s
.678 .847 .902 r
.18282 .08012 m
.18282 .42305 L
.18306 .42305 L
.18306 .08012 L
F
.2 .63 .79 r
.18282 .08012 m
.18282 .42305 L
.18306 .42305 L
.18306 .08012 L
s
.678 .847 .902 r
.18306 .08012 m
.18306 .42264 L
.18354 .42264 L
.18354 .08012 L
F
.2 .63 .79 r
.18306 .08012 m
.18306 .42264 L
.18354 .42264 L
.18354 .08012 L
s
.678 .847 .902 r
.18354 .08012 m
.18354 .42228 L
.18399 .42228 L
.18399 .08012 L
F
.2 .63 .79 r
.18354 .08012 m
.18354 .42228 L
.18399 .42228 L
.18399 .08012 L
s
.678 .847 .902 r
.18399 .08012 m
.18399 .42192 L
.18422 .42192 L
.18422 .08012 L
F
.2 .63 .79 r
.18399 .08012 m
.18399 .42192 L
.18422 .42192 L
.18422 .08012 L
s
.678 .847 .902 r
.18422 .08012 m
.18422 .42163 L
.18439 .42163 L
.18439 .08012 L
F
.2 .63 .79 r
.18422 .08012 m
.18422 .42163 L
.18439 .42163 L
.18439 .08012 L
s
.678 .847 .902 r
.18439 .08012 m
.18439 .42128 L
.18469 .42128 L
.18469 .08012 L
F
.2 .63 .79 r
.18439 .08012 m
.18439 .42128 L
.18469 .42128 L
.18469 .08012 L
s
.678 .847 .902 r
.18469 .08012 m
.18469 .42116 L
.18488 .42116 L
.18488 .08012 L
F
.2 .63 .79 r
.18469 .08012 m
.18469 .42116 L
.18488 .42116 L
.18488 .08012 L
s
.678 .847 .902 r
.18488 .08012 m
.18488 .4209 L
.18519 .4209 L
.18519 .08012 L
F
.2 .63 .79 r
.18488 .08012 m
.18488 .4209 L
.18519 .4209 L
.18519 .08012 L
s
.678 .847 .902 r
.18519 .08012 m
.18519 .42055 L
.18567 .42055 L
.18567 .08012 L
F
.2 .63 .79 r
.18519 .08012 m
.18519 .42055 L
.18567 .42055 L
.18567 .08012 L
s
.678 .847 .902 r
.18567 .08012 m
.18567 .42015 L
.18591 .42015 L
.18591 .08012 L
F
.2 .63 .79 r
.18567 .08012 m
.18567 .42015 L
.18591 .42015 L
.18591 .08012 L
s
.678 .847 .902 r
.18591 .08012 m
.18591 .41986 L
.18613 .41986 L
.18613 .08012 L
F
.2 .63 .79 r
.18591 .08012 m
.18591 .41986 L
.18613 .41986 L
.18613 .08012 L
s
.678 .847 .902 r
.18613 .08012 m
.18613 .4197 L
.18636 .4197 L
.18636 .08012 L
F
.2 .63 .79 r
.18613 .08012 m
.18613 .4197 L
.18636 .4197 L
.18636 .08012 L
s
.678 .847 .902 r
.18636 .08012 m
.18636 .4194 L
.18657 .4194 L
.18657 .08012 L
F
.2 .63 .79 r
.18636 .08012 m
.18636 .4194 L
.18657 .4194 L
.18657 .08012 L
s
.678 .847 .902 r
.18657 .08012 m
.18657 .41911 L
.1869 .41911 L
.1869 .08012 L
F
.2 .63 .79 r
.18657 .08012 m
.18657 .41911 L
.1869 .41911 L
.1869 .08012 L
s
.678 .847 .902 r
.1869 .08012 m
.1869 .41861 L
.18732 .41861 L
.18732 .08012 L
F
.2 .63 .79 r
.1869 .08012 m
.1869 .41861 L
.18732 .41861 L
.18732 .08012 L
s
.678 .847 .902 r
.18732 .08012 m
.18732 .41843 L
.18758 .41843 L
.18758 .08012 L
F
.2 .63 .79 r
.18732 .08012 m
.18732 .41843 L
.18758 .41843 L
.18758 .08012 L
s
.678 .847 .902 r
.18758 .08012 m
.18758 .41821 L
.18805 .41821 L
.18805 .08012 L
F
.2 .63 .79 r
.18758 .08012 m
.18758 .41821 L
.18805 .41821 L
.18805 .08012 L
s
.678 .847 .902 r
.18805 .08012 m
.18805 .41779 L
.18825 .41779 L
.18825 .08012 L
F
.2 .63 .79 r
.18805 .08012 m
.18805 .41779 L
.18825 .41779 L
.18825 .08012 L
s
.678 .847 .902 r
.18825 .08012 m
.18825 .41749 L
.18855 .41749 L
.18855 .08012 L
F
.2 .63 .79 r
.18825 .08012 m
.18825 .41749 L
.18855 .41749 L
.18855 .08012 L
s
.678 .847 .902 r
.18855 .08012 m
.18855 .41712 L
.18889 .41712 L
.18889 .08012 L
F
.2 .63 .79 r
.18855 .08012 m
.18855 .41712 L
.18889 .41712 L
.18889 .08012 L
s
.678 .847 .902 r
.18889 .08012 m
.18889 .41673 L
.18914 .41673 L
.18914 .08012 L
F
.2 .63 .79 r
.18889 .08012 m
.18889 .41673 L
.18914 .41673 L
.18914 .08012 L
s
.678 .847 .902 r
.18914 .08012 m
.18914 .41652 L
.18935 .41652 L
.18935 .08012 L
F
.2 .63 .79 r
.18914 .08012 m
.18914 .41652 L
.18935 .41652 L
.18935 .08012 L
s
.678 .847 .902 r
.18935 .08012 m
.18935 .41647 L
.18972 .41647 L
.18972 .08012 L
F
.2 .63 .79 r
.18935 .08012 m
.18935 .41647 L
.18972 .41647 L
.18972 .08012 L
s
.678 .847 .902 r
.18972 .08012 m
.18972 .41591 L
.19007 .41591 L
.19007 .08012 L
F
.2 .63 .79 r
.18972 .08012 m
.18972 .41591 L
.19007 .41591 L
.19007 .08012 L
s
.678 .847 .902 r
.19007 .08012 m
.19007 .41569 L
.19024 .41569 L
.19024 .08012 L
F
.2 .63 .79 r
.19007 .08012 m
.19007 .41569 L
.19024 .41569 L
.19024 .08012 L
s
.678 .847 .902 r
.19024 .08012 m
.19024 .41552 L
.19046 .41552 L
.19046 .08012 L
F
.2 .63 .79 r
.19024 .08012 m
.19024 .41552 L
.19046 .41552 L
.19046 .08012 L
s
.678 .847 .902 r
.19046 .08012 m
.19046 .41506 L
.19087 .41506 L
.19087 .08012 L
F
.2 .63 .79 r
.19046 .08012 m
.19046 .41506 L
.19087 .41506 L
.19087 .08012 L
s
.678 .847 .902 r
.19087 .08012 m
.19087 .41485 L
.19114 .41485 L
.19114 .08012 L
F
.2 .63 .79 r
.19087 .08012 m
.19087 .41485 L
.19114 .41485 L
.19114 .08012 L
s
.678 .847 .902 r
.19114 .08012 m
.19114 .41429 L
.19162 .41429 L
.19162 .08012 L
F
.2 .63 .79 r
.19114 .08012 m
.19114 .41429 L
.19162 .41429 L
.19162 .08012 L
s
.678 .847 .902 r
.19162 .08012 m
.19162 .41402 L
.19204 .41402 L
.19204 .08012 L
F
.2 .63 .79 r
.19162 .08012 m
.19162 .41402 L
.19204 .41402 L
.19204 .08012 L
s
.678 .847 .902 r
.19204 .08012 m
.19204 .41367 L
.19242 .41367 L
.19242 .08012 L
F
.2 .63 .79 r
.19204 .08012 m
.19204 .41367 L
.19242 .41367 L
.19242 .08012 L
s
.678 .847 .902 r
.19242 .08012 m
.19242 .41301 L
.19287 .41301 L
.19287 .08012 L
F
.2 .63 .79 r
.19242 .08012 m
.19242 .41301 L
.19287 .41301 L
.19287 .08012 L
s
.678 .847 .902 r
.19287 .08012 m
.19287 .41273 L
.19336 .41273 L
.19336 .08012 L
F
.2 .63 .79 r
.19287 .08012 m
.19287 .41273 L
.19336 .41273 L
.19336 .08012 L
s
.678 .847 .902 r
.19336 .08012 m
.19336 .41209 L
.19368 .41209 L
.19368 .08012 L
F
.2 .63 .79 r
.19336 .08012 m
.19336 .41209 L
.19368 .41209 L
.19368 .08012 L
s
.678 .847 .902 r
.19368 .08012 m
.19368 .4119 L
.19399 .4119 L
.19399 .08012 L
F
.2 .63 .79 r
.19368 .08012 m
.19368 .4119 L
.19399 .4119 L
.19399 .08012 L
s
.678 .847 .902 r
.19399 .08012 m
.19399 .4116 L
.19436 .4116 L
.19436 .08012 L
F
.2 .63 .79 r
.19399 .08012 m
.19399 .4116 L
.19436 .4116 L
.19436 .08012 L
s
.678 .847 .902 r
.19436 .08012 m
.19436 .41109 L
.19478 .41109 L
.19478 .08012 L
F
.2 .63 .79 r
.19436 .08012 m
.19436 .41109 L
.19478 .41109 L
.19478 .08012 L
s
.678 .847 .902 r
.19478 .08012 m
.19478 .4108 L
.19527 .4108 L
.19527 .08012 L
F
.2 .63 .79 r
.19478 .08012 m
.19478 .4108 L
.19527 .4108 L
.19527 .08012 L
s
.678 .847 .902 r
.19527 .08012 m
.19527 .41021 L
.19565 .41021 L
.19565 .08012 L
F
.2 .63 .79 r
.19527 .08012 m
.19527 .41021 L
.19565 .41021 L
.19565 .08012 L
s
.678 .847 .902 r
.19565 .08012 m
.19565 .40983 L
.1959 .40983 L
.1959 .08012 L
F
.2 .63 .79 r
.19565 .08012 m
.19565 .40983 L
.1959 .40983 L
.1959 .08012 L
s
.678 .847 .902 r
.1959 .08012 m
.1959 .40958 L
.19635 .40958 L
.19635 .08012 L
F
.2 .63 .79 r
.1959 .08012 m
.1959 .40958 L
.19635 .40958 L
.19635 .08012 L
s
.678 .847 .902 r
.19635 .08012 m
.19635 .40928 L
.19679 .40928 L
.19679 .08012 L
F
.2 .63 .79 r
.19635 .08012 m
.19635 .40928 L
.19679 .40928 L
.19679 .08012 L
s
.678 .847 .902 r
.19679 .08012 m
.19679 .40886 L
.19701 .40886 L
.19701 .08012 L
F
.2 .63 .79 r
.19679 .08012 m
.19679 .40886 L
.19701 .40886 L
.19701 .08012 L
s
.678 .847 .902 r
.19701 .08012 m
.19701 .40851 L
.19742 .40851 L
.19742 .08012 L
F
.2 .63 .79 r
.19701 .08012 m
.19701 .40851 L
.19742 .40851 L
.19742 .08012 L
s
.678 .847 .902 r
.19742 .08012 m
.19742 .40807 L
.19777 .40807 L
.19777 .08012 L
F
.2 .63 .79 r
.19742 .08012 m
.19742 .40807 L
.19777 .40807 L
.19777 .08012 L
s
.678 .847 .902 r
.19777 .08012 m
.19777 .4078 L
.19814 .4078 L
.19814 .08012 L
F
.2 .63 .79 r
.19777 .08012 m
.19777 .4078 L
.19814 .4078 L
.19814 .08012 L
s
.678 .847 .902 r
.19814 .08012 m
.19814 .40748 L
.19849 .40748 L
.19849 .08012 L
F
.2 .63 .79 r
.19814 .08012 m
.19814 .40748 L
.19849 .40748 L
.19849 .08012 L
s
.678 .847 .902 r
.19849 .08012 m
.19849 .40702 L
.19869 .40702 L
.19869 .08012 L
F
.2 .63 .79 r
.19849 .08012 m
.19849 .40702 L
.19869 .40702 L
.19869 .08012 L
s
.678 .847 .902 r
.19869 .08012 m
.19869 .40691 L
.19902 .40691 L
.19902 .08012 L
F
.2 .63 .79 r
.19869 .08012 m
.19869 .40691 L
.19902 .40691 L
.19902 .08012 L
s
.678 .847 .902 r
.19902 .08012 m
.19902 .40664 L
.19933 .40664 L
.19933 .08012 L
F
.2 .63 .79 r
.19902 .08012 m
.19902 .40664 L
.19933 .40664 L
.19933 .08012 L
s
.678 .847 .902 r
.19933 .08012 m
.19933 .40614 L
.19975 .40614 L
.19975 .08012 L
F
.2 .63 .79 r
.19933 .08012 m
.19933 .40614 L
.19975 .40614 L
.19975 .08012 L
s
.678 .847 .902 r
.19975 .08012 m
.19975 .40567 L
.20017 .40567 L
.20017 .08012 L
F
.2 .63 .79 r
.19975 .08012 m
.19975 .40567 L
.20017 .40567 L
.20017 .08012 L
s
.678 .847 .902 r
.20017 .08012 m
.20017 .40532 L
.20052 .40532 L
.20052 .08012 L
F
.2 .63 .79 r
.20017 .08012 m
.20017 .40532 L
.20052 .40532 L
.20052 .08012 L
s
.678 .847 .902 r
.20052 .08012 m
.20052 .40488 L
.2009 .40488 L
.2009 .08012 L
F
.2 .63 .79 r
.20052 .08012 m
.20052 .40488 L
.2009 .40488 L
.2009 .08012 L
s
.678 .847 .902 r
.2009 .08012 m
.2009 .40471 L
.20109 .40471 L
.20109 .08012 L
F
.2 .63 .79 r
.2009 .08012 m
.2009 .40471 L
.20109 .40471 L
.20109 .08012 L
s
.678 .847 .902 r
.20109 .08012 m
.20109 .40419 L
.20155 .40419 L
.20155 .08012 L
F
.2 .63 .79 r
.20109 .08012 m
.20109 .40419 L
.20155 .40419 L
.20155 .08012 L
s
.678 .847 .902 r
.20155 .08012 m
.20155 .40405 L
.2019 .40405 L
.2019 .08012 L
F
.2 .63 .79 r
.20155 .08012 m
.20155 .40405 L
.2019 .40405 L
.2019 .08012 L
s
.678 .847 .902 r
.2019 .08012 m
.2019 .40361 L
.2021 .40361 L
.2021 .08012 L
F
.2 .63 .79 r
.2019 .08012 m
.2019 .40361 L
.2021 .40361 L
.2021 .08012 L
s
.678 .847 .902 r
.2021 .08012 m
.2021 .40326 L
.20248 .40326 L
.20248 .08012 L
F
.2 .63 .79 r
.2021 .08012 m
.2021 .40326 L
.20248 .40326 L
.20248 .08012 L
s
.678 .847 .902 r
.20248 .08012 m
.20248 .40308 L
.20272 .40308 L
.20272 .08012 L
F
.2 .63 .79 r
.20248 .08012 m
.20248 .40308 L
.20272 .40308 L
.20272 .08012 L
s
.678 .847 .902 r
.20272 .08012 m
.20272 .40273 L
.20314 .40273 L
.20314 .08012 L
F
.2 .63 .79 r
.20272 .08012 m
.20272 .40273 L
.20314 .40273 L
.20314 .08012 L
s
.678 .847 .902 r
.20314 .08012 m
.20314 .40242 L
.20334 .40242 L
.20334 .08012 L
F
.2 .63 .79 r
.20314 .08012 m
.20314 .40242 L
.20334 .40242 L
.20334 .08012 L
s
.678 .847 .902 r
.20334 .08012 m
.20334 .4023 L
.20349 .4023 L
.20349 .08012 L
F
.2 .63 .79 r
.20334 .08012 m
.20334 .4023 L
.20349 .4023 L
.20349 .08012 L
s
.678 .847 .902 r
.20349 .08012 m
.20349 .40195 L
.20398 .40195 L
.20398 .08012 L
F
.2 .63 .79 r
.20349 .08012 m
.20349 .40195 L
.20398 .40195 L
.20398 .08012 L
s
.678 .847 .902 r
.20398 .08012 m
.20398 .40123 L
.20444 .40123 L
.20444 .08012 L
F
.2 .63 .79 r
.20398 .08012 m
.20398 .40123 L
.20444 .40123 L
.20444 .08012 L
s
.678 .847 .902 r
.20444 .08012 m
.20444 .40115 L
.20469 .40115 L
.20469 .08012 L
F
.2 .63 .79 r
.20444 .08012 m
.20444 .40115 L
.20469 .40115 L
.20469 .08012 L
s
.678 .847 .902 r
.20469 .08012 m
.20469 .4006 L
.20511 .4006 L
.20511 .08012 L
F
.2 .63 .79 r
.20469 .08012 m
.20469 .4006 L
.20511 .4006 L
.20511 .08012 L
s
.678 .847 .902 r
.20511 .08012 m
.20511 .40055 L
.20534 .40055 L
.20534 .08012 L
F
.2 .63 .79 r
.20511 .08012 m
.20511 .40055 L
.20534 .40055 L
.20534 .08012 L
s
.678 .847 .902 r
.20534 .08012 m
.20534 .40023 L
.20559 .40023 L
.20559 .08012 L
F
.2 .63 .79 r
.20534 .08012 m
.20534 .40023 L
.20559 .40023 L
.20559 .08012 L
s
.678 .847 .902 r
.20559 .08012 m
.20559 .39971 L
.20597 .39971 L
.20597 .08012 L
F
.2 .63 .79 r
.20559 .08012 m
.20559 .39971 L
.20597 .39971 L
.20597 .08012 L
s
.678 .847 .902 r
.20597 .08012 m
.20597 .39955 L
.20619 .39955 L
.20619 .08012 L
F
.2 .63 .79 r
.20597 .08012 m
.20597 .39955 L
.20619 .39955 L
.20619 .08012 L
s
.678 .847 .902 r
.20619 .08012 m
.20619 .39946 L
.20636 .39946 L
.20636 .08012 L
F
.2 .63 .79 r
.20619 .08012 m
.20619 .39946 L
.20636 .39946 L
.20636 .08012 L
s
.678 .847 .902 r
.20636 .08012 m
.20636 .39926 L
.20678 .39926 L
.20678 .08012 L
F
.2 .63 .79 r
.20636 .08012 m
.20636 .39926 L
.20678 .39926 L
.20678 .08012 L
s
.678 .847 .902 r
.20678 .08012 m
.20678 .39869 L
.207 .39869 L
.207 .08012 L
F
.2 .63 .79 r
.20678 .08012 m
.20678 .39869 L
.207 .39869 L
.207 .08012 L
s
.678 .847 .902 r
.207 .08012 m
.207 .39862 L
.20729 .39862 L
.20729 .08012 L
F
.2 .63 .79 r
.207 .08012 m
.207 .39862 L
.20729 .39862 L
.20729 .08012 L
s
.678 .847 .902 r
.20729 .08012 m
.20729 .39826 L
.20753 .39826 L
.20753 .08012 L
F
.2 .63 .79 r
.20729 .08012 m
.20729 .39826 L
.20753 .39826 L
.20753 .08012 L
s
.678 .847 .902 r
.20753 .08012 m
.20753 .39801 L
.20775 .39801 L
.20775 .08012 L
F
.2 .63 .79 r
.20753 .08012 m
.20753 .39801 L
.20775 .39801 L
.20775 .08012 L
s
.678 .847 .902 r
.20775 .08012 m
.20775 .39787 L
.20808 .39787 L
.20808 .08012 L
F
.2 .63 .79 r
.20775 .08012 m
.20775 .39787 L
.20808 .39787 L
.20808 .08012 L
s
.678 .847 .902 r
.20808 .08012 m
.20808 .39738 L
.20833 .39738 L
.20833 .08012 L
F
.2 .63 .79 r
.20808 .08012 m
.20808 .39738 L
.20833 .39738 L
.20833 .08012 L
s
.678 .847 .902 r
.20833 .08012 m
.20833 .39717 L
.2086 .39717 L
.2086 .08012 L
F
.2 .63 .79 r
.20833 .08012 m
.20833 .39717 L
.2086 .39717 L
.2086 .08012 L
s
.678 .847 .902 r
.2086 .08012 m
.2086 .39693 L
.20896 .39693 L
.20896 .08012 L
F
.2 .63 .79 r
.2086 .08012 m
.2086 .39693 L
.20896 .39693 L
.20896 .08012 L
s
.678 .847 .902 r
.20896 .08012 m
.20896 .39661 L
.20924 .39661 L
.20924 .08012 L
F
.2 .63 .79 r
.20896 .08012 m
.20896 .39661 L
.20924 .39661 L
.20924 .08012 L
s
.678 .847 .902 r
.20924 .08012 m
.20924 .39643 L
.2096 .39643 L
.2096 .08012 L
F
.2 .63 .79 r
.20924 .08012 m
.20924 .39643 L
.2096 .39643 L
.2096 .08012 L
s
.678 .847 .902 r
.2096 .08012 m
.2096 .39604 L
.20977 .39604 L
.20977 .08012 L
F
.2 .63 .79 r
.2096 .08012 m
.2096 .39604 L
.20977 .39604 L
.20977 .08012 L
s
.678 .847 .902 r
.20977 .08012 m
.20977 .39552 L
.21021 .39552 L
.21021 .08012 L
F
.2 .63 .79 r
.20977 .08012 m
.20977 .39552 L
.21021 .39552 L
.21021 .08012 L
s
.678 .847 .902 r
.21021 .08012 m
.21021 .39527 L
.21043 .39527 L
.21043 .08012 L
F
.2 .63 .79 r
.21021 .08012 m
.21021 .39527 L
.21043 .39527 L
.21043 .08012 L
s
.678 .847 .902 r
.21043 .08012 m
.21043 .39494 L
.2108 .39494 L
.2108 .08012 L
F
.2 .63 .79 r
.21043 .08012 m
.21043 .39494 L
.2108 .39494 L
.2108 .08012 L
s
.678 .847 .902 r
.2108 .08012 m
.2108 .39475 L
.21098 .39475 L
.21098 .08012 L
F
.2 .63 .79 r
.2108 .08012 m
.2108 .39475 L
.21098 .39475 L
.21098 .08012 L
s
.678 .847 .902 r
.21098 .08012 m
.21098 .39429 L
.21144 .39429 L
.21144 .08012 L
F
.2 .63 .79 r
.21098 .08012 m
.21098 .39429 L
.21144 .39429 L
.21144 .08012 L
s
.678 .847 .902 r
.21144 .08012 m
.21144 .39398 L
.2119 .39398 L
.2119 .08012 L
F
.2 .63 .79 r
.21144 .08012 m
.21144 .39398 L
.2119 .39398 L
.2119 .08012 L
s
.678 .847 .902 r
.2119 .08012 m
.2119 .39336 L
.21234 .39336 L
.21234 .08012 L
F
.2 .63 .79 r
.2119 .08012 m
.2119 .39336 L
.21234 .39336 L
.21234 .08012 L
s
.678 .847 .902 r
.21234 .08012 m
.21234 .39302 L
.21279 .39302 L
.21279 .08012 L
F
.2 .63 .79 r
.21234 .08012 m
.21234 .39302 L
.21279 .39302 L
.21279 .08012 L
s
.678 .847 .902 r
.21279 .08012 m
.21279 .39272 L
.21315 .39272 L
.21315 .08012 L
F
.2 .63 .79 r
.21279 .08012 m
.21279 .39272 L
.21315 .39272 L
.21315 .08012 L
s
.678 .847 .902 r
.21315 .08012 m
.21315 .3924 L
.21338 .3924 L
.21338 .08012 L
F
.2 .63 .79 r
.21315 .08012 m
.21315 .3924 L
.21338 .3924 L
.21338 .08012 L
s
.678 .847 .902 r
.21338 .08012 m
.21338 .39221 L
.21375 .39221 L
.21375 .08012 L
F
.2 .63 .79 r
.21338 .08012 m
.21338 .39221 L
.21375 .39221 L
.21375 .08012 L
s
.678 .847 .902 r
.21375 .08012 m
.21375 .39169 L
.21417 .39169 L
.21417 .08012 L
F
.2 .63 .79 r
.21375 .08012 m
.21375 .39169 L
.21417 .39169 L
.21417 .08012 L
s
.678 .847 .902 r
.21417 .08012 m
.21417 .39135 L
.2146 .39135 L
.2146 .08012 L
F
.2 .63 .79 r
.21417 .08012 m
.21417 .39135 L
.2146 .39135 L
.2146 .08012 L
s
.678 .847 .902 r
.2146 .08012 m
.2146 .39099 L
.21476 .39099 L
.21476 .08012 L
F
.2 .63 .79 r
.2146 .08012 m
.2146 .39099 L
.21476 .39099 L
.21476 .08012 L
s
.678 .847 .902 r
.21476 .08012 m
.21476 .39091 L
.21499 .39091 L
.21499 .08012 L
F
.2 .63 .79 r
.21476 .08012 m
.21476 .39091 L
.21499 .39091 L
.21499 .08012 L
s
.678 .847 .902 r
.21499 .08012 m
.21499 .39067 L
.21531 .39067 L
.21531 .08012 L
F
.2 .63 .79 r
.21499 .08012 m
.21499 .39067 L
.21531 .39067 L
.21531 .08012 L
s
.678 .847 .902 r
.21531 .08012 m
.21531 .39009 L
.21568 .39009 L
.21568 .08012 L
F
.2 .63 .79 r
.21531 .08012 m
.21531 .39009 L
.21568 .39009 L
.21568 .08012 L
s
.678 .847 .902 r
.21568 .08012 m
.21568 .38985 L
.216 .38985 L
.216 .08012 L
F
.2 .63 .79 r
.21568 .08012 m
.21568 .38985 L
.216 .38985 L
.216 .08012 L
s
.678 .847 .902 r
.216 .08012 m
.216 .38957 L
.21647 .38957 L
.21647 .08012 L
F
.2 .63 .79 r
.216 .08012 m
.216 .38957 L
.21647 .38957 L
.21647 .08012 L
s
.678 .847 .902 r
.21647 .08012 m
.21647 .38916 L
.21667 .38916 L
.21667 .08012 L
F
.2 .63 .79 r
.21647 .08012 m
.21647 .38916 L
.21667 .38916 L
.21667 .08012 L
s
.678 .847 .902 r
.21667 .08012 m
.21667 .38899 L
.21683 .38899 L
.21683 .08012 L
F
.2 .63 .79 r
.21667 .08012 m
.21667 .38899 L
.21683 .38899 L
.21683 .08012 L
s
.678 .847 .902 r
.21683 .08012 m
.21683 .38886 L
.21702 .38886 L
.21702 .08012 L
F
.2 .63 .79 r
.21683 .08012 m
.21683 .38886 L
.21702 .38886 L
.21702 .08012 L
s
.678 .847 .902 r
.21702 .08012 m
.21702 .38864 L
.21727 .38864 L
.21727 .08012 L
F
.2 .63 .79 r
.21702 .08012 m
.21702 .38864 L
.21727 .38864 L
.21727 .08012 L
s
.678 .847 .902 r
.21727 .08012 m
.21727 .38842 L
.21744 .38842 L
.21744 .08012 L
F
.2 .63 .79 r
.21727 .08012 m
.21727 .38842 L
.21744 .38842 L
.21744 .08012 L
s
.678 .847 .902 r
.21744 .08012 m
.21744 .38817 L
.21766 .38817 L
.21766 .08012 L
F
.2 .63 .79 r
.21744 .08012 m
.21744 .38817 L
.21766 .38817 L
.21766 .08012 L
s
.678 .847 .902 r
.21766 .08012 m
.21766 .38791 L
.21811 .38791 L
.21811 .08012 L
F
.2 .63 .79 r
.21766 .08012 m
.21766 .38791 L
.21811 .38791 L
.21811 .08012 L
s
.678 .847 .902 r
.21811 .08012 m
.21811 .38746 L
.21849 .38746 L
.21849 .08012 L
F
.2 .63 .79 r
.21811 .08012 m
.21811 .38746 L
.21849 .38746 L
.21849 .08012 L
s
.678 .847 .902 r
.21849 .08012 m
.21849 .38697 L
.21898 .38697 L
.21898 .08012 L
F
.2 .63 .79 r
.21849 .08012 m
.21849 .38697 L
.21898 .38697 L
.21898 .08012 L
s
.678 .847 .902 r
.21898 .08012 m
.21898 .38662 L
.21923 .38662 L
.21923 .08012 L
F
.2 .63 .79 r
.21898 .08012 m
.21898 .38662 L
.21923 .38662 L
.21923 .08012 L
s
.678 .847 .902 r
.21923 .08012 m
.21923 .38615 L
.21971 .38615 L
.21971 .08012 L
F
.2 .63 .79 r
.21923 .08012 m
.21923 .38615 L
.21971 .38615 L
.21971 .08012 L
s
.678 .847 .902 r
.21971 .08012 m
.21971 .38585 L
.22014 .38585 L
.22014 .08012 L
F
.2 .63 .79 r
.21971 .08012 m
.21971 .38585 L
.22014 .38585 L
.22014 .08012 L
s
.678 .847 .902 r
.22014 .08012 m
.22014 .38548 L
.22034 .38548 L
.22034 .08012 L
F
.2 .63 .79 r
.22014 .08012 m
.22014 .38548 L
.22034 .38548 L
.22034 .08012 L
s
.678 .847 .902 r
.22034 .08012 m
.22034 .38539 L
.22071 .38539 L
.22071 .08012 L
F
.2 .63 .79 r
.22034 .08012 m
.22034 .38539 L
.22071 .38539 L
.22071 .08012 L
s
.678 .847 .902 r
.22071 .08012 m
.22071 .38501 L
.22111 .38501 L
.22111 .08012 L
F
.2 .63 .79 r
.22071 .08012 m
.22071 .38501 L
.22111 .38501 L
.22111 .08012 L
s
.678 .847 .902 r
.22111 .08012 m
.22111 .38465 L
.22132 .38465 L
.22132 .08012 L
F
.2 .63 .79 r
.22111 .08012 m
.22111 .38465 L
.22132 .38465 L
.22132 .08012 L
s
.678 .847 .902 r
.22132 .08012 m
.22132 .38443 L
.22159 .38443 L
.22159 .08012 L
F
.2 .63 .79 r
.22132 .08012 m
.22132 .38443 L
.22159 .38443 L
.22159 .08012 L
s
.678 .847 .902 r
.22159 .08012 m
.22159 .38391 L
.22202 .38391 L
.22202 .08012 L
F
.2 .63 .79 r
.22159 .08012 m
.22159 .38391 L
.22202 .38391 L
.22202 .08012 L
s
.678 .847 .902 r
.22202 .08012 m
.22202 .38364 L
.22241 .38364 L
.22241 .08012 L
F
.2 .63 .79 r
.22202 .08012 m
.22202 .38364 L
.22241 .38364 L
.22241 .08012 L
s
.678 .847 .902 r
.22241 .08012 m
.22241 .38339 L
.22289 .38339 L
.22289 .08012 L
F
.2 .63 .79 r
.22241 .08012 m
.22241 .38339 L
.22289 .38339 L
.22289 .08012 L
s
.678 .847 .902 r
.22289 .08012 m
.22289 .38292 L
.22333 .38292 L
.22333 .08012 L
F
.2 .63 .79 r
.22289 .08012 m
.22289 .38292 L
.22333 .38292 L
.22333 .08012 L
s
.678 .847 .902 r
.22333 .08012 m
.22333 .38235 L
.22353 .38235 L
.22353 .08012 L
F
.2 .63 .79 r
.22333 .08012 m
.22333 .38235 L
.22353 .38235 L
.22353 .08012 L
s
.678 .847 .902 r
.22353 .08012 m
.22353 .38215 L
.22375 .38215 L
.22375 .08012 L
F
.2 .63 .79 r
.22353 .08012 m
.22353 .38215 L
.22375 .38215 L
.22375 .08012 L
s
.678 .847 .902 r
.22375 .08012 m
.22375 .38201 L
.22391 .38201 L
.22391 .08012 L
F
.2 .63 .79 r
.22375 .08012 m
.22375 .38201 L
.22391 .38201 L
.22391 .08012 L
s
.678 .847 .902 r
.22391 .08012 m
.22391 .38176 L
.2243 .38176 L
.2243 .08012 L
F
.2 .63 .79 r
.22391 .08012 m
.22391 .38176 L
.2243 .38176 L
.2243 .08012 L
s
.678 .847 .902 r
.2243 .08012 m
.2243 .38151 L
.22449 .38151 L
.22449 .08012 L
F
.2 .63 .79 r
.2243 .08012 m
.2243 .38151 L
.22449 .38151 L
.22449 .08012 L
s
.678 .847 .902 r
.22449 .08012 m
.22449 .3813 L
.22466 .3813 L
.22466 .08012 L
F
.2 .63 .79 r
.22449 .08012 m
.22449 .3813 L
.22466 .3813 L
.22466 .08012 L
s
.678 .847 .902 r
.22466 .08012 m
.22466 .38107 L
.22506 .38107 L
.22506 .08012 L
F
.2 .63 .79 r
.22466 .08012 m
.22466 .38107 L
.22506 .38107 L
.22506 .08012 L
s
.678 .847 .902 r
.22506 .08012 m
.22506 .38078 L
.22543 .38078 L
.22543 .08012 L
F
.2 .63 .79 r
.22506 .08012 m
.22506 .38078 L
.22543 .38078 L
.22543 .08012 L
s
.678 .847 .902 r
.22543 .08012 m
.22543 .38013 L
.22589 .38013 L
.22589 .08012 L
F
.2 .63 .79 r
.22543 .08012 m
.22543 .38013 L
.22589 .38013 L
.22589 .08012 L
s
.678 .847 .902 r
.22589 .08012 m
.22589 .38 L
.22611 .38 L
.22611 .08012 L
F
.2 .63 .79 r
.22589 .08012 m
.22589 .38 L
.22611 .38 L
.22611 .08012 L
s
.678 .847 .902 r
.22611 .08012 m
.22611 .37967 L
.22628 .37967 L
.22628 .08012 L
F
.2 .63 .79 r
.22611 .08012 m
.22611 .37967 L
.22628 .37967 L
.22628 .08012 L
s
.678 .847 .902 r
.22628 .08012 m
.22628 .37947 L
.22664 .37947 L
.22664 .08012 L
F
.2 .63 .79 r
.22628 .08012 m
.22628 .37947 L
.22664 .37947 L
.22664 .08012 L
s
.678 .847 .902 r
.22664 .08012 m
.22664 .37929 L
.22701 .37929 L
.22701 .08012 L
F
.2 .63 .79 r
.22664 .08012 m
.22664 .37929 L
.22701 .37929 L
.22701 .08012 L
s
.678 .847 .902 r
.22701 .08012 m
.22701 .37887 L
.22723 .37887 L
.22723 .08012 L
F
.2 .63 .79 r
.22701 .08012 m
.22701 .37887 L
.22723 .37887 L
.22723 .08012 L
s
.678 .847 .902 r
.22723 .08012 m
.22723 .37864 L
.22746 .37864 L
.22746 .08012 L
F
.2 .63 .79 r
.22723 .08012 m
.22723 .37864 L
.22746 .37864 L
.22746 .08012 L
s
.678 .847 .902 r
.22746 .08012 m
.22746 .37831 L
.22778 .37831 L
.22778 .08012 L
F
.2 .63 .79 r
.22746 .08012 m
.22746 .37831 L
.22778 .37831 L
.22778 .08012 L
s
.678 .847 .902 r
.22778 .08012 m
.22778 .3778 L
.22827 .3778 L
.22827 .08012 L
F
.2 .63 .79 r
.22778 .08012 m
.22778 .3778 L
.22827 .3778 L
.22827 .08012 L
s
.678 .847 .902 r
.22827 .08012 m
.22827 .37769 L
.22858 .37769 L
.22858 .08012 L
F
.2 .63 .79 r
.22827 .08012 m
.22827 .37769 L
.22858 .37769 L
.22858 .08012 L
s
.678 .847 .902 r
.22858 .08012 m
.22858 .3774 L
.22875 .3774 L
.22875 .08012 L
F
.2 .63 .79 r
.22858 .08012 m
.22858 .3774 L
.22875 .3774 L
.22875 .08012 L
s
.678 .847 .902 r
.22875 .08012 m
.22875 .37718 L
.22895 .37718 L
.22895 .08012 L
F
.2 .63 .79 r
.22875 .08012 m
.22875 .37718 L
.22895 .37718 L
.22895 .08012 L
s
.678 .847 .902 r
.22895 .08012 m
.22895 .37705 L
.22915 .37705 L
.22915 .08012 L
F
.2 .63 .79 r
.22895 .08012 m
.22895 .37705 L
.22915 .37705 L
.22915 .08012 L
s
.678 .847 .902 r
.22915 .08012 m
.22915 .3766 L
.22957 .3766 L
.22957 .08012 L
F
.2 .63 .79 r
.22915 .08012 m
.22915 .3766 L
.22957 .3766 L
.22957 .08012 L
s
.678 .847 .902 r
.22957 .08012 m
.22957 .37645 L
.22976 .37645 L
.22976 .08012 L
F
.2 .63 .79 r
.22957 .08012 m
.22957 .37645 L
.22976 .37645 L
.22976 .08012 L
s
.678 .847 .902 r
.22976 .08012 m
.22976 .37621 L
.23 .37621 L
.23 .08012 L
F
.2 .63 .79 r
.22976 .08012 m
.22976 .37621 L
.23 .37621 L
.23 .08012 L
s
.678 .847 .902 r
.23 .08012 m
.23 .37596 L
.23049 .37596 L
.23049 .08012 L
F
.2 .63 .79 r
.23 .08012 m
.23 .37596 L
.23049 .37596 L
.23049 .08012 L
s
.678 .847 .902 r
.23049 .08012 m
.23049 .37529 L
.23085 .37529 L
.23085 .08012 L
F
.2 .63 .79 r
.23049 .08012 m
.23049 .37529 L
.23085 .37529 L
.23085 .08012 L
s
.678 .847 .902 r
.23085 .08012 m
.23085 .37518 L
.23102 .37518 L
.23102 .08012 L
F
.2 .63 .79 r
.23085 .08012 m
.23085 .37518 L
.23102 .37518 L
.23102 .08012 L
s
.678 .847 .902 r
.23102 .08012 m
.23102 .37481 L
.23137 .37481 L
.23137 .08012 L
F
.2 .63 .79 r
.23102 .08012 m
.23102 .37481 L
.23137 .37481 L
.23137 .08012 L
s
.678 .847 .902 r
.23137 .08012 m
.23137 .37439 L
.23182 .37439 L
.23182 .08012 L
F
.2 .63 .79 r
.23137 .08012 m
.23137 .37439 L
.23182 .37439 L
.23182 .08012 L
s
.678 .847 .902 r
.23182 .08012 m
.23182 .37421 L
.23214 .37421 L
.23214 .08012 L
F
.2 .63 .79 r
.23182 .08012 m
.23182 .37421 L
.23214 .37421 L
.23214 .08012 L
s
.678 .847 .902 r
.23214 .08012 m
.23214 .37375 L
.23241 .37375 L
.23241 .08012 L
F
.2 .63 .79 r
.23214 .08012 m
.23214 .37375 L
.23241 .37375 L
.23241 .08012 L
s
.678 .847 .902 r
.23241 .08012 m
.23241 .37346 L
.23289 .37346 L
.23289 .08012 L
F
.2 .63 .79 r
.23241 .08012 m
.23241 .37346 L
.23289 .37346 L
.23289 .08012 L
s
.678 .847 .902 r
.23289 .08012 m
.23289 .3728 L
.23336 .3728 L
.23336 .08012 L
F
.2 .63 .79 r
.23289 .08012 m
.23289 .3728 L
.23336 .3728 L
.23336 .08012 L
s
.678 .847 .902 r
.23336 .08012 m
.23336 .37278 L
.23362 .37278 L
.23362 .08012 L
F
.2 .63 .79 r
.23336 .08012 m
.23336 .37278 L
.23362 .37278 L
.23362 .08012 L
s
.678 .847 .902 r
.23362 .08012 m
.23362 .37233 L
.23386 .37233 L
.23386 .08012 L
F
.2 .63 .79 r
.23362 .08012 m
.23362 .37233 L
.23386 .37233 L
.23386 .08012 L
s
.678 .847 .902 r
.23386 .08012 m
.23386 .37231 L
.23413 .37231 L
.23413 .08012 L
F
.2 .63 .79 r
.23386 .08012 m
.23386 .37231 L
.23413 .37231 L
.23413 .08012 L
s
.678 .847 .902 r
.23413 .08012 m
.23413 .37183 L
.23438 .37183 L
.23438 .08012 L
F
.2 .63 .79 r
.23413 .08012 m
.23413 .37183 L
.23438 .37183 L
.23438 .08012 L
s
.678 .847 .902 r
.23438 .08012 m
.23438 .37169 L
.23456 .37169 L
.23456 .08012 L
F
.2 .63 .79 r
.23438 .08012 m
.23438 .37169 L
.23456 .37169 L
.23456 .08012 L
s
.678 .847 .902 r
.23456 .08012 m
.23456 .37155 L
.23472 .37155 L
.23472 .08012 L
F
.2 .63 .79 r
.23456 .08012 m
.23456 .37155 L
.23472 .37155 L
.23472 .08012 L
s
.678 .847 .902 r
.23472 .08012 m
.23472 .37133 L
.23516 .37133 L
.23516 .08012 L
F
.2 .63 .79 r
.23472 .08012 m
.23472 .37133 L
.23516 .37133 L
.23516 .08012 L
s
.678 .847 .902 r
.23516 .08012 m
.23516 .37104 L
.23542 .37104 L
.23542 .08012 L
F
.2 .63 .79 r
.23516 .08012 m
.23516 .37104 L
.23542 .37104 L
.23542 .08012 L
s
.678 .847 .902 r
.23542 .08012 m
.23542 .3706 L
.23577 .3706 L
.23577 .08012 L
F
.2 .63 .79 r
.23542 .08012 m
.23542 .3706 L
.23577 .3706 L
.23577 .08012 L
s
.678 .847 .902 r
.23577 .08012 m
.23577 .37027 L
.23626 .37027 L
.23626 .08012 L
F
.2 .63 .79 r
.23577 .08012 m
.23577 .37027 L
.23626 .37027 L
.23626 .08012 L
s
.678 .847 .902 r
.23626 .08012 m
.23626 .37 L
.23665 .37 L
.23665 .08012 L
F
.2 .63 .79 r
.23626 .08012 m
.23626 .37 L
.23665 .37 L
.23665 .08012 L
s
.678 .847 .902 r
.23665 .08012 m
.23665 .36963 L
.23686 .36963 L
.23686 .08012 L
F
.2 .63 .79 r
.23665 .08012 m
.23665 .36963 L
.23686 .36963 L
.23686 .08012 L
s
.678 .847 .902 r
.23686 .08012 m
.23686 .36904 L
.23728 .36904 L
.23728 .08012 L
F
.2 .63 .79 r
.23686 .08012 m
.23686 .36904 L
.23728 .36904 L
.23728 .08012 L
s
.678 .847 .902 r
.23728 .08012 m
.23728 .36885 L
.23773 .36885 L
.23773 .08012 L
F
.2 .63 .79 r
.23728 .08012 m
.23728 .36885 L
.23773 .36885 L
.23773 .08012 L
s
.678 .847 .902 r
.23773 .08012 m
.23773 .36839 L
.23802 .36839 L
.23802 .08012 L
F
.2 .63 .79 r
.23773 .08012 m
.23773 .36839 L
.23802 .36839 L
.23802 .08012 L
s
.678 .847 .902 r
.23802 .08012 m
.23802 .36815 L
.23823 .36815 L
.23823 .08012 L
F
.2 .63 .79 r
.23802 .08012 m
.23802 .36815 L
.23823 .36815 L
.23823 .08012 L
s
.678 .847 .902 r
.23823 .08012 m
.23823 .36808 L
.23845 .36808 L
.23845 .08012 L
F
.2 .63 .79 r
.23823 .08012 m
.23823 .36808 L
.23845 .36808 L
.23845 .08012 L
s
.678 .847 .902 r
.23845 .08012 m
.23845 .36785 L
.23887 .36785 L
.23887 .08012 L
F
.2 .63 .79 r
.23845 .08012 m
.23845 .36785 L
.23887 .36785 L
.23887 .08012 L
s
.678 .847 .902 r
.23887 .08012 m
.23887 .3675 L
.2393 .3675 L
.2393 .08012 L
F
.2 .63 .79 r
.23887 .08012 m
.23887 .3675 L
.2393 .3675 L
.2393 .08012 L
s
.678 .847 .902 r
.2393 .08012 m
.2393 .36707 L
.23956 .36707 L
.23956 .08012 L
F
.2 .63 .79 r
.2393 .08012 m
.2393 .36707 L
.23956 .36707 L
.23956 .08012 L
s
.678 .847 .902 r
.23956 .08012 m
.23956 .3665 L
.23995 .3665 L
.23995 .08012 L
F
.2 .63 .79 r
.23956 .08012 m
.23956 .3665 L
.23995 .3665 L
.23995 .08012 L
s
.678 .847 .902 r
.23995 .08012 m
.23995 .36639 L
.24025 .36639 L
.24025 .08012 L
F
.2 .63 .79 r
.23995 .08012 m
.23995 .36639 L
.24025 .36639 L
.24025 .08012 L
s
.678 .847 .902 r
.24025 .08012 m
.24025 .36599 L
.24069 .36599 L
.24069 .08012 L
F
.2 .63 .79 r
.24025 .08012 m
.24025 .36599 L
.24069 .36599 L
.24069 .08012 L
s
.678 .847 .902 r
.24069 .08012 m
.24069 .36573 L
.24097 .36573 L
.24097 .08012 L
F
.2 .63 .79 r
.24069 .08012 m
.24069 .36573 L
.24097 .36573 L
.24097 .08012 L
s
.678 .847 .902 r
.24097 .08012 m
.24097 .36526 L
.24125 .36526 L
.24125 .08012 L
F
.2 .63 .79 r
.24097 .08012 m
.24097 .36526 L
.24125 .36526 L
.24125 .08012 L
s
.678 .847 .902 r
.24125 .08012 m
.24125 .36516 L
.24146 .36516 L
.24146 .08012 L
F
.2 .63 .79 r
.24125 .08012 m
.24125 .36516 L
.24146 .36516 L
.24146 .08012 L
s
.678 .847 .902 r
.24146 .08012 m
.24146 .36489 L
.24178 .36489 L
.24178 .08012 L
F
.2 .63 .79 r
.24146 .08012 m
.24146 .36489 L
.24178 .36489 L
.24178 .08012 L
s
.678 .847 .902 r
.24178 .08012 m
.24178 .36469 L
.24195 .36469 L
.24195 .08012 L
F
.2 .63 .79 r
.24178 .08012 m
.24178 .36469 L
.24195 .36469 L
.24195 .08012 L
s
.678 .847 .902 r
.24195 .08012 m
.24195 .36453 L
.24221 .36453 L
.24221 .08012 L
F
.2 .63 .79 r
.24195 .08012 m
.24195 .36453 L
.24221 .36453 L
.24221 .08012 L
s
.678 .847 .902 r
.24221 .08012 m
.24221 .36418 L
.24239 .36418 L
.24239 .08012 L
F
.2 .63 .79 r
.24221 .08012 m
.24221 .36418 L
.24239 .36418 L
.24239 .08012 L
s
.678 .847 .902 r
.24239 .08012 m
.24239 .36411 L
.24277 .36411 L
.24277 .08012 L
F
.2 .63 .79 r
.24239 .08012 m
.24239 .36411 L
.24277 .36411 L
.24277 .08012 L
s
.678 .847 .902 r
.24277 .08012 m
.24277 .36375 L
.24317 .36375 L
.24317 .08012 L
F
.2 .63 .79 r
.24277 .08012 m
.24277 .36375 L
.24317 .36375 L
.24317 .08012 L
s
.678 .847 .902 r
.24317 .08012 m
.24317 .3632 L
.24357 .3632 L
.24357 .08012 L
F
.2 .63 .79 r
.24317 .08012 m
.24317 .3632 L
.24357 .3632 L
.24357 .08012 L
s
.678 .847 .902 r
.24357 .08012 m
.24357 .36296 L
.24376 .36296 L
.24376 .08012 L
F
.2 .63 .79 r
.24357 .08012 m
.24357 .36296 L
.24376 .36296 L
.24376 .08012 L
s
.678 .847 .902 r
.24376 .08012 m
.24376 .3628 L
.24424 .3628 L
.24424 .08012 L
F
.2 .63 .79 r
.24376 .08012 m
.24376 .3628 L
.24424 .3628 L
.24424 .08012 L
s
.678 .847 .902 r
.24424 .08012 m
.24424 .36236 L
.24458 .36236 L
.24458 .08012 L
F
.2 .63 .79 r
.24424 .08012 m
.24424 .36236 L
.24458 .36236 L
.24458 .08012 L
s
.678 .847 .902 r
.24458 .08012 m
.24458 .36181 L
.24505 .36181 L
.24505 .08012 L
F
.2 .63 .79 r
.24458 .08012 m
.24458 .36181 L
.24505 .36181 L
.24505 .08012 L
s
.678 .847 .902 r
.24505 .08012 m
.24505 .36141 L
.24528 .36141 L
.24528 .08012 L
F
.2 .63 .79 r
.24505 .08012 m
.24505 .36141 L
.24528 .36141 L
.24528 .08012 L
s
.678 .847 .902 r
.24528 .08012 m
.24528 .36128 L
.24562 .36128 L
.24562 .08012 L
F
.2 .63 .79 r
.24528 .08012 m
.24528 .36128 L
.24562 .36128 L
.24562 .08012 L
s
.678 .847 .902 r
.24562 .08012 m
.24562 .36101 L
.2459 .36101 L
.2459 .08012 L
F
.2 .63 .79 r
.24562 .08012 m
.24562 .36101 L
.2459 .36101 L
.2459 .08012 L
s
.678 .847 .902 r
.2459 .08012 m
.2459 .36065 L
.24629 .36065 L
.24629 .08012 L
F
.2 .63 .79 r
.2459 .08012 m
.2459 .36065 L
.24629 .36065 L
.24629 .08012 L
s
.678 .847 .902 r
.24629 .08012 m
.24629 .36021 L
.2466 .36021 L
.2466 .08012 L
F
.2 .63 .79 r
.24629 .08012 m
.24629 .36021 L
.2466 .36021 L
.2466 .08012 L
s
.678 .847 .902 r
.2466 .08012 m
.2466 .36002 L
.247 .36002 L
.247 .08012 L
F
.2 .63 .79 r
.2466 .08012 m
.2466 .36002 L
.247 .36002 L
.247 .08012 L
s
.678 .847 .902 r
.247 .08012 m
.247 .35974 L
.24717 .35974 L
.24717 .08012 L
F
.2 .63 .79 r
.247 .08012 m
.247 .35974 L
.24717 .35974 L
.24717 .08012 L
s
.678 .847 .902 r
.24717 .08012 m
.24717 .35954 L
.24732 .35954 L
.24732 .08012 L
F
.2 .63 .79 r
.24717 .08012 m
.24717 .35954 L
.24732 .35954 L
.24732 .08012 L
s
.678 .847 .902 r
.24732 .08012 m
.24732 .35939 L
.24747 .35939 L
.24747 .08012 L
F
.2 .63 .79 r
.24732 .08012 m
.24732 .35939 L
.24747 .35939 L
.24747 .08012 L
s
.678 .847 .902 r
.24747 .08012 m
.24747 .35896 L
.24792 .35896 L
.24792 .08012 L
F
.2 .63 .79 r
.24747 .08012 m
.24747 .35896 L
.24792 .35896 L
.24792 .08012 L
s
.678 .847 .902 r
.24792 .08012 m
.24792 .35888 L
.24831 .35888 L
.24831 .08012 L
F
.2 .63 .79 r
.24792 .08012 m
.24792 .35888 L
.24831 .35888 L
.24831 .08012 L
s
.678 .847 .902 r
.24831 .08012 m
.24831 .35832 L
.24866 .35832 L
.24866 .08012 L
F
.2 .63 .79 r
.24831 .08012 m
.24831 .35832 L
.24866 .35832 L
.24866 .08012 L
s
.678 .847 .902 r
.24866 .08012 m
.24866 .35812 L
.24911 .35812 L
.24911 .08012 L
F
.2 .63 .79 r
.24866 .08012 m
.24866 .35812 L
.24911 .35812 L
.24911 .08012 L
s
.678 .847 .902 r
.24911 .08012 m
.24911 .35767 L
.24938 .35767 L
.24938 .08012 L
F
.2 .63 .79 r
.24911 .08012 m
.24911 .35767 L
.24938 .35767 L
.24938 .08012 L
s
.678 .847 .902 r
.24938 .08012 m
.24938 .35722 L
.24974 .35722 L
.24974 .08012 L
F
.2 .63 .79 r
.24938 .08012 m
.24938 .35722 L
.24974 .35722 L
.24974 .08012 L
s
.678 .847 .902 r
.24974 .08012 m
.24974 .35706 L
.24999 .35706 L
.24999 .08012 L
F
.2 .63 .79 r
.24974 .08012 m
.24974 .35706 L
.24999 .35706 L
.24999 .08012 L
s
.678 .847 .902 r
.24999 .08012 m
.24999 .35679 L
.2504 .35679 L
.2504 .08012 L
F
.2 .63 .79 r
.24999 .08012 m
.24999 .35679 L
.2504 .35679 L
.2504 .08012 L
s
.678 .847 .902 r
.2504 .08012 m
.2504 .35645 L
.25078 .35645 L
.25078 .08012 L
F
.2 .63 .79 r
.2504 .08012 m
.2504 .35645 L
.25078 .35645 L
.25078 .08012 L
s
.678 .847 .902 r
.25078 .08012 m
.25078 .35586 L
.25124 .35586 L
.25124 .08012 L
F
.2 .63 .79 r
.25078 .08012 m
.25078 .35586 L
.25124 .35586 L
.25124 .08012 L
s
.678 .847 .902 r
.25124 .08012 m
.25124 .35545 L
.25158 .35545 L
.25158 .08012 L
F
.2 .63 .79 r
.25124 .08012 m
.25124 .35545 L
.25158 .35545 L
.25158 .08012 L
s
.678 .847 .902 r
.25158 .08012 m
.25158 .35542 L
.25195 .35542 L
.25195 .08012 L
F
.2 .63 .79 r
.25158 .08012 m
.25158 .35542 L
.25195 .35542 L
.25195 .08012 L
s
.678 .847 .902 r
.25195 .08012 m
.25195 .35502 L
.25234 .35502 L
.25234 .08012 L
F
.2 .63 .79 r
.25195 .08012 m
.25195 .35502 L
.25234 .35502 L
.25234 .08012 L
s
.678 .847 .902 r
.25234 .08012 m
.25234 .35455 L
.2526 .35455 L
.2526 .08012 L
F
.2 .63 .79 r
.25234 .08012 m
.25234 .35455 L
.2526 .35455 L
.2526 .08012 L
s
.678 .847 .902 r
.2526 .08012 m
.2526 .35434 L
.25298 .35434 L
.25298 .08012 L
F
.2 .63 .79 r
.2526 .08012 m
.2526 .35434 L
.25298 .35434 L
.25298 .08012 L
s
.678 .847 .902 r
.25298 .08012 m
.25298 .35409 L
.25325 .35409 L
.25325 .08012 L
F
.2 .63 .79 r
.25298 .08012 m
.25298 .35409 L
.25325 .35409 L
.25325 .08012 L
s
.678 .847 .902 r
.25325 .08012 m
.25325 .35371 L
.25345 .35371 L
.25345 .08012 L
F
.2 .63 .79 r
.25325 .08012 m
.25325 .35371 L
.25345 .35371 L
.25345 .08012 L
s
.678 .847 .902 r
.25345 .08012 m
.25345 .35346 L
.25393 .35346 L
.25393 .08012 L
F
.2 .63 .79 r
.25345 .08012 m
.25345 .35346 L
.25393 .35346 L
.25393 .08012 L
s
.678 .847 .902 r
.25393 .08012 m
.25393 .3528 L
.2544 .3528 L
.2544 .08012 L
F
.2 .63 .79 r
.25393 .08012 m
.25393 .3528 L
.2544 .3528 L
.2544 .08012 L
s
.678 .847 .902 r
.2544 .08012 m
.2544 .35263 L
.25487 .35263 L
.25487 .08012 L
F
.2 .63 .79 r
.2544 .08012 m
.2544 .35263 L
.25487 .35263 L
.25487 .08012 L
s
.678 .847 .902 r
.25487 .08012 m
.25487 .35221 L
.25516 .35221 L
.25516 .08012 L
F
.2 .63 .79 r
.25487 .08012 m
.25487 .35221 L
.25516 .35221 L
.25516 .08012 L
s
.678 .847 .902 r
.25516 .08012 m
.25516 .35194 L
.25562 .35194 L
.25562 .08012 L
F
.2 .63 .79 r
.25516 .08012 m
.25516 .35194 L
.25562 .35194 L
.25562 .08012 L
s
.678 .847 .902 r
.25562 .08012 m
.25562 .35144 L
.25609 .35144 L
.25609 .08012 L
F
.2 .63 .79 r
.25562 .08012 m
.25562 .35144 L
.25609 .35144 L
.25609 .08012 L
s
.678 .847 .902 r
.25609 .08012 m
.25609 .35085 L
.25654 .35085 L
.25654 .08012 L
F
.2 .63 .79 r
.25609 .08012 m
.25609 .35085 L
.25654 .35085 L
.25654 .08012 L
s
.678 .847 .902 r
.25654 .08012 m
.25654 .35057 L
.25688 .35057 L
.25688 .08012 L
F
.2 .63 .79 r
.25654 .08012 m
.25654 .35057 L
.25688 .35057 L
.25688 .08012 L
s
.678 .847 .902 r
.25688 .08012 m
.25688 .35042 L
.2571 .35042 L
.2571 .08012 L
F
.2 .63 .79 r
.25688 .08012 m
.25688 .35042 L
.2571 .35042 L
.2571 .08012 L
s
.678 .847 .902 r
.2571 .08012 m
.2571 .35006 L
.25736 .35006 L
.25736 .08012 L
F
.2 .63 .79 r
.2571 .08012 m
.2571 .35006 L
.25736 .35006 L
.25736 .08012 L
s
.678 .847 .902 r
.25736 .08012 m
.25736 .34993 L
.25752 .34993 L
.25752 .08012 L
F
.2 .63 .79 r
.25736 .08012 m
.25736 .34993 L
.25752 .34993 L
.25752 .08012 L
s
.678 .847 .902 r
.25752 .08012 m
.25752 .34982 L
.25773 .34982 L
.25773 .08012 L
F
.2 .63 .79 r
.25752 .08012 m
.25752 .34982 L
.25773 .34982 L
.25773 .08012 L
s
.678 .847 .902 r
.25773 .08012 m
.25773 .34954 L
.25808 .34954 L
.25808 .08012 L
F
.2 .63 .79 r
.25773 .08012 m
.25773 .34954 L
.25808 .34954 L
.25808 .08012 L
s
.678 .847 .902 r
.25808 .08012 m
.25808 .3493 L
.25824 .3493 L
.25824 .08012 L
F
.2 .63 .79 r
.25808 .08012 m
.25808 .3493 L
.25824 .3493 L
.25824 .08012 L
s
.678 .847 .902 r
.25824 .08012 m
.25824 .34914 L
.25849 .34914 L
.25849 .08012 L
F
.2 .63 .79 r
.25824 .08012 m
.25824 .34914 L
.25849 .34914 L
.25849 .08012 L
s
.678 .847 .902 r
.25849 .08012 m
.25849 .34868 L
.25881 .34868 L
.25881 .08012 L
F
.2 .63 .79 r
.25849 .08012 m
.25849 .34868 L
.25881 .34868 L
.25881 .08012 L
s
.678 .847 .902 r
.25881 .08012 m
.25881 .34845 L
.2592 .34845 L
.2592 .08012 L
F
.2 .63 .79 r
.25881 .08012 m
.25881 .34845 L
.2592 .34845 L
.2592 .08012 L
s
.678 .847 .902 r
.2592 .08012 m
.2592 .34821 L
.2595 .34821 L
.2595 .08012 L
F
.2 .63 .79 r
.2592 .08012 m
.2592 .34821 L
.2595 .34821 L
.2595 .08012 L
s
.678 .847 .902 r
.2595 .08012 m
.2595 .34796 L
.25987 .34796 L
.25987 .08012 L
F
.2 .63 .79 r
.2595 .08012 m
.2595 .34796 L
.25987 .34796 L
.25987 .08012 L
s
.678 .847 .902 r
.25987 .08012 m
.25987 .34739 L
.2603 .34739 L
.2603 .08012 L
F
.2 .63 .79 r
.25987 .08012 m
.25987 .34739 L
.2603 .34739 L
.2603 .08012 L
s
.678 .847 .902 r
.2603 .08012 m
.2603 .34707 L
.26057 .34707 L
.26057 .08012 L
F
.2 .63 .79 r
.2603 .08012 m
.2603 .34707 L
.26057 .34707 L
.26057 .08012 L
s
.678 .847 .902 r
.26057 .08012 m
.26057 .34666 L
.26099 .34666 L
.26099 .08012 L
F
.2 .63 .79 r
.26057 .08012 m
.26057 .34666 L
.26099 .34666 L
.26099 .08012 L
s
.678 .847 .902 r
.26099 .08012 m
.26099 .34663 L
.26124 .34663 L
.26124 .08012 L
F
.2 .63 .79 r
.26099 .08012 m
.26099 .34663 L
.26124 .34663 L
.26124 .08012 L
s
.678 .847 .902 r
.26124 .08012 m
.26124 .34612 L
.26161 .34612 L
.26161 .08012 L
F
.2 .63 .79 r
.26124 .08012 m
.26124 .34612 L
.26161 .34612 L
.26161 .08012 L
s
.678 .847 .902 r
.26161 .08012 m
.26161 .34597 L
.26189 .34597 L
.26189 .08012 L
F
.2 .63 .79 r
.26161 .08012 m
.26161 .34597 L
.26189 .34597 L
.26189 .08012 L
s
.678 .847 .902 r
.26189 .08012 m
.26189 .34541 L
.26233 .34541 L
.26233 .08012 L
F
.2 .63 .79 r
.26189 .08012 m
.26189 .34541 L
.26233 .34541 L
.26233 .08012 L
s
.678 .847 .902 r
.26233 .08012 m
.26233 .34522 L
.26261 .34522 L
.26261 .08012 L
F
.2 .63 .79 r
.26233 .08012 m
.26233 .34522 L
.26261 .34522 L
.26261 .08012 L
s
.678 .847 .902 r
.26261 .08012 m
.26261 .34508 L
.26284 .34508 L
.26284 .08012 L
F
.2 .63 .79 r
.26261 .08012 m
.26261 .34508 L
.26284 .34508 L
.26284 .08012 L
s
.678 .847 .902 r
.26284 .08012 m
.26284 .34492 L
.26315 .34492 L
.26315 .08012 L
F
.2 .63 .79 r
.26284 .08012 m
.26284 .34492 L
.26315 .34492 L
.26315 .08012 L
s
.678 .847 .902 r
.26315 .08012 m
.26315 .34444 L
.26361 .34444 L
.26361 .08012 L
F
.2 .63 .79 r
.26315 .08012 m
.26315 .34444 L
.26361 .34444 L
.26361 .08012 L
s
.678 .847 .902 r
.26361 .08012 m
.26361 .34397 L
.26393 .34397 L
.26393 .08012 L
F
.2 .63 .79 r
.26361 .08012 m
.26361 .34397 L
.26393 .34397 L
.26393 .08012 L
s
.678 .847 .902 r
.26393 .08012 m
.26393 .34371 L
.26432 .34371 L
.26432 .08012 L
F
.2 .63 .79 r
.26393 .08012 m
.26393 .34371 L
.26432 .34371 L
.26432 .08012 L
s
.678 .847 .902 r
.26432 .08012 m
.26432 .34341 L
.26456 .34341 L
.26456 .08012 L
F
.2 .63 .79 r
.26432 .08012 m
.26432 .34341 L
.26456 .34341 L
.26456 .08012 L
s
.678 .847 .902 r
.26456 .08012 m
.26456 .34315 L
.26491 .34315 L
.26491 .08012 L
F
.2 .63 .79 r
.26456 .08012 m
.26456 .34315 L
.26491 .34315 L
.26491 .08012 L
s
.678 .847 .902 r
.26491 .08012 m
.26491 .34299 L
.26521 .34299 L
.26521 .08012 L
F
.2 .63 .79 r
.26491 .08012 m
.26491 .34299 L
.26521 .34299 L
.26521 .08012 L
s
.678 .847 .902 r
.26521 .08012 m
.26521 .34265 L
.26553 .34265 L
.26553 .08012 L
F
.2 .63 .79 r
.26521 .08012 m
.26521 .34265 L
.26553 .34265 L
.26553 .08012 L
s
.678 .847 .902 r
.26553 .08012 m
.26553 .34234 L
.26591 .34234 L
.26591 .08012 L
F
.2 .63 .79 r
.26553 .08012 m
.26553 .34234 L
.26591 .34234 L
.26591 .08012 L
s
.678 .847 .902 r
.26591 .08012 m
.26591 .34202 L
.26625 .34202 L
.26625 .08012 L
F
.2 .63 .79 r
.26591 .08012 m
.26591 .34202 L
.26625 .34202 L
.26625 .08012 L
s
.678 .847 .902 r
.26625 .08012 m
.26625 .34163 L
.26646 .34163 L
.26646 .08012 L
F
.2 .63 .79 r
.26625 .08012 m
.26625 .34163 L
.26646 .34163 L
.26646 .08012 L
s
.678 .847 .902 r
.26646 .08012 m
.26646 .34145 L
.26695 .34145 L
.26695 .08012 L
F
.2 .63 .79 r
.26646 .08012 m
.26646 .34145 L
.26695 .34145 L
.26695 .08012 L
s
.678 .847 .902 r
.26695 .08012 m
.26695 .34083 L
.26744 .34083 L
.26744 .08012 L
F
.2 .63 .79 r
.26695 .08012 m
.26695 .34083 L
.26744 .34083 L
.26744 .08012 L
s
.678 .847 .902 r
.26744 .08012 m
.26744 .34055 L
.26762 .34055 L
.26762 .08012 L
F
.2 .63 .79 r
.26744 .08012 m
.26744 .34055 L
.26762 .34055 L
.26762 .08012 L
s
.678 .847 .902 r
.26762 .08012 m
.26762 .34035 L
.26794 .34035 L
.26794 .08012 L
F
.2 .63 .79 r
.26762 .08012 m
.26762 .34035 L
.26794 .34035 L
.26794 .08012 L
s
.678 .847 .902 r
.26794 .08012 m
.26794 .34012 L
.26816 .34012 L
.26816 .08012 L
F
.2 .63 .79 r
.26794 .08012 m
.26794 .34012 L
.26816 .34012 L
.26816 .08012 L
s
.678 .847 .902 r
.26816 .08012 m
.26816 .33977 L
.26853 .33977 L
.26853 .08012 L
F
.2 .63 .79 r
.26816 .08012 m
.26816 .33977 L
.26853 .33977 L
.26853 .08012 L
s
.678 .847 .902 r
.26853 .08012 m
.26853 .33948 L
.26878 .33948 L
.26878 .08012 L
F
.2 .63 .79 r
.26853 .08012 m
.26853 .33948 L
.26878 .33948 L
.26878 .08012 L
s
.678 .847 .902 r
.26878 .08012 m
.26878 .33936 L
.269 .33936 L
.269 .08012 L
F
.2 .63 .79 r
.26878 .08012 m
.26878 .33936 L
.269 .33936 L
.269 .08012 L
s
.678 .847 .902 r
.269 .08012 m
.269 .33905 L
.26933 .33905 L
.26933 .08012 L
F
.2 .63 .79 r
.269 .08012 m
.269 .33905 L
.26933 .33905 L
.26933 .08012 L
s
.678 .847 .902 r
.26933 .08012 m
.26933 .33887 L
.26957 .33887 L
.26957 .08012 L
F
.2 .63 .79 r
.26933 .08012 m
.26933 .33887 L
.26957 .33887 L
.26957 .08012 L
s
.678 .847 .902 r
.26957 .08012 m
.26957 .33848 L
.26988 .33848 L
.26988 .08012 L
F
.2 .63 .79 r
.26957 .08012 m
.26957 .33848 L
.26988 .33848 L
.26988 .08012 L
s
.678 .847 .902 r
.26988 .08012 m
.26988 .33814 L
.27031 .33814 L
.27031 .08012 L
F
.2 .63 .79 r
.26988 .08012 m
.26988 .33814 L
.27031 .33814 L
.27031 .08012 L
s
.678 .847 .902 r
.27031 .08012 m
.27031 .33797 L
.27056 .33797 L
.27056 .08012 L
F
.2 .63 .79 r
.27031 .08012 m
.27031 .33797 L
.27056 .33797 L
.27056 .08012 L
s
.678 .847 .902 r
.27056 .08012 m
.27056 .3377 L
.27098 .3377 L
.27098 .08012 L
F
.2 .63 .79 r
.27056 .08012 m
.27056 .3377 L
.27098 .3377 L
.27098 .08012 L
s
.678 .847 .902 r
.27098 .08012 m
.27098 .33732 L
.27132 .33732 L
.27132 .08012 L
F
.2 .63 .79 r
.27098 .08012 m
.27098 .33732 L
.27132 .33732 L
.27132 .08012 L
s
.678 .847 .902 r
.27132 .08012 m
.27132 .33691 L
.27158 .33691 L
.27158 .08012 L
F
.2 .63 .79 r
.27132 .08012 m
.27132 .33691 L
.27158 .33691 L
.27158 .08012 L
s
.678 .847 .902 r
.27158 .08012 m
.27158 .33665 L
.27193 .33665 L
.27193 .08012 L
F
.2 .63 .79 r
.27158 .08012 m
.27158 .33665 L
.27193 .33665 L
.27193 .08012 L
s
.678 .847 .902 r
.27193 .08012 m
.27193 .33639 L
.27226 .33639 L
.27226 .08012 L
F
.2 .63 .79 r
.27193 .08012 m
.27193 .33639 L
.27226 .33639 L
.27226 .08012 L
s
.678 .847 .902 r
.27226 .08012 m
.27226 .33593 L
.27275 .33593 L
.27275 .08012 L
F
.2 .63 .79 r
.27226 .08012 m
.27226 .33593 L
.27275 .33593 L
.27275 .08012 L
s
.678 .847 .902 r
.27275 .08012 m
.27275 .3355 L
.2732 .3355 L
.2732 .08012 L
F
.2 .63 .79 r
.27275 .08012 m
.27275 .3355 L
.2732 .3355 L
.2732 .08012 L
s
.678 .847 .902 r
.2732 .08012 m
.2732 .33535 L
.27337 .33535 L
.27337 .08012 L
F
.2 .63 .79 r
.2732 .08012 m
.2732 .33535 L
.27337 .33535 L
.27337 .08012 L
s
.678 .847 .902 r
.27337 .08012 m
.27337 .33515 L
.27382 .33515 L
.27382 .08012 L
F
.2 .63 .79 r
.27337 .08012 m
.27337 .33515 L
.27382 .33515 L
.27382 .08012 L
s
.678 .847 .902 r
.27382 .08012 m
.27382 .33472 L
.27411 .33472 L
.27411 .08012 L
F
.2 .63 .79 r
.27382 .08012 m
.27382 .33472 L
.27411 .33472 L
.27411 .08012 L
s
.678 .847 .902 r
.27411 .08012 m
.27411 .33425 L
.2745 .33425 L
.2745 .08012 L
F
.2 .63 .79 r
.27411 .08012 m
.27411 .33425 L
.2745 .33425 L
.2745 .08012 L
s
.678 .847 .902 r
.2745 .08012 m
.2745 .33421 L
.27468 .33421 L
.27468 .08012 L
F
.2 .63 .79 r
.2745 .08012 m
.2745 .33421 L
.27468 .33421 L
.27468 .08012 L
s
.678 .847 .902 r
.27468 .08012 m
.27468 .33384 L
.27513 .33384 L
.27513 .08012 L
F
.2 .63 .79 r
.27468 .08012 m
.27468 .33384 L
.27513 .33384 L
.27513 .08012 L
s
.678 .847 .902 r
.27513 .08012 m
.27513 .33352 L
.27538 .33352 L
.27538 .08012 L
F
.2 .63 .79 r
.27513 .08012 m
.27513 .33352 L
.27538 .33352 L
.27538 .08012 L
s
.678 .847 .902 r
.27538 .08012 m
.27538 .33336 L
.2756 .33336 L
.2756 .08012 L
F
.2 .63 .79 r
.27538 .08012 m
.27538 .33336 L
.2756 .33336 L
.2756 .08012 L
s
.678 .847 .902 r
.2756 .08012 m
.2756 .33301 L
.27605 .33301 L
.27605 .08012 L
F
.2 .63 .79 r
.2756 .08012 m
.2756 .33301 L
.27605 .33301 L
.27605 .08012 L
s
.678 .847 .902 r
.27605 .08012 m
.27605 .33266 L
.27628 .33266 L
.27628 .08012 L
F
.2 .63 .79 r
.27605 .08012 m
.27605 .33266 L
.27628 .33266 L
.27628 .08012 L
s
.678 .847 .902 r
.27628 .08012 m
.27628 .33229 L
.27677 .33229 L
.27677 .08012 L
F
.2 .63 .79 r
.27628 .08012 m
.27628 .33229 L
.27677 .33229 L
.27677 .08012 L
s
.678 .847 .902 r
.27677 .08012 m
.27677 .33179 L
.27726 .33179 L
.27726 .08012 L
F
.2 .63 .79 r
.27677 .08012 m
.27677 .33179 L
.27726 .33179 L
.27726 .08012 L
s
.678 .847 .902 r
.27726 .08012 m
.27726 .33151 L
.27754 .33151 L
.27754 .08012 L
F
.2 .63 .79 r
.27726 .08012 m
.27726 .33151 L
.27754 .33151 L
.27754 .08012 L
s
.678 .847 .902 r
.27754 .08012 m
.27754 .3313 L
.27802 .3313 L
.27802 .08012 L
F
.2 .63 .79 r
.27754 .08012 m
.27754 .3313 L
.27802 .3313 L
.27802 .08012 L
s
.678 .847 .902 r
.27802 .08012 m
.27802 .33079 L
.27834 .33079 L
.27834 .08012 L
F
.2 .63 .79 r
.27802 .08012 m
.27802 .33079 L
.27834 .33079 L
.27834 .08012 L
s
.678 .847 .902 r
.27834 .08012 m
.27834 .33073 L
.27855 .33073 L
.27855 .08012 L
F
.2 .63 .79 r
.27834 .08012 m
.27834 .33073 L
.27855 .33073 L
.27855 .08012 L
s
.678 .847 .902 r
.27855 .08012 m
.27855 .33048 L
.27873 .33048 L
.27873 .08012 L
F
.2 .63 .79 r
.27855 .08012 m
.27855 .33048 L
.27873 .33048 L
.27873 .08012 L
s
.678 .847 .902 r
.27873 .08012 m
.27873 .33038 L
.27893 .33038 L
.27893 .08012 L
F
.2 .63 .79 r
.27873 .08012 m
.27873 .33038 L
.27893 .33038 L
.27893 .08012 L
s
.678 .847 .902 r
.27893 .08012 m
.27893 .33003 L
.27941 .33003 L
.27941 .08012 L
F
.2 .63 .79 r
.27893 .08012 m
.27893 .33003 L
.27941 .33003 L
.27941 .08012 L
s
.678 .847 .902 r
.27941 .08012 m
.27941 .32972 L
.27985 .32972 L
.27985 .08012 L
F
.2 .63 .79 r
.27941 .08012 m
.27941 .32972 L
.27985 .32972 L
.27985 .08012 L
s
.678 .847 .902 r
.27985 .08012 m
.27985 .32917 L
.28017 .32917 L
.28017 .08012 L
F
.2 .63 .79 r
.27985 .08012 m
.27985 .32917 L
.28017 .32917 L
.28017 .08012 L
s
.678 .847 .902 r
.28017 .08012 m
.28017 .32894 L
.28054 .32894 L
.28054 .08012 L
F
.2 .63 .79 r
.28017 .08012 m
.28017 .32894 L
.28054 .32894 L
.28054 .08012 L
s
.678 .847 .902 r
.28054 .08012 m
.28054 .32848 L
.28102 .32848 L
.28102 .08012 L
F
.2 .63 .79 r
.28054 .08012 m
.28054 .32848 L
.28102 .32848 L
.28102 .08012 L
s
.678 .847 .902 r
.28102 .08012 m
.28102 .32817 L
.2815 .32817 L
.2815 .08012 L
F
.2 .63 .79 r
.28102 .08012 m
.28102 .32817 L
.2815 .32817 L
.2815 .08012 L
s
.678 .847 .902 r
.2815 .08012 m
.2815 .32781 L
.2818 .32781 L
.2818 .08012 L
F
.2 .63 .79 r
.2815 .08012 m
.2815 .32781 L
.2818 .32781 L
.2818 .08012 L
s
.678 .847 .902 r
.2818 .08012 m
.2818 .32755 L
.28221 .32755 L
.28221 .08012 L
F
.2 .63 .79 r
.2818 .08012 m
.2818 .32755 L
.28221 .32755 L
.28221 .08012 L
s
.678 .847 .902 r
.28221 .08012 m
.28221 .32721 L
.28255 .32721 L
.28255 .08012 L
F
.2 .63 .79 r
.28221 .08012 m
.28221 .32721 L
.28255 .32721 L
.28255 .08012 L
s
.678 .847 .902 r
.28255 .08012 m
.28255 .32686 L
.28279 .32686 L
.28279 .08012 L
F
.2 .63 .79 r
.28255 .08012 m
.28255 .32686 L
.28279 .32686 L
.28279 .08012 L
s
.678 .847 .902 r
.28279 .08012 m
.28279 .32668 L
.28306 .32668 L
.28306 .08012 L
F
.2 .63 .79 r
.28279 .08012 m
.28279 .32668 L
.28306 .32668 L
.28306 .08012 L
s
.678 .847 .902 r
.28306 .08012 m
.28306 .32623 L
.28351 .32623 L
.28351 .08012 L
F
.2 .63 .79 r
.28306 .08012 m
.28306 .32623 L
.28351 .32623 L
.28351 .08012 L
s
.678 .847 .902 r
.28351 .08012 m
.28351 .32597 L
.28375 .32597 L
.28375 .08012 L
F
.2 .63 .79 r
.28351 .08012 m
.28351 .32597 L
.28375 .32597 L
.28375 .08012 L
s
.678 .847 .902 r
.28375 .08012 m
.28375 .32586 L
.28391 .32586 L
.28391 .08012 L
F
.2 .63 .79 r
.28375 .08012 m
.28375 .32586 L
.28391 .32586 L
.28391 .08012 L
s
.678 .847 .902 r
.28391 .08012 m
.28391 .32554 L
.28422 .32554 L
.28422 .08012 L
F
.2 .63 .79 r
.28391 .08012 m
.28391 .32554 L
.28422 .32554 L
.28422 .08012 L
s
.678 .847 .902 r
.28422 .08012 m
.28422 .32516 L
.28459 .32516 L
.28459 .08012 L
F
.2 .63 .79 r
.28422 .08012 m
.28422 .32516 L
.28459 .32516 L
.28459 .08012 L
s
.678 .847 .902 r
.28459 .08012 m
.28459 .32494 L
.28483 .32494 L
.28483 .08012 L
F
.2 .63 .79 r
.28459 .08012 m
.28459 .32494 L
.28483 .32494 L
.28483 .08012 L
s
.678 .847 .902 r
.28483 .08012 m
.28483 .32486 L
.285 .32486 L
.285 .08012 L
F
.2 .63 .79 r
.28483 .08012 m
.28483 .32486 L
.285 .32486 L
.285 .08012 L
s
.678 .847 .902 r
.285 .08012 m
.285 .32462 L
.28518 .32462 L
.28518 .08012 L
F
.2 .63 .79 r
.285 .08012 m
.285 .32462 L
.28518 .32462 L
.28518 .08012 L
s
.678 .847 .902 r
.28518 .08012 m
.28518 .32442 L
.28557 .32442 L
.28557 .08012 L
F
.2 .63 .79 r
.28518 .08012 m
.28518 .32442 L
.28557 .32442 L
.28557 .08012 L
s
.678 .847 .902 r
.28557 .08012 m
.28557 .3239 L
.28597 .3239 L
.28597 .08012 L
F
.2 .63 .79 r
.28557 .08012 m
.28557 .3239 L
.28597 .3239 L
.28597 .08012 L
s
.678 .847 .902 r
.28597 .08012 m
.28597 .32382 L
.28642 .32382 L
.28642 .08012 L
F
.2 .63 .79 r
.28597 .08012 m
.28597 .32382 L
.28642 .32382 L
.28642 .08012 L
s
.678 .847 .902 r
.28642 .08012 m
.28642 .32343 L
.28657 .32343 L
.28657 .08012 L
F
.2 .63 .79 r
.28642 .08012 m
.28642 .32343 L
.28657 .32343 L
.28657 .08012 L
s
.678 .847 .902 r
.28657 .08012 m
.28657 .32321 L
.2869 .32321 L
.2869 .08012 L
F
.2 .63 .79 r
.28657 .08012 m
.28657 .32321 L
.2869 .32321 L
.2869 .08012 L
s
.678 .847 .902 r
.2869 .08012 m
.2869 .32284 L
.28732 .32284 L
.28732 .08012 L
F
.2 .63 .79 r
.2869 .08012 m
.2869 .32284 L
.28732 .32284 L
.28732 .08012 L
s
.678 .847 .902 r
.28732 .08012 m
.28732 .32252 L
.28748 .32252 L
.28748 .08012 L
F
.2 .63 .79 r
.28732 .08012 m
.28732 .32252 L
.28748 .32252 L
.28748 .08012 L
s
.678 .847 .902 r
.28748 .08012 m
.28748 .32235 L
.2878 .32235 L
.2878 .08012 L
F
.2 .63 .79 r
.28748 .08012 m
.28748 .32235 L
.2878 .32235 L
.2878 .08012 L
s
.678 .847 .902 r
.2878 .08012 m
.2878 .32185 L
.28825 .32185 L
.28825 .08012 L
F
.2 .63 .79 r
.2878 .08012 m
.2878 .32185 L
.28825 .32185 L
.28825 .08012 L
s
.678 .847 .902 r
.28825 .08012 m
.28825 .32149 L
.28868 .32149 L
.28868 .08012 L
F
.2 .63 .79 r
.28825 .08012 m
.28825 .32149 L
.28868 .32149 L
.28868 .08012 L
s
.678 .847 .902 r
.28868 .08012 m
.28868 .32135 L
.28886 .32135 L
.28886 .08012 L
F
.2 .63 .79 r
.28868 .08012 m
.28868 .32135 L
.28886 .32135 L
.28886 .08012 L
s
.678 .847 .902 r
.28886 .08012 m
.28886 .32125 L
.28903 .32125 L
.28903 .08012 L
F
.2 .63 .79 r
.28886 .08012 m
.28886 .32125 L
.28903 .32125 L
.28903 .08012 L
s
.678 .847 .902 r
.28903 .08012 m
.28903 .32101 L
.28922 .32101 L
.28922 .08012 L
F
.2 .63 .79 r
.28903 .08012 m
.28903 .32101 L
.28922 .32101 L
.28922 .08012 L
s
.678 .847 .902 r
.28922 .08012 m
.28922 .32081 L
.28945 .32081 L
.28945 .08012 L
F
.2 .63 .79 r
.28922 .08012 m
.28922 .32081 L
.28945 .32081 L
.28945 .08012 L
s
.678 .847 .902 r
.28945 .08012 m
.28945 .32066 L
.28988 .32066 L
.28988 .08012 L
F
.2 .63 .79 r
.28945 .08012 m
.28945 .32066 L
.28988 .32066 L
.28988 .08012 L
s
.678 .847 .902 r
.28988 .08012 m
.28988 .32034 L
.29027 .32034 L
.29027 .08012 L
F
.2 .63 .79 r
.28988 .08012 m
.28988 .32034 L
.29027 .32034 L
.29027 .08012 L
s
.678 .847 .902 r
.29027 .08012 m
.29027 .32 L
.2905 .32 L
.2905 .08012 L
F
.2 .63 .79 r
.29027 .08012 m
.29027 .32 L
.2905 .32 L
.2905 .08012 L
s
.678 .847 .902 r
.2905 .08012 m
.2905 .31971 L
.29099 .31971 L
.29099 .08012 L
F
.2 .63 .79 r
.2905 .08012 m
.2905 .31971 L
.29099 .31971 L
.29099 .08012 L
s
.678 .847 .902 r
.29099 .08012 m
.29099 .31931 L
.29141 .31931 L
.29141 .08012 L
F
.2 .63 .79 r
.29099 .08012 m
.29099 .31931 L
.29141 .31931 L
.29141 .08012 L
s
.678 .847 .902 r
.29141 .08012 m
.29141 .31892 L
.29164 .31892 L
.29164 .08012 L
F
.2 .63 .79 r
.29141 .08012 m
.29141 .31892 L
.29164 .31892 L
.29164 .08012 L
s
.678 .847 .902 r
.29164 .08012 m
.29164 .31872 L
.29198 .31872 L
.29198 .08012 L
F
.2 .63 .79 r
.29164 .08012 m
.29164 .31872 L
.29198 .31872 L
.29198 .08012 L
s
.678 .847 .902 r
.29198 .08012 m
.29198 .31832 L
.29238 .31832 L
.29238 .08012 L
F
.2 .63 .79 r
.29198 .08012 m
.29198 .31832 L
.29238 .31832 L
.29238 .08012 L
s
.678 .847 .902 r
.29238 .08012 m
.29238 .31814 L
.29278 .31814 L
.29278 .08012 L
F
.2 .63 .79 r
.29238 .08012 m
.29238 .31814 L
.29278 .31814 L
.29278 .08012 L
s
.678 .847 .902 r
.29278 .08012 m
.29278 .31768 L
.29298 .31768 L
.29298 .08012 L
F
.2 .63 .79 r
.29278 .08012 m
.29278 .31768 L
.29298 .31768 L
.29298 .08012 L
s
.678 .847 .902 r
.29298 .08012 m
.29298 .31728 L
.29343 .31728 L
.29343 .08012 L
F
.2 .63 .79 r
.29298 .08012 m
.29298 .31728 L
.29343 .31728 L
.29343 .08012 L
s
.678 .847 .902 r
.29343 .08012 m
.29343 .31697 L
.29392 .31697 L
.29392 .08012 L
F
.2 .63 .79 r
.29343 .08012 m
.29343 .31697 L
.29392 .31697 L
.29392 .08012 L
s
.678 .847 .902 r
.29392 .08012 m
.29392 .31644 L
.29436 .31644 L
.29436 .08012 L
F
.2 .63 .79 r
.29392 .08012 m
.29392 .31644 L
.29436 .31644 L
.29436 .08012 L
s
.678 .847 .902 r
.29436 .08012 m
.29436 .31633 L
.29456 .31633 L
.29456 .08012 L
F
.2 .63 .79 r
.29436 .08012 m
.29436 .31633 L
.29456 .31633 L
.29456 .08012 L
s
.678 .847 .902 r
.29456 .08012 m
.29456 .31612 L
.29483 .31612 L
.29483 .08012 L
F
.2 .63 .79 r
.29456 .08012 m
.29456 .31612 L
.29483 .31612 L
.29483 .08012 L
s
.678 .847 .902 r
.29483 .08012 m
.29483 .31598 L
.29505 .31598 L
.29505 .08012 L
F
.2 .63 .79 r
.29483 .08012 m
.29483 .31598 L
.29505 .31598 L
.29505 .08012 L
s
.678 .847 .902 r
.29505 .08012 m
.29505 .31546 L
.29546 .31546 L
.29546 .08012 L
F
.2 .63 .79 r
.29505 .08012 m
.29505 .31546 L
.29546 .31546 L
.29546 .08012 L
s
.678 .847 .902 r
.29546 .08012 m
.29546 .31516 L
.29584 .31516 L
.29584 .08012 L
F
.2 .63 .79 r
.29546 .08012 m
.29546 .31516 L
.29584 .31516 L
.29584 .08012 L
s
.678 .847 .902 r
.29584 .08012 m
.29584 .31495 L
.29615 .31495 L
.29615 .08012 L
F
.2 .63 .79 r
.29584 .08012 m
.29584 .31495 L
.29615 .31495 L
.29615 .08012 L
s
.678 .847 .902 r
.29615 .08012 m
.29615 .31478 L
.29644 .31478 L
.29644 .08012 L
F
.2 .63 .79 r
.29615 .08012 m
.29615 .31478 L
.29644 .31478 L
.29644 .08012 L
s
.678 .847 .902 r
.29644 .08012 m
.29644 .31448 L
.29682 .31448 L
.29682 .08012 L
F
.2 .63 .79 r
.29644 .08012 m
.29644 .31448 L
.29682 .31448 L
.29682 .08012 L
s
.678 .847 .902 r
.29682 .08012 m
.29682 .31407 L
.29717 .31407 L
.29717 .08012 L
F
.2 .63 .79 r
.29682 .08012 m
.29682 .31407 L
.29717 .31407 L
.29717 .08012 L
s
.678 .847 .902 r
.29717 .08012 m
.29717 .31374 L
.29744 .31374 L
.29744 .08012 L
F
.2 .63 .79 r
.29717 .08012 m
.29717 .31374 L
.29744 .31374 L
.29744 .08012 L
s
.678 .847 .902 r
.29744 .08012 m
.29744 .31361 L
.29765 .31361 L
.29765 .08012 L
F
.2 .63 .79 r
.29744 .08012 m
.29744 .31361 L
.29765 .31361 L
.29765 .08012 L
s
.678 .847 .902 r
.29765 .08012 m
.29765 .31311 L
.29809 .31311 L
.29809 .08012 L
F
.2 .63 .79 r
.29765 .08012 m
.29765 .31311 L
.29809 .31311 L
.29809 .08012 L
s
.678 .847 .902 r
.29809 .08012 m
.29809 .31295 L
.29854 .31295 L
.29854 .08012 L
F
.2 .63 .79 r
.29809 .08012 m
.29809 .31295 L
.29854 .31295 L
.29854 .08012 L
s
.678 .847 .902 r
.29854 .08012 m
.29854 .31261 L
.29873 .31261 L
.29873 .08012 L
F
.2 .63 .79 r
.29854 .08012 m
.29854 .31261 L
.29873 .31261 L
.29873 .08012 L
s
.678 .847 .902 r
.29873 .08012 m
.29873 .31253 L
.29894 .31253 L
.29894 .08012 L
F
.2 .63 .79 r
.29873 .08012 m
.29873 .31253 L
.29894 .31253 L
.29894 .08012 L
s
.678 .847 .902 r
.29894 .08012 m
.29894 .31225 L
.29911 .31225 L
.29911 .08012 L
F
.2 .63 .79 r
.29894 .08012 m
.29894 .31225 L
.29911 .31225 L
.29911 .08012 L
s
.678 .847 .902 r
.29911 .08012 m
.29911 .31191 L
.29948 .31191 L
.29948 .08012 L
F
.2 .63 .79 r
.29911 .08012 m
.29911 .31191 L
.29948 .31191 L
.29948 .08012 L
s
.678 .847 .902 r
.29948 .08012 m
.29948 .3118 L
.29981 .3118 L
.29981 .08012 L
F
.2 .63 .79 r
.29948 .08012 m
.29948 .3118 L
.29981 .3118 L
.29981 .08012 L
s
.678 .847 .902 r
.29981 .08012 m
.29981 .31143 L
.30012 .31143 L
.30012 .08012 L
F
.2 .63 .79 r
.29981 .08012 m
.29981 .31143 L
.30012 .31143 L
.30012 .08012 L
s
.678 .847 .902 r
.30012 .08012 m
.30012 .31115 L
.30038 .31115 L
.30038 .08012 L
F
.2 .63 .79 r
.30012 .08012 m
.30012 .31115 L
.30038 .31115 L
.30038 .08012 L
s
.678 .847 .902 r
.30038 .08012 m
.30038 .31103 L
.3007 .31103 L
.3007 .08012 L
F
.2 .63 .79 r
.30038 .08012 m
.30038 .31103 L
.3007 .31103 L
.3007 .08012 L
s
.678 .847 .902 r
.3007 .08012 m
.3007 .31068 L
.30108 .31068 L
.30108 .08012 L
F
.2 .63 .79 r
.3007 .08012 m
.3007 .31068 L
.30108 .31068 L
.30108 .08012 L
s
.678 .847 .902 r
.30108 .08012 m
.30108 .31048 L
.30138 .31048 L
.30138 .08012 L
F
.2 .63 .79 r
.30108 .08012 m
.30108 .31048 L
.30138 .31048 L
.30138 .08012 L
s
.678 .847 .902 r
.30138 .08012 m
.30138 .30998 L
.3017 .30998 L
.3017 .08012 L
F
.2 .63 .79 r
.30138 .08012 m
.30138 .30998 L
.3017 .30998 L
.3017 .08012 L
s
.678 .847 .902 r
.3017 .08012 m
.3017 .30974 L
.30197 .30974 L
.30197 .08012 L
F
.2 .63 .79 r
.3017 .08012 m
.3017 .30974 L
.30197 .30974 L
.30197 .08012 L
s
.678 .847 .902 r
.30197 .08012 m
.30197 .30949 L
.30222 .30949 L
.30222 .08012 L
F
.2 .63 .79 r
.30197 .08012 m
.30197 .30949 L
.30222 .30949 L
.30222 .08012 L
s
.678 .847 .902 r
.30222 .08012 m
.30222 .30929 L
.30245 .30929 L
.30245 .08012 L
F
.2 .63 .79 r
.30222 .08012 m
.30222 .30929 L
.30245 .30929 L
.30245 .08012 L
s
.678 .847 .902 r
.30245 .08012 m
.30245 .30895 L
.30285 .30895 L
.30285 .08012 L
F
.2 .63 .79 r
.30245 .08012 m
.30245 .30895 L
.30285 .30895 L
.30285 .08012 L
s
.678 .847 .902 r
.30285 .08012 m
.30285 .30892 L
.30324 .30892 L
.30324 .08012 L
F
.2 .63 .79 r
.30285 .08012 m
.30285 .30892 L
.30324 .30892 L
.30324 .08012 L
s
.678 .847 .902 r
.30324 .08012 m
.30324 .30842 L
.30368 .30842 L
.30368 .08012 L
F
.2 .63 .79 r
.30324 .08012 m
.30324 .30842 L
.30368 .30842 L
.30368 .08012 L
s
.678 .847 .902 r
.30368 .08012 m
.30368 .30791 L
.30411 .30791 L
.30411 .08012 L
F
.2 .63 .79 r
.30368 .08012 m
.30368 .30791 L
.30411 .30791 L
.30411 .08012 L
s
.678 .847 .902 r
.30411 .08012 m
.30411 .30774 L
.30427 .30774 L
.30427 .08012 L
F
.2 .63 .79 r
.30411 .08012 m
.30411 .30774 L
.30427 .30774 L
.30427 .08012 L
s
.678 .847 .902 r
.30427 .08012 m
.30427 .30761 L
.30445 .30761 L
.30445 .08012 L
F
.2 .63 .79 r
.30427 .08012 m
.30427 .30761 L
.30445 .30761 L
.30445 .08012 L
s
.678 .847 .902 r
.30445 .08012 m
.30445 .30734 L
.30477 .30734 L
.30477 .08012 L
F
.2 .63 .79 r
.30445 .08012 m
.30445 .30734 L
.30477 .30734 L
.30477 .08012 L
s
.678 .847 .902 r
.30477 .08012 m
.30477 .30712 L
.30515 .30712 L
.30515 .08012 L
F
.2 .63 .79 r
.30477 .08012 m
.30477 .30712 L
.30515 .30712 L
.30515 .08012 L
s
.678 .847 .902 r
.30515 .08012 m
.30515 .3068 L
.30536 .3068 L
.30536 .08012 L
F
.2 .63 .79 r
.30515 .08012 m
.30515 .3068 L
.30536 .3068 L
.30536 .08012 L
s
.678 .847 .902 r
.30536 .08012 m
.30536 .30672 L
.30557 .30672 L
.30557 .08012 L
F
.2 .63 .79 r
.30536 .08012 m
.30536 .30672 L
.30557 .30672 L
.30557 .08012 L
s
.678 .847 .902 r
.30557 .08012 m
.30557 .30653 L
.30586 .30653 L
.30586 .08012 L
F
.2 .63 .79 r
.30557 .08012 m
.30557 .30653 L
.30586 .30653 L
.30586 .08012 L
s
.678 .847 .902 r
.30586 .08012 m
.30586 .30623 L
.30617 .30623 L
.30617 .08012 L
F
.2 .63 .79 r
.30586 .08012 m
.30586 .30623 L
.30617 .30623 L
.30617 .08012 L
s
.678 .847 .902 r
.30617 .08012 m
.30617 .30589 L
.30636 .30589 L
.30636 .08012 L
F
.2 .63 .79 r
.30617 .08012 m
.30617 .30589 L
.30636 .30589 L
.30636 .08012 L
s
.678 .847 .902 r
.30636 .08012 m
.30636 .30581 L
.3067 .30581 L
.3067 .08012 L
F
.2 .63 .79 r
.30636 .08012 m
.30636 .30581 L
.3067 .30581 L
.3067 .08012 L
s
.678 .847 .902 r
.3067 .08012 m
.3067 .30527 L
.30714 .30527 L
.30714 .08012 L
F
.2 .63 .79 r
.3067 .08012 m
.3067 .30527 L
.30714 .30527 L
.30714 .08012 L
s
.678 .847 .902 r
.30714 .08012 m
.30714 .3051 L
.3073 .3051 L
.3073 .08012 L
F
.2 .63 .79 r
.30714 .08012 m
.30714 .3051 L
.3073 .3051 L
.3073 .08012 L
s
.678 .847 .902 r
.3073 .08012 m
.3073 .305 L
.30771 .305 L
.30771 .08012 L
F
.2 .63 .79 r
.3073 .08012 m
.3073 .305 L
.30771 .305 L
.30771 .08012 L
s
.678 .847 .902 r
.30771 .08012 m
.30771 .30456 L
.30788 .30456 L
.30788 .08012 L
F
.2 .63 .79 r
.30771 .08012 m
.30771 .30456 L
.30788 .30456 L
.30788 .08012 L
s
.678 .847 .902 r
.30788 .08012 m
.30788 .30448 L
.3081 .30448 L
.3081 .08012 L
F
.2 .63 .79 r
.30788 .08012 m
.30788 .30448 L
.3081 .30448 L
.3081 .08012 L
s
.678 .847 .902 r
.3081 .08012 m
.3081 .30417 L
.30844 .30417 L
.30844 .08012 L
F
.2 .63 .79 r
.3081 .08012 m
.3081 .30417 L
.30844 .30417 L
.30844 .08012 L
s
.678 .847 .902 r
.30844 .08012 m
.30844 .304 L
.30868 .304 L
.30868 .08012 L
F
.2 .63 .79 r
.30844 .08012 m
.30844 .304 L
.30868 .304 L
.30868 .08012 L
s
.678 .847 .902 r
.30868 .08012 m
.30868 .30381 L
.30907 .30381 L
.30907 .08012 L
F
.2 .63 .79 r
.30868 .08012 m
.30868 .30381 L
.30907 .30381 L
.30907 .08012 L
s
.678 .847 .902 r
.30907 .08012 m
.30907 .30335 L
.30953 .30335 L
.30953 .08012 L
F
.2 .63 .79 r
.30907 .08012 m
.30907 .30335 L
.30953 .30335 L
.30953 .08012 L
s
.678 .847 .902 r
.30953 .08012 m
.30953 .30297 L
.30979 .30297 L
.30979 .08012 L
F
.2 .63 .79 r
.30953 .08012 m
.30953 .30297 L
.30979 .30297 L
.30979 .08012 L
s
.678 .847 .902 r
.30979 .08012 m
.30979 .3028 L
.31013 .3028 L
.31013 .08012 L
F
.2 .63 .79 r
.30979 .08012 m
.30979 .3028 L
.31013 .3028 L
.31013 .08012 L
s
.678 .847 .902 r
.31013 .08012 m
.31013 .3026 L
.31028 .3026 L
.31028 .08012 L
F
.2 .63 .79 r
.31013 .08012 m
.31013 .3026 L
.31028 .3026 L
.31028 .08012 L
s
.678 .847 .902 r
.31028 .08012 m
.31028 .30234 L
.31044 .30234 L
.31044 .08012 L
F
.2 .63 .79 r
.31028 .08012 m
.31028 .30234 L
.31044 .30234 L
.31044 .08012 L
s
.678 .847 .902 r
.31044 .08012 m
.31044 .3021 L
.31076 .3021 L
.31076 .08012 L
F
.2 .63 .79 r
.31044 .08012 m
.31044 .3021 L
.31076 .3021 L
.31076 .08012 L
s
.678 .847 .902 r
.31076 .08012 m
.31076 .30187 L
.31109 .30187 L
.31109 .08012 L
F
.2 .63 .79 r
.31076 .08012 m
.31076 .30187 L
.31109 .30187 L
.31109 .08012 L
s
.678 .847 .902 r
.31109 .08012 m
.31109 .30155 L
.31155 .30155 L
.31155 .08012 L
F
.2 .63 .79 r
.31109 .08012 m
.31109 .30155 L
.31155 .30155 L
.31155 .08012 L
s
.678 .847 .902 r
.31155 .08012 m
.31155 .3013 L
.31189 .3013 L
.31189 .08012 L
F
.2 .63 .79 r
.31155 .08012 m
.31155 .3013 L
.31189 .3013 L
.31189 .08012 L
s
.678 .847 .902 r
.31189 .08012 m
.31189 .30092 L
.31232 .30092 L
.31232 .08012 L
F
.2 .63 .79 r
.31189 .08012 m
.31189 .30092 L
.31232 .30092 L
.31232 .08012 L
s
.678 .847 .902 r
.31232 .08012 m
.31232 .30049 L
.31259 .30049 L
.31259 .08012 L
F
.2 .63 .79 r
.31232 .08012 m
.31232 .30049 L
.31259 .30049 L
.31259 .08012 L
s
.678 .847 .902 r
.31259 .08012 m
.31259 .30034 L
.31298 .30034 L
.31298 .08012 L
F
.2 .63 .79 r
.31259 .08012 m
.31259 .30034 L
.31298 .30034 L
.31298 .08012 L
s
.678 .847 .902 r
.31298 .08012 m
.31298 .30012 L
.31318 .30012 L
.31318 .08012 L
F
.2 .63 .79 r
.31298 .08012 m
.31298 .30012 L
.31318 .30012 L
.31318 .08012 L
s
.678 .847 .902 r
.31318 .08012 m
.31318 .29994 L
.31345 .29994 L
.31345 .08012 L
F
.2 .63 .79 r
.31318 .08012 m
.31318 .29994 L
.31345 .29994 L
.31345 .08012 L
s
.678 .847 .902 r
.31345 .08012 m
.31345 .29973 L
.31367 .29973 L
.31367 .08012 L
F
.2 .63 .79 r
.31345 .08012 m
.31345 .29973 L
.31367 .29973 L
.31367 .08012 L
s
.678 .847 .902 r
.31367 .08012 m
.31367 .29952 L
.31388 .29952 L
.31388 .08012 L
F
.2 .63 .79 r
.31367 .08012 m
.31367 .29952 L
.31388 .29952 L
.31388 .08012 L
s
.678 .847 .902 r
.31388 .08012 m
.31388 .2993 L
.31413 .2993 L
.31413 .08012 L
F
.2 .63 .79 r
.31388 .08012 m
.31388 .2993 L
.31413 .2993 L
.31413 .08012 L
s
.678 .847 .902 r
.31413 .08012 m
.31413 .29905 L
.31439 .29905 L
.31439 .08012 L
F
.2 .63 .79 r
.31413 .08012 m
.31413 .29905 L
.31439 .29905 L
.31439 .08012 L
s
.678 .847 .902 r
.31439 .08012 m
.31439 .29871 L
.31469 .29871 L
.31469 .08012 L
F
.2 .63 .79 r
.31439 .08012 m
.31439 .29871 L
.31469 .29871 L
.31469 .08012 L
s
.678 .847 .902 r
.31469 .08012 m
.31469 .29865 L
.31487 .29865 L
.31487 .08012 L
F
.2 .63 .79 r
.31469 .08012 m
.31469 .29865 L
.31487 .29865 L
.31487 .08012 L
s
.678 .847 .902 r
.31487 .08012 m
.31487 .29837 L
.31506 .29837 L
.31506 .08012 L
F
.2 .63 .79 r
.31487 .08012 m
.31487 .29837 L
.31506 .29837 L
.31506 .08012 L
s
.678 .847 .902 r
.31506 .08012 m
.31506 .29808 L
.31546 .29808 L
.31546 .08012 L
F
.2 .63 .79 r
.31506 .08012 m
.31506 .29808 L
.31546 .29808 L
.31546 .08012 L
s
.678 .847 .902 r
.31546 .08012 m
.31546 .29792 L
.31567 .29792 L
.31567 .08012 L
F
.2 .63 .79 r
.31546 .08012 m
.31546 .29792 L
.31567 .29792 L
.31567 .08012 L
s
.678 .847 .902 r
.31567 .08012 m
.31567 .29783 L
.31596 .29783 L
.31596 .08012 L
F
.2 .63 .79 r
.31567 .08012 m
.31567 .29783 L
.31596 .29783 L
.31596 .08012 L
s
.678 .847 .902 r
.31596 .08012 m
.31596 .2975 L
.31618 .2975 L
.31618 .08012 L
F
.2 .63 .79 r
.31596 .08012 m
.31596 .2975 L
.31618 .2975 L
.31618 .08012 L
s
.678 .847 .902 r
.31618 .08012 m
.31618 .29737 L
.31647 .29737 L
.31647 .08012 L
F
.2 .63 .79 r
.31618 .08012 m
.31618 .29737 L
.31647 .29737 L
.31647 .08012 L
s
.678 .847 .902 r
.31647 .08012 m
.31647 .29709 L
.31683 .29709 L
.31683 .08012 L
F
.2 .63 .79 r
.31647 .08012 m
.31647 .29709 L
.31683 .29709 L
.31683 .08012 L
s
.678 .847 .902 r
.31683 .08012 m
.31683 .29661 L
.31711 .29661 L
.31711 .08012 L
F
.2 .63 .79 r
.31683 .08012 m
.31683 .29661 L
.31711 .29661 L
.31711 .08012 L
s
.678 .847 .902 r
.31711 .08012 m
.31711 .29651 L
.31731 .29651 L
.31731 .08012 L
F
.2 .63 .79 r
.31711 .08012 m
.31711 .29651 L
.31731 .29651 L
.31731 .08012 L
s
.678 .847 .902 r
.31731 .08012 m
.31731 .29632 L
.31779 .29632 L
.31779 .08012 L
F
.2 .63 .79 r
.31731 .08012 m
.31731 .29632 L
.31779 .29632 L
.31779 .08012 L
s
.678 .847 .902 r
.31779 .08012 m
.31779 .29595 L
.31796 .29595 L
.31796 .08012 L
F
.2 .63 .79 r
.31779 .08012 m
.31779 .29595 L
.31796 .29595 L
.31796 .08012 L
s
.678 .847 .902 r
.31796 .08012 m
.31796 .29577 L
.31828 .29577 L
.31828 .08012 L
F
.2 .63 .79 r
.31796 .08012 m
.31796 .29577 L
.31828 .29577 L
.31828 .08012 L
s
.678 .847 .902 r
.31828 .08012 m
.31828 .29553 L
.31863 .29553 L
.31863 .08012 L
F
.2 .63 .79 r
.31828 .08012 m
.31828 .29553 L
.31863 .29553 L
.31863 .08012 L
s
.678 .847 .902 r
.31863 .08012 m
.31863 .29518 L
.31882 .29518 L
.31882 .08012 L
F
.2 .63 .79 r
.31863 .08012 m
.31863 .29518 L
.31882 .29518 L
.31882 .08012 L
s
.678 .847 .902 r
.31882 .08012 m
.31882 .29495 L
.31922 .29495 L
.31922 .08012 L
F
.2 .63 .79 r
.31882 .08012 m
.31882 .29495 L
.31922 .29495 L
.31922 .08012 L
s
.678 .847 .902 r
.31922 .08012 m
.31922 .29446 L
.31964 .29446 L
.31964 .08012 L
F
.2 .63 .79 r
.31922 .08012 m
.31922 .29446 L
.31964 .29446 L
.31964 .08012 L
s
.678 .847 .902 r
.31964 .08012 m
.31964 .29442 L
.31994 .29442 L
.31994 .08012 L
F
.2 .63 .79 r
.31964 .08012 m
.31964 .29442 L
.31994 .29442 L
.31994 .08012 L
s
.678 .847 .902 r
.31994 .08012 m
.31994 .29397 L
.32035 .29397 L
.32035 .08012 L
F
.2 .63 .79 r
.31994 .08012 m
.31994 .29397 L
.32035 .29397 L
.32035 .08012 L
s
.678 .847 .902 r
.32035 .08012 m
.32035 .2937 L
.32068 .2937 L
.32068 .08012 L
F
.2 .63 .79 r
.32035 .08012 m
.32035 .2937 L
.32068 .2937 L
.32068 .08012 L
s
.678 .847 .902 r
.32068 .08012 m
.32068 .29333 L
.32103 .29333 L
.32103 .08012 L
F
.2 .63 .79 r
.32068 .08012 m
.32068 .29333 L
.32103 .29333 L
.32103 .08012 L
s
.678 .847 .902 r
.32103 .08012 m
.32103 .29313 L
.32123 .29313 L
.32123 .08012 L
F
.2 .63 .79 r
.32103 .08012 m
.32103 .29313 L
.32123 .29313 L
.32123 .08012 L
s
.678 .847 .902 r
.32123 .08012 m
.32123 .29305 L
.32153 .29305 L
.32153 .08012 L
F
.2 .63 .79 r
.32123 .08012 m
.32123 .29305 L
.32153 .29305 L
.32153 .08012 L
s
.678 .847 .902 r
.32153 .08012 m
.32153 .29274 L
.32171 .29274 L
.32171 .08012 L
F
.2 .63 .79 r
.32153 .08012 m
.32153 .29274 L
.32171 .29274 L
.32171 .08012 L
s
.678 .847 .902 r
.32171 .08012 m
.32171 .29253 L
.32203 .29253 L
.32203 .08012 L
F
.2 .63 .79 r
.32171 .08012 m
.32171 .29253 L
.32203 .29253 L
.32203 .08012 L
s
.678 .847 .902 r
.32203 .08012 m
.32203 .2923 L
.32219 .2923 L
.32219 .08012 L
F
.2 .63 .79 r
.32203 .08012 m
.32203 .2923 L
.32219 .2923 L
.32219 .08012 L
s
.678 .847 .902 r
.32219 .08012 m
.32219 .29217 L
.32257 .29217 L
.32257 .08012 L
F
.2 .63 .79 r
.32219 .08012 m
.32219 .29217 L
.32257 .29217 L
.32257 .08012 L
s
.678 .847 .902 r
.32257 .08012 m
.32257 .29192 L
.32304 .29192 L
.32304 .08012 L
F
.2 .63 .79 r
.32257 .08012 m
.32257 .29192 L
.32304 .29192 L
.32304 .08012 L
s
.678 .847 .902 r
.32304 .08012 m
.32304 .29148 L
.32322 .29148 L
.32322 .08012 L
F
.2 .63 .79 r
.32304 .08012 m
.32304 .29148 L
.32322 .29148 L
.32322 .08012 L
s
.678 .847 .902 r
.32322 .08012 m
.32322 .2913 L
.32366 .2913 L
.32366 .08012 L
F
.2 .63 .79 r
.32322 .08012 m
.32322 .2913 L
.32366 .2913 L
.32366 .08012 L
s
.678 .847 .902 r
.32366 .08012 m
.32366 .291 L
.32389 .291 L
.32389 .08012 L
F
.2 .63 .79 r
.32366 .08012 m
.32366 .291 L
.32389 .291 L
.32389 .08012 L
s
.678 .847 .902 r
.32389 .08012 m
.32389 .29064 L
.32415 .29064 L
.32415 .08012 L
F
.2 .63 .79 r
.32389 .08012 m
.32389 .29064 L
.32415 .29064 L
.32415 .08012 L
s
.678 .847 .902 r
.32415 .08012 m
.32415 .29044 L
.32453 .29044 L
.32453 .08012 L
F
.2 .63 .79 r
.32415 .08012 m
.32415 .29044 L
.32453 .29044 L
.32453 .08012 L
s
.678 .847 .902 r
.32453 .08012 m
.32453 .29005 L
.32492 .29005 L
.32492 .08012 L
F
.2 .63 .79 r
.32453 .08012 m
.32453 .29005 L
.32492 .29005 L
.32492 .08012 L
s
.678 .847 .902 r
.32492 .08012 m
.32492 .28977 L
.32517 .28977 L
.32517 .08012 L
F
.2 .63 .79 r
.32492 .08012 m
.32492 .28977 L
.32517 .28977 L
.32517 .08012 L
s
.678 .847 .902 r
.32517 .08012 m
.32517 .28968 L
.3254 .28968 L
.3254 .08012 L
F
.2 .63 .79 r
.32517 .08012 m
.32517 .28968 L
.3254 .28968 L
.3254 .08012 L
s
.678 .847 .902 r
.3254 .08012 m
.3254 .28953 L
.32562 .28953 L
.32562 .08012 L
F
.2 .63 .79 r
.3254 .08012 m
.3254 .28953 L
.32562 .28953 L
.32562 .08012 L
s
.678 .847 .902 r
.32562 .08012 m
.32562 .2893 L
.32579 .2893 L
.32579 .08012 L
F
.2 .63 .79 r
.32562 .08012 m
.32562 .2893 L
.32579 .2893 L
.32579 .08012 L
s
.678 .847 .902 r
.32579 .08012 m
.32579 .2892 L
.32601 .2892 L
.32601 .08012 L
F
.2 .63 .79 r
.32579 .08012 m
.32579 .2892 L
.32601 .2892 L
.32601 .08012 L
s
.678 .847 .902 r
.32601 .08012 m
.32601 .28883 L
.32633 .28883 L
.32633 .08012 L
F
.2 .63 .79 r
.32601 .08012 m
.32601 .28883 L
.32633 .28883 L
.32633 .08012 L
s
.678 .847 .902 r
.32633 .08012 m
.32633 .28873 L
.32662 .28873 L
.32662 .08012 L
F
.2 .63 .79 r
.32633 .08012 m
.32633 .28873 L
.32662 .28873 L
.32662 .08012 L
s
.678 .847 .902 r
.32662 .08012 m
.32662 .28841 L
.32699 .28841 L
.32699 .08012 L
F
.2 .63 .79 r
.32662 .08012 m
.32662 .28841 L
.32699 .28841 L
.32699 .08012 L
s
.678 .847 .902 r
.32699 .08012 m
.32699 .28809 L
.32729 .28809 L
.32729 .08012 L
F
.2 .63 .79 r
.32699 .08012 m
.32699 .28809 L
.32729 .28809 L
.32729 .08012 L
s
.678 .847 .902 r
.32729 .08012 m
.32729 .28785 L
.32777 .28785 L
.32777 .08012 L
F
.2 .63 .79 r
.32729 .08012 m
.32729 .28785 L
.32777 .28785 L
.32777 .08012 L
s
.678 .847 .902 r
.32777 .08012 m
.32777 .28741 L
.3282 .28741 L
.3282 .08012 L
F
.2 .63 .79 r
.32777 .08012 m
.32777 .28741 L
.3282 .28741 L
.3282 .08012 L
s
.678 .847 .902 r
.3282 .08012 m
.3282 .28703 L
.32851 .28703 L
.32851 .08012 L
F
.2 .63 .79 r
.3282 .08012 m
.3282 .28703 L
.32851 .28703 L
.32851 .08012 L
s
.678 .847 .902 r
.32851 .08012 m
.32851 .28689 L
.32867 .28689 L
.32867 .08012 L
F
.2 .63 .79 r
.32851 .08012 m
.32851 .28689 L
.32867 .28689 L
.32867 .08012 L
s
.678 .847 .902 r
.32867 .08012 m
.32867 .28656 L
.32912 .28656 L
.32912 .08012 L
F
.2 .63 .79 r
.32867 .08012 m
.32867 .28656 L
.32912 .28656 L
.32912 .08012 L
s
.678 .847 .902 r
.32912 .08012 m
.32912 .28624 L
.32938 .28624 L
.32938 .08012 L
F
.2 .63 .79 r
.32912 .08012 m
.32912 .28624 L
.32938 .28624 L
.32938 .08012 L
s
.678 .847 .902 r
.32938 .08012 m
.32938 .28601 L
.32967 .28601 L
.32967 .08012 L
F
.2 .63 .79 r
.32938 .08012 m
.32938 .28601 L
.32967 .28601 L
.32967 .08012 L
s
.678 .847 .902 r
.32967 .08012 m
.32967 .28596 L
.32994 .28596 L
.32994 .08012 L
F
.2 .63 .79 r
.32967 .08012 m
.32967 .28596 L
.32994 .28596 L
.32994 .08012 L
s
.678 .847 .902 r
.32994 .08012 m
.32994 .28551 L
.33042 .28551 L
.33042 .08012 L
F
.2 .63 .79 r
.32994 .08012 m
.32994 .28551 L
.33042 .28551 L
.33042 .08012 L
s
.678 .847 .902 r
.33042 .08012 m
.33042 .28527 L
.33064 .28527 L
.33064 .08012 L
F
.2 .63 .79 r
.33042 .08012 m
.33042 .28527 L
.33064 .28527 L
.33064 .08012 L
s
.678 .847 .902 r
.33064 .08012 m
.33064 .285 L
.33099 .285 L
.33099 .08012 L
F
.2 .63 .79 r
.33064 .08012 m
.33064 .285 L
.33099 .285 L
.33099 .08012 L
s
.678 .847 .902 r
.33099 .08012 m
.33099 .28473 L
.33117 .28473 L
.33117 .08012 L
F
.2 .63 .79 r
.33099 .08012 m
.33099 .28473 L
.33117 .28473 L
.33117 .08012 L
s
.678 .847 .902 r
.33117 .08012 m
.33117 .28449 L
.33154 .28449 L
.33154 .08012 L
F
.2 .63 .79 r
.33117 .08012 m
.33117 .28449 L
.33154 .28449 L
.33154 .08012 L
s
.678 .847 .902 r
.33154 .08012 m
.33154 .28417 L
.33187 .28417 L
.33187 .08012 L
F
.2 .63 .79 r
.33154 .08012 m
.33154 .28417 L
.33187 .28417 L
.33187 .08012 L
s
.678 .847 .902 r
.33187 .08012 m
.33187 .28382 L
.33233 .28382 L
.33233 .08012 L
F
.2 .63 .79 r
.33187 .08012 m
.33187 .28382 L
.33233 .28382 L
.33233 .08012 L
s
.678 .847 .902 r
.33233 .08012 m
.33233 .28341 L
.33275 .28341 L
.33275 .08012 L
F
.2 .63 .79 r
.33233 .08012 m
.33233 .28341 L
.33275 .28341 L
.33275 .08012 L
s
.678 .847 .902 r
.33275 .08012 m
.33275 .28331 L
.33304 .28331 L
.33304 .08012 L
F
.2 .63 .79 r
.33275 .08012 m
.33275 .28331 L
.33304 .28331 L
.33304 .08012 L
s
.678 .847 .902 r
.33304 .08012 m
.33304 .283 L
.3333 .283 L
.3333 .08012 L
F
.2 .63 .79 r
.33304 .08012 m
.33304 .283 L
.3333 .283 L
.3333 .08012 L
s
.678 .847 .902 r
.3333 .08012 m
.3333 .28282 L
.33373 .28282 L
.33373 .08012 L
F
.2 .63 .79 r
.3333 .08012 m
.3333 .28282 L
.33373 .28282 L
.33373 .08012 L
s
.678 .847 .902 r
.33373 .08012 m
.33373 .28233 L
.33407 .28233 L
.33407 .08012 L
F
.2 .63 .79 r
.33373 .08012 m
.33373 .28233 L
.33407 .28233 L
.33407 .08012 L
s
.678 .847 .902 r
.33407 .08012 m
.33407 .28207 L
.33454 .28207 L
.33454 .08012 L
F
.2 .63 .79 r
.33407 .08012 m
.33407 .28207 L
.33454 .28207 L
.33454 .08012 L
s
.678 .847 .902 r
.33454 .08012 m
.33454 .28171 L
.335 .28171 L
.335 .08012 L
F
.2 .63 .79 r
.33454 .08012 m
.33454 .28171 L
.335 .28171 L
.335 .08012 L
s
.678 .847 .902 r
.335 .08012 m
.335 .28135 L
.33521 .28135 L
.33521 .08012 L
F
.2 .63 .79 r
.335 .08012 m
.335 .28135 L
.33521 .28135 L
.33521 .08012 L
s
.678 .847 .902 r
.33521 .08012 m
.33521 .28128 L
.3354 .28128 L
.3354 .08012 L
F
.2 .63 .79 r
.33521 .08012 m
.33521 .28128 L
.3354 .28128 L
.3354 .08012 L
s
.678 .847 .902 r
.3354 .08012 m
.3354 .28107 L
.33587 .28107 L
.33587 .08012 L
F
.2 .63 .79 r
.3354 .08012 m
.3354 .28107 L
.33587 .28107 L
.33587 .08012 L
s
.678 .847 .902 r
.33587 .08012 m
.33587 .28077 L
.33605 .28077 L
.33605 .08012 L
F
.2 .63 .79 r
.33587 .08012 m
.33587 .28077 L
.33605 .28077 L
.33605 .08012 L
s
.678 .847 .902 r
.33605 .08012 m
.33605 .28053 L
.33645 .28053 L
.33645 .08012 L
F
.2 .63 .79 r
.33605 .08012 m
.33605 .28053 L
.33645 .28053 L
.33645 .08012 L
s
.678 .847 .902 r
.33645 .08012 m
.33645 .28015 L
.33664 .28015 L
.33664 .08012 L
F
.2 .63 .79 r
.33645 .08012 m
.33645 .28015 L
.33664 .28015 L
.33664 .08012 L
s
.678 .847 .902 r
.33664 .08012 m
.33664 .28007 L
.3368 .28007 L
.3368 .08012 L
F
.2 .63 .79 r
.33664 .08012 m
.33664 .28007 L
.3368 .28007 L
.3368 .08012 L
s
.678 .847 .902 r
.3368 .08012 m
.3368 .27994 L
.33722 .27994 L
.33722 .08012 L
F
.2 .63 .79 r
.3368 .08012 m
.3368 .27994 L
.33722 .27994 L
.33722 .08012 L
s
.678 .847 .902 r
.33722 .08012 m
.33722 .27957 L
.33747 .27957 L
.33747 .08012 L
F
.2 .63 .79 r
.33722 .08012 m
.33722 .27957 L
.33747 .27957 L
.33747 .08012 L
s
.678 .847 .902 r
.33747 .08012 m
.33747 .27914 L
.33788 .27914 L
.33788 .08012 L
F
.2 .63 .79 r
.33747 .08012 m
.33747 .27914 L
.33788 .27914 L
.33788 .08012 L
s
.678 .847 .902 r
.33788 .08012 m
.33788 .27911 L
.33805 .27911 L
.33805 .08012 L
F
.2 .63 .79 r
.33788 .08012 m
.33788 .27911 L
.33805 .27911 L
.33805 .08012 L
s
.678 .847 .902 r
.33805 .08012 m
.33805 .27873 L
.33839 .27873 L
.33839 .08012 L
F
.2 .63 .79 r
.33805 .08012 m
.33805 .27873 L
.33839 .27873 L
.33839 .08012 L
s
.678 .847 .902 r
.33839 .08012 m
.33839 .27838 L
.33879 .27838 L
.33879 .08012 L
F
.2 .63 .79 r
.33839 .08012 m
.33839 .27838 L
.33879 .27838 L
.33879 .08012 L
s
.678 .847 .902 r
.33879 .08012 m
.33879 .27834 L
.33917 .27834 L
.33917 .08012 L
F
.2 .63 .79 r
.33879 .08012 m
.33879 .27834 L
.33917 .27834 L
.33917 .08012 L
s
.678 .847 .902 r
.33917 .08012 m
.33917 .27797 L
.33946 .27797 L
.33946 .08012 L
F
.2 .63 .79 r
.33917 .08012 m
.33917 .27797 L
.33946 .27797 L
.33946 .08012 L
s
.678 .847 .902 r
.33946 .08012 m
.33946 .2778 L
.33962 .2778 L
.33962 .08012 L
F
.2 .63 .79 r
.33946 .08012 m
.33946 .2778 L
.33962 .2778 L
.33962 .08012 L
s
.678 .847 .902 r
.33962 .08012 m
.33962 .27761 L
.34005 .27761 L
.34005 .08012 L
F
.2 .63 .79 r
.33962 .08012 m
.33962 .27761 L
.34005 .27761 L
.34005 .08012 L
s
.678 .847 .902 r
.34005 .08012 m
.34005 .27726 L
.34051 .27726 L
.34051 .08012 L
F
.2 .63 .79 r
.34005 .08012 m
.34005 .27726 L
.34051 .27726 L
.34051 .08012 L
s
.678 .847 .902 r
.34051 .08012 m
.34051 .27694 L
.34066 .27694 L
.34066 .08012 L
F
.2 .63 .79 r
.34051 .08012 m
.34051 .27694 L
.34066 .27694 L
.34066 .08012 L
s
.678 .847 .902 r
.34066 .08012 m
.34066 .27669 L
.34105 .27669 L
.34105 .08012 L
F
.2 .63 .79 r
.34066 .08012 m
.34066 .27669 L
.34105 .27669 L
.34105 .08012 L
s
.678 .847 .902 r
.34105 .08012 m
.34105 .27639 L
.3412 .27639 L
.3412 .08012 L
F
.2 .63 .79 r
.34105 .08012 m
.34105 .27639 L
.3412 .27639 L
.3412 .08012 L
s
.678 .847 .902 r
.3412 .08012 m
.3412 .2763 L
.34145 .2763 L
.34145 .08012 L
F
.2 .63 .79 r
.3412 .08012 m
.3412 .2763 L
.34145 .2763 L
.34145 .08012 L
s
.678 .847 .902 r
.34145 .08012 m
.34145 .2761 L
.34164 .2761 L
.34164 .08012 L
F
.2 .63 .79 r
.34145 .08012 m
.34145 .2761 L
.34164 .2761 L
.34164 .08012 L
s
.678 .847 .902 r
.34164 .08012 m
.34164 .27569 L
.34206 .27569 L
.34206 .08012 L
F
.2 .63 .79 r
.34164 .08012 m
.34164 .27569 L
.34206 .27569 L
.34206 .08012 L
s
.678 .847 .902 r
.34206 .08012 m
.34206 .27532 L
.34248 .27532 L
.34248 .08012 L
F
.2 .63 .79 r
.34206 .08012 m
.34206 .27532 L
.34248 .27532 L
.34248 .08012 L
s
.678 .847 .902 r
.34248 .08012 m
.34248 .27531 L
.34269 .27531 L
.34269 .08012 L
F
.2 .63 .79 r
.34248 .08012 m
.34248 .27531 L
.34269 .27531 L
.34269 .08012 L
s
.678 .847 .902 r
.34269 .08012 m
.34269 .27511 L
.3429 .27511 L
.3429 .08012 L
F
.2 .63 .79 r
.34269 .08012 m
.34269 .27511 L
.3429 .27511 L
.3429 .08012 L
s
.678 .847 .902 r
.3429 .08012 m
.3429 .2747 L
.34329 .2747 L
.34329 .08012 L
F
.2 .63 .79 r
.3429 .08012 m
.3429 .2747 L
.34329 .2747 L
.34329 .08012 L
s
.678 .847 .902 r
.34329 .08012 m
.34329 .27456 L
.34347 .27456 L
.34347 .08012 L
F
.2 .63 .79 r
.34329 .08012 m
.34329 .27456 L
.34347 .27456 L
.34347 .08012 L
s
.678 .847 .902 r
.34347 .08012 m
.34347 .2745 L
.34364 .2745 L
.34364 .08012 L
F
.2 .63 .79 r
.34347 .08012 m
.34347 .2745 L
.34364 .2745 L
.34364 .08012 L
s
.678 .847 .902 r
.34364 .08012 m
.34364 .27428 L
.34383 .27428 L
.34383 .08012 L
F
.2 .63 .79 r
.34364 .08012 m
.34364 .27428 L
.34383 .27428 L
.34383 .08012 L
s
.678 .847 .902 r
.34383 .08012 m
.34383 .27396 L
.34429 .27396 L
.34429 .08012 L
F
.2 .63 .79 r
.34383 .08012 m
.34383 .27396 L
.34429 .27396 L
.34429 .08012 L
s
.678 .847 .902 r
.34429 .08012 m
.34429 .27377 L
.34472 .27377 L
.34472 .08012 L
F
.2 .63 .79 r
.34429 .08012 m
.34429 .27377 L
.34472 .27377 L
.34472 .08012 L
s
.678 .847 .902 r
.34472 .08012 m
.34472 .27346 L
.34496 .27346 L
.34496 .08012 L
F
.2 .63 .79 r
.34472 .08012 m
.34472 .27346 L
.34496 .27346 L
.34496 .08012 L
s
.678 .847 .902 r
.34496 .08012 m
.34496 .27321 L
.34513 .27321 L
.34513 .08012 L
F
.2 .63 .79 r
.34496 .08012 m
.34496 .27321 L
.34513 .27321 L
.34513 .08012 L
s
.678 .847 .902 r
.34513 .08012 m
.34513 .27297 L
.3454 .27297 L
.3454 .08012 L
F
.2 .63 .79 r
.34513 .08012 m
.34513 .27297 L
.3454 .27297 L
.3454 .08012 L
s
.678 .847 .902 r
.3454 .08012 m
.3454 .27289 L
.34558 .27289 L
.34558 .08012 L
F
.2 .63 .79 r
.3454 .08012 m
.3454 .27289 L
.34558 .27289 L
.34558 .08012 L
s
.678 .847 .902 r
.34558 .08012 m
.34558 .27277 L
.34593 .27277 L
.34593 .08012 L
F
.2 .63 .79 r
.34558 .08012 m
.34558 .27277 L
.34593 .27277 L
.34593 .08012 L
s
.678 .847 .902 r
.34593 .08012 m
.34593 .27242 L
.3463 .27242 L
.3463 .08012 L
F
.2 .63 .79 r
.34593 .08012 m
.34593 .27242 L
.3463 .27242 L
.3463 .08012 L
s
.678 .847 .902 r
.3463 .08012 m
.3463 .27204 L
.34656 .27204 L
.34656 .08012 L
F
.2 .63 .79 r
.3463 .08012 m
.3463 .27204 L
.34656 .27204 L
.34656 .08012 L
s
.678 .847 .902 r
.34656 .08012 m
.34656 .27197 L
.3468 .27197 L
.3468 .08012 L
F
.2 .63 .79 r
.34656 .08012 m
.34656 .27197 L
.3468 .27197 L
.3468 .08012 L
s
.678 .847 .902 r
.3468 .08012 m
.3468 .2715 L
.34719 .2715 L
.34719 .08012 L
F
.2 .63 .79 r
.3468 .08012 m
.3468 .2715 L
.34719 .2715 L
.34719 .08012 L
s
.678 .847 .902 r
.34719 .08012 m
.34719 .2714 L
.34756 .2714 L
.34756 .08012 L
F
.2 .63 .79 r
.34719 .08012 m
.34719 .2714 L
.34756 .2714 L
.34756 .08012 L
s
.678 .847 .902 r
.34756 .08012 m
.34756 .27108 L
.34792 .27108 L
.34792 .08012 L
F
.2 .63 .79 r
.34756 .08012 m
.34756 .27108 L
.34792 .27108 L
.34792 .08012 L
s
.678 .847 .902 r
.34792 .08012 m
.34792 .27084 L
.34815 .27084 L
.34815 .08012 L
F
.2 .63 .79 r
.34792 .08012 m
.34792 .27084 L
.34815 .27084 L
.34815 .08012 L
s
.678 .847 .902 r
.34815 .08012 m
.34815 .27055 L
.34844 .27055 L
.34844 .08012 L
F
.2 .63 .79 r
.34815 .08012 m
.34815 .27055 L
.34844 .27055 L
.34844 .08012 L
s
.678 .847 .902 r
.34844 .08012 m
.34844 .27024 L
.34877 .27024 L
.34877 .08012 L
F
.2 .63 .79 r
.34844 .08012 m
.34844 .27024 L
.34877 .27024 L
.34877 .08012 L
s
.678 .847 .902 r
.34877 .08012 m
.34877 .27005 L
.3492 .27005 L
.3492 .08012 L
F
.2 .63 .79 r
.34877 .08012 m
.34877 .27005 L
.3492 .27005 L
.3492 .08012 L
s
.678 .847 .902 r
.3492 .08012 m
.3492 .26978 L
.3495 .26978 L
.3495 .08012 L
F
.2 .63 .79 r
.3492 .08012 m
.3492 .26978 L
.3495 .26978 L
.3495 .08012 L
s
.678 .847 .902 r
.3495 .08012 m
.3495 .26948 L
.34973 .26948 L
.34973 .08012 L
F
.2 .63 .79 r
.3495 .08012 m
.3495 .26948 L
.34973 .26948 L
.34973 .08012 L
s
.678 .847 .902 r
.34973 .08012 m
.34973 .26927 L
.35 .26927 L
.35 .08012 L
F
.2 .63 .79 r
.34973 .08012 m
.34973 .26927 L
.35 .26927 L
.35 .08012 L
s
.678 .847 .902 r
.35 .08012 m
.35 .2691 L
.35019 .2691 L
.35019 .08012 L
F
.2 .63 .79 r
.35 .08012 m
.35 .2691 L
.35019 .2691 L
.35019 .08012 L
s
.678 .847 .902 r
.35019 .08012 m
.35019 .26891 L
.35046 .26891 L
.35046 .08012 L
F
.2 .63 .79 r
.35019 .08012 m
.35019 .26891 L
.35046 .26891 L
.35046 .08012 L
s
.678 .847 .902 r
.35046 .08012 m
.35046 .26872 L
.35066 .26872 L
.35066 .08012 L
F
.2 .63 .79 r
.35046 .08012 m
.35046 .26872 L
.35066 .26872 L
.35066 .08012 L
s
.678 .847 .902 r
.35066 .08012 m
.35066 .26846 L
.35089 .26846 L
.35089 .08012 L
F
.2 .63 .79 r
.35066 .08012 m
.35066 .26846 L
.35089 .26846 L
.35089 .08012 L
s
.678 .847 .902 r
.35089 .08012 m
.35089 .2683 L
.35112 .2683 L
.35112 .08012 L
F
.2 .63 .79 r
.35089 .08012 m
.35089 .2683 L
.35112 .2683 L
.35112 .08012 L
s
.678 .847 .902 r
.35112 .08012 m
.35112 .26819 L
.35145 .26819 L
.35145 .08012 L
F
.2 .63 .79 r
.35112 .08012 m
.35112 .26819 L
.35145 .26819 L
.35145 .08012 L
s
.678 .847 .902 r
.35145 .08012 m
.35145 .26787 L
.3519 .26787 L
.3519 .08012 L
F
.2 .63 .79 r
.35145 .08012 m
.35145 .26787 L
.3519 .26787 L
.3519 .08012 L
s
.678 .847 .902 r
.3519 .08012 m
.3519 .26756 L
.3521 .26756 L
.3521 .08012 L
F
.2 .63 .79 r
.3519 .08012 m
.3519 .26756 L
.3521 .26756 L
.3521 .08012 L
s
.678 .847 .902 r
.3521 .08012 m
.3521 .26746 L
.35255 .26746 L
.35255 .08012 L
F
.2 .63 .79 r
.3521 .08012 m
.3521 .26746 L
.35255 .26746 L
.35255 .08012 L
s
.678 .847 .902 r
.35255 .08012 m
.35255 .26709 L
.35286 .26709 L
.35286 .08012 L
F
.2 .63 .79 r
.35255 .08012 m
.35255 .26709 L
.35286 .26709 L
.35286 .08012 L
s
.678 .847 .902 r
.35286 .08012 m
.35286 .26679 L
.35309 .26679 L
.35309 .08012 L
F
.2 .63 .79 r
.35286 .08012 m
.35286 .26679 L
.35309 .26679 L
.35309 .08012 L
s
.678 .847 .902 r
.35309 .08012 m
.35309 .26661 L
.35343 .26661 L
.35343 .08012 L
F
.2 .63 .79 r
.35309 .08012 m
.35309 .26661 L
.35343 .26661 L
.35343 .08012 L
s
.678 .847 .902 r
.35343 .08012 m
.35343 .26631 L
.35377 .26631 L
.35377 .08012 L
F
.2 .63 .79 r
.35343 .08012 m
.35343 .26631 L
.35377 .26631 L
.35377 .08012 L
s
.678 .847 .902 r
.35377 .08012 m
.35377 .26612 L
.35398 .26612 L
.35398 .08012 L
F
.2 .63 .79 r
.35377 .08012 m
.35377 .26612 L
.35398 .26612 L
.35398 .08012 L
s
.678 .847 .902 r
.35398 .08012 m
.35398 .26582 L
.35432 .26582 L
.35432 .08012 L
F
.2 .63 .79 r
.35398 .08012 m
.35398 .26582 L
.35432 .26582 L
.35432 .08012 L
s
.678 .847 .902 r
.35432 .08012 m
.35432 .26531 L
.35478 .26531 L
.35478 .08012 L
F
.2 .63 .79 r
.35432 .08012 m
.35432 .26531 L
.35478 .26531 L
.35478 .08012 L
s
.678 .847 .902 r
.35478 .08012 m
.35478 .2653 L
.35524 .2653 L
.35524 .08012 L
F
.2 .63 .79 r
.35478 .08012 m
.35478 .2653 L
.35524 .2653 L
.35524 .08012 L
s
.678 .847 .902 r
.35524 .08012 m
.35524 .26459 L
.35571 .26459 L
.35571 .08012 L
F
.2 .63 .79 r
.35524 .08012 m
.35524 .26459 L
.35571 .26459 L
.35571 .08012 L
s
.678 .847 .902 r
.35571 .08012 m
.35571 .2644 L
.35591 .2644 L
.35591 .08012 L
F
.2 .63 .79 r
.35571 .08012 m
.35571 .2644 L
.35591 .2644 L
.35591 .08012 L
s
.678 .847 .902 r
.35591 .08012 m
.35591 .26433 L
.35619 .26433 L
.35619 .08012 L
F
.2 .63 .79 r
.35591 .08012 m
.35591 .26433 L
.35619 .26433 L
.35619 .08012 L
s
.678 .847 .902 r
.35619 .08012 m
.35619 .26407 L
.35637 .26407 L
.35637 .08012 L
F
.2 .63 .79 r
.35619 .08012 m
.35619 .26407 L
.35637 .26407 L
.35637 .08012 L
s
.678 .847 .902 r
.35637 .08012 m
.35637 .26383 L
.35669 .26383 L
.35669 .08012 L
F
.2 .63 .79 r
.35637 .08012 m
.35637 .26383 L
.35669 .26383 L
.35669 .08012 L
s
.678 .847 .902 r
.35669 .08012 m
.35669 .2636 L
.35716 .2636 L
.35716 .08012 L
F
.2 .63 .79 r
.35669 .08012 m
.35669 .2636 L
.35716 .2636 L
.35716 .08012 L
s
.678 .847 .902 r
.35716 .08012 m
.35716 .2633 L
.35732 .2633 L
.35732 .08012 L
F
.2 .63 .79 r
.35716 .08012 m
.35716 .2633 L
.35732 .2633 L
.35732 .08012 L
s
.678 .847 .902 r
.35732 .08012 m
.35732 .26318 L
.35779 .26318 L
.35779 .08012 L
F
.2 .63 .79 r
.35732 .08012 m
.35732 .26318 L
.35779 .26318 L
.35779 .08012 L
s
.678 .847 .902 r
.35779 .08012 m
.35779 .26284 L
.35799 .26284 L
.35799 .08012 L
F
.2 .63 .79 r
.35779 .08012 m
.35779 .26284 L
.35799 .26284 L
.35799 .08012 L
s
.678 .847 .902 r
.35799 .08012 m
.35799 .2624 L
.3584 .2624 L
.3584 .08012 L
F
.2 .63 .79 r
.35799 .08012 m
.35799 .2624 L
.3584 .2624 L
.3584 .08012 L
s
.678 .847 .902 r
.3584 .08012 m
.3584 .26214 L
.35883 .26214 L
.35883 .08012 L
F
.2 .63 .79 r
.3584 .08012 m
.3584 .26214 L
.35883 .26214 L
.35883 .08012 L
s
.678 .847 .902 r
.35883 .08012 m
.35883 .26192 L
.35922 .26192 L
.35922 .08012 L
F
.2 .63 .79 r
.35883 .08012 m
.35883 .26192 L
.35922 .26192 L
.35922 .08012 L
s
.678 .847 .902 r
.35922 .08012 m
.35922 .26145 L
.35959 .26145 L
.35959 .08012 L
F
.2 .63 .79 r
.35922 .08012 m
.35922 .26145 L
.35959 .26145 L
.35959 .08012 L
s
.678 .847 .902 r
.35959 .08012 m
.35959 .26121 L
.36004 .26121 L
.36004 .08012 L
F
.2 .63 .79 r
.35959 .08012 m
.35959 .26121 L
.36004 .26121 L
.36004 .08012 L
s
.678 .847 .902 r
.36004 .08012 m
.36004 .26098 L
.36041 .26098 L
.36041 .08012 L
F
.2 .63 .79 r
.36004 .08012 m
.36004 .26098 L
.36041 .26098 L
.36041 .08012 L
s
.678 .847 .902 r
.36041 .08012 m
.36041 .26065 L
.36084 .26065 L
.36084 .08012 L
F
.2 .63 .79 r
.36041 .08012 m
.36041 .26065 L
.36084 .26065 L
.36084 .08012 L
s
.678 .847 .902 r
.36084 .08012 m
.36084 .26028 L
.36105 .26028 L
.36105 .08012 L
F
.2 .63 .79 r
.36084 .08012 m
.36084 .26028 L
.36105 .26028 L
.36105 .08012 L
s
.678 .847 .902 r
.36105 .08012 m
.36105 .26018 L
.36142 .26018 L
.36142 .08012 L
F
.2 .63 .79 r
.36105 .08012 m
.36105 .26018 L
.36142 .26018 L
.36142 .08012 L
s
.678 .847 .902 r
.36142 .08012 m
.36142 .25996 L
.36159 .25996 L
.36159 .08012 L
F
.2 .63 .79 r
.36142 .08012 m
.36142 .25996 L
.36159 .25996 L
.36159 .08012 L
s
.678 .847 .902 r
.36159 .08012 m
.36159 .25982 L
.36184 .25982 L
.36184 .08012 L
F
.2 .63 .79 r
.36159 .08012 m
.36159 .25982 L
.36184 .25982 L
.36184 .08012 L
s
.678 .847 .902 r
.36184 .08012 m
.36184 .25929 L
.36233 .25929 L
.36233 .08012 L
F
.2 .63 .79 r
.36184 .08012 m
.36184 .25929 L
.36233 .25929 L
.36233 .08012 L
s
.678 .847 .902 r
.36233 .08012 m
.36233 .25913 L
.36251 .25913 L
.36251 .08012 L
F
.2 .63 .79 r
.36233 .08012 m
.36233 .25913 L
.36251 .25913 L
.36251 .08012 L
s
.678 .847 .902 r
.36251 .08012 m
.36251 .25909 L
.36271 .25909 L
.36271 .08012 L
F
.2 .63 .79 r
.36251 .08012 m
.36251 .25909 L
.36271 .25909 L
.36271 .08012 L
s
.678 .847 .902 r
.36271 .08012 m
.36271 .25893 L
.36299 .25893 L
.36299 .08012 L
F
.2 .63 .79 r
.36271 .08012 m
.36271 .25893 L
.36299 .25893 L
.36299 .08012 L
s
.678 .847 .902 r
.36299 .08012 m
.36299 .25873 L
.36316 .25873 L
.36316 .08012 L
F
.2 .63 .79 r
.36299 .08012 m
.36299 .25873 L
.36316 .25873 L
.36316 .08012 L
s
.678 .847 .902 r
.36316 .08012 m
.36316 .25825 L
.36362 .25825 L
.36362 .08012 L
F
.2 .63 .79 r
.36316 .08012 m
.36316 .25825 L
.36362 .25825 L
.36362 .08012 L
s
.678 .847 .902 r
.36362 .08012 m
.36362 .25793 L
.36404 .25793 L
.36404 .08012 L
F
.2 .63 .79 r
.36362 .08012 m
.36362 .25793 L
.36404 .25793 L
.36404 .08012 L
s
.678 .847 .902 r
.36404 .08012 m
.36404 .25781 L
.36428 .25781 L
.36428 .08012 L
F
.2 .63 .79 r
.36404 .08012 m
.36404 .25781 L
.36428 .25781 L
.36428 .08012 L
s
.678 .847 .902 r
.36428 .08012 m
.36428 .25762 L
.36463 .25762 L
.36463 .08012 L
F
.2 .63 .79 r
.36428 .08012 m
.36428 .25762 L
.36463 .25762 L
.36463 .08012 L
s
.678 .847 .902 r
.36463 .08012 m
.36463 .25723 L
.36512 .25723 L
.36512 .08012 L
F
.2 .63 .79 r
.36463 .08012 m
.36463 .25723 L
.36512 .25723 L
.36512 .08012 L
s
.678 .847 .902 r
.36512 .08012 m
.36512 .25697 L
.36553 .25697 L
.36553 .08012 L
F
.2 .63 .79 r
.36512 .08012 m
.36512 .25697 L
.36553 .25697 L
.36553 .08012 L
s
.678 .847 .902 r
.36553 .08012 m
.36553 .25667 L
.36579 .25667 L
.36579 .08012 L
F
.2 .63 .79 r
.36553 .08012 m
.36553 .25667 L
.36579 .25667 L
.36579 .08012 L
s
.678 .847 .902 r
.36579 .08012 m
.36579 .25649 L
.36608 .25649 L
.36608 .08012 L
F
.2 .63 .79 r
.36579 .08012 m
.36579 .25649 L
.36608 .25649 L
.36608 .08012 L
s
.678 .847 .902 r
.36608 .08012 m
.36608 .25618 L
.3663 .25618 L
.3663 .08012 L
F
.2 .63 .79 r
.36608 .08012 m
.36608 .25618 L
.3663 .25618 L
.3663 .08012 L
s
.678 .847 .902 r
.3663 .08012 m
.3663 .25592 L
.36678 .25592 L
.36678 .08012 L
F
.2 .63 .79 r
.3663 .08012 m
.3663 .25592 L
.36678 .25592 L
.36678 .08012 L
s
.678 .847 .902 r
.36678 .08012 m
.36678 .25549 L
.36714 .25549 L
.36714 .08012 L
F
.2 .63 .79 r
.36678 .08012 m
.36678 .25549 L
.36714 .25549 L
.36714 .08012 L
s
.678 .847 .902 r
.36714 .08012 m
.36714 .25541 L
.36755 .25541 L
.36755 .08012 L
F
.2 .63 .79 r
.36714 .08012 m
.36714 .25541 L
.36755 .25541 L
.36755 .08012 L
s
.678 .847 .902 r
.36755 .08012 m
.36755 .25492 L
.36782 .25492 L
.36782 .08012 L
F
.2 .63 .79 r
.36755 .08012 m
.36755 .25492 L
.36782 .25492 L
.36782 .08012 L
s
.678 .847 .902 r
.36782 .08012 m
.36782 .25486 L
.36808 .25486 L
.36808 .08012 L
F
.2 .63 .79 r
.36782 .08012 m
.36782 .25486 L
.36808 .25486 L
.36808 .08012 L
s
.678 .847 .902 r
.36808 .08012 m
.36808 .25455 L
.36849 .25455 L
.36849 .08012 L
F
.2 .63 .79 r
.36808 .08012 m
.36808 .25455 L
.36849 .25455 L
.36849 .08012 L
s
.678 .847 .902 r
.36849 .08012 m
.36849 .25432 L
.36885 .25432 L
.36885 .08012 L
F
.2 .63 .79 r
.36849 .08012 m
.36849 .25432 L
.36885 .25432 L
.36885 .08012 L
s
.678 .847 .902 r
.36885 .08012 m
.36885 .2539 L
.36924 .2539 L
.36924 .08012 L
F
.2 .63 .79 r
.36885 .08012 m
.36885 .2539 L
.36924 .2539 L
.36924 .08012 L
s
.678 .847 .902 r
.36924 .08012 m
.36924 .25377 L
.36947 .25377 L
.36947 .08012 L
F
.2 .63 .79 r
.36924 .08012 m
.36924 .25377 L
.36947 .25377 L
.36947 .08012 L
s
.678 .847 .902 r
.36947 .08012 m
.36947 .25351 L
.36978 .25351 L
.36978 .08012 L
F
.2 .63 .79 r
.36947 .08012 m
.36947 .25351 L
.36978 .25351 L
.36978 .08012 L
s
.678 .847 .902 r
.36978 .08012 m
.36978 .25327 L
.37014 .25327 L
.37014 .08012 L
F
.2 .63 .79 r
.36978 .08012 m
.36978 .25327 L
.37014 .25327 L
.37014 .08012 L
s
.678 .847 .902 r
.37014 .08012 m
.37014 .25285 L
.37051 .25285 L
.37051 .08012 L
F
.2 .63 .79 r
.37014 .08012 m
.37014 .25285 L
.37051 .25285 L
.37051 .08012 L
s
.678 .847 .902 r
.37051 .08012 m
.37051 .25265 L
.37068 .25265 L
.37068 .08012 L
F
.2 .63 .79 r
.37051 .08012 m
.37051 .25265 L
.37068 .25265 L
.37068 .08012 L
s
.678 .847 .902 r
.37068 .08012 m
.37068 .2526 L
.37087 .2526 L
.37087 .08012 L
F
.2 .63 .79 r
.37068 .08012 m
.37068 .2526 L
.37087 .2526 L
.37087 .08012 L
s
.678 .847 .902 r
.37087 .08012 m
.37087 .25242 L
.3712 .25242 L
.3712 .08012 L
F
.2 .63 .79 r
.37087 .08012 m
.37087 .25242 L
.3712 .25242 L
.3712 .08012 L
s
.678 .847 .902 r
.3712 .08012 m
.3712 .25197 L
.3716 .25197 L
.3716 .08012 L
F
.2 .63 .79 r
.3712 .08012 m
.3712 .25197 L
.3716 .25197 L
.3716 .08012 L
s
.678 .847 .902 r
.3716 .08012 m
.3716 .25191 L
.37185 .25191 L
.37185 .08012 L
F
.2 .63 .79 r
.3716 .08012 m
.3716 .25191 L
.37185 .25191 L
.37185 .08012 L
s
.678 .847 .902 r
.37185 .08012 m
.37185 .25142 L
.37228 .25142 L
.37228 .08012 L
F
.2 .63 .79 r
.37185 .08012 m
.37185 .25142 L
.37228 .25142 L
.37228 .08012 L
s
.678 .847 .902 r
.37228 .08012 m
.37228 .25101 L
.37276 .25101 L
.37276 .08012 L
F
.2 .63 .79 r
.37228 .08012 m
.37228 .25101 L
.37276 .25101 L
.37276 .08012 L
s
.678 .847 .902 r
.37276 .08012 m
.37276 .2509 L
.37316 .2509 L
.37316 .08012 L
F
.2 .63 .79 r
.37276 .08012 m
.37276 .2509 L
.37316 .2509 L
.37316 .08012 L
s
.678 .847 .902 r
.37316 .08012 m
.37316 .25048 L
.37349 .25048 L
.37349 .08012 L
F
.2 .63 .79 r
.37316 .08012 m
.37316 .25048 L
.37349 .25048 L
.37349 .08012 L
s
.678 .847 .902 r
.37349 .08012 m
.37349 .25026 L
.37381 .25026 L
.37381 .08012 L
F
.2 .63 .79 r
.37349 .08012 m
.37349 .25026 L
.37381 .25026 L
.37381 .08012 L
s
.678 .847 .902 r
.37381 .08012 m
.37381 .24993 L
.37415 .24993 L
.37415 .08012 L
F
.2 .63 .79 r
.37381 .08012 m
.37381 .24993 L
.37415 .24993 L
.37415 .08012 L
s
.678 .847 .902 r
.37415 .08012 m
.37415 .24971 L
.37448 .24971 L
.37448 .08012 L
F
.2 .63 .79 r
.37415 .08012 m
.37415 .24971 L
.37448 .24971 L
.37448 .08012 L
s
.678 .847 .902 r
.37448 .08012 m
.37448 .24957 L
.37482 .24957 L
.37482 .08012 L
F
.2 .63 .79 r
.37448 .08012 m
.37448 .24957 L
.37482 .24957 L
.37482 .08012 L
s
.678 .847 .902 r
.37482 .08012 m
.37482 .24908 L
.37527 .24908 L
.37527 .08012 L
F
.2 .63 .79 r
.37482 .08012 m
.37482 .24908 L
.37527 .24908 L
.37527 .08012 L
s
.678 .847 .902 r
.37527 .08012 m
.37527 .24876 L
.37569 .24876 L
.37569 .08012 L
F
.2 .63 .79 r
.37527 .08012 m
.37527 .24876 L
.37569 .24876 L
.37569 .08012 L
s
.678 .847 .902 r
.37569 .08012 m
.37569 .24857 L
.3759 .24857 L
.3759 .08012 L
F
.2 .63 .79 r
.37569 .08012 m
.37569 .24857 L
.3759 .24857 L
.3759 .08012 L
s
.678 .847 .902 r
.3759 .08012 m
.3759 .24852 L
.37613 .24852 L
.37613 .08012 L
F
.2 .63 .79 r
.3759 .08012 m
.3759 .24852 L
.37613 .24852 L
.37613 .08012 L
s
.678 .847 .902 r
.37613 .08012 m
.37613 .24831 L
.37631 .24831 L
.37631 .08012 L
F
.2 .63 .79 r
.37613 .08012 m
.37613 .24831 L
.37631 .24831 L
.37631 .08012 L
s
.678 .847 .902 r
.37631 .08012 m
.37631 .24812 L
.37653 .24812 L
.37653 .08012 L
F
.2 .63 .79 r
.37631 .08012 m
.37631 .24812 L
.37653 .24812 L
.37653 .08012 L
s
.678 .847 .902 r
.37653 .08012 m
.37653 .24798 L
.37683 .24798 L
.37683 .08012 L
F
.2 .63 .79 r
.37653 .08012 m
.37653 .24798 L
.37683 .24798 L
.37683 .08012 L
s
.678 .847 .902 r
.37683 .08012 m
.37683 .24777 L
.37732 .24777 L
.37732 .08012 L
F
.2 .63 .79 r
.37683 .08012 m
.37683 .24777 L
.37732 .24777 L
.37732 .08012 L
s
.678 .847 .902 r
.37732 .08012 m
.37732 .24741 L
.37769 .24741 L
.37769 .08012 L
F
.2 .63 .79 r
.37732 .08012 m
.37732 .24741 L
.37769 .24741 L
.37769 .08012 L
s
.678 .847 .902 r
.37769 .08012 m
.37769 .24705 L
.37804 .24705 L
.37804 .08012 L
F
.2 .63 .79 r
.37769 .08012 m
.37769 .24705 L
.37804 .24705 L
.37804 .08012 L
s
.678 .847 .902 r
.37804 .08012 m
.37804 .24669 L
.37846 .24669 L
.37846 .08012 L
F
.2 .63 .79 r
.37804 .08012 m
.37804 .24669 L
.37846 .24669 L
.37846 .08012 L
s
.678 .847 .902 r
.37846 .08012 m
.37846 .24647 L
.37893 .24647 L
.37893 .08012 L
F
.2 .63 .79 r
.37846 .08012 m
.37846 .24647 L
.37893 .24647 L
.37893 .08012 L
s
.678 .847 .902 r
.37893 .08012 m
.37893 .24598 L
.37927 .24598 L
.37927 .08012 L
F
.2 .63 .79 r
.37893 .08012 m
.37893 .24598 L
.37927 .24598 L
.37927 .08012 L
s
.678 .847 .902 r
.37927 .08012 m
.37927 .24592 L
.37943 .24592 L
.37943 .08012 L
F
.2 .63 .79 r
.37927 .08012 m
.37927 .24592 L
.37943 .24592 L
.37943 .08012 L
s
.678 .847 .902 r
.37943 .08012 m
.37943 .24571 L
.3796 .24571 L
.3796 .08012 L
F
.2 .63 .79 r
.37943 .08012 m
.37943 .24571 L
.3796 .24571 L
.3796 .08012 L
s
.678 .847 .902 r
.3796 .08012 m
.3796 .24562 L
.37997 .24562 L
.37997 .08012 L
F
.2 .63 .79 r
.3796 .08012 m
.3796 .24562 L
.37997 .24562 L
.37997 .08012 L
s
.678 .847 .902 r
.37997 .08012 m
.37997 .2451 L
.38037 .2451 L
.38037 .08012 L
F
.2 .63 .79 r
.37997 .08012 m
.37997 .2451 L
.38037 .2451 L
.38037 .08012 L
s
.678 .847 .902 r
.38037 .08012 m
.38037 .24507 L
.38054 .24507 L
.38054 .08012 L
F
.2 .63 .79 r
.38037 .08012 m
.38037 .24507 L
.38054 .24507 L
.38054 .08012 L
s
.678 .847 .902 r
.38054 .08012 m
.38054 .24487 L
.3808 .24487 L
.3808 .08012 L
F
.2 .63 .79 r
.38054 .08012 m
.38054 .24487 L
.3808 .24487 L
.3808 .08012 L
s
.678 .847 .902 r
.3808 .08012 m
.3808 .2447 L
.38099 .2447 L
.38099 .08012 L
F
.2 .63 .79 r
.3808 .08012 m
.3808 .2447 L
.38099 .2447 L
.38099 .08012 L
s
.678 .847 .902 r
.38099 .08012 m
.38099 .24457 L
.38121 .24457 L
.38121 .08012 L
F
.2 .63 .79 r
.38099 .08012 m
.38099 .24457 L
.38121 .24457 L
.38121 .08012 L
s
.678 .847 .902 r
.38121 .08012 m
.38121 .24439 L
.38153 .24439 L
.38153 .08012 L
F
.2 .63 .79 r
.38121 .08012 m
.38121 .24439 L
.38153 .24439 L
.38153 .08012 L
s
.678 .847 .902 r
.38153 .08012 m
.38153 .24399 L
.38196 .24399 L
.38196 .08012 L
F
.2 .63 .79 r
.38153 .08012 m
.38153 .24399 L
.38196 .24399 L
.38196 .08012 L
s
.678 .847 .902 r
.38196 .08012 m
.38196 .24386 L
.3823 .24386 L
.3823 .08012 L
F
.2 .63 .79 r
.38196 .08012 m
.38196 .24386 L
.3823 .24386 L
.3823 .08012 L
s
.678 .847 .902 r
.3823 .08012 m
.3823 .24353 L
.38257 .24353 L
.38257 .08012 L
F
.2 .63 .79 r
.3823 .08012 m
.3823 .24353 L
.38257 .24353 L
.38257 .08012 L
s
.678 .847 .902 r
.38257 .08012 m
.38257 .2433 L
.38296 .2433 L
.38296 .08012 L
F
.2 .63 .79 r
.38257 .08012 m
.38257 .2433 L
.38296 .2433 L
.38296 .08012 L
s
.678 .847 .902 r
.38296 .08012 m
.38296 .2429 L
.38333 .2429 L
.38333 .08012 L
F
.2 .63 .79 r
.38296 .08012 m
.38296 .2429 L
.38333 .2429 L
.38333 .08012 L
s
.678 .847 .902 r
.38333 .08012 m
.38333 .24264 L
.38359 .24264 L
.38359 .08012 L
F
.2 .63 .79 r
.38333 .08012 m
.38333 .24264 L
.38359 .24264 L
.38359 .08012 L
s
.678 .847 .902 r
.38359 .08012 m
.38359 .24246 L
.38382 .24246 L
.38382 .08012 L
F
.2 .63 .79 r
.38359 .08012 m
.38359 .24246 L
.38382 .24246 L
.38382 .08012 L
s
.678 .847 .902 r
.38382 .08012 m
.38382 .24229 L
.38414 .24229 L
.38414 .08012 L
F
.2 .63 .79 r
.38382 .08012 m
.38382 .24229 L
.38414 .24229 L
.38414 .08012 L
s
.678 .847 .902 r
.38414 .08012 m
.38414 .24213 L
.38435 .24213 L
.38435 .08012 L
F
.2 .63 .79 r
.38414 .08012 m
.38414 .24213 L
.38435 .24213 L
.38435 .08012 L
s
.678 .847 .902 r
.38435 .08012 m
.38435 .24189 L
.38462 .24189 L
.38462 .08012 L
F
.2 .63 .79 r
.38435 .08012 m
.38435 .24189 L
.38462 .24189 L
.38462 .08012 L
s
.678 .847 .902 r
.38462 .08012 m
.38462 .24163 L
.38497 .24163 L
.38497 .08012 L
F
.2 .63 .79 r
.38462 .08012 m
.38462 .24163 L
.38497 .24163 L
.38497 .08012 L
s
.678 .847 .902 r
.38497 .08012 m
.38497 .2415 L
.38544 .2415 L
.38544 .08012 L
F
.2 .63 .79 r
.38497 .08012 m
.38497 .2415 L
.38544 .2415 L
.38544 .08012 L
s
.678 .847 .902 r
.38544 .08012 m
.38544 .24104 L
.38572 .24104 L
.38572 .08012 L
F
.2 .63 .79 r
.38544 .08012 m
.38544 .24104 L
.38572 .24104 L
.38572 .08012 L
s
.678 .847 .902 r
.38572 .08012 m
.38572 .24089 L
.386 .24089 L
.386 .08012 L
F
.2 .63 .79 r
.38572 .08012 m
.38572 .24089 L
.386 .24089 L
.386 .08012 L
s
.678 .847 .902 r
.386 .08012 m
.386 .24065 L
.38617 .24065 L
.38617 .08012 L
F
.2 .63 .79 r
.386 .08012 m
.386 .24065 L
.38617 .24065 L
.38617 .08012 L
s
.678 .847 .902 r
.38617 .08012 m
.38617 .24029 L
.38662 .24029 L
.38662 .08012 L
F
.2 .63 .79 r
.38617 .08012 m
.38617 .24029 L
.38662 .24029 L
.38662 .08012 L
s
.678 .847 .902 r
.38662 .08012 m
.38662 .2401 L
.38688 .2401 L
.38688 .08012 L
F
.2 .63 .79 r
.38662 .08012 m
.38662 .2401 L
.38688 .2401 L
.38688 .08012 L
s
.678 .847 .902 r
.38688 .08012 m
.38688 .24004 L
.38729 .24004 L
.38729 .08012 L
F
.2 .63 .79 r
.38688 .08012 m
.38688 .24004 L
.38729 .24004 L
.38729 .08012 L
s
.678 .847 .902 r
.38729 .08012 m
.38729 .2396 L
.38755 .2396 L
.38755 .08012 L
F
.2 .63 .79 r
.38729 .08012 m
.38729 .2396 L
.38755 .2396 L
.38755 .08012 L
s
.678 .847 .902 r
.38755 .08012 m
.38755 .2393 L
.38798 .2393 L
.38798 .08012 L
F
.2 .63 .79 r
.38755 .08012 m
.38755 .2393 L
.38798 .2393 L
.38798 .08012 L
s
.678 .847 .902 r
.38798 .08012 m
.38798 .23919 L
.38813 .23919 L
.38813 .08012 L
F
.2 .63 .79 r
.38798 .08012 m
.38798 .23919 L
.38813 .23919 L
.38813 .08012 L
s
.678 .847 .902 r
.38813 .08012 m
.38813 .23892 L
.38849 .23892 L
.38849 .08012 L
F
.2 .63 .79 r
.38813 .08012 m
.38813 .23892 L
.38849 .23892 L
.38849 .08012 L
s
.678 .847 .902 r
.38849 .08012 m
.38849 .23877 L
.38867 .23877 L
.38867 .08012 L
F
.2 .63 .79 r
.38849 .08012 m
.38849 .23877 L
.38867 .23877 L
.38867 .08012 L
s
.678 .847 .902 r
.38867 .08012 m
.38867 .23859 L
.38893 .23859 L
.38893 .08012 L
F
.2 .63 .79 r
.38867 .08012 m
.38867 .23859 L
.38893 .23859 L
.38893 .08012 L
s
.678 .847 .902 r
.38893 .08012 m
.38893 .23838 L
.38915 .23838 L
.38915 .08012 L
F
.2 .63 .79 r
.38893 .08012 m
.38893 .23838 L
.38915 .23838 L
.38915 .08012 L
s
.678 .847 .902 r
.38915 .08012 m
.38915 .23826 L
.38931 .23826 L
.38931 .08012 L
F
.2 .63 .79 r
.38915 .08012 m
.38915 .23826 L
.38931 .23826 L
.38931 .08012 L
s
.678 .847 .902 r
.38931 .08012 m
.38931 .23814 L
.38972 .23814 L
.38972 .08012 L
F
.2 .63 .79 r
.38931 .08012 m
.38931 .23814 L
.38972 .23814 L
.38972 .08012 L
s
.678 .847 .902 r
.38972 .08012 m
.38972 .23782 L
.39008 .23782 L
.39008 .08012 L
F
.2 .63 .79 r
.38972 .08012 m
.38972 .23782 L
.39008 .23782 L
.39008 .08012 L
s
.678 .847 .902 r
.39008 .08012 m
.39008 .2376 L
.39042 .2376 L
.39042 .08012 L
F
.2 .63 .79 r
.39008 .08012 m
.39008 .2376 L
.39042 .2376 L
.39042 .08012 L
s
.678 .847 .902 r
.39042 .08012 m
.39042 .2371 L
.39081 .2371 L
.39081 .08012 L
F
.2 .63 .79 r
.39042 .08012 m
.39042 .2371 L
.39081 .2371 L
.39081 .08012 L
s
.678 .847 .902 r
.39081 .08012 m
.39081 .23697 L
.39115 .23697 L
.39115 .08012 L
F
.2 .63 .79 r
.39081 .08012 m
.39081 .23697 L
.39115 .23697 L
.39115 .08012 L
s
.678 .847 .902 r
.39115 .08012 m
.39115 .23673 L
.39132 .23673 L
.39132 .08012 L
F
.2 .63 .79 r
.39115 .08012 m
.39115 .23673 L
.39132 .23673 L
.39132 .08012 L
s
.678 .847 .902 r
.39132 .08012 m
.39132 .23651 L
.39161 .23651 L
.39161 .08012 L
F
.2 .63 .79 r
.39132 .08012 m
.39132 .23651 L
.39161 .23651 L
.39161 .08012 L
s
.678 .847 .902 r
.39161 .08012 m
.39161 .23642 L
.39188 .23642 L
.39188 .08012 L
F
.2 .63 .79 r
.39161 .08012 m
.39161 .23642 L
.39188 .23642 L
.39188 .08012 L
s
.678 .847 .902 r
.39188 .08012 m
.39188 .236 L
.39236 .236 L
.39236 .08012 L
F
.2 .63 .79 r
.39188 .08012 m
.39188 .236 L
.39236 .236 L
.39236 .08012 L
s
.678 .847 .902 r
.39236 .08012 m
.39236 .23582 L
.39256 .23582 L
.39256 .08012 L
F
.2 .63 .79 r
.39236 .08012 m
.39236 .23582 L
.39256 .23582 L
.39256 .08012 L
s
.678 .847 .902 r
.39256 .08012 m
.39256 .23569 L
.39305 .23569 L
.39305 .08012 L
F
.2 .63 .79 r
.39256 .08012 m
.39256 .23569 L
.39305 .23569 L
.39305 .08012 L
s
.678 .847 .902 r
.39305 .08012 m
.39305 .23505 L
.39354 .23505 L
.39354 .08012 L
F
.2 .63 .79 r
.39305 .08012 m
.39305 .23505 L
.39354 .23505 L
.39354 .08012 L
s
.678 .847 .902 r
.39354 .08012 m
.39354 .2347 L
.394 .2347 L
.394 .08012 L
F
.2 .63 .79 r
.39354 .08012 m
.39354 .2347 L
.394 .2347 L
.394 .08012 L
s
.678 .847 .902 r
.394 .08012 m
.394 .23456 L
.39423 .23456 L
.39423 .08012 L
F
.2 .63 .79 r
.394 .08012 m
.394 .23456 L
.39423 .23456 L
.39423 .08012 L
s
.678 .847 .902 r
.39423 .08012 m
.39423 .23441 L
.39461 .23441 L
.39461 .08012 L
F
.2 .63 .79 r
.39423 .08012 m
.39423 .23441 L
.39461 .23441 L
.39461 .08012 L
s
.678 .847 .902 r
.39461 .08012 m
.39461 .23407 L
.39484 .23407 L
.39484 .08012 L
F
.2 .63 .79 r
.39461 .08012 m
.39461 .23407 L
.39484 .23407 L
.39484 .08012 L
s
.678 .847 .902 r
.39484 .08012 m
.39484 .23402 L
.39519 .23402 L
.39519 .08012 L
F
.2 .63 .79 r
.39484 .08012 m
.39484 .23402 L
.39519 .23402 L
.39519 .08012 L
s
.678 .847 .902 r
.39519 .08012 m
.39519 .23359 L
.39549 .23359 L
.39549 .08012 L
F
.2 .63 .79 r
.39519 .08012 m
.39519 .23359 L
.39549 .23359 L
.39549 .08012 L
s
.678 .847 .902 r
.39549 .08012 m
.39549 .2333 L
.39586 .2333 L
.39586 .08012 L
F
.2 .63 .79 r
.39549 .08012 m
.39549 .2333 L
.39586 .2333 L
.39586 .08012 L
s
.678 .847 .902 r
.39586 .08012 m
.39586 .23326 L
.39623 .23326 L
.39623 .08012 L
F
.2 .63 .79 r
.39586 .08012 m
.39586 .23326 L
.39623 .23326 L
.39623 .08012 L
s
.678 .847 .902 r
.39623 .08012 m
.39623 .23288 L
.39654 .23288 L
.39654 .08012 L
F
.2 .63 .79 r
.39623 .08012 m
.39623 .23288 L
.39654 .23288 L
.39654 .08012 L
s
.678 .847 .902 r
.39654 .08012 m
.39654 .23274 L
.39673 .23274 L
.39673 .08012 L
F
.2 .63 .79 r
.39654 .08012 m
.39654 .23274 L
.39673 .23274 L
.39673 .08012 L
s
.678 .847 .902 r
.39673 .08012 m
.39673 .2326 L
.39703 .2326 L
.39703 .08012 L
F
.2 .63 .79 r
.39673 .08012 m
.39673 .2326 L
.39703 .2326 L
.39703 .08012 L
s
.678 .847 .902 r
.39703 .08012 m
.39703 .23231 L
.39738 .23231 L
.39738 .08012 L
F
.2 .63 .79 r
.39703 .08012 m
.39703 .23231 L
.39738 .23231 L
.39738 .08012 L
s
.678 .847 .902 r
.39738 .08012 m
.39738 .23207 L
.39777 .23207 L
.39777 .08012 L
F
.2 .63 .79 r
.39738 .08012 m
.39738 .23207 L
.39777 .23207 L
.39777 .08012 L
s
.678 .847 .902 r
.39777 .08012 m
.39777 .23163 L
.3981 .23163 L
.3981 .08012 L
F
.2 .63 .79 r
.39777 .08012 m
.39777 .23163 L
.3981 .23163 L
.3981 .08012 L
s
.678 .847 .902 r
.3981 .08012 m
.3981 .23129 L
.39854 .23129 L
.39854 .08012 L
F
.2 .63 .79 r
.3981 .08012 m
.3981 .23129 L
.39854 .23129 L
.39854 .08012 L
s
.678 .847 .902 r
.39854 .08012 m
.39854 .23113 L
.399 .23113 L
.399 .08012 L
F
.2 .63 .79 r
.39854 .08012 m
.39854 .23113 L
.399 .23113 L
.399 .08012 L
s
.678 .847 .902 r
.399 .08012 m
.399 .2308 L
.39919 .2308 L
.39919 .08012 L
F
.2 .63 .79 r
.399 .08012 m
.399 .2308 L
.39919 .2308 L
.39919 .08012 L
s
.678 .847 .902 r
.39919 .08012 m
.39919 .23074 L
.3995 .23074 L
.3995 .08012 L
F
.2 .63 .79 r
.39919 .08012 m
.39919 .23074 L
.3995 .23074 L
.3995 .08012 L
s
.678 .847 .902 r
.3995 .08012 m
.3995 .2303 L
.39981 .2303 L
.39981 .08012 L
F
.2 .63 .79 r
.3995 .08012 m
.3995 .2303 L
.39981 .2303 L
.39981 .08012 L
s
.678 .847 .902 r
.39981 .08012 m
.39981 .23028 L
.40014 .23028 L
.40014 .08012 L
F
.2 .63 .79 r
.39981 .08012 m
.39981 .23028 L
.40014 .23028 L
.40014 .08012 L
s
.678 .847 .902 r
.40014 .08012 m
.40014 .2299 L
.40034 .2299 L
.40034 .08012 L
F
.2 .63 .79 r
.40014 .08012 m
.40014 .2299 L
.40034 .2299 L
.40034 .08012 L
s
.678 .847 .902 r
.40034 .08012 m
.40034 .22981 L
.40061 .22981 L
.40061 .08012 L
F
.2 .63 .79 r
.40034 .08012 m
.40034 .22981 L
.40061 .22981 L
.40061 .08012 L
s
.678 .847 .902 r
.40061 .08012 m
.40061 .22952 L
.40092 .22952 L
.40092 .08012 L
F
.2 .63 .79 r
.40061 .08012 m
.40061 .22952 L
.40092 .22952 L
.40092 .08012 L
s
.678 .847 .902 r
.40092 .08012 m
.40092 .22944 L
.40125 .22944 L
.40125 .08012 L
F
.2 .63 .79 r
.40092 .08012 m
.40092 .22944 L
.40125 .22944 L
.40125 .08012 L
s
.678 .847 .902 r
.40125 .08012 m
.40125 .22922 L
.40148 .22922 L
.40148 .08012 L
F
.2 .63 .79 r
.40125 .08012 m
.40125 .22922 L
.40148 .22922 L
.40148 .08012 L
s
.678 .847 .902 r
.40148 .08012 m
.40148 .22894 L
.40166 .22894 L
.40166 .08012 L
F
.2 .63 .79 r
.40148 .08012 m
.40148 .22894 L
.40166 .22894 L
.40166 .08012 L
s
.678 .847 .902 r
.40166 .08012 m
.40166 .22876 L
.40209 .22876 L
.40209 .08012 L
F
.2 .63 .79 r
.40166 .08012 m
.40166 .22876 L
.40209 .22876 L
.40209 .08012 L
s
.678 .847 .902 r
.40209 .08012 m
.40209 .22853 L
.40233 .22853 L
.40233 .08012 L
F
.2 .63 .79 r
.40209 .08012 m
.40209 .22853 L
.40233 .22853 L
.40233 .08012 L
s
.678 .847 .902 r
.40233 .08012 m
.40233 .22842 L
.40271 .22842 L
.40271 .08012 L
F
.2 .63 .79 r
.40233 .08012 m
.40233 .22842 L
.40271 .22842 L
.40271 .08012 L
s
.678 .847 .902 r
.40271 .08012 m
.40271 .22811 L
.40308 .22811 L
.40308 .08012 L
F
.2 .63 .79 r
.40271 .08012 m
.40271 .22811 L
.40308 .22811 L
.40308 .08012 L
s
.678 .847 .902 r
.40308 .08012 m
.40308 .22776 L
.40329 .22776 L
.40329 .08012 L
F
.2 .63 .79 r
.40308 .08012 m
.40308 .22776 L
.40329 .22776 L
.40329 .08012 L
s
.678 .847 .902 r
.40329 .08012 m
.40329 .22761 L
.40365 .22761 L
.40365 .08012 L
F
.2 .63 .79 r
.40329 .08012 m
.40329 .22761 L
.40365 .22761 L
.40365 .08012 L
s
.678 .847 .902 r
.40365 .08012 m
.40365 .22734 L
.40388 .22734 L
.40388 .08012 L
F
.2 .63 .79 r
.40365 .08012 m
.40365 .22734 L
.40388 .22734 L
.40388 .08012 L
s
.678 .847 .902 r
.40388 .08012 m
.40388 .22704 L
.4042 .22704 L
.4042 .08012 L
F
.2 .63 .79 r
.40388 .08012 m
.40388 .22704 L
.4042 .22704 L
.4042 .08012 L
s
.678 .847 .902 r
.4042 .08012 m
.4042 .22685 L
.4046 .22685 L
.4046 .08012 L
F
.2 .63 .79 r
.4042 .08012 m
.4042 .22685 L
.4046 .22685 L
.4046 .08012 L
s
.678 .847 .902 r
.4046 .08012 m
.4046 .22672 L
.40476 .22672 L
.40476 .08012 L
F
.2 .63 .79 r
.4046 .08012 m
.4046 .22672 L
.40476 .22672 L
.40476 .08012 L
s
.678 .847 .902 r
.40476 .08012 m
.40476 .22652 L
.40509 .22652 L
.40509 .08012 L
F
.2 .63 .79 r
.40476 .08012 m
.40476 .22652 L
.40509 .22652 L
.40509 .08012 L
s
.678 .847 .902 r
.40509 .08012 m
.40509 .22633 L
.40557 .22633 L
.40557 .08012 L
F
.2 .63 .79 r
.40509 .08012 m
.40509 .22633 L
.40557 .22633 L
.40557 .08012 L
s
.678 .847 .902 r
.40557 .08012 m
.40557 .22577 L
.40602 .22577 L
.40602 .08012 L
F
.2 .63 .79 r
.40557 .08012 m
.40557 .22577 L
.40602 .22577 L
.40602 .08012 L
s
.678 .847 .902 r
.40602 .08012 m
.40602 .22557 L
.40622 .22557 L
.40622 .08012 L
F
.2 .63 .79 r
.40602 .08012 m
.40602 .22557 L
.40622 .22557 L
.40622 .08012 L
s
.678 .847 .902 r
.40622 .08012 m
.40622 .2254 L
.40651 .2254 L
.40651 .08012 L
F
.2 .63 .79 r
.40622 .08012 m
.40622 .2254 L
.40651 .2254 L
.40651 .08012 L
s
.678 .847 .902 r
.40651 .08012 m
.40651 .22531 L
.40682 .22531 L
.40682 .08012 L
F
.2 .63 .79 r
.40651 .08012 m
.40651 .22531 L
.40682 .22531 L
.40682 .08012 L
s
.678 .847 .902 r
.40682 .08012 m
.40682 .22493 L
.40711 .22493 L
.40711 .08012 L
F
.2 .63 .79 r
.40682 .08012 m
.40682 .22493 L
.40711 .22493 L
.40711 .08012 L
s
.678 .847 .902 r
.40711 .08012 m
.40711 .2247 L
.40748 .2247 L
.40748 .08012 L
F
.2 .63 .79 r
.40711 .08012 m
.40711 .2247 L
.40748 .2247 L
.40748 .08012 L
s
.678 .847 .902 r
.40748 .08012 m
.40748 .2245 L
.4077 .2245 L
.4077 .08012 L
F
.2 .63 .79 r
.40748 .08012 m
.40748 .2245 L
.4077 .2245 L
.4077 .08012 L
s
.678 .847 .902 r
.4077 .08012 m
.4077 .22436 L
.4079 .22436 L
.4079 .08012 L
F
.2 .63 .79 r
.4077 .08012 m
.4077 .22436 L
.4079 .22436 L
.4079 .08012 L
s
.678 .847 .902 r
.4079 .08012 m
.4079 .22397 L
.40837 .22397 L
.40837 .08012 L
F
.2 .63 .79 r
.4079 .08012 m
.4079 .22397 L
.40837 .22397 L
.40837 .08012 L
s
.678 .847 .902 r
.40837 .08012 m
.40837 .22387 L
.40856 .22387 L
.40856 .08012 L
F
.2 .63 .79 r
.40837 .08012 m
.40837 .22387 L
.40856 .22387 L
.40856 .08012 L
s
.678 .847 .902 r
.40856 .08012 m
.40856 .22361 L
.40904 .22361 L
.40904 .08012 L
F
.2 .63 .79 r
.40856 .08012 m
.40856 .22361 L
.40904 .22361 L
.40904 .08012 L
s
.678 .847 .902 r
.40904 .08012 m
.40904 .22337 L
.40921 .22337 L
.40921 .08012 L
F
.2 .63 .79 r
.40904 .08012 m
.40904 .22337 L
.40921 .22337 L
.40921 .08012 L
s
.678 .847 .902 r
.40921 .08012 m
.40921 .22326 L
.4094 .22326 L
.4094 .08012 L
F
.2 .63 .79 r
.40921 .08012 m
.40921 .22326 L
.4094 .22326 L
.4094 .08012 L
s
.678 .847 .902 r
.4094 .08012 m
.4094 .22315 L
.40984 .22315 L
.40984 .08012 L
F
.2 .63 .79 r
.4094 .08012 m
.4094 .22315 L
.40984 .22315 L
.40984 .08012 L
s
.678 .847 .902 r
.40984 .08012 m
.40984 .22277 L
.41008 .22277 L
.41008 .08012 L
F
.2 .63 .79 r
.40984 .08012 m
.40984 .22277 L
.41008 .22277 L
.41008 .08012 L
s
.678 .847 .902 r
.41008 .08012 m
.41008 .22256 L
.41037 .22256 L
.41037 .08012 L
F
.2 .63 .79 r
.41008 .08012 m
.41008 .22256 L
.41037 .22256 L
.41037 .08012 L
s
.678 .847 .902 r
.41037 .08012 m
.41037 .22218 L
.41086 .22218 L
.41086 .08012 L
F
.2 .63 .79 r
.41037 .08012 m
.41037 .22218 L
.41086 .22218 L
.41086 .08012 L
s
.678 .847 .902 r
.41086 .08012 m
.41086 .22199 L
.41108 .22199 L
.41108 .08012 L
F
.2 .63 .79 r
.41086 .08012 m
.41086 .22199 L
.41108 .22199 L
.41108 .08012 L
s
.678 .847 .902 r
.41108 .08012 m
.41108 .22184 L
.41124 .22184 L
.41124 .08012 L
F
.2 .63 .79 r
.41108 .08012 m
.41108 .22184 L
.41124 .22184 L
.41124 .08012 L
s
.678 .847 .902 r
.41124 .08012 m
.41124 .22161 L
.4117 .22161 L
.4117 .08012 L
F
.2 .63 .79 r
.41124 .08012 m
.41124 .22161 L
.4117 .22161 L
.4117 .08012 L
s
.678 .847 .902 r
.4117 .08012 m
.4117 .22146 L
.41193 .22146 L
.41193 .08012 L
F
.2 .63 .79 r
.4117 .08012 m
.4117 .22146 L
.41193 .22146 L
.41193 .08012 L
s
.678 .847 .902 r
.41193 .08012 m
.41193 .22122 L
.41214 .22122 L
.41214 .08012 L
F
.2 .63 .79 r
.41193 .08012 m
.41193 .22122 L
.41214 .22122 L
.41214 .08012 L
s
.678 .847 .902 r
.41214 .08012 m
.41214 .22103 L
.41246 .22103 L
.41246 .08012 L
F
.2 .63 .79 r
.41214 .08012 m
.41214 .22103 L
.41246 .22103 L
.41246 .08012 L
s
.678 .847 .902 r
.41246 .08012 m
.41246 .22074 L
.41293 .22074 L
.41293 .08012 L
F
.2 .63 .79 r
.41246 .08012 m
.41246 .22074 L
.41293 .22074 L
.41293 .08012 L
s
.678 .847 .902 r
.41293 .08012 m
.41293 .2205 L
.41322 .2205 L
.41322 .08012 L
F
.2 .63 .79 r
.41293 .08012 m
.41293 .2205 L
.41322 .2205 L
.41322 .08012 L
s
.678 .847 .902 r
.41322 .08012 m
.41322 .22028 L
.41337 .22028 L
.41337 .08012 L
F
.2 .63 .79 r
.41322 .08012 m
.41322 .22028 L
.41337 .22028 L
.41337 .08012 L
s
.678 .847 .902 r
.41337 .08012 m
.41337 .22014 L
.41355 .22014 L
.41355 .08012 L
F
.2 .63 .79 r
.41337 .08012 m
.41337 .22014 L
.41355 .22014 L
.41355 .08012 L
s
.678 .847 .902 r
.41355 .08012 m
.41355 .22002 L
.41386 .22002 L
.41386 .08012 L
F
.2 .63 .79 r
.41355 .08012 m
.41355 .22002 L
.41386 .22002 L
.41386 .08012 L
s
.678 .847 .902 r
.41386 .08012 m
.41386 .21966 L
.41435 .21966 L
.41435 .08012 L
F
.2 .63 .79 r
.41386 .08012 m
.41386 .21966 L
.41435 .21966 L
.41435 .08012 L
s
.678 .847 .902 r
.41435 .08012 m
.41435 .2195 L
.41462 .2195 L
.41462 .08012 L
F
.2 .63 .79 r
.41435 .08012 m
.41435 .2195 L
.41462 .2195 L
.41462 .08012 L
s
.678 .847 .902 r
.41462 .08012 m
.41462 .21924 L
.41507 .21924 L
.41507 .08012 L
F
.2 .63 .79 r
.41462 .08012 m
.41462 .21924 L
.41507 .21924 L
.41507 .08012 L
s
.678 .847 .902 r
.41507 .08012 m
.41507 .21885 L
.41532 .21885 L
.41532 .08012 L
F
.2 .63 .79 r
.41507 .08012 m
.41507 .21885 L
.41532 .21885 L
.41532 .08012 L
s
.678 .847 .902 r
.41532 .08012 m
.41532 .21875 L
.4155 .21875 L
.4155 .08012 L
F
.2 .63 .79 r
.41532 .08012 m
.41532 .21875 L
.4155 .21875 L
.4155 .08012 L
s
.678 .847 .902 r
.4155 .08012 m
.4155 .21859 L
.41572 .21859 L
.41572 .08012 L
F
.2 .63 .79 r
.4155 .08012 m
.4155 .21859 L
.41572 .21859 L
.41572 .08012 L
s
.678 .847 .902 r
.41572 .08012 m
.41572 .21828 L
.41619 .21828 L
.41619 .08012 L
F
.2 .63 .79 r
.41572 .08012 m
.41572 .21828 L
.41619 .21828 L
.41619 .08012 L
s
.678 .847 .902 r
.41619 .08012 m
.41619 .21817 L
.41642 .21817 L
.41642 .08012 L
F
.2 .63 .79 r
.41619 .08012 m
.41619 .21817 L
.41642 .21817 L
.41642 .08012 L
s
.678 .847 .902 r
.41642 .08012 m
.41642 .21794 L
.41689 .21794 L
.41689 .08012 L
F
.2 .63 .79 r
.41642 .08012 m
.41642 .21794 L
.41689 .21794 L
.41689 .08012 L
s
.678 .847 .902 r
.41689 .08012 m
.41689 .21757 L
.41717 .21757 L
.41717 .08012 L
F
.2 .63 .79 r
.41689 .08012 m
.41689 .21757 L
.41717 .21757 L
.41717 .08012 L
s
.678 .847 .902 r
.41717 .08012 m
.41717 .21743 L
.41755 .21743 L
.41755 .08012 L
F
.2 .63 .79 r
.41717 .08012 m
.41717 .21743 L
.41755 .21743 L
.41755 .08012 L
s
.678 .847 .902 r
.41755 .08012 m
.41755 .21702 L
.41797 .21702 L
.41797 .08012 L
F
.2 .63 .79 r
.41755 .08012 m
.41755 .21702 L
.41797 .21702 L
.41797 .08012 L
s
.678 .847 .902 r
.41797 .08012 m
.41797 .21674 L
.41846 .21674 L
.41846 .08012 L
F
.2 .63 .79 r
.41797 .08012 m
.41797 .21674 L
.41846 .21674 L
.41846 .08012 L
s
.678 .847 .902 r
.41846 .08012 m
.41846 .21644 L
.41866 .21644 L
.41866 .08012 L
F
.2 .63 .79 r
.41846 .08012 m
.41846 .21644 L
.41866 .21644 L
.41866 .08012 L
s
.678 .847 .902 r
.41866 .08012 m
.41866 .21635 L
.41903 .21635 L
.41903 .08012 L
F
.2 .63 .79 r
.41866 .08012 m
.41866 .21635 L
.41903 .21635 L
.41903 .08012 L
s
.678 .847 .902 r
.41903 .08012 m
.41903 .21616 L
.41948 .21616 L
.41948 .08012 L
F
.2 .63 .79 r
.41903 .08012 m
.41903 .21616 L
.41948 .21616 L
.41948 .08012 L
s
.678 .847 .902 r
.41948 .08012 m
.41948 .21574 L
.41988 .21574 L
.41988 .08012 L
F
.2 .63 .79 r
.41948 .08012 m
.41948 .21574 L
.41988 .21574 L
.41988 .08012 L
s
.678 .847 .902 r
.41988 .08012 m
.41988 .21545 L
.42037 .21545 L
.42037 .08012 L
F
.2 .63 .79 r
.41988 .08012 m
.41988 .21545 L
.42037 .21545 L
.42037 .08012 L
s
.678 .847 .902 r
.42037 .08012 m
.42037 .2151 L
.42057 .2151 L
.42057 .08012 L
F
.2 .63 .79 r
.42037 .08012 m
.42037 .2151 L
.42057 .2151 L
.42057 .08012 L
s
.678 .847 .902 r
.42057 .08012 m
.42057 .2149 L
.42104 .2149 L
.42104 .08012 L
F
.2 .63 .79 r
.42057 .08012 m
.42057 .2149 L
.42104 .2149 L
.42104 .08012 L
s
.678 .847 .902 r
.42104 .08012 m
.42104 .21455 L
.4213 .21455 L
.4213 .08012 L
F
.2 .63 .79 r
.42104 .08012 m
.42104 .21455 L
.4213 .21455 L
.4213 .08012 L
s
.678 .847 .902 r
.4213 .08012 m
.4213 .21442 L
.42179 .21442 L
.42179 .08012 L
F
.2 .63 .79 r
.4213 .08012 m
.4213 .21442 L
.42179 .21442 L
.42179 .08012 L
s
.678 .847 .902 r
.42179 .08012 m
.42179 .21409 L
.42195 .21409 L
.42195 .08012 L
F
.2 .63 .79 r
.42179 .08012 m
.42179 .21409 L
.42195 .21409 L
.42195 .08012 L
s
.678 .847 .902 r
.42195 .08012 m
.42195 .21385 L
.42226 .21385 L
.42226 .08012 L
F
.2 .63 .79 r
.42195 .08012 m
.42195 .21385 L
.42226 .21385 L
.42226 .08012 L
s
.678 .847 .902 r
.42226 .08012 m
.42226 .21381 L
.42253 .21381 L
.42253 .08012 L
F
.2 .63 .79 r
.42226 .08012 m
.42226 .21381 L
.42253 .21381 L
.42253 .08012 L
s
.678 .847 .902 r
.42253 .08012 m
.42253 .21338 L
.4229 .21338 L
.4229 .08012 L
F
.2 .63 .79 r
.42253 .08012 m
.42253 .21338 L
.4229 .21338 L
.4229 .08012 L
s
.678 .847 .902 r
.4229 .08012 m
.4229 .21333 L
.42309 .21333 L
.42309 .08012 L
F
.2 .63 .79 r
.4229 .08012 m
.4229 .21333 L
.42309 .21333 L
.42309 .08012 L
s
.678 .847 .902 r
.42309 .08012 m
.42309 .2131 L
.4233 .2131 L
.4233 .08012 L
F
.2 .63 .79 r
.42309 .08012 m
.42309 .2131 L
.4233 .2131 L
.4233 .08012 L
s
.678 .847 .902 r
.4233 .08012 m
.4233 .21303 L
.42354 .21303 L
.42354 .08012 L
F
.2 .63 .79 r
.4233 .08012 m
.4233 .21303 L
.42354 .21303 L
.42354 .08012 L
s
.678 .847 .902 r
.42354 .08012 m
.42354 .21288 L
.42384 .21288 L
.42384 .08012 L
F
.2 .63 .79 r
.42354 .08012 m
.42354 .21288 L
.42384 .21288 L
.42384 .08012 L
s
.678 .847 .902 r
.42384 .08012 m
.42384 .21263 L
.42405 .21263 L
.42405 .08012 L
F
.2 .63 .79 r
.42384 .08012 m
.42384 .21263 L
.42405 .21263 L
.42405 .08012 L
s
.678 .847 .902 r
.42405 .08012 m
.42405 .21235 L
.42452 .21235 L
.42452 .08012 L
F
.2 .63 .79 r
.42405 .08012 m
.42405 .21235 L
.42452 .21235 L
.42452 .08012 L
s
.678 .847 .902 r
.42452 .08012 m
.42452 .21202 L
.42478 .21202 L
.42478 .08012 L
F
.2 .63 .79 r
.42452 .08012 m
.42452 .21202 L
.42478 .21202 L
.42478 .08012 L
s
.678 .847 .902 r
.42478 .08012 m
.42478 .21197 L
.42495 .21197 L
.42495 .08012 L
F
.2 .63 .79 r
.42478 .08012 m
.42478 .21197 L
.42495 .21197 L
.42495 .08012 L
s
.678 .847 .902 r
.42495 .08012 m
.42495 .21186 L
.42527 .21186 L
.42527 .08012 L
F
.2 .63 .79 r
.42495 .08012 m
.42495 .21186 L
.42527 .21186 L
.42527 .08012 L
s
.678 .847 .902 r
.42527 .08012 m
.42527 .21155 L
.42547 .21155 L
.42547 .08012 L
F
.2 .63 .79 r
.42527 .08012 m
.42527 .21155 L
.42547 .21155 L
.42547 .08012 L
s
.678 .847 .902 r
.42547 .08012 m
.42547 .21144 L
.42574 .21144 L
.42574 .08012 L
F
.2 .63 .79 r
.42547 .08012 m
.42547 .21144 L
.42574 .21144 L
.42574 .08012 L
s
.678 .847 .902 r
.42574 .08012 m
.42574 .21118 L
.4262 .21118 L
.4262 .08012 L
F
.2 .63 .79 r
.42574 .08012 m
.42574 .21118 L
.4262 .21118 L
.4262 .08012 L
s
.678 .847 .902 r
.4262 .08012 m
.4262 .21073 L
.42664 .21073 L
.42664 .08012 L
F
.2 .63 .79 r
.4262 .08012 m
.4262 .21073 L
.42664 .21073 L
.42664 .08012 L
s
.678 .847 .902 r
.42664 .08012 m
.42664 .21055 L
.42688 .21055 L
.42688 .08012 L
F
.2 .63 .79 r
.42664 .08012 m
.42664 .21055 L
.42688 .21055 L
.42688 .08012 L
s
.678 .847 .902 r
.42688 .08012 m
.42688 .21049 L
.42724 .21049 L
.42724 .08012 L
F
.2 .63 .79 r
.42688 .08012 m
.42688 .21049 L
.42724 .21049 L
.42724 .08012 L
s
.678 .847 .902 r
.42724 .08012 m
.42724 .2102 L
.4277 .2102 L
.4277 .08012 L
F
.2 .63 .79 r
.42724 .08012 m
.42724 .2102 L
.4277 .2102 L
.4277 .08012 L
s
.678 .847 .902 r
.4277 .08012 m
.4277 .20988 L
.4281 .20988 L
.4281 .08012 L
F
.2 .63 .79 r
.4277 .08012 m
.4277 .20988 L
.4281 .20988 L
.4281 .08012 L
s
.678 .847 .902 r
.4281 .08012 m
.4281 .20958 L
.42836 .20958 L
.42836 .08012 L
F
.2 .63 .79 r
.4281 .08012 m
.4281 .20958 L
.42836 .20958 L
.42836 .08012 L
s
.678 .847 .902 r
.42836 .08012 m
.42836 .20943 L
.4286 .20943 L
.4286 .08012 L
F
.2 .63 .79 r
.42836 .08012 m
.42836 .20943 L
.4286 .20943 L
.4286 .08012 L
s
.678 .847 .902 r
.4286 .08012 m
.4286 .209 L
.42906 .209 L
.42906 .08012 L
F
.2 .63 .79 r
.4286 .08012 m
.4286 .209 L
.42906 .209 L
.42906 .08012 L
s
.678 .847 .902 r
.42906 .08012 m
.42906 .20883 L
.42945 .20883 L
.42945 .08012 L
F
.2 .63 .79 r
.42906 .08012 m
.42906 .20883 L
.42945 .20883 L
.42945 .08012 L
s
.678 .847 .902 r
.42945 .08012 m
.42945 .20853 L
.42989 .20853 L
.42989 .08012 L
F
.2 .63 .79 r
.42945 .08012 m
.42945 .20853 L
.42989 .20853 L
.42989 .08012 L
s
.678 .847 .902 r
.42989 .08012 m
.42989 .20834 L
.43036 .20834 L
.43036 .08012 L
F
.2 .63 .79 r
.42989 .08012 m
.42989 .20834 L
.43036 .20834 L
.43036 .08012 L
s
.678 .847 .902 r
.43036 .08012 m
.43036 .20789 L
.4306 .20789 L
.4306 .08012 L
F
.2 .63 .79 r
.43036 .08012 m
.43036 .20789 L
.4306 .20789 L
.4306 .08012 L
s
.678 .847 .902 r
.4306 .08012 m
.4306 .20783 L
.43095 .20783 L
.43095 .08012 L
F
.2 .63 .79 r
.4306 .08012 m
.4306 .20783 L
.43095 .20783 L
.43095 .08012 L
s
.678 .847 .902 r
.43095 .08012 m
.43095 .20747 L
.43132 .20747 L
.43132 .08012 L
F
.2 .63 .79 r
.43095 .08012 m
.43095 .20747 L
.43132 .20747 L
.43132 .08012 L
s
.678 .847 .902 r
.43132 .08012 m
.43132 .20716 L
.4317 .20716 L
.4317 .08012 L
F
.2 .63 .79 r
.43132 .08012 m
.43132 .20716 L
.4317 .20716 L
.4317 .08012 L
s
.678 .847 .902 r
.4317 .08012 m
.4317 .20685 L
.43214 .20685 L
.43214 .08012 L
F
.2 .63 .79 r
.4317 .08012 m
.4317 .20685 L
.43214 .20685 L
.43214 .08012 L
s
.678 .847 .902 r
.43214 .08012 m
.43214 .20665 L
.43242 .20665 L
.43242 .08012 L
F
.2 .63 .79 r
.43214 .08012 m
.43214 .20665 L
.43242 .20665 L
.43242 .08012 L
s
.678 .847 .902 r
.43242 .08012 m
.43242 .20659 L
.4328 .20659 L
.4328 .08012 L
F
.2 .63 .79 r
.43242 .08012 m
.43242 .20659 L
.4328 .20659 L
.4328 .08012 L
s
.678 .847 .902 r
.4328 .08012 m
.4328 .20618 L
.43307 .20618 L
.43307 .08012 L
F
.2 .63 .79 r
.4328 .08012 m
.4328 .20618 L
.43307 .20618 L
.43307 .08012 L
s
.678 .847 .902 r
.43307 .08012 m
.43307 .20602 L
.43349 .20602 L
.43349 .08012 L
F
.2 .63 .79 r
.43307 .08012 m
.43307 .20602 L
.43349 .20602 L
.43349 .08012 L
s
.678 .847 .902 r
.43349 .08012 m
.43349 .20568 L
.43395 .20568 L
.43395 .08012 L
F
.2 .63 .79 r
.43349 .08012 m
.43349 .20568 L
.43395 .20568 L
.43395 .08012 L
s
.678 .847 .902 r
.43395 .08012 m
.43395 .20549 L
.43428 .20549 L
.43428 .08012 L
F
.2 .63 .79 r
.43395 .08012 m
.43395 .20549 L
.43428 .20549 L
.43428 .08012 L
s
.678 .847 .902 r
.43428 .08012 m
.43428 .20517 L
.43477 .20517 L
.43477 .08012 L
F
.2 .63 .79 r
.43428 .08012 m
.43428 .20517 L
.43477 .20517 L
.43477 .08012 L
s
.678 .847 .902 r
.43477 .08012 m
.43477 .20465 L
.43522 .20465 L
.43522 .08012 L
F
.2 .63 .79 r
.43477 .08012 m
.43477 .20465 L
.43522 .20465 L
.43522 .08012 L
s
.678 .847 .902 r
.43522 .08012 m
.43522 .20455 L
.43539 .20455 L
.43539 .08012 L
F
.2 .63 .79 r
.43522 .08012 m
.43522 .20455 L
.43539 .20455 L
.43539 .08012 L
s
.678 .847 .902 r
.43539 .08012 m
.43539 .20446 L
.43563 .20446 L
.43563 .08012 L
F
.2 .63 .79 r
.43539 .08012 m
.43539 .20446 L
.43563 .20446 L
.43563 .08012 L
s
.678 .847 .902 r
.43563 .08012 m
.43563 .2043 L
.4359 .2043 L
.4359 .08012 L
F
.2 .63 .79 r
.43563 .08012 m
.43563 .2043 L
.4359 .2043 L
.4359 .08012 L
s
.678 .847 .902 r
.4359 .08012 m
.4359 .2039 L
.43639 .2039 L
.43639 .08012 L
F
.2 .63 .79 r
.4359 .08012 m
.4359 .2039 L
.43639 .2039 L
.43639 .08012 L
s
.678 .847 .902 r
.43639 .08012 m
.43639 .20373 L
.43665 .20373 L
.43665 .08012 L
F
.2 .63 .79 r
.43639 .08012 m
.43639 .20373 L
.43665 .20373 L
.43665 .08012 L
s
.678 .847 .902 r
.43665 .08012 m
.43665 .20334 L
.43712 .20334 L
.43712 .08012 L
F
.2 .63 .79 r
.43665 .08012 m
.43665 .20334 L
.43712 .20334 L
.43712 .08012 L
s
.678 .847 .902 r
.43712 .08012 m
.43712 .20317 L
.4373 .20317 L
.4373 .08012 L
F
.2 .63 .79 r
.43712 .08012 m
.43712 .20317 L
.4373 .20317 L
.4373 .08012 L
s
.678 .847 .902 r
.4373 .08012 m
.4373 .20307 L
.43747 .20307 L
.43747 .08012 L
F
.2 .63 .79 r
.4373 .08012 m
.4373 .20307 L
.43747 .20307 L
.43747 .08012 L
s
.678 .847 .902 r
.43747 .08012 m
.43747 .20283 L
.43784 .20283 L
.43784 .08012 L
F
.2 .63 .79 r
.43747 .08012 m
.43747 .20283 L
.43784 .20283 L
.43784 .08012 L
s
.678 .847 .902 r
.43784 .08012 m
.43784 .20275 L
.43803 .20275 L
.43803 .08012 L
F
.2 .63 .79 r
.43784 .08012 m
.43784 .20275 L
.43803 .20275 L
.43803 .08012 L
s
.678 .847 .902 r
.43803 .08012 m
.43803 .20255 L
.43822 .20255 L
.43822 .08012 L
F
.2 .63 .79 r
.43803 .08012 m
.43803 .20255 L
.43822 .20255 L
.43822 .08012 L
s
.678 .847 .902 r
.43822 .08012 m
.43822 .20228 L
.43864 .20228 L
.43864 .08012 L
F
.2 .63 .79 r
.43822 .08012 m
.43822 .20228 L
.43864 .20228 L
.43864 .08012 L
s
.678 .847 .902 r
.43864 .08012 m
.43864 .20215 L
.43881 .20215 L
.43881 .08012 L
F
.2 .63 .79 r
.43864 .08012 m
.43864 .20215 L
.43881 .20215 L
.43881 .08012 L
s
.678 .847 .902 r
.43881 .08012 m
.43881 .20196 L
.43912 .20196 L
.43912 .08012 L
F
.2 .63 .79 r
.43881 .08012 m
.43881 .20196 L
.43912 .20196 L
.43912 .08012 L
s
.678 .847 .902 r
.43912 .08012 m
.43912 .20189 L
.43943 .20189 L
.43943 .08012 L
F
.2 .63 .79 r
.43912 .08012 m
.43912 .20189 L
.43943 .20189 L
.43943 .08012 L
s
.678 .847 .902 r
.43943 .08012 m
.43943 .20135 L
.43991 .20135 L
.43991 .08012 L
F
.2 .63 .79 r
.43943 .08012 m
.43943 .20135 L
.43991 .20135 L
.43991 .08012 L
s
.678 .847 .902 r
.43991 .08012 m
.43991 .20111 L
.44028 .20111 L
.44028 .08012 L
F
.2 .63 .79 r
.43991 .08012 m
.43991 .20111 L
.44028 .20111 L
.44028 .08012 L
s
.678 .847 .902 r
.44028 .08012 m
.44028 .2009 L
.4407 .2009 L
.4407 .08012 L
F
.2 .63 .79 r
.44028 .08012 m
.44028 .2009 L
.4407 .2009 L
.4407 .08012 L
s
.678 .847 .902 r
.4407 .08012 m
.4407 .20077 L
.44089 .20077 L
.44089 .08012 L
F
.2 .63 .79 r
.4407 .08012 m
.4407 .20077 L
.44089 .20077 L
.44089 .08012 L
s
.678 .847 .902 r
.44089 .08012 m
.44089 .20058 L
.44109 .20058 L
.44109 .08012 L
F
.2 .63 .79 r
.44089 .08012 m
.44089 .20058 L
.44109 .20058 L
.44109 .08012 L
s
.678 .847 .902 r
.44109 .08012 m
.44109 .20041 L
.4415 .20041 L
.4415 .08012 L
F
.2 .63 .79 r
.44109 .08012 m
.44109 .20041 L
.4415 .20041 L
.4415 .08012 L
s
.678 .847 .902 r
.4415 .08012 m
.4415 .20016 L
.44174 .20016 L
.44174 .08012 L
F
.2 .63 .79 r
.4415 .08012 m
.4415 .20016 L
.44174 .20016 L
.44174 .08012 L
s
.678 .847 .902 r
.44174 .08012 m
.44174 .19996 L
.44193 .19996 L
.44193 .08012 L
F
.2 .63 .79 r
.44174 .08012 m
.44174 .19996 L
.44193 .19996 L
.44193 .08012 L
s
.678 .847 .902 r
.44193 .08012 m
.44193 .19983 L
.44217 .19983 L
.44217 .08012 L
F
.2 .63 .79 r
.44193 .08012 m
.44193 .19983 L
.44217 .19983 L
.44217 .08012 L
s
.678 .847 .902 r
.44217 .08012 m
.44217 .19956 L
.44257 .19956 L
.44257 .08012 L
F
.2 .63 .79 r
.44217 .08012 m
.44217 .19956 L
.44257 .19956 L
.44257 .08012 L
s
.678 .847 .902 r
.44257 .08012 m
.44257 .19942 L
.44305 .19942 L
.44305 .08012 L
F
.2 .63 .79 r
.44257 .08012 m
.44257 .19942 L
.44305 .19942 L
.44305 .08012 L
s
.678 .847 .902 r
.44305 .08012 m
.44305 .19897 L
.44347 .19897 L
.44347 .08012 L
F
.2 .63 .79 r
.44305 .08012 m
.44305 .19897 L
.44347 .19897 L
.44347 .08012 L
s
.678 .847 .902 r
.44347 .08012 m
.44347 .19872 L
.44371 .19872 L
.44371 .08012 L
F
.2 .63 .79 r
.44347 .08012 m
.44347 .19872 L
.44371 .19872 L
.44371 .08012 L
s
.678 .847 .902 r
.44371 .08012 m
.44371 .19863 L
.44399 .19863 L
.44399 .08012 L
F
.2 .63 .79 r
.44371 .08012 m
.44371 .19863 L
.44399 .19863 L
.44399 .08012 L
s
.678 .847 .902 r
.44399 .08012 m
.44399 .19847 L
.44415 .19847 L
.44415 .08012 L
F
.2 .63 .79 r
.44399 .08012 m
.44399 .19847 L
.44415 .19847 L
.44415 .08012 L
s
.678 .847 .902 r
.44415 .08012 m
.44415 .19821 L
.44453 .19821 L
.44453 .08012 L
F
.2 .63 .79 r
.44415 .08012 m
.44415 .19821 L
.44453 .19821 L
.44453 .08012 L
s
.678 .847 .902 r
.44453 .08012 m
.44453 .19812 L
.44475 .19812 L
.44475 .08012 L
F
.2 .63 .79 r
.44453 .08012 m
.44453 .19812 L
.44475 .19812 L
.44475 .08012 L
s
.678 .847 .902 r
.44475 .08012 m
.44475 .19783 L
.44516 .19783 L
.44516 .08012 L
F
.2 .63 .79 r
.44475 .08012 m
.44475 .19783 L
.44516 .19783 L
.44516 .08012 L
s
.678 .847 .902 r
.44516 .08012 m
.44516 .19768 L
.44563 .19768 L
.44563 .08012 L
F
.2 .63 .79 r
.44516 .08012 m
.44516 .19768 L
.44563 .19768 L
.44563 .08012 L
s
.678 .847 .902 r
.44563 .08012 m
.44563 .19717 L
.44596 .19717 L
.44596 .08012 L
F
.2 .63 .79 r
.44563 .08012 m
.44563 .19717 L
.44596 .19717 L
.44596 .08012 L
s
.678 .847 .902 r
.44596 .08012 m
.44596 .19709 L
.44625 .19709 L
.44625 .08012 L
F
.2 .63 .79 r
.44596 .08012 m
.44596 .19709 L
.44625 .19709 L
.44625 .08012 L
s
.678 .847 .902 r
.44625 .08012 m
.44625 .19672 L
.44664 .19672 L
.44664 .08012 L
F
.2 .63 .79 r
.44625 .08012 m
.44625 .19672 L
.44664 .19672 L
.44664 .08012 L
s
.678 .847 .902 r
.44664 .08012 m
.44664 .1966 L
.44695 .1966 L
.44695 .08012 L
F
.2 .63 .79 r
.44664 .08012 m
.44664 .1966 L
.44695 .1966 L
.44695 .08012 L
s
.678 .847 .902 r
.44695 .08012 m
.44695 .19637 L
.44711 .19637 L
.44711 .08012 L
F
.2 .63 .79 r
.44695 .08012 m
.44695 .19637 L
.44711 .19637 L
.44711 .08012 L
s
.678 .847 .902 r
.44711 .08012 m
.44711 .19629 L
.44742 .19629 L
.44742 .08012 L
F
.2 .63 .79 r
.44711 .08012 m
.44711 .19629 L
.44742 .19629 L
.44742 .08012 L
s
.678 .847 .902 r
.44742 .08012 m
.44742 .19605 L
.44758 .19605 L
.44758 .08012 L
F
.2 .63 .79 r
.44742 .08012 m
.44742 .19605 L
.44758 .19605 L
.44758 .08012 L
s
.678 .847 .902 r
.44758 .08012 m
.44758 .19584 L
.44797 .19584 L
.44797 .08012 L
F
.2 .63 .79 r
.44758 .08012 m
.44758 .19584 L
.44797 .19584 L
.44797 .08012 L
s
.678 .847 .902 r
.44797 .08012 m
.44797 .19555 L
.44843 .19555 L
.44843 .08012 L
F
.2 .63 .79 r
.44797 .08012 m
.44797 .19555 L
.44843 .19555 L
.44843 .08012 L
s
.678 .847 .902 r
.44843 .08012 m
.44843 .19533 L
.44869 .19533 L
.44869 .08012 L
F
.2 .63 .79 r
.44843 .08012 m
.44843 .19533 L
.44869 .19533 L
.44869 .08012 L
s
.678 .847 .902 r
.44869 .08012 m
.44869 .19519 L
.44893 .19519 L
.44893 .08012 L
F
.2 .63 .79 r
.44869 .08012 m
.44869 .19519 L
.44893 .19519 L
.44893 .08012 L
s
.678 .847 .902 r
.44893 .08012 m
.44893 .19507 L
.44923 .19507 L
.44923 .08012 L
F
.2 .63 .79 r
.44893 .08012 m
.44893 .19507 L
.44923 .19507 L
.44923 .08012 L
s
.678 .847 .902 r
.44923 .08012 m
.44923 .19468 L
.44964 .19468 L
.44964 .08012 L
F
.2 .63 .79 r
.44923 .08012 m
.44923 .19468 L
.44964 .19468 L
.44964 .08012 L
s
.678 .847 .902 r
.44964 .08012 m
.44964 .19463 L
.44981 .19463 L
.44981 .08012 L
F
.2 .63 .79 r
.44964 .08012 m
.44964 .19463 L
.44981 .19463 L
.44981 .08012 L
s
.678 .847 .902 r
.44981 .08012 m
.44981 .19434 L
.45015 .19434 L
.45015 .08012 L
F
.2 .63 .79 r
.44981 .08012 m
.44981 .19434 L
.45015 .19434 L
.45015 .08012 L
s
.678 .847 .902 r
.45015 .08012 m
.45015 .19429 L
.45045 .19429 L
.45045 .08012 L
F
.2 .63 .79 r
.45015 .08012 m
.45015 .19429 L
.45045 .19429 L
.45045 .08012 L
s
.678 .847 .902 r
.45045 .08012 m
.45045 .19406 L
.4506 .19406 L
.4506 .08012 L
F
.2 .63 .79 r
.45045 .08012 m
.45045 .19406 L
.4506 .19406 L
.4506 .08012 L
s
.678 .847 .902 r
.4506 .08012 m
.4506 .19394 L
.45102 .19394 L
.45102 .08012 L
F
.2 .63 .79 r
.4506 .08012 m
.4506 .19394 L
.45102 .19394 L
.45102 .08012 L
s
.678 .847 .902 r
.45102 .08012 m
.45102 .19364 L
.45123 .19364 L
.45123 .08012 L
F
.2 .63 .79 r
.45102 .08012 m
.45102 .19364 L
.45123 .19364 L
.45123 .08012 L
s
.678 .847 .902 r
.45123 .08012 m
.45123 .19343 L
.45152 .19343 L
.45152 .08012 L
F
.2 .63 .79 r
.45123 .08012 m
.45123 .19343 L
.45152 .19343 L
.45152 .08012 L
s
.678 .847 .902 r
.45152 .08012 m
.45152 .19328 L
.45178 .19328 L
.45178 .08012 L
F
.2 .63 .79 r
.45152 .08012 m
.45152 .19328 L
.45178 .19328 L
.45178 .08012 L
s
.678 .847 .902 r
.45178 .08012 m
.45178 .19295 L
.45212 .19295 L
.45212 .08012 L
F
.2 .63 .79 r
.45178 .08012 m
.45178 .19295 L
.45212 .19295 L
.45212 .08012 L
s
.678 .847 .902 r
.45212 .08012 m
.45212 .19279 L
.45241 .19279 L
.45241 .08012 L
F
.2 .63 .79 r
.45212 .08012 m
.45212 .19279 L
.45241 .19279 L
.45241 .08012 L
s
.678 .847 .902 r
.45241 .08012 m
.45241 .19264 L
.45273 .19264 L
.45273 .08012 L
F
.2 .63 .79 r
.45241 .08012 m
.45241 .19264 L
.45273 .19264 L
.45273 .08012 L
s
.678 .847 .902 r
.45273 .08012 m
.45273 .1924 L
.45315 .1924 L
.45315 .08012 L
F
.2 .63 .79 r
.45273 .08012 m
.45273 .1924 L
.45315 .1924 L
.45315 .08012 L
s
.678 .847 .902 r
.45315 .08012 m
.45315 .19216 L
.45335 .19216 L
.45335 .08012 L
F
.2 .63 .79 r
.45315 .08012 m
.45315 .19216 L
.45335 .19216 L
.45335 .08012 L
s
.678 .847 .902 r
.45335 .08012 m
.45335 .19188 L
.45375 .19188 L
.45375 .08012 L
F
.2 .63 .79 r
.45335 .08012 m
.45335 .19188 L
.45375 .19188 L
.45375 .08012 L
s
.678 .847 .902 r
.45375 .08012 m
.45375 .19183 L
.4539 .19183 L
.4539 .08012 L
F
.2 .63 .79 r
.45375 .08012 m
.45375 .19183 L
.4539 .19183 L
.4539 .08012 L
s
.678 .847 .902 r
.4539 .08012 m
.4539 .1916 L
.45431 .1916 L
.45431 .08012 L
F
.2 .63 .79 r
.4539 .08012 m
.4539 .1916 L
.45431 .1916 L
.45431 .08012 L
s
.678 .847 .902 r
.45431 .08012 m
.45431 .19139 L
.45469 .19139 L
.45469 .08012 L
F
.2 .63 .79 r
.45431 .08012 m
.45431 .19139 L
.45469 .19139 L
.45469 .08012 L
s
.678 .847 .902 r
.45469 .08012 m
.45469 .19097 L
.45507 .19097 L
.45507 .08012 L
F
.2 .63 .79 r
.45469 .08012 m
.45469 .19097 L
.45507 .19097 L
.45507 .08012 L
s
.678 .847 .902 r
.45507 .08012 m
.45507 .19089 L
.45533 .19089 L
.45533 .08012 L
F
.2 .63 .79 r
.45507 .08012 m
.45507 .19089 L
.45533 .19089 L
.45533 .08012 L
s
.678 .847 .902 r
.45533 .08012 m
.45533 .19054 L
.45577 .19054 L
.45577 .08012 L
F
.2 .63 .79 r
.45533 .08012 m
.45533 .19054 L
.45577 .19054 L
.45577 .08012 L
s
.678 .847 .902 r
.45577 .08012 m
.45577 .19038 L
.45604 .19038 L
.45604 .08012 L
F
.2 .63 .79 r
.45577 .08012 m
.45577 .19038 L
.45604 .19038 L
.45604 .08012 L
s
.678 .847 .902 r
.45604 .08012 m
.45604 .19023 L
.45633 .19023 L
.45633 .08012 L
F
.2 .63 .79 r
.45604 .08012 m
.45604 .19023 L
.45633 .19023 L
.45633 .08012 L
s
.678 .847 .902 r
.45633 .08012 m
.45633 .19007 L
.45678 .19007 L
.45678 .08012 L
F
.2 .63 .79 r
.45633 .08012 m
.45633 .19007 L
.45678 .19007 L
.45678 .08012 L
s
.678 .847 .902 r
.45678 .08012 m
.45678 .18968 L
.45696 .18968 L
.45696 .08012 L
F
.2 .63 .79 r
.45678 .08012 m
.45678 .18968 L
.45696 .18968 L
.45696 .08012 L
s
.678 .847 .902 r
.45696 .08012 m
.45696 .1896 L
.4572 .1896 L
.4572 .08012 L
F
.2 .63 .79 r
.45696 .08012 m
.45696 .1896 L
.4572 .1896 L
.4572 .08012 L
s
.678 .847 .902 r
.4572 .08012 m
.4572 .18934 L
.45765 .18934 L
.45765 .08012 L
F
.2 .63 .79 r
.4572 .08012 m
.4572 .18934 L
.45765 .18934 L
.45765 .08012 L
s
.678 .847 .902 r
.45765 .08012 m
.45765 .18919 L
.45795 .18919 L
.45795 .08012 L
F
.2 .63 .79 r
.45765 .08012 m
.45765 .18919 L
.45795 .18919 L
.45795 .08012 L
s
.678 .847 .902 r
.45795 .08012 m
.45795 .18891 L
.45812 .18891 L
.45812 .08012 L
F
.2 .63 .79 r
.45795 .08012 m
.45795 .18891 L
.45812 .18891 L
.45812 .08012 L
s
.678 .847 .902 r
.45812 .08012 m
.45812 .18882 L
.45844 .18882 L
.45844 .08012 L
F
.2 .63 .79 r
.45812 .08012 m
.45812 .18882 L
.45844 .18882 L
.45844 .08012 L
s
.678 .847 .902 r
.45844 .08012 m
.45844 .18862 L
.45882 .18862 L
.45882 .08012 L
F
.2 .63 .79 r
.45844 .08012 m
.45844 .18862 L
.45882 .18862 L
.45882 .08012 L
s
.678 .847 .902 r
.45882 .08012 m
.45882 .18837 L
.45898 .18837 L
.45898 .08012 L
F
.2 .63 .79 r
.45882 .08012 m
.45882 .18837 L
.45898 .18837 L
.45898 .08012 L
s
.678 .847 .902 r
.45898 .08012 m
.45898 .18821 L
.45938 .18821 L
.45938 .08012 L
F
.2 .63 .79 r
.45898 .08012 m
.45898 .18821 L
.45938 .18821 L
.45938 .08012 L
s
.678 .847 .902 r
.45938 .08012 m
.45938 .18792 L
.45985 .18792 L
.45985 .08012 L
F
.2 .63 .79 r
.45938 .08012 m
.45938 .18792 L
.45985 .18792 L
.45985 .08012 L
s
.678 .847 .902 r
.45985 .08012 m
.45985 .18766 L
.46009 .18766 L
.46009 .08012 L
F
.2 .63 .79 r
.45985 .08012 m
.45985 .18766 L
.46009 .18766 L
.46009 .08012 L
s
.678 .847 .902 r
.46009 .08012 m
.46009 .18735 L
.46043 .18735 L
.46043 .08012 L
F
.2 .63 .79 r
.46009 .08012 m
.46009 .18735 L
.46043 .18735 L
.46043 .08012 L
s
.678 .847 .902 r
.46043 .08012 m
.46043 .18705 L
.4609 .18705 L
.4609 .08012 L
F
.2 .63 .79 r
.46043 .08012 m
.46043 .18705 L
.4609 .18705 L
.4609 .08012 L
s
.678 .847 .902 r
.4609 .08012 m
.4609 .18681 L
.46131 .18681 L
.46131 .08012 L
F
.2 .63 .79 r
.4609 .08012 m
.4609 .18681 L
.46131 .18681 L
.46131 .08012 L
s
.678 .847 .902 r
.46131 .08012 m
.46131 .18662 L
.46165 .18662 L
.46165 .08012 L
F
.2 .63 .79 r
.46131 .08012 m
.46131 .18662 L
.46165 .18662 L
.46165 .08012 L
s
.678 .847 .902 r
.46165 .08012 m
.46165 .18633 L
.46199 .18633 L
.46199 .08012 L
F
.2 .63 .79 r
.46165 .08012 m
.46165 .18633 L
.46199 .18633 L
.46199 .08012 L
s
.678 .847 .902 r
.46199 .08012 m
.46199 .18624 L
.4622 .18624 L
.4622 .08012 L
F
.2 .63 .79 r
.46199 .08012 m
.46199 .18624 L
.4622 .18624 L
.4622 .08012 L
s
.678 .847 .902 r
.4622 .08012 m
.4622 .1861 L
.46238 .1861 L
.46238 .08012 L
F
.2 .63 .79 r
.4622 .08012 m
.4622 .1861 L
.46238 .1861 L
.46238 .08012 L
s
.678 .847 .902 r
.46238 .08012 m
.46238 .18584 L
.46283 .18584 L
.46283 .08012 L
F
.2 .63 .79 r
.46238 .08012 m
.46238 .18584 L
.46283 .18584 L
.46283 .08012 L
s
.678 .847 .902 r
.46283 .08012 m
.46283 .18566 L
.46305 .18566 L
.46305 .08012 L
F
.2 .63 .79 r
.46283 .08012 m
.46283 .18566 L
.46305 .18566 L
.46305 .08012 L
s
.678 .847 .902 r
.46305 .08012 m
.46305 .18548 L
.46331 .18548 L
.46331 .08012 L
F
.2 .63 .79 r
.46305 .08012 m
.46305 .18548 L
.46331 .18548 L
.46331 .08012 L
s
.678 .847 .902 r
.46331 .08012 m
.46331 .18515 L
.46372 .18515 L
.46372 .08012 L
F
.2 .63 .79 r
.46331 .08012 m
.46331 .18515 L
.46372 .18515 L
.46372 .08012 L
s
.678 .847 .902 r
.46372 .08012 m
.46372 .18507 L
.46402 .18507 L
.46402 .08012 L
F
.2 .63 .79 r
.46372 .08012 m
.46372 .18507 L
.46402 .18507 L
.46402 .08012 L
s
.678 .847 .902 r
.46402 .08012 m
.46402 .18486 L
.46428 .18486 L
.46428 .08012 L
F
.2 .63 .79 r
.46402 .08012 m
.46402 .18486 L
.46428 .18486 L
.46428 .08012 L
s
.678 .847 .902 r
.46428 .08012 m
.46428 .18466 L
.46452 .18466 L
.46452 .08012 L
F
.2 .63 .79 r
.46428 .08012 m
.46428 .18466 L
.46452 .18466 L
.46452 .08012 L
s
.678 .847 .902 r
.46452 .08012 m
.46452 .1845 L
.46483 .1845 L
.46483 .08012 L
F
.2 .63 .79 r
.46452 .08012 m
.46452 .1845 L
.46483 .1845 L
.46483 .08012 L
s
.678 .847 .902 r
.46483 .08012 m
.46483 .18422 L
.46518 .18422 L
.46518 .08012 L
F
.2 .63 .79 r
.46483 .08012 m
.46483 .18422 L
.46518 .18422 L
.46518 .08012 L
s
.678 .847 .902 r
.46518 .08012 m
.46518 .18405 L
.46564 .18405 L
.46564 .08012 L
F
.2 .63 .79 r
.46518 .08012 m
.46518 .18405 L
.46564 .18405 L
.46564 .08012 L
s
.678 .847 .902 r
.46564 .08012 m
.46564 .18374 L
.46585 .18374 L
.46585 .08012 L
F
.2 .63 .79 r
.46564 .08012 m
.46564 .18374 L
.46585 .18374 L
.46585 .08012 L
s
.678 .847 .902 r
.46585 .08012 m
.46585 .18367 L
.46633 .18367 L
.46633 .08012 L
F
.2 .63 .79 r
.46585 .08012 m
.46585 .18367 L
.46633 .18367 L
.46633 .08012 L
s
.678 .847 .902 r
.46633 .08012 m
.46633 .18322 L
.46678 .18322 L
.46678 .08012 L
F
.2 .63 .79 r
.46633 .08012 m
.46633 .18322 L
.46678 .18322 L
.46678 .08012 L
s
.678 .847 .902 r
.46678 .08012 m
.46678 .18283 L
.46723 .18283 L
.46723 .08012 L
F
.2 .63 .79 r
.46678 .08012 m
.46678 .18283 L
.46723 .18283 L
.46723 .08012 L
s
.678 .847 .902 r
.46723 .08012 m
.46723 .18271 L
.46753 .18271 L
.46753 .08012 L
F
.2 .63 .79 r
.46723 .08012 m
.46723 .18271 L
.46753 .18271 L
.46753 .08012 L
s
.678 .847 .902 r
.46753 .08012 m
.46753 .18253 L
.4677 .18253 L
.4677 .08012 L
F
.2 .63 .79 r
.46753 .08012 m
.46753 .18253 L
.4677 .18253 L
.4677 .08012 L
s
.678 .847 .902 r
.4677 .08012 m
.4677 .18246 L
.46805 .18246 L
.46805 .08012 L
F
.2 .63 .79 r
.4677 .08012 m
.4677 .18246 L
.46805 .18246 L
.46805 .08012 L
s
.678 .847 .902 r
.46805 .08012 m
.46805 .18227 L
.46831 .18227 L
.46831 .08012 L
F
.2 .63 .79 r
.46805 .08012 m
.46805 .18227 L
.46831 .18227 L
.46831 .08012 L
s
.678 .847 .902 r
.46831 .08012 m
.46831 .18197 L
.46863 .18197 L
.46863 .08012 L
F
.2 .63 .79 r
.46831 .08012 m
.46831 .18197 L
.46863 .18197 L
.46863 .08012 L
s
.678 .847 .902 r
.46863 .08012 m
.46863 .18188 L
.46888 .18188 L
.46888 .08012 L
F
.2 .63 .79 r
.46863 .08012 m
.46863 .18188 L
.46888 .18188 L
.46888 .08012 L
s
.678 .847 .902 r
.46888 .08012 m
.46888 .18166 L
.46904 .18166 L
.46904 .08012 L
F
.2 .63 .79 r
.46888 .08012 m
.46888 .18166 L
.46904 .18166 L
.46904 .08012 L
s
.678 .847 .902 r
.46904 .08012 m
.46904 .18157 L
.46946 .18157 L
.46946 .08012 L
F
.2 .63 .79 r
.46904 .08012 m
.46904 .18157 L
.46946 .18157 L
.46946 .08012 L
s
.678 .847 .902 r
.46946 .08012 m
.46946 .18131 L
.46972 .18131 L
.46972 .08012 L
F
.2 .63 .79 r
.46946 .08012 m
.46946 .18131 L
.46972 .18131 L
.46972 .08012 L
s
.678 .847 .902 r
.46972 .08012 m
.46972 .1811 L
.46993 .1811 L
.46993 .08012 L
F
.2 .63 .79 r
.46972 .08012 m
.46972 .1811 L
.46993 .1811 L
.46993 .08012 L
s
.678 .847 .902 r
.46993 .08012 m
.46993 .18103 L
.47014 .18103 L
.47014 .08012 L
F
.2 .63 .79 r
.46993 .08012 m
.46993 .18103 L
.47014 .18103 L
.47014 .08012 L
s
.678 .847 .902 r
.47014 .08012 m
.47014 .18076 L
.47048 .18076 L
.47048 .08012 L
F
.2 .63 .79 r
.47014 .08012 m
.47014 .18076 L
.47048 .18076 L
.47048 .08012 L
s
.678 .847 .902 r
.47048 .08012 m
.47048 .18062 L
.47063 .18062 L
.47063 .08012 L
F
.2 .63 .79 r
.47048 .08012 m
.47048 .18062 L
.47063 .18062 L
.47063 .08012 L
s
.678 .847 .902 r
.47063 .08012 m
.47063 .18046 L
.47093 .18046 L
.47093 .08012 L
F
.2 .63 .79 r
.47063 .08012 m
.47063 .18046 L
.47093 .18046 L
.47093 .08012 L
s
.678 .847 .902 r
.47093 .08012 m
.47093 .18021 L
.47133 .18021 L
.47133 .08012 L
F
.2 .63 .79 r
.47093 .08012 m
.47093 .18021 L
.47133 .18021 L
.47133 .08012 L
s
.678 .847 .902 r
.47133 .08012 m
.47133 .1801 L
.47155 .1801 L
.47155 .08012 L
F
.2 .63 .79 r
.47133 .08012 m
.47133 .1801 L
.47155 .1801 L
.47155 .08012 L
s
.678 .847 .902 r
.47155 .08012 m
.47155 .17975 L
.47195 .17975 L
.47195 .08012 L
F
.2 .63 .79 r
.47155 .08012 m
.47155 .17975 L
.47195 .17975 L
.47195 .08012 L
s
.678 .847 .902 r
.47195 .08012 m
.47195 .17969 L
.47244 .17969 L
.47244 .08012 L
F
.2 .63 .79 r
.47195 .08012 m
.47195 .17969 L
.47244 .17969 L
.47244 .08012 L
s
.678 .847 .902 r
.47244 .08012 m
.47244 .17929 L
.47264 .17929 L
.47264 .08012 L
F
.2 .63 .79 r
.47244 .08012 m
.47244 .17929 L
.47264 .17929 L
.47264 .08012 L
s
.678 .847 .902 r
.47264 .08012 m
.47264 .17914 L
.47289 .17914 L
.47289 .08012 L
F
.2 .63 .79 r
.47264 .08012 m
.47264 .17914 L
.47289 .17914 L
.47289 .08012 L
s
.678 .847 .902 r
.47289 .08012 m
.47289 .17889 L
.47323 .17889 L
.47323 .08012 L
F
.2 .63 .79 r
.47289 .08012 m
.47289 .17889 L
.47323 .17889 L
.47323 .08012 L
s
.678 .847 .902 r
.47323 .08012 m
.47323 .17879 L
.47338 .17879 L
.47338 .08012 L
F
.2 .63 .79 r
.47323 .08012 m
.47323 .17879 L
.47338 .17879 L
.47338 .08012 L
s
.678 .847 .902 r
.47338 .08012 m
.47338 .17875 L
.47362 .17875 L
.47362 .08012 L
F
.2 .63 .79 r
.47338 .08012 m
.47338 .17875 L
.47362 .17875 L
.47362 .08012 L
s
.678 .847 .902 r
.47362 .08012 m
.47362 .17847 L
.47392 .17847 L
.47392 .08012 L
F
.2 .63 .79 r
.47362 .08012 m
.47362 .17847 L
.47392 .17847 L
.47392 .08012 L
s
.678 .847 .902 r
.47392 .08012 m
.47392 .17838 L
.4741 .17838 L
.4741 .08012 L
F
.2 .63 .79 r
.47392 .08012 m
.47392 .17838 L
.4741 .17838 L
.4741 .08012 L
s
.678 .847 .902 r
.4741 .08012 m
.4741 .17829 L
.47458 .17829 L
.47458 .08012 L
F
.2 .63 .79 r
.4741 .08012 m
.4741 .17829 L
.47458 .17829 L
.47458 .08012 L
s
.678 .847 .902 r
.47458 .08012 m
.47458 .17776 L
.47495 .17776 L
.47495 .08012 L
F
.2 .63 .79 r
.47458 .08012 m
.47458 .17776 L
.47495 .17776 L
.47495 .08012 L
s
.678 .847 .902 r
.47495 .08012 m
.47495 .17766 L
.47515 .17766 L
.47515 .08012 L
F
.2 .63 .79 r
.47495 .08012 m
.47495 .17766 L
.47515 .17766 L
.47515 .08012 L
s
.678 .847 .902 r
.47515 .08012 m
.47515 .17746 L
.4755 .17746 L
.4755 .08012 L
F
.2 .63 .79 r
.47515 .08012 m
.47515 .17746 L
.4755 .17746 L
.4755 .08012 L
s
.678 .847 .902 r
.4755 .08012 m
.4755 .17715 L
.47588 .17715 L
.47588 .08012 L
F
.2 .63 .79 r
.4755 .08012 m
.4755 .17715 L
.47588 .17715 L
.47588 .08012 L
s
.678 .847 .902 r
.47588 .08012 m
.47588 .17708 L
.47624 .17708 L
.47624 .08012 L
F
.2 .63 .79 r
.47588 .08012 m
.47588 .17708 L
.47624 .17708 L
.47624 .08012 L
s
.678 .847 .902 r
.47624 .08012 m
.47624 .17682 L
.47651 .17682 L
.47651 .08012 L
F
.2 .63 .79 r
.47624 .08012 m
.47624 .17682 L
.47651 .17682 L
.47651 .08012 L
s
.678 .847 .902 r
.47651 .08012 m
.47651 .17666 L
.47675 .17666 L
.47675 .08012 L
F
.2 .63 .79 r
.47651 .08012 m
.47651 .17666 L
.47675 .17666 L
.47675 .08012 L
s
.678 .847 .902 r
.47675 .08012 m
.47675 .1765 L
.47706 .1765 L
.47706 .08012 L
F
.2 .63 .79 r
.47675 .08012 m
.47675 .1765 L
.47706 .1765 L
.47706 .08012 L
s
.678 .847 .902 r
.47706 .08012 m
.47706 .17632 L
.47735 .17632 L
.47735 .08012 L
F
.2 .63 .79 r
.47706 .08012 m
.47706 .17632 L
.47735 .17632 L
.47735 .08012 L
s
.678 .847 .902 r
.47735 .08012 m
.47735 .17593 L
.47778 .17593 L
.47778 .08012 L
F
.2 .63 .79 r
.47735 .08012 m
.47735 .17593 L
.47778 .17593 L
.47778 .08012 L
s
.678 .847 .902 r
.47778 .08012 m
.47778 .17577 L
.47802 .17577 L
.47802 .08012 L
F
.2 .63 .79 r
.47778 .08012 m
.47778 .17577 L
.47802 .17577 L
.47802 .08012 L
s
.678 .847 .902 r
.47802 .08012 m
.47802 .17567 L
.47818 .17567 L
.47818 .08012 L
F
.2 .63 .79 r
.47802 .08012 m
.47802 .17567 L
.47818 .17567 L
.47818 .08012 L
s
.678 .847 .902 r
.47818 .08012 m
.47818 .17549 L
.47857 .17549 L
.47857 .08012 L
F
.2 .63 .79 r
.47818 .08012 m
.47818 .17549 L
.47857 .17549 L
.47857 .08012 L
s
.678 .847 .902 r
.47857 .08012 m
.47857 .17523 L
.47892 .17523 L
.47892 .08012 L
F
.2 .63 .79 r
.47857 .08012 m
.47857 .17523 L
.47892 .17523 L
.47892 .08012 L
s
.678 .847 .902 r
.47892 .08012 m
.47892 .17515 L
.47925 .17515 L
.47925 .08012 L
F
.2 .63 .79 r
.47892 .08012 m
.47892 .17515 L
.47925 .17515 L
.47925 .08012 L
s
.678 .847 .902 r
.47925 .08012 m
.47925 .17488 L
.47942 .17488 L
.47942 .08012 L
F
.2 .63 .79 r
.47925 .08012 m
.47925 .17488 L
.47942 .17488 L
.47942 .08012 L
s
.678 .847 .902 r
.47942 .08012 m
.47942 .17468 L
.47976 .17468 L
.47976 .08012 L
F
.2 .63 .79 r
.47942 .08012 m
.47942 .17468 L
.47976 .17468 L
.47976 .08012 L
s
.678 .847 .902 r
.47976 .08012 m
.47976 .17464 L
.48 .17464 L
.48 .08012 L
F
.2 .63 .79 r
.47976 .08012 m
.47976 .17464 L
.48 .17464 L
.48 .08012 L
s
.678 .847 .902 r
.48 .08012 m
.48 .17442 L
.48048 .17442 L
.48048 .08012 L
F
.2 .63 .79 r
.48 .08012 m
.48 .17442 L
.48048 .17442 L
.48048 .08012 L
s
.678 .847 .902 r
.48048 .08012 m
.48048 .17408 L
.48064 .17408 L
.48064 .08012 L
F
.2 .63 .79 r
.48048 .08012 m
.48048 .17408 L
.48064 .17408 L
.48064 .08012 L
s
.678 .847 .902 r
.48064 .08012 m
.48064 .17397 L
.4809 .17397 L
.4809 .08012 L
F
.2 .63 .79 r
.48064 .08012 m
.48064 .17397 L
.4809 .17397 L
.4809 .08012 L
s
.678 .847 .902 r
.4809 .08012 m
.4809 .17384 L
.48134 .17384 L
.48134 .08012 L
F
.2 .63 .79 r
.4809 .08012 m
.4809 .17384 L
.48134 .17384 L
.48134 .08012 L
s
.678 .847 .902 r
.48134 .08012 m
.48134 .17339 L
.48178 .17339 L
.48178 .08012 L
F
.2 .63 .79 r
.48134 .08012 m
.48134 .17339 L
.48178 .17339 L
.48178 .08012 L
s
.678 .847 .902 r
.48178 .08012 m
.48178 .17324 L
.48195 .17324 L
.48195 .08012 L
F
.2 .63 .79 r
.48178 .08012 m
.48178 .17324 L
.48195 .17324 L
.48195 .08012 L
s
.678 .847 .902 r
.48195 .08012 m
.48195 .17308 L
.48232 .17308 L
.48232 .08012 L
F
.2 .63 .79 r
.48195 .08012 m
.48195 .17308 L
.48232 .17308 L
.48232 .08012 L
s
.678 .847 .902 r
.48232 .08012 m
.48232 .17287 L
.48272 .17287 L
.48272 .08012 L
F
.2 .63 .79 r
.48232 .08012 m
.48232 .17287 L
.48272 .17287 L
.48272 .08012 L
s
.678 .847 .902 r
.48272 .08012 m
.48272 .17273 L
.48295 .17273 L
.48295 .08012 L
F
.2 .63 .79 r
.48272 .08012 m
.48272 .17273 L
.48295 .17273 L
.48295 .08012 L
s
.678 .847 .902 r
.48295 .08012 m
.48295 .17242 L
.48324 .17242 L
.48324 .08012 L
F
.2 .63 .79 r
.48295 .08012 m
.48295 .17242 L
.48324 .17242 L
.48324 .08012 L
s
.678 .847 .902 r
.48324 .08012 m
.48324 .17237 L
.48341 .17237 L
.48341 .08012 L
F
.2 .63 .79 r
.48324 .08012 m
.48324 .17237 L
.48341 .17237 L
.48341 .08012 L
s
.678 .847 .902 r
.48341 .08012 m
.48341 .17214 L
.48368 .17214 L
.48368 .08012 L
F
.2 .63 .79 r
.48341 .08012 m
.48341 .17214 L
.48368 .17214 L
.48368 .08012 L
s
.678 .847 .902 r
.48368 .08012 m
.48368 .17196 L
.48417 .17196 L
.48417 .08012 L
F
.2 .63 .79 r
.48368 .08012 m
.48368 .17196 L
.48417 .17196 L
.48417 .08012 L
s
.678 .847 .902 r
.48417 .08012 m
.48417 .17167 L
.48463 .17167 L
.48463 .08012 L
F
.2 .63 .79 r
.48417 .08012 m
.48417 .17167 L
.48463 .17167 L
.48463 .08012 L
s
.678 .847 .902 r
.48463 .08012 m
.48463 .17152 L
.48499 .17152 L
.48499 .08012 L
F
.2 .63 .79 r
.48463 .08012 m
.48463 .17152 L
.48499 .17152 L
.48499 .08012 L
s
.678 .847 .902 r
.48499 .08012 m
.48499 .17108 L
.48533 .17108 L
.48533 .08012 L
F
.2 .63 .79 r
.48499 .08012 m
.48499 .17108 L
.48533 .17108 L
.48533 .08012 L
s
.678 .847 .902 r
.48533 .08012 m
.48533 .17093 L
.48573 .17093 L
.48573 .08012 L
F
.2 .63 .79 r
.48533 .08012 m
.48533 .17093 L
.48573 .17093 L
.48573 .08012 L
s
.678 .847 .902 r
.48573 .08012 m
.48573 .17064 L
.48617 .17064 L
.48617 .08012 L
F
.2 .63 .79 r
.48573 .08012 m
.48573 .17064 L
.48617 .17064 L
.48617 .08012 L
s
.678 .847 .902 r
.48617 .08012 m
.48617 .17043 L
.48665 .17043 L
.48665 .08012 L
F
.2 .63 .79 r
.48617 .08012 m
.48617 .17043 L
.48665 .17043 L
.48665 .08012 L
s
.678 .847 .902 r
.48665 .08012 m
.48665 .17018 L
.48712 .17018 L
.48712 .08012 L
F
.2 .63 .79 r
.48665 .08012 m
.48665 .17018 L
.48712 .17018 L
.48712 .08012 L
s
.678 .847 .902 r
.48712 .08012 m
.48712 .16987 L
.48734 .16987 L
.48734 .08012 L
F
.2 .63 .79 r
.48712 .08012 m
.48712 .16987 L
.48734 .16987 L
.48734 .08012 L
s
.678 .847 .902 r
.48734 .08012 m
.48734 .16957 L
.48777 .16957 L
.48777 .08012 L
F
.2 .63 .79 r
.48734 .08012 m
.48734 .16957 L
.48777 .16957 L
.48777 .08012 L
s
.678 .847 .902 r
.48777 .08012 m
.48777 .16943 L
.48805 .16943 L
.48805 .08012 L
F
.2 .63 .79 r
.48777 .08012 m
.48777 .16943 L
.48805 .16943 L
.48805 .08012 L
s
.678 .847 .902 r
.48805 .08012 m
.48805 .16931 L
.48843 .16931 L
.48843 .08012 L
F
.2 .63 .79 r
.48805 .08012 m
.48805 .16931 L
.48843 .16931 L
.48843 .08012 L
s
.678 .847 .902 r
.48843 .08012 m
.48843 .16907 L
.48866 .16907 L
.48866 .08012 L
F
.2 .63 .79 r
.48843 .08012 m
.48843 .16907 L
.48866 .16907 L
.48866 .08012 L
s
.678 .847 .902 r
.48866 .08012 m
.48866 .16873 L
.48907 .16873 L
.48907 .08012 L
F
.2 .63 .79 r
.48866 .08012 m
.48866 .16873 L
.48907 .16873 L
.48907 .08012 L
s
.678 .847 .902 r
.48907 .08012 m
.48907 .1686 L
.48925 .1686 L
.48925 .08012 L
F
.2 .63 .79 r
.48907 .08012 m
.48907 .1686 L
.48925 .1686 L
.48925 .08012 L
s
.678 .847 .902 r
.48925 .08012 m
.48925 .16835 L
.48968 .16835 L
.48968 .08012 L
F
.2 .63 .79 r
.48925 .08012 m
.48925 .16835 L
.48968 .16835 L
.48968 .08012 L
s
.678 .847 .902 r
.48968 .08012 m
.48968 .16825 L
.48996 .16825 L
.48996 .08012 L
F
.2 .63 .79 r
.48968 .08012 m
.48968 .16825 L
.48996 .16825 L
.48996 .08012 L
s
.678 .847 .902 r
.48996 .08012 m
.48996 .1679 L
.49035 .1679 L
.49035 .08012 L
F
.2 .63 .79 r
.48996 .08012 m
.48996 .1679 L
.49035 .1679 L
.49035 .08012 L
s
.678 .847 .902 r
.49035 .08012 m
.49035 .16785 L
.49065 .16785 L
.49065 .08012 L
F
.2 .63 .79 r
.49035 .08012 m
.49035 .16785 L
.49065 .16785 L
.49065 .08012 L
s
.678 .847 .902 r
.49065 .08012 m
.49065 .16766 L
.49082 .16766 L
.49082 .08012 L
F
.2 .63 .79 r
.49065 .08012 m
.49065 .16766 L
.49082 .16766 L
.49082 .08012 L
s
.678 .847 .902 r
.49082 .08012 m
.49082 .16755 L
.49102 .16755 L
.49102 .08012 L
F
.2 .63 .79 r
.49082 .08012 m
.49082 .16755 L
.49102 .16755 L
.49102 .08012 L
s
.678 .847 .902 r
.49102 .08012 m
.49102 .16746 L
.49127 .16746 L
.49127 .08012 L
F
.2 .63 .79 r
.49102 .08012 m
.49102 .16746 L
.49127 .16746 L
.49127 .08012 L
s
.678 .847 .902 r
.49127 .08012 m
.49127 .16716 L
.49155 .16716 L
.49155 .08012 L
F
.2 .63 .79 r
.49127 .08012 m
.49127 .16716 L
.49155 .16716 L
.49155 .08012 L
s
.678 .847 .902 r
.49155 .08012 m
.49155 .16702 L
.49195 .16702 L
.49195 .08012 L
F
.2 .63 .79 r
.49155 .08012 m
.49155 .16702 L
.49195 .16702 L
.49195 .08012 L
s
.678 .847 .902 r
.49195 .08012 m
.49195 .16679 L
.49215 .16679 L
.49215 .08012 L
F
.2 .63 .79 r
.49195 .08012 m
.49195 .16679 L
.49215 .16679 L
.49215 .08012 L
s
.678 .847 .902 r
.49215 .08012 m
.49215 .16666 L
.49244 .16666 L
.49244 .08012 L
F
.2 .63 .79 r
.49215 .08012 m
.49215 .16666 L
.49244 .16666 L
.49244 .08012 L
s
.678 .847 .902 r
.49244 .08012 m
.49244 .16636 L
.49283 .16636 L
.49283 .08012 L
F
.2 .63 .79 r
.49244 .08012 m
.49244 .16636 L
.49283 .16636 L
.49283 .08012 L
s
.678 .847 .902 r
.49283 .08012 m
.49283 .16626 L
.49304 .16626 L
.49304 .08012 L
F
.2 .63 .79 r
.49283 .08012 m
.49283 .16626 L
.49304 .16626 L
.49304 .08012 L
s
.678 .847 .902 r
.49304 .08012 m
.49304 .16616 L
.49334 .16616 L
.49334 .08012 L
F
.2 .63 .79 r
.49304 .08012 m
.49304 .16616 L
.49334 .16616 L
.49334 .08012 L
s
.678 .847 .902 r
.49334 .08012 m
.49334 .16582 L
.49367 .16582 L
.49367 .08012 L
F
.2 .63 .79 r
.49334 .08012 m
.49334 .16582 L
.49367 .16582 L
.49367 .08012 L
s
.678 .847 .902 r
.49367 .08012 m
.49367 .16567 L
.49409 .16567 L
.49409 .08012 L
F
.2 .63 .79 r
.49367 .08012 m
.49367 .16567 L
.49409 .16567 L
.49409 .08012 L
s
.678 .847 .902 r
.49409 .08012 m
.49409 .1655 L
.49431 .1655 L
.49431 .08012 L
F
.2 .63 .79 r
.49409 .08012 m
.49409 .1655 L
.49431 .1655 L
.49431 .08012 L
s
.678 .847 .902 r
.49431 .08012 m
.49431 .16529 L
.49454 .16529 L
.49454 .08012 L
F
.2 .63 .79 r
.49431 .08012 m
.49431 .16529 L
.49454 .16529 L
.49454 .08012 L
s
.678 .847 .902 r
.49454 .08012 m
.49454 .16524 L
.49494 .16524 L
.49494 .08012 L
F
.2 .63 .79 r
.49454 .08012 m
.49454 .16524 L
.49494 .16524 L
.49494 .08012 L
s
.678 .847 .902 r
.49494 .08012 m
.49494 .16484 L
.49522 .16484 L
.49522 .08012 L
F
.2 .63 .79 r
.49494 .08012 m
.49494 .16484 L
.49522 .16484 L
.49522 .08012 L
s
.678 .847 .902 r
.49522 .08012 m
.49522 .1648 L
.49556 .1648 L
.49556 .08012 L
F
.2 .63 .79 r
.49522 .08012 m
.49522 .1648 L
.49556 .1648 L
.49556 .08012 L
s
.678 .847 .902 r
.49556 .08012 m
.49556 .16457 L
.49571 .16457 L
.49571 .08012 L
F
.2 .63 .79 r
.49556 .08012 m
.49556 .16457 L
.49571 .16457 L
.49571 .08012 L
s
.678 .847 .902 r
.49571 .08012 m
.49571 .16446 L
.49619 .16446 L
.49619 .08012 L
F
.2 .63 .79 r
.49571 .08012 m
.49571 .16446 L
.49619 .16446 L
.49619 .08012 L
s
.678 .847 .902 r
.49619 .08012 m
.49619 .16422 L
.49644 .16422 L
.49644 .08012 L
F
.2 .63 .79 r
.49619 .08012 m
.49619 .16422 L
.49644 .16422 L
.49644 .08012 L
s
.678 .847 .902 r
.49644 .08012 m
.49644 .164 L
.49684 .164 L
.49684 .08012 L
F
.2 .63 .79 r
.49644 .08012 m
.49644 .164 L
.49684 .164 L
.49684 .08012 L
s
.678 .847 .902 r
.49684 .08012 m
.49684 .16378 L
.4972 .16378 L
.4972 .08012 L
F
.2 .63 .79 r
.49684 .08012 m
.49684 .16378 L
.4972 .16378 L
.4972 .08012 L
s
.678 .847 .902 r
.4972 .08012 m
.4972 .16356 L
.49743 .16356 L
.49743 .08012 L
F
.2 .63 .79 r
.4972 .08012 m
.4972 .16356 L
.49743 .16356 L
.49743 .08012 L
s
.678 .847 .902 r
.49743 .08012 m
.49743 .16321 L
.49788 .16321 L
.49788 .08012 L
F
.2 .63 .79 r
.49743 .08012 m
.49743 .16321 L
.49788 .16321 L
.49788 .08012 L
s
.678 .847 .902 r
.49788 .08012 m
.49788 .16297 L
.49825 .16297 L
.49825 .08012 L
F
.2 .63 .79 r
.49788 .08012 m
.49788 .16297 L
.49825 .16297 L
.49825 .08012 L
s
.678 .847 .902 r
.49825 .08012 m
.49825 .16278 L
.49856 .16278 L
.49856 .08012 L
F
.2 .63 .79 r
.49825 .08012 m
.49825 .16278 L
.49856 .16278 L
.49856 .08012 L
s
.678 .847 .902 r
.49856 .08012 m
.49856 .16269 L
.49903 .16269 L
.49903 .08012 L
F
.2 .63 .79 r
.49856 .08012 m
.49856 .16269 L
.49903 .16269 L
.49903 .08012 L
s
.678 .847 .902 r
.49903 .08012 m
.49903 .16246 L
.49936 .16246 L
.49936 .08012 L
F
.2 .63 .79 r
.49903 .08012 m
.49903 .16246 L
.49936 .16246 L
.49936 .08012 L
s
.678 .847 .902 r
.49936 .08012 m
.49936 .16213 L
.49982 .16213 L
.49982 .08012 L
F
.2 .63 .79 r
.49936 .08012 m
.49936 .16213 L
.49982 .16213 L
.49982 .08012 L
s
.678 .847 .902 r
.49982 .08012 m
.49982 .16196 L
.50008 .16196 L
.50008 .08012 L
F
.2 .63 .79 r
.49982 .08012 m
.49982 .16196 L
.50008 .16196 L
.50008 .08012 L
s
.678 .847 .902 r
.50008 .08012 m
.50008 .16167 L
.50041 .16167 L
.50041 .08012 L
F
.2 .63 .79 r
.50008 .08012 m
.50008 .16167 L
.50041 .16167 L
.50041 .08012 L
s
.678 .847 .902 r
.50041 .08012 m
.50041 .16157 L
.50083 .16157 L
.50083 .08012 L
F
.2 .63 .79 r
.50041 .08012 m
.50041 .16157 L
.50083 .16157 L
.50083 .08012 L
s
.678 .847 .902 r
.50083 .08012 m
.50083 .16112 L
.50124 .16112 L
.50124 .08012 L
F
.2 .63 .79 r
.50083 .08012 m
.50083 .16112 L
.50124 .16112 L
.50124 .08012 L
s
.678 .847 .902 r
.50124 .08012 m
.50124 .16086 L
.50168 .16086 L
.50168 .08012 L
F
.2 .63 .79 r
.50124 .08012 m
.50124 .16086 L
.50168 .16086 L
.50168 .08012 L
s
.678 .847 .902 r
.50168 .08012 m
.50168 .16075 L
.50183 .16075 L
.50183 .08012 L
F
.2 .63 .79 r
.50168 .08012 m
.50168 .16075 L
.50183 .16075 L
.50183 .08012 L
s
.678 .847 .902 r
.50183 .08012 m
.50183 .16068 L
.50198 .16068 L
.50198 .08012 L
F
.2 .63 .79 r
.50183 .08012 m
.50183 .16068 L
.50198 .16068 L
.50198 .08012 L
s
.678 .847 .902 r
.50198 .08012 m
.50198 .16052 L
.50231 .16052 L
.50231 .08012 L
F
.2 .63 .79 r
.50198 .08012 m
.50198 .16052 L
.50231 .16052 L
.50231 .08012 L
s
.678 .847 .902 r
.50231 .08012 m
.50231 .16042 L
.50267 .16042 L
.50267 .08012 L
F
.2 .63 .79 r
.50231 .08012 m
.50231 .16042 L
.50267 .16042 L
.50267 .08012 L
s
.678 .847 .902 r
.50267 .08012 m
.50267 .16011 L
.50292 .16011 L
.50292 .08012 L
F
.2 .63 .79 r
.50267 .08012 m
.50267 .16011 L
.50292 .16011 L
.50292 .08012 L
s
.678 .847 .902 r
.50292 .08012 m
.50292 .15992 L
.50328 .15992 L
.50328 .08012 L
F
.2 .63 .79 r
.50292 .08012 m
.50292 .15992 L
.50328 .15992 L
.50328 .08012 L
s
.678 .847 .902 r
.50328 .08012 m
.50328 .15971 L
.50376 .15971 L
.50376 .08012 L
F
.2 .63 .79 r
.50328 .08012 m
.50328 .15971 L
.50376 .15971 L
.50376 .08012 L
s
.678 .847 .902 r
.50376 .08012 m
.50376 .15944 L
.50413 .15944 L
.50413 .08012 L
F
.2 .63 .79 r
.50376 .08012 m
.50376 .15944 L
.50413 .15944 L
.50413 .08012 L
s
.678 .847 .902 r
.50413 .08012 m
.50413 .15925 L
.50439 .15925 L
.50439 .08012 L
F
.2 .63 .79 r
.50413 .08012 m
.50413 .15925 L
.50439 .15925 L
.50439 .08012 L
s
.678 .847 .902 r
.50439 .08012 m
.50439 .15908 L
.50464 .15908 L
.50464 .08012 L
F
.2 .63 .79 r
.50439 .08012 m
.50439 .15908 L
.50464 .15908 L
.50464 .08012 L
s
.678 .847 .902 r
.50464 .08012 m
.50464 .15899 L
.50487 .15899 L
.50487 .08012 L
F
.2 .63 .79 r
.50464 .08012 m
.50464 .15899 L
.50487 .15899 L
.50487 .08012 L
s
.678 .847 .902 r
.50487 .08012 m
.50487 .15884 L
.50502 .15884 L
.50502 .08012 L
F
.2 .63 .79 r
.50487 .08012 m
.50487 .15884 L
.50502 .15884 L
.50502 .08012 L
s
.678 .847 .902 r
.50502 .08012 m
.50502 .15875 L
.5052 .15875 L
.5052 .08012 L
F
.2 .63 .79 r
.50502 .08012 m
.50502 .15875 L
.5052 .15875 L
.5052 .08012 L
s
.678 .847 .902 r
.5052 .08012 m
.5052 .15855 L
.5055 .15855 L
.5055 .08012 L
F
.2 .63 .79 r
.5052 .08012 m
.5052 .15855 L
.5055 .15855 L
.5055 .08012 L
s
.678 .847 .902 r
.5055 .08012 m
.5055 .15843 L
.50585 .15843 L
.50585 .08012 L
F
.2 .63 .79 r
.5055 .08012 m
.5055 .15843 L
.50585 .15843 L
.50585 .08012 L
s
.678 .847 .902 r
.50585 .08012 m
.50585 .15819 L
.50618 .15819 L
.50618 .08012 L
F
.2 .63 .79 r
.50585 .08012 m
.50585 .15819 L
.50618 .15819 L
.50618 .08012 L
s
.678 .847 .902 r
.50618 .08012 m
.50618 .15795 L
.50638 .15795 L
.50638 .08012 L
F
.2 .63 .79 r
.50618 .08012 m
.50618 .15795 L
.50638 .15795 L
.50638 .08012 L
s
.678 .847 .902 r
.50638 .08012 m
.50638 .15777 L
.50685 .15777 L
.50685 .08012 L
F
.2 .63 .79 r
.50638 .08012 m
.50638 .15777 L
.50685 .15777 L
.50685 .08012 L
s
.678 .847 .902 r
.50685 .08012 m
.50685 .15748 L
.50723 .15748 L
.50723 .08012 L
F
.2 .63 .79 r
.50685 .08012 m
.50685 .15748 L
.50723 .15748 L
.50723 .08012 L
s
.678 .847 .902 r
.50723 .08012 m
.50723 .1574 L
.50745 .1574 L
.50745 .08012 L
F
.2 .63 .79 r
.50723 .08012 m
.50723 .1574 L
.50745 .1574 L
.50745 .08012 L
s
.678 .847 .902 r
.50745 .08012 m
.50745 .15724 L
.5078 .15724 L
.5078 .08012 L
F
.2 .63 .79 r
.50745 .08012 m
.50745 .15724 L
.5078 .15724 L
.5078 .08012 L
s
.678 .847 .902 r
.5078 .08012 m
.5078 .15702 L
.508 .15702 L
.508 .08012 L
F
.2 .63 .79 r
.5078 .08012 m
.5078 .15702 L
.508 .15702 L
.508 .08012 L
s
.678 .847 .902 r
.508 .08012 m
.508 .15672 L
.50847 .15672 L
.50847 .08012 L
F
.2 .63 .79 r
.508 .08012 m
.508 .15672 L
.50847 .15672 L
.50847 .08012 L
s
.678 .847 .902 r
.50847 .08012 m
.50847 .15661 L
.50874 .15661 L
.50874 .08012 L
F
.2 .63 .79 r
.50847 .08012 m
.50847 .15661 L
.50874 .15661 L
.50874 .08012 L
s
.678 .847 .902 r
.50874 .08012 m
.50874 .15641 L
.50909 .15641 L
.50909 .08012 L
F
.2 .63 .79 r
.50874 .08012 m
.50874 .15641 L
.50909 .15641 L
.50909 .08012 L
s
.678 .847 .902 r
.50909 .08012 m
.50909 .1562 L
.50929 .1562 L
.50929 .08012 L
F
.2 .63 .79 r
.50909 .08012 m
.50909 .1562 L
.50929 .1562 L
.50929 .08012 L
s
.678 .847 .902 r
.50929 .08012 m
.50929 .15614 L
.50957 .15614 L
.50957 .08012 L
F
.2 .63 .79 r
.50929 .08012 m
.50929 .15614 L
.50957 .15614 L
.50957 .08012 L
s
.678 .847 .902 r
.50957 .08012 m
.50957 .15593 L
.50998 .15593 L
.50998 .08012 L
F
.2 .63 .79 r
.50957 .08012 m
.50957 .15593 L
.50998 .15593 L
.50998 .08012 L
s
.678 .847 .902 r
.50998 .08012 m
.50998 .15565 L
.51023 .15565 L
.51023 .08012 L
F
.2 .63 .79 r
.50998 .08012 m
.50998 .15565 L
.51023 .15565 L
.51023 .08012 L
s
.678 .847 .902 r
.51023 .08012 m
.51023 .15559 L
.51056 .15559 L
.51056 .08012 L
F
.2 .63 .79 r
.51023 .08012 m
.51023 .15559 L
.51056 .15559 L
.51056 .08012 L
s
.678 .847 .902 r
.51056 .08012 m
.51056 .15528 L
.51084 .15528 L
.51084 .08012 L
F
.2 .63 .79 r
.51056 .08012 m
.51056 .15528 L
.51084 .15528 L
.51084 .08012 L
s
.678 .847 .902 r
.51084 .08012 m
.51084 .15514 L
.51104 .15514 L
.51104 .08012 L
F
.2 .63 .79 r
.51084 .08012 m
.51084 .15514 L
.51104 .15514 L
.51104 .08012 L
s
.678 .847 .902 r
.51104 .08012 m
.51104 .15505 L
.51152 .15505 L
.51152 .08012 L
F
.2 .63 .79 r
.51104 .08012 m
.51104 .15505 L
.51152 .15505 L
.51152 .08012 L
s
.678 .847 .902 r
.51152 .08012 m
.51152 .15475 L
.51174 .15475 L
.51174 .08012 L
F
.2 .63 .79 r
.51152 .08012 m
.51152 .15475 L
.51174 .15475 L
.51174 .08012 L
s
.678 .847 .902 r
.51174 .08012 m
.51174 .15463 L
.51195 .15463 L
.51195 .08012 L
F
.2 .63 .79 r
.51174 .08012 m
.51174 .15463 L
.51195 .15463 L
.51195 .08012 L
s
.678 .847 .902 r
.51195 .08012 m
.51195 .15451 L
.51213 .15451 L
.51213 .08012 L
F
.2 .63 .79 r
.51195 .08012 m
.51195 .15451 L
.51213 .15451 L
.51213 .08012 L
s
.678 .847 .902 r
.51213 .08012 m
.51213 .15445 L
.51259 .15445 L
.51259 .08012 L
F
.2 .63 .79 r
.51213 .08012 m
.51213 .15445 L
.51259 .15445 L
.51259 .08012 L
s
.678 .847 .902 r
.51259 .08012 m
.51259 .15396 L
.51301 .15396 L
.51301 .08012 L
F
.2 .63 .79 r
.51259 .08012 m
.51259 .15396 L
.51301 .15396 L
.51301 .08012 L
s
.678 .847 .902 r
.51301 .08012 m
.51301 .15387 L
.51335 .15387 L
.51335 .08012 L
F
.2 .63 .79 r
.51301 .08012 m
.51301 .15387 L
.51335 .15387 L
.51335 .08012 L
s
.678 .847 .902 r
.51335 .08012 m
.51335 .1537 L
.5137 .1537 L
.5137 .08012 L
F
.2 .63 .79 r
.51335 .08012 m
.51335 .1537 L
.5137 .1537 L
.5137 .08012 L
s
.678 .847 .902 r
.5137 .08012 m
.5137 .15351 L
.51411 .15351 L
.51411 .08012 L
F
.2 .63 .79 r
.5137 .08012 m
.5137 .15351 L
.51411 .15351 L
.51411 .08012 L
s
.678 .847 .902 r
.51411 .08012 m
.51411 .15321 L
.51455 .15321 L
.51455 .08012 L
F
.2 .63 .79 r
.51411 .08012 m
.51411 .15321 L
.51455 .15321 L
.51455 .08012 L
s
.678 .847 .902 r
.51455 .08012 m
.51455 .15287 L
.515 .15287 L
.515 .08012 L
F
.2 .63 .79 r
.51455 .08012 m
.51455 .15287 L
.515 .15287 L
.515 .08012 L
s
.678 .847 .902 r
.515 .08012 m
.515 .1526 L
.51527 .1526 L
.51527 .08012 L
F
.2 .63 .79 r
.515 .08012 m
.515 .1526 L
.51527 .1526 L
.51527 .08012 L
s
.678 .847 .902 r
.51527 .08012 m
.51527 .15248 L
.51548 .15248 L
.51548 .08012 L
F
.2 .63 .79 r
.51527 .08012 m
.51527 .15248 L
.51548 .15248 L
.51548 .08012 L
s
.678 .847 .902 r
.51548 .08012 m
.51548 .15228 L
.51587 .15228 L
.51587 .08012 L
F
.2 .63 .79 r
.51548 .08012 m
.51548 .15228 L
.51587 .15228 L
.51587 .08012 L
s
.678 .847 .902 r
.51587 .08012 m
.51587 .15203 L
.51635 .15203 L
.51635 .08012 L
F
.2 .63 .79 r
.51587 .08012 m
.51587 .15203 L
.51635 .15203 L
.51635 .08012 L
s
.678 .847 .902 r
.51635 .08012 m
.51635 .15179 L
.51684 .15179 L
.51684 .08012 L
F
.2 .63 .79 r
.51635 .08012 m
.51635 .15179 L
.51684 .15179 L
.51684 .08012 L
s
.678 .847 .902 r
.51684 .08012 m
.51684 .15158 L
.51718 .15158 L
.51718 .08012 L
F
.2 .63 .79 r
.51684 .08012 m
.51684 .15158 L
.51718 .15158 L
.51718 .08012 L
s
.678 .847 .902 r
.51718 .08012 m
.51718 .15124 L
.51753 .15124 L
.51753 .08012 L
F
.2 .63 .79 r
.51718 .08012 m
.51718 .15124 L
.51753 .15124 L
.51753 .08012 L
s
.678 .847 .902 r
.51753 .08012 m
.51753 .15114 L
.51788 .15114 L
.51788 .08012 L
F
.2 .63 .79 r
.51753 .08012 m
.51753 .15114 L
.51788 .15114 L
.51788 .08012 L
s
.678 .847 .902 r
.51788 .08012 m
.51788 .151 L
.5181 .151 L
.5181 .08012 L
F
.2 .63 .79 r
.51788 .08012 m
.51788 .151 L
.5181 .151 L
.5181 .08012 L
s
.678 .847 .902 r
.5181 .08012 m
.5181 .15081 L
.51835 .15081 L
.51835 .08012 L
F
.2 .63 .79 r
.5181 .08012 m
.5181 .15081 L
.51835 .15081 L
.51835 .08012 L
s
.678 .847 .902 r
.51835 .08012 m
.51835 .15067 L
.51851 .15067 L
.51851 .08012 L
F
.2 .63 .79 r
.51835 .08012 m
.51835 .15067 L
.51851 .15067 L
.51851 .08012 L
s
.678 .847 .902 r
.51851 .08012 m
.51851 .15057 L
.51872 .15057 L
.51872 .08012 L
F
.2 .63 .79 r
.51851 .08012 m
.51851 .15057 L
.51872 .15057 L
.51872 .08012 L
s
.678 .847 .902 r
.51872 .08012 m
.51872 .15049 L
.5189 .15049 L
.5189 .08012 L
F
.2 .63 .79 r
.51872 .08012 m
.51872 .15049 L
.5189 .15049 L
.5189 .08012 L
s
.678 .847 .902 r
.5189 .08012 m
.5189 .15038 L
.51916 .15038 L
.51916 .08012 L
F
.2 .63 .79 r
.5189 .08012 m
.5189 .15038 L
.51916 .15038 L
.51916 .08012 L
s
.678 .847 .902 r
.51916 .08012 m
.51916 .15021 L
.51958 .15021 L
.51958 .08012 L
F
.2 .63 .79 r
.51916 .08012 m
.51916 .15021 L
.51958 .15021 L
.51958 .08012 L
s
.678 .847 .902 r
.51958 .08012 m
.51958 .15 L
.51974 .15 L
.51974 .08012 L
F
.2 .63 .79 r
.51958 .08012 m
.51958 .15 L
.51974 .15 L
.51974 .08012 L
s
.678 .847 .902 r
.51974 .08012 m
.51974 .14969 L
.52022 .14969 L
.52022 .08012 L
F
.2 .63 .79 r
.51974 .08012 m
.51974 .14969 L
.52022 .14969 L
.52022 .08012 L
s
.678 .847 .902 r
.52022 .08012 m
.52022 .14959 L
.52052 .14959 L
.52052 .08012 L
F
.2 .63 .79 r
.52022 .08012 m
.52022 .14959 L
.52052 .14959 L
.52052 .08012 L
s
.678 .847 .902 r
.52052 .08012 m
.52052 .14943 L
.52067 .14943 L
.52067 .08012 L
F
.2 .63 .79 r
.52052 .08012 m
.52052 .14943 L
.52067 .14943 L
.52067 .08012 L
s
.678 .847 .902 r
.52067 .08012 m
.52067 .14923 L
.52098 .14923 L
.52098 .08012 L
F
.2 .63 .79 r
.52067 .08012 m
.52067 .14923 L
.52098 .14923 L
.52098 .08012 L
s
.678 .847 .902 r
.52098 .08012 m
.52098 .14908 L
.52126 .14908 L
.52126 .08012 L
F
.2 .63 .79 r
.52098 .08012 m
.52098 .14908 L
.52126 .14908 L
.52126 .08012 L
s
.678 .847 .902 r
.52126 .08012 m
.52126 .14898 L
.52164 .14898 L
.52164 .08012 L
F
.2 .63 .79 r
.52126 .08012 m
.52126 .14898 L
.52164 .14898 L
.52164 .08012 L
s
.678 .847 .902 r
.52164 .08012 m
.52164 .14879 L
.52184 .14879 L
.52184 .08012 L
F
.2 .63 .79 r
.52164 .08012 m
.52164 .14879 L
.52184 .14879 L
.52184 .08012 L
s
.678 .847 .902 r
.52184 .08012 m
.52184 .14863 L
.52219 .14863 L
.52219 .08012 L
F
.2 .63 .79 r
.52184 .08012 m
.52184 .14863 L
.52219 .14863 L
.52219 .08012 L
s
.678 .847 .902 r
.52219 .08012 m
.52219 .1484 L
.52236 .1484 L
.52236 .08012 L
F
.2 .63 .79 r
.52219 .08012 m
.52219 .1484 L
.52236 .1484 L
.52236 .08012 L
s
.678 .847 .902 r
.52236 .08012 m
.52236 .1483 L
.52268 .1483 L
.52268 .08012 L
F
.2 .63 .79 r
.52236 .08012 m
.52236 .1483 L
.52268 .1483 L
.52268 .08012 L
s
.678 .847 .902 r
.52268 .08012 m
.52268 .14813 L
.52297 .14813 L
.52297 .08012 L
F
.2 .63 .79 r
.52268 .08012 m
.52268 .14813 L
.52297 .14813 L
.52297 .08012 L
s
.678 .847 .902 r
.52297 .08012 m
.52297 .14789 L
.52333 .14789 L
.52333 .08012 L
F
.2 .63 .79 r
.52297 .08012 m
.52297 .14789 L
.52333 .14789 L
.52333 .08012 L
s
.678 .847 .902 r
.52333 .08012 m
.52333 .14777 L
.52351 .14777 L
.52351 .08012 L
F
.2 .63 .79 r
.52333 .08012 m
.52333 .14777 L
.52351 .14777 L
.52351 .08012 L
s
.678 .847 .902 r
.52351 .08012 m
.52351 .14766 L
.52397 .14766 L
.52397 .08012 L
F
.2 .63 .79 r
.52351 .08012 m
.52351 .14766 L
.52397 .14766 L
.52397 .08012 L
s
.678 .847 .902 r
.52397 .08012 m
.52397 .14733 L
.52442 .14733 L
.52442 .08012 L
F
.2 .63 .79 r
.52397 .08012 m
.52397 .14733 L
.52442 .14733 L
.52442 .08012 L
s
.678 .847 .902 r
.52442 .08012 m
.52442 .14715 L
.52458 .14715 L
.52458 .08012 L
F
.2 .63 .79 r
.52442 .08012 m
.52442 .14715 L
.52458 .14715 L
.52458 .08012 L
s
.678 .847 .902 r
.52458 .08012 m
.52458 .14704 L
.52502 .14704 L
.52502 .08012 L
F
.2 .63 .79 r
.52458 .08012 m
.52458 .14704 L
.52502 .14704 L
.52502 .08012 L
s
.678 .847 .902 r
.52502 .08012 m
.52502 .14668 L
.52539 .14668 L
.52539 .08012 L
F
.2 .63 .79 r
.52502 .08012 m
.52502 .14668 L
.52539 .14668 L
.52539 .08012 L
s
.678 .847 .902 r
.52539 .08012 m
.52539 .14646 L
.52582 .14646 L
.52582 .08012 L
F
.2 .63 .79 r
.52539 .08012 m
.52539 .14646 L
.52582 .14646 L
.52582 .08012 L
s
.678 .847 .902 r
.52582 .08012 m
.52582 .14623 L
.52626 .14623 L
.52626 .08012 L
F
.2 .63 .79 r
.52582 .08012 m
.52582 .14623 L
.52626 .14623 L
.52626 .08012 L
s
.678 .847 .902 r
.52626 .08012 m
.52626 .1459 L
.52667 .1459 L
.52667 .08012 L
F
.2 .63 .79 r
.52626 .08012 m
.52626 .1459 L
.52667 .1459 L
.52667 .08012 L
s
.678 .847 .902 r
.52667 .08012 m
.52667 .1458 L
.52693 .1458 L
.52693 .08012 L
F
.2 .63 .79 r
.52667 .08012 m
.52667 .1458 L
.52693 .1458 L
.52693 .08012 L
s
.678 .847 .902 r
.52693 .08012 m
.52693 .14567 L
.52708 .14567 L
.52708 .08012 L
F
.2 .63 .79 r
.52693 .08012 m
.52693 .14567 L
.52708 .14567 L
.52708 .08012 L
s
.678 .847 .902 r
.52708 .08012 m
.52708 .14551 L
.52752 .14551 L
.52752 .08012 L
F
.2 .63 .79 r
.52708 .08012 m
.52708 .14551 L
.52752 .14551 L
.52752 .08012 L
s
.678 .847 .902 r
.52752 .08012 m
.52752 .14512 L
.52793 .14512 L
.52793 .08012 L
F
.2 .63 .79 r
.52752 .08012 m
.52752 .14512 L
.52793 .14512 L
.52793 .08012 L
s
.678 .847 .902 r
.52793 .08012 m
.52793 .14509 L
.52838 .14509 L
.52838 .08012 L
F
.2 .63 .79 r
.52793 .08012 m
.52793 .14509 L
.52838 .14509 L
.52838 .08012 L
s
.678 .847 .902 r
.52838 .08012 m
.52838 .14476 L
.52854 .14476 L
.52854 .08012 L
F
.2 .63 .79 r
.52838 .08012 m
.52838 .14476 L
.52854 .14476 L
.52854 .08012 L
s
.678 .847 .902 r
.52854 .08012 m
.52854 .14466 L
.52881 .14466 L
.52881 .08012 L
F
.2 .63 .79 r
.52854 .08012 m
.52854 .14466 L
.52881 .14466 L
.52881 .08012 L
s
.678 .847 .902 r
.52881 .08012 m
.52881 .14455 L
.52909 .14455 L
.52909 .08012 L
F
.2 .63 .79 r
.52881 .08012 m
.52881 .14455 L
.52909 .14455 L
.52909 .08012 L
s
.678 .847 .902 r
.52909 .08012 m
.52909 .14432 L
.52931 .14432 L
.52931 .08012 L
F
.2 .63 .79 r
.52909 .08012 m
.52909 .14432 L
.52931 .14432 L
.52931 .08012 L
s
.678 .847 .902 r
.52931 .08012 m
.52931 .14407 L
.52976 .14407 L
.52976 .08012 L
F
.2 .63 .79 r
.52931 .08012 m
.52931 .14407 L
.52976 .14407 L
.52976 .08012 L
s
.678 .847 .902 r
.52976 .08012 m
.52976 .14396 L
.53018 .14396 L
.53018 .08012 L
F
.2 .63 .79 r
.52976 .08012 m
.52976 .14396 L
.53018 .14396 L
.53018 .08012 L
s
.678 .847 .902 r
.53018 .08012 m
.53018 .14373 L
.53043 .14373 L
.53043 .08012 L
F
.2 .63 .79 r
.53018 .08012 m
.53018 .14373 L
.53043 .14373 L
.53043 .08012 L
s
.678 .847 .902 r
.53043 .08012 m
.53043 .14355 L
.53082 .14355 L
.53082 .08012 L
F
.2 .63 .79 r
.53043 .08012 m
.53043 .14355 L
.53082 .14355 L
.53082 .08012 L
s
.678 .847 .902 r
.53082 .08012 m
.53082 .14332 L
.53112 .14332 L
.53112 .08012 L
F
.2 .63 .79 r
.53082 .08012 m
.53082 .14332 L
.53112 .14332 L
.53112 .08012 L
s
.678 .847 .902 r
.53112 .08012 m
.53112 .14316 L
.53133 .14316 L
.53133 .08012 L
F
.2 .63 .79 r
.53112 .08012 m
.53112 .14316 L
.53133 .14316 L
.53133 .08012 L
s
.678 .847 .902 r
.53133 .08012 m
.53133 .14311 L
.53155 .14311 L
.53155 .08012 L
F
.2 .63 .79 r
.53133 .08012 m
.53133 .14311 L
.53155 .14311 L
.53155 .08012 L
s
.678 .847 .902 r
.53155 .08012 m
.53155 .14292 L
.53198 .14292 L
.53198 .08012 L
F
.2 .63 .79 r
.53155 .08012 m
.53155 .14292 L
.53198 .14292 L
.53198 .08012 L
s
.678 .847 .902 r
.53198 .08012 m
.53198 .14271 L
.53233 .14271 L
.53233 .08012 L
F
.2 .63 .79 r
.53198 .08012 m
.53198 .14271 L
.53233 .14271 L
.53233 .08012 L
s
.678 .847 .902 r
.53233 .08012 m
.53233 .14249 L
.53252 .14249 L
.53252 .08012 L
F
.2 .63 .79 r
.53233 .08012 m
.53233 .14249 L
.53252 .14249 L
.53252 .08012 L
s
.678 .847 .902 r
.53252 .08012 m
.53252 .14243 L
.53279 .14243 L
.53279 .08012 L
F
.2 .63 .79 r
.53252 .08012 m
.53252 .14243 L
.53279 .14243 L
.53279 .08012 L
s
.678 .847 .902 r
.53279 .08012 m
.53279 .1422 L
.533 .1422 L
.533 .08012 L
F
.2 .63 .79 r
.53279 .08012 m
.53279 .1422 L
.533 .1422 L
.533 .08012 L
s
.678 .847 .902 r
.533 .08012 m
.533 .14201 L
.53341 .14201 L
.53341 .08012 L
F
.2 .63 .79 r
.533 .08012 m
.533 .14201 L
.53341 .14201 L
.53341 .08012 L
s
.678 .847 .902 r
.53341 .08012 m
.53341 .14191 L
.53365 .14191 L
.53365 .08012 L
F
.2 .63 .79 r
.53341 .08012 m
.53341 .14191 L
.53365 .14191 L
.53365 .08012 L
s
.678 .847 .902 r
.53365 .08012 m
.53365 .14173 L
.53401 .14173 L
.53401 .08012 L
F
.2 .63 .79 r
.53365 .08012 m
.53365 .14173 L
.53401 .14173 L
.53401 .08012 L
s
.678 .847 .902 r
.53401 .08012 m
.53401 .14147 L
.53445 .14147 L
.53445 .08012 L
F
.2 .63 .79 r
.53401 .08012 m
.53401 .14147 L
.53445 .14147 L
.53445 .08012 L
s
.678 .847 .902 r
.53445 .08012 m
.53445 .14125 L
.53485 .14125 L
.53485 .08012 L
F
.2 .63 .79 r
.53445 .08012 m
.53445 .14125 L
.53485 .14125 L
.53485 .08012 L
s
.678 .847 .902 r
.53485 .08012 m
.53485 .14097 L
.53515 .14097 L
.53515 .08012 L
F
.2 .63 .79 r
.53485 .08012 m
.53485 .14097 L
.53515 .14097 L
.53515 .08012 L
s
.678 .847 .902 r
.53515 .08012 m
.53515 .14085 L
.53559 .14085 L
.53559 .08012 L
F
.2 .63 .79 r
.53515 .08012 m
.53515 .14085 L
.53559 .14085 L
.53559 .08012 L
s
.678 .847 .902 r
.53559 .08012 m
.53559 .14058 L
.53607 .14058 L
.53607 .08012 L
F
.2 .63 .79 r
.53559 .08012 m
.53559 .14058 L
.53607 .14058 L
.53607 .08012 L
s
.678 .847 .902 r
.53607 .08012 m
.53607 .14033 L
.53646 .14033 L
.53646 .08012 L
F
.2 .63 .79 r
.53607 .08012 m
.53607 .14033 L
.53646 .14033 L
.53646 .08012 L
s
.678 .847 .902 r
.53646 .08012 m
.53646 .14017 L
.53663 .14017 L
.53663 .08012 L
F
.2 .63 .79 r
.53646 .08012 m
.53646 .14017 L
.53663 .14017 L
.53663 .08012 L
s
.678 .847 .902 r
.53663 .08012 m
.53663 .14008 L
.53695 .14008 L
.53695 .08012 L
F
.2 .63 .79 r
.53663 .08012 m
.53663 .14008 L
.53695 .14008 L
.53695 .08012 L
s
.678 .847 .902 r
.53695 .08012 m
.53695 .1398 L
.53735 .1398 L
.53735 .08012 L
F
.2 .63 .79 r
.53695 .08012 m
.53695 .1398 L
.53735 .1398 L
.53735 .08012 L
s
.678 .847 .902 r
.53735 .08012 m
.53735 .13956 L
.53779 .13956 L
.53779 .08012 L
F
.2 .63 .79 r
.53735 .08012 m
.53735 .13956 L
.53779 .13956 L
.53779 .08012 L
s
.678 .847 .902 r
.53779 .08012 m
.53779 .13931 L
.53803 .13931 L
.53803 .08012 L
F
.2 .63 .79 r
.53779 .08012 m
.53779 .13931 L
.53803 .13931 L
.53803 .08012 L
s
.678 .847 .902 r
.53803 .08012 m
.53803 .13923 L
.53825 .13923 L
.53825 .08012 L
F
.2 .63 .79 r
.53803 .08012 m
.53803 .13923 L
.53825 .13923 L
.53825 .08012 L
s
.678 .847 .902 r
.53825 .08012 m
.53825 .13918 L
.5384 .13918 L
.5384 .08012 L
F
.2 .63 .79 r
.53825 .08012 m
.53825 .13918 L
.5384 .13918 L
.5384 .08012 L
s
.678 .847 .902 r
.5384 .08012 m
.5384 .13895 L
.53869 .13895 L
.53869 .08012 L
F
.2 .63 .79 r
.5384 .08012 m
.5384 .13895 L
.53869 .13895 L
.53869 .08012 L
s
.678 .847 .902 r
.53869 .08012 m
.53869 .13891 L
.53887 .13891 L
.53887 .08012 L
F
.2 .63 .79 r
.53869 .08012 m
.53869 .13891 L
.53887 .13891 L
.53887 .08012 L
s
.678 .847 .902 r
.53887 .08012 m
.53887 .13874 L
.53936 .13874 L
.53936 .08012 L
F
.2 .63 .79 r
.53887 .08012 m
.53887 .13874 L
.53936 .13874 L
.53936 .08012 L
s
.678 .847 .902 r
.53936 .08012 m
.53936 .13847 L
.53958 .13847 L
.53958 .08012 L
F
.2 .63 .79 r
.53936 .08012 m
.53936 .13847 L
.53958 .13847 L
.53958 .08012 L
s
.678 .847 .902 r
.53958 .08012 m
.53958 .13828 L
.54001 .13828 L
.54001 .08012 L
F
.2 .63 .79 r
.53958 .08012 m
.53958 .13828 L
.54001 .13828 L
.54001 .08012 L
s
.678 .847 .902 r
.54001 .08012 m
.54001 .13805 L
.54049 .13805 L
.54049 .08012 L
F
.2 .63 .79 r
.54001 .08012 m
.54001 .13805 L
.54049 .13805 L
.54049 .08012 L
s
.678 .847 .902 r
.54049 .08012 m
.54049 .13787 L
.54085 .13787 L
.54085 .08012 L
F
.2 .63 .79 r
.54049 .08012 m
.54049 .13787 L
.54085 .13787 L
.54085 .08012 L
s
.678 .847 .902 r
.54085 .08012 m
.54085 .13763 L
.54102 .13763 L
.54102 .08012 L
F
.2 .63 .79 r
.54085 .08012 m
.54085 .13763 L
.54102 .13763 L
.54102 .08012 L
s
.678 .847 .902 r
.54102 .08012 m
.54102 .13753 L
.54118 .13753 L
.54118 .08012 L
F
.2 .63 .79 r
.54102 .08012 m
.54102 .13753 L
.54118 .13753 L
.54118 .08012 L
s
.678 .847 .902 r
.54118 .08012 m
.54118 .13746 L
.54158 .13746 L
.54158 .08012 L
F
.2 .63 .79 r
.54118 .08012 m
.54118 .13746 L
.54158 .13746 L
.54158 .08012 L
s
.678 .847 .902 r
.54158 .08012 m
.54158 .13707 L
.54206 .13707 L
.54206 .08012 L
F
.2 .63 .79 r
.54158 .08012 m
.54158 .13707 L
.54206 .13707 L
.54206 .08012 L
s
.678 .847 .902 r
.54206 .08012 m
.54206 .13698 L
.54228 .13698 L
.54228 .08012 L
F
.2 .63 .79 r
.54206 .08012 m
.54206 .13698 L
.54228 .13698 L
.54228 .08012 L
s
.678 .847 .902 r
.54228 .08012 m
.54228 .13683 L
.54254 .13683 L
.54254 .08012 L
F
.2 .63 .79 r
.54228 .08012 m
.54228 .13683 L
.54254 .13683 L
.54254 .08012 L
s
.678 .847 .902 r
.54254 .08012 m
.54254 .1367 L
.54278 .1367 L
.54278 .08012 L
F
.2 .63 .79 r
.54254 .08012 m
.54254 .1367 L
.54278 .1367 L
.54278 .08012 L
s
.678 .847 .902 r
.54278 .08012 m
.54278 .13657 L
.54297 .13657 L
.54297 .08012 L
F
.2 .63 .79 r
.54278 .08012 m
.54278 .13657 L
.54297 .13657 L
.54297 .08012 L
s
.678 .847 .902 r
.54297 .08012 m
.54297 .13638 L
.54321 .13638 L
.54321 .08012 L
F
.2 .63 .79 r
.54297 .08012 m
.54297 .13638 L
.54321 .13638 L
.54321 .08012 L
s
.678 .847 .902 r
.54321 .08012 m
.54321 .13636 L
.54357 .13636 L
.54357 .08012 L
F
.2 .63 .79 r
.54321 .08012 m
.54321 .13636 L
.54357 .13636 L
.54357 .08012 L
s
.678 .847 .902 r
.54357 .08012 m
.54357 .13616 L
.54379 .13616 L
.54379 .08012 L
F
.2 .63 .79 r
.54357 .08012 m
.54357 .13616 L
.54379 .13616 L
.54379 .08012 L
s
.678 .847 .902 r
.54379 .08012 m
.54379 .13598 L
.54415 .13598 L
.54415 .08012 L
F
.2 .63 .79 r
.54379 .08012 m
.54379 .13598 L
.54415 .13598 L
.54415 .08012 L
s
.678 .847 .902 r
.54415 .08012 m
.54415 .13577 L
.54448 .13577 L
.54448 .08012 L
F
.2 .63 .79 r
.54415 .08012 m
.54415 .13577 L
.54448 .13577 L
.54448 .08012 L
s
.678 .847 .902 r
.54448 .08012 m
.54448 .13553 L
.54489 .13553 L
.54489 .08012 L
F
.2 .63 .79 r
.54448 .08012 m
.54448 .13553 L
.54489 .13553 L
.54489 .08012 L
s
.678 .847 .902 r
.54489 .08012 m
.54489 .1354 L
.54535 .1354 L
.54535 .08012 L
F
.2 .63 .79 r
.54489 .08012 m
.54489 .1354 L
.54535 .1354 L
.54535 .08012 L
s
.678 .847 .902 r
.54535 .08012 m
.54535 .13504 L
.54566 .13504 L
.54566 .08012 L
F
.2 .63 .79 r
.54535 .08012 m
.54535 .13504 L
.54566 .13504 L
.54566 .08012 L
s
.678 .847 .902 r
.54566 .08012 m
.54566 .13493 L
.54598 .13493 L
.54598 .08012 L
F
.2 .63 .79 r
.54566 .08012 m
.54566 .13493 L
.54598 .13493 L
.54598 .08012 L
s
.678 .847 .902 r
.54598 .08012 m
.54598 .13472 L
.54625 .13472 L
.54625 .08012 L
F
.2 .63 .79 r
.54598 .08012 m
.54598 .13472 L
.54625 .13472 L
.54625 .08012 L
s
.678 .847 .902 r
.54625 .08012 m
.54625 .13467 L
.54667 .13467 L
.54667 .08012 L
F
.2 .63 .79 r
.54625 .08012 m
.54625 .13467 L
.54667 .13467 L
.54667 .08012 L
s
.678 .847 .902 r
.54667 .08012 m
.54667 .13435 L
.54699 .13435 L
.54699 .08012 L
F
.2 .63 .79 r
.54667 .08012 m
.54667 .13435 L
.54699 .13435 L
.54699 .08012 L
s
.678 .847 .902 r
.54699 .08012 m
.54699 .13415 L
.54723 .13415 L
.54723 .08012 L
F
.2 .63 .79 r
.54699 .08012 m
.54699 .13415 L
.54723 .13415 L
.54723 .08012 L
s
.678 .847 .902 r
.54723 .08012 m
.54723 .13411 L
.54757 .13411 L
.54757 .08012 L
F
.2 .63 .79 r
.54723 .08012 m
.54723 .13411 L
.54757 .13411 L
.54757 .08012 L
s
.678 .847 .902 r
.54757 .08012 m
.54757 .1338 L
.548 .1338 L
.548 .08012 L
F
.2 .63 .79 r
.54757 .08012 m
.54757 .1338 L
.548 .1338 L
.548 .08012 L
s
.678 .847 .902 r
.548 .08012 m
.548 .13361 L
.54845 .13361 L
.54845 .08012 L
F
.2 .63 .79 r
.548 .08012 m
.548 .13361 L
.54845 .13361 L
.54845 .08012 L
s
.678 .847 .902 r
.54845 .08012 m
.54845 .13332 L
.54868 .13332 L
.54868 .08012 L
F
.2 .63 .79 r
.54845 .08012 m
.54845 .13332 L
.54868 .13332 L
.54868 .08012 L
s
.678 .847 .902 r
.54868 .08012 m
.54868 .13329 L
.54899 .13329 L
.54899 .08012 L
F
.2 .63 .79 r
.54868 .08012 m
.54868 .13329 L
.54899 .13329 L
.54899 .08012 L
s
.678 .847 .902 r
.54899 .08012 m
.54899 .13311 L
.54918 .13311 L
.54918 .08012 L
F
.2 .63 .79 r
.54899 .08012 m
.54899 .13311 L
.54918 .13311 L
.54918 .08012 L
s
.678 .847 .902 r
.54918 .08012 m
.54918 .1329 L
.54964 .1329 L
.54964 .08012 L
F
.2 .63 .79 r
.54918 .08012 m
.54918 .1329 L
.54964 .1329 L
.54964 .08012 L
s
.678 .847 .902 r
.54964 .08012 m
.54964 .13273 L
.54979 .13273 L
.54979 .08012 L
F
.2 .63 .79 r
.54964 .08012 m
.54964 .13273 L
.54979 .13273 L
.54979 .08012 L
s
.678 .847 .902 r
.54979 .08012 m
.54979 .13262 L
.54999 .13262 L
.54999 .08012 L
F
.2 .63 .79 r
.54979 .08012 m
.54979 .13262 L
.54999 .13262 L
.54999 .08012 L
s
.678 .847 .902 r
.54999 .08012 m
.54999 .13236 L
.55043 .13236 L
.55043 .08012 L
F
.2 .63 .79 r
.54999 .08012 m
.54999 .13236 L
.55043 .13236 L
.55043 .08012 L
s
.678 .847 .902 r
.55043 .08012 m
.55043 .13231 L
.55085 .13231 L
.55085 .08012 L
F
.2 .63 .79 r
.55043 .08012 m
.55043 .13231 L
.55085 .13231 L
.55085 .08012 L
s
.678 .847 .902 r
.55085 .08012 m
.55085 .13195 L
.55125 .13195 L
.55125 .08012 L
F
.2 .63 .79 r
.55085 .08012 m
.55085 .13195 L
.55125 .13195 L
.55125 .08012 L
s
.678 .847 .902 r
.55125 .08012 m
.55125 .13177 L
.55159 .13177 L
.55159 .08012 L
F
.2 .63 .79 r
.55125 .08012 m
.55125 .13177 L
.55159 .13177 L
.55159 .08012 L
s
.678 .847 .902 r
.55159 .08012 m
.55159 .13152 L
.55196 .13152 L
.55196 .08012 L
F
.2 .63 .79 r
.55159 .08012 m
.55159 .13152 L
.55196 .13152 L
.55196 .08012 L
s
.678 .847 .902 r
.55196 .08012 m
.55196 .13142 L
.55216 .13142 L
.55216 .08012 L
F
.2 .63 .79 r
.55196 .08012 m
.55196 .13142 L
.55216 .13142 L
.55216 .08012 L
s
.678 .847 .902 r
.55216 .08012 m
.55216 .13135 L
.55238 .13135 L
.55238 .08012 L
F
.2 .63 .79 r
.55216 .08012 m
.55216 .13135 L
.55238 .13135 L
.55238 .08012 L
s
.678 .847 .902 r
.55238 .08012 m
.55238 .13124 L
.55281 .13124 L
.55281 .08012 L
F
.2 .63 .79 r
.55238 .08012 m
.55238 .13124 L
.55281 .13124 L
.55281 .08012 L
s
.678 .847 .902 r
.55281 .08012 m
.55281 .13087 L
.5532 .13087 L
.5532 .08012 L
F
.2 .63 .79 r
.55281 .08012 m
.55281 .13087 L
.5532 .13087 L
.5532 .08012 L
s
.678 .847 .902 r
.5532 .08012 m
.5532 .13082 L
.55359 .13082 L
.55359 .08012 L
F
.2 .63 .79 r
.5532 .08012 m
.5532 .13082 L
.55359 .13082 L
.55359 .08012 L
s
.678 .847 .902 r
.55359 .08012 m
.55359 .1304 L
.55398 .1304 L
.55398 .08012 L
F
.2 .63 .79 r
.55359 .08012 m
.55359 .1304 L
.55398 .1304 L
.55398 .08012 L
s
.678 .847 .902 r
.55398 .08012 m
.55398 .13032 L
.55429 .13032 L
.55429 .08012 L
F
.2 .63 .79 r
.55398 .08012 m
.55398 .13032 L
.55429 .13032 L
.55429 .08012 L
s
.678 .847 .902 r
.55429 .08012 m
.55429 .13003 L
.55475 .13003 L
.55475 .08012 L
F
.2 .63 .79 r
.55429 .08012 m
.55429 .13003 L
.55475 .13003 L
.55475 .08012 L
s
.678 .847 .902 r
.55475 .08012 m
.55475 .12991 L
.55497 .12991 L
.55497 .08012 L
F
.2 .63 .79 r
.55475 .08012 m
.55475 .12991 L
.55497 .12991 L
.55497 .08012 L
s
.678 .847 .902 r
.55497 .08012 m
.55497 .12982 L
.55527 .12982 L
.55527 .08012 L
F
.2 .63 .79 r
.55497 .08012 m
.55497 .12982 L
.55527 .12982 L
.55527 .08012 L
s
.678 .847 .902 r
.55527 .08012 m
.55527 .12959 L
.55573 .12959 L
.55573 .08012 L
F
.2 .63 .79 r
.55527 .08012 m
.55527 .12959 L
.55573 .12959 L
.55573 .08012 L
s
.678 .847 .902 r
.55573 .08012 m
.55573 .12942 L
.5559 .12942 L
.5559 .08012 L
F
.2 .63 .79 r
.55573 .08012 m
.55573 .12942 L
.5559 .12942 L
.5559 .08012 L
s
.678 .847 .902 r
.5559 .08012 m
.5559 .12932 L
.55617 .12932 L
.55617 .08012 L
F
.2 .63 .79 r
.5559 .08012 m
.5559 .12932 L
.55617 .12932 L
.55617 .08012 L
s
.678 .847 .902 r
.55617 .08012 m
.55617 .12917 L
.55639 .12917 L
.55639 .08012 L
F
.2 .63 .79 r
.55617 .08012 m
.55617 .12917 L
.55639 .12917 L
.55639 .08012 L
s
.678 .847 .902 r
.55639 .08012 m
.55639 .12905 L
.55668 .12905 L
.55668 .08012 L
F
.2 .63 .79 r
.55639 .08012 m
.55639 .12905 L
.55668 .12905 L
.55668 .08012 L
s
.678 .847 .902 r
.55668 .08012 m
.55668 .12868 L
.55716 .12868 L
.55716 .08012 L
F
.2 .63 .79 r
.55668 .08012 m
.55668 .12868 L
.55716 .12868 L
.55716 .08012 L
s
.678 .847 .902 r
.55716 .08012 m
.55716 .12856 L
.55746 .12856 L
.55746 .08012 L
F
.2 .63 .79 r
.55716 .08012 m
.55716 .12856 L
.55746 .12856 L
.55746 .08012 L
s
.678 .847 .902 r
.55746 .08012 m
.55746 .12843 L
.55767 .12843 L
.55767 .08012 L
F
.2 .63 .79 r
.55746 .08012 m
.55746 .12843 L
.55767 .12843 L
.55767 .08012 L
s
.678 .847 .902 r
.55767 .08012 m
.55767 .12832 L
.55791 .12832 L
.55791 .08012 L
F
.2 .63 .79 r
.55767 .08012 m
.55767 .12832 L
.55791 .12832 L
.55791 .08012 L
s
.678 .847 .902 r
.55791 .08012 m
.55791 .12815 L
.5581 .12815 L
.5581 .08012 L
F
.2 .63 .79 r
.55791 .08012 m
.55791 .12815 L
.5581 .12815 L
.5581 .08012 L
s
.678 .847 .902 r
.5581 .08012 m
.5581 .12805 L
.55848 .12805 L
.55848 .08012 L
F
.2 .63 .79 r
.5581 .08012 m
.5581 .12805 L
.55848 .12805 L
.55848 .08012 L
s
.678 .847 .902 r
.55848 .08012 m
.55848 .12781 L
.55878 .12781 L
.55878 .08012 L
F
.2 .63 .79 r
.55848 .08012 m
.55848 .12781 L
.55878 .12781 L
.55878 .08012 L
s
.678 .847 .902 r
.55878 .08012 m
.55878 .12762 L
.55917 .12762 L
.55917 .08012 L
F
.2 .63 .79 r
.55878 .08012 m
.55878 .12762 L
.55917 .12762 L
.55917 .08012 L
s
.678 .847 .902 r
.55917 .08012 m
.55917 .12757 L
.55948 .12757 L
.55948 .08012 L
F
.2 .63 .79 r
.55917 .08012 m
.55917 .12757 L
.55948 .12757 L
.55948 .08012 L
s
.678 .847 .902 r
.55948 .08012 m
.55948 .12729 L
.55981 .12729 L
.55981 .08012 L
F
.2 .63 .79 r
.55948 .08012 m
.55948 .12729 L
.55981 .12729 L
.55981 .08012 L
s
.678 .847 .902 r
.55981 .08012 m
.55981 .12717 L
.56004 .12717 L
.56004 .08012 L
F
.2 .63 .79 r
.55981 .08012 m
.55981 .12717 L
.56004 .12717 L
.56004 .08012 L
s
.678 .847 .902 r
.56004 .08012 m
.56004 .12695 L
.56049 .12695 L
.56049 .08012 L
F
.2 .63 .79 r
.56004 .08012 m
.56004 .12695 L
.56049 .12695 L
.56049 .08012 L
s
.678 .847 .902 r
.56049 .08012 m
.56049 .1268 L
.56091 .1268 L
.56091 .08012 L
F
.2 .63 .79 r
.56049 .08012 m
.56049 .1268 L
.56091 .1268 L
.56091 .08012 L
s
.678 .847 .902 r
.56091 .08012 m
.56091 .12649 L
.56133 .12649 L
.56133 .08012 L
F
.2 .63 .79 r
.56091 .08012 m
.56091 .12649 L
.56133 .12649 L
.56133 .08012 L
s
.678 .847 .902 r
.56133 .08012 m
.56133 .12632 L
.56166 .12632 L
.56166 .08012 L
F
.2 .63 .79 r
.56133 .08012 m
.56133 .12632 L
.56166 .12632 L
.56166 .08012 L
s
.678 .847 .902 r
.56166 .08012 m
.56166 .1262 L
.56195 .1262 L
.56195 .08012 L
F
.2 .63 .79 r
.56166 .08012 m
.56166 .1262 L
.56195 .1262 L
.56195 .08012 L
s
.678 .847 .902 r
.56195 .08012 m
.56195 .12595 L
.56241 .12595 L
.56241 .08012 L
F
.2 .63 .79 r
.56195 .08012 m
.56195 .12595 L
.56241 .12595 L
.56241 .08012 L
s
.678 .847 .902 r
.56241 .08012 m
.56241 .12581 L
.56276 .12581 L
.56276 .08012 L
F
.2 .63 .79 r
.56241 .08012 m
.56241 .12581 L
.56276 .12581 L
.56276 .08012 L
s
.678 .847 .902 r
.56276 .08012 m
.56276 .12561 L
.56294 .12561 L
.56294 .08012 L
F
.2 .63 .79 r
.56276 .08012 m
.56276 .12561 L
.56294 .12561 L
.56294 .08012 L
s
.678 .847 .902 r
.56294 .08012 m
.56294 .12541 L
.56326 .12541 L
.56326 .08012 L
F
.2 .63 .79 r
.56294 .08012 m
.56294 .12541 L
.56326 .12541 L
.56326 .08012 L
s
.678 .847 .902 r
.56326 .08012 m
.56326 .12531 L
.56369 .12531 L
.56369 .08012 L
F
.2 .63 .79 r
.56326 .08012 m
.56326 .12531 L
.56369 .12531 L
.56369 .08012 L
s
.678 .847 .902 r
.56369 .08012 m
.56369 .12502 L
.56392 .12502 L
.56392 .08012 L
F
.2 .63 .79 r
.56369 .08012 m
.56369 .12502 L
.56392 .12502 L
.56392 .08012 L
s
.678 .847 .902 r
.56392 .08012 m
.56392 .125 L
.56437 .125 L
.56437 .08012 L
F
.2 .63 .79 r
.56392 .08012 m
.56392 .125 L
.56437 .125 L
.56437 .08012 L
s
.678 .847 .902 r
.56437 .08012 m
.56437 .12472 L
.56455 .12472 L
.56455 .08012 L
F
.2 .63 .79 r
.56437 .08012 m
.56437 .12472 L
.56455 .12472 L
.56455 .08012 L
s
.678 .847 .902 r
.56455 .08012 m
.56455 .12459 L
.56499 .12459 L
.56499 .08012 L
F
.2 .63 .79 r
.56455 .08012 m
.56455 .12459 L
.56499 .12459 L
.56499 .08012 L
s
.678 .847 .902 r
.56499 .08012 m
.56499 .12438 L
.56541 .12438 L
.56541 .08012 L
F
.2 .63 .79 r
.56499 .08012 m
.56499 .12438 L
.56541 .12438 L
.56541 .08012 L
s
.678 .847 .902 r
.56541 .08012 m
.56541 .12411 L
.5658 .12411 L
.5658 .08012 L
F
.2 .63 .79 r
.56541 .08012 m
.56541 .12411 L
.5658 .12411 L
.5658 .08012 L
s
.678 .847 .902 r
.5658 .08012 m
.5658 .12398 L
.56623 .12398 L
.56623 .08012 L
F
.2 .63 .79 r
.5658 .08012 m
.5658 .12398 L
.56623 .12398 L
.56623 .08012 L
s
.678 .847 .902 r
.56623 .08012 m
.56623 .12369 L
.56663 .12369 L
.56663 .08012 L
F
.2 .63 .79 r
.56623 .08012 m
.56623 .12369 L
.56663 .12369 L
.56663 .08012 L
s
.678 .847 .902 r
.56663 .08012 m
.56663 .12348 L
.56683 .12348 L
.56683 .08012 L
F
.2 .63 .79 r
.56663 .08012 m
.56663 .12348 L
.56683 .12348 L
.56683 .08012 L
s
.678 .847 .902 r
.56683 .08012 m
.56683 .12338 L
.56706 .12338 L
.56706 .08012 L
F
.2 .63 .79 r
.56683 .08012 m
.56683 .12338 L
.56706 .12338 L
.56706 .08012 L
s
.678 .847 .902 r
.56706 .08012 m
.56706 .1233 L
.56725 .1233 L
.56725 .08012 L
F
.2 .63 .79 r
.56706 .08012 m
.56706 .1233 L
.56725 .1233 L
.56725 .08012 L
s
.678 .847 .902 r
.56725 .08012 m
.56725 .12319 L
.56748 .12319 L
.56748 .08012 L
F
.2 .63 .79 r
.56725 .08012 m
.56725 .12319 L
.56748 .12319 L
.56748 .08012 L
s
.678 .847 .902 r
.56748 .08012 m
.56748 .12309 L
.56785 .12309 L
.56785 .08012 L
F
.2 .63 .79 r
.56748 .08012 m
.56748 .12309 L
.56785 .12309 L
.56785 .08012 L
s
.678 .847 .902 r
.56785 .08012 m
.56785 .12291 L
.568 .12291 L
.568 .08012 L
F
.2 .63 .79 r
.56785 .08012 m
.56785 .12291 L
.568 .12291 L
.568 .08012 L
s
.678 .847 .902 r
.568 .08012 m
.568 .12275 L
.56823 .12275 L
.56823 .08012 L
F
.2 .63 .79 r
.568 .08012 m
.568 .12275 L
.56823 .12275 L
.56823 .08012 L
s
.678 .847 .902 r
.56823 .08012 m
.56823 .1227 L
.56853 .1227 L
.56853 .08012 L
F
.2 .63 .79 r
.56823 .08012 m
.56823 .1227 L
.56853 .1227 L
.56853 .08012 L
s
.678 .847 .902 r
.56853 .08012 m
.56853 .12244 L
.56896 .12244 L
.56896 .08012 L
F
.2 .63 .79 r
.56853 .08012 m
.56853 .12244 L
.56896 .12244 L
.56896 .08012 L
s
.678 .847 .902 r
.56896 .08012 m
.56896 .12221 L
.56928 .12221 L
.56928 .08012 L
F
.2 .63 .79 r
.56896 .08012 m
.56896 .12221 L
.56928 .12221 L
.56928 .08012 L
s
.678 .847 .902 r
.56928 .08012 m
.56928 .12203 L
.56971 .12203 L
.56971 .08012 L
F
.2 .63 .79 r
.56928 .08012 m
.56928 .12203 L
.56971 .12203 L
.56971 .08012 L
s
.678 .847 .902 r
.56971 .08012 m
.56971 .12182 L
.57005 .12182 L
.57005 .08012 L
F
.2 .63 .79 r
.56971 .08012 m
.56971 .12182 L
.57005 .12182 L
.57005 .08012 L
s
.678 .847 .902 r
.57005 .08012 m
.57005 .1217 L
.57028 .1217 L
.57028 .08012 L
F
.2 .63 .79 r
.57005 .08012 m
.57005 .1217 L
.57028 .1217 L
.57028 .08012 L
s
.678 .847 .902 r
.57028 .08012 m
.57028 .12157 L
.57056 .12157 L
.57056 .08012 L
F
.2 .63 .79 r
.57028 .08012 m
.57028 .12157 L
.57056 .12157 L
.57056 .08012 L
s
.678 .847 .902 r
.57056 .08012 m
.57056 .12138 L
.57082 .12138 L
.57082 .08012 L
F
.2 .63 .79 r
.57056 .08012 m
.57056 .12138 L
.57082 .12138 L
.57082 .08012 L
s
.678 .847 .902 r
.57082 .08012 m
.57082 .12127 L
.57122 .12127 L
.57122 .08012 L
F
.2 .63 .79 r
.57082 .08012 m
.57082 .12127 L
.57122 .12127 L
.57122 .08012 L
s
.678 .847 .902 r
.57122 .08012 m
.57122 .1211 L
.57137 .1211 L
.57137 .08012 L
F
.2 .63 .79 r
.57122 .08012 m
.57122 .1211 L
.57137 .1211 L
.57137 .08012 L
s
.678 .847 .902 r
.57137 .08012 m
.57137 .121 L
.57169 .121 L
.57169 .08012 L
F
.2 .63 .79 r
.57137 .08012 m
.57137 .121 L
.57169 .121 L
.57169 .08012 L
s
.678 .847 .902 r
.57169 .08012 m
.57169 .12087 L
.57192 .12087 L
.57192 .08012 L
F
.2 .63 .79 r
.57169 .08012 m
.57169 .12087 L
.57192 .12087 L
.57192 .08012 L
s
.678 .847 .902 r
.57192 .08012 m
.57192 .12076 L
.57238 .12076 L
.57238 .08012 L
F
.2 .63 .79 r
.57192 .08012 m
.57192 .12076 L
.57238 .12076 L
.57238 .08012 L
s
.678 .847 .902 r
.57238 .08012 m
.57238 .1205 L
.57259 .1205 L
.57259 .08012 L
F
.2 .63 .79 r
.57238 .08012 m
.57238 .1205 L
.57259 .1205 L
.57259 .08012 L
s
.678 .847 .902 r
.57259 .08012 m
.57259 .12023 L
.57302 .12023 L
.57302 .08012 L
F
.2 .63 .79 r
.57259 .08012 m
.57259 .12023 L
.57302 .12023 L
.57302 .08012 L
s
.678 .847 .902 r
.57302 .08012 m
.57302 .12018 L
.57331 .12018 L
.57331 .08012 L
F
.2 .63 .79 r
.57302 .08012 m
.57302 .12018 L
.57331 .12018 L
.57331 .08012 L
s
.678 .847 .902 r
.57331 .08012 m
.57331 .11998 L
.57352 .11998 L
.57352 .08012 L
F
.2 .63 .79 r
.57331 .08012 m
.57331 .11998 L
.57352 .11998 L
.57352 .08012 L
s
.678 .847 .902 r
.57352 .08012 m
.57352 .1199 L
.57368 .1199 L
.57368 .08012 L
F
.2 .63 .79 r
.57352 .08012 m
.57352 .1199 L
.57368 .1199 L
.57368 .08012 L
s
.678 .847 .902 r
.57368 .08012 m
.57368 .11982 L
.57403 .11982 L
.57403 .08012 L
F
.2 .63 .79 r
.57368 .08012 m
.57368 .11982 L
.57403 .11982 L
.57403 .08012 L
s
.678 .847 .902 r
.57403 .08012 m
.57403 .11958 L
.57427 .11958 L
.57427 .08012 L
F
.2 .63 .79 r
.57403 .08012 m
.57403 .11958 L
.57427 .11958 L
.57427 .08012 L
s
.678 .847 .902 r
.57427 .08012 m
.57427 .11949 L
.57474 .11949 L
.57474 .08012 L
F
.2 .63 .79 r
.57427 .08012 m
.57427 .11949 L
.57474 .11949 L
.57474 .08012 L
s
.678 .847 .902 r
.57474 .08012 m
.57474 .11925 L
.57503 .11925 L
.57503 .08012 L
F
.2 .63 .79 r
.57474 .08012 m
.57474 .11925 L
.57503 .11925 L
.57503 .08012 L
s
.678 .847 .902 r
.57503 .08012 m
.57503 .11897 L
.57537 .11897 L
.57537 .08012 L
F
.2 .63 .79 r
.57503 .08012 m
.57503 .11897 L
.57537 .11897 L
.57537 .08012 L
s
.678 .847 .902 r
.57537 .08012 m
.57537 .11889 L
.57553 .11889 L
.57553 .08012 L
F
.2 .63 .79 r
.57537 .08012 m
.57537 .11889 L
.57553 .11889 L
.57553 .08012 L
s
.678 .847 .902 r
.57553 .08012 m
.57553 .11887 L
.57585 .11887 L
.57585 .08012 L
F
.2 .63 .79 r
.57553 .08012 m
.57553 .11887 L
.57585 .11887 L
.57585 .08012 L
s
.678 .847 .902 r
.57585 .08012 m
.57585 .11858 L
.5762 .11858 L
.5762 .08012 L
F
.2 .63 .79 r
.57585 .08012 m
.57585 .11858 L
.5762 .11858 L
.5762 .08012 L
s
.678 .847 .902 r
.5762 .08012 m
.5762 .11852 L
.57637 .11852 L
.57637 .08012 L
F
.2 .63 .79 r
.5762 .08012 m
.5762 .11852 L
.57637 .11852 L
.57637 .08012 L
s
.678 .847 .902 r
.57637 .08012 m
.57637 .1184 L
.5766 .1184 L
.5766 .08012 L
F
.2 .63 .79 r
.57637 .08012 m
.57637 .1184 L
.5766 .1184 L
.5766 .08012 L
s
.678 .847 .902 r
.5766 .08012 m
.5766 .11822 L
.57707 .11822 L
.57707 .08012 L
F
.2 .63 .79 r
.5766 .08012 m
.5766 .11822 L
.57707 .11822 L
.57707 .08012 L
s
.678 .847 .902 r
.57707 .08012 m
.57707 .11805 L
.57733 .11805 L
.57733 .08012 L
F
.2 .63 .79 r
.57707 .08012 m
.57707 .11805 L
.57733 .11805 L
.57733 .08012 L
s
.678 .847 .902 r
.57733 .08012 m
.57733 .11779 L
.57771 .11779 L
.57771 .08012 L
F
.2 .63 .79 r
.57733 .08012 m
.57733 .11779 L
.57771 .11779 L
.57771 .08012 L
s
.678 .847 .902 r
.57771 .08012 m
.57771 .11761 L
.57818 .11761 L
.57818 .08012 L
F
.2 .63 .79 r
.57771 .08012 m
.57771 .11761 L
.57818 .11761 L
.57818 .08012 L
s
.678 .847 .902 r
.57818 .08012 m
.57818 .11751 L
.57839 .11751 L
.57839 .08012 L
F
.2 .63 .79 r
.57818 .08012 m
.57818 .11751 L
.57839 .11751 L
.57839 .08012 L
s
.678 .847 .902 r
.57839 .08012 m
.57839 .11731 L
.57865 .11731 L
.57865 .08012 L
F
.2 .63 .79 r
.57839 .08012 m
.57839 .11731 L
.57865 .11731 L
.57865 .08012 L
s
.678 .847 .902 r
.57865 .08012 m
.57865 .11722 L
.57886 .11722 L
.57886 .08012 L
F
.2 .63 .79 r
.57865 .08012 m
.57865 .11722 L
.57886 .11722 L
.57886 .08012 L
s
.678 .847 .902 r
.57886 .08012 m
.57886 .11709 L
.57924 .11709 L
.57924 .08012 L
F
.2 .63 .79 r
.57886 .08012 m
.57886 .11709 L
.57924 .11709 L
.57924 .08012 L
s
.678 .847 .902 r
.57924 .08012 m
.57924 .11696 L
.57949 .11696 L
.57949 .08012 L
F
.2 .63 .79 r
.57924 .08012 m
.57924 .11696 L
.57949 .11696 L
.57949 .08012 L
s
.678 .847 .902 r
.57949 .08012 m
.57949 .11679 L
.57968 .11679 L
.57968 .08012 L
F
.2 .63 .79 r
.57949 .08012 m
.57949 .11679 L
.57968 .11679 L
.57968 .08012 L
s
.678 .847 .902 r
.57968 .08012 m
.57968 .11666 L
.57996 .11666 L
.57996 .08012 L
F
.2 .63 .79 r
.57968 .08012 m
.57968 .11666 L
.57996 .11666 L
.57996 .08012 L
s
.678 .847 .902 r
.57996 .08012 m
.57996 .11656 L
.5802 .11656 L
.5802 .08012 L
F
.2 .63 .79 r
.57996 .08012 m
.57996 .11656 L
.5802 .11656 L
.5802 .08012 L
s
.678 .847 .902 r
.5802 .08012 m
.5802 .11643 L
.58039 .11643 L
.58039 .08012 L
F
.2 .63 .79 r
.5802 .08012 m
.5802 .11643 L
.58039 .11643 L
.58039 .08012 L
s
.678 .847 .902 r
.58039 .08012 m
.58039 .11638 L
.58056 .11638 L
.58056 .08012 L
F
.2 .63 .79 r
.58039 .08012 m
.58039 .11638 L
.58056 .11638 L
.58056 .08012 L
s
.678 .847 .902 r
.58056 .08012 m
.58056 .1162 L
.58099 .1162 L
.58099 .08012 L
F
.2 .63 .79 r
.58056 .08012 m
.58056 .1162 L
.58099 .1162 L
.58099 .08012 L
s
.678 .847 .902 r
.58099 .08012 m
.58099 .11603 L
.58114 .11603 L
.58114 .08012 L
F
.2 .63 .79 r
.58099 .08012 m
.58099 .11603 L
.58114 .11603 L
.58114 .08012 L
s
.678 .847 .902 r
.58114 .08012 m
.58114 .11598 L
.58134 .11598 L
.58134 .08012 L
F
.2 .63 .79 r
.58114 .08012 m
.58114 .11598 L
.58134 .11598 L
.58134 .08012 L
s
.678 .847 .902 r
.58134 .08012 m
.58134 .11575 L
.58172 .11575 L
.58172 .08012 L
F
.2 .63 .79 r
.58134 .08012 m
.58134 .11575 L
.58172 .11575 L
.58172 .08012 L
s
.678 .847 .902 r
.58172 .08012 m
.58172 .11565 L
.58195 .11565 L
.58195 .08012 L
F
.2 .63 .79 r
.58172 .08012 m
.58172 .11565 L
.58195 .11565 L
.58195 .08012 L
s
.678 .847 .902 r
.58195 .08012 m
.58195 .11544 L
.58243 .11544 L
.58243 .08012 L
F
.2 .63 .79 r
.58195 .08012 m
.58195 .11544 L
.58243 .11544 L
.58243 .08012 L
s
.678 .847 .902 r
.58243 .08012 m
.58243 .11532 L
.58281 .11532 L
.58281 .08012 L
F
.2 .63 .79 r
.58243 .08012 m
.58243 .11532 L
.58281 .11532 L
.58281 .08012 L
s
.678 .847 .902 r
.58281 .08012 m
.58281 .11505 L
.58298 .11505 L
.58298 .08012 L
F
.2 .63 .79 r
.58281 .08012 m
.58281 .11505 L
.58298 .11505 L
.58298 .08012 L
s
.678 .847 .902 r
.58298 .08012 m
.58298 .11503 L
.58319 .11503 L
.58319 .08012 L
F
.2 .63 .79 r
.58298 .08012 m
.58298 .11503 L
.58319 .11503 L
.58319 .08012 L
s
.678 .847 .902 r
.58319 .08012 m
.58319 .11491 L
.5836 .11491 L
.5836 .08012 L
F
.2 .63 .79 r
.58319 .08012 m
.58319 .11491 L
.5836 .11491 L
.5836 .08012 L
s
.678 .847 .902 r
.5836 .08012 m
.5836 .11461 L
.584 .11461 L
.584 .08012 L
F
.2 .63 .79 r
.5836 .08012 m
.5836 .11461 L
.584 .11461 L
.584 .08012 L
s
.678 .847 .902 r
.584 .08012 m
.584 .1144 L
.5844 .1144 L
.5844 .08012 L
F
.2 .63 .79 r
.584 .08012 m
.584 .1144 L
.5844 .1144 L
.5844 .08012 L
s
.678 .847 .902 r
.5844 .08012 m
.5844 .11427 L
.58472 .11427 L
.58472 .08012 L
F
.2 .63 .79 r
.5844 .08012 m
.5844 .11427 L
.58472 .11427 L
.58472 .08012 L
s
.678 .847 .902 r
.58472 .08012 m
.58472 .11405 L
.58515 .11405 L
.58515 .08012 L
F
.2 .63 .79 r
.58472 .08012 m
.58472 .11405 L
.58515 .11405 L
.58515 .08012 L
s
.678 .847 .902 r
.58515 .08012 m
.58515 .11385 L
.58549 .11385 L
.58549 .08012 L
F
.2 .63 .79 r
.58515 .08012 m
.58515 .11385 L
.58549 .11385 L
.58549 .08012 L
s
.678 .847 .902 r
.58549 .08012 m
.58549 .11364 L
.58578 .11364 L
.58578 .08012 L
F
.2 .63 .79 r
.58549 .08012 m
.58549 .11364 L
.58578 .11364 L
.58578 .08012 L
s
.678 .847 .902 r
.58578 .08012 m
.58578 .11351 L
.58603 .11351 L
.58603 .08012 L
F
.2 .63 .79 r
.58578 .08012 m
.58578 .11351 L
.58603 .11351 L
.58603 .08012 L
s
.678 .847 .902 r
.58603 .08012 m
.58603 .11348 L
.58623 .11348 L
.58623 .08012 L
F
.2 .63 .79 r
.58603 .08012 m
.58603 .11348 L
.58623 .11348 L
.58623 .08012 L
s
.678 .847 .902 r
.58623 .08012 m
.58623 .11334 L
.58647 .11334 L
.58647 .08012 L
F
.2 .63 .79 r
.58623 .08012 m
.58623 .11334 L
.58647 .11334 L
.58647 .08012 L
s
.678 .847 .902 r
.58647 .08012 m
.58647 .11322 L
.58672 .11322 L
.58672 .08012 L
F
.2 .63 .79 r
.58647 .08012 m
.58647 .11322 L
.58672 .11322 L
.58672 .08012 L
s
.678 .847 .902 r
.58672 .08012 m
.58672 .11307 L
.58719 .11307 L
.58719 .08012 L
F
.2 .63 .79 r
.58672 .08012 m
.58672 .11307 L
.58719 .11307 L
.58719 .08012 L
s
.678 .847 .902 r
.58719 .08012 m
.58719 .11272 L
.58763 .11272 L
.58763 .08012 L
F
.2 .63 .79 r
.58719 .08012 m
.58719 .11272 L
.58763 .11272 L
.58763 .08012 L
s
.678 .847 .902 r
.58763 .08012 m
.58763 .11268 L
.58784 .11268 L
.58784 .08012 L
F
.2 .63 .79 r
.58763 .08012 m
.58763 .11268 L
.58784 .11268 L
.58784 .08012 L
s
.678 .847 .902 r
.58784 .08012 m
.58784 .11254 L
.58805 .11254 L
.58805 .08012 L
F
.2 .63 .79 r
.58784 .08012 m
.58784 .11254 L
.58805 .11254 L
.58805 .08012 L
s
.678 .847 .902 r
.58805 .08012 m
.58805 .11239 L
.58825 .11239 L
.58825 .08012 L
F
.2 .63 .79 r
.58805 .08012 m
.58805 .11239 L
.58825 .11239 L
.58825 .08012 L
s
.678 .847 .902 r
.58825 .08012 m
.58825 .11231 L
.58869 .11231 L
.58869 .08012 L
F
.2 .63 .79 r
.58825 .08012 m
.58825 .11231 L
.58869 .11231 L
.58869 .08012 L
s
.678 .847 .902 r
.58869 .08012 m
.58869 .11192 L
.58918 .11192 L
.58918 .08012 L
F
.2 .63 .79 r
.58869 .08012 m
.58869 .11192 L
.58918 .11192 L
.58918 .08012 L
s
.678 .847 .902 r
.58918 .08012 m
.58918 .11179 L
.58951 .11179 L
.58951 .08012 L
F
.2 .63 .79 r
.58918 .08012 m
.58918 .11179 L
.58951 .11179 L
.58951 .08012 L
s
.678 .847 .902 r
.58951 .08012 m
.58951 .11162 L
.58997 .11162 L
.58997 .08012 L
F
.2 .63 .79 r
.58951 .08012 m
.58951 .11162 L
.58997 .11162 L
.58997 .08012 L
s
.678 .847 .902 r
.58997 .08012 m
.58997 .11134 L
.59042 .11134 L
.59042 .08012 L
F
.2 .63 .79 r
.58997 .08012 m
.58997 .11134 L
.59042 .11134 L
.59042 .08012 L
s
.678 .847 .902 r
.59042 .08012 m
.59042 .11117 L
.59068 .11117 L
.59068 .08012 L
F
.2 .63 .79 r
.59042 .08012 m
.59042 .11117 L
.59068 .11117 L
.59068 .08012 L
s
.678 .847 .902 r
.59068 .08012 m
.59068 .11104 L
.59099 .11104 L
.59099 .08012 L
F
.2 .63 .79 r
.59068 .08012 m
.59068 .11104 L
.59099 .11104 L
.59099 .08012 L
s
.678 .847 .902 r
.59099 .08012 m
.59099 .11093 L
.59139 .11093 L
.59139 .08012 L
F
.2 .63 .79 r
.59099 .08012 m
.59099 .11093 L
.59139 .11093 L
.59139 .08012 L
s
.678 .847 .902 r
.59139 .08012 m
.59139 .11075 L
.59158 .11075 L
.59158 .08012 L
F
.2 .63 .79 r
.59139 .08012 m
.59139 .11075 L
.59158 .11075 L
.59158 .08012 L
s
.678 .847 .902 r
.59158 .08012 m
.59158 .11066 L
.59193 .11066 L
.59193 .08012 L
F
.2 .63 .79 r
.59158 .08012 m
.59158 .11066 L
.59193 .11066 L
.59193 .08012 L
s
.678 .847 .902 r
.59193 .08012 m
.59193 .11051 L
.59233 .11051 L
.59233 .08012 L
F
.2 .63 .79 r
.59193 .08012 m
.59193 .11051 L
.59233 .11051 L
.59233 .08012 L
s
.678 .847 .902 r
.59233 .08012 m
.59233 .11034 L
.59256 .11034 L
.59256 .08012 L
F
.2 .63 .79 r
.59233 .08012 m
.59233 .11034 L
.59256 .11034 L
.59256 .08012 L
s
.678 .847 .902 r
.59256 .08012 m
.59256 .11021 L
.59281 .11021 L
.59281 .08012 L
F
.2 .63 .79 r
.59256 .08012 m
.59256 .11021 L
.59281 .11021 L
.59281 .08012 L
s
.678 .847 .902 r
.59281 .08012 m
.59281 .11004 L
.59296 .11004 L
.59296 .08012 L
F
.2 .63 .79 r
.59281 .08012 m
.59281 .11004 L
.59296 .11004 L
.59296 .08012 L
s
.678 .847 .902 r
.59296 .08012 m
.59296 .10999 L
.59322 .10999 L
.59322 .08012 L
F
.2 .63 .79 r
.59296 .08012 m
.59296 .10999 L
.59322 .10999 L
.59322 .08012 L
s
.678 .847 .902 r
.59322 .08012 m
.59322 .10987 L
.59369 .10987 L
.59369 .08012 L
F
.2 .63 .79 r
.59322 .08012 m
.59322 .10987 L
.59369 .10987 L
.59369 .08012 L
s
.678 .847 .902 r
.59369 .08012 m
.59369 .10957 L
.59389 .10957 L
.59389 .08012 L
F
.2 .63 .79 r
.59369 .08012 m
.59369 .10957 L
.59389 .10957 L
.59389 .08012 L
s
.678 .847 .902 r
.59389 .08012 m
.59389 .1095 L
.59429 .1095 L
.59429 .08012 L
F
.2 .63 .79 r
.59389 .08012 m
.59389 .1095 L
.59429 .1095 L
.59429 .08012 L
s
.678 .847 .902 r
.59429 .08012 m
.59429 .10929 L
.59446 .10929 L
.59446 .08012 L
F
.2 .63 .79 r
.59429 .08012 m
.59429 .10929 L
.59446 .10929 L
.59446 .08012 L
s
.678 .847 .902 r
.59446 .08012 m
.59446 .10922 L
.59461 .10922 L
.59461 .08012 L
F
.2 .63 .79 r
.59446 .08012 m
.59446 .10922 L
.59461 .10922 L
.59461 .08012 L
s
.678 .847 .902 r
.59461 .08012 m
.59461 .1092 L
.59485 .1092 L
.59485 .08012 L
F
.2 .63 .79 r
.59461 .08012 m
.59461 .1092 L
.59485 .1092 L
.59485 .08012 L
s
.678 .847 .902 r
.59485 .08012 m
.59485 .10905 L
.5952 .10905 L
.5952 .08012 L
F
.2 .63 .79 r
.59485 .08012 m
.59485 .10905 L
.5952 .10905 L
.5952 .08012 L
s
.678 .847 .902 r
.5952 .08012 m
.5952 .10882 L
.59565 .10882 L
.59565 .08012 L
F
.2 .63 .79 r
.5952 .08012 m
.5952 .10882 L
.59565 .10882 L
.59565 .08012 L
s
.678 .847 .902 r
.59565 .08012 m
.59565 .10851 L
.59609 .10851 L
.59609 .08012 L
F
.2 .63 .79 r
.59565 .08012 m
.59565 .10851 L
.59609 .10851 L
.59609 .08012 L
s
.678 .847 .902 r
.59609 .08012 m
.59609 .10836 L
.59638 .10836 L
.59638 .08012 L
F
.2 .63 .79 r
.59609 .08012 m
.59609 .10836 L
.59638 .10836 L
.59638 .08012 L
s
.678 .847 .902 r
.59638 .08012 m
.59638 .10828 L
.59674 .10828 L
.59674 .08012 L
F
.2 .63 .79 r
.59638 .08012 m
.59638 .10828 L
.59674 .10828 L
.59674 .08012 L
s
.678 .847 .902 r
.59674 .08012 m
.59674 .10807 L
.597 .10807 L
.597 .08012 L
F
.2 .63 .79 r
.59674 .08012 m
.59674 .10807 L
.597 .10807 L
.597 .08012 L
s
.678 .847 .902 r
.597 .08012 m
.597 .10796 L
.59747 .10796 L
.59747 .08012 L
F
.2 .63 .79 r
.597 .08012 m
.597 .10796 L
.59747 .10796 L
.59747 .08012 L
s
.678 .847 .902 r
.59747 .08012 m
.59747 .10763 L
.59781 .10763 L
.59781 .08012 L
F
.2 .63 .79 r
.59747 .08012 m
.59747 .10763 L
.59781 .10763 L
.59781 .08012 L
s
.678 .847 .902 r
.59781 .08012 m
.59781 .10759 L
.59805 .10759 L
.59805 .08012 L
F
.2 .63 .79 r
.59781 .08012 m
.59781 .10759 L
.59805 .10759 L
.59805 .08012 L
s
.678 .847 .902 r
.59805 .08012 m
.59805 .10731 L
.59849 .10731 L
.59849 .08012 L
F
.2 .63 .79 r
.59805 .08012 m
.59805 .10731 L
.59849 .10731 L
.59849 .08012 L
s
.678 .847 .902 r
.59849 .08012 m
.59849 .10719 L
.59872 .10719 L
.59872 .08012 L
F
.2 .63 .79 r
.59849 .08012 m
.59849 .10719 L
.59872 .10719 L
.59872 .08012 L
s
.678 .847 .902 r
.59872 .08012 m
.59872 .10713 L
.59901 .10713 L
.59901 .08012 L
F
.2 .63 .79 r
.59872 .08012 m
.59872 .10713 L
.59901 .10713 L
.59901 .08012 L
s
.678 .847 .902 r
.59901 .08012 m
.59901 .10703 L
.5994 .10703 L
.5994 .08012 L
F
.2 .63 .79 r
.59901 .08012 m
.59901 .10703 L
.5994 .10703 L
.5994 .08012 L
s
.678 .847 .902 r
.5994 .08012 m
.5994 .10678 L
.59959 .10678 L
.59959 .08012 L
F
.2 .63 .79 r
.5994 .08012 m
.5994 .10678 L
.59959 .10678 L
.59959 .08012 L
s
.678 .847 .902 r
.59959 .08012 m
.59959 .10653 L
.60007 .10653 L
.60007 .08012 L
F
.2 .63 .79 r
.59959 .08012 m
.59959 .10653 L
.60007 .10653 L
.60007 .08012 L
s
.678 .847 .902 r
.60007 .08012 m
.60007 .10649 L
.60026 .10649 L
.60026 .08012 L
F
.2 .63 .79 r
.60007 .08012 m
.60007 .10649 L
.60026 .10649 L
.60026 .08012 L
s
.678 .847 .902 r
.60026 .08012 m
.60026 .10638 L
.60065 .10638 L
.60065 .08012 L
F
.2 .63 .79 r
.60026 .08012 m
.60026 .10638 L
.60065 .10638 L
.60065 .08012 L
s
.678 .847 .902 r
.60065 .08012 m
.60065 .10613 L
.60107 .10613 L
.60107 .08012 L
F
.2 .63 .79 r
.60065 .08012 m
.60065 .10613 L
.60107 .10613 L
.60107 .08012 L
s
.678 .847 .902 r
.60107 .08012 m
.60107 .10597 L
.60123 .10597 L
.60123 .08012 L
F
.2 .63 .79 r
.60107 .08012 m
.60107 .10597 L
.60123 .10597 L
.60123 .08012 L
s
.678 .847 .902 r
.60123 .08012 m
.60123 .10586 L
.60171 .10586 L
.60171 .08012 L
F
.2 .63 .79 r
.60123 .08012 m
.60123 .10586 L
.60171 .10586 L
.60171 .08012 L
s
.678 .847 .902 r
.60171 .08012 m
.60171 .1055 L
.60219 .1055 L
.60219 .08012 L
F
.2 .63 .79 r
.60171 .08012 m
.60171 .1055 L
.60219 .1055 L
.60219 .08012 L
s
.678 .847 .902 r
.60219 .08012 m
.60219 .10535 L
.60259 .10535 L
.60259 .08012 L
F
.2 .63 .79 r
.60219 .08012 m
.60219 .10535 L
.60259 .10535 L
.60259 .08012 L
s
.678 .847 .902 r
.60259 .08012 m
.60259 .10529 L
.60275 .10529 L
.60275 .08012 L
F
.2 .63 .79 r
.60259 .08012 m
.60259 .10529 L
.60275 .10529 L
.60275 .08012 L
s
.678 .847 .902 r
.60275 .08012 m
.60275 .10515 L
.60313 .10515 L
.60313 .08012 L
F
.2 .63 .79 r
.60275 .08012 m
.60275 .10515 L
.60313 .10515 L
.60313 .08012 L
s
.678 .847 .902 r
.60313 .08012 m
.60313 .10493 L
.60341 .10493 L
.60341 .08012 L
F
.2 .63 .79 r
.60313 .08012 m
.60313 .10493 L
.60341 .10493 L
.60341 .08012 L
s
.678 .847 .902 r
.60341 .08012 m
.60341 .10482 L
.60386 .10482 L
.60386 .08012 L
F
.2 .63 .79 r
.60341 .08012 m
.60341 .10482 L
.60386 .10482 L
.60386 .08012 L
s
.678 .847 .902 r
.60386 .08012 m
.60386 .10465 L
.60407 .10465 L
.60407 .08012 L
F
.2 .63 .79 r
.60386 .08012 m
.60386 .10465 L
.60407 .10465 L
.60407 .08012 L
s
.678 .847 .902 r
.60407 .08012 m
.60407 .10451 L
.60431 .10451 L
.60431 .08012 L
F
.2 .63 .79 r
.60407 .08012 m
.60407 .10451 L
.60431 .10451 L
.60431 .08012 L
s
.678 .847 .902 r
.60431 .08012 m
.60431 .10435 L
.60472 .10435 L
.60472 .08012 L
F
.2 .63 .79 r
.60431 .08012 m
.60431 .10435 L
.60472 .10435 L
.60472 .08012 L
s
.678 .847 .902 r
.60472 .08012 m
.60472 .10415 L
.60506 .10415 L
.60506 .08012 L
F
.2 .63 .79 r
.60472 .08012 m
.60472 .10415 L
.60506 .10415 L
.60506 .08012 L
s
.678 .847 .902 r
.60506 .08012 m
.60506 .104 L
.60528 .104 L
.60528 .08012 L
F
.2 .63 .79 r
.60506 .08012 m
.60506 .104 L
.60528 .104 L
.60528 .08012 L
s
.678 .847 .902 r
.60528 .08012 m
.60528 .10387 L
.60568 .10387 L
.60568 .08012 L
F
.2 .63 .79 r
.60528 .08012 m
.60528 .10387 L
.60568 .10387 L
.60568 .08012 L
s
.678 .847 .902 r
.60568 .08012 m
.60568 .10377 L
.606 .10377 L
.606 .08012 L
F
.2 .63 .79 r
.60568 .08012 m
.60568 .10377 L
.606 .10377 L
.606 .08012 L
s
.678 .847 .902 r
.606 .08012 m
.606 .1035 L
.60639 .1035 L
.60639 .08012 L
F
.2 .63 .79 r
.606 .08012 m
.606 .1035 L
.60639 .1035 L
.60639 .08012 L
s
.678 .847 .902 r
.60639 .08012 m
.60639 .10346 L
.60688 .10346 L
.60688 .08012 L
F
.2 .63 .79 r
.60639 .08012 m
.60639 .10346 L
.60688 .10346 L
.60688 .08012 L
s
.678 .847 .902 r
.60688 .08012 m
.60688 .10319 L
.60714 .10319 L
.60714 .08012 L
F
.2 .63 .79 r
.60688 .08012 m
.60688 .10319 L
.60714 .10319 L
.60714 .08012 L
s
.678 .847 .902 r
.60714 .08012 m
.60714 .10307 L
.60755 .10307 L
.60755 .08012 L
F
.2 .63 .79 r
.60714 .08012 m
.60714 .10307 L
.60755 .10307 L
.60755 .08012 L
s
.678 .847 .902 r
.60755 .08012 m
.60755 .1029 L
.6079 .1029 L
.6079 .08012 L
F
.2 .63 .79 r
.60755 .08012 m
.60755 .1029 L
.6079 .1029 L
.6079 .08012 L
s
.678 .847 .902 r
.6079 .08012 m
.6079 .10273 L
.60805 .10273 L
.60805 .08012 L
F
.2 .63 .79 r
.6079 .08012 m
.6079 .10273 L
.60805 .10273 L
.60805 .08012 L
s
.678 .847 .902 r
.60805 .08012 m
.60805 .10256 L
.60828 .10256 L
.60828 .08012 L
F
.2 .63 .79 r
.60805 .08012 m
.60805 .10256 L
.60828 .10256 L
.60828 .08012 L
s
.678 .847 .902 r
.60828 .08012 m
.60828 .10248 L
.60845 .10248 L
.60845 .08012 L
F
.2 .63 .79 r
.60828 .08012 m
.60828 .10248 L
.60845 .10248 L
.60845 .08012 L
s
.678 .847 .902 r
.60845 .08012 m
.60845 .10237 L
.60887 .10237 L
.60887 .08012 L
F
.2 .63 .79 r
.60845 .08012 m
.60845 .10237 L
.60887 .10237 L
.60887 .08012 L
s
.678 .847 .902 r
.60887 .08012 m
.60887 .10221 L
.60935 .10221 L
.60935 .08012 L
F
.2 .63 .79 r
.60887 .08012 m
.60887 .10221 L
.60935 .10221 L
.60935 .08012 L
s
.678 .847 .902 r
.60935 .08012 m
.60935 .10198 L
.60959 .10198 L
.60959 .08012 L
F
.2 .63 .79 r
.60935 .08012 m
.60935 .10198 L
.60959 .10198 L
.60959 .08012 L
s
.678 .847 .902 r
.60959 .08012 m
.60959 .10184 L
.60978 .10184 L
.60978 .08012 L
F
.2 .63 .79 r
.60959 .08012 m
.60959 .10184 L
.60978 .10184 L
.60978 .08012 L
s
.678 .847 .902 r
.60978 .08012 m
.60978 .10178 L
.60994 .10178 L
.60994 .08012 L
F
.2 .63 .79 r
.60978 .08012 m
.60978 .10178 L
.60994 .10178 L
.60994 .08012 L
s
.678 .847 .902 r
.60994 .08012 m
.60994 .10171 L
.61042 .10171 L
.61042 .08012 L
F
.2 .63 .79 r
.60994 .08012 m
.60994 .10171 L
.61042 .10171 L
.61042 .08012 L
s
.678 .847 .902 r
.61042 .08012 m
.61042 .1015 L
.61076 .1015 L
.61076 .08012 L
F
.2 .63 .79 r
.61042 .08012 m
.61042 .1015 L
.61076 .1015 L
.61076 .08012 L
s
.678 .847 .902 r
.61076 .08012 m
.61076 .10134 L
.61116 .10134 L
.61116 .08012 L
F
.2 .63 .79 r
.61076 .08012 m
.61076 .10134 L
.61116 .10134 L
.61116 .08012 L
s
.678 .847 .902 r
.61116 .08012 m
.61116 .10113 L
.61137 .10113 L
.61137 .08012 L
F
.2 .63 .79 r
.61116 .08012 m
.61116 .10113 L
.61137 .10113 L
.61137 .08012 L
s
.678 .847 .902 r
.61137 .08012 m
.61137 .10089 L
.61178 .10089 L
.61178 .08012 L
F
.2 .63 .79 r
.61137 .08012 m
.61137 .10089 L
.61178 .10089 L
.61178 .08012 L
s
.678 .847 .902 r
.61178 .08012 m
.61178 .10081 L
.61204 .10081 L
.61204 .08012 L
F
.2 .63 .79 r
.61178 .08012 m
.61178 .10081 L
.61204 .10081 L
.61204 .08012 L
s
.678 .847 .902 r
.61204 .08012 m
.61204 .10062 L
.61252 .10062 L
.61252 .08012 L
F
.2 .63 .79 r
.61204 .08012 m
.61204 .10062 L
.61252 .10062 L
.61252 .08012 L
s
.678 .847 .902 r
.61252 .08012 m
.61252 .1004 L
.61288 .1004 L
.61288 .08012 L
F
.2 .63 .79 r
.61252 .08012 m
.61252 .1004 L
.61288 .1004 L
.61288 .08012 L
s
.678 .847 .902 r
.61288 .08012 m
.61288 .10037 L
.61322 .10037 L
.61322 .08012 L
F
.2 .63 .79 r
.61288 .08012 m
.61288 .10037 L
.61322 .10037 L
.61322 .08012 L
s
.678 .847 .902 r
.61322 .08012 m
.61322 .10021 L
.61356 .10021 L
.61356 .08012 L
F
.2 .63 .79 r
.61322 .08012 m
.61322 .10021 L
.61356 .10021 L
.61356 .08012 L
s
.678 .847 .902 r
.61356 .08012 m
.61356 .09998 L
.61387 .09998 L
.61387 .08012 L
F
.2 .63 .79 r
.61356 .08012 m
.61356 .09998 L
.61387 .09998 L
.61387 .08012 L
s
.678 .847 .902 r
.61387 .08012 m
.61387 .09989 L
.61433 .09989 L
.61433 .08012 L
F
.2 .63 .79 r
.61387 .08012 m
.61387 .09989 L
.61433 .09989 L
.61433 .08012 L
s
.678 .847 .902 r
.61433 .08012 m
.61433 .09968 L
.61468 .09968 L
.61468 .08012 L
F
.2 .63 .79 r
.61433 .08012 m
.61433 .09968 L
.61468 .09968 L
.61468 .08012 L
s
.678 .847 .902 r
.61468 .08012 m
.61468 .09944 L
.61491 .09944 L
.61491 .08012 L
F
.2 .63 .79 r
.61468 .08012 m
.61468 .09944 L
.61491 .09944 L
.61491 .08012 L
s
.678 .847 .902 r
.61491 .08012 m
.61491 .09936 L
.6153 .09936 L
.6153 .08012 L
F
.2 .63 .79 r
.61491 .08012 m
.61491 .09936 L
.6153 .09936 L
.6153 .08012 L
s
.678 .847 .902 r
.6153 .08012 m
.6153 .09923 L
.61556 .09923 L
.61556 .08012 L
F
.2 .63 .79 r
.6153 .08012 m
.6153 .09923 L
.61556 .09923 L
.61556 .08012 L
s
.678 .847 .902 r
.61556 .08012 m
.61556 .09896 L
.6159 .09896 L
.6159 .08012 L
F
.2 .63 .79 r
.61556 .08012 m
.61556 .09896 L
.6159 .09896 L
.6159 .08012 L
s
.678 .847 .902 r
.6159 .08012 m
.6159 .09889 L
.61606 .09889 L
.61606 .08012 L
F
.2 .63 .79 r
.6159 .08012 m
.6159 .09889 L
.61606 .09889 L
.61606 .08012 L
s
.678 .847 .902 r
.61606 .08012 m
.61606 .09881 L
.61642 .09881 L
.61642 .08012 L
F
.2 .63 .79 r
.61606 .08012 m
.61606 .09881 L
.61642 .09881 L
.61642 .08012 L
s
.678 .847 .902 r
.61642 .08012 m
.61642 .09863 L
.61675 .09863 L
.61675 .08012 L
F
.2 .63 .79 r
.61642 .08012 m
.61642 .09863 L
.61675 .09863 L
.61675 .08012 L
s
.678 .847 .902 r
.61675 .08012 m
.61675 .09844 L
.6171 .09844 L
.6171 .08012 L
F
.2 .63 .79 r
.61675 .08012 m
.61675 .09844 L
.6171 .09844 L
.6171 .08012 L
s
.678 .847 .902 r
.6171 .08012 m
.6171 .09835 L
.61752 .09835 L
.61752 .08012 L
F
.2 .63 .79 r
.6171 .08012 m
.6171 .09835 L
.61752 .09835 L
.61752 .08012 L
s
.678 .847 .902 r
.61752 .08012 m
.61752 .09814 L
.61783 .09814 L
.61783 .08012 L
F
.2 .63 .79 r
.61752 .08012 m
.61752 .09814 L
.61783 .09814 L
.61783 .08012 L
s
.678 .847 .902 r
.61783 .08012 m
.61783 .09795 L
.61815 .09795 L
.61815 .08012 L
F
.2 .63 .79 r
.61783 .08012 m
.61783 .09795 L
.61815 .09795 L
.61815 .08012 L
s
.678 .847 .902 r
.61815 .08012 m
.61815 .09782 L
.61852 .09782 L
.61852 .08012 L
F
.2 .63 .79 r
.61815 .08012 m
.61815 .09782 L
.61852 .09782 L
.61852 .08012 L
s
.678 .847 .902 r
.61852 .08012 m
.61852 .09763 L
.61875 .09763 L
.61875 .08012 L
F
.2 .63 .79 r
.61852 .08012 m
.61852 .09763 L
.61875 .09763 L
.61875 .08012 L
s
.678 .847 .902 r
.61875 .08012 m
.61875 .09758 L
.61915 .09758 L
.61915 .08012 L
F
.2 .63 .79 r
.61875 .08012 m
.61875 .09758 L
.61915 .09758 L
.61915 .08012 L
s
.678 .847 .902 r
.61915 .08012 m
.61915 .09742 L
.6194 .09742 L
.6194 .08012 L
F
.2 .63 .79 r
.61915 .08012 m
.61915 .09742 L
.6194 .09742 L
.6194 .08012 L
s
.678 .847 .902 r
.6194 .08012 m
.6194 .09722 L
.61986 .09722 L
.61986 .08012 L
F
.2 .63 .79 r
.6194 .08012 m
.6194 .09722 L
.61986 .09722 L
.61986 .08012 L
s
.678 .847 .902 r
.61986 .08012 m
.61986 .09704 L
.62032 .09704 L
.62032 .08012 L
F
.2 .63 .79 r
.61986 .08012 m
.61986 .09704 L
.62032 .09704 L
.62032 .08012 L
s
.678 .847 .902 r
.62032 .08012 m
.62032 .09679 L
.62073 .09679 L
.62073 .08012 L
F
.2 .63 .79 r
.62032 .08012 m
.62032 .09679 L
.62073 .09679 L
.62073 .08012 L
s
.678 .847 .902 r
.62073 .08012 m
.62073 .09664 L
.62112 .09664 L
.62112 .08012 L
F
.2 .63 .79 r
.62073 .08012 m
.62073 .09664 L
.62112 .09664 L
.62112 .08012 L
s
.678 .847 .902 r
.62112 .08012 m
.62112 .09648 L
.62138 .09648 L
.62138 .08012 L
F
.2 .63 .79 r
.62112 .08012 m
.62112 .09648 L
.62138 .09648 L
.62138 .08012 L
s
.678 .847 .902 r
.62138 .08012 m
.62138 .09637 L
.62165 .09637 L
.62165 .08012 L
F
.2 .63 .79 r
.62138 .08012 m
.62138 .09637 L
.62165 .09637 L
.62165 .08012 L
s
.678 .847 .902 r
.62165 .08012 m
.62165 .09628 L
.62189 .09628 L
.62189 .08012 L
F
.2 .63 .79 r
.62165 .08012 m
.62165 .09628 L
.62189 .09628 L
.62189 .08012 L
s
.678 .847 .902 r
.62189 .08012 m
.62189 .09611 L
.62231 .09611 L
.62231 .08012 L
F
.2 .63 .79 r
.62189 .08012 m
.62189 .09611 L
.62231 .09611 L
.62231 .08012 L
s
.678 .847 .902 r
.62231 .08012 m
.62231 .0959 L
.62272 .0959 L
.62272 .08012 L
F
.2 .63 .79 r
.62231 .08012 m
.62231 .0959 L
.62272 .0959 L
.62272 .08012 L
s
.678 .847 .902 r
.62272 .08012 m
.62272 .09574 L
.6229 .09574 L
.6229 .08012 L
F
.2 .63 .79 r
.62272 .08012 m
.62272 .09574 L
.6229 .09574 L
.6229 .08012 L
s
.678 .847 .902 r
.6229 .08012 m
.6229 .09558 L
.62326 .09558 L
.62326 .08012 L
F
.2 .63 .79 r
.6229 .08012 m
.6229 .09558 L
.62326 .09558 L
.62326 .08012 L
s
.678 .847 .902 r
.62326 .08012 m
.62326 .0955 L
.62356 .0955 L
.62356 .08012 L
F
.2 .63 .79 r
.62326 .08012 m
.62326 .0955 L
.62356 .0955 L
.62356 .08012 L
s
.678 .847 .902 r
.62356 .08012 m
.62356 .09536 L
.62378 .09536 L
.62378 .08012 L
F
.2 .63 .79 r
.62356 .08012 m
.62356 .09536 L
.62378 .09536 L
.62378 .08012 L
s
.678 .847 .902 r
.62378 .08012 m
.62378 .09525 L
.62394 .09525 L
.62394 .08012 L
F
.2 .63 .79 r
.62378 .08012 m
.62378 .09525 L
.62394 .09525 L
.62394 .08012 L
s
.678 .847 .902 r
.62394 .08012 m
.62394 .0952 L
.62409 .0952 L
.62409 .08012 L
F
.2 .63 .79 r
.62394 .08012 m
.62394 .0952 L
.62409 .0952 L
.62409 .08012 L
s
.678 .847 .902 r
.62409 .08012 m
.62409 .095 L
.62456 .095 L
.62456 .08012 L
F
.2 .63 .79 r
.62409 .08012 m
.62409 .095 L
.62456 .095 L
.62456 .08012 L
s
.678 .847 .902 r
.62456 .08012 m
.62456 .09482 L
.62491 .09482 L
.62491 .08012 L
F
.2 .63 .79 r
.62456 .08012 m
.62456 .09482 L
.62491 .09482 L
.62491 .08012 L
s
.678 .847 .902 r
.62491 .08012 m
.62491 .09472 L
.62515 .09472 L
.62515 .08012 L
F
.2 .63 .79 r
.62491 .08012 m
.62491 .09472 L
.62515 .09472 L
.62515 .08012 L
s
.678 .847 .902 r
.62515 .08012 m
.62515 .09468 L
.62548 .09468 L
.62548 .08012 L
F
.2 .63 .79 r
.62515 .08012 m
.62515 .09468 L
.62548 .09468 L
.62548 .08012 L
s
.678 .847 .902 r
.62548 .08012 m
.62548 .09452 L
.62577 .09452 L
.62577 .08012 L
F
.2 .63 .79 r
.62548 .08012 m
.62548 .09452 L
.62577 .09452 L
.62577 .08012 L
s
.678 .847 .902 r
.62577 .08012 m
.62577 .09433 L
.62625 .09433 L
.62625 .08012 L
F
.2 .63 .79 r
.62577 .08012 m
.62577 .09433 L
.62625 .09433 L
.62625 .08012 L
s
.678 .847 .902 r
.62625 .08012 m
.62625 .09413 L
.62641 .09413 L
.62641 .08012 L
F
.2 .63 .79 r
.62625 .08012 m
.62625 .09413 L
.62641 .09413 L
.62641 .08012 L
s
.678 .847 .902 r
.62641 .08012 m
.62641 .09396 L
.62684 .09396 L
.62684 .08012 L
F
.2 .63 .79 r
.62641 .08012 m
.62641 .09396 L
.62684 .09396 L
.62684 .08012 L
s
.678 .847 .902 r
.62684 .08012 m
.62684 .09384 L
.62702 .09384 L
.62702 .08012 L
F
.2 .63 .79 r
.62684 .08012 m
.62684 .09384 L
.62702 .09384 L
.62702 .08012 L
s
.678 .847 .902 r
.62702 .08012 m
.62702 .09377 L
.62719 .09377 L
.62719 .08012 L
F
.2 .63 .79 r
.62702 .08012 m
.62702 .09377 L
.62719 .09377 L
.62719 .08012 L
s
.678 .847 .902 r
.62719 .08012 m
.62719 .09373 L
.62738 .09373 L
.62738 .08012 L
F
.2 .63 .79 r
.62719 .08012 m
.62719 .09373 L
.62738 .09373 L
.62738 .08012 L
s
.678 .847 .902 r
.62738 .08012 m
.62738 .09365 L
.62754 .09365 L
.62754 .08012 L
F
.2 .63 .79 r
.62738 .08012 m
.62738 .09365 L
.62754 .09365 L
.62754 .08012 L
s
.678 .847 .902 r
.62754 .08012 m
.62754 .09354 L
.62783 .09354 L
.62783 .08012 L
F
.2 .63 .79 r
.62754 .08012 m
.62754 .09354 L
.62783 .09354 L
.62783 .08012 L
s
.678 .847 .902 r
.62783 .08012 m
.62783 .09339 L
.62824 .09339 L
.62824 .08012 L
F
.2 .63 .79 r
.62783 .08012 m
.62783 .09339 L
.62824 .09339 L
.62824 .08012 L
s
.678 .847 .902 r
.62824 .08012 m
.62824 .0931 L
.62865 .0931 L
.62865 .08012 L
F
.2 .63 .79 r
.62824 .08012 m
.62824 .0931 L
.62865 .0931 L
.62865 .08012 L
s
.678 .847 .902 r
.62865 .08012 m
.62865 .09308 L
.62906 .09308 L
.62906 .08012 L
F
.2 .63 .79 r
.62865 .08012 m
.62865 .09308 L
.62906 .09308 L
.62906 .08012 L
s
.678 .847 .902 r
.62906 .08012 m
.62906 .09289 L
.62941 .09289 L
.62941 .08012 L
F
.2 .63 .79 r
.62906 .08012 m
.62906 .09289 L
.62941 .09289 L
.62941 .08012 L
s
.678 .847 .902 r
.62941 .08012 m
.62941 .09254 L
.6299 .09254 L
.6299 .08012 L
F
.2 .63 .79 r
.62941 .08012 m
.62941 .09254 L
.6299 .09254 L
.6299 .08012 L
s
.678 .847 .902 r
.6299 .08012 m
.6299 .09246 L
.63029 .09246 L
.63029 .08012 L
F
.2 .63 .79 r
.6299 .08012 m
.6299 .09246 L
.63029 .09246 L
.63029 .08012 L
s
.678 .847 .902 r
.63029 .08012 m
.63029 .09233 L
.63048 .09233 L
.63048 .08012 L
F
.2 .63 .79 r
.63029 .08012 m
.63029 .09233 L
.63048 .09233 L
.63048 .08012 L
s
.678 .847 .902 r
.63048 .08012 m
.63048 .0922 L
.63068 .0922 L
.63068 .08012 L
F
.2 .63 .79 r
.63048 .08012 m
.63048 .0922 L
.63068 .0922 L
.63068 .08012 L
s
.678 .847 .902 r
.63068 .08012 m
.63068 .09209 L
.63111 .09209 L
.63111 .08012 L
F
.2 .63 .79 r
.63068 .08012 m
.63068 .09209 L
.63111 .09209 L
.63111 .08012 L
s
.678 .847 .902 r
.63111 .08012 m
.63111 .0919 L
.63148 .0919 L
.63148 .08012 L
F
.2 .63 .79 r
.63111 .08012 m
.63111 .0919 L
.63148 .0919 L
.63148 .08012 L
s
.678 .847 .902 r
.63148 .08012 m
.63148 .09175 L
.63167 .09175 L
.63167 .08012 L
F
.2 .63 .79 r
.63148 .08012 m
.63148 .09175 L
.63167 .09175 L
.63167 .08012 L
s
.678 .847 .902 r
.63167 .08012 m
.63167 .09174 L
.6319 .09174 L
.6319 .08012 L
F
.2 .63 .79 r
.63167 .08012 m
.63167 .09174 L
.6319 .09174 L
.6319 .08012 L
s
.678 .847 .902 r
.6319 .08012 m
.6319 .09157 L
.63211 .09157 L
.63211 .08012 L
F
.2 .63 .79 r
.6319 .08012 m
.6319 .09157 L
.63211 .09157 L
.63211 .08012 L
s
.678 .847 .902 r
.63211 .08012 m
.63211 .09142 L
.63239 .09142 L
.63239 .08012 L
F
.2 .63 .79 r
.63211 .08012 m
.63211 .09142 L
.63239 .09142 L
.63239 .08012 L
s
.678 .847 .902 r
.63239 .08012 m
.63239 .09128 L
.63275 .09128 L
.63275 .08012 L
F
.2 .63 .79 r
.63239 .08012 m
.63239 .09128 L
.63275 .09128 L
.63275 .08012 L
s
.678 .847 .902 r
.63275 .08012 m
.63275 .09108 L
.63317 .09108 L
.63317 .08012 L
F
.2 .63 .79 r
.63275 .08012 m
.63275 .09108 L
.63317 .09108 L
.63317 .08012 L
s
.678 .847 .902 r
.63317 .08012 m
.63317 .09103 L
.6334 .09103 L
.6334 .08012 L
F
.2 .63 .79 r
.63317 .08012 m
.63317 .09103 L
.6334 .09103 L
.6334 .08012 L
s
.678 .847 .902 r
.6334 .08012 m
.6334 .09093 L
.63367 .09093 L
.63367 .08012 L
F
.2 .63 .79 r
.6334 .08012 m
.6334 .09093 L
.63367 .09093 L
.63367 .08012 L
s
.678 .847 .902 r
.63367 .08012 m
.63367 .09084 L
.63409 .09084 L
.63409 .08012 L
F
.2 .63 .79 r
.63367 .08012 m
.63367 .09084 L
.63409 .09084 L
.63409 .08012 L
s
.678 .847 .902 r
.63409 .08012 m
.63409 .09065 L
.63449 .09065 L
.63449 .08012 L
F
.2 .63 .79 r
.63409 .08012 m
.63409 .09065 L
.63449 .09065 L
.63449 .08012 L
s
.678 .847 .902 r
.63449 .08012 m
.63449 .09044 L
.63469 .09044 L
.63469 .08012 L
F
.2 .63 .79 r
.63449 .08012 m
.63449 .09044 L
.63469 .09044 L
.63469 .08012 L
s
.678 .847 .902 r
.63469 .08012 m
.63469 .0903 L
.63492 .0903 L
.63492 .08012 L
F
.2 .63 .79 r
.63469 .08012 m
.63469 .0903 L
.63492 .0903 L
.63492 .08012 L
s
.678 .847 .902 r
.63492 .08012 m
.63492 .09014 L
.63532 .09014 L
.63532 .08012 L
F
.2 .63 .79 r
.63492 .08012 m
.63492 .09014 L
.63532 .09014 L
.63532 .08012 L
s
.678 .847 .902 r
.63532 .08012 m
.63532 .09005 L
.63558 .09005 L
.63558 .08012 L
F
.2 .63 .79 r
.63532 .08012 m
.63532 .09005 L
.63558 .09005 L
.63558 .08012 L
s
.678 .847 .902 r
.63558 .08012 m
.63558 .08999 L
.63587 .08999 L
.63587 .08012 L
F
.2 .63 .79 r
.63558 .08012 m
.63558 .08999 L
.63587 .08999 L
.63587 .08012 L
s
.678 .847 .902 r
.63587 .08012 m
.63587 .08987 L
.63617 .08987 L
.63617 .08012 L
F
.2 .63 .79 r
.63587 .08012 m
.63587 .08987 L
.63617 .08987 L
.63617 .08012 L
s
.678 .847 .902 r
.63617 .08012 m
.63617 .08969 L
.63632 .08969 L
.63632 .08012 L
F
.2 .63 .79 r
.63617 .08012 m
.63617 .08969 L
.63632 .08969 L
.63632 .08012 L
s
.678 .847 .902 r
.63632 .08012 m
.63632 .0896 L
.63671 .0896 L
.63671 .08012 L
F
.2 .63 .79 r
.63632 .08012 m
.63632 .0896 L
.63671 .0896 L
.63671 .08012 L
s
.678 .847 .902 r
.63671 .08012 m
.63671 .08948 L
.637 .08948 L
.637 .08012 L
F
.2 .63 .79 r
.63671 .08012 m
.63671 .08948 L
.637 .08948 L
.637 .08012 L
s
.678 .847 .902 r
.637 .08012 m
.637 .08926 L
.63742 .08926 L
.63742 .08012 L
F
.2 .63 .79 r
.637 .08012 m
.637 .08926 L
.63742 .08926 L
.63742 .08012 L
s
.678 .847 .902 r
.63742 .08012 m
.63742 .08911 L
.63786 .08911 L
.63786 .08012 L
F
.2 .63 .79 r
.63742 .08012 m
.63742 .08911 L
.63786 .08911 L
.63786 .08012 L
s
.678 .847 .902 r
.63786 .08012 m
.63786 .0889 L
.6382 .0889 L
.6382 .08012 L
F
.2 .63 .79 r
.63786 .08012 m
.63786 .0889 L
.6382 .0889 L
.6382 .08012 L
s
.678 .847 .902 r
.6382 .08012 m
.6382 .08875 L
.63856 .08875 L
.63856 .08012 L
F
.2 .63 .79 r
.6382 .08012 m
.6382 .08875 L
.63856 .08875 L
.63856 .08012 L
s
.678 .847 .902 r
.63856 .08012 m
.63856 .08869 L
.63875 .08869 L
.63875 .08012 L
F
.2 .63 .79 r
.63856 .08012 m
.63856 .08869 L
.63875 .08869 L
.63875 .08012 L
s
.678 .847 .902 r
.63875 .08012 m
.63875 .08851 L
.63915 .08851 L
.63915 .08012 L
F
.2 .63 .79 r
.63875 .08012 m
.63875 .08851 L
.63915 .08851 L
.63915 .08012 L
s
.678 .847 .902 r
.63915 .08012 m
.63915 .08836 L
.63941 .08836 L
.63941 .08012 L
F
.2 .63 .79 r
.63915 .08012 m
.63915 .08836 L
.63941 .08836 L
.63941 .08012 L
s
.678 .847 .902 r
.63941 .08012 m
.63941 .0882 L
.6397 .0882 L
.6397 .08012 L
F
.2 .63 .79 r
.63941 .08012 m
.63941 .0882 L
.6397 .0882 L
.6397 .08012 L
s
.678 .847 .902 r
.6397 .08012 m
.6397 .08818 L
.64011 .08818 L
.64011 .08012 L
F
.2 .63 .79 r
.6397 .08012 m
.6397 .08818 L
.64011 .08818 L
.64011 .08012 L
s
.678 .847 .902 r
.64011 .08012 m
.64011 .08795 L
.6403 .08795 L
.6403 .08012 L
F
.2 .63 .79 r
.64011 .08012 m
.64011 .08795 L
.6403 .08795 L
.6403 .08012 L
s
.678 .847 .902 r
.6403 .08012 m
.6403 .08783 L
.64062 .08783 L
.64062 .08012 L
F
.2 .63 .79 r
.6403 .08012 m
.6403 .08783 L
.64062 .08783 L
.64062 .08012 L
s
.678 .847 .902 r
.64062 .08012 m
.64062 .08773 L
.64083 .08773 L
.64083 .08012 L
F
.2 .63 .79 r
.64062 .08012 m
.64062 .08773 L
.64083 .08773 L
.64083 .08012 L
s
.678 .847 .902 r
.64083 .08012 m
.64083 .0876 L
.64112 .0876 L
.64112 .08012 L
F
.2 .63 .79 r
.64083 .08012 m
.64083 .0876 L
.64112 .0876 L
.64112 .08012 L
s
.678 .847 .902 r
.64112 .08012 m
.64112 .0875 L
.64138 .0875 L
.64138 .08012 L
F
.2 .63 .79 r
.64112 .08012 m
.64112 .0875 L
.64138 .0875 L
.64138 .08012 L
s
.678 .847 .902 r
.64138 .08012 m
.64138 .08734 L
.64181 .08734 L
.64181 .08012 L
F
.2 .63 .79 r
.64138 .08012 m
.64138 .08734 L
.64181 .08734 L
.64181 .08012 L
s
.678 .847 .902 r
.64181 .08012 m
.64181 .08727 L
.64196 .08727 L
.64196 .08012 L
F
.2 .63 .79 r
.64181 .08012 m
.64181 .08727 L
.64196 .08727 L
.64196 .08012 L
s
.678 .847 .902 r
.64196 .08012 m
.64196 .08714 L
.64217 .08714 L
.64217 .08012 L
F
.2 .63 .79 r
.64196 .08012 m
.64196 .08714 L
.64217 .08714 L
.64217 .08012 L
s
.678 .847 .902 r
.64217 .08012 m
.64217 .087 L
.64252 .087 L
.64252 .08012 L
F
.2 .63 .79 r
.64217 .08012 m
.64217 .087 L
.64252 .087 L
.64252 .08012 L
s
.678 .847 .902 r
.64252 .08012 m
.64252 .08696 L
.64283 .08696 L
.64283 .08012 L
F
.2 .63 .79 r
.64252 .08012 m
.64252 .08696 L
.64283 .08696 L
.64283 .08012 L
s
.678 .847 .902 r
.64283 .08012 m
.64283 .08668 L
.64319 .08668 L
.64319 .08012 L
F
.2 .63 .79 r
.64283 .08012 m
.64283 .08668 L
.64319 .08668 L
.64319 .08012 L
s
.678 .847 .902 r
.64319 .08012 m
.64319 .08654 L
.64358 .08654 L
.64358 .08012 L
F
.2 .63 .79 r
.64319 .08012 m
.64319 .08654 L
.64358 .08654 L
.64358 .08012 L
s
.678 .847 .902 r
.64358 .08012 m
.64358 .08649 L
.64393 .08649 L
.64393 .08012 L
F
.2 .63 .79 r
.64358 .08012 m
.64358 .08649 L
.64393 .08649 L
.64393 .08012 L
s
.678 .847 .902 r
.64393 .08012 m
.64393 .08624 L
.64434 .08624 L
.64434 .08012 L
F
.2 .63 .79 r
.64393 .08012 m
.64393 .08624 L
.64434 .08624 L
.64434 .08012 L
s
.678 .847 .902 r
.64434 .08012 m
.64434 .0861 L
.64456 .0861 L
.64456 .08012 L
F
.2 .63 .79 r
.64434 .08012 m
.64434 .0861 L
.64456 .0861 L
.64456 .08012 L
s
.678 .847 .902 r
.64456 .08012 m
.64456 .08605 L
.64503 .08605 L
.64503 .08012 L
F
.2 .63 .79 r
.64456 .08012 m
.64456 .08605 L
.64503 .08605 L
.64503 .08012 L
s
.678 .847 .902 r
.64503 .08012 m
.64503 .08577 L
.64543 .08577 L
.64543 .08012 L
F
.2 .63 .79 r
.64503 .08012 m
.64503 .08577 L
.64543 .08577 L
.64543 .08012 L
s
.678 .847 .902 r
.64543 .08012 m
.64543 .08571 L
.64565 .08571 L
.64565 .08012 L
F
.2 .63 .79 r
.64543 .08012 m
.64543 .08571 L
.64565 .08571 L
.64565 .08012 L
s
.678 .847 .902 r
.64565 .08012 m
.64565 .08559 L
.646 .08559 L
.646 .08012 L
F
.2 .63 .79 r
.64565 .08012 m
.64565 .08559 L
.646 .08559 L
.646 .08012 L
s
.678 .847 .902 r
.646 .08012 m
.646 .08544 L
.64643 .08544 L
.64643 .08012 L
F
.2 .63 .79 r
.646 .08012 m
.646 .08544 L
.64643 .08544 L
.64643 .08012 L
s
.678 .847 .902 r
.64643 .08012 m
.64643 .08526 L
.64692 .08526 L
.64692 .08012 L
F
.2 .63 .79 r
.64643 .08012 m
.64643 .08526 L
.64692 .08526 L
.64692 .08012 L
s
.678 .847 .902 r
.64692 .08012 m
.64692 .085 L
.64737 .085 L
.64737 .08012 L
F
.2 .63 .79 r
.64692 .08012 m
.64692 .085 L
.64737 .085 L
.64737 .08012 L
s
.678 .847 .902 r
.64737 .08012 m
.64737 .08486 L
.64758 .08486 L
.64758 .08012 L
F
.2 .63 .79 r
.64737 .08012 m
.64737 .08486 L
.64758 .08486 L
.64758 .08012 L
s
.678 .847 .902 r
.64758 .08012 m
.64758 .08479 L
.64775 .08479 L
.64775 .08012 L
F
.2 .63 .79 r
.64758 .08012 m
.64758 .08479 L
.64775 .08479 L
.64775 .08012 L
s
.678 .847 .902 r
.64775 .08012 m
.64775 .08464 L
.64819 .08464 L
.64819 .08012 L
F
.2 .63 .79 r
.64775 .08012 m
.64775 .08464 L
.64819 .08464 L
.64819 .08012 L
s
.678 .847 .902 r
.64819 .08012 m
.64819 .08445 L
.64847 .08445 L
.64847 .08012 L
F
.2 .63 .79 r
.64819 .08012 m
.64819 .08445 L
.64847 .08445 L
.64847 .08012 L
s
.678 .847 .902 r
.64847 .08012 m
.64847 .08437 L
.64862 .08437 L
.64862 .08012 L
F
.2 .63 .79 r
.64847 .08012 m
.64847 .08437 L
.64862 .08437 L
.64862 .08012 L
s
.678 .847 .902 r
.64862 .08012 m
.64862 .0843 L
.64899 .0843 L
.64899 .08012 L
F
.2 .63 .79 r
.64862 .08012 m
.64862 .0843 L
.64899 .0843 L
.64899 .08012 L
s
.678 .847 .902 r
.64899 .08012 m
.64899 .08408 L
.64932 .08408 L
.64932 .08012 L
F
.2 .63 .79 r
.64899 .08012 m
.64899 .08408 L
.64932 .08408 L
.64932 .08012 L
s
.678 .847 .902 r
.64932 .08012 m
.64932 .08404 L
.64967 .08404 L
.64967 .08012 L
F
.2 .63 .79 r
.64932 .08012 m
.64932 .08404 L
.64967 .08404 L
.64967 .08012 L
s
.678 .847 .902 r
.64967 .08012 m
.64967 .08379 L
.65016 .08379 L
.65016 .08012 L
F
.2 .63 .79 r
.64967 .08012 m
.64967 .08379 L
.65016 .08379 L
.65016 .08012 L
s
.678 .847 .902 r
.65016 .08012 m
.65016 .08363 L
.65047 .08363 L
.65047 .08012 L
F
.2 .63 .79 r
.65016 .08012 m
.65016 .08363 L
.65047 .08363 L
.65047 .08012 L
s
.678 .847 .902 r
.65047 .08012 m
.65047 .08337 L
.65094 .08337 L
.65094 .08012 L
F
.2 .63 .79 r
.65047 .08012 m
.65047 .08337 L
.65094 .08337 L
.65094 .08012 L
s
.678 .847 .902 r
.65094 .08012 m
.65094 .08329 L
.65112 .08329 L
.65112 .08012 L
F
.2 .63 .79 r
.65094 .08012 m
.65094 .08329 L
.65112 .08329 L
.65112 .08012 L
s
.678 .847 .902 r
.65112 .08012 m
.65112 .08322 L
.6514 .08322 L
.6514 .08012 L
F
.2 .63 .79 r
.65112 .08012 m
.65112 .08322 L
.6514 .08322 L
.6514 .08012 L
s
.678 .847 .902 r
.6514 .08012 m
.6514 .08304 L
.65181 .08304 L
.65181 .08012 L
F
.2 .63 .79 r
.6514 .08012 m
.6514 .08304 L
.65181 .08304 L
.65181 .08012 L
s
.678 .847 .902 r
.65181 .08012 m
.65181 .0829 L
.65208 .0829 L
.65208 .08012 L
F
.2 .63 .79 r
.65181 .08012 m
.65181 .0829 L
.65208 .0829 L
.65208 .08012 L
s
.678 .847 .902 r
.65208 .08012 m
.65208 .08285 L
.65234 .08285 L
.65234 .08012 L
F
.2 .63 .79 r
.65208 .08012 m
.65208 .08285 L
.65234 .08285 L
.65234 .08012 L
s
.678 .847 .902 r
.65234 .08012 m
.65234 .0827 L
.65255 .0827 L
.65255 .08012 L
F
.2 .63 .79 r
.65234 .08012 m
.65234 .0827 L
.65255 .0827 L
.65255 .08012 L
s
.678 .847 .902 r
.65255 .08012 m
.65255 .08258 L
.65299 .08258 L
.65299 .08012 L
F
.2 .63 .79 r
.65255 .08012 m
.65255 .08258 L
.65299 .08258 L
.65299 .08012 L
s
.678 .847 .902 r
.65299 .08012 m
.65299 .08247 L
.65335 .08247 L
.65335 .08012 L
F
.2 .63 .79 r
.65299 .08012 m
.65299 .08247 L
.65335 .08247 L
.65335 .08012 L
s
.678 .847 .902 r
.65335 .08012 m
.65335 .08233 L
.65354 .08233 L
.65354 .08012 L
F
.2 .63 .79 r
.65335 .08012 m
.65335 .08233 L
.65354 .08233 L
.65354 .08012 L
s
.678 .847 .902 r
.65354 .08012 m
.65354 .08218 L
.65389 .08218 L
.65389 .08012 L
F
.2 .63 .79 r
.65354 .08012 m
.65354 .08218 L
.65389 .08218 L
.65389 .08012 L
s
.678 .847 .902 r
.65389 .08012 m
.65389 .0821 L
.65404 .0821 L
.65404 .08012 L
F
.2 .63 .79 r
.65389 .08012 m
.65389 .0821 L
.65404 .0821 L
.65404 .08012 L
s
.678 .847 .902 r
.65404 .08012 m
.65404 .08205 L
.65441 .08205 L
.65441 .08012 L
F
.2 .63 .79 r
.65404 .08012 m
.65404 .08205 L
.65441 .08205 L
.65441 .08012 L
s
.678 .847 .902 r
.65441 .08012 m
.65441 .08182 L
.65463 .08182 L
.65463 .08012 L
F
.2 .63 .79 r
.65441 .08012 m
.65441 .08182 L
.65463 .08182 L
.65463 .08012 L
s
.678 .847 .902 r
.65463 .08012 m
.65463 .08176 L
.65492 .08176 L
.65492 .08012 L
F
.2 .63 .79 r
.65463 .08012 m
.65463 .08176 L
.65492 .08176 L
.65492 .08012 L
s
.678 .847 .902 r
.65492 .08012 m
.65492 .08161 L
.6554 .08161 L
.6554 .08012 L
F
.2 .63 .79 r
.65492 .08012 m
.65492 .08161 L
.6554 .08161 L
.6554 .08012 L
s
.678 .847 .902 r
.6554 .08012 m
.6554 .08137 L
.65582 .08137 L
.65582 .08012 L
F
.2 .63 .79 r
.6554 .08012 m
.6554 .08137 L
.65582 .08137 L
.65582 .08012 L
s
.678 .847 .902 r
.65582 .08012 m
.65582 .08128 L
.65625 .08128 L
.65625 .08012 L
F
.2 .63 .79 r
.65582 .08012 m
.65582 .08128 L
.65625 .08128 L
.65625 .08012 L
s
.678 .847 .902 r
.65625 .08012 m
.65625 .08104 L
.65654 .08104 L
.65654 .08012 L
F
.2 .63 .79 r
.65625 .08012 m
.65625 .08104 L
.65654 .08104 L
.65654 .08012 L
s
.678 .847 .902 r
.65654 .08012 m
.65654 .08101 L
.6568 .08101 L
.6568 .08012 L
F
.2 .63 .79 r
.65654 .08012 m
.65654 .08101 L
.6568 .08101 L
.6568 .08012 L
s
.678 .847 .902 r
.6568 .08012 m
.6568 .08082 L
.65703 .08082 L
.65703 .08012 L
F
.2 .63 .79 r
.6568 .08012 m
.6568 .08082 L
.65703 .08082 L
.65703 .08012 L
s
.678 .847 .902 r
.65703 .08012 m
.65703 .0808 L
.65727 .0808 L
.65727 .08012 L
F
.2 .63 .79 r
.65703 .08012 m
.65703 .0808 L
.65727 .0808 L
.65727 .08012 L
s
.678 .847 .902 r
.65727 .08012 m
.65727 .08068 L
.65756 .08068 L
.65756 .08012 L
F
.2 .63 .79 r
.65727 .08012 m
.65727 .08068 L
.65756 .08068 L
.65756 .08012 L
s
.678 .847 .902 r
.65756 .08012 m
.65756 .08049 L
.65799 .08049 L
.65799 .08012 L
F
.2 .63 .79 r
.65756 .08012 m
.65756 .08049 L
.65799 .08049 L
.65799 .08012 L
s
.678 .847 .902 r
.65799 .08012 m
.65799 .08031 L
.65825 .08031 L
.65825 .08012 L
F
.2 .63 .79 r
.65799 .08012 m
.65799 .08031 L
.65825 .08031 L
.65825 .08012 L
s
.678 .847 .902 r
.65825 .08012 m
.65825 .08029 L
.65845 .08029 L
.65845 .08012 L
F
.2 .63 .79 r
.65825 .08012 m
.65825 .08029 L
.65845 .08029 L
.65845 .08012 L
s
.678 .847 .902 r
.65845 .08012 m
.65845 .08018 L
.65861 .08018 L
.65861 .08012 L
F
.2 .63 .79 r
.65845 .08012 m
.65845 .08018 L
.65861 .08018 L
.65861 .08012 L
s
1 .894 .882 r
.65861 .08012 m
.65861 .0801 L
.65879 .0801 L
.65879 .08012 L
F
.804 .522 .247 r
.65861 .08012 m
.65861 .0801 L
.65879 .0801 L
.65879 .08012 L
s
1 .894 .882 r
.65879 .08012 m
.65879 .08007 L
.65927 .08007 L
.65927 .08012 L
F
.804 .522 .247 r
.65879 .08012 m
.65879 .08007 L
.65927 .08007 L
.65927 .08012 L
s
1 .894 .882 r
.65927 .08012 m
.65927 .07973 L
.6597 .07973 L
.6597 .08012 L
F
.804 .522 .247 r
.65927 .08012 m
.65927 .07973 L
.6597 .07973 L
.6597 .08012 L
s
1 .894 .882 r
.6597 .08012 m
.6597 .07955 L
.66014 .07955 L
.66014 .08012 L
F
.804 .522 .247 r
.6597 .08012 m
.6597 .07955 L
.66014 .07955 L
.66014 .08012 L
s
1 .894 .882 r
.66014 .08012 m
.66014 .07951 L
.66037 .07951 L
.66037 .08012 L
F
.804 .522 .247 r
.66014 .08012 m
.66014 .07951 L
.66037 .07951 L
.66037 .08012 L
s
1 .894 .882 r
.66037 .08012 m
.66037 .07934 L
.66064 .07934 L
.66064 .08012 L
F
.804 .522 .247 r
.66037 .08012 m
.66037 .07934 L
.66064 .07934 L
.66064 .08012 L
s
1 .894 .882 r
.66064 .08012 m
.66064 .07923 L
.66103 .07923 L
.66103 .08012 L
F
.804 .522 .247 r
.66064 .08012 m
.66064 .07923 L
.66103 .07923 L
.66103 .08012 L
s
1 .894 .882 r
.66103 .08012 m
.66103 .07914 L
.66127 .07914 L
.66127 .08012 L
F
.804 .522 .247 r
.66103 .08012 m
.66103 .07914 L
.66127 .07914 L
.66127 .08012 L
s
1 .894 .882 r
.66127 .08012 m
.66127 .079 L
.6615 .079 L
.6615 .08012 L
F
.804 .522 .247 r
.66127 .08012 m
.66127 .079 L
.6615 .079 L
.6615 .08012 L
s
1 .894 .882 r
.6615 .08012 m
.6615 .07885 L
.66189 .07885 L
.66189 .08012 L
F
.804 .522 .247 r
.6615 .08012 m
.6615 .07885 L
.66189 .07885 L
.66189 .08012 L
s
1 .894 .882 r
.66189 .08012 m
.66189 .07873 L
.6622 .07873 L
.6622 .08012 L
F
.804 .522 .247 r
.66189 .08012 m
.66189 .07873 L
.6622 .07873 L
.6622 .08012 L
s
1 .894 .882 r
.6622 .08012 m
.6622 .07853 L
.66264 .07853 L
.66264 .08012 L
F
.804 .522 .247 r
.6622 .08012 m
.6622 .07853 L
.66264 .07853 L
.66264 .08012 L
s
1 .894 .882 r
.66264 .08012 m
.66264 .07847 L
.66289 .07847 L
.66289 .08012 L
F
.804 .522 .247 r
.66264 .08012 m
.66264 .07847 L
.66289 .07847 L
.66289 .08012 L
s
1 .894 .882 r
.66289 .08012 m
.66289 .07839 L
.66335 .07839 L
.66335 .08012 L
F
.804 .522 .247 r
.66289 .08012 m
.66289 .07839 L
.66335 .07839 L
.66335 .08012 L
s
1 .894 .882 r
.66335 .08012 m
.66335 .07816 L
.66373 .07816 L
.66373 .08012 L
F
.804 .522 .247 r
.66335 .08012 m
.66335 .07816 L
.66373 .07816 L
.66373 .08012 L
s
1 .894 .882 r
.66373 .08012 m
.66373 .07807 L
.66403 .07807 L
.66403 .08012 L
F
.804 .522 .247 r
.66373 .08012 m
.66373 .07807 L
.66403 .07807 L
.66403 .08012 L
s
1 .894 .882 r
.66403 .08012 m
.66403 .07789 L
.66451 .07789 L
.66451 .08012 L
F
.804 .522 .247 r
.66403 .08012 m
.66403 .07789 L
.66451 .07789 L
.66451 .08012 L
s
1 .894 .882 r
.66451 .08012 m
.66451 .07773 L
.66488 .07773 L
.66488 .08012 L
F
.804 .522 .247 r
.66451 .08012 m
.66451 .07773 L
.66488 .07773 L
.66488 .08012 L
s
1 .894 .882 r
.66488 .08012 m
.66488 .07758 L
.66517 .07758 L
.66517 .08012 L
F
.804 .522 .247 r
.66488 .08012 m
.66488 .07758 L
.66517 .07758 L
.66517 .08012 L
s
1 .894 .882 r
.66517 .08012 m
.66517 .07744 L
.66533 .07744 L
.66533 .08012 L
F
.804 .522 .247 r
.66517 .08012 m
.66517 .07744 L
.66533 .07744 L
.66533 .08012 L
s
1 .894 .882 r
.66533 .08012 m
.66533 .07737 L
.66552 .07737 L
.66552 .08012 L
F
.804 .522 .247 r
.66533 .08012 m
.66533 .07737 L
.66552 .07737 L
.66552 .08012 L
s
1 .894 .882 r
.66552 .08012 m
.66552 .07733 L
.66578 .07733 L
.66578 .08012 L
F
.804 .522 .247 r
.66552 .08012 m
.66552 .07733 L
.66578 .07733 L
.66578 .08012 L
s
1 .894 .882 r
.66578 .08012 m
.66578 .07715 L
.66602 .07715 L
.66602 .08012 L
F
.804 .522 .247 r
.66578 .08012 m
.66578 .07715 L
.66602 .07715 L
.66602 .08012 L
s
1 .894 .882 r
.66602 .08012 m
.66602 .07714 L
.66651 .07714 L
.66651 .08012 L
F
.804 .522 .247 r
.66602 .08012 m
.66602 .07714 L
.66651 .07714 L
.66651 .08012 L
s
1 .894 .882 r
.66651 .08012 m
.66651 .07689 L
.66668 .07689 L
.66668 .08012 L
F
.804 .522 .247 r
.66651 .08012 m
.66651 .07689 L
.66668 .07689 L
.66668 .08012 L
s
1 .894 .882 r
.66668 .08012 m
.66668 .07688 L
.66694 .07688 L
.66694 .08012 L
F
.804 .522 .247 r
.66668 .08012 m
.66668 .07688 L
.66694 .07688 L
.66694 .08012 L
s
1 .894 .882 r
.66694 .08012 m
.66694 .07677 L
.66725 .07677 L
.66725 .08012 L
F
.804 .522 .247 r
.66694 .08012 m
.66694 .07677 L
.66725 .07677 L
.66725 .08012 L
s
1 .894 .882 r
.66725 .08012 m
.66725 .07664 L
.66744 .07664 L
.66744 .08012 L
F
.804 .522 .247 r
.66725 .08012 m
.66725 .07664 L
.66744 .07664 L
.66744 .08012 L
s
1 .894 .882 r
.66744 .08012 m
.66744 .07647 L
.66787 .07647 L
.66787 .08012 L
F
.804 .522 .247 r
.66744 .08012 m
.66744 .07647 L
.66787 .07647 L
.66787 .08012 L
s
1 .894 .882 r
.66787 .08012 m
.66787 .0764 L
.66802 .0764 L
.66802 .08012 L
F
.804 .522 .247 r
.66787 .08012 m
.66787 .0764 L
.66802 .0764 L
.66802 .08012 L
s
1 .894 .882 r
.66802 .08012 m
.66802 .07628 L
.66843 .07628 L
.66843 .08012 L
F
.804 .522 .247 r
.66802 .08012 m
.66802 .07628 L
.66843 .07628 L
.66843 .08012 L
s
1 .894 .882 r
.66843 .08012 m
.66843 .07604 L
.66887 .07604 L
.66887 .08012 L
F
.804 .522 .247 r
.66843 .08012 m
.66843 .07604 L
.66887 .07604 L
.66887 .08012 L
s
1 .894 .882 r
.66887 .08012 m
.66887 .0759 L
.66922 .0759 L
.66922 .08012 L
F
.804 .522 .247 r
.66887 .08012 m
.66887 .0759 L
.66922 .0759 L
.66922 .08012 L
s
1 .894 .882 r
.66922 .08012 m
.66922 .07583 L
.66947 .07583 L
.66947 .08012 L
F
.804 .522 .247 r
.66922 .08012 m
.66922 .07583 L
.66947 .07583 L
.66947 .08012 L
s
1 .894 .882 r
.66947 .08012 m
.66947 .07569 L
.66971 .07569 L
.66971 .08012 L
F
.804 .522 .247 r
.66947 .08012 m
.66947 .07569 L
.66971 .07569 L
.66971 .08012 L
s
1 .894 .882 r
.66971 .08012 m
.66971 .07561 L
.66986 .07561 L
.66986 .08012 L
F
.804 .522 .247 r
.66971 .08012 m
.66971 .07561 L
.66986 .07561 L
.66986 .08012 L
s
1 .894 .882 r
.66986 .08012 m
.66986 .07557 L
.67011 .07557 L
.67011 .08012 L
F
.804 .522 .247 r
.66986 .08012 m
.66986 .07557 L
.67011 .07557 L
.67011 .08012 L
s
1 .894 .882 r
.67011 .08012 m
.67011 .07548 L
.6704 .07548 L
.6704 .08012 L
F
.804 .522 .247 r
.67011 .08012 m
.67011 .07548 L
.6704 .07548 L
.6704 .08012 L
s
1 .894 .882 r
.6704 .08012 m
.6704 .07535 L
.67075 .07535 L
.67075 .08012 L
F
.804 .522 .247 r
.6704 .08012 m
.6704 .07535 L
.67075 .07535 L
.67075 .08012 L
s
1 .894 .882 r
.67075 .08012 m
.67075 .07514 L
.6711 .07514 L
.6711 .08012 L
F
.804 .522 .247 r
.67075 .08012 m
.67075 .07514 L
.6711 .07514 L
.6711 .08012 L
s
1 .894 .882 r
.6711 .08012 m
.6711 .07511 L
.67135 .07511 L
.67135 .08012 L
F
.804 .522 .247 r
.6711 .08012 m
.6711 .07511 L
.67135 .07511 L
.67135 .08012 L
s
1 .894 .882 r
.67135 .08012 m
.67135 .075 L
.67176 .075 L
.67176 .08012 L
F
.804 .522 .247 r
.67135 .08012 m
.67135 .075 L
.67176 .075 L
.67176 .08012 L
s
1 .894 .882 r
.67176 .08012 m
.67176 .07485 L
.67197 .07485 L
.67197 .08012 L
F
.804 .522 .247 r
.67176 .08012 m
.67176 .07485 L
.67197 .07485 L
.67197 .08012 L
s
1 .894 .882 r
.67197 .08012 m
.67197 .07476 L
.67231 .07476 L
.67231 .08012 L
F
.804 .522 .247 r
.67197 .08012 m
.67197 .07476 L
.67231 .07476 L
.67231 .08012 L
s
1 .894 .882 r
.67231 .08012 m
.67231 .07461 L
.67252 .07461 L
.67252 .08012 L
F
.804 .522 .247 r
.67231 .08012 m
.67231 .07461 L
.67252 .07461 L
.67252 .08012 L
s
1 .894 .882 r
.67252 .08012 m
.67252 .07445 L
.67282 .07445 L
.67282 .08012 L
F
.804 .522 .247 r
.67252 .08012 m
.67252 .07445 L
.67282 .07445 L
.67282 .08012 L
s
1 .894 .882 r
.67282 .08012 m
.67282 .07442 L
.67328 .07442 L
.67328 .08012 L
F
.804 .522 .247 r
.67282 .08012 m
.67282 .07442 L
.67328 .07442 L
.67328 .08012 L
s
1 .894 .882 r
.67328 .08012 m
.67328 .07425 L
.67362 .07425 L
.67362 .08012 L
F
.804 .522 .247 r
.67328 .08012 m
.67328 .07425 L
.67362 .07425 L
.67362 .08012 L
s
1 .894 .882 r
.67362 .08012 m
.67362 .07409 L
.67381 .07409 L
.67381 .08012 L
F
.804 .522 .247 r
.67362 .08012 m
.67362 .07409 L
.67381 .07409 L
.67381 .08012 L
s
1 .894 .882 r
.67381 .08012 m
.67381 .07399 L
.67399 .07399 L
.67399 .08012 L
F
.804 .522 .247 r
.67381 .08012 m
.67381 .07399 L
.67399 .07399 L
.67399 .08012 L
s
1 .894 .882 r
.67399 .08012 m
.67399 .07397 L
.67429 .07397 L
.67429 .08012 L
F
.804 .522 .247 r
.67399 .08012 m
.67399 .07397 L
.67429 .07397 L
.67429 .08012 L
s
1 .894 .882 r
.67429 .08012 m
.67429 .07375 L
.67459 .07375 L
.67459 .08012 L
F
.804 .522 .247 r
.67429 .08012 m
.67429 .07375 L
.67459 .07375 L
.67459 .08012 L
s
1 .894 .882 r
.67459 .08012 m
.67459 .07366 L
.67484 .07366 L
.67484 .08012 L
F
.804 .522 .247 r
.67459 .08012 m
.67459 .07366 L
.67484 .07366 L
.67484 .08012 L
s
1 .894 .882 r
.67484 .08012 m
.67484 .07359 L
.67502 .07359 L
.67502 .08012 L
F
.804 .522 .247 r
.67484 .08012 m
.67484 .07359 L
.67502 .07359 L
.67502 .08012 L
s
1 .894 .882 r
.67502 .08012 m
.67502 .07347 L
.67541 .07347 L
.67541 .08012 L
F
.804 .522 .247 r
.67502 .08012 m
.67502 .07347 L
.67541 .07347 L
.67541 .08012 L
s
1 .894 .882 r
.67541 .08012 m
.67541 .0734 L
.67575 .0734 L
.67575 .08012 L
F
.804 .522 .247 r
.67541 .08012 m
.67541 .0734 L
.67575 .0734 L
.67575 .08012 L
s
1 .894 .882 r
.67575 .08012 m
.67575 .07328 L
.67615 .07328 L
.67615 .08012 L
F
.804 .522 .247 r
.67575 .08012 m
.67575 .07328 L
.67615 .07328 L
.67615 .08012 L
s
1 .894 .882 r
.67615 .08012 m
.67615 .07307 L
.67657 .07307 L
.67657 .08012 L
F
.804 .522 .247 r
.67615 .08012 m
.67615 .07307 L
.67657 .07307 L
.67657 .08012 L
s
1 .894 .882 r
.67657 .08012 m
.67657 .07286 L
.67687 .07286 L
.67687 .08012 L
F
.804 .522 .247 r
.67657 .08012 m
.67657 .07286 L
.67687 .07286 L
.67687 .08012 L
s
1 .894 .882 r
.67687 .08012 m
.67687 .07282 L
.6772 .07282 L
.6772 .08012 L
F
.804 .522 .247 r
.67687 .08012 m
.67687 .07282 L
.6772 .07282 L
.6772 .08012 L
s
1 .894 .882 r
.6772 .08012 m
.6772 .07264 L
.67751 .07264 L
.67751 .08012 L
F
.804 .522 .247 r
.6772 .08012 m
.6772 .07264 L
.67751 .07264 L
.67751 .08012 L
s
1 .894 .882 r
.67751 .08012 m
.67751 .07259 L
.67779 .07259 L
.67779 .08012 L
F
.804 .522 .247 r
.67751 .08012 m
.67751 .07259 L
.67779 .07259 L
.67779 .08012 L
s
1 .894 .882 r
.67779 .08012 m
.67779 .07239 L
.67822 .07239 L
.67822 .08012 L
F
.804 .522 .247 r
.67779 .08012 m
.67779 .07239 L
.67822 .07239 L
.67822 .08012 L
s
1 .894 .882 r
.67822 .08012 m
.67822 .07226 L
.6787 .07226 L
.6787 .08012 L
F
.804 .522 .247 r
.67822 .08012 m
.67822 .07226 L
.6787 .07226 L
.6787 .08012 L
s
1 .894 .882 r
.6787 .08012 m
.6787 .0721 L
.6789 .0721 L
.6789 .08012 L
F
.804 .522 .247 r
.6787 .08012 m
.6787 .0721 L
.6789 .0721 L
.6789 .08012 L
s
1 .894 .882 r
.6789 .08012 m
.6789 .07206 L
.67926 .07206 L
.67926 .08012 L
F
.804 .522 .247 r
.6789 .08012 m
.6789 .07206 L
.67926 .07206 L
.67926 .08012 L
s
1 .894 .882 r
.67926 .08012 m
.67926 .07185 L
.67963 .07185 L
.67963 .08012 L
F
.804 .522 .247 r
.67926 .08012 m
.67926 .07185 L
.67963 .07185 L
.67963 .08012 L
s
1 .894 .882 r
.67963 .08012 m
.67963 .07176 L
.67992 .07176 L
.67992 .08012 L
F
.804 .522 .247 r
.67963 .08012 m
.67963 .07176 L
.67992 .07176 L
.67992 .08012 L
s
1 .894 .882 r
.67992 .08012 m
.67992 .07161 L
.68041 .07161 L
.68041 .08012 L
F
.804 .522 .247 r
.67992 .08012 m
.67992 .07161 L
.68041 .07161 L
.68041 .08012 L
s
1 .894 .882 r
.68041 .08012 m
.68041 .07148 L
.68061 .07148 L
.68061 .08012 L
F
.804 .522 .247 r
.68041 .08012 m
.68041 .07148 L
.68061 .07148 L
.68061 .08012 L
s
1 .894 .882 r
.68061 .08012 m
.68061 .07135 L
.68102 .07135 L
.68102 .08012 L
F
.804 .522 .247 r
.68061 .08012 m
.68061 .07135 L
.68102 .07135 L
.68102 .08012 L
s
1 .894 .882 r
.68102 .08012 m
.68102 .07122 L
.68145 .07122 L
.68145 .08012 L
F
.804 .522 .247 r
.68102 .08012 m
.68102 .07122 L
.68145 .07122 L
.68145 .08012 L
s
1 .894 .882 r
.68145 .08012 m
.68145 .07094 L
.6819 .07094 L
.6819 .08012 L
F
.804 .522 .247 r
.68145 .08012 m
.68145 .07094 L
.6819 .07094 L
.6819 .08012 L
s
1 .894 .882 r
.6819 .08012 m
.6819 .0709 L
.68207 .0709 L
.68207 .08012 L
F
.804 .522 .247 r
.6819 .08012 m
.6819 .0709 L
.68207 .0709 L
.68207 .08012 L
s
1 .894 .882 r
.68207 .08012 m
.68207 .07082 L
.68233 .07082 L
.68233 .08012 L
F
.804 .522 .247 r
.68207 .08012 m
.68207 .07082 L
.68233 .07082 L
.68233 .08012 L
s
1 .894 .882 r
.68233 .08012 m
.68233 .07073 L
.68261 .07073 L
.68261 .08012 L
F
.804 .522 .247 r
.68233 .08012 m
.68233 .07073 L
.68261 .07073 L
.68261 .08012 L
s
1 .894 .882 r
.68261 .08012 m
.68261 .07064 L
.68296 .07064 L
.68296 .08012 L
F
.804 .522 .247 r
.68261 .08012 m
.68261 .07064 L
.68296 .07064 L
.68296 .08012 L
s
1 .894 .882 r
.68296 .08012 m
.68296 .07042 L
.68344 .07042 L
.68344 .08012 L
F
.804 .522 .247 r
.68296 .08012 m
.68296 .07042 L
.68344 .07042 L
.68344 .08012 L
s
1 .894 .882 r
.68344 .08012 m
.68344 .07025 L
.6838 .07025 L
.6838 .08012 L
F
.804 .522 .247 r
.68344 .08012 m
.68344 .07025 L
.6838 .07025 L
.6838 .08012 L
s
1 .894 .882 r
.6838 .08012 m
.6838 .07018 L
.68424 .07018 L
.68424 .08012 L
F
.804 .522 .247 r
.6838 .08012 m
.6838 .07018 L
.68424 .07018 L
.68424 .08012 L
s
1 .894 .882 r
.68424 .08012 m
.68424 .06987 L
.68467 .06987 L
.68467 .08012 L
F
.804 .522 .247 r
.68424 .08012 m
.68424 .06987 L
.68467 .06987 L
.68467 .08012 L
s
1 .894 .882 r
.68467 .08012 m
.68467 .06985 L
.68488 .06985 L
.68488 .08012 L
F
.804 .522 .247 r
.68467 .08012 m
.68467 .06985 L
.68488 .06985 L
.68488 .08012 L
s
1 .894 .882 r
.68488 .08012 m
.68488 .06973 L
.68509 .06973 L
.68509 .08012 L
F
.804 .522 .247 r
.68488 .08012 m
.68488 .06973 L
.68509 .06973 L
.68509 .08012 L
s
1 .894 .882 r
.68509 .08012 m
.68509 .06963 L
.68534 .06963 L
.68534 .08012 L
F
.804 .522 .247 r
.68509 .08012 m
.68509 .06963 L
.68534 .06963 L
.68534 .08012 L
s
1 .894 .882 r
.68534 .08012 m
.68534 .06958 L
.68562 .06958 L
.68562 .08012 L
F
.804 .522 .247 r
.68534 .08012 m
.68534 .06958 L
.68562 .06958 L
.68562 .08012 L
s
1 .894 .882 r
.68562 .08012 m
.68562 .0695 L
.68604 .0695 L
.68604 .08012 L
F
.804 .522 .247 r
.68562 .08012 m
.68562 .0695 L
.68604 .0695 L
.68604 .08012 L
s
1 .894 .882 r
.68604 .08012 m
.68604 .06934 L
.68631 .06934 L
.68631 .08012 L
F
.804 .522 .247 r
.68604 .08012 m
.68604 .06934 L
.68631 .06934 L
.68631 .08012 L
s
1 .894 .882 r
.68631 .08012 m
.68631 .0692 L
.68658 .0692 L
.68658 .08012 L
F
.804 .522 .247 r
.68631 .08012 m
.68631 .0692 L
.68658 .0692 L
.68658 .08012 L
s
1 .894 .882 r
.68658 .08012 m
.68658 .06909 L
.6868 .06909 L
.6868 .08012 L
F
.804 .522 .247 r
.68658 .08012 m
.68658 .06909 L
.6868 .06909 L
.6868 .08012 L
s
1 .894 .882 r
.6868 .08012 m
.6868 .06899 L
.687 .06899 L
.687 .08012 L
F
.804 .522 .247 r
.6868 .08012 m
.6868 .06899 L
.687 .06899 L
.687 .08012 L
s
1 .894 .882 r
.687 .08012 m
.687 .06891 L
.6874 .06891 L
.6874 .08012 L
F
.804 .522 .247 r
.687 .08012 m
.687 .06891 L
.6874 .06891 L
.6874 .08012 L
s
1 .894 .882 r
.6874 .08012 m
.6874 .06881 L
.68787 .06881 L
.68787 .08012 L
F
.804 .522 .247 r
.6874 .08012 m
.6874 .06881 L
.68787 .06881 L
.68787 .08012 L
s
1 .894 .882 r
.68787 .08012 m
.68787 .06864 L
.6881 .06864 L
.6881 .08012 L
F
.804 .522 .247 r
.68787 .08012 m
.68787 .06864 L
.6881 .06864 L
.6881 .08012 L
s
1 .894 .882 r
.6881 .08012 m
.6881 .06842 L
.68859 .06842 L
.68859 .08012 L
F
.804 .522 .247 r
.6881 .08012 m
.6881 .06842 L
.68859 .06842 L
.68859 .08012 L
s
1 .894 .882 r
.68859 .08012 m
.68859 .06837 L
.68907 .06837 L
.68907 .08012 L
F
.804 .522 .247 r
.68859 .08012 m
.68859 .06837 L
.68907 .06837 L
.68907 .08012 L
s
1 .894 .882 r
.68907 .08012 m
.68907 .06815 L
.68925 .06815 L
.68925 .08012 L
F
.804 .522 .247 r
.68907 .08012 m
.68907 .06815 L
.68925 .06815 L
.68925 .08012 L
s
1 .894 .882 r
.68925 .08012 m
.68925 .0681 L
.68953 .0681 L
.68953 .08012 L
F
.804 .522 .247 r
.68925 .08012 m
.68925 .0681 L
.68953 .0681 L
.68953 .08012 L
s
1 .894 .882 r
.68953 .08012 m
.68953 .06794 L
.68999 .06794 L
.68999 .08012 L
F
.804 .522 .247 r
.68953 .08012 m
.68953 .06794 L
.68999 .06794 L
.68999 .08012 L
s
1 .894 .882 r
.68999 .08012 m
.68999 .06776 L
.69037 .06776 L
.69037 .08012 L
F
.804 .522 .247 r
.68999 .08012 m
.68999 .06776 L
.69037 .06776 L
.69037 .08012 L
s
1 .894 .882 r
.69037 .08012 m
.69037 .06763 L
.69075 .06763 L
.69075 .08012 L
F
.804 .522 .247 r
.69037 .08012 m
.69037 .06763 L
.69075 .06763 L
.69075 .08012 L
s
1 .894 .882 r
.69075 .08012 m
.69075 .06753 L
.69118 .06753 L
.69118 .08012 L
F
.804 .522 .247 r
.69075 .08012 m
.69075 .06753 L
.69118 .06753 L
.69118 .08012 L
s
1 .894 .882 r
.69118 .08012 m
.69118 .06742 L
.69165 .06742 L
.69165 .08012 L
F
.804 .522 .247 r
.69118 .08012 m
.69118 .06742 L
.69165 .06742 L
.69165 .08012 L
s
1 .894 .882 r
.69165 .08012 m
.69165 .06724 L
.69181 .06724 L
.69181 .08012 L
F
.804 .522 .247 r
.69165 .08012 m
.69165 .06724 L
.69181 .06724 L
.69181 .08012 L
s
1 .894 .882 r
.69181 .08012 m
.69181 .06709 L
.69226 .06709 L
.69226 .08012 L
F
.804 .522 .247 r
.69181 .08012 m
.69181 .06709 L
.69226 .06709 L
.69226 .08012 L
s
1 .894 .882 r
.69226 .08012 m
.69226 .06696 L
.69274 .06696 L
.69274 .08012 L
F
.804 .522 .247 r
.69226 .08012 m
.69226 .06696 L
.69274 .06696 L
.69274 .08012 L
s
1 .894 .882 r
.69274 .08012 m
.69274 .06672 L
.69316 .06672 L
.69316 .08012 L
F
.804 .522 .247 r
.69274 .08012 m
.69274 .06672 L
.69316 .06672 L
.69316 .08012 L
s
1 .894 .882 r
.69316 .08012 m
.69316 .06662 L
.69359 .06662 L
.69359 .08012 L
F
.804 .522 .247 r
.69316 .08012 m
.69316 .06662 L
.69359 .06662 L
.69359 .08012 L
s
1 .894 .882 r
.69359 .08012 m
.69359 .06643 L
.69394 .06643 L
.69394 .08012 L
F
.804 .522 .247 r
.69359 .08012 m
.69359 .06643 L
.69394 .06643 L
.69394 .08012 L
s
1 .894 .882 r
.69394 .08012 m
.69394 .0664 L
.69429 .0664 L
.69429 .08012 L
F
.804 .522 .247 r
.69394 .08012 m
.69394 .0664 L
.69429 .0664 L
.69429 .08012 L
s
1 .894 .882 r
.69429 .08012 m
.69429 .06613 L
.69478 .06613 L
.69478 .08012 L
F
.804 .522 .247 r
.69429 .08012 m
.69429 .06613 L
.69478 .06613 L
.69478 .08012 L
s
1 .894 .882 r
.69478 .08012 m
.69478 .06605 L
.69509 .06605 L
.69509 .08012 L
F
.804 .522 .247 r
.69478 .08012 m
.69478 .06605 L
.69509 .06605 L
.69509 .08012 L
s
1 .894 .882 r
.69509 .08012 m
.69509 .06596 L
.69532 .06596 L
.69532 .08012 L
F
.804 .522 .247 r
.69509 .08012 m
.69509 .06596 L
.69532 .06596 L
.69532 .08012 L
s
1 .894 .882 r
.69532 .08012 m
.69532 .06586 L
.69559 .06586 L
.69559 .08012 L
F
.804 .522 .247 r
.69532 .08012 m
.69532 .06586 L
.69559 .06586 L
.69559 .08012 L
s
1 .894 .882 r
.69559 .08012 m
.69559 .06567 L
.69603 .06567 L
.69603 .08012 L
F
.804 .522 .247 r
.69559 .08012 m
.69559 .06567 L
.69603 .06567 L
.69603 .08012 L
s
1 .894 .882 r
.69603 .08012 m
.69603 .06552 L
.69643 .06552 L
.69643 .08012 L
F
.804 .522 .247 r
.69603 .08012 m
.69603 .06552 L
.69643 .06552 L
.69643 .08012 L
s
1 .894 .882 r
.69643 .08012 m
.69643 .06548 L
.69669 .06548 L
.69669 .08012 L
F
.804 .522 .247 r
.69643 .08012 m
.69643 .06548 L
.69669 .06548 L
.69669 .08012 L
s
1 .894 .882 r
.69669 .08012 m
.69669 .0654 L
.69687 .0654 L
.69687 .08012 L
F
.804 .522 .247 r
.69669 .08012 m
.69669 .0654 L
.69687 .0654 L
.69687 .08012 L
s
1 .894 .882 r
.69687 .08012 m
.69687 .06534 L
.69733 .06534 L
.69733 .08012 L
F
.804 .522 .247 r
.69687 .08012 m
.69687 .06534 L
.69733 .06534 L
.69733 .08012 L
s
1 .894 .882 r
.69733 .08012 m
.69733 .06506 L
.69774 .06506 L
.69774 .08012 L
F
.804 .522 .247 r
.69733 .08012 m
.69733 .06506 L
.69774 .06506 L
.69774 .08012 L
s
1 .894 .882 r
.69774 .08012 m
.69774 .06501 L
.69796 .06501 L
.69796 .08012 L
F
.804 .522 .247 r
.69774 .08012 m
.69774 .06501 L
.69796 .06501 L
.69796 .08012 L
s
1 .894 .882 r
.69796 .08012 m
.69796 .06484 L
.69836 .06484 L
.69836 .08012 L
F
.804 .522 .247 r
.69796 .08012 m
.69796 .06484 L
.69836 .06484 L
.69836 .08012 L
s
1 .894 .882 r
.69836 .08012 m
.69836 .06473 L
.69884 .06473 L
.69884 .08012 L
F
.804 .522 .247 r
.69836 .08012 m
.69836 .06473 L
.69884 .06473 L
.69884 .08012 L
s
1 .894 .882 r
.69884 .08012 m
.69884 .06457 L
.69902 .06457 L
.69902 .08012 L
F
.804 .522 .247 r
.69884 .08012 m
.69884 .06457 L
.69902 .06457 L
.69902 .08012 L
s
1 .894 .882 r
.69902 .08012 m
.69902 .0645 L
.69935 .0645 L
.69935 .08012 L
F
.804 .522 .247 r
.69902 .08012 m
.69902 .0645 L
.69935 .0645 L
.69935 .08012 L
s
1 .894 .882 r
.69935 .08012 m
.69935 .06437 L
.69981 .06437 L
.69981 .08012 L
F
.804 .522 .247 r
.69935 .08012 m
.69935 .06437 L
.69981 .06437 L
.69981 .08012 L
s
1 .894 .882 r
.69981 .08012 m
.69981 .06426 L
.69997 .06426 L
.69997 .08012 L
F
.804 .522 .247 r
.69981 .08012 m
.69981 .06426 L
.69997 .06426 L
.69997 .08012 L
s
1 .894 .882 r
.69997 .08012 m
.69997 .06418 L
.70014 .06418 L
.70014 .08012 L
F
.804 .522 .247 r
.69997 .08012 m
.69997 .06418 L
.70014 .06418 L
.70014 .08012 L
s
1 .894 .882 r
.70014 .08012 m
.70014 .06404 L
.70052 .06404 L
.70052 .08012 L
F
.804 .522 .247 r
.70014 .08012 m
.70014 .06404 L
.70052 .06404 L
.70052 .08012 L
s
1 .894 .882 r
.70052 .08012 m
.70052 .06402 L
.70098 .06402 L
.70098 .08012 L
F
.804 .522 .247 r
.70052 .08012 m
.70052 .06402 L
.70098 .06402 L
.70098 .08012 L
s
1 .894 .882 r
.70098 .08012 m
.70098 .06382 L
.70122 .06382 L
.70122 .08012 L
F
.804 .522 .247 r
.70098 .08012 m
.70098 .06382 L
.70122 .06382 L
.70122 .08012 L
s
1 .894 .882 r
.70122 .08012 m
.70122 .06376 L
.70145 .06376 L
.70145 .08012 L
F
.804 .522 .247 r
.70122 .08012 m
.70122 .06376 L
.70145 .06376 L
.70145 .08012 L
s
1 .894 .882 r
.70145 .08012 m
.70145 .0637 L
.70162 .0637 L
.70162 .08012 L
F
.804 .522 .247 r
.70145 .08012 m
.70145 .0637 L
.70162 .0637 L
.70162 .08012 L
s
1 .894 .882 r
.70162 .08012 m
.70162 .06354 L
.70189 .06354 L
.70189 .08012 L
F
.804 .522 .247 r
.70162 .08012 m
.70162 .06354 L
.70189 .06354 L
.70189 .08012 L
s
1 .894 .882 r
.70189 .08012 m
.70189 .06349 L
.70213 .06349 L
.70213 .08012 L
F
.804 .522 .247 r
.70189 .08012 m
.70189 .06349 L
.70213 .06349 L
.70213 .08012 L
s
1 .894 .882 r
.70213 .08012 m
.70213 .06333 L
.70254 .06333 L
.70254 .08012 L
F
.804 .522 .247 r
.70213 .08012 m
.70213 .06333 L
.70254 .06333 L
.70254 .08012 L
s
1 .894 .882 r
.70254 .08012 m
.70254 .06321 L
.70297 .06321 L
.70297 .08012 L
F
.804 .522 .247 r
.70254 .08012 m
.70254 .06321 L
.70297 .06321 L
.70297 .08012 L
s
1 .894 .882 r
.70297 .08012 m
.70297 .06307 L
.70346 .06307 L
.70346 .08012 L
F
.804 .522 .247 r
.70297 .08012 m
.70297 .06307 L
.70346 .06307 L
.70346 .08012 L
s
1 .894 .882 r
.70346 .08012 m
.70346 .06291 L
.70375 .06291 L
.70375 .08012 L
F
.804 .522 .247 r
.70346 .08012 m
.70346 .06291 L
.70375 .06291 L
.70375 .08012 L
s
1 .894 .882 r
.70375 .08012 m
.70375 .06283 L
.70391 .06283 L
.70391 .08012 L
F
.804 .522 .247 r
.70375 .08012 m
.70375 .06283 L
.70391 .06283 L
.70391 .08012 L
s
1 .894 .882 r
.70391 .08012 m
.70391 .06278 L
.70423 .06278 L
.70423 .08012 L
F
.804 .522 .247 r
.70391 .08012 m
.70391 .06278 L
.70423 .06278 L
.70423 .08012 L
s
1 .894 .882 r
.70423 .08012 m
.70423 .06266 L
.70469 .06266 L
.70469 .08012 L
F
.804 .522 .247 r
.70423 .08012 m
.70423 .06266 L
.70469 .06266 L
.70469 .08012 L
s
1 .894 .882 r
.70469 .08012 m
.70469 .06247 L
.70502 .06247 L
.70502 .08012 L
F
.804 .522 .247 r
.70469 .08012 m
.70469 .06247 L
.70502 .06247 L
.70502 .08012 L
s
1 .894 .882 r
.70502 .08012 m
.70502 .06242 L
.70526 .06242 L
.70526 .08012 L
F
.804 .522 .247 r
.70502 .08012 m
.70502 .06242 L
.70526 .06242 L
.70526 .08012 L
s
1 .894 .882 r
.70526 .08012 m
.70526 .06234 L
.7055 .06234 L
.7055 .08012 L
F
.804 .522 .247 r
.70526 .08012 m
.70526 .06234 L
.7055 .06234 L
.7055 .08012 L
s
1 .894 .882 r
.7055 .08012 m
.7055 .06223 L
.70571 .06223 L
.70571 .08012 L
F
.804 .522 .247 r
.7055 .08012 m
.7055 .06223 L
.70571 .06223 L
.70571 .08012 L
s
1 .894 .882 r
.70571 .08012 m
.70571 .06216 L
.70605 .06216 L
.70605 .08012 L
F
.804 .522 .247 r
.70571 .08012 m
.70571 .06216 L
.70605 .06216 L
.70605 .08012 L
s
1 .894 .882 r
.70605 .08012 m
.70605 .06206 L
.70626 .06206 L
.70626 .08012 L
F
.804 .522 .247 r
.70605 .08012 m
.70605 .06206 L
.70626 .06206 L
.70626 .08012 L
s
1 .894 .882 r
.70626 .08012 m
.70626 .06192 L
.70667 .06192 L
.70667 .08012 L
F
.804 .522 .247 r
.70626 .08012 m
.70626 .06192 L
.70667 .06192 L
.70667 .08012 L
s
1 .894 .882 r
.70667 .08012 m
.70667 .06185 L
.70691 .06185 L
.70691 .08012 L
F
.804 .522 .247 r
.70667 .08012 m
.70667 .06185 L
.70691 .06185 L
.70691 .08012 L
s
1 .894 .882 r
.70691 .08012 m
.70691 .06167 L
.70724 .06167 L
.70724 .08012 L
F
.804 .522 .247 r
.70691 .08012 m
.70691 .06167 L
.70724 .06167 L
.70724 .08012 L
s
1 .894 .882 r
.70724 .08012 m
.70724 .06163 L
.70742 .06163 L
.70742 .08012 L
F
.804 .522 .247 r
.70724 .08012 m
.70724 .06163 L
.70742 .06163 L
.70742 .08012 L
s
1 .894 .882 r
.70742 .08012 m
.70742 .06155 L
.7076 .06155 L
.7076 .08012 L
F
.804 .522 .247 r
.70742 .08012 m
.70742 .06155 L
.7076 .06155 L
.7076 .08012 L
s
1 .894 .882 r
.7076 .08012 m
.7076 .06144 L
.70787 .06144 L
.70787 .08012 L
F
.804 .522 .247 r
.7076 .08012 m
.7076 .06144 L
.70787 .06144 L
.70787 .08012 L
s
1 .894 .882 r
.70787 .08012 m
.70787 .06141 L
.7081 .06141 L
.7081 .08012 L
F
.804 .522 .247 r
.70787 .08012 m
.70787 .06141 L
.7081 .06141 L
.7081 .08012 L
s
1 .894 .882 r
.7081 .08012 m
.7081 .06134 L
.70856 .06134 L
.70856 .08012 L
F
.804 .522 .247 r
.7081 .08012 m
.7081 .06134 L
.70856 .06134 L
.70856 .08012 L
s
1 .894 .882 r
.70856 .08012 m
.70856 .0611 L
.70905 .0611 L
.70905 .08012 L
F
.804 .522 .247 r
.70856 .08012 m
.70856 .0611 L
.70905 .0611 L
.70905 .08012 L
s
1 .894 .882 r
.70905 .08012 m
.70905 .06097 L
.7092 .06097 L
.7092 .08012 L
F
.804 .522 .247 r
.70905 .08012 m
.70905 .06097 L
.7092 .06097 L
.7092 .08012 L
s
1 .894 .882 r
.7092 .08012 m
.7092 .06085 L
.70969 .06085 L
.70969 .08012 L
F
.804 .522 .247 r
.7092 .08012 m
.7092 .06085 L
.70969 .06085 L
.70969 .08012 L
s
1 .894 .882 r
.70969 .08012 m
.70969 .06079 L
.70988 .06079 L
.70988 .08012 L
F
.804 .522 .247 r
.70969 .08012 m
.70969 .06079 L
.70988 .06079 L
.70988 .08012 L
s
1 .894 .882 r
.70988 .08012 m
.70988 .06067 L
.71009 .06067 L
.71009 .08012 L
F
.804 .522 .247 r
.70988 .08012 m
.70988 .06067 L
.71009 .06067 L
.71009 .08012 L
s
1 .894 .882 r
.71009 .08012 m
.71009 .06064 L
.71024 .06064 L
.71024 .08012 L
F
.804 .522 .247 r
.71009 .08012 m
.71009 .06064 L
.71024 .06064 L
.71024 .08012 L
s
1 .894 .882 r
.71024 .08012 m
.71024 .0605 L
.71059 .0605 L
.71059 .08012 L
F
.804 .522 .247 r
.71024 .08012 m
.71024 .0605 L
.71059 .0605 L
.71059 .08012 L
s
1 .894 .882 r
.71059 .08012 m
.71059 .06048 L
.71077 .06048 L
.71077 .08012 L
F
.804 .522 .247 r
.71059 .08012 m
.71059 .06048 L
.71077 .06048 L
.71077 .08012 L
s
1 .894 .882 r
.71077 .08012 m
.71077 .06037 L
.71114 .06037 L
.71114 .08012 L
F
.804 .522 .247 r
.71077 .08012 m
.71077 .06037 L
.71114 .06037 L
.71114 .08012 L
s
1 .894 .882 r
.71114 .08012 m
.71114 .06029 L
.71134 .06029 L
.71134 .08012 L
F
.804 .522 .247 r
.71114 .08012 m
.71114 .06029 L
.71134 .06029 L
.71134 .08012 L
s
1 .894 .882 r
.71134 .08012 m
.71134 .06022 L
.7115 .06022 L
.7115 .08012 L
F
.804 .522 .247 r
.71134 .08012 m
.71134 .06022 L
.7115 .06022 L
.7115 .08012 L
s
1 .894 .882 r
.7115 .08012 m
.7115 .06015 L
.71193 .06015 L
.71193 .08012 L
F
.804 .522 .247 r
.7115 .08012 m
.7115 .06015 L
.71193 .06015 L
.71193 .08012 L
s
1 .894 .882 r
.71193 .08012 m
.71193 .06 L
.71221 .06 L
.71221 .08012 L
F
.804 .522 .247 r
.71193 .08012 m
.71193 .06 L
.71221 .06 L
.71221 .08012 L
s
1 .894 .882 r
.71221 .08012 m
.71221 .05983 L
.71268 .05983 L
.71268 .08012 L
F
.804 .522 .247 r
.71221 .08012 m
.71221 .05983 L
.71268 .05983 L
.71268 .08012 L
s
1 .894 .882 r
.71268 .08012 m
.71268 .05977 L
.713 .05977 L
.713 .08012 L
F
.804 .522 .247 r
.71268 .08012 m
.71268 .05977 L
.713 .05977 L
.713 .08012 L
s
1 .894 .882 r
.713 .08012 m
.713 .05966 L
.71338 .05966 L
.71338 .08012 L
F
.804 .522 .247 r
.713 .08012 m
.713 .05966 L
.71338 .05966 L
.71338 .08012 L
s
1 .894 .882 r
.71338 .08012 m
.71338 .05944 L
.71374 .05944 L
.71374 .08012 L
F
.804 .522 .247 r
.71338 .08012 m
.71338 .05944 L
.71374 .05944 L
.71374 .08012 L
s
1 .894 .882 r
.71374 .08012 m
.71374 .05934 L
.71412 .05934 L
.71412 .08012 L
F
.804 .522 .247 r
.71374 .08012 m
.71374 .05934 L
.71412 .05934 L
.71412 .08012 L
s
1 .894 .882 r
.71412 .08012 m
.71412 .05926 L
.7146 .05926 L
.7146 .08012 L
F
.804 .522 .247 r
.71412 .08012 m
.71412 .05926 L
.7146 .05926 L
.7146 .08012 L
s
1 .894 .882 r
.7146 .08012 m
.7146 .05904 L
.71494 .05904 L
.71494 .08012 L
F
.804 .522 .247 r
.7146 .08012 m
.7146 .05904 L
.71494 .05904 L
.71494 .08012 L
s
1 .894 .882 r
.71494 .08012 m
.71494 .05899 L
.71527 .05899 L
.71527 .08012 L
F
.804 .522 .247 r
.71494 .08012 m
.71494 .05899 L
.71527 .05899 L
.71527 .08012 L
s
1 .894 .882 r
.71527 .08012 m
.71527 .05884 L
.71553 .05884 L
.71553 .08012 L
F
.804 .522 .247 r
.71527 .08012 m
.71527 .05884 L
.71553 .05884 L
.71553 .08012 L
s
1 .894 .882 r
.71553 .08012 m
.71553 .05871 L
.71592 .05871 L
.71592 .08012 L
F
.804 .522 .247 r
.71553 .08012 m
.71553 .05871 L
.71592 .05871 L
.71592 .08012 L
s
1 .894 .882 r
.71592 .08012 m
.71592 .0586 L
.7163 .0586 L
.7163 .08012 L
F
.804 .522 .247 r
.71592 .08012 m
.71592 .0586 L
.7163 .0586 L
.7163 .08012 L
s
1 .894 .882 r
.7163 .08012 m
.7163 .05849 L
.71663 .05849 L
.71663 .08012 L
F
.804 .522 .247 r
.7163 .08012 m
.7163 .05849 L
.71663 .05849 L
.71663 .08012 L
s
1 .894 .882 r
.71663 .08012 m
.71663 .05838 L
.71689 .05838 L
.71689 .08012 L
F
.804 .522 .247 r
.71663 .08012 m
.71663 .05838 L
.71689 .05838 L
.71689 .08012 L
s
1 .894 .882 r
.71689 .08012 m
.71689 .05835 L
.71728 .05835 L
.71728 .08012 L
F
.804 .522 .247 r
.71689 .08012 m
.71689 .05835 L
.71728 .05835 L
.71728 .08012 L
s
1 .894 .882 r
.71728 .08012 m
.71728 .05817 L
.71761 .05817 L
.71761 .08012 L
F
.804 .522 .247 r
.71728 .08012 m
.71728 .05817 L
.71761 .05817 L
.71761 .08012 L
s
1 .894 .882 r
.71761 .08012 m
.71761 .05805 L
.71789 .05805 L
.71789 .08012 L
F
.804 .522 .247 r
.71761 .08012 m
.71761 .05805 L
.71789 .05805 L
.71789 .08012 L
s
1 .894 .882 r
.71789 .08012 m
.71789 .058 L
.71814 .058 L
.71814 .08012 L
F
.804 .522 .247 r
.71789 .08012 m
.71789 .058 L
.71814 .058 L
.71814 .08012 L
s
1 .894 .882 r
.71814 .08012 m
.71814 .05793 L
.71834 .05793 L
.71834 .08012 L
F
.804 .522 .247 r
.71814 .08012 m
.71814 .05793 L
.71834 .05793 L
.71834 .08012 L
s
1 .894 .882 r
.71834 .08012 m
.71834 .05785 L
.71863 .05785 L
.71863 .08012 L
F
.804 .522 .247 r
.71834 .08012 m
.71834 .05785 L
.71863 .05785 L
.71863 .08012 L
s
1 .894 .882 r
.71863 .08012 m
.71863 .05775 L
.71903 .05775 L
.71903 .08012 L
F
.804 .522 .247 r
.71863 .08012 m
.71863 .05775 L
.71903 .05775 L
.71903 .08012 L
s
1 .894 .882 r
.71903 .08012 m
.71903 .05763 L
.71923 .05763 L
.71923 .08012 L
F
.804 .522 .247 r
.71903 .08012 m
.71903 .05763 L
.71923 .05763 L
.71923 .08012 L
s
1 .894 .882 r
.71923 .08012 m
.71923 .05752 L
.71942 .05752 L
.71942 .08012 L
F
.804 .522 .247 r
.71923 .08012 m
.71923 .05752 L
.71942 .05752 L
.71942 .08012 L
s
1 .894 .882 r
.71942 .08012 m
.71942 .0574 L
.71977 .0574 L
.71977 .08012 L
F
.804 .522 .247 r
.71942 .08012 m
.71942 .0574 L
.71977 .0574 L
.71977 .08012 L
s
1 .894 .882 r
.71977 .08012 m
.71977 .05732 L
.72004 .05732 L
.72004 .08012 L
F
.804 .522 .247 r
.71977 .08012 m
.71977 .05732 L
.72004 .05732 L
.72004 .08012 L
s
1 .894 .882 r
.72004 .08012 m
.72004 .05727 L
.72026 .05727 L
.72026 .08012 L
F
.804 .522 .247 r
.72004 .08012 m
.72004 .05727 L
.72026 .05727 L
.72026 .08012 L
s
1 .894 .882 r
.72026 .08012 m
.72026 .05713 L
.72062 .05713 L
.72062 .08012 L
F
.804 .522 .247 r
.72026 .08012 m
.72026 .05713 L
.72062 .05713 L
.72062 .08012 L
s
1 .894 .882 r
.72062 .08012 m
.72062 .05697 L
.72108 .05697 L
.72108 .08012 L
F
.804 .522 .247 r
.72062 .08012 m
.72062 .05697 L
.72108 .05697 L
.72108 .08012 L
s
1 .894 .882 r
.72108 .08012 m
.72108 .05682 L
.72149 .05682 L
.72149 .08012 L
F
.804 .522 .247 r
.72108 .08012 m
.72108 .05682 L
.72149 .05682 L
.72149 .08012 L
s
1 .894 .882 r
.72149 .08012 m
.72149 .05673 L
.72182 .05673 L
.72182 .08012 L
F
.804 .522 .247 r
.72149 .08012 m
.72149 .05673 L
.72182 .05673 L
.72182 .08012 L
s
1 .894 .882 r
.72182 .08012 m
.72182 .05663 L
.7222 .05663 L
.7222 .08012 L
F
.804 .522 .247 r
.72182 .08012 m
.72182 .05663 L
.7222 .05663 L
.7222 .08012 L
s
1 .894 .882 r
.7222 .08012 m
.7222 .05656 L
.72247 .05656 L
.72247 .08012 L
F
.804 .522 .247 r
.7222 .08012 m
.7222 .05656 L
.72247 .05656 L
.72247 .08012 L
s
1 .894 .882 r
.72247 .08012 m
.72247 .05643 L
.72269 .05643 L
.72269 .08012 L
F
.804 .522 .247 r
.72247 .08012 m
.72247 .05643 L
.72269 .05643 L
.72269 .08012 L
s
1 .894 .882 r
.72269 .08012 m
.72269 .05641 L
.7229 .05641 L
.7229 .08012 L
F
.804 .522 .247 r
.72269 .08012 m
.72269 .05641 L
.7229 .05641 L
.7229 .08012 L
s
1 .894 .882 r
.7229 .08012 m
.7229 .05621 L
.72338 .05621 L
.72338 .08012 L
F
.804 .522 .247 r
.7229 .08012 m
.7229 .05621 L
.72338 .05621 L
.72338 .08012 L
s
1 .894 .882 r
.72338 .08012 m
.72338 .05612 L
.72377 .05612 L
.72377 .08012 L
F
.804 .522 .247 r
.72338 .08012 m
.72338 .05612 L
.72377 .05612 L
.72377 .08012 L
s
1 .894 .882 r
.72377 .08012 m
.72377 .05603 L
.72415 .05603 L
.72415 .08012 L
F
.804 .522 .247 r
.72377 .08012 m
.72377 .05603 L
.72415 .05603 L
.72415 .08012 L
s
1 .894 .882 r
.72415 .08012 m
.72415 .05587 L
.7246 .05587 L
.7246 .08012 L
F
.804 .522 .247 r
.72415 .08012 m
.72415 .05587 L
.7246 .05587 L
.7246 .08012 L
s
1 .894 .882 r
.7246 .08012 m
.7246 .05573 L
.72483 .05573 L
.72483 .08012 L
F
.804 .522 .247 r
.7246 .08012 m
.7246 .05573 L
.72483 .05573 L
.72483 .08012 L
s
1 .894 .882 r
.72483 .08012 m
.72483 .0557 L
.72504 .0557 L
.72504 .08012 L
F
.804 .522 .247 r
.72483 .08012 m
.72483 .0557 L
.72504 .0557 L
.72504 .08012 L
s
1 .894 .882 r
.72504 .08012 m
.72504 .0556 L
.72529 .0556 L
.72529 .08012 L
F
.804 .522 .247 r
.72504 .08012 m
.72504 .0556 L
.72529 .0556 L
.72529 .08012 L
s
1 .894 .882 r
.72529 .08012 m
.72529 .05554 L
.72564 .05554 L
.72564 .08012 L
F
.804 .522 .247 r
.72529 .08012 m
.72529 .05554 L
.72564 .05554 L
.72564 .08012 L
s
1 .894 .882 r
.72564 .08012 m
.72564 .05541 L
.72581 .05541 L
.72581 .08012 L
F
.804 .522 .247 r
.72564 .08012 m
.72564 .05541 L
.72581 .05541 L
.72581 .08012 L
s
1 .894 .882 r
.72581 .08012 m
.72581 .05538 L
.72622 .05538 L
.72622 .08012 L
F
.804 .522 .247 r
.72581 .08012 m
.72581 .05538 L
.72622 .05538 L
.72622 .08012 L
s
1 .894 .882 r
.72622 .08012 m
.72622 .05521 L
.72657 .05521 L
.72657 .08012 L
F
.804 .522 .247 r
.72622 .08012 m
.72622 .05521 L
.72657 .05521 L
.72657 .08012 L
s
1 .894 .882 r
.72657 .08012 m
.72657 .05513 L
.72686 .05513 L
.72686 .08012 L
F
.804 .522 .247 r
.72657 .08012 m
.72657 .05513 L
.72686 .05513 L
.72686 .08012 L
s
1 .894 .882 r
.72686 .08012 m
.72686 .05505 L
.72734 .05505 L
.72734 .08012 L
F
.804 .522 .247 r
.72686 .08012 m
.72686 .05505 L
.72734 .05505 L
.72734 .08012 L
s
1 .894 .882 r
.72734 .08012 m
.72734 .05488 L
.72755 .05488 L
.72755 .08012 L
F
.804 .522 .247 r
.72734 .08012 m
.72734 .05488 L
.72755 .05488 L
.72755 .08012 L
s
1 .894 .882 r
.72755 .08012 m
.72755 .05478 L
.72778 .05478 L
.72778 .08012 L
F
.804 .522 .247 r
.72755 .08012 m
.72755 .05478 L
.72778 .05478 L
.72778 .08012 L
s
1 .894 .882 r
.72778 .08012 m
.72778 .0547 L
.728 .0547 L
.728 .08012 L
F
.804 .522 .247 r
.72778 .08012 m
.72778 .0547 L
.728 .0547 L
.728 .08012 L
s
1 .894 .882 r
.728 .08012 m
.728 .05466 L
.72826 .05466 L
.72826 .08012 L
F
.804 .522 .247 r
.728 .08012 m
.728 .05466 L
.72826 .05466 L
.72826 .08012 L
s
1 .894 .882 r
.72826 .08012 m
.72826 .05458 L
.7285 .05458 L
.7285 .08012 L
F
.804 .522 .247 r
.72826 .08012 m
.72826 .05458 L
.7285 .05458 L
.7285 .08012 L
s
1 .894 .882 r
.7285 .08012 m
.7285 .05445 L
.72881 .05445 L
.72881 .08012 L
F
.804 .522 .247 r
.7285 .08012 m
.7285 .05445 L
.72881 .05445 L
.72881 .08012 L
s
1 .894 .882 r
.72881 .08012 m
.72881 .05441 L
.72919 .05441 L
.72919 .08012 L
F
.804 .522 .247 r
.72881 .08012 m
.72881 .05441 L
.72919 .05441 L
.72919 .08012 L
s
1 .894 .882 r
.72919 .08012 m
.72919 .05422 L
.72957 .05422 L
.72957 .08012 L
F
.804 .522 .247 r
.72919 .08012 m
.72919 .05422 L
.72957 .05422 L
.72957 .08012 L
s
1 .894 .882 r
.72957 .08012 m
.72957 .05415 L
.73003 .05415 L
.73003 .08012 L
F
.804 .522 .247 r
.72957 .08012 m
.72957 .05415 L
.73003 .05415 L
.73003 .08012 L
s
1 .894 .882 r
.73003 .08012 m
.73003 .05396 L
.73027 .05396 L
.73027 .08012 L
F
.804 .522 .247 r
.73003 .08012 m
.73003 .05396 L
.73027 .05396 L
.73027 .08012 L
s
1 .894 .882 r
.73027 .08012 m
.73027 .05395 L
.73059 .05395 L
.73059 .08012 L
F
.804 .522 .247 r
.73027 .08012 m
.73027 .05395 L
.73059 .05395 L
.73059 .08012 L
s
1 .894 .882 r
.73059 .08012 m
.73059 .05376 L
.73097 .05376 L
.73097 .08012 L
F
.804 .522 .247 r
.73059 .08012 m
.73059 .05376 L
.73097 .05376 L
.73097 .08012 L
s
1 .894 .882 r
.73097 .08012 m
.73097 .05369 L
.7312 .05369 L
.7312 .08012 L
F
.804 .522 .247 r
.73097 .08012 m
.73097 .05369 L
.7312 .05369 L
.7312 .08012 L
s
1 .894 .882 r
.7312 .08012 m
.7312 .05359 L
.73155 .05359 L
.73155 .08012 L
F
.804 .522 .247 r
.7312 .08012 m
.7312 .05359 L
.73155 .05359 L
.73155 .08012 L
s
1 .894 .882 r
.73155 .08012 m
.73155 .05348 L
.7319 .05348 L
.7319 .08012 L
F
.804 .522 .247 r
.73155 .08012 m
.73155 .05348 L
.7319 .05348 L
.7319 .08012 L
s
1 .894 .882 r
.7319 .08012 m
.7319 .05335 L
.73221 .05335 L
.73221 .08012 L
F
.804 .522 .247 r
.7319 .08012 m
.7319 .05335 L
.73221 .05335 L
.73221 .08012 L
s
1 .894 .882 r
.73221 .08012 m
.73221 .05332 L
.73238 .05332 L
.73238 .08012 L
F
.804 .522 .247 r
.73221 .08012 m
.73221 .05332 L
.73238 .05332 L
.73238 .08012 L
s
1 .894 .882 r
.73238 .08012 m
.73238 .05329 L
.73261 .05329 L
.73261 .08012 L
F
.804 .522 .247 r
.73238 .08012 m
.73238 .05329 L
.73261 .05329 L
.73261 .08012 L
s
1 .894 .882 r
.73261 .08012 m
.73261 .05319 L
.73278 .05319 L
.73278 .08012 L
F
.804 .522 .247 r
.73261 .08012 m
.73261 .05319 L
.73278 .05319 L
.73278 .08012 L
s
1 .894 .882 r
.73278 .08012 m
.73278 .05315 L
.73306 .05315 L
.73306 .08012 L
F
.804 .522 .247 r
.73278 .08012 m
.73278 .05315 L
.73306 .05315 L
.73306 .08012 L
s
1 .894 .882 r
.73306 .08012 m
.73306 .05305 L
.73331 .05305 L
.73331 .08012 L
F
.804 .522 .247 r
.73306 .08012 m
.73306 .05305 L
.73331 .05305 L
.73331 .08012 L
s
1 .894 .882 r
.73331 .08012 m
.73331 .05293 L
.73368 .05293 L
.73368 .08012 L
F
.804 .522 .247 r
.73331 .08012 m
.73331 .05293 L
.73368 .05293 L
.73368 .08012 L
s
1 .894 .882 r
.73368 .08012 m
.73368 .05286 L
.73405 .05286 L
.73405 .08012 L
F
.804 .522 .247 r
.73368 .08012 m
.73368 .05286 L
.73405 .05286 L
.73405 .08012 L
s
1 .894 .882 r
.73405 .08012 m
.73405 .05276 L
.73434 .05276 L
.73434 .08012 L
F
.804 .522 .247 r
.73405 .08012 m
.73405 .05276 L
.73434 .05276 L
.73434 .08012 L
s
1 .894 .882 r
.73434 .08012 m
.73434 .05267 L
.73453 .05267 L
.73453 .08012 L
F
.804 .522 .247 r
.73434 .08012 m
.73434 .05267 L
.73453 .05267 L
.73453 .08012 L
s
1 .894 .882 r
.73453 .08012 m
.73453 .05254 L
.73483 .05254 L
.73483 .08012 L
F
.804 .522 .247 r
.73453 .08012 m
.73453 .05254 L
.73483 .05254 L
.73483 .08012 L
s
1 .894 .882 r
.73483 .08012 m
.73483 .05249 L
.73513 .05249 L
.73513 .08012 L
F
.804 .522 .247 r
.73483 .08012 m
.73483 .05249 L
.73513 .05249 L
.73513 .08012 L
s
1 .894 .882 r
.73513 .08012 m
.73513 .05238 L
.73531 .05238 L
.73531 .08012 L
F
.804 .522 .247 r
.73513 .08012 m
.73513 .05238 L
.73531 .05238 L
.73531 .08012 L
s
1 .894 .882 r
.73531 .08012 m
.73531 .05228 L
.73575 .05228 L
.73575 .08012 L
F
.804 .522 .247 r
.73531 .08012 m
.73531 .05228 L
.73575 .05228 L
.73575 .08012 L
s
1 .894 .882 r
.73575 .08012 m
.73575 .05222 L
.73622 .05222 L
.73622 .08012 L
F
.804 .522 .247 r
.73575 .08012 m
.73575 .05222 L
.73622 .05222 L
.73622 .08012 L
s
1 .894 .882 r
.73622 .08012 m
.73622 .05207 L
.73663 .05207 L
.73663 .08012 L
F
.804 .522 .247 r
.73622 .08012 m
.73622 .05207 L
.73663 .05207 L
.73663 .08012 L
s
1 .894 .882 r
.73663 .08012 m
.73663 .05195 L
.73693 .05195 L
.73693 .08012 L
F
.804 .522 .247 r
.73663 .08012 m
.73663 .05195 L
.73693 .05195 L
.73693 .08012 L
s
1 .894 .882 r
.73693 .08012 m
.73693 .0518 L
.7374 .0518 L
.7374 .08012 L
F
.804 .522 .247 r
.73693 .08012 m
.73693 .0518 L
.7374 .0518 L
.7374 .08012 L
s
1 .894 .882 r
.7374 .08012 m
.7374 .05171 L
.73777 .05171 L
.73777 .08012 L
F
.804 .522 .247 r
.7374 .08012 m
.7374 .05171 L
.73777 .05171 L
.73777 .08012 L
s
1 .894 .882 r
.73777 .08012 m
.73777 .0516 L
.73802 .0516 L
.73802 .08012 L
F
.804 .522 .247 r
.73777 .08012 m
.73777 .0516 L
.73802 .0516 L
.73802 .08012 L
s
1 .894 .882 r
.73802 .08012 m
.73802 .05149 L
.73842 .05149 L
.73842 .08012 L
F
.804 .522 .247 r
.73802 .08012 m
.73802 .05149 L
.73842 .05149 L
.73842 .08012 L
s
1 .894 .882 r
.73842 .08012 m
.73842 .0513 L
.73882 .0513 L
.73882 .08012 L
F
.804 .522 .247 r
.73842 .08012 m
.73842 .0513 L
.73882 .0513 L
.73882 .08012 L
s
1 .894 .882 r
.73882 .08012 m
.73882 .05126 L
.73899 .05126 L
.73899 .08012 L
F
.804 .522 .247 r
.73882 .08012 m
.73882 .05126 L
.73899 .05126 L
.73899 .08012 L
s
1 .894 .882 r
.73899 .08012 m
.73899 .05118 L
.73937 .05118 L
.73937 .08012 L
F
.804 .522 .247 r
.73899 .08012 m
.73899 .05118 L
.73937 .05118 L
.73937 .08012 L
s
1 .894 .882 r
.73937 .08012 m
.73937 .05109 L
.73961 .05109 L
.73961 .08012 L
F
.804 .522 .247 r
.73937 .08012 m
.73937 .05109 L
.73961 .05109 L
.73961 .08012 L
s
1 .894 .882 r
.73961 .08012 m
.73961 .05099 L
.73999 .05099 L
.73999 .08012 L
F
.804 .522 .247 r
.73961 .08012 m
.73961 .05099 L
.73999 .05099 L
.73999 .08012 L
s
1 .894 .882 r
.73999 .08012 m
.73999 .05087 L
.74042 .05087 L
.74042 .08012 L
F
.804 .522 .247 r
.73999 .08012 m
.73999 .05087 L
.74042 .05087 L
.74042 .08012 L
s
1 .894 .882 r
.74042 .08012 m
.74042 .05068 L
.74079 .05068 L
.74079 .08012 L
F
.804 .522 .247 r
.74042 .08012 m
.74042 .05068 L
.74079 .05068 L
.74079 .08012 L
s
1 .894 .882 r
.74079 .08012 m
.74079 .05065 L
.74124 .05065 L
.74124 .08012 L
F
.804 .522 .247 r
.74079 .08012 m
.74079 .05065 L
.74124 .05065 L
.74124 .08012 L
s
1 .894 .882 r
.74124 .08012 m
.74124 .05053 L
.74152 .05053 L
.74152 .08012 L
F
.804 .522 .247 r
.74124 .08012 m
.74124 .05053 L
.74152 .05053 L
.74152 .08012 L
s
1 .894 .882 r
.74152 .08012 m
.74152 .0504 L
.74172 .0504 L
.74172 .08012 L
F
.804 .522 .247 r
.74152 .08012 m
.74152 .0504 L
.74172 .0504 L
.74172 .08012 L
s
1 .894 .882 r
.74172 .08012 m
.74172 .05028 L
.74221 .05028 L
.74221 .08012 L
F
.804 .522 .247 r
.74172 .08012 m
.74172 .05028 L
.74221 .05028 L
.74221 .08012 L
s
1 .894 .882 r
.74221 .08012 m
.74221 .05023 L
.74252 .05023 L
.74252 .08012 L
F
.804 .522 .247 r
.74221 .08012 m
.74221 .05023 L
.74252 .05023 L
.74252 .08012 L
s
1 .894 .882 r
.74252 .08012 m
.74252 .05014 L
.74275 .05014 L
.74275 .08012 L
F
.804 .522 .247 r
.74252 .08012 m
.74252 .05014 L
.74275 .05014 L
.74275 .08012 L
s
1 .894 .882 r
.74275 .08012 m
.74275 .05007 L
.74315 .05007 L
.74315 .08012 L
F
.804 .522 .247 r
.74275 .08012 m
.74275 .05007 L
.74315 .05007 L
.74315 .08012 L
s
1 .894 .882 r
.74315 .08012 m
.74315 .04991 L
.74349 .04991 L
.74349 .08012 L
F
.804 .522 .247 r
.74315 .08012 m
.74315 .04991 L
.74349 .04991 L
.74349 .08012 L
s
1 .894 .882 r
.74349 .08012 m
.74349 .04982 L
.74377 .04982 L
.74377 .08012 L
F
.804 .522 .247 r
.74349 .08012 m
.74349 .04982 L
.74377 .04982 L
.74377 .08012 L
s
1 .894 .882 r
.74377 .08012 m
.74377 .04973 L
.74405 .04973 L
.74405 .08012 L
F
.804 .522 .247 r
.74377 .08012 m
.74377 .04973 L
.74405 .04973 L
.74405 .08012 L
s
1 .894 .882 r
.74405 .08012 m
.74405 .04956 L
.74448 .04956 L
.74448 .08012 L
F
.804 .522 .247 r
.74405 .08012 m
.74405 .04956 L
.74448 .04956 L
.74448 .08012 L
s
1 .894 .882 r
.74448 .08012 m
.74448 .04951 L
.7449 .04951 L
.7449 .08012 L
F
.804 .522 .247 r
.74448 .08012 m
.74448 .04951 L
.7449 .04951 L
.7449 .08012 L
s
1 .894 .882 r
.7449 .08012 m
.7449 .04939 L
.74537 .04939 L
.74537 .08012 L
F
.804 .522 .247 r
.7449 .08012 m
.7449 .04939 L
.74537 .04939 L
.74537 .08012 L
s
1 .894 .882 r
.74537 .08012 m
.74537 .04929 L
.74568 .04929 L
.74568 .08012 L
F
.804 .522 .247 r
.74537 .08012 m
.74537 .04929 L
.74568 .04929 L
.74568 .08012 L
s
1 .894 .882 r
.74568 .08012 m
.74568 .04915 L
.74587 .04915 L
.74587 .08012 L
F
.804 .522 .247 r
.74568 .08012 m
.74568 .04915 L
.74587 .04915 L
.74587 .08012 L
s
1 .894 .882 r
.74587 .08012 m
.74587 .04911 L
.74619 .04911 L
.74619 .08012 L
F
.804 .522 .247 r
.74587 .08012 m
.74587 .04911 L
.74619 .04911 L
.74619 .08012 L
s
1 .894 .882 r
.74619 .08012 m
.74619 .04904 L
.74641 .04904 L
.74641 .08012 L
F
.804 .522 .247 r
.74619 .08012 m
.74619 .04904 L
.74641 .04904 L
.74641 .08012 L
s
1 .894 .882 r
.74641 .08012 m
.74641 .04896 L
.74681 .04896 L
.74681 .08012 L
F
.804 .522 .247 r
.74641 .08012 m
.74641 .04896 L
.74681 .04896 L
.74681 .08012 L
s
1 .894 .882 r
.74681 .08012 m
.74681 .04884 L
.74697 .04884 L
.74697 .08012 L
F
.804 .522 .247 r
.74681 .08012 m
.74681 .04884 L
.74697 .04884 L
.74697 .08012 L
s
1 .894 .882 r
.74697 .08012 m
.74697 .04869 L
.74741 .04869 L
.74741 .08012 L
F
.804 .522 .247 r
.74697 .08012 m
.74697 .04869 L
.74741 .04869 L
.74741 .08012 L
s
1 .894 .882 r
.74741 .08012 m
.74741 .04858 L
.74788 .04858 L
.74788 .08012 L
F
.804 .522 .247 r
.74741 .08012 m
.74741 .04858 L
.74788 .04858 L
.74788 .08012 L
s
1 .894 .882 r
.74788 .08012 m
.74788 .0485 L
.74806 .0485 L
.74806 .08012 L
F
.804 .522 .247 r
.74788 .08012 m
.74788 .0485 L
.74806 .0485 L
.74806 .08012 L
s
1 .894 .882 r
.74806 .08012 m
.74806 .04849 L
.74828 .04849 L
.74828 .08012 L
F
.804 .522 .247 r
.74806 .08012 m
.74806 .04849 L
.74828 .04849 L
.74828 .08012 L
s
1 .894 .882 r
.74828 .08012 m
.74828 .04836 L
.74849 .04836 L
.74849 .08012 L
F
.804 .522 .247 r
.74828 .08012 m
.74828 .04836 L
.74849 .04836 L
.74849 .08012 L
s
1 .894 .882 r
.74849 .08012 m
.74849 .04833 L
.74866 .04833 L
.74866 .08012 L
F
.804 .522 .247 r
.74849 .08012 m
.74849 .04833 L
.74866 .04833 L
.74866 .08012 L
s
1 .894 .882 r
.74866 .08012 m
.74866 .04823 L
.74905 .04823 L
.74905 .08012 L
F
.804 .522 .247 r
.74866 .08012 m
.74866 .04823 L
.74905 .04823 L
.74905 .08012 L
s
1 .894 .882 r
.74905 .08012 m
.74905 .04819 L
.74922 .04819 L
.74922 .08012 L
F
.804 .522 .247 r
.74905 .08012 m
.74905 .04819 L
.74922 .04819 L
.74922 .08012 L
s
1 .894 .882 r
.74922 .08012 m
.74922 .04813 L
.74944 .04813 L
.74944 .08012 L
F
.804 .522 .247 r
.74922 .08012 m
.74922 .04813 L
.74944 .04813 L
.74944 .08012 L
s
1 .894 .882 r
.74944 .08012 m
.74944 .04803 L
.74979 .04803 L
.74979 .08012 L
F
.804 .522 .247 r
.74944 .08012 m
.74944 .04803 L
.74979 .04803 L
.74979 .08012 L
s
1 .894 .882 r
.74979 .08012 m
.74979 .04793 L
.75009 .04793 L
.75009 .08012 L
F
.804 .522 .247 r
.74979 .08012 m
.74979 .04793 L
.75009 .04793 L
.75009 .08012 L
s
1 .894 .882 r
.75009 .08012 m
.75009 .04788 L
.75035 .04788 L
.75035 .08012 L
F
.804 .522 .247 r
.75009 .08012 m
.75009 .04788 L
.75035 .04788 L
.75035 .08012 L
s
1 .894 .882 r
.75035 .08012 m
.75035 .04773 L
.75072 .04773 L
.75072 .08012 L
F
.804 .522 .247 r
.75035 .08012 m
.75035 .04773 L
.75072 .04773 L
.75072 .08012 L
s
1 .894 .882 r
.75072 .08012 m
.75072 .0477 L
.75095 .0477 L
.75095 .08012 L
F
.804 .522 .247 r
.75072 .08012 m
.75072 .0477 L
.75095 .0477 L
.75095 .08012 L
s
1 .894 .882 r
.75095 .08012 m
.75095 .04763 L
.75111 .04763 L
.75111 .08012 L
F
.804 .522 .247 r
.75095 .08012 m
.75095 .04763 L
.75111 .04763 L
.75111 .08012 L
s
1 .894 .882 r
.75111 .08012 m
.75111 .04757 L
.75144 .04757 L
.75144 .08012 L
F
.804 .522 .247 r
.75111 .08012 m
.75111 .04757 L
.75144 .04757 L
.75144 .08012 L
s
1 .894 .882 r
.75144 .08012 m
.75144 .04745 L
.75188 .04745 L
.75188 .08012 L
F
.804 .522 .247 r
.75144 .08012 m
.75144 .04745 L
.75188 .04745 L
.75188 .08012 L
s
1 .894 .882 r
.75188 .08012 m
.75188 .04731 L
.75214 .04731 L
.75214 .08012 L
F
.804 .522 .247 r
.75188 .08012 m
.75188 .04731 L
.75214 .04731 L
.75214 .08012 L
s
1 .894 .882 r
.75214 .08012 m
.75214 .04728 L
.75248 .04728 L
.75248 .08012 L
F
.804 .522 .247 r
.75214 .08012 m
.75214 .04728 L
.75248 .04728 L
.75248 .08012 L
s
1 .894 .882 r
.75248 .08012 m
.75248 .04717 L
.75277 .04717 L
.75277 .08012 L
F
.804 .522 .247 r
.75248 .08012 m
.75248 .04717 L
.75277 .04717 L
.75277 .08012 L
s
1 .894 .882 r
.75277 .08012 m
.75277 .04711 L
.75303 .04711 L
.75303 .08012 L
F
.804 .522 .247 r
.75277 .08012 m
.75277 .04711 L
.75303 .04711 L
.75303 .08012 L
s
1 .894 .882 r
.75303 .08012 m
.75303 .04699 L
.75322 .04699 L
.75322 .08012 L
F
.804 .522 .247 r
.75303 .08012 m
.75303 .04699 L
.75322 .04699 L
.75322 .08012 L
s
1 .894 .882 r
.75322 .08012 m
.75322 .04687 L
.75365 .04687 L
.75365 .08012 L
F
.804 .522 .247 r
.75322 .08012 m
.75322 .04687 L
.75365 .04687 L
.75365 .08012 L
s
1 .894 .882 r
.75365 .08012 m
.75365 .04679 L
.75392 .04679 L
.75392 .08012 L
F
.804 .522 .247 r
.75365 .08012 m
.75365 .04679 L
.75392 .04679 L
.75392 .08012 L
s
1 .894 .882 r
.75392 .08012 m
.75392 .04677 L
.75424 .04677 L
.75424 .08012 L
F
.804 .522 .247 r
.75392 .08012 m
.75392 .04677 L
.75424 .04677 L
.75424 .08012 L
s
1 .894 .882 r
.75424 .08012 m
.75424 .04663 L
.75445 .04663 L
.75445 .08012 L
F
.804 .522 .247 r
.75424 .08012 m
.75424 .04663 L
.75445 .04663 L
.75445 .08012 L
s
1 .894 .882 r
.75445 .08012 m
.75445 .04661 L
.75485 .04661 L
.75485 .08012 L
F
.804 .522 .247 r
.75445 .08012 m
.75445 .04661 L
.75485 .04661 L
.75485 .08012 L
s
1 .894 .882 r
.75485 .08012 m
.75485 .04646 L
.75505 .04646 L
.75505 .08012 L
F
.804 .522 .247 r
.75485 .08012 m
.75485 .04646 L
.75505 .04646 L
.75505 .08012 L
s
1 .894 .882 r
.75505 .08012 m
.75505 .04644 L
.7553 .04644 L
.7553 .08012 L
F
.804 .522 .247 r
.75505 .08012 m
.75505 .04644 L
.7553 .04644 L
.7553 .08012 L
s
1 .894 .882 r
.7553 .08012 m
.7553 .04636 L
.75549 .04636 L
.75549 .08012 L
F
.804 .522 .247 r
.7553 .08012 m
.7553 .04636 L
.75549 .04636 L
.75549 .08012 L
s
1 .894 .882 r
.75549 .08012 m
.75549 .0463 L
.75565 .0463 L
.75565 .08012 L
F
.804 .522 .247 r
.75549 .08012 m
.75549 .0463 L
.75565 .0463 L
.75565 .08012 L
s
1 .894 .882 r
.75565 .08012 m
.75565 .04625 L
.75583 .04625 L
.75583 .08012 L
F
.804 .522 .247 r
.75565 .08012 m
.75565 .04625 L
.75583 .04625 L
.75583 .08012 L
s
1 .894 .882 r
.75583 .08012 m
.75583 .04618 L
.75601 .04618 L
.75601 .08012 L
F
.804 .522 .247 r
.75583 .08012 m
.75583 .04618 L
.75601 .04618 L
.75601 .08012 L
s
1 .894 .882 r
.75601 .08012 m
.75601 .04609 L
.75633 .04609 L
.75633 .08012 L
F
.804 .522 .247 r
.75601 .08012 m
.75601 .04609 L
.75633 .04609 L
.75633 .08012 L
s
1 .894 .882 r
.75633 .08012 m
.75633 .04599 L
.75668 .04599 L
.75668 .08012 L
F
.804 .522 .247 r
.75633 .08012 m
.75633 .04599 L
.75668 .04599 L
.75668 .08012 L
s
1 .894 .882 r
.75668 .08012 m
.75668 .04593 L
.7571 .04593 L
.7571 .08012 L
F
.804 .522 .247 r
.75668 .08012 m
.75668 .04593 L
.7571 .04593 L
.7571 .08012 L
s
1 .894 .882 r
.7571 .08012 m
.7571 .04585 L
.7574 .04585 L
.7574 .08012 L
F
.804 .522 .247 r
.7571 .08012 m
.7571 .04585 L
.7574 .04585 L
.7574 .08012 L
s
1 .894 .882 r
.7574 .08012 m
.7574 .04572 L
.75764 .04572 L
.75764 .08012 L
F
.804 .522 .247 r
.7574 .08012 m
.7574 .04572 L
.75764 .04572 L
.75764 .08012 L
s
1 .894 .882 r
.75764 .08012 m
.75764 .04563 L
.75798 .04563 L
.75798 .08012 L
F
.804 .522 .247 r
.75764 .08012 m
.75764 .04563 L
.75798 .04563 L
.75798 .08012 L
s
1 .894 .882 r
.75798 .08012 m
.75798 .0456 L
.75821 .0456 L
.75821 .08012 L
F
.804 .522 .247 r
.75798 .08012 m
.75798 .0456 L
.75821 .0456 L
.75821 .08012 L
s
1 .894 .882 r
.75821 .08012 m
.75821 .04547 L
.75857 .04547 L
.75857 .08012 L
F
.804 .522 .247 r
.75821 .08012 m
.75821 .04547 L
.75857 .04547 L
.75857 .08012 L
s
1 .894 .882 r
.75857 .08012 m
.75857 .04543 L
.75905 .04543 L
.75905 .08012 L
F
.804 .522 .247 r
.75857 .08012 m
.75857 .04543 L
.75905 .04543 L
.75905 .08012 L
s
1 .894 .882 r
.75905 .08012 m
.75905 .04522 L
.75953 .04522 L
.75953 .08012 L
F
.804 .522 .247 r
.75905 .08012 m
.75905 .04522 L
.75953 .04522 L
.75953 .08012 L
s
1 .894 .882 r
.75953 .08012 m
.75953 .04518 L
.75997 .04518 L
.75997 .08012 L
F
.804 .522 .247 r
.75953 .08012 m
.75953 .04518 L
.75997 .04518 L
.75997 .08012 L
s
1 .894 .882 r
.75997 .08012 m
.75997 .045 L
.76021 .045 L
.76021 .08012 L
F
.804 .522 .247 r
.75997 .08012 m
.75997 .045 L
.76021 .045 L
.76021 .08012 L
s
1 .894 .882 r
.76021 .08012 m
.76021 .04494 L
.76065 .04494 L
.76065 .08012 L
F
.804 .522 .247 r
.76021 .08012 m
.76021 .04494 L
.76065 .04494 L
.76065 .08012 L
s
1 .894 .882 r
.76065 .08012 m
.76065 .04482 L
.76086 .04482 L
.76086 .08012 L
F
.804 .522 .247 r
.76065 .08012 m
.76065 .04482 L
.76086 .04482 L
.76086 .08012 L
s
1 .894 .882 r
.76086 .08012 m
.76086 .04479 L
.76117 .04479 L
.76117 .08012 L
F
.804 .522 .247 r
.76086 .08012 m
.76086 .04479 L
.76117 .04479 L
.76117 .08012 L
s
1 .894 .882 r
.76117 .08012 m
.76117 .04464 L
.76158 .04464 L
.76158 .08012 L
F
.804 .522 .247 r
.76117 .08012 m
.76117 .04464 L
.76158 .04464 L
.76158 .08012 L
s
1 .894 .882 r
.76158 .08012 m
.76158 .04456 L
.76196 .04456 L
.76196 .08012 L
F
.804 .522 .247 r
.76158 .08012 m
.76158 .04456 L
.76196 .04456 L
.76196 .08012 L
s
1 .894 .882 r
.76196 .08012 m
.76196 .04444 L
.76226 .04444 L
.76226 .08012 L
F
.804 .522 .247 r
.76196 .08012 m
.76196 .04444 L
.76226 .04444 L
.76226 .08012 L
s
1 .894 .882 r
.76226 .08012 m
.76226 .04439 L
.76253 .04439 L
.76253 .08012 L
F
.804 .522 .247 r
.76226 .08012 m
.76226 .04439 L
.76253 .04439 L
.76253 .08012 L
s
1 .894 .882 r
.76253 .08012 m
.76253 .04429 L
.76283 .04429 L
.76283 .08012 L
F
.804 .522 .247 r
.76253 .08012 m
.76253 .04429 L
.76283 .04429 L
.76283 .08012 L
s
1 .894 .882 r
.76283 .08012 m
.76283 .04425 L
.76316 .04425 L
.76316 .08012 L
F
.804 .522 .247 r
.76283 .08012 m
.76283 .04425 L
.76316 .04425 L
.76316 .08012 L
s
1 .894 .882 r
.76316 .08012 m
.76316 .04415 L
.76345 .04415 L
.76345 .08012 L
F
.804 .522 .247 r
.76316 .08012 m
.76316 .04415 L
.76345 .04415 L
.76345 .08012 L
s
1 .894 .882 r
.76345 .08012 m
.76345 .04404 L
.76369 .04404 L
.76369 .08012 L
F
.804 .522 .247 r
.76345 .08012 m
.76345 .04404 L
.76369 .04404 L
.76369 .08012 L
s
1 .894 .882 r
.76369 .08012 m
.76369 .04397 L
.76395 .04397 L
.76395 .08012 L
F
.804 .522 .247 r
.76369 .08012 m
.76369 .04397 L
.76395 .04397 L
.76395 .08012 L
s
1 .894 .882 r
.76395 .08012 m
.76395 .04394 L
.76411 .04394 L
.76411 .08012 L
F
.804 .522 .247 r
.76395 .08012 m
.76395 .04394 L
.76411 .04394 L
.76411 .08012 L
s
1 .894 .882 r
.76411 .08012 m
.76411 .04386 L
.76454 .04386 L
.76454 .08012 L
F
.804 .522 .247 r
.76411 .08012 m
.76411 .04386 L
.76454 .04386 L
.76454 .08012 L
s
1 .894 .882 r
.76454 .08012 m
.76454 .04376 L
.76486 .04376 L
.76486 .08012 L
F
.804 .522 .247 r
.76454 .08012 m
.76454 .04376 L
.76486 .04376 L
.76486 .08012 L
s
1 .894 .882 r
.76486 .08012 m
.76486 .04363 L
.76531 .04363 L
.76531 .08012 L
F
.804 .522 .247 r
.76486 .08012 m
.76486 .04363 L
.76531 .04363 L
.76531 .08012 L
s
1 .894 .882 r
.76531 .08012 m
.76531 .04354 L
.76572 .04354 L
.76572 .08012 L
F
.804 .522 .247 r
.76531 .08012 m
.76531 .04354 L
.76572 .04354 L
.76572 .08012 L
s
1 .894 .882 r
.76572 .08012 m
.76572 .04342 L
.76597 .04342 L
.76597 .08012 L
F
.804 .522 .247 r
.76572 .08012 m
.76572 .04342 L
.76597 .04342 L
.76597 .08012 L
s
1 .894 .882 r
.76597 .08012 m
.76597 .04339 L
.7662 .04339 L
.7662 .08012 L
F
.804 .522 .247 r
.76597 .08012 m
.76597 .04339 L
.7662 .04339 L
.7662 .08012 L
s
1 .894 .882 r
.7662 .08012 m
.7662 .04328 L
.76644 .04328 L
.76644 .08012 L
F
.804 .522 .247 r
.7662 .08012 m
.7662 .04328 L
.76644 .04328 L
.76644 .08012 L
s
1 .894 .882 r
.76644 .08012 m
.76644 .04325 L
.76687 .04325 L
.76687 .08012 L
F
.804 .522 .247 r
.76644 .08012 m
.76644 .04325 L
.76687 .04325 L
.76687 .08012 L
s
1 .894 .882 r
.76687 .08012 m
.76687 .04309 L
.76712 .04309 L
.76712 .08012 L
F
.804 .522 .247 r
.76687 .08012 m
.76687 .04309 L
.76712 .04309 L
.76712 .08012 L
s
1 .894 .882 r
.76712 .08012 m
.76712 .04301 L
.7674 .04301 L
.7674 .08012 L
F
.804 .522 .247 r
.76712 .08012 m
.76712 .04301 L
.7674 .04301 L
.7674 .08012 L
s
1 .894 .882 r
.7674 .08012 m
.7674 .04296 L
.76755 .04296 L
.76755 .08012 L
F
.804 .522 .247 r
.7674 .08012 m
.7674 .04296 L
.76755 .04296 L
.76755 .08012 L
s
1 .894 .882 r
.76755 .08012 m
.76755 .04287 L
.76803 .04287 L
.76803 .08012 L
F
.804 .522 .247 r
.76755 .08012 m
.76755 .04287 L
.76803 .04287 L
.76803 .08012 L
s
1 .894 .882 r
.76803 .08012 m
.76803 .04283 L
.76822 .04283 L
.76822 .08012 L
F
.804 .522 .247 r
.76803 .08012 m
.76803 .04283 L
.76822 .04283 L
.76822 .08012 L
s
1 .894 .882 r
.76822 .08012 m
.76822 .04268 L
.76868 .04268 L
.76868 .08012 L
F
.804 .522 .247 r
.76822 .08012 m
.76822 .04268 L
.76868 .04268 L
.76868 .08012 L
s
1 .894 .882 r
.76868 .08012 m
.76868 .04264 L
.76892 .04264 L
.76892 .08012 L
F
.804 .522 .247 r
.76868 .08012 m
.76868 .04264 L
.76892 .04264 L
.76892 .08012 L
s
1 .894 .882 r
.76892 .08012 m
.76892 .04258 L
.76917 .04258 L
.76917 .08012 L
F
.804 .522 .247 r
.76892 .08012 m
.76892 .04258 L
.76917 .04258 L
.76917 .08012 L
s
1 .894 .882 r
.76917 .08012 m
.76917 .04249 L
.76956 .04249 L
.76956 .08012 L
F
.804 .522 .247 r
.76917 .08012 m
.76917 .04249 L
.76956 .04249 L
.76956 .08012 L
s
1 .894 .882 r
.76956 .08012 m
.76956 .04238 L
.76989 .04238 L
.76989 .08012 L
F
.804 .522 .247 r
.76956 .08012 m
.76956 .04238 L
.76989 .04238 L
.76989 .08012 L
s
1 .894 .882 r
.76989 .08012 m
.76989 .04225 L
.77032 .04225 L
.77032 .08012 L
F
.804 .522 .247 r
.76989 .08012 m
.76989 .04225 L
.77032 .04225 L
.77032 .08012 L
s
1 .894 .882 r
.77032 .08012 m
.77032 .0422 L
.77073 .0422 L
.77073 .08012 L
F
.804 .522 .247 r
.77032 .08012 m
.77032 .0422 L
.77073 .0422 L
.77073 .08012 L
s
1 .894 .882 r
.77073 .08012 m
.77073 .0421 L
.77097 .0421 L
.77097 .08012 L
F
.804 .522 .247 r
.77073 .08012 m
.77073 .0421 L
.77097 .0421 L
.77097 .08012 L
s
1 .894 .882 r
.77097 .08012 m
.77097 .042 L
.77121 .042 L
.77121 .08012 L
F
.804 .522 .247 r
.77097 .08012 m
.77097 .042 L
.77121 .042 L
.77121 .08012 L
s
1 .894 .882 r
.77121 .08012 m
.77121 .0419 L
.77153 .0419 L
.77153 .08012 L
F
.804 .522 .247 r
.77121 .08012 m
.77121 .0419 L
.77153 .0419 L
.77153 .08012 L
s
1 .894 .882 r
.77153 .08012 m
.77153 .04189 L
.77193 .04189 L
.77193 .08012 L
F
.804 .522 .247 r
.77153 .08012 m
.77153 .04189 L
.77193 .04189 L
.77193 .08012 L
s
1 .894 .882 r
.77193 .08012 m
.77193 .04173 L
.77223 .04173 L
.77223 .08012 L
F
.804 .522 .247 r
.77193 .08012 m
.77193 .04173 L
.77223 .04173 L
.77223 .08012 L
s
1 .894 .882 r
.77223 .08012 m
.77223 .04167 L
.77265 .04167 L
.77265 .08012 L
F
.804 .522 .247 r
.77223 .08012 m
.77223 .04167 L
.77265 .04167 L
.77265 .08012 L
s
1 .894 .882 r
.77265 .08012 m
.77265 .04156 L
.77301 .04156 L
.77301 .08012 L
F
.804 .522 .247 r
.77265 .08012 m
.77265 .04156 L
.77301 .04156 L
.77301 .08012 L
s
1 .894 .882 r
.77301 .08012 m
.77301 .0414 L
.77349 .0414 L
.77349 .08012 L
F
.804 .522 .247 r
.77301 .08012 m
.77301 .0414 L
.77349 .0414 L
.77349 .08012 L
s
1 .894 .882 r
.77349 .08012 m
.77349 .04137 L
.77369 .04137 L
.77369 .08012 L
F
.804 .522 .247 r
.77349 .08012 m
.77349 .04137 L
.77369 .04137 L
.77369 .08012 L
s
1 .894 .882 r
.77369 .08012 m
.77369 .04129 L
.77403 .04129 L
.77403 .08012 L
F
.804 .522 .247 r
.77369 .08012 m
.77369 .04129 L
.77403 .04129 L
.77403 .08012 L
s
1 .894 .882 r
.77403 .08012 m
.77403 .04119 L
.77429 .04119 L
.77429 .08012 L
F
.804 .522 .247 r
.77403 .08012 m
.77403 .04119 L
.77429 .04119 L
.77429 .08012 L
s
1 .894 .882 r
.77429 .08012 m
.77429 .04113 L
.77449 .04113 L
.77449 .08012 L
F
.804 .522 .247 r
.77429 .08012 m
.77429 .04113 L
.77449 .04113 L
.77449 .08012 L
s
1 .894 .882 r
.77449 .08012 m
.77449 .04108 L
.77494 .04108 L
.77494 .08012 L
F
.804 .522 .247 r
.77449 .08012 m
.77449 .04108 L
.77494 .04108 L
.77494 .08012 L
s
1 .894 .882 r
.77494 .08012 m
.77494 .04098 L
.77514 .04098 L
.77514 .08012 L
F
.804 .522 .247 r
.77494 .08012 m
.77494 .04098 L
.77514 .04098 L
.77514 .08012 L
s
1 .894 .882 r
.77514 .08012 m
.77514 .04089 L
.7754 .04089 L
.7754 .08012 L
F
.804 .522 .247 r
.77514 .08012 m
.77514 .04089 L
.7754 .04089 L
.7754 .08012 L
s
1 .894 .882 r
.7754 .08012 m
.7754 .04083 L
.77561 .04083 L
.77561 .08012 L
F
.804 .522 .247 r
.7754 .08012 m
.7754 .04083 L
.77561 .04083 L
.77561 .08012 L
s
1 .894 .882 r
.77561 .08012 m
.77561 .04079 L
.77601 .04079 L
.77601 .08012 L
F
.804 .522 .247 r
.77561 .08012 m
.77561 .04079 L
.77601 .04079 L
.77601 .08012 L
s
1 .894 .882 r
.77601 .08012 m
.77601 .04068 L
.77626 .04068 L
.77626 .08012 L
F
.804 .522 .247 r
.77601 .08012 m
.77601 .04068 L
.77626 .04068 L
.77626 .08012 L
s
1 .894 .882 r
.77626 .08012 m
.77626 .04064 L
.77642 .04064 L
.77642 .08012 L
F
.804 .522 .247 r
.77626 .08012 m
.77626 .04064 L
.77642 .04064 L
.77642 .08012 L
s
1 .894 .882 r
.77642 .08012 m
.77642 .04054 L
.77687 .04054 L
.77687 .08012 L
F
.804 .522 .247 r
.77642 .08012 m
.77642 .04054 L
.77687 .04054 L
.77687 .08012 L
s
1 .894 .882 r
.77687 .08012 m
.77687 .04046 L
.77704 .04046 L
.77704 .08012 L
F
.804 .522 .247 r
.77687 .08012 m
.77687 .04046 L
.77704 .04046 L
.77704 .08012 L
s
1 .894 .882 r
.77704 .08012 m
.77704 .04044 L
.77745 .04044 L
.77745 .08012 L
F
.804 .522 .247 r
.77704 .08012 m
.77704 .04044 L
.77745 .04044 L
.77745 .08012 L
s
1 .894 .882 r
.77745 .08012 m
.77745 .0403 L
.77766 .0403 L
.77766 .08012 L
F
.804 .522 .247 r
.77745 .08012 m
.77745 .0403 L
.77766 .0403 L
.77766 .08012 L
s
1 .894 .882 r
.77766 .08012 m
.77766 .04027 L
.77785 .04027 L
.77785 .08012 L
F
.804 .522 .247 r
.77766 .08012 m
.77766 .04027 L
.77785 .04027 L
.77785 .08012 L
s
1 .894 .882 r
.77785 .08012 m
.77785 .04015 L
.77827 .04015 L
.77827 .08012 L
F
.804 .522 .247 r
.77785 .08012 m
.77785 .04015 L
.77827 .04015 L
.77827 .08012 L
s
1 .894 .882 r
.77827 .08012 m
.77827 .0401 L
.77858 .0401 L
.77858 .08012 L
F
.804 .522 .247 r
.77827 .08012 m
.77827 .0401 L
.77858 .0401 L
.77858 .08012 L
s
1 .894 .882 r
.77858 .08012 m
.77858 .03998 L
.77898 .03998 L
.77898 .08012 L
F
.804 .522 .247 r
.77858 .08012 m
.77858 .03998 L
.77898 .03998 L
.77898 .08012 L
s
1 .894 .882 r
.77898 .08012 m
.77898 .03992 L
.77925 .03992 L
.77925 .08012 L
F
.804 .522 .247 r
.77898 .08012 m
.77898 .03992 L
.77925 .03992 L
.77925 .08012 L
s
1 .894 .882 r
.77925 .08012 m
.77925 .03988 L
.77952 .03988 L
.77952 .08012 L
F
.804 .522 .247 r
.77925 .08012 m
.77925 .03988 L
.77952 .03988 L
.77952 .08012 L
s
1 .894 .882 r
.77952 .08012 m
.77952 .03981 L
.77991 .03981 L
.77991 .08012 L
F
.804 .522 .247 r
.77952 .08012 m
.77952 .03981 L
.77991 .03981 L
.77991 .08012 L
s
1 .894 .882 r
.77991 .08012 m
.77991 .0397 L
.78009 .0397 L
.78009 .08012 L
F
.804 .522 .247 r
.77991 .08012 m
.77991 .0397 L
.78009 .0397 L
.78009 .08012 L
s
1 .894 .882 r
.78009 .08012 m
.78009 .03962 L
.78037 .03962 L
.78037 .08012 L
F
.804 .522 .247 r
.78009 .08012 m
.78009 .03962 L
.78037 .03962 L
.78037 .08012 L
s
1 .894 .882 r
.78037 .08012 m
.78037 .03955 L
.78059 .03955 L
.78059 .08012 L
F
.804 .522 .247 r
.78037 .08012 m
.78037 .03955 L
.78059 .03955 L
.78059 .08012 L
s
1 .894 .882 r
.78059 .08012 m
.78059 .03951 L
.7808 .03951 L
.7808 .08012 L
F
.804 .522 .247 r
.78059 .08012 m
.78059 .03951 L
.7808 .03951 L
.7808 .08012 L
s
1 .894 .882 r
.7808 .08012 m
.7808 .03943 L
.78121 .03943 L
.78121 .08012 L
F
.804 .522 .247 r
.7808 .08012 m
.7808 .03943 L
.78121 .03943 L
.78121 .08012 L
s
1 .894 .882 r
.78121 .08012 m
.78121 .03933 L
.78143 .03933 L
.78143 .08012 L
F
.804 .522 .247 r
.78121 .08012 m
.78121 .03933 L
.78143 .03933 L
.78143 .08012 L
s
1 .894 .882 r
.78143 .08012 m
.78143 .03929 L
.78169 .03929 L
.78169 .08012 L
F
.804 .522 .247 r
.78143 .08012 m
.78143 .03929 L
.78169 .03929 L
.78169 .08012 L
s
1 .894 .882 r
.78169 .08012 m
.78169 .03926 L
.78184 .03926 L
.78184 .08012 L
F
.804 .522 .247 r
.78169 .08012 m
.78169 .03926 L
.78184 .03926 L
.78184 .08012 L
s
1 .894 .882 r
.78184 .08012 m
.78184 .03916 L
.78215 .03916 L
.78215 .08012 L
F
.804 .522 .247 r
.78184 .08012 m
.78184 .03916 L
.78215 .03916 L
.78215 .08012 L
s
1 .894 .882 r
.78215 .08012 m
.78215 .03915 L
.78231 .03915 L
.78231 .08012 L
F
.804 .522 .247 r
.78215 .08012 m
.78215 .03915 L
.78231 .03915 L
.78231 .08012 L
s
1 .894 .882 r
.78231 .08012 m
.78231 .03908 L
.78266 .03908 L
.78266 .08012 L
F
.804 .522 .247 r
.78231 .08012 m
.78231 .03908 L
.78266 .03908 L
.78266 .08012 L
s
1 .894 .882 r
.78266 .08012 m
.78266 .03895 L
.78306 .03895 L
.78306 .08012 L
F
.804 .522 .247 r
.78266 .08012 m
.78266 .03895 L
.78306 .03895 L
.78306 .08012 L
s
1 .894 .882 r
.78306 .08012 m
.78306 .03889 L
.78335 .03889 L
.78335 .08012 L
F
.804 .522 .247 r
.78306 .08012 m
.78306 .03889 L
.78335 .03889 L
.78335 .08012 L
s
1 .894 .882 r
.78335 .08012 m
.78335 .03883 L
.78355 .03883 L
.78355 .08012 L
F
.804 .522 .247 r
.78335 .08012 m
.78335 .03883 L
.78355 .03883 L
.78355 .08012 L
s
1 .894 .882 r
.78355 .08012 m
.78355 .03876 L
.78388 .03876 L
.78388 .08012 L
F
.804 .522 .247 r
.78355 .08012 m
.78355 .03876 L
.78388 .03876 L
.78388 .08012 L
s
1 .894 .882 r
.78388 .08012 m
.78388 .03865 L
.78436 .03865 L
.78436 .08012 L
F
.804 .522 .247 r
.78388 .08012 m
.78388 .03865 L
.78436 .03865 L
.78436 .08012 L
s
1 .894 .882 r
.78436 .08012 m
.78436 .03856 L
.78459 .03856 L
.78459 .08012 L
F
.804 .522 .247 r
.78436 .08012 m
.78436 .03856 L
.78459 .03856 L
.78459 .08012 L
s
1 .894 .882 r
.78459 .08012 m
.78459 .0385 L
.78476 .0385 L
.78476 .08012 L
F
.804 .522 .247 r
.78459 .08012 m
.78459 .0385 L
.78476 .0385 L
.78476 .08012 L
s
1 .894 .882 r
.78476 .08012 m
.78476 .03844 L
.78515 .03844 L
.78515 .08012 L
F
.804 .522 .247 r
.78476 .08012 m
.78476 .03844 L
.78515 .03844 L
.78515 .08012 L
s
1 .894 .882 r
.78515 .08012 m
.78515 .03839 L
.78547 .03839 L
.78547 .08012 L
F
.804 .522 .247 r
.78515 .08012 m
.78515 .03839 L
.78547 .03839 L
.78547 .08012 L
s
1 .894 .882 r
.78547 .08012 m
.78547 .03825 L
.78579 .03825 L
.78579 .08012 L
F
.804 .522 .247 r
.78547 .08012 m
.78547 .03825 L
.78579 .03825 L
.78579 .08012 L
s
1 .894 .882 r
.78579 .08012 m
.78579 .03819 L
.78618 .03819 L
.78618 .08012 L
F
.804 .522 .247 r
.78579 .08012 m
.78579 .03819 L
.78618 .03819 L
.78618 .08012 L
s
1 .894 .882 r
.78618 .08012 m
.78618 .03811 L
.78646 .03811 L
.78646 .08012 L
F
.804 .522 .247 r
.78618 .08012 m
.78618 .03811 L
.78646 .03811 L
.78646 .08012 L
s
1 .894 .882 r
.78646 .08012 m
.78646 .03806 L
.78687 .03806 L
.78687 .08012 L
F
.804 .522 .247 r
.78646 .08012 m
.78646 .03806 L
.78687 .03806 L
.78687 .08012 L
s
1 .894 .882 r
.78687 .08012 m
.78687 .03794 L
.78716 .03794 L
.78716 .08012 L
F
.804 .522 .247 r
.78687 .08012 m
.78687 .03794 L
.78716 .03794 L
.78716 .08012 L
s
1 .894 .882 r
.78716 .08012 m
.78716 .03785 L
.78742 .03785 L
.78742 .08012 L
F
.804 .522 .247 r
.78716 .08012 m
.78716 .03785 L
.78742 .03785 L
.78742 .08012 L
s
1 .894 .882 r
.78742 .08012 m
.78742 .03781 L
.78763 .03781 L
.78763 .08012 L
F
.804 .522 .247 r
.78742 .08012 m
.78742 .03781 L
.78763 .03781 L
.78763 .08012 L
s
1 .894 .882 r
.78763 .08012 m
.78763 .03775 L
.78798 .03775 L
.78798 .08012 L
F
.804 .522 .247 r
.78763 .08012 m
.78763 .03775 L
.78798 .03775 L
.78798 .08012 L
s
1 .894 .882 r
.78798 .08012 m
.78798 .03762 L
.78835 .03762 L
.78835 .08012 L
F
.804 .522 .247 r
.78798 .08012 m
.78798 .03762 L
.78835 .03762 L
.78835 .08012 L
s
1 .894 .882 r
.78835 .08012 m
.78835 .03757 L
.78853 .03757 L
.78853 .08012 L
F
.804 .522 .247 r
.78835 .08012 m
.78835 .03757 L
.78853 .03757 L
.78853 .08012 L
s
1 .894 .882 r
.78853 .08012 m
.78853 .03747 L
.78897 .03747 L
.78897 .08012 L
F
.804 .522 .247 r
.78853 .08012 m
.78853 .03747 L
.78897 .03747 L
.78897 .08012 L
s
1 .894 .882 r
.78897 .08012 m
.78897 .03744 L
.78932 .03744 L
.78932 .08012 L
F
.804 .522 .247 r
.78897 .08012 m
.78897 .03744 L
.78932 .03744 L
.78932 .08012 L
s
1 .894 .882 r
.78932 .08012 m
.78932 .03737 L
.78953 .03737 L
.78953 .08012 L
F
.804 .522 .247 r
.78932 .08012 m
.78932 .03737 L
.78953 .03737 L
.78953 .08012 L
s
1 .894 .882 r
.78953 .08012 m
.78953 .03729 L
.7897 .03729 L
.7897 .08012 L
F
.804 .522 .247 r
.78953 .08012 m
.78953 .03729 L
.7897 .03729 L
.7897 .08012 L
s
1 .894 .882 r
.7897 .08012 m
.7897 .03725 L
.78995 .03725 L
.78995 .08012 L
F
.804 .522 .247 r
.7897 .08012 m
.7897 .03725 L
.78995 .03725 L
.78995 .08012 L
s
1 .894 .882 r
.78995 .08012 m
.78995 .03717 L
.79038 .03717 L
.79038 .08012 L
F
.804 .522 .247 r
.78995 .08012 m
.78995 .03717 L
.79038 .03717 L
.79038 .08012 L
s
1 .894 .882 r
.79038 .08012 m
.79038 .03705 L
.79079 .03705 L
.79079 .08012 L
F
.804 .522 .247 r
.79038 .08012 m
.79038 .03705 L
.79079 .03705 L
.79079 .08012 L
s
1 .894 .882 r
.79079 .08012 m
.79079 .03697 L
.79125 .03697 L
.79125 .08012 L
F
.804 .522 .247 r
.79079 .08012 m
.79079 .03697 L
.79125 .03697 L
.79125 .08012 L
s
1 .894 .882 r
.79125 .08012 m
.79125 .03689 L
.79166 .03689 L
.79166 .08012 L
F
.804 .522 .247 r
.79125 .08012 m
.79125 .03689 L
.79166 .03689 L
.79166 .08012 L
s
1 .894 .882 r
.79166 .08012 m
.79166 .03681 L
.7921 .03681 L
.7921 .08012 L
F
.804 .522 .247 r
.79166 .08012 m
.79166 .03681 L
.7921 .03681 L
.7921 .08012 L
s
1 .894 .882 r
.7921 .08012 m
.7921 .03669 L
.79244 .03669 L
.79244 .08012 L
F
.804 .522 .247 r
.7921 .08012 m
.7921 .03669 L
.79244 .03669 L
.79244 .08012 L
s
1 .894 .882 r
.79244 .08012 m
.79244 .03657 L
.79288 .03657 L
.79288 .08012 L
F
.804 .522 .247 r
.79244 .08012 m
.79244 .03657 L
.79288 .03657 L
.79288 .08012 L
s
1 .894 .882 r
.79288 .08012 m
.79288 .0365 L
.79304 .0365 L
.79304 .08012 L
F
.804 .522 .247 r
.79288 .08012 m
.79288 .0365 L
.79304 .0365 L
.79304 .08012 L
s
1 .894 .882 r
.79304 .08012 m
.79304 .03643 L
.79332 .03643 L
.79332 .08012 L
F
.804 .522 .247 r
.79304 .08012 m
.79304 .03643 L
.79332 .03643 L
.79332 .08012 L
s
1 .894 .882 r
.79332 .08012 m
.79332 .0364 L
.79347 .0364 L
.79347 .08012 L
F
.804 .522 .247 r
.79332 .08012 m
.79332 .0364 L
.79347 .0364 L
.79347 .08012 L
s
1 .894 .882 r
.79347 .08012 m
.79347 .03638 L
.79367 .03638 L
.79367 .08012 L
F
.804 .522 .247 r
.79347 .08012 m
.79347 .03638 L
.79367 .03638 L
.79367 .08012 L
s
1 .894 .882 r
.79367 .08012 m
.79367 .03632 L
.79405 .03632 L
.79405 .08012 L
F
.804 .522 .247 r
.79367 .08012 m
.79367 .03632 L
.79405 .03632 L
.79405 .08012 L
s
1 .894 .882 r
.79405 .08012 m
.79405 .03618 L
.79441 .03618 L
.79441 .08012 L
F
.804 .522 .247 r
.79405 .08012 m
.79405 .03618 L
.79441 .03618 L
.79441 .08012 L
s
1 .894 .882 r
.79441 .08012 m
.79441 .03609 L
.79477 .03609 L
.79477 .08012 L
F
.804 .522 .247 r
.79441 .08012 m
.79441 .03609 L
.79477 .03609 L
.79477 .08012 L
s
1 .894 .882 r
.79477 .08012 m
.79477 .03606 L
.7952 .03606 L
.7952 .08012 L
F
.804 .522 .247 r
.79477 .08012 m
.79477 .03606 L
.7952 .03606 L
.7952 .08012 L
s
1 .894 .882 r
.7952 .08012 m
.7952 .03592 L
.79551 .03592 L
.79551 .08012 L
F
.804 .522 .247 r
.7952 .08012 m
.7952 .03592 L
.79551 .03592 L
.79551 .08012 L
s
1 .894 .882 r
.79551 .08012 m
.79551 .03589 L
.79567 .03589 L
.79567 .08012 L
F
.804 .522 .247 r
.79551 .08012 m
.79551 .03589 L
.79567 .03589 L
.79567 .08012 L
s
1 .894 .882 r
.79567 .08012 m
.79567 .03576 L
.79615 .03576 L
.79615 .08012 L
F
.804 .522 .247 r
.79567 .08012 m
.79567 .03576 L
.79615 .03576 L
.79615 .08012 L
s
1 .894 .882 r
.79615 .08012 m
.79615 .03572 L
.79655 .03572 L
.79655 .08012 L
F
.804 .522 .247 r
.79615 .08012 m
.79615 .03572 L
.79655 .03572 L
.79655 .08012 L
s
1 .894 .882 r
.79655 .08012 m
.79655 .03559 L
.79691 .03559 L
.79691 .08012 L
F
.804 .522 .247 r
.79655 .08012 m
.79655 .03559 L
.79691 .03559 L
.79691 .08012 L
s
1 .894 .882 r
.79691 .08012 m
.79691 .03557 L
.79722 .03557 L
.79722 .08012 L
F
.804 .522 .247 r
.79691 .08012 m
.79691 .03557 L
.79722 .03557 L
.79722 .08012 L
s
1 .894 .882 r
.79722 .08012 m
.79722 .03542 L
.79763 .03542 L
.79763 .08012 L
F
.804 .522 .247 r
.79722 .08012 m
.79722 .03542 L
.79763 .03542 L
.79763 .08012 L
s
1 .894 .882 r
.79763 .08012 m
.79763 .03536 L
.79801 .03536 L
.79801 .08012 L
F
.804 .522 .247 r
.79763 .08012 m
.79763 .03536 L
.79801 .03536 L
.79801 .08012 L
s
1 .894 .882 r
.79801 .08012 m
.79801 .0353 L
.79827 .0353 L
.79827 .08012 L
F
.804 .522 .247 r
.79801 .08012 m
.79801 .0353 L
.79827 .0353 L
.79827 .08012 L
s
1 .894 .882 r
.79827 .08012 m
.79827 .03522 L
.79864 .03522 L
.79864 .08012 L
F
.804 .522 .247 r
.79827 .08012 m
.79827 .03522 L
.79864 .03522 L
.79864 .08012 L
s
1 .894 .882 r
.79864 .08012 m
.79864 .03517 L
.79878 .03517 L
.79878 .08012 L
F
.804 .522 .247 r
.79864 .08012 m
.79864 .03517 L
.79878 .03517 L
.79878 .08012 L
s
1 .894 .882 r
.79878 .08012 m
.79878 .03513 L
.7992 .03513 L
.7992 .08012 L
F
.804 .522 .247 r
.79878 .08012 m
.79878 .03513 L
.7992 .03513 L
.7992 .08012 L
s
1 .894 .882 r
.7992 .08012 m
.7992 .03504 L
.79954 .03504 L
.79954 .08012 L
F
.804 .522 .247 r
.7992 .08012 m
.7992 .03504 L
.79954 .03504 L
.79954 .08012 L
s
1 .894 .882 r
.79954 .08012 m
.79954 .03492 L
.79996 .03492 L
.79996 .08012 L
F
.804 .522 .247 r
.79954 .08012 m
.79954 .03492 L
.79996 .03492 L
.79996 .08012 L
s
1 .894 .882 r
.79996 .08012 m
.79996 .0348 L
.80026 .0348 L
.80026 .08012 L
F
.804 .522 .247 r
.79996 .08012 m
.79996 .0348 L
.80026 .0348 L
.80026 .08012 L
s
1 .894 .882 r
.80026 .08012 m
.80026 .03474 L
.80073 .03474 L
.80073 .08012 L
F
.804 .522 .247 r
.80026 .08012 m
.80026 .03474 L
.80073 .03474 L
.80073 .08012 L
s
1 .894 .882 r
.80073 .08012 m
.80073 .03466 L
.80106 .03466 L
.80106 .08012 L
F
.804 .522 .247 r
.80073 .08012 m
.80073 .03466 L
.80106 .03466 L
.80106 .08012 L
s
1 .894 .882 r
.80106 .08012 m
.80106 .03458 L
.80135 .03458 L
.80135 .08012 L
F
.804 .522 .247 r
.80106 .08012 m
.80106 .03458 L
.80135 .03458 L
.80135 .08012 L
s
1 .894 .882 r
.80135 .08012 m
.80135 .03451 L
.80164 .03451 L
.80164 .08012 L
F
.804 .522 .247 r
.80135 .08012 m
.80135 .03451 L
.80164 .03451 L
.80164 .08012 L
s
1 .894 .882 r
.80164 .08012 m
.80164 .03443 L
.80206 .03443 L
.80206 .08012 L
F
.804 .522 .247 r
.80164 .08012 m
.80164 .03443 L
.80206 .03443 L
.80206 .08012 L
s
1 .894 .882 r
.80206 .08012 m
.80206 .03437 L
.80251 .03437 L
.80251 .08012 L
F
.804 .522 .247 r
.80206 .08012 m
.80206 .03437 L
.80251 .03437 L
.80251 .08012 L
s
1 .894 .882 r
.80251 .08012 m
.80251 .03421 L
.80293 .03421 L
.80293 .08012 L
F
.804 .522 .247 r
.80251 .08012 m
.80251 .03421 L
.80293 .03421 L
.80293 .08012 L
s
1 .894 .882 r
.80293 .08012 m
.80293 .03412 L
.80335 .03412 L
.80335 .08012 L
F
.804 .522 .247 r
.80293 .08012 m
.80293 .03412 L
.80335 .03412 L
.80335 .08012 L
s
1 .894 .882 r
.80335 .08012 m
.80335 .03406 L
.80383 .03406 L
.80383 .08012 L
F
.804 .522 .247 r
.80335 .08012 m
.80335 .03406 L
.80383 .03406 L
.80383 .08012 L
s
1 .894 .882 r
.80383 .08012 m
.80383 .03396 L
.80412 .03396 L
.80412 .08012 L
F
.804 .522 .247 r
.80383 .08012 m
.80383 .03396 L
.80412 .03396 L
.80412 .08012 L
s
1 .894 .882 r
.80412 .08012 m
.80412 .03388 L
.80452 .03388 L
.80452 .08012 L
F
.804 .522 .247 r
.80412 .08012 m
.80412 .03388 L
.80452 .03388 L
.80452 .08012 L
s
1 .894 .882 r
.80452 .08012 m
.80452 .03375 L
.80496 .03375 L
.80496 .08012 L
F
.804 .522 .247 r
.80452 .08012 m
.80452 .03375 L
.80496 .03375 L
.80496 .08012 L
s
1 .894 .882 r
.80496 .08012 m
.80496 .03374 L
.80519 .03374 L
.80519 .08012 L
F
.804 .522 .247 r
.80496 .08012 m
.80496 .03374 L
.80519 .03374 L
.80519 .08012 L
s
1 .894 .882 r
.80519 .08012 m
.80519 .03362 L
.80561 .03362 L
.80561 .08012 L
F
.804 .522 .247 r
.80519 .08012 m
.80519 .03362 L
.80561 .03362 L
.80561 .08012 L
s
1 .894 .882 r
.80561 .08012 m
.80561 .03357 L
.80585 .03357 L
.80585 .08012 L
F
.804 .522 .247 r
.80561 .08012 m
.80561 .03357 L
.80585 .03357 L
.80585 .08012 L
s
1 .894 .882 r
.80585 .08012 m
.80585 .03354 L
.80603 .03354 L
.80603 .08012 L
F
.804 .522 .247 r
.80585 .08012 m
.80585 .03354 L
.80603 .03354 L
.80603 .08012 L
s
1 .894 .882 r
.80603 .08012 m
.80603 .03346 L
.80636 .03346 L
.80636 .08012 L
F
.804 .522 .247 r
.80603 .08012 m
.80603 .03346 L
.80636 .03346 L
.80636 .08012 L
s
1 .894 .882 r
.80636 .08012 m
.80636 .03339 L
.80667 .03339 L
.80667 .08012 L
F
.804 .522 .247 r
.80636 .08012 m
.80636 .03339 L
.80667 .03339 L
.80667 .08012 L
s
1 .894 .882 r
.80667 .08012 m
.80667 .03336 L
.80704 .03336 L
.80704 .08012 L
F
.804 .522 .247 r
.80667 .08012 m
.80667 .03336 L
.80704 .03336 L
.80704 .08012 L
s
1 .894 .882 r
.80704 .08012 m
.80704 .03325 L
.80722 .03325 L
.80722 .08012 L
F
.804 .522 .247 r
.80704 .08012 m
.80704 .03325 L
.80722 .03325 L
.80722 .08012 L
s
1 .894 .882 r
.80722 .08012 m
.80722 .0332 L
.80763 .0332 L
.80763 .08012 L
F
.804 .522 .247 r
.80722 .08012 m
.80722 .0332 L
.80763 .0332 L
.80763 .08012 L
s
1 .894 .882 r
.80763 .08012 m
.80763 .0331 L
.80808 .0331 L
.80808 .08012 L
F
.804 .522 .247 r
.80763 .08012 m
.80763 .0331 L
.80808 .0331 L
.80808 .08012 L
s
1 .894 .882 r
.80808 .08012 m
.80808 .033 L
.80854 .033 L
.80854 .08012 L
F
.804 .522 .247 r
.80808 .08012 m
.80808 .033 L
.80854 .033 L
.80854 .08012 L
s
1 .894 .882 r
.80854 .08012 m
.80854 .03288 L
.8089 .03288 L
.8089 .08012 L
F
.804 .522 .247 r
.80854 .08012 m
.80854 .03288 L
.8089 .03288 L
.8089 .08012 L
s
1 .894 .882 r
.8089 .08012 m
.8089 .03279 L
.80933 .03279 L
.80933 .08012 L
F
.804 .522 .247 r
.8089 .08012 m
.8089 .03279 L
.80933 .03279 L
.80933 .08012 L
s
1 .894 .882 r
.80933 .08012 m
.80933 .03277 L
.8096 .03277 L
.8096 .08012 L
F
.804 .522 .247 r
.80933 .08012 m
.80933 .03277 L
.8096 .03277 L
.8096 .08012 L
s
1 .894 .882 r
.8096 .08012 m
.8096 .03266 L
.80992 .03266 L
.80992 .08012 L
F
.804 .522 .247 r
.8096 .08012 m
.8096 .03266 L
.80992 .03266 L
.80992 .08012 L
s
1 .894 .882 r
.80992 .08012 m
.80992 .03264 L
.81014 .03264 L
.81014 .08012 L
F
.804 .522 .247 r
.80992 .08012 m
.80992 .03264 L
.81014 .03264 L
.81014 .08012 L
s
1 .894 .882 r
.81014 .08012 m
.81014 .0326 L
.81029 .0326 L
.81029 .08012 L
F
.804 .522 .247 r
.81014 .08012 m
.81014 .0326 L
.81029 .0326 L
.81029 .08012 L
s
1 .894 .882 r
.81029 .08012 m
.81029 .03251 L
.81061 .03251 L
.81061 .08012 L
F
.804 .522 .247 r
.81029 .08012 m
.81029 .03251 L
.81061 .03251 L
.81061 .08012 L
s
1 .894 .882 r
.81061 .08012 m
.81061 .0325 L
.81101 .0325 L
.81101 .08012 L
F
.804 .522 .247 r
.81061 .08012 m
.81061 .0325 L
.81101 .0325 L
.81101 .08012 L
s
1 .894 .882 r
.81101 .08012 m
.81101 .03239 L
.81129 .03239 L
.81129 .08012 L
F
.804 .522 .247 r
.81101 .08012 m
.81101 .03239 L
.81129 .03239 L
.81129 .08012 L
s
1 .894 .882 r
.81129 .08012 m
.81129 .03233 L
.81145 .03233 L
.81145 .08012 L
F
.804 .522 .247 r
.81129 .08012 m
.81129 .03233 L
.81145 .03233 L
.81145 .08012 L
s
1 .894 .882 r
.81145 .08012 m
.81145 .03231 L
.81164 .03231 L
.81164 .08012 L
F
.804 .522 .247 r
.81145 .08012 m
.81145 .03231 L
.81164 .03231 L
.81164 .08012 L
s
1 .894 .882 r
.81164 .08012 m
.81164 .03223 L
.81212 .03223 L
.81212 .08012 L
F
.804 .522 .247 r
.81164 .08012 m
.81164 .03223 L
.81212 .03223 L
.81212 .08012 L
s
1 .894 .882 r
.81212 .08012 m
.81212 .03214 L
.81245 .03214 L
.81245 .08012 L
F
.804 .522 .247 r
.81212 .08012 m
.81212 .03214 L
.81245 .03214 L
.81245 .08012 L
s
1 .894 .882 r
.81245 .08012 m
.81245 .03203 L
.81289 .03203 L
.81289 .08012 L
F
.804 .522 .247 r
.81245 .08012 m
.81245 .03203 L
.81289 .03203 L
.81289 .08012 L
s
1 .894 .882 r
.81289 .08012 m
.81289 .03199 L
.81315 .03199 L
.81315 .08012 L
F
.804 .522 .247 r
.81289 .08012 m
.81289 .03199 L
.81315 .03199 L
.81315 .08012 L
s
1 .894 .882 r
.81315 .08012 m
.81315 .03196 L
.81353 .03196 L
.81353 .08012 L
F
.804 .522 .247 r
.81315 .08012 m
.81315 .03196 L
.81353 .03196 L
.81353 .08012 L
s
1 .894 .882 r
.81353 .08012 m
.81353 .03185 L
.81383 .03185 L
.81383 .08012 L
F
.804 .522 .247 r
.81353 .08012 m
.81353 .03185 L
.81383 .03185 L
.81383 .08012 L
s
1 .894 .882 r
.81383 .08012 m
.81383 .0318 L
.81408 .0318 L
.81408 .08012 L
F
.804 .522 .247 r
.81383 .08012 m
.81383 .0318 L
.81408 .0318 L
.81408 .08012 L
s
1 .894 .882 r
.81408 .08012 m
.81408 .03168 L
.81453 .03168 L
.81453 .08012 L
F
.804 .522 .247 r
.81408 .08012 m
.81408 .03168 L
.81453 .03168 L
.81453 .08012 L
s
1 .894 .882 r
.81453 .08012 m
.81453 .03164 L
.81468 .03164 L
.81468 .08012 L
F
.804 .522 .247 r
.81453 .08012 m
.81453 .03164 L
.81468 .03164 L
.81468 .08012 L
s
1 .894 .882 r
.81468 .08012 m
.81468 .0316 L
.81496 .0316 L
.81496 .08012 L
F
.804 .522 .247 r
.81468 .08012 m
.81468 .0316 L
.81496 .0316 L
.81496 .08012 L
s
1 .894 .882 r
.81496 .08012 m
.81496 .03152 L
.81529 .03152 L
.81529 .08012 L
F
.804 .522 .247 r
.81496 .08012 m
.81496 .03152 L
.81529 .03152 L
.81529 .08012 L
s
1 .894 .882 r
.81529 .08012 m
.81529 .03148 L
.81578 .03148 L
.81578 .08012 L
F
.804 .522 .247 r
.81529 .08012 m
.81529 .03148 L
.81578 .03148 L
.81578 .08012 L
s
1 .894 .882 r
.81578 .08012 m
.81578 .0314 L
.81596 .0314 L
.81596 .08012 L
F
.804 .522 .247 r
.81578 .08012 m
.81578 .0314 L
.81596 .0314 L
.81596 .08012 L
s
1 .894 .882 r
.81596 .08012 m
.81596 .03131 L
.81637 .03131 L
.81637 .08012 L
F
.804 .522 .247 r
.81596 .08012 m
.81596 .03131 L
.81637 .03131 L
.81637 .08012 L
s
1 .894 .882 r
.81637 .08012 m
.81637 .03121 L
.81677 .03121 L
.81677 .08012 L
F
.804 .522 .247 r
.81637 .08012 m
.81637 .03121 L
.81677 .03121 L
.81677 .08012 L
s
1 .894 .882 r
.81677 .08012 m
.81677 .0312 L
.81713 .0312 L
.81713 .08012 L
F
.804 .522 .247 r
.81677 .08012 m
.81677 .0312 L
.81713 .0312 L
.81713 .08012 L
s
1 .894 .882 r
.81713 .08012 m
.81713 .0311 L
.81749 .0311 L
.81749 .08012 L
F
.804 .522 .247 r
.81713 .08012 m
.81713 .0311 L
.81749 .0311 L
.81749 .08012 L
s
1 .894 .882 r
.81749 .08012 m
.81749 .03103 L
.81783 .03103 L
.81783 .08012 L
F
.804 .522 .247 r
.81749 .08012 m
.81749 .03103 L
.81783 .03103 L
.81783 .08012 L
s
1 .894 .882 r
.81783 .08012 m
.81783 .03094 L
.81822 .03094 L
.81822 .08012 L
F
.804 .522 .247 r
.81783 .08012 m
.81783 .03094 L
.81822 .03094 L
.81822 .08012 L
s
1 .894 .882 r
.81822 .08012 m
.81822 .0309 L
.81841 .0309 L
.81841 .08012 L
F
.804 .522 .247 r
.81822 .08012 m
.81822 .0309 L
.81841 .0309 L
.81841 .08012 L
s
1 .894 .882 r
.81841 .08012 m
.81841 .03084 L
.81886 .03084 L
.81886 .08012 L
F
.804 .522 .247 r
.81841 .08012 m
.81841 .03084 L
.81886 .03084 L
.81886 .08012 L
s
1 .894 .882 r
.81886 .08012 m
.81886 .03074 L
.81907 .03074 L
.81907 .08012 L
F
.804 .522 .247 r
.81886 .08012 m
.81886 .03074 L
.81907 .03074 L
.81907 .08012 L
s
1 .894 .882 r
.81907 .08012 m
.81907 .03069 L
.81945 .03069 L
.81945 .08012 L
F
.804 .522 .247 r
.81907 .08012 m
.81907 .03069 L
.81945 .03069 L
.81945 .08012 L
s
1 .894 .882 r
.81945 .08012 m
.81945 .03057 L
.81994 .03057 L
.81994 .08012 L
F
.804 .522 .247 r
.81945 .08012 m
.81945 .03057 L
.81994 .03057 L
.81994 .08012 L
s
1 .894 .882 r
.81994 .08012 m
.81994 .03048 L
.8204 .03048 L
.8204 .08012 L
F
.804 .522 .247 r
.81994 .08012 m
.81994 .03048 L
.8204 .03048 L
.8204 .08012 L
s
1 .894 .882 r
.8204 .08012 m
.8204 .03044 L
.82077 .03044 L
.82077 .08012 L
F
.804 .522 .247 r
.8204 .08012 m
.8204 .03044 L
.82077 .03044 L
.82077 .08012 L
s
1 .894 .882 r
.82077 .08012 m
.82077 .03033 L
.82121 .03033 L
.82121 .08012 L
F
.804 .522 .247 r
.82077 .08012 m
.82077 .03033 L
.82121 .03033 L
.82121 .08012 L
s
1 .894 .882 r
.82121 .08012 m
.82121 .03027 L
.82159 .03027 L
.82159 .08012 L
F
.804 .522 .247 r
.82121 .08012 m
.82121 .03027 L
.82159 .03027 L
.82159 .08012 L
s
1 .894 .882 r
.82159 .08012 m
.82159 .03019 L
.82182 .03019 L
.82182 .08012 L
F
.804 .522 .247 r
.82159 .08012 m
.82159 .03019 L
.82182 .03019 L
.82182 .08012 L
s
1 .894 .882 r
.82182 .08012 m
.82182 .03015 L
.82203 .03015 L
.82203 .08012 L
F
.804 .522 .247 r
.82182 .08012 m
.82182 .03015 L
.82203 .03015 L
.82203 .08012 L
s
1 .894 .882 r
.82203 .08012 m
.82203 .03011 L
.82237 .03011 L
.82237 .08012 L
F
.804 .522 .247 r
.82203 .08012 m
.82203 .03011 L
.82237 .03011 L
.82237 .08012 L
s
1 .894 .882 r
.82237 .08012 m
.82237 .03003 L
.82279 .03003 L
.82279 .08012 L
F
.804 .522 .247 r
.82237 .08012 m
.82237 .03003 L
.82279 .03003 L
.82279 .08012 L
s
1 .894 .882 r
.82279 .08012 m
.82279 .02995 L
.82301 .02995 L
.82301 .08012 L
F
.804 .522 .247 r
.82279 .08012 m
.82279 .02995 L
.82301 .02995 L
.82301 .08012 L
s
1 .894 .882 r
.82301 .08012 m
.82301 .02994 L
.82344 .02994 L
.82344 .08012 L
F
.804 .522 .247 r
.82301 .08012 m
.82301 .02994 L
.82344 .02994 L
.82344 .08012 L
s
1 .894 .882 r
.82344 .08012 m
.82344 .02984 L
.8236 .02984 L
.8236 .08012 L
F
.804 .522 .247 r
.82344 .08012 m
.82344 .02984 L
.8236 .02984 L
.8236 .08012 L
s
1 .894 .882 r
.8236 .08012 m
.8236 .02981 L
.82402 .02981 L
.82402 .08012 L
F
.804 .522 .247 r
.8236 .08012 m
.8236 .02981 L
.82402 .02981 L
.82402 .08012 L
s
1 .894 .882 r
.82402 .08012 m
.82402 .02973 L
.82421 .02973 L
.82421 .08012 L
F
.804 .522 .247 r
.82402 .08012 m
.82402 .02973 L
.82421 .02973 L
.82421 .08012 L
s
1 .894 .882 r
.82421 .08012 m
.82421 .0297 L
.82438 .0297 L
.82438 .08012 L
F
.804 .522 .247 r
.82421 .08012 m
.82421 .0297 L
.82438 .0297 L
.82438 .08012 L
s
1 .894 .882 r
.82438 .08012 m
.82438 .02965 L
.82462 .02965 L
.82462 .08012 L
F
.804 .522 .247 r
.82438 .08012 m
.82438 .02965 L
.82462 .02965 L
.82462 .08012 L
s
1 .894 .882 r
.82462 .08012 m
.82462 .02962 L
.82483 .02962 L
.82483 .08012 L
F
.804 .522 .247 r
.82462 .08012 m
.82462 .02962 L
.82483 .02962 L
.82483 .08012 L
s
1 .894 .882 r
.82483 .08012 m
.82483 .02952 L
.82516 .02952 L
.82516 .08012 L
F
.804 .522 .247 r
.82483 .08012 m
.82483 .02952 L
.82516 .02952 L
.82516 .08012 L
s
1 .894 .882 r
.82516 .08012 m
.82516 .02947 L
.82548 .02947 L
.82548 .08012 L
F
.804 .522 .247 r
.82516 .08012 m
.82516 .02947 L
.82548 .02947 L
.82548 .08012 L
s
1 .894 .882 r
.82548 .08012 m
.82548 .0294 L
.82582 .0294 L
.82582 .08012 L
F
.804 .522 .247 r
.82548 .08012 m
.82548 .0294 L
.82582 .0294 L
.82582 .08012 L
s
1 .894 .882 r
.82582 .08012 m
.82582 .02936 L
.826 .02936 L
.826 .08012 L
F
.804 .522 .247 r
.82582 .08012 m
.82582 .02936 L
.826 .02936 L
.826 .08012 L
s
1 .894 .882 r
.826 .08012 m
.826 .02931 L
.82637 .02931 L
.82637 .08012 L
F
.804 .522 .247 r
.826 .08012 m
.826 .02931 L
.82637 .02931 L
.82637 .08012 L
s
1 .894 .882 r
.82637 .08012 m
.82637 .02924 L
.82663 .02924 L
.82663 .08012 L
F
.804 .522 .247 r
.82637 .08012 m
.82637 .02924 L
.82663 .02924 L
.82663 .08012 L
s
1 .894 .882 r
.82663 .08012 m
.82663 .02921 L
.82707 .02921 L
.82707 .08012 L
F
.804 .522 .247 r
.82663 .08012 m
.82663 .02921 L
.82707 .02921 L
.82707 .08012 L
s
1 .894 .882 r
.82707 .08012 m
.82707 .02911 L
.82726 .02911 L
.82726 .08012 L
F
.804 .522 .247 r
.82707 .08012 m
.82707 .02911 L
.82726 .02911 L
.82726 .08012 L
s
1 .894 .882 r
.82726 .08012 m
.82726 .02905 L
.82765 .02905 L
.82765 .08012 L
F
.804 .522 .247 r
.82726 .08012 m
.82726 .02905 L
.82765 .02905 L
.82765 .08012 L
s
1 .894 .882 r
.82765 .08012 m
.82765 .029 L
.82804 .029 L
.82804 .08012 L
F
.804 .522 .247 r
.82765 .08012 m
.82765 .029 L
.82804 .029 L
.82804 .08012 L
s
1 .894 .882 r
.82804 .08012 m
.82804 .02894 L
.82819 .02894 L
.82819 .08012 L
F
.804 .522 .247 r
.82804 .08012 m
.82804 .02894 L
.82819 .02894 L
.82819 .08012 L
s
1 .894 .882 r
.82819 .08012 m
.82819 .0289 L
.82849 .0289 L
.82849 .08012 L
F
.804 .522 .247 r
.82819 .08012 m
.82819 .0289 L
.82849 .0289 L
.82849 .08012 L
s
1 .894 .882 r
.82849 .08012 m
.82849 .02881 L
.82881 .02881 L
.82881 .08012 L
F
.804 .522 .247 r
.82849 .08012 m
.82849 .02881 L
.82881 .02881 L
.82881 .08012 L
s
1 .894 .882 r
.82881 .08012 m
.82881 .02876 L
.82912 .02876 L
.82912 .08012 L
F
.804 .522 .247 r
.82881 .08012 m
.82881 .02876 L
.82912 .02876 L
.82912 .08012 L
s
1 .894 .882 r
.82912 .08012 m
.82912 .02874 L
.82943 .02874 L
.82943 .08012 L
F
.804 .522 .247 r
.82912 .08012 m
.82912 .02874 L
.82943 .02874 L
.82943 .08012 L
s
1 .894 .882 r
.82943 .08012 m
.82943 .02869 L
.82981 .02869 L
.82981 .08012 L
F
.804 .522 .247 r
.82943 .08012 m
.82943 .02869 L
.82981 .02869 L
.82981 .08012 L
s
1 .894 .882 r
.82981 .08012 m
.82981 .02861 L
.83004 .02861 L
.83004 .08012 L
F
.804 .522 .247 r
.82981 .08012 m
.82981 .02861 L
.83004 .02861 L
.83004 .08012 L
s
1 .894 .882 r
.83004 .08012 m
.83004 .02852 L
.83042 .02852 L
.83042 .08012 L
F
.804 .522 .247 r
.83004 .08012 m
.83004 .02852 L
.83042 .02852 L
.83042 .08012 L
s
1 .894 .882 r
.83042 .08012 m
.83042 .02846 L
.83072 .02846 L
.83072 .08012 L
F
.804 .522 .247 r
.83042 .08012 m
.83042 .02846 L
.83072 .02846 L
.83072 .08012 L
s
1 .894 .882 r
.83072 .08012 m
.83072 .02838 L
.83117 .02838 L
.83117 .08012 L
F
.804 .522 .247 r
.83072 .08012 m
.83072 .02838 L
.83117 .02838 L
.83117 .08012 L
s
1 .894 .882 r
.83117 .08012 m
.83117 .02833 L
.83136 .02833 L
.83136 .08012 L
F
.804 .522 .247 r
.83117 .08012 m
.83117 .02833 L
.83136 .02833 L
.83136 .08012 L
s
1 .894 .882 r
.83136 .08012 m
.83136 .02829 L
.83172 .02829 L
.83172 .08012 L
F
.804 .522 .247 r
.83136 .08012 m
.83136 .02829 L
.83172 .02829 L
.83172 .08012 L
s
1 .894 .882 r
.83172 .08012 m
.83172 .02825 L
.83193 .02825 L
.83193 .08012 L
F
.804 .522 .247 r
.83172 .08012 m
.83172 .02825 L
.83193 .02825 L
.83193 .08012 L
s
1 .894 .882 r
.83193 .08012 m
.83193 .02816 L
.83231 .02816 L
.83231 .08012 L
F
.804 .522 .247 r
.83193 .08012 m
.83193 .02816 L
.83231 .02816 L
.83231 .08012 L
s
1 .894 .882 r
.83231 .08012 m
.83231 .02809 L
.83266 .02809 L
.83266 .08012 L
F
.804 .522 .247 r
.83231 .08012 m
.83231 .02809 L
.83266 .02809 L
.83266 .08012 L
s
1 .894 .882 r
.83266 .08012 m
.83266 .02806 L
.83285 .02806 L
.83285 .08012 L
F
.804 .522 .247 r
.83266 .08012 m
.83266 .02806 L
.83285 .02806 L
.83285 .08012 L
s
1 .894 .882 r
.83285 .08012 m
.83285 .02802 L
.83321 .02802 L
.83321 .08012 L
F
.804 .522 .247 r
.83285 .08012 m
.83285 .02802 L
.83321 .02802 L
.83321 .08012 L
s
1 .894 .882 r
.83321 .08012 m
.83321 .02792 L
.83356 .02792 L
.83356 .08012 L
F
.804 .522 .247 r
.83321 .08012 m
.83321 .02792 L
.83356 .02792 L
.83356 .08012 L
s
1 .894 .882 r
.83356 .08012 m
.83356 .02789 L
.83404 .02789 L
.83404 .08012 L
F
.804 .522 .247 r
.83356 .08012 m
.83356 .02789 L
.83404 .02789 L
.83404 .08012 L
s
1 .894 .882 r
.83404 .08012 m
.83404 .02776 L
.83446 .02776 L
.83446 .08012 L
F
.804 .522 .247 r
.83404 .08012 m
.83404 .02776 L
.83446 .02776 L
.83446 .08012 L
s
1 .894 .882 r
.83446 .08012 m
.83446 .02774 L
.83487 .02774 L
.83487 .08012 L
F
.804 .522 .247 r
.83446 .08012 m
.83446 .02774 L
.83487 .02774 L
.83487 .08012 L
s
1 .894 .882 r
.83487 .08012 m
.83487 .02767 L
.83518 .02767 L
.83518 .08012 L
F
.804 .522 .247 r
.83487 .08012 m
.83487 .02767 L
.83518 .02767 L
.83518 .08012 L
s
1 .894 .882 r
.83518 .08012 m
.83518 .0276 L
.83541 .0276 L
.83541 .08012 L
F
.804 .522 .247 r
.83518 .08012 m
.83518 .0276 L
.83541 .0276 L
.83541 .08012 L
s
1 .894 .882 r
.83541 .08012 m
.83541 .02756 L
.83559 .02756 L
.83559 .08012 L
F
.804 .522 .247 r
.83541 .08012 m
.83541 .02756 L
.83559 .02756 L
.83559 .08012 L
s
1 .894 .882 r
.83559 .08012 m
.83559 .0275 L
.83599 .0275 L
.83599 .08012 L
F
.804 .522 .247 r
.83559 .08012 m
.83559 .0275 L
.83599 .0275 L
.83599 .08012 L
s
1 .894 .882 r
.83599 .08012 m
.83599 .02745 L
.83616 .02745 L
.83616 .08012 L
F
.804 .522 .247 r
.83599 .08012 m
.83599 .02745 L
.83616 .02745 L
.83616 .08012 L
s
1 .894 .882 r
.83616 .08012 m
.83616 .0274 L
.83657 .0274 L
.83657 .08012 L
F
.804 .522 .247 r
.83616 .08012 m
.83616 .0274 L
.83657 .0274 L
.83657 .08012 L
s
1 .894 .882 r
.83657 .08012 m
.83657 .02732 L
.83692 .02732 L
.83692 .08012 L
F
.804 .522 .247 r
.83657 .08012 m
.83657 .02732 L
.83692 .02732 L
.83692 .08012 L
s
1 .894 .882 r
.83692 .08012 m
.83692 .02729 L
.83716 .02729 L
.83716 .08012 L
F
.804 .522 .247 r
.83692 .08012 m
.83692 .02729 L
.83716 .02729 L
.83716 .08012 L
s
1 .894 .882 r
.83716 .08012 m
.83716 .02723 L
.83744 .02723 L
.83744 .08012 L
F
.804 .522 .247 r
.83716 .08012 m
.83716 .02723 L
.83744 .02723 L
.83744 .08012 L
s
1 .894 .882 r
.83744 .08012 m
.83744 .02719 L
.83777 .02719 L
.83777 .08012 L
F
.804 .522 .247 r
.83744 .08012 m
.83744 .02719 L
.83777 .02719 L
.83777 .08012 L
s
1 .894 .882 r
.83777 .08012 m
.83777 .02707 L
.83823 .02707 L
.83823 .08012 L
F
.804 .522 .247 r
.83777 .08012 m
.83777 .02707 L
.83823 .02707 L
.83823 .08012 L
s
1 .894 .882 r
.83823 .08012 m
.83823 .02703 L
.83866 .02703 L
.83866 .08012 L
F
.804 .522 .247 r
.83823 .08012 m
.83823 .02703 L
.83866 .02703 L
.83866 .08012 L
s
1 .894 .882 r
.83866 .08012 m
.83866 .02695 L
.83899 .02695 L
.83899 .08012 L
F
.804 .522 .247 r
.83866 .08012 m
.83866 .02695 L
.83899 .02695 L
.83899 .08012 L
s
1 .894 .882 r
.83899 .08012 m
.83899 .0269 L
.83927 .0269 L
.83927 .08012 L
F
.804 .522 .247 r
.83899 .08012 m
.83899 .0269 L
.83927 .0269 L
.83927 .08012 L
s
1 .894 .882 r
.83927 .08012 m
.83927 .02686 L
.83952 .02686 L
.83952 .08012 L
F
.804 .522 .247 r
.83927 .08012 m
.83927 .02686 L
.83952 .02686 L
.83952 .08012 L
s
1 .894 .882 r
.83952 .08012 m
.83952 .02682 L
.8399 .02682 L
.8399 .08012 L
F
.804 .522 .247 r
.83952 .08012 m
.83952 .02682 L
.8399 .02682 L
.8399 .08012 L
s
1 .894 .882 r
.8399 .08012 m
.8399 .0267 L
.84034 .0267 L
.84034 .08012 L
F
.804 .522 .247 r
.8399 .08012 m
.8399 .0267 L
.84034 .0267 L
.84034 .08012 L
s
1 .894 .882 r
.84034 .08012 m
.84034 .02664 L
.84075 .02664 L
.84075 .08012 L
F
.804 .522 .247 r
.84034 .08012 m
.84034 .02664 L
.84075 .02664 L
.84075 .08012 L
s
1 .894 .882 r
.84075 .08012 m
.84075 .02659 L
.84097 .02659 L
.84097 .08012 L
F
.804 .522 .247 r
.84075 .08012 m
.84075 .02659 L
.84097 .02659 L
.84097 .08012 L
s
1 .894 .882 r
.84097 .08012 m
.84097 .02656 L
.84113 .02656 L
.84113 .08012 L
F
.804 .522 .247 r
.84097 .08012 m
.84097 .02656 L
.84113 .02656 L
.84113 .08012 L
s
1 .894 .882 r
.84113 .08012 m
.84113 .02651 L
.84137 .02651 L
.84137 .08012 L
F
.804 .522 .247 r
.84113 .08012 m
.84113 .02651 L
.84137 .02651 L
.84137 .08012 L
s
1 .894 .882 r
.84137 .08012 m
.84137 .02648 L
.84179 .02648 L
.84179 .08012 L
F
.804 .522 .247 r
.84137 .08012 m
.84137 .02648 L
.84179 .02648 L
.84179 .08012 L
s
1 .894 .882 r
.84179 .08012 m
.84179 .0264 L
.84208 .0264 L
.84208 .08012 L
F
.804 .522 .247 r
.84179 .08012 m
.84179 .0264 L
.84208 .0264 L
.84208 .08012 L
s
1 .894 .882 r
.84208 .08012 m
.84208 .02636 L
.84233 .02636 L
.84233 .08012 L
F
.804 .522 .247 r
.84208 .08012 m
.84208 .02636 L
.84233 .02636 L
.84233 .08012 L
s
1 .894 .882 r
.84233 .08012 m
.84233 .02628 L
.84274 .02628 L
.84274 .08012 L
F
.804 .522 .247 r
.84233 .08012 m
.84233 .02628 L
.84274 .02628 L
.84274 .08012 L
s
1 .894 .882 r
.84274 .08012 m
.84274 .02622 L
.84308 .02622 L
.84308 .08012 L
F
.804 .522 .247 r
.84274 .08012 m
.84274 .02622 L
.84308 .02622 L
.84308 .08012 L
s
1 .894 .882 r
.84308 .08012 m
.84308 .0262 L
.84334 .0262 L
.84334 .08012 L
F
.804 .522 .247 r
.84308 .08012 m
.84308 .0262 L
.84334 .0262 L
.84334 .08012 L
s
1 .894 .882 r
.84334 .08012 m
.84334 .02616 L
.84368 .02616 L
.84368 .08012 L
F
.804 .522 .247 r
.84334 .08012 m
.84334 .02616 L
.84368 .02616 L
.84368 .08012 L
s
1 .894 .882 r
.84368 .08012 m
.84368 .02609 L
.84408 .02609 L
.84408 .08012 L
F
.804 .522 .247 r
.84368 .08012 m
.84368 .02609 L
.84408 .02609 L
.84408 .08012 L
s
1 .894 .882 r
.84408 .08012 m
.84408 .02601 L
.8445 .02601 L
.8445 .08012 L
F
.804 .522 .247 r
.84408 .08012 m
.84408 .02601 L
.8445 .02601 L
.8445 .08012 L
s
1 .894 .882 r
.8445 .08012 m
.8445 .02593 L
.8449 .02593 L
.8449 .08012 L
F
.804 .522 .247 r
.8445 .08012 m
.8445 .02593 L
.8449 .02593 L
.8449 .08012 L
s
1 .894 .882 r
.8449 .08012 m
.8449 .02587 L
.84514 .02587 L
.84514 .08012 L
F
.804 .522 .247 r
.8449 .08012 m
.8449 .02587 L
.84514 .02587 L
.84514 .08012 L
s
1 .894 .882 r
.84514 .08012 m
.84514 .02583 L
.84541 .02583 L
.84541 .08012 L
F
.804 .522 .247 r
.84514 .08012 m
.84514 .02583 L
.84541 .02583 L
.84541 .08012 L
s
1 .894 .882 r
.84541 .08012 m
.84541 .02581 L
.84566 .02581 L
.84566 .08012 L
F
.804 .522 .247 r
.84541 .08012 m
.84541 .02581 L
.84566 .02581 L
.84566 .08012 L
s
1 .894 .882 r
.84566 .08012 m
.84566 .02572 L
.84608 .02572 L
.84608 .08012 L
F
.804 .522 .247 r
.84566 .08012 m
.84566 .02572 L
.84608 .02572 L
.84608 .08012 L
s
1 .894 .882 r
.84608 .08012 m
.84608 .02568 L
.84639 .02568 L
.84639 .08012 L
F
.804 .522 .247 r
.84608 .08012 m
.84608 .02568 L
.84639 .02568 L
.84639 .08012 L
s
1 .894 .882 r
.84639 .08012 m
.84639 .02558 L
.84682 .02558 L
.84682 .08012 L
F
.804 .522 .247 r
.84639 .08012 m
.84639 .02558 L
.84682 .02558 L
.84682 .08012 L
s
1 .894 .882 r
.84682 .08012 m
.84682 .02553 L
.84728 .02553 L
.84728 .08012 L
F
.804 .522 .247 r
.84682 .08012 m
.84682 .02553 L
.84728 .02553 L
.84728 .08012 L
s
1 .894 .882 r
.84728 .08012 m
.84728 .02549 L
.8476 .02549 L
.8476 .08012 L
F
.804 .522 .247 r
.84728 .08012 m
.84728 .02549 L
.8476 .02549 L
.8476 .08012 L
s
1 .894 .882 r
.8476 .08012 m
.8476 .02543 L
.84802 .02543 L
.84802 .08012 L
F
.804 .522 .247 r
.8476 .08012 m
.8476 .02543 L
.84802 .02543 L
.84802 .08012 L
s
1 .894 .882 r
.84802 .08012 m
.84802 .02537 L
.8485 .02537 L
.8485 .08012 L
F
.804 .522 .247 r
.84802 .08012 m
.84802 .02537 L
.8485 .02537 L
.8485 .08012 L
s
1 .894 .882 r
.8485 .08012 m
.8485 .02527 L
.8487 .02527 L
.8487 .08012 L
F
.804 .522 .247 r
.8485 .08012 m
.8485 .02527 L
.8487 .02527 L
.8487 .08012 L
s
1 .894 .882 r
.8487 .08012 m
.8487 .02524 L
.84895 .02524 L
.84895 .08012 L
F
.804 .522 .247 r
.8487 .08012 m
.8487 .02524 L
.84895 .02524 L
.84895 .08012 L
s
1 .894 .882 r
.84895 .08012 m
.84895 .0252 L
.84936 .0252 L
.84936 .08012 L
F
.804 .522 .247 r
.84895 .08012 m
.84895 .0252 L
.84936 .0252 L
.84936 .08012 L
s
1 .894 .882 r
.84936 .08012 m
.84936 .02515 L
.84975 .02515 L
.84975 .08012 L
F
.804 .522 .247 r
.84936 .08012 m
.84936 .02515 L
.84975 .02515 L
.84975 .08012 L
s
1 .894 .882 r
.84975 .08012 m
.84975 .02507 L
.85002 .02507 L
.85002 .08012 L
F
.804 .522 .247 r
.84975 .08012 m
.84975 .02507 L
.85002 .02507 L
.85002 .08012 L
s
1 .894 .882 r
.85002 .08012 m
.85002 .02498 L
.85047 .02498 L
.85047 .08012 L
F
.804 .522 .247 r
.85002 .08012 m
.85002 .02498 L
.85047 .02498 L
.85047 .08012 L
s
1 .894 .882 r
.85047 .08012 m
.85047 .02493 L
.85078 .02493 L
.85078 .08012 L
F
.804 .522 .247 r
.85047 .08012 m
.85047 .02493 L
.85078 .02493 L
.85078 .08012 L
s
1 .894 .882 r
.85078 .08012 m
.85078 .0249 L
.85125 .0249 L
.85125 .08012 L
F
.804 .522 .247 r
.85078 .08012 m
.85078 .0249 L
.85125 .0249 L
.85125 .08012 L
s
1 .894 .882 r
.85125 .08012 m
.85125 .02481 L
.85167 .02481 L
.85167 .08012 L
F
.804 .522 .247 r
.85125 .08012 m
.85125 .02481 L
.85167 .02481 L
.85167 .08012 L
s
1 .894 .882 r
.85167 .08012 m
.85167 .02475 L
.85201 .02475 L
.85201 .08012 L
F
.804 .522 .247 r
.85167 .08012 m
.85167 .02475 L
.85201 .02475 L
.85201 .08012 L
s
1 .894 .882 r
.85201 .08012 m
.85201 .02467 L
.85247 .02467 L
.85247 .08012 L
F
.804 .522 .247 r
.85201 .08012 m
.85201 .02467 L
.85247 .02467 L
.85247 .08012 L
s
1 .894 .882 r
.85247 .08012 m
.85247 .02462 L
.85269 .02462 L
.85269 .08012 L
F
.804 .522 .247 r
.85247 .08012 m
.85247 .02462 L
.85269 .02462 L
.85269 .08012 L
s
1 .894 .882 r
.85269 .08012 m
.85269 .0246 L
.85318 .0246 L
.85318 .08012 L
F
.804 .522 .247 r
.85269 .08012 m
.85269 .0246 L
.85318 .0246 L
.85318 .08012 L
s
1 .894 .882 r
.85318 .08012 m
.85318 .02447 L
.85361 .02447 L
.85361 .08012 L
F
.804 .522 .247 r
.85318 .08012 m
.85318 .02447 L
.85361 .02447 L
.85361 .08012 L
s
1 .894 .882 r
.85361 .08012 m
.85361 .02442 L
.85398 .02442 L
.85398 .08012 L
F
.804 .522 .247 r
.85361 .08012 m
.85361 .02442 L
.85398 .02442 L
.85398 .08012 L
s
1 .894 .882 r
.85398 .08012 m
.85398 .02439 L
.85442 .02439 L
.85442 .08012 L
F
.804 .522 .247 r
.85398 .08012 m
.85398 .02439 L
.85442 .02439 L
.85442 .08012 L
s
1 .894 .882 r
.85442 .08012 m
.85442 .02433 L
.85481 .02433 L
.85481 .08012 L
F
.804 .522 .247 r
.85442 .08012 m
.85442 .02433 L
.85481 .02433 L
.85481 .08012 L
s
1 .894 .882 r
.85481 .08012 m
.85481 .02427 L
.85497 .02427 L
.85497 .08012 L
F
.804 .522 .247 r
.85481 .08012 m
.85481 .02427 L
.85497 .02427 L
.85497 .08012 L
s
1 .894 .882 r
.85497 .08012 m
.85497 .02423 L
.85518 .02423 L
.85518 .08012 L
F
.804 .522 .247 r
.85497 .08012 m
.85497 .02423 L
.85518 .02423 L
.85518 .08012 L
s
1 .894 .882 r
.85518 .08012 m
.85518 .02421 L
.85534 .02421 L
.85534 .08012 L
F
.804 .522 .247 r
.85518 .08012 m
.85518 .02421 L
.85534 .02421 L
.85534 .08012 L
s
1 .894 .882 r
.85534 .08012 m
.85534 .02415 L
.85576 .02415 L
.85576 .08012 L
F
.804 .522 .247 r
.85534 .08012 m
.85534 .02415 L
.85576 .02415 L
.85576 .08012 L
s
1 .894 .882 r
.85576 .08012 m
.85576 .02413 L
.85609 .02413 L
.85609 .08012 L
F
.804 .522 .247 r
.85576 .08012 m
.85576 .02413 L
.85609 .02413 L
.85609 .08012 L
s
1 .894 .882 r
.85609 .08012 m
.85609 .02406 L
.85637 .02406 L
.85637 .08012 L
F
.804 .522 .247 r
.85609 .08012 m
.85609 .02406 L
.85637 .02406 L
.85637 .08012 L
s
1 .894 .882 r
.85637 .08012 m
.85637 .02403 L
.85654 .02403 L
.85654 .08012 L
F
.804 .522 .247 r
.85637 .08012 m
.85637 .02403 L
.85654 .02403 L
.85654 .08012 L
s
1 .894 .882 r
.85654 .08012 m
.85654 .02396 L
.85691 .02396 L
.85691 .08012 L
F
.804 .522 .247 r
.85654 .08012 m
.85654 .02396 L
.85691 .02396 L
.85691 .08012 L
s
1 .894 .882 r
.85691 .08012 m
.85691 .02393 L
.85714 .02393 L
.85714 .08012 L
F
.804 .522 .247 r
.85691 .08012 m
.85691 .02393 L
.85714 .02393 L
.85714 .08012 L
s
1 .894 .882 r
.85714 .08012 m
.85714 .02386 L
.85751 .02386 L
.85751 .08012 L
F
.804 .522 .247 r
.85714 .08012 m
.85714 .02386 L
.85751 .02386 L
.85751 .08012 L
s
1 .894 .882 r
.85751 .08012 m
.85751 .02385 L
.85777 .02385 L
.85777 .08012 L
F
.804 .522 .247 r
.85751 .08012 m
.85751 .02385 L
.85777 .02385 L
.85777 .08012 L
s
1 .894 .882 r
.85777 .08012 m
.85777 .02381 L
.85802 .02381 L
.85802 .08012 L
F
.804 .522 .247 r
.85777 .08012 m
.85777 .02381 L
.85802 .02381 L
.85802 .08012 L
s
1 .894 .882 r
.85802 .08012 m
.85802 .02375 L
.8583 .02375 L
.8583 .08012 L
F
.804 .522 .247 r
.85802 .08012 m
.85802 .02375 L
.8583 .02375 L
.8583 .08012 L
s
1 .894 .882 r
.8583 .08012 m
.8583 .02373 L
.8585 .02373 L
.8585 .08012 L
F
.804 .522 .247 r
.8583 .08012 m
.8583 .02373 L
.8585 .02373 L
.8585 .08012 L
s
1 .894 .882 r
.8585 .08012 m
.8585 .02367 L
.85879 .02367 L
.85879 .08012 L
F
.804 .522 .247 r
.8585 .08012 m
.8585 .02367 L
.85879 .02367 L
.85879 .08012 L
s
1 .894 .882 r
.85879 .08012 m
.85879 .02363 L
.85912 .02363 L
.85912 .08012 L
F
.804 .522 .247 r
.85879 .08012 m
.85879 .02363 L
.85912 .02363 L
.85912 .08012 L
s
1 .894 .882 r
.85912 .08012 m
.85912 .02361 L
.85954 .02361 L
.85954 .08012 L
F
.804 .522 .247 r
.85912 .08012 m
.85912 .02361 L
.85954 .02361 L
.85954 .08012 L
s
1 .894 .882 r
.85954 .08012 m
.85954 .02353 L
.85976 .02353 L
.85976 .08012 L
F
.804 .522 .247 r
.85954 .08012 m
.85954 .02353 L
.85976 .02353 L
.85976 .08012 L
s
1 .894 .882 r
.85976 .08012 m
.85976 .02348 L
.86 .02348 L
.86 .08012 L
F
.804 .522 .247 r
.85976 .08012 m
.85976 .02348 L
.86 .02348 L
.86 .08012 L
s
1 .894 .882 r
.86 .08012 m
.86 .02345 L
.86032 .02345 L
.86032 .08012 L
F
.804 .522 .247 r
.86 .08012 m
.86 .02345 L
.86032 .02345 L
.86032 .08012 L
s
1 .894 .882 r
.86032 .08012 m
.86032 .02342 L
.86081 .02342 L
.86081 .08012 L
F
.804 .522 .247 r
.86032 .08012 m
.86032 .02342 L
.86081 .02342 L
.86081 .08012 L
s
1 .894 .882 r
.86081 .08012 m
.86081 .02332 L
.86115 .02332 L
.86115 .08012 L
F
.804 .522 .247 r
.86081 .08012 m
.86081 .02332 L
.86115 .02332 L
.86115 .08012 L
s
1 .894 .882 r
.86115 .08012 m
.86115 .02327 L
.86144 .02327 L
.86144 .08012 L
F
.804 .522 .247 r
.86115 .08012 m
.86115 .02327 L
.86144 .02327 L
.86144 .08012 L
s
1 .894 .882 r
.86144 .08012 m
.86144 .02324 L
.86186 .02324 L
.86186 .08012 L
F
.804 .522 .247 r
.86144 .08012 m
.86144 .02324 L
.86186 .02324 L
.86186 .08012 L
s
1 .894 .882 r
.86186 .08012 m
.86186 .02314 L
.86234 .02314 L
.86234 .08012 L
F
.804 .522 .247 r
.86186 .08012 m
.86186 .02314 L
.86234 .02314 L
.86234 .08012 L
s
1 .894 .882 r
.86234 .08012 m
.86234 .02312 L
.86261 .02312 L
.86261 .08012 L
F
.804 .522 .247 r
.86234 .08012 m
.86234 .02312 L
.86261 .02312 L
.86261 .08012 L
s
1 .894 .882 r
.86261 .08012 m
.86261 .02307 L
.8629 .02307 L
.8629 .08012 L
F
.804 .522 .247 r
.86261 .08012 m
.86261 .02307 L
.8629 .02307 L
.8629 .08012 L
s
1 .894 .882 r
.8629 .08012 m
.8629 .02303 L
.86305 .02303 L
.86305 .08012 L
F
.804 .522 .247 r
.8629 .08012 m
.8629 .02303 L
.86305 .02303 L
.86305 .08012 L
s
1 .894 .882 r
.86305 .08012 m
.86305 .02299 L
.86334 .02299 L
.86334 .08012 L
F
.804 .522 .247 r
.86305 .08012 m
.86305 .02299 L
.86334 .02299 L
.86334 .08012 L
s
1 .894 .882 r
.86334 .08012 m
.86334 .02292 L
.86382 .02292 L
.86382 .08012 L
F
.804 .522 .247 r
.86334 .08012 m
.86334 .02292 L
.86382 .02292 L
.86382 .08012 L
s
1 .894 .882 r
.86382 .08012 m
.86382 .0229 L
.86409 .0229 L
.86409 .08012 L
F
.804 .522 .247 r
.86382 .08012 m
.86382 .0229 L
.86409 .0229 L
.86409 .08012 L
s
1 .894 .882 r
.86409 .08012 m
.86409 .02283 L
.86436 .02283 L
.86436 .08012 L
F
.804 .522 .247 r
.86409 .08012 m
.86409 .02283 L
.86436 .02283 L
.86436 .08012 L
s
1 .894 .882 r
.86436 .08012 m
.86436 .02282 L
.86457 .02282 L
.86457 .08012 L
F
.804 .522 .247 r
.86436 .08012 m
.86436 .02282 L
.86457 .02282 L
.86457 .08012 L
s
1 .894 .882 r
.86457 .08012 m
.86457 .02277 L
.86483 .02277 L
.86483 .08012 L
F
.804 .522 .247 r
.86457 .08012 m
.86457 .02277 L
.86483 .02277 L
.86483 .08012 L
s
1 .894 .882 r
.86483 .08012 m
.86483 .02275 L
.86533 .02275 L
.86533 .08012 L
F
.804 .522 .247 r
.86483 .08012 m
.86483 .02275 L
.86533 .02275 L
.86533 .08012 L
s
1 .894 .882 r
.86533 .08012 m
.86533 .02267 L
.86549 .02267 L
.86549 .08012 L
F
.804 .522 .247 r
.86533 .08012 m
.86533 .02267 L
.86549 .02267 L
.86549 .08012 L
s
1 .894 .882 r
.86549 .08012 m
.86549 .02262 L
.86592 .02262 L
.86592 .08012 L
F
.804 .522 .247 r
.86549 .08012 m
.86549 .02262 L
.86592 .02262 L
.86592 .08012 L
s
1 .894 .882 r
.86592 .08012 m
.86592 .02258 L
.86614 .02258 L
.86614 .08012 L
F
.804 .522 .247 r
.86592 .08012 m
.86592 .02258 L
.86614 .02258 L
.86614 .08012 L
s
1 .894 .882 r
.86614 .08012 m
.86614 .02255 L
.86648 .02255 L
.86648 .08012 L
F
.804 .522 .247 r
.86614 .08012 m
.86614 .02255 L
.86648 .02255 L
.86648 .08012 L
s
1 .894 .882 r
.86648 .08012 m
.86648 .02252 L
.86682 .02252 L
.86682 .08012 L
F
.804 .522 .247 r
.86648 .08012 m
.86648 .02252 L
.86682 .02252 L
.86682 .08012 L
s
1 .894 .882 r
.86682 .08012 m
.86682 .02246 L
.86697 .02246 L
.86697 .08012 L
F
.804 .522 .247 r
.86682 .08012 m
.86682 .02246 L
.86697 .02246 L
.86697 .08012 L
s
1 .894 .882 r
.86697 .08012 m
.86697 .02245 L
.86745 .02245 L
.86745 .08012 L
F
.804 .522 .247 r
.86697 .08012 m
.86697 .02245 L
.86745 .02245 L
.86745 .08012 L
s
1 .894 .882 r
.86745 .08012 m
.86745 .02237 L
.86771 .02237 L
.86771 .08012 L
F
.804 .522 .247 r
.86745 .08012 m
.86745 .02237 L
.86771 .02237 L
.86771 .08012 L
s
1 .894 .882 r
.86771 .08012 m
.86771 .02234 L
.86787 .02234 L
.86787 .08012 L
F
.804 .522 .247 r
.86771 .08012 m
.86771 .02234 L
.86787 .02234 L
.86787 .08012 L
s
1 .894 .882 r
.86787 .08012 m
.86787 .02232 L
.86803 .02232 L
.86803 .08012 L
F
.804 .522 .247 r
.86787 .08012 m
.86787 .02232 L
.86803 .02232 L
.86803 .08012 L
s
1 .894 .882 r
.86803 .08012 m
.86803 .02229 L
.86832 .02229 L
.86832 .08012 L
F
.804 .522 .247 r
.86803 .08012 m
.86803 .02229 L
.86832 .02229 L
.86832 .08012 L
s
1 .894 .882 r
.86832 .08012 m
.86832 .02221 L
.86878 .02221 L
.86878 .08012 L
F
.804 .522 .247 r
.86832 .08012 m
.86832 .02221 L
.86878 .02221 L
.86878 .08012 L
s
1 .894 .882 r
.86878 .08012 m
.86878 .02219 L
.86901 .02219 L
.86901 .08012 L
F
.804 .522 .247 r
.86878 .08012 m
.86878 .02219 L
.86901 .02219 L
.86901 .08012 L
s
1 .894 .882 r
.86901 .08012 m
.86901 .02215 L
.86918 .02215 L
.86918 .08012 L
F
.804 .522 .247 r
.86901 .08012 m
.86901 .02215 L
.86918 .02215 L
.86918 .08012 L
s
1 .894 .882 r
.86918 .08012 m
.86918 .02214 L
.86934 .02214 L
.86934 .08012 L
F
.804 .522 .247 r
.86918 .08012 m
.86918 .02214 L
.86934 .02214 L
.86934 .08012 L
s
1 .894 .882 r
.86934 .08012 m
.86934 .02211 L
.86967 .02211 L
.86967 .08012 L
F
.804 .522 .247 r
.86934 .08012 m
.86934 .02211 L
.86967 .02211 L
.86967 .08012 L
s
1 .894 .882 r
.86967 .08012 m
.86967 .02206 L
.86989 .02206 L
.86989 .08012 L
F
.804 .522 .247 r
.86967 .08012 m
.86967 .02206 L
.86989 .02206 L
.86989 .08012 L
s
1 .894 .882 r
.86989 .08012 m
.86989 .02204 L
.87027 .02204 L
.87027 .08012 L
F
.804 .522 .247 r
.86989 .08012 m
.86989 .02204 L
.87027 .02204 L
.87027 .08012 L
s
1 .894 .882 r
.87027 .08012 m
.87027 .02199 L
.87044 .02199 L
.87044 .08012 L
F
.804 .522 .247 r
.87027 .08012 m
.87027 .02199 L
.87044 .02199 L
.87044 .08012 L
s
1 .894 .882 r
.87044 .08012 m
.87044 .02197 L
.87065 .02197 L
.87065 .08012 L
F
.804 .522 .247 r
.87044 .08012 m
.87044 .02197 L
.87065 .02197 L
.87065 .08012 L
s
1 .894 .882 r
.87065 .08012 m
.87065 .02191 L
.87109 .02191 L
.87109 .08012 L
F
.804 .522 .247 r
.87065 .08012 m
.87065 .02191 L
.87109 .02191 L
.87109 .08012 L
s
1 .894 .882 r
.87109 .08012 m
.87109 .02185 L
.87141 .02185 L
.87141 .08012 L
F
.804 .522 .247 r
.87109 .08012 m
.87109 .02185 L
.87141 .02185 L
.87141 .08012 L
s
1 .894 .882 r
.87141 .08012 m
.87141 .02182 L
.8718 .02182 L
.8718 .08012 L
F
.804 .522 .247 r
.87141 .08012 m
.87141 .02182 L
.8718 .02182 L
.8718 .08012 L
s
1 .894 .882 r
.8718 .08012 m
.8718 .02176 L
.87202 .02176 L
.87202 .08012 L
F
.804 .522 .247 r
.8718 .08012 m
.8718 .02176 L
.87202 .02176 L
.87202 .08012 L
s
1 .894 .882 r
.87202 .08012 m
.87202 .02171 L
.87244 .02171 L
.87244 .08012 L
F
.804 .522 .247 r
.87202 .08012 m
.87202 .02171 L
.87244 .02171 L
.87244 .08012 L
s
1 .894 .882 r
.87244 .08012 m
.87244 .02169 L
.87282 .02169 L
.87282 .08012 L
F
.804 .522 .247 r
.87244 .08012 m
.87244 .02169 L
.87282 .02169 L
.87282 .08012 L
s
1 .894 .882 r
.87282 .08012 m
.87282 .02162 L
.87315 .02162 L
.87315 .08012 L
F
.804 .522 .247 r
.87282 .08012 m
.87282 .02162 L
.87315 .02162 L
.87315 .08012 L
s
1 .894 .882 r
.87315 .08012 m
.87315 .02158 L
.87351 .02158 L
.87351 .08012 L
F
.804 .522 .247 r
.87315 .08012 m
.87315 .02158 L
.87351 .02158 L
.87351 .08012 L
s
1 .894 .882 r
.87351 .08012 m
.87351 .02153 L
.87374 .02153 L
.87374 .08012 L
F
.804 .522 .247 r
.87351 .08012 m
.87351 .02153 L
.87374 .02153 L
.87374 .08012 L
s
1 .894 .882 r
.87374 .08012 m
.87374 .0215 L
.87412 .0215 L
.87412 .08012 L
F
.804 .522 .247 r
.87374 .08012 m
.87374 .0215 L
.87412 .0215 L
.87412 .08012 L
s
1 .894 .882 r
.87412 .08012 m
.87412 .02145 L
.87446 .02145 L
.87446 .08012 L
F
.804 .522 .247 r
.87412 .08012 m
.87412 .02145 L
.87446 .02145 L
.87446 .08012 L
s
1 .894 .882 r
.87446 .08012 m
.87446 .0214 L
.8747 .0214 L
.8747 .08012 L
F
.804 .522 .247 r
.87446 .08012 m
.87446 .0214 L
.8747 .0214 L
.8747 .08012 L
s
1 .894 .882 r
.8747 .08012 m
.8747 .02139 L
.87493 .02139 L
.87493 .08012 L
F
.804 .522 .247 r
.8747 .08012 m
.8747 .02139 L
.87493 .02139 L
.87493 .08012 L
s
1 .894 .882 r
.87493 .08012 m
.87493 .02133 L
.8753 .02133 L
.8753 .08012 L
F
.804 .522 .247 r
.87493 .08012 m
.87493 .02133 L
.8753 .02133 L
.8753 .08012 L
s
1 .894 .882 r
.8753 .08012 m
.8753 .02132 L
.87549 .02132 L
.87549 .08012 L
F
.804 .522 .247 r
.8753 .08012 m
.8753 .02132 L
.87549 .02132 L
.87549 .08012 L
s
1 .894 .882 r
.87549 .08012 m
.87549 .02129 L
.87576 .02129 L
.87576 .08012 L
F
.804 .522 .247 r
.87549 .08012 m
.87549 .02129 L
.87576 .02129 L
.87576 .08012 L
s
1 .894 .882 r
.87576 .08012 m
.87576 .0212 L
.87626 .0212 L
.87626 .08012 L
F
.804 .522 .247 r
.87576 .08012 m
.87576 .0212 L
.87626 .0212 L
.87626 .08012 L
s
1 .894 .882 r
.87626 .08012 m
.87626 .02115 L
.8766 .02115 L
.8766 .08012 L
F
.804 .522 .247 r
.87626 .08012 m
.87626 .02115 L
.8766 .02115 L
.8766 .08012 L
s
1 .894 .882 r
.8766 .08012 m
.8766 .02113 L
.87678 .02113 L
.87678 .08012 L
F
.804 .522 .247 r
.8766 .08012 m
.8766 .02113 L
.87678 .02113 L
.87678 .08012 L
s
1 .894 .882 r
.87678 .08012 m
.87678 .02109 L
.87721 .02109 L
.87721 .08012 L
F
.804 .522 .247 r
.87678 .08012 m
.87678 .02109 L
.87721 .02109 L
.87721 .08012 L
s
1 .894 .882 r
.87721 .08012 m
.87721 .02106 L
.87763 .02106 L
.87763 .08012 L
F
.804 .522 .247 r
.87721 .08012 m
.87721 .02106 L
.87763 .02106 L
.87763 .08012 L
s
1 .894 .882 r
.87763 .08012 m
.87763 .02097 L
.87809 .02097 L
.87809 .08012 L
F
.804 .522 .247 r
.87763 .08012 m
.87763 .02097 L
.87809 .02097 L
.87809 .08012 L
s
1 .894 .882 r
.87809 .08012 m
.87809 .02095 L
.87825 .02095 L
.87825 .08012 L
F
.804 .522 .247 r
.87809 .08012 m
.87809 .02095 L
.87825 .02095 L
.87825 .08012 L
s
1 .894 .882 r
.87825 .08012 m
.87825 .02091 L
.87862 .02091 L
.87862 .08012 L
F
.804 .522 .247 r
.87825 .08012 m
.87825 .02091 L
.87862 .02091 L
.87862 .08012 L
s
1 .894 .882 r
.87862 .08012 m
.87862 .02085 L
.87909 .02085 L
.87909 .08012 L
F
.804 .522 .247 r
.87862 .08012 m
.87862 .02085 L
.87909 .02085 L
.87909 .08012 L
s
1 .894 .882 r
.87909 .08012 m
.87909 .0208 L
.87939 .0208 L
.87939 .08012 L
F
.804 .522 .247 r
.87909 .08012 m
.87909 .0208 L
.87939 .0208 L
.87939 .08012 L
s
1 .894 .882 r
.87939 .08012 m
.87939 .02079 L
.87964 .02079 L
.87964 .08012 L
F
.804 .522 .247 r
.87939 .08012 m
.87939 .02079 L
.87964 .02079 L
.87964 .08012 L
s
1 .894 .882 r
.87964 .08012 m
.87964 .02074 L
.87994 .02074 L
.87994 .08012 L
F
.804 .522 .247 r
.87964 .08012 m
.87964 .02074 L
.87994 .02074 L
.87994 .08012 L
s
1 .894 .882 r
.87994 .08012 m
.87994 .02071 L
.88014 .02071 L
.88014 .08012 L
F
.804 .522 .247 r
.87994 .08012 m
.87994 .02071 L
.88014 .02071 L
.88014 .08012 L
s
1 .894 .882 r
.88014 .08012 m
.88014 .02066 L
.88055 .02066 L
.88055 .08012 L
F
.804 .522 .247 r
.88014 .08012 m
.88014 .02066 L
.88055 .02066 L
.88055 .08012 L
s
1 .894 .882 r
.88055 .08012 m
.88055 .02063 L
.88096 .02063 L
.88096 .08012 L
F
.804 .522 .247 r
.88055 .08012 m
.88055 .02063 L
.88096 .02063 L
.88096 .08012 L
s
1 .894 .882 r
.88096 .08012 m
.88096 .02059 L
.8814 .02059 L
.8814 .08012 L
F
.804 .522 .247 r
.88096 .08012 m
.88096 .02059 L
.8814 .02059 L
.8814 .08012 L
s
1 .894 .882 r
.8814 .08012 m
.8814 .02049 L
.88185 .02049 L
.88185 .08012 L
F
.804 .522 .247 r
.8814 .08012 m
.8814 .02049 L
.88185 .02049 L
.88185 .08012 L
s
1 .894 .882 r
.88185 .08012 m
.88185 .02048 L
.88203 .02048 L
.88203 .08012 L
F
.804 .522 .247 r
.88185 .08012 m
.88185 .02048 L
.88203 .02048 L
.88203 .08012 L
s
1 .894 .882 r
.88203 .08012 m
.88203 .02045 L
.88226 .02045 L
.88226 .08012 L
F
.804 .522 .247 r
.88203 .08012 m
.88203 .02045 L
.88226 .02045 L
.88226 .08012 L
s
1 .894 .882 r
.88226 .08012 m
.88226 .02043 L
.8826 .02043 L
.8826 .08012 L
F
.804 .522 .247 r
.88226 .08012 m
.88226 .02043 L
.8826 .02043 L
.8826 .08012 L
s
1 .894 .882 r
.8826 .08012 m
.8826 .02037 L
.88297 .02037 L
.88297 .08012 L
F
.804 .522 .247 r
.8826 .08012 m
.8826 .02037 L
.88297 .02037 L
.88297 .08012 L
s
1 .894 .882 r
.88297 .08012 m
.88297 .02034 L
.88328 .02034 L
.88328 .08012 L
F
.804 .522 .247 r
.88297 .08012 m
.88297 .02034 L
.88328 .02034 L
.88328 .08012 L
s
1 .894 .882 r
.88328 .08012 m
.88328 .0203 L
.88346 .0203 L
.88346 .08012 L
F
.804 .522 .247 r
.88328 .08012 m
.88328 .0203 L
.88346 .0203 L
.88346 .08012 L
s
1 .894 .882 r
.88346 .08012 m
.88346 .02029 L
.88367 .02029 L
.88367 .08012 L
F
.804 .522 .247 r
.88346 .08012 m
.88346 .02029 L
.88367 .02029 L
.88367 .08012 L
s
1 .894 .882 r
.88367 .08012 m
.88367 .02023 L
.88405 .02023 L
.88405 .08012 L
F
.804 .522 .247 r
.88367 .08012 m
.88367 .02023 L
.88405 .02023 L
.88405 .08012 L
s
1 .894 .882 r
.88405 .08012 m
.88405 .02019 L
.88449 .02019 L
.88449 .08012 L
F
.804 .522 .247 r
.88405 .08012 m
.88405 .02019 L
.88449 .02019 L
.88449 .08012 L
s
1 .894 .882 r
.88449 .08012 m
.88449 .02014 L
.88499 .02014 L
.88499 .08012 L
F
.804 .522 .247 r
.88449 .08012 m
.88449 .02014 L
.88499 .02014 L
.88499 .08012 L
s
1 .894 .882 r
.88499 .08012 m
.88499 .0201 L
.88526 .0201 L
.88526 .08012 L
F
.804 .522 .247 r
.88499 .08012 m
.88499 .0201 L
.88526 .0201 L
.88526 .08012 L
s
1 .894 .882 r
.88526 .08012 m
.88526 .02005 L
.88571 .02005 L
.88571 .08012 L
F
.804 .522 .247 r
.88526 .08012 m
.88526 .02005 L
.88571 .02005 L
.88571 .08012 L
s
1 .894 .882 r
.88571 .08012 m
.88571 .01998 L
.88619 .01998 L
.88619 .08012 L
F
.804 .522 .247 r
.88571 .08012 m
.88571 .01998 L
.88619 .01998 L
.88619 .08012 L
s
1 .894 .882 r
.88619 .08012 m
.88619 .01992 L
.88667 .01992 L
.88667 .08012 L
F
.804 .522 .247 r
.88619 .08012 m
.88619 .01992 L
.88667 .01992 L
.88667 .08012 L
s
1 .894 .882 r
.88667 .08012 m
.88667 .01987 L
.88707 .01987 L
.88707 .08012 L
F
.804 .522 .247 r
.88667 .08012 m
.88667 .01987 L
.88707 .01987 L
.88707 .08012 L
s
1 .894 .882 r
.88707 .08012 m
.88707 .01982 L
.88754 .01982 L
.88754 .08012 L
F
.804 .522 .247 r
.88707 .08012 m
.88707 .01982 L
.88754 .01982 L
.88754 .08012 L
s
1 .894 .882 r
.88754 .08012 m
.88754 .01978 L
.88787 .01978 L
.88787 .08012 L
F
.804 .522 .247 r
.88754 .08012 m
.88754 .01978 L
.88787 .01978 L
.88787 .08012 L
s
1 .894 .882 r
.88787 .08012 m
.88787 .01974 L
.88825 .01974 L
.88825 .08012 L
F
.804 .522 .247 r
.88787 .08012 m
.88787 .01974 L
.88825 .01974 L
.88825 .08012 L
s
1 .894 .882 r
.88825 .08012 m
.88825 .01973 L
.88849 .01973 L
.88849 .08012 L
F
.804 .522 .247 r
.88825 .08012 m
.88825 .01973 L
.88849 .01973 L
.88849 .08012 L
s
1 .894 .882 r
.88849 .08012 m
.88849 .0197 L
.88891 .0197 L
.88891 .08012 L
F
.804 .522 .247 r
.88849 .08012 m
.88849 .0197 L
.88891 .0197 L
.88891 .08012 L
s
1 .894 .882 r
.88891 .08012 m
.88891 .01965 L
.88933 .01965 L
.88933 .08012 L
F
.804 .522 .247 r
.88891 .08012 m
.88891 .01965 L
.88933 .01965 L
.88933 .08012 L
s
1 .894 .882 r
.88933 .08012 m
.88933 .0196 L
.88978 .0196 L
.88978 .08012 L
F
.804 .522 .247 r
.88933 .08012 m
.88933 .0196 L
.88978 .0196 L
.88978 .08012 L
s
1 .894 .882 r
.88978 .08012 m
.88978 .01956 L
.89008 .01956 L
.89008 .08012 L
F
.804 .522 .247 r
.88978 .08012 m
.88978 .01956 L
.89008 .01956 L
.89008 .08012 L
s
1 .894 .882 r
.89008 .08012 m
.89008 .01952 L
.89054 .01952 L
.89054 .08012 L
F
.804 .522 .247 r
.89008 .08012 m
.89008 .01952 L
.89054 .01952 L
.89054 .08012 L
s
1 .894 .882 r
.89054 .08012 m
.89054 .01944 L
.89093 .01944 L
.89093 .08012 L
F
.804 .522 .247 r
.89054 .08012 m
.89054 .01944 L
.89093 .01944 L
.89093 .08012 L
s
1 .894 .882 r
.89093 .08012 m
.89093 .01941 L
.89129 .01941 L
.89129 .08012 L
F
.804 .522 .247 r
.89093 .08012 m
.89093 .01941 L
.89129 .01941 L
.89129 .08012 L
s
1 .894 .882 r
.89129 .08012 m
.89129 .01935 L
.89175 .01935 L
.89175 .08012 L
F
.804 .522 .247 r
.89129 .08012 m
.89129 .01935 L
.89175 .01935 L
.89175 .08012 L
s
1 .894 .882 r
.89175 .08012 m
.89175 .01933 L
.89198 .01933 L
.89198 .08012 L
F
.804 .522 .247 r
.89175 .08012 m
.89175 .01933 L
.89198 .01933 L
.89198 .08012 L
s
1 .894 .882 r
.89198 .08012 m
.89198 .01931 L
.89222 .01931 L
.89222 .08012 L
F
.804 .522 .247 r
.89198 .08012 m
.89198 .01931 L
.89222 .01931 L
.89222 .08012 L
s
1 .894 .882 r
.89222 .08012 m
.89222 .01926 L
.89255 .01926 L
.89255 .08012 L
F
.804 .522 .247 r
.89222 .08012 m
.89222 .01926 L
.89255 .01926 L
.89255 .08012 L
s
1 .894 .882 r
.89255 .08012 m
.89255 .01923 L
.89295 .01923 L
.89295 .08012 L
F
.804 .522 .247 r
.89255 .08012 m
.89255 .01923 L
.89295 .01923 L
.89295 .08012 L
s
1 .894 .882 r
.89295 .08012 m
.89295 .01919 L
.89329 .01919 L
.89329 .08012 L
F
.804 .522 .247 r
.89295 .08012 m
.89295 .01919 L
.89329 .01919 L
.89329 .08012 L
s
1 .894 .882 r
.89329 .08012 m
.89329 .01915 L
.89357 .01915 L
.89357 .08012 L
F
.804 .522 .247 r
.89329 .08012 m
.89329 .01915 L
.89357 .01915 L
.89357 .08012 L
s
1 .894 .882 r
.89357 .08012 m
.89357 .01913 L
.8939 .01913 L
.8939 .08012 L
F
.804 .522 .247 r
.89357 .08012 m
.89357 .01913 L
.8939 .01913 L
.8939 .08012 L
s
1 .894 .882 r
.8939 .08012 m
.8939 .01911 L
.89418 .01911 L
.89418 .08012 L
F
.804 .522 .247 r
.8939 .08012 m
.8939 .01911 L
.89418 .01911 L
.89418 .08012 L
s
1 .894 .882 r
.89418 .08012 m
.89418 .01904 L
.89456 .01904 L
.89456 .08012 L
F
.804 .522 .247 r
.89418 .08012 m
.89418 .01904 L
.89456 .01904 L
.89456 .08012 L
s
1 .894 .882 r
.89456 .08012 m
.89456 .01901 L
.89485 .01901 L
.89485 .08012 L
F
.804 .522 .247 r
.89456 .08012 m
.89456 .01901 L
.89485 .01901 L
.89485 .08012 L
s
1 .894 .882 r
.89485 .08012 m
.89485 .019 L
.8952 .019 L
.8952 .08012 L
F
.804 .522 .247 r
.89485 .08012 m
.89485 .019 L
.8952 .019 L
.8952 .08012 L
s
1 .894 .882 r
.8952 .08012 m
.8952 .01897 L
.89557 .01897 L
.89557 .08012 L
F
.804 .522 .247 r
.8952 .08012 m
.8952 .01897 L
.89557 .01897 L
.89557 .08012 L
s
1 .894 .882 r
.89557 .08012 m
.89557 .01893 L
.89597 .01893 L
.89597 .08012 L
F
.804 .522 .247 r
.89557 .08012 m
.89557 .01893 L
.89597 .01893 L
.89597 .08012 L
s
1 .894 .882 r
.89597 .08012 m
.89597 .01885 L
.89642 .01885 L
.89642 .08012 L
F
.804 .522 .247 r
.89597 .08012 m
.89597 .01885 L
.89642 .01885 L
.89642 .08012 L
s
1 .894 .882 r
.89642 .08012 m
.89642 .01882 L
.89688 .01882 L
.89688 .08012 L
F
.804 .522 .247 r
.89642 .08012 m
.89642 .01882 L
.89688 .01882 L
.89688 .08012 L
s
1 .894 .882 r
.89688 .08012 m
.89688 .01877 L
.89716 .01877 L
.89716 .08012 L
F
.804 .522 .247 r
.89688 .08012 m
.89688 .01877 L
.89716 .01877 L
.89716 .08012 L
s
1 .894 .882 r
.89716 .08012 m
.89716 .01876 L
.89763 .01876 L
.89763 .08012 L
F
.804 .522 .247 r
.89716 .08012 m
.89716 .01876 L
.89763 .01876 L
.89763 .08012 L
s
1 .894 .882 r
.89763 .08012 m
.89763 .0187 L
.89781 .0187 L
.89781 .08012 L
F
.804 .522 .247 r
.89763 .08012 m
.89763 .0187 L
.89781 .0187 L
.89781 .08012 L
s
1 .894 .882 r
.89781 .08012 m
.89781 .0187 L
.89797 .0187 L
.89797 .08012 L
F
.804 .522 .247 r
.89781 .08012 m
.89781 .0187 L
.89797 .0187 L
.89797 .08012 L
s
1 .894 .882 r
.89797 .08012 m
.89797 .01865 L
.89844 .01865 L
.89844 .08012 L
F
.804 .522 .247 r
.89797 .08012 m
.89797 .01865 L
.89844 .01865 L
.89844 .08012 L
s
1 .894 .882 r
.89844 .08012 m
.89844 .01864 L
.89859 .01864 L
.89859 .08012 L
F
.804 .522 .247 r
.89844 .08012 m
.89844 .01864 L
.89859 .01864 L
.89859 .08012 L
s
1 .894 .882 r
.89859 .08012 m
.89859 .01862 L
.89888 .01862 L
.89888 .08012 L
F
.804 .522 .247 r
.89859 .08012 m
.89859 .01862 L
.89888 .01862 L
.89888 .08012 L
s
1 .894 .882 r
.89888 .08012 m
.89888 .01857 L
.89917 .01857 L
.89917 .08012 L
F
.804 .522 .247 r
.89888 .08012 m
.89888 .01857 L
.89917 .01857 L
.89917 .08012 L
s
1 .894 .882 r
.89917 .08012 m
.89917 .01856 L
.89933 .01856 L
.89933 .08012 L
F
.804 .522 .247 r
.89917 .08012 m
.89917 .01856 L
.89933 .01856 L
.89933 .08012 L
s
1 .894 .882 r
.89933 .08012 m
.89933 .01852 L
.89974 .01852 L
.89974 .08012 L
F
.804 .522 .247 r
.89933 .08012 m
.89933 .01852 L
.89974 .01852 L
.89974 .08012 L
s
1 .894 .882 r
.89974 .08012 m
.89974 .01849 L
.89995 .01849 L
.89995 .08012 L
F
.804 .522 .247 r
.89974 .08012 m
.89974 .01849 L
.89995 .01849 L
.89995 .08012 L
s
1 .894 .882 r
.89995 .08012 m
.89995 .01845 L
.90039 .01845 L
.90039 .08012 L
F
.804 .522 .247 r
.89995 .08012 m
.89995 .01845 L
.90039 .01845 L
.90039 .08012 L
s
1 .894 .882 r
.90039 .08012 m
.90039 .01843 L
.90064 .01843 L
.90064 .08012 L
F
.804 .522 .247 r
.90039 .08012 m
.90039 .01843 L
.90064 .01843 L
.90064 .08012 L
s
1 .894 .882 r
.90064 .08012 m
.90064 .01841 L
.90086 .01841 L
.90086 .08012 L
F
.804 .522 .247 r
.90064 .08012 m
.90064 .01841 L
.90086 .01841 L
.90086 .08012 L
s
1 .894 .882 r
.90086 .08012 m
.90086 .01836 L
.90129 .01836 L
.90129 .08012 L
F
.804 .522 .247 r
.90086 .08012 m
.90086 .01836 L
.90129 .01836 L
.90129 .08012 L
s
1 .894 .882 r
.90129 .08012 m
.90129 .01834 L
.90154 .01834 L
.90154 .08012 L
F
.804 .522 .247 r
.90129 .08012 m
.90129 .01834 L
.90154 .01834 L
.90154 .08012 L
s
1 .894 .882 r
.90154 .08012 m
.90154 .01831 L
.90201 .01831 L
.90201 .08012 L
F
.804 .522 .247 r
.90154 .08012 m
.90154 .01831 L
.90201 .01831 L
.90201 .08012 L
s
1 .894 .882 r
.90201 .08012 m
.90201 .01828 L
.90234 .01828 L
.90234 .08012 L
F
.804 .522 .247 r
.90201 .08012 m
.90201 .01828 L
.90234 .01828 L
.90234 .08012 L
s
1 .894 .882 r
.90234 .08012 m
.90234 .01825 L
.90262 .01825 L
.90262 .08012 L
F
.804 .522 .247 r
.90234 .08012 m
.90234 .01825 L
.90262 .01825 L
.90262 .08012 L
s
1 .894 .882 r
.90262 .08012 m
.90262 .01822 L
.90302 .01822 L
.90302 .08012 L
F
.804 .522 .247 r
.90262 .08012 m
.90262 .01822 L
.90302 .01822 L
.90302 .08012 L
s
1 .894 .882 r
.90302 .08012 m
.90302 .01818 L
.90327 .01818 L
.90327 .08012 L
F
.804 .522 .247 r
.90302 .08012 m
.90302 .01818 L
.90327 .01818 L
.90327 .08012 L
s
1 .894 .882 r
.90327 .08012 m
.90327 .01816 L
.90369 .01816 L
.90369 .08012 L
F
.804 .522 .247 r
.90327 .08012 m
.90327 .01816 L
.90369 .01816 L
.90369 .08012 L
s
1 .894 .882 r
.90369 .08012 m
.90369 .01812 L
.90402 .01812 L
.90402 .08012 L
F
.804 .522 .247 r
.90369 .08012 m
.90369 .01812 L
.90402 .01812 L
.90402 .08012 L
s
1 .894 .882 r
.90402 .08012 m
.90402 .01807 L
.90444 .01807 L
.90444 .08012 L
F
.804 .522 .247 r
.90402 .08012 m
.90402 .01807 L
.90444 .01807 L
.90444 .08012 L
s
1 .894 .882 r
.90444 .08012 m
.90444 .01803 L
.90491 .01803 L
.90491 .08012 L
F
.804 .522 .247 r
.90444 .08012 m
.90444 .01803 L
.90491 .01803 L
.90491 .08012 L
s
1 .894 .882 r
.90491 .08012 m
.90491 .01797 L
.90535 .01797 L
.90535 .08012 L
F
.804 .522 .247 r
.90491 .08012 m
.90491 .01797 L
.90535 .01797 L
.90535 .08012 L
s
1 .894 .882 r
.90535 .08012 m
.90535 .01797 L
.90565 .01797 L
.90565 .08012 L
F
.804 .522 .247 r
.90535 .08012 m
.90535 .01797 L
.90565 .01797 L
.90565 .08012 L
s
1 .894 .882 r
.90565 .08012 m
.90565 .01793 L
.90605 .01793 L
.90605 .08012 L
F
.804 .522 .247 r
.90565 .08012 m
.90565 .01793 L
.90605 .01793 L
.90605 .08012 L
s
1 .894 .882 r
.90605 .08012 m
.90605 .0179 L
.9062 .0179 L
.9062 .08012 L
F
.804 .522 .247 r
.90605 .08012 m
.90605 .0179 L
.9062 .0179 L
.9062 .08012 L
s
1 .894 .882 r
.9062 .08012 m
.9062 .01786 L
.90664 .01786 L
.90664 .08012 L
F
.804 .522 .247 r
.9062 .08012 m
.9062 .01786 L
.90664 .01786 L
.90664 .08012 L
s
1 .894 .882 r
.90664 .08012 m
.90664 .01785 L
.90679 .01785 L
.90679 .08012 L
F
.804 .522 .247 r
.90664 .08012 m
.90664 .01785 L
.90679 .01785 L
.90679 .08012 L
s
1 .894 .882 r
.90679 .08012 m
.90679 .01783 L
.90705 .01783 L
.90705 .08012 L
F
.804 .522 .247 r
.90679 .08012 m
.90679 .01783 L
.90705 .01783 L
.90705 .08012 L
s
1 .894 .882 r
.90705 .08012 m
.90705 .01779 L
.90754 .01779 L
.90754 .08012 L
F
.804 .522 .247 r
.90705 .08012 m
.90705 .01779 L
.90754 .01779 L
.90754 .08012 L
s
1 .894 .882 r
.90754 .08012 m
.90754 .01777 L
.90771 .01777 L
.90771 .08012 L
F
.804 .522 .247 r
.90754 .08012 m
.90754 .01777 L
.90771 .01777 L
.90771 .08012 L
s
1 .894 .882 r
.90771 .08012 m
.90771 .01774 L
.90815 .01774 L
.90815 .08012 L
F
.804 .522 .247 r
.90771 .08012 m
.90771 .01774 L
.90815 .01774 L
.90815 .08012 L
s
1 .894 .882 r
.90815 .08012 m
.90815 .0177 L
.90845 .0177 L
.90845 .08012 L
F
.804 .522 .247 r
.90815 .08012 m
.90815 .0177 L
.90845 .0177 L
.90845 .08012 L
s
1 .894 .882 r
.90845 .08012 m
.90845 .01769 L
.90884 .01769 L
.90884 .08012 L
F
.804 .522 .247 r
.90845 .08012 m
.90845 .01769 L
.90884 .01769 L
.90884 .08012 L
s
1 .894 .882 r
.90884 .08012 m
.90884 .01766 L
.90928 .01766 L
.90928 .08012 L
F
.804 .522 .247 r
.90884 .08012 m
.90884 .01766 L
.90928 .01766 L
.90928 .08012 L
s
1 .894 .882 r
.90928 .08012 m
.90928 .01761 L
.90945 .01761 L
.90945 .08012 L
F
.804 .522 .247 r
.90928 .08012 m
.90928 .01761 L
.90945 .01761 L
.90945 .08012 L
s
1 .894 .882 r
.90945 .08012 m
.90945 .0176 L
.90965 .0176 L
.90965 .08012 L
F
.804 .522 .247 r
.90945 .08012 m
.90945 .0176 L
.90965 .0176 L
.90965 .08012 L
s
1 .894 .882 r
.90965 .08012 m
.90965 .01757 L
.91005 .01757 L
.91005 .08012 L
F
.804 .522 .247 r
.90965 .08012 m
.90965 .01757 L
.91005 .01757 L
.91005 .08012 L
s
1 .894 .882 r
.91005 .08012 m
.91005 .01754 L
.91031 .01754 L
.91031 .08012 L
F
.804 .522 .247 r
.91005 .08012 m
.91005 .01754 L
.91031 .01754 L
.91031 .08012 L
s
1 .894 .882 r
.91031 .08012 m
.91031 .01752 L
.91069 .01752 L
.91069 .08012 L
F
.804 .522 .247 r
.91031 .08012 m
.91031 .01752 L
.91069 .01752 L
.91069 .08012 L
s
1 .894 .882 r
.91069 .08012 m
.91069 .01748 L
.91099 .01748 L
.91099 .08012 L
F
.804 .522 .247 r
.91069 .08012 m
.91069 .01748 L
.91099 .01748 L
.91099 .08012 L
s
1 .894 .882 r
.91099 .08012 m
.91099 .01747 L
.91129 .01747 L
.91129 .08012 L
F
.804 .522 .247 r
.91099 .08012 m
.91099 .01747 L
.91129 .01747 L
.91129 .08012 L
s
1 .894 .882 r
.91129 .08012 m
.91129 .01743 L
.91162 .01743 L
.91162 .08012 L
F
.804 .522 .247 r
.91129 .08012 m
.91129 .01743 L
.91162 .01743 L
.91162 .08012 L
s
1 .894 .882 r
.91162 .08012 m
.91162 .01741 L
.91182 .01741 L
.91182 .08012 L
F
.804 .522 .247 r
.91162 .08012 m
.91162 .01741 L
.91182 .01741 L
.91182 .08012 L
s
1 .894 .882 r
.91182 .08012 m
.91182 .0174 L
.91219 .0174 L
.91219 .08012 L
F
.804 .522 .247 r
.91182 .08012 m
.91182 .0174 L
.91219 .0174 L
.91219 .08012 L
s
1 .894 .882 r
.91219 .08012 m
.91219 .01735 L
.91251 .01735 L
.91251 .08012 L
F
.804 .522 .247 r
.91219 .08012 m
.91219 .01735 L
.91251 .01735 L
.91251 .08012 L
s
1 .894 .882 r
.91251 .08012 m
.91251 .01732 L
.91289 .01732 L
.91289 .08012 L
F
.804 .522 .247 r
.91251 .08012 m
.91251 .01732 L
.91289 .01732 L
.91289 .08012 L
s
1 .894 .882 r
.91289 .08012 m
.91289 .01731 L
.91329 .01731 L
.91329 .08012 L
F
.804 .522 .247 r
.91289 .08012 m
.91289 .01731 L
.91329 .01731 L
.91329 .08012 L
s
1 .894 .882 r
.91329 .08012 m
.91329 .01725 L
.91375 .01725 L
.91375 .08012 L
F
.804 .522 .247 r
.91329 .08012 m
.91329 .01725 L
.91375 .01725 L
.91375 .08012 L
s
1 .894 .882 r
.91375 .08012 m
.91375 .01724 L
.91407 .01724 L
.91407 .08012 L
F
.804 .522 .247 r
.91375 .08012 m
.91375 .01724 L
.91407 .01724 L
.91407 .08012 L
s
1 .894 .882 r
.91407 .08012 m
.91407 .01719 L
.91451 .01719 L
.91451 .08012 L
F
.804 .522 .247 r
.91407 .08012 m
.91407 .01719 L
.91451 .01719 L
.91451 .08012 L
s
1 .894 .882 r
.91451 .08012 m
.91451 .01715 L
.9149 .01715 L
.9149 .08012 L
F
.804 .522 .247 r
.91451 .08012 m
.91451 .01715 L
.9149 .01715 L
.9149 .08012 L
s
1 .894 .882 r
.9149 .08012 m
.9149 .01714 L
.91525 .01714 L
.91525 .08012 L
F
.804 .522 .247 r
.9149 .08012 m
.9149 .01714 L
.91525 .01714 L
.91525 .08012 L
s
1 .894 .882 r
.91525 .08012 m
.91525 .01711 L
.91556 .01711 L
.91556 .08012 L
F
.804 .522 .247 r
.91525 .08012 m
.91525 .01711 L
.91556 .01711 L
.91556 .08012 L
s
1 .894 .882 r
.91556 .08012 m
.91556 .01708 L
.91598 .01708 L
.91598 .08012 L
F
.804 .522 .247 r
.91556 .08012 m
.91556 .01708 L
.91598 .01708 L
.91598 .08012 L
s
1 .894 .882 r
.91598 .08012 m
.91598 .01705 L
.91642 .01705 L
.91642 .08012 L
F
.804 .522 .247 r
.91598 .08012 m
.91598 .01705 L
.91642 .01705 L
.91642 .08012 L
s
1 .894 .882 r
.91642 .08012 m
.91642 .01702 L
.91662 .01702 L
.91662 .08012 L
F
.804 .522 .247 r
.91642 .08012 m
.91642 .01702 L
.91662 .01702 L
.91662 .08012 L
s
1 .894 .882 r
.91662 .08012 m
.91662 .017 L
.91704 .017 L
.91704 .08012 L
F
.804 .522 .247 r
.91662 .08012 m
.91662 .017 L
.91704 .017 L
.91704 .08012 L
s
1 .894 .882 r
.91704 .08012 m
.91704 .01696 L
.91751 .01696 L
.91751 .08012 L
F
.804 .522 .247 r
.91704 .08012 m
.91704 .01696 L
.91751 .01696 L
.91751 .08012 L
s
1 .894 .882 r
.91751 .08012 m
.91751 .01692 L
.91793 .01692 L
.91793 .08012 L
F
.804 .522 .247 r
.91751 .08012 m
.91751 .01692 L
.91793 .01692 L
.91793 .08012 L
s
1 .894 .882 r
.91793 .08012 m
.91793 .01691 L
.91807 .01691 L
.91807 .08012 L
F
.804 .522 .247 r
.91793 .08012 m
.91793 .01691 L
.91807 .01691 L
.91807 .08012 L
s
1 .894 .882 r
.91807 .08012 m
.91807 .0169 L
.91823 .0169 L
.91823 .08012 L
F
.804 .522 .247 r
.91807 .08012 m
.91807 .0169 L
.91823 .0169 L
.91823 .08012 L
s
1 .894 .882 r
.91823 .08012 m
.91823 .01687 L
.9186 .01687 L
.9186 .08012 L
F
.804 .522 .247 r
.91823 .08012 m
.91823 .01687 L
.9186 .01687 L
.9186 .08012 L
s
1 .894 .882 r
.9186 .08012 m
.9186 .01686 L
.91878 .01686 L
.91878 .08012 L
F
.804 .522 .247 r
.9186 .08012 m
.9186 .01686 L
.91878 .01686 L
.91878 .08012 L
s
1 .894 .882 r
.91878 .08012 m
.91878 .01683 L
.91913 .01683 L
.91913 .08012 L
F
.804 .522 .247 r
.91878 .08012 m
.91878 .01683 L
.91913 .01683 L
.91913 .08012 L
s
1 .894 .882 r
.91913 .08012 m
.91913 .01682 L
.91948 .01682 L
.91948 .08012 L
F
.804 .522 .247 r
.91913 .08012 m
.91913 .01682 L
.91948 .01682 L
.91948 .08012 L
s
1 .894 .882 r
.91948 .08012 m
.91948 .0168 L
.91965 .0168 L
.91965 .08012 L
F
.804 .522 .247 r
.91948 .08012 m
.91948 .0168 L
.91965 .0168 L
.91965 .08012 L
s
1 .894 .882 r
.91965 .08012 m
.91965 .01679 L
.92013 .01679 L
.92013 .08012 L
F
.804 .522 .247 r
.91965 .08012 m
.91965 .01679 L
.92013 .01679 L
.92013 .08012 L
s
1 .894 .882 r
.92013 .08012 m
.92013 .01673 L
.9206 .01673 L
.9206 .08012 L
F
.804 .522 .247 r
.92013 .08012 m
.92013 .01673 L
.9206 .01673 L
.9206 .08012 L
s
1 .894 .882 r
.9206 .08012 m
.9206 .01671 L
.92078 .01671 L
.92078 .08012 L
F
.804 .522 .247 r
.9206 .08012 m
.9206 .01671 L
.92078 .01671 L
.92078 .08012 L
s
1 .894 .882 r
.92078 .08012 m
.92078 .0167 L
.92106 .0167 L
.92106 .08012 L
F
.804 .522 .247 r
.92078 .08012 m
.92078 .0167 L
.92106 .0167 L
.92106 .08012 L
s
1 .894 .882 r
.92106 .08012 m
.92106 .01667 L
.92129 .01667 L
.92129 .08012 L
F
.804 .522 .247 r
.92106 .08012 m
.92106 .01667 L
.92129 .01667 L
.92129 .08012 L
s
1 .894 .882 r
.92129 .08012 m
.92129 .01666 L
.92145 .01666 L
.92145 .08012 L
F
.804 .522 .247 r
.92129 .08012 m
.92129 .01666 L
.92145 .01666 L
.92145 .08012 L
s
1 .894 .882 r
.92145 .08012 m
.92145 .01664 L
.92181 .01664 L
.92181 .08012 L
F
.804 .522 .247 r
.92145 .08012 m
.92145 .01664 L
.92181 .01664 L
.92181 .08012 L
s
1 .894 .882 r
.92181 .08012 m
.92181 .01662 L
.92214 .01662 L
.92214 .08012 L
F
.804 .522 .247 r
.92181 .08012 m
.92181 .01662 L
.92214 .01662 L
.92214 .08012 L
s
1 .894 .882 r
.92214 .08012 m
.92214 .01659 L
.92247 .01659 L
.92247 .08012 L
F
.804 .522 .247 r
.92214 .08012 m
.92214 .01659 L
.92247 .01659 L
.92247 .08012 L
s
1 .894 .882 r
.92247 .08012 m
.92247 .01658 L
.92277 .01658 L
.92277 .08012 L
F
.804 .522 .247 r
.92247 .08012 m
.92247 .01658 L
.92277 .01658 L
.92277 .08012 L
s
1 .894 .882 r
.92277 .08012 m
.92277 .01657 L
.92296 .01657 L
.92296 .08012 L
F
.804 .522 .247 r
.92277 .08012 m
.92277 .01657 L
.92296 .01657 L
.92296 .08012 L
s
1 .894 .882 r
.92296 .08012 m
.92296 .01653 L
.92337 .01653 L
.92337 .08012 L
F
.804 .522 .247 r
.92296 .08012 m
.92296 .01653 L
.92337 .01653 L
.92337 .08012 L
s
1 .894 .882 r
.92337 .08012 m
.92337 .01651 L
.92375 .01651 L
.92375 .08012 L
F
.804 .522 .247 r
.92337 .08012 m
.92337 .01651 L
.92375 .01651 L
.92375 .08012 L
s
1 .894 .882 r
.92375 .08012 m
.92375 .01649 L
.92401 .01649 L
.92401 .08012 L
F
.804 .522 .247 r
.92375 .08012 m
.92375 .01649 L
.92401 .01649 L
.92401 .08012 L
s
1 .894 .882 r
.92401 .08012 m
.92401 .01647 L
.92427 .01647 L
.92427 .08012 L
F
.804 .522 .247 r
.92401 .08012 m
.92401 .01647 L
.92427 .01647 L
.92427 .08012 L
s
1 .894 .882 r
.92427 .08012 m
.92427 .01646 L
.92469 .01646 L
.92469 .08012 L
F
.804 .522 .247 r
.92427 .08012 m
.92427 .01646 L
.92469 .01646 L
.92469 .08012 L
s
1 .894 .882 r
.92469 .08012 m
.92469 .01642 L
.92515 .01642 L
.92515 .08012 L
F
.804 .522 .247 r
.92469 .08012 m
.92469 .01642 L
.92515 .01642 L
.92515 .08012 L
s
1 .894 .882 r
.92515 .08012 m
.92515 .01639 L
.92541 .01639 L
.92541 .08012 L
F
.804 .522 .247 r
.92515 .08012 m
.92515 .01639 L
.92541 .01639 L
.92541 .08012 L
s
1 .894 .882 r
.92541 .08012 m
.92541 .01638 L
.92566 .01638 L
.92566 .08012 L
F
.804 .522 .247 r
.92541 .08012 m
.92541 .01638 L
.92566 .01638 L
.92566 .08012 L
s
1 .894 .882 r
.92566 .08012 m
.92566 .01637 L
.92587 .01637 L
.92587 .08012 L
F
.804 .522 .247 r
.92566 .08012 m
.92566 .01637 L
.92587 .01637 L
.92587 .08012 L
s
1 .894 .882 r
.92587 .08012 m
.92587 .01633 L
.92629 .01633 L
.92629 .08012 L
F
.804 .522 .247 r
.92587 .08012 m
.92587 .01633 L
.92629 .01633 L
.92629 .08012 L
s
1 .894 .882 r
.92629 .08012 m
.92629 .01631 L
.92669 .01631 L
.92669 .08012 L
F
.804 .522 .247 r
.92629 .08012 m
.92629 .01631 L
.92669 .01631 L
.92669 .08012 L
s
1 .894 .882 r
.92669 .08012 m
.92669 .0163 L
.92708 .0163 L
.92708 .08012 L
F
.804 .522 .247 r
.92669 .08012 m
.92669 .0163 L
.92708 .0163 L
.92708 .08012 L
s
1 .894 .882 r
.92708 .08012 m
.92708 .01628 L
.92727 .01628 L
.92727 .08012 L
F
.804 .522 .247 r
.92708 .08012 m
.92708 .01628 L
.92727 .01628 L
.92727 .08012 L
s
1 .894 .882 r
.92727 .08012 m
.92727 .01624 L
.92771 .01624 L
.92771 .08012 L
F
.804 .522 .247 r
.92727 .08012 m
.92727 .01624 L
.92771 .01624 L
.92771 .08012 L
s
1 .894 .882 r
.92771 .08012 m
.92771 .01623 L
.92812 .01623 L
.92812 .08012 L
F
.804 .522 .247 r
.92771 .08012 m
.92771 .01623 L
.92812 .01623 L
.92812 .08012 L
s
1 .894 .882 r
.92812 .08012 m
.92812 .0162 L
.92848 .0162 L
.92848 .08012 L
F
.804 .522 .247 r
.92812 .08012 m
.92812 .0162 L
.92848 .0162 L
.92848 .08012 L
s
1 .894 .882 r
.92848 .08012 m
.92848 .01617 L
.92888 .01617 L
.92888 .08012 L
F
.804 .522 .247 r
.92848 .08012 m
.92848 .01617 L
.92888 .01617 L
.92888 .08012 L
s
1 .894 .882 r
.92888 .08012 m
.92888 .01617 L
.92924 .01617 L
.92924 .08012 L
F
.804 .522 .247 r
.92888 .08012 m
.92888 .01617 L
.92924 .01617 L
.92924 .08012 L
s
1 .894 .882 r
.92924 .08012 m
.92924 .01613 L
.92964 .01613 L
.92964 .08012 L
F
.804 .522 .247 r
.92924 .08012 m
.92924 .01613 L
.92964 .01613 L
.92964 .08012 L
s
1 .894 .882 r
.92964 .08012 m
.92964 .01612 L
.92979 .01612 L
.92979 .08012 L
F
.804 .522 .247 r
.92964 .08012 m
.92964 .01612 L
.92979 .01612 L
.92979 .08012 L
s
1 .894 .882 r
.92979 .08012 m
.92979 .01611 L
.93 .01611 L
.93 .08012 L
F
.804 .522 .247 r
.92979 .08012 m
.92979 .01611 L
.93 .01611 L
.93 .08012 L
s
1 .894 .882 r
.93 .08012 m
.93 .0161 L
.93018 .0161 L
.93018 .08012 L
F
.804 .522 .247 r
.93 .08012 m
.93 .0161 L
.93018 .0161 L
.93018 .08012 L
s
1 .894 .882 r
.93018 .08012 m
.93018 .01608 L
.93043 .01608 L
.93043 .08012 L
F
.804 .522 .247 r
.93018 .08012 m
.93018 .01608 L
.93043 .01608 L
.93043 .08012 L
s
1 .894 .882 r
.93043 .08012 m
.93043 .01605 L
.93088 .01605 L
.93088 .08012 L
F
.804 .522 .247 r
.93043 .08012 m
.93043 .01605 L
.93088 .01605 L
.93088 .08012 L
s
1 .894 .882 r
.93088 .08012 m
.93088 .01604 L
.93118 .01604 L
.93118 .08012 L
F
.804 .522 .247 r
.93088 .08012 m
.93088 .01604 L
.93118 .01604 L
.93118 .08012 L
s
1 .894 .882 r
.93118 .08012 m
.93118 .01602 L
.93147 .01602 L
.93147 .08012 L
F
.804 .522 .247 r
.93118 .08012 m
.93118 .01602 L
.93147 .01602 L
.93147 .08012 L
s
1 .894 .882 r
.93147 .08012 m
.93147 .01601 L
.93195 .01601 L
.93195 .08012 L
F
.804 .522 .247 r
.93147 .08012 m
.93147 .01601 L
.93195 .01601 L
.93195 .08012 L
s
1 .894 .882 r
.93195 .08012 m
.93195 .01598 L
.9323 .01598 L
.9323 .08012 L
F
.804 .522 .247 r
.93195 .08012 m
.93195 .01598 L
.9323 .01598 L
.9323 .08012 L
s
1 .894 .882 r
.9323 .08012 m
.9323 .01596 L
.93266 .01596 L
.93266 .08012 L
F
.804 .522 .247 r
.9323 .08012 m
.9323 .01596 L
.93266 .01596 L
.93266 .08012 L
s
1 .894 .882 r
.93266 .08012 m
.93266 .01594 L
.93298 .01594 L
.93298 .08012 L
F
.804 .522 .247 r
.93266 .08012 m
.93266 .01594 L
.93298 .01594 L
.93298 .08012 L
s
1 .894 .882 r
.93298 .08012 m
.93298 .01592 L
.93335 .01592 L
.93335 .08012 L
F
.804 .522 .247 r
.93298 .08012 m
.93298 .01592 L
.93335 .01592 L
.93335 .08012 L
s
1 .894 .882 r
.93335 .08012 m
.93335 .0159 L
.9336 .0159 L
.9336 .08012 L
F
.804 .522 .247 r
.93335 .08012 m
.93335 .0159 L
.9336 .0159 L
.9336 .08012 L
s
1 .894 .882 r
.9336 .08012 m
.9336 .01588 L
.93389 .01588 L
.93389 .08012 L
F
.804 .522 .247 r
.9336 .08012 m
.9336 .01588 L
.93389 .01588 L
.93389 .08012 L
s
1 .894 .882 r
.93389 .08012 m
.93389 .01587 L
.93429 .01587 L
.93429 .08012 L
F
.804 .522 .247 r
.93389 .08012 m
.93389 .01587 L
.93429 .01587 L
.93429 .08012 L
s
1 .894 .882 r
.93429 .08012 m
.93429 .01584 L
.93476 .01584 L
.93476 .08012 L
F
.804 .522 .247 r
.93429 .08012 m
.93429 .01584 L
.93476 .01584 L
.93476 .08012 L
s
1 .894 .882 r
.93476 .08012 m
.93476 .01582 L
.9351 .01582 L
.9351 .08012 L
F
.804 .522 .247 r
.93476 .08012 m
.93476 .01582 L
.9351 .01582 L
.9351 .08012 L
s
1 .894 .882 r
.9351 .08012 m
.9351 .01581 L
.93536 .01581 L
.93536 .08012 L
F
.804 .522 .247 r
.9351 .08012 m
.9351 .01581 L
.93536 .01581 L
.93536 .08012 L
s
1 .894 .882 r
.93536 .08012 m
.93536 .01579 L
.9358 .01579 L
.9358 .08012 L
F
.804 .522 .247 r
.93536 .08012 m
.93536 .01579 L
.9358 .01579 L
.9358 .08012 L
s
1 .894 .882 r
.9358 .08012 m
.9358 .01577 L
.936 .01577 L
.936 .08012 L
F
.804 .522 .247 r
.9358 .08012 m
.9358 .01577 L
.936 .01577 L
.936 .08012 L
s
1 .894 .882 r
.936 .08012 m
.936 .01575 L
.93649 .01575 L
.93649 .08012 L
F
.804 .522 .247 r
.936 .08012 m
.936 .01575 L
.93649 .01575 L
.93649 .08012 L
s
1 .894 .882 r
.93649 .08012 m
.93649 .01573 L
.93684 .01573 L
.93684 .08012 L
F
.804 .522 .247 r
.93649 .08012 m
.93649 .01573 L
.93684 .01573 L
.93684 .08012 L
s
1 .894 .882 r
.93684 .08012 m
.93684 .01572 L
.93706 .01572 L
.93706 .08012 L
F
.804 .522 .247 r
.93684 .08012 m
.93684 .01572 L
.93706 .01572 L
.93706 .08012 L
s
1 .894 .882 r
.93706 .08012 m
.93706 .0157 L
.93736 .0157 L
.93736 .08012 L
F
.804 .522 .247 r
.93706 .08012 m
.93706 .0157 L
.93736 .0157 L
.93736 .08012 L
s
1 .894 .882 r
.93736 .08012 m
.93736 .01568 L
.93784 .01568 L
.93784 .08012 L
F
.804 .522 .247 r
.93736 .08012 m
.93736 .01568 L
.93784 .01568 L
.93784 .08012 L
s
1 .894 .882 r
.93784 .08012 m
.93784 .01566 L
.93813 .01566 L
.93813 .08012 L
F
.804 .522 .247 r
.93784 .08012 m
.93784 .01566 L
.93813 .01566 L
.93813 .08012 L
s
1 .894 .882 r
.93813 .08012 m
.93813 .01565 L
.93832 .01565 L
.93832 .08012 L
F
.804 .522 .247 r
.93813 .08012 m
.93813 .01565 L
.93832 .01565 L
.93832 .08012 L
s
1 .894 .882 r
.93832 .08012 m
.93832 .01564 L
.93852 .01564 L
.93852 .08012 L
F
.804 .522 .247 r
.93832 .08012 m
.93832 .01564 L
.93852 .01564 L
.93852 .08012 L
s
1 .894 .882 r
.93852 .08012 m
.93852 .01563 L
.93869 .01563 L
.93869 .08012 L
F
.804 .522 .247 r
.93852 .08012 m
.93852 .01563 L
.93869 .01563 L
.93869 .08012 L
s
1 .894 .882 r
.93869 .08012 m
.93869 .01562 L
.93918 .01562 L
.93918 .08012 L
F
.804 .522 .247 r
.93869 .08012 m
.93869 .01562 L
.93918 .01562 L
.93918 .08012 L
s
1 .894 .882 r
.93918 .08012 m
.93918 .01559 L
.93957 .01559 L
.93957 .08012 L
F
.804 .522 .247 r
.93918 .08012 m
.93918 .01559 L
.93957 .01559 L
.93957 .08012 L
s
1 .894 .882 r
.93957 .08012 m
.93957 .01558 L
.93978 .01558 L
.93978 .08012 L
F
.804 .522 .247 r
.93957 .08012 m
.93957 .01558 L
.93978 .01558 L
.93978 .08012 L
s
1 .894 .882 r
.93978 .08012 m
.93978 .01557 L
.9401 .01557 L
.9401 .08012 L
F
.804 .522 .247 r
.93978 .08012 m
.93978 .01557 L
.9401 .01557 L
.9401 .08012 L
s
1 .894 .882 r
.9401 .08012 m
.9401 .01556 L
.94037 .01556 L
.94037 .08012 L
F
.804 .522 .247 r
.9401 .08012 m
.9401 .01556 L
.94037 .01556 L
.94037 .08012 L
s
1 .894 .882 r
.94037 .08012 m
.94037 .01554 L
.94059 .01554 L
.94059 .08012 L
F
.804 .522 .247 r
.94037 .08012 m
.94037 .01554 L
.94059 .01554 L
.94059 .08012 L
s
1 .894 .882 r
.94059 .08012 m
.94059 .01552 L
.94092 .01552 L
.94092 .08012 L
F
.804 .522 .247 r
.94059 .08012 m
.94059 .01552 L
.94092 .01552 L
.94092 .08012 L
s
1 .894 .882 r
.94092 .08012 m
.94092 .01552 L
.94114 .01552 L
.94114 .08012 L
F
.804 .522 .247 r
.94092 .08012 m
.94092 .01552 L
.94114 .01552 L
.94114 .08012 L
s
1 .894 .882 r
.94114 .08012 m
.94114 .0155 L
.94161 .0155 L
.94161 .08012 L
F
.804 .522 .247 r
.94114 .08012 m
.94114 .0155 L
.94161 .0155 L
.94161 .08012 L
s
1 .894 .882 r
.94161 .08012 m
.94161 .01549 L
.94193 .01549 L
.94193 .08012 L
F
.804 .522 .247 r
.94161 .08012 m
.94161 .01549 L
.94193 .01549 L
.94193 .08012 L
s
1 .894 .882 r
.94193 .08012 m
.94193 .01547 L
.94228 .01547 L
.94228 .08012 L
F
.804 .522 .247 r
.94193 .08012 m
.94193 .01547 L
.94228 .01547 L
.94228 .08012 L
s
1 .894 .882 r
.94228 .08012 m
.94228 .01545 L
.94264 .01545 L
.94264 .08012 L
F
.804 .522 .247 r
.94228 .08012 m
.94228 .01545 L
.94264 .01545 L
.94264 .08012 L
s
1 .894 .882 r
.94264 .08012 m
.94264 .01544 L
.94301 .01544 L
.94301 .08012 L
F
.804 .522 .247 r
.94264 .08012 m
.94264 .01544 L
.94301 .01544 L
.94301 .08012 L
s
1 .894 .882 r
.94301 .08012 m
.94301 .01541 L
.94337 .01541 L
.94337 .08012 L
F
.804 .522 .247 r
.94301 .08012 m
.94301 .01541 L
.94337 .01541 L
.94337 .08012 L
s
1 .894 .882 r
.94337 .08012 m
.94337 .01541 L
.94367 .01541 L
.94367 .08012 L
F
.804 .522 .247 r
.94337 .08012 m
.94337 .01541 L
.94367 .01541 L
.94367 .08012 L
s
1 .894 .882 r
.94367 .08012 m
.94367 .01539 L
.94405 .01539 L
.94405 .08012 L
F
.804 .522 .247 r
.94367 .08012 m
.94367 .01539 L
.94405 .01539 L
.94405 .08012 L
s
1 .894 .882 r
.94405 .08012 m
.94405 .01538 L
.94421 .01538 L
.94421 .08012 L
F
.804 .522 .247 r
.94405 .08012 m
.94405 .01538 L
.94421 .01538 L
.94421 .08012 L
s
1 .894 .882 r
.94421 .08012 m
.94421 .01537 L
.94449 .01537 L
.94449 .08012 L
F
.804 .522 .247 r
.94421 .08012 m
.94421 .01537 L
.94449 .01537 L
.94449 .08012 L
s
1 .894 .882 r
.94449 .08012 m
.94449 .01536 L
.94465 .01536 L
.94465 .08012 L
F
.804 .522 .247 r
.94449 .08012 m
.94449 .01536 L
.94465 .01536 L
.94465 .08012 L
s
1 .894 .882 r
.94465 .08012 m
.94465 .01536 L
.94503 .01536 L
.94503 .08012 L
F
.804 .522 .247 r
.94465 .08012 m
.94465 .01536 L
.94503 .01536 L
.94503 .08012 L
s
1 .894 .882 r
.94503 .08012 m
.94503 .01533 L
.9454 .01533 L
.9454 .08012 L
F
.804 .522 .247 r
.94503 .08012 m
.94503 .01533 L
.9454 .01533 L
.9454 .08012 L
s
1 .894 .882 r
.9454 .08012 m
.9454 .01533 L
.94564 .01533 L
.94564 .08012 L
F
.804 .522 .247 r
.9454 .08012 m
.9454 .01533 L
.94564 .01533 L
.94564 .08012 L
s
1 .894 .882 r
.94564 .08012 m
.94564 .01532 L
.94608 .01532 L
.94608 .08012 L
F
.804 .522 .247 r
.94564 .08012 m
.94564 .01532 L
.94608 .01532 L
.94608 .08012 L
s
1 .894 .882 r
.94608 .08012 m
.94608 .0153 L
.94645 .0153 L
.94645 .08012 L
F
.804 .522 .247 r
.94608 .08012 m
.94608 .0153 L
.94645 .0153 L
.94645 .08012 L
s
1 .894 .882 r
.94645 .08012 m
.94645 .01528 L
.94682 .01528 L
.94682 .08012 L
F
.804 .522 .247 r
.94645 .08012 m
.94645 .01528 L
.94682 .01528 L
.94682 .08012 L
s
1 .894 .882 r
.94682 .08012 m
.94682 .01527 L
.94716 .01527 L
.94716 .08012 L
F
.804 .522 .247 r
.94682 .08012 m
.94682 .01527 L
.94716 .01527 L
.94716 .08012 L
s
1 .894 .882 r
.94716 .08012 m
.94716 .01525 L
.94754 .01525 L
.94754 .08012 L
F
.804 .522 .247 r
.94716 .08012 m
.94716 .01525 L
.94754 .01525 L
.94754 .08012 L
s
1 .894 .882 r
.94754 .08012 m
.94754 .01525 L
.94774 .01525 L
.94774 .08012 L
F
.804 .522 .247 r
.94754 .08012 m
.94754 .01525 L
.94774 .01525 L
.94774 .08012 L
s
1 .894 .882 r
.94774 .08012 m
.94774 .01524 L
.94798 .01524 L
.94798 .08012 L
F
.804 .522 .247 r
.94774 .08012 m
.94774 .01524 L
.94798 .01524 L
.94798 .08012 L
s
1 .894 .882 r
.94798 .08012 m
.94798 .01523 L
.94826 .01523 L
.94826 .08012 L
F
.804 .522 .247 r
.94798 .08012 m
.94798 .01523 L
.94826 .01523 L
.94826 .08012 L
s
1 .894 .882 r
.94826 .08012 m
.94826 .01522 L
.94845 .01522 L
.94845 .08012 L
F
.804 .522 .247 r
.94826 .08012 m
.94826 .01522 L
.94845 .01522 L
.94845 .08012 L
s
1 .894 .882 r
.94845 .08012 m
.94845 .01521 L
.94892 .01521 L
.94892 .08012 L
F
.804 .522 .247 r
.94845 .08012 m
.94845 .01521 L
.94892 .01521 L
.94892 .08012 L
s
1 .894 .882 r
.94892 .08012 m
.94892 .01519 L
.94918 .01519 L
.94918 .08012 L
F
.804 .522 .247 r
.94892 .08012 m
.94892 .01519 L
.94918 .01519 L
.94918 .08012 L
s
1 .894 .882 r
.94918 .08012 m
.94918 .01518 L
.94964 .01518 L
.94964 .08012 L
F
.804 .522 .247 r
.94918 .08012 m
.94918 .01518 L
.94964 .01518 L
.94964 .08012 L
s
1 .894 .882 r
.94964 .08012 m
.94964 .01516 L
.94996 .01516 L
.94996 .08012 L
F
.804 .522 .247 r
.94964 .08012 m
.94964 .01516 L
.94996 .01516 L
.94996 .08012 L
s
1 .894 .882 r
.94996 .08012 m
.94996 .01516 L
.95023 .01516 L
.95023 .08012 L
F
.804 .522 .247 r
.94996 .08012 m
.94996 .01516 L
.95023 .01516 L
.95023 .08012 L
s
1 .894 .882 r
.95023 .08012 m
.95023 .01514 L
.95061 .01514 L
.95061 .08012 L
F
.804 .522 .247 r
.95023 .08012 m
.95023 .01514 L
.95061 .01514 L
.95061 .08012 L
s
1 .894 .882 r
.95061 .08012 m
.95061 .01514 L
.95085 .01514 L
.95085 .08012 L
F
.804 .522 .247 r
.95061 .08012 m
.95061 .01514 L
.95085 .01514 L
.95085 .08012 L
s
1 .894 .882 r
.95085 .08012 m
.95085 .01513 L
.95102 .01513 L
.95102 .08012 L
F
.804 .522 .247 r
.95085 .08012 m
.95085 .01513 L
.95102 .01513 L
.95102 .08012 L
s
1 .894 .882 r
.95102 .08012 m
.95102 .01512 L
.95141 .01512 L
.95141 .08012 L
F
.804 .522 .247 r
.95102 .08012 m
.95102 .01512 L
.95141 .01512 L
.95141 .08012 L
s
1 .894 .882 r
.95141 .08012 m
.95141 .01511 L
.95178 .01511 L
.95178 .08012 L
F
.804 .522 .247 r
.95141 .08012 m
.95141 .01511 L
.95178 .01511 L
.95178 .08012 L
s
1 .894 .882 r
.95178 .08012 m
.95178 .01509 L
.95222 .01509 L
.95222 .08012 L
F
.804 .522 .247 r
.95178 .08012 m
.95178 .01509 L
.95222 .01509 L
.95222 .08012 L
s
1 .894 .882 r
.95222 .08012 m
.95222 .01509 L
.95239 .01509 L
.95239 .08012 L
F
.804 .522 .247 r
.95222 .08012 m
.95222 .01509 L
.95239 .01509 L
.95239 .08012 L
s
1 .894 .882 r
.95239 .08012 m
.95239 .01508 L
.95288 .01508 L
.95288 .08012 L
F
.804 .522 .247 r
.95239 .08012 m
.95239 .01508 L
.95288 .01508 L
.95288 .08012 L
s
1 .894 .882 r
.95288 .08012 m
.95288 .01507 L
.95304 .01507 L
.95304 .08012 L
F
.804 .522 .247 r
.95288 .08012 m
.95288 .01507 L
.95304 .01507 L
.95304 .08012 L
s
1 .894 .882 r
.95304 .08012 m
.95304 .01506 L
.95339 .01506 L
.95339 .08012 L
F
.804 .522 .247 r
.95304 .08012 m
.95304 .01506 L
.95339 .01506 L
.95339 .08012 L
s
1 .894 .882 r
.95339 .08012 m
.95339 .01505 L
.9536 .01505 L
.9536 .08012 L
F
.804 .522 .247 r
.95339 .08012 m
.95339 .01505 L
.9536 .01505 L
.9536 .08012 L
s
1 .894 .882 r
.9536 .08012 m
.9536 .01504 L
.95387 .01504 L
.95387 .08012 L
F
.804 .522 .247 r
.9536 .08012 m
.9536 .01504 L
.95387 .01504 L
.95387 .08012 L
s
1 .894 .882 r
.95387 .08012 m
.95387 .01503 L
.95415 .01503 L
.95415 .08012 L
F
.804 .522 .247 r
.95387 .08012 m
.95387 .01503 L
.95415 .01503 L
.95415 .08012 L
s
1 .894 .882 r
.95415 .08012 m
.95415 .01503 L
.95431 .01503 L
.95431 .08012 L
F
.804 .522 .247 r
.95415 .08012 m
.95415 .01503 L
.95431 .01503 L
.95431 .08012 L
s
1 .894 .882 r
.95431 .08012 m
.95431 .01502 L
.95464 .01502 L
.95464 .08012 L
F
.804 .522 .247 r
.95431 .08012 m
.95431 .01502 L
.95464 .01502 L
.95464 .08012 L
s
1 .894 .882 r
.95464 .08012 m
.95464 .01501 L
.95485 .01501 L
.95485 .08012 L
F
.804 .522 .247 r
.95464 .08012 m
.95464 .01501 L
.95485 .01501 L
.95485 .08012 L
s
1 .894 .882 r
.95485 .08012 m
.95485 .01501 L
.95504 .01501 L
.95504 .08012 L
F
.804 .522 .247 r
.95485 .08012 m
.95485 .01501 L
.95504 .01501 L
.95504 .08012 L
s
1 .894 .882 r
.95504 .08012 m
.95504 .015 L
.95541 .015 L
.95541 .08012 L
F
.804 .522 .247 r
.95504 .08012 m
.95504 .015 L
.95541 .015 L
.95541 .08012 L
s
1 .894 .882 r
.95541 .08012 m
.95541 .01499 L
.9557 .01499 L
.9557 .08012 L
F
.804 .522 .247 r
.95541 .08012 m
.95541 .01499 L
.9557 .01499 L
.9557 .08012 L
s
1 .894 .882 r
.9557 .08012 m
.9557 .01498 L
.95593 .01498 L
.95593 .08012 L
F
.804 .522 .247 r
.9557 .08012 m
.9557 .01498 L
.95593 .01498 L
.95593 .08012 L
s
1 .894 .882 r
.95593 .08012 m
.95593 .01498 L
.95636 .01498 L
.95636 .08012 L
F
.804 .522 .247 r
.95593 .08012 m
.95593 .01498 L
.95636 .01498 L
.95636 .08012 L
s
1 .894 .882 r
.95636 .08012 m
.95636 .01497 L
.95676 .01497 L
.95676 .08012 L
F
.804 .522 .247 r
.95636 .08012 m
.95636 .01497 L
.95676 .01497 L
.95676 .08012 L
s
1 .894 .882 r
.95676 .08012 m
.95676 .01496 L
.95722 .01496 L
.95722 .08012 L
F
.804 .522 .247 r
.95676 .08012 m
.95676 .01496 L
.95722 .01496 L
.95722 .08012 L
s
1 .894 .882 r
.95722 .08012 m
.95722 .01494 L
.95768 .01494 L
.95768 .08012 L
F
.804 .522 .247 r
.95722 .08012 m
.95722 .01494 L
.95768 .01494 L
.95768 .08012 L
s
1 .894 .882 r
.95768 .08012 m
.95768 .01494 L
.95786 .01494 L
.95786 .08012 L
F
.804 .522 .247 r
.95768 .08012 m
.95768 .01494 L
.95786 .01494 L
.95786 .08012 L
s
1 .894 .882 r
.95786 .08012 m
.95786 .01493 L
.95818 .01493 L
.95818 .08012 L
F
.804 .522 .247 r
.95786 .08012 m
.95786 .01493 L
.95818 .01493 L
.95818 .08012 L
s
1 .894 .882 r
.95818 .08012 m
.95818 .01492 L
.95861 .01492 L
.95861 .08012 L
F
.804 .522 .247 r
.95818 .08012 m
.95818 .01492 L
.95861 .01492 L
.95861 .08012 L
s
1 .894 .882 r
.95861 .08012 m
.95861 .01491 L
.95883 .01491 L
.95883 .08012 L
F
.804 .522 .247 r
.95861 .08012 m
.95861 .01491 L
.95883 .01491 L
.95883 .08012 L
s
1 .894 .882 r
.95883 .08012 m
.95883 .01491 L
.95914 .01491 L
.95914 .08012 L
F
.804 .522 .247 r
.95883 .08012 m
.95883 .01491 L
.95914 .01491 L
.95914 .08012 L
s
1 .894 .882 r
.95914 .08012 m
.95914 .0149 L
.9595 .0149 L
.9595 .08012 L
F
.804 .522 .247 r
.95914 .08012 m
.95914 .0149 L
.9595 .0149 L
.9595 .08012 L
s
1 .894 .882 r
.9595 .08012 m
.9595 .01489 L
.95991 .01489 L
.95991 .08012 L
F
.804 .522 .247 r
.9595 .08012 m
.9595 .01489 L
.95991 .01489 L
.95991 .08012 L
s
1 .894 .882 r
.95991 .08012 m
.95991 .01489 L
.96014 .01489 L
.96014 .08012 L
F
.804 .522 .247 r
.95991 .08012 m
.95991 .01489 L
.96014 .01489 L
.96014 .08012 L
s
1 .894 .882 r
.96014 .08012 m
.96014 .01488 L
.96043 .01488 L
.96043 .08012 L
F
.804 .522 .247 r
.96014 .08012 m
.96014 .01488 L
.96043 .01488 L
.96043 .08012 L
s
1 .894 .882 r
.96043 .08012 m
.96043 .01487 L
.9606 .01487 L
.9606 .08012 L
F
.804 .522 .247 r
.96043 .08012 m
.96043 .01487 L
.9606 .01487 L
.9606 .08012 L
s
1 .894 .882 r
.9606 .08012 m
.9606 .01487 L
.96094 .01487 L
.96094 .08012 L
F
.804 .522 .247 r
.9606 .08012 m
.9606 .01487 L
.96094 .01487 L
.96094 .08012 L
s
1 .894 .882 r
.96094 .08012 m
.96094 .01486 L
.9614 .01486 L
.9614 .08012 L
F
.804 .522 .247 r
.96094 .08012 m
.96094 .01486 L
.9614 .01486 L
.9614 .08012 L
s
1 .894 .882 r
.9614 .08012 m
.9614 .01486 L
.96155 .01486 L
.96155 .08012 L
F
.804 .522 .247 r
.9614 .08012 m
.9614 .01486 L
.96155 .01486 L
.96155 .08012 L
s
1 .894 .882 r
.96155 .08012 m
.96155 .01485 L
.96171 .01485 L
.96171 .08012 L
F
.804 .522 .247 r
.96155 .08012 m
.96155 .01485 L
.96171 .01485 L
.96171 .08012 L
s
1 .894 .882 r
.96171 .08012 m
.96171 .01485 L
.96187 .01485 L
.96187 .08012 L
F
.804 .522 .247 r
.96171 .08012 m
.96171 .01485 L
.96187 .01485 L
.96187 .08012 L
s
1 .894 .882 r
.96187 .08012 m
.96187 .01484 L
.96226 .01484 L
.96226 .08012 L
F
.804 .522 .247 r
.96187 .08012 m
.96187 .01484 L
.96226 .01484 L
.96226 .08012 L
s
1 .894 .882 r
.96226 .08012 m
.96226 .01484 L
.96271 .01484 L
.96271 .08012 L
F
.804 .522 .247 r
.96226 .08012 m
.96226 .01484 L
.96271 .01484 L
.96271 .08012 L
s
1 .894 .882 r
.96271 .08012 m
.96271 .01483 L
.963 .01483 L
.963 .08012 L
F
.804 .522 .247 r
.96271 .08012 m
.96271 .01483 L
.963 .01483 L
.963 .08012 L
s
1 .894 .882 r
.963 .08012 m
.963 .01483 L
.96335 .01483 L
.96335 .08012 L
F
.804 .522 .247 r
.963 .08012 m
.963 .01483 L
.96335 .01483 L
.96335 .08012 L
s
1 .894 .882 r
.96335 .08012 m
.96335 .01482 L
.96367 .01482 L
.96367 .08012 L
F
.804 .522 .247 r
.96335 .08012 m
.96335 .01482 L
.96367 .01482 L
.96367 .08012 L
s
1 .894 .882 r
.96367 .08012 m
.96367 .01482 L
.96385 .01482 L
.96385 .08012 L
F
.804 .522 .247 r
.96367 .08012 m
.96367 .01482 L
.96385 .01482 L
.96385 .08012 L
s
1 .894 .882 r
.96385 .08012 m
.96385 .01481 L
.96422 .01481 L
.96422 .08012 L
F
.804 .522 .247 r
.96385 .08012 m
.96385 .01481 L
.96422 .01481 L
.96422 .08012 L
s
1 .894 .882 r
.96422 .08012 m
.96422 .0148 L
.9646 .0148 L
.9646 .08012 L
F
.804 .522 .247 r
.96422 .08012 m
.96422 .0148 L
.9646 .0148 L
.9646 .08012 L
s
1 .894 .882 r
.9646 .08012 m
.9646 .0148 L
.96495 .0148 L
.96495 .08012 L
F
.804 .522 .247 r
.9646 .08012 m
.9646 .0148 L
.96495 .0148 L
.96495 .08012 L
s
1 .894 .882 r
.96495 .08012 m
.96495 .01479 L
.96544 .01479 L
.96544 .08012 L
F
.804 .522 .247 r
.96495 .08012 m
.96495 .01479 L
.96544 .01479 L
.96544 .08012 L
s
1 .894 .882 r
.96544 .08012 m
.96544 .01479 L
.96564 .01479 L
.96564 .08012 L
F
.804 .522 .247 r
.96544 .08012 m
.96544 .01479 L
.96564 .01479 L
.96564 .08012 L
s
1 .894 .882 r
.96564 .08012 m
.96564 .01479 L
.96609 .01479 L
.96609 .08012 L
F
.804 .522 .247 r
.96564 .08012 m
.96564 .01479 L
.96609 .01479 L
.96609 .08012 L
s
1 .894 .882 r
.96609 .08012 m
.96609 .01478 L
.96636 .01478 L
.96636 .08012 L
F
.804 .522 .247 r
.96609 .08012 m
.96609 .01478 L
.96636 .01478 L
.96636 .08012 L
s
1 .894 .882 r
.96636 .08012 m
.96636 .01478 L
.9667 .01478 L
.9667 .08012 L
F
.804 .522 .247 r
.96636 .08012 m
.96636 .01478 L
.9667 .01478 L
.9667 .08012 L
s
1 .894 .882 r
.9667 .08012 m
.9667 .01477 L
.96702 .01477 L
.96702 .08012 L
F
.804 .522 .247 r
.9667 .08012 m
.9667 .01477 L
.96702 .01477 L
.96702 .08012 L
s
1 .894 .882 r
.96702 .08012 m
.96702 .01477 L
.96721 .01477 L
.96721 .08012 L
F
.804 .522 .247 r
.96702 .08012 m
.96702 .01477 L
.96721 .01477 L
.96721 .08012 L
s
1 .894 .882 r
.96721 .08012 m
.96721 .01477 L
.9674 .01477 L
.9674 .08012 L
F
.804 .522 .247 r
.96721 .08012 m
.96721 .01477 L
.9674 .01477 L
.9674 .08012 L
s
1 .894 .882 r
.9674 .08012 m
.9674 .01476 L
.96759 .01476 L
.96759 .08012 L
F
.804 .522 .247 r
.9674 .08012 m
.9674 .01476 L
.96759 .01476 L
.96759 .08012 L
s
1 .894 .882 r
.96759 .08012 m
.96759 .01476 L
.9679 .01476 L
.9679 .08012 L
F
.804 .522 .247 r
.96759 .08012 m
.96759 .01476 L
.9679 .01476 L
.9679 .08012 L
s
1 .894 .882 r
.9679 .08012 m
.9679 .01476 L
.96823 .01476 L
.96823 .08012 L
F
.804 .522 .247 r
.9679 .08012 m
.9679 .01476 L
.96823 .01476 L
.96823 .08012 L
s
1 .894 .882 r
.96823 .08012 m
.96823 .01475 L
.96846 .01475 L
.96846 .08012 L
F
.804 .522 .247 r
.96823 .08012 m
.96823 .01475 L
.96846 .01475 L
.96846 .08012 L
s
1 .894 .882 r
.96846 .08012 m
.96846 .01475 L
.96864 .01475 L
.96864 .08012 L
F
.804 .522 .247 r
.96846 .08012 m
.96846 .01475 L
.96864 .01475 L
.96864 .08012 L
s
1 .894 .882 r
.96864 .08012 m
.96864 .01475 L
.96895 .01475 L
.96895 .08012 L
F
.804 .522 .247 r
.96864 .08012 m
.96864 .01475 L
.96895 .01475 L
.96895 .08012 L
s
1 .894 .882 r
.96895 .08012 m
.96895 .01475 L
.96927 .01475 L
.96927 .08012 L
F
.804 .522 .247 r
.96895 .08012 m
.96895 .01475 L
.96927 .01475 L
.96927 .08012 L
s
1 .894 .882 r
.96927 .08012 m
.96927 .01475 L
.9696 .01475 L
.9696 .08012 L
F
.804 .522 .247 r
.96927 .08012 m
.96927 .01475 L
.9696 .01475 L
.9696 .08012 L
s
1 .894 .882 r
.9696 .08012 m
.9696 .01474 L
.96982 .01474 L
.96982 .08012 L
F
.804 .522 .247 r
.9696 .08012 m
.9696 .01474 L
.96982 .01474 L
.96982 .08012 L
s
1 .894 .882 r
.96982 .08012 m
.96982 .01474 L
.96998 .01474 L
.96998 .08012 L
F
.804 .522 .247 r
.96982 .08012 m
.96982 .01474 L
.96998 .01474 L
.96998 .08012 L
s
1 .894 .882 r
.96998 .08012 m
.96998 .01474 L
.97045 .01474 L
.97045 .08012 L
F
.804 .522 .247 r
.96998 .08012 m
.96998 .01474 L
.97045 .01474 L
.97045 .08012 L
s
1 .894 .882 r
.97045 .08012 m
.97045 .01474 L
.97061 .01474 L
.97061 .08012 L
F
.804 .522 .247 r
.97045 .08012 m
.97045 .01474 L
.97061 .01474 L
.97061 .08012 L
s
1 .894 .882 r
.97061 .08012 m
.97061 .01473 L
.9708 .01473 L
.9708 .08012 L
F
.804 .522 .247 r
.97061 .08012 m
.97061 .01473 L
.9708 .01473 L
.9708 .08012 L
s
1 .894 .882 r
.9708 .08012 m
.9708 .01473 L
.97108 .01473 L
.97108 .08012 L
F
.804 .522 .247 r
.9708 .08012 m
.9708 .01473 L
.97108 .01473 L
.97108 .08012 L
s
1 .894 .882 r
.97108 .08012 m
.97108 .01473 L
.97131 .01473 L
.97131 .08012 L
F
.804 .522 .247 r
.97108 .08012 m
.97108 .01473 L
.97131 .01473 L
.97131 .08012 L
s
1 .894 .882 r
.97131 .08012 m
.97131 .01473 L
.97161 .01473 L
.97161 .08012 L
F
.804 .522 .247 r
.97131 .08012 m
.97131 .01473 L
.97161 .01473 L
.97161 .08012 L
s
1 .894 .882 r
.97161 .08012 m
.97161 .01473 L
.9718 .01473 L
.9718 .08012 L
F
.804 .522 .247 r
.97161 .08012 m
.97161 .01473 L
.9718 .01473 L
.9718 .08012 L
s
1 .894 .882 r
.9718 .08012 m
.9718 .01473 L
.97204 .01473 L
.97204 .08012 L
F
.804 .522 .247 r
.9718 .08012 m
.9718 .01473 L
.97204 .01473 L
.97204 .08012 L
s
1 .894 .882 r
.97204 .08012 m
.97204 .01473 L
.9723 .01473 L
.9723 .08012 L
F
.804 .522 .247 r
.97204 .08012 m
.97204 .01473 L
.9723 .01473 L
.9723 .08012 L
s
1 .894 .882 r
.9723 .08012 m
.9723 .01472 L
.97248 .01472 L
.97248 .08012 L
F
.804 .522 .247 r
.9723 .08012 m
.9723 .01472 L
.97248 .01472 L
.97248 .08012 L
s
1 .894 .882 r
.97248 .08012 m
.97248 .01472 L
.97284 .01472 L
.97284 .08012 L
F
.804 .522 .247 r
.97248 .08012 m
.97248 .01472 L
.97284 .01472 L
.97284 .08012 L
s
1 .894 .882 r
.97284 .08012 m
.97284 .01472 L
.97323 .01472 L
.97323 .08012 L
F
.804 .522 .247 r
.97284 .08012 m
.97284 .01472 L
.97323 .01472 L
.97323 .08012 L
s
1 .894 .882 r
.97323 .08012 m
.97323 .01472 L
.97346 .01472 L
.97346 .08012 L
F
.804 .522 .247 r
.97323 .08012 m
.97323 .01472 L
.97346 .01472 L
.97346 .08012 L
s
1 .894 .882 r
.97346 .08012 m
.97346 .01472 L
.97394 .01472 L
.97394 .08012 L
F
.804 .522 .247 r
.97346 .08012 m
.97346 .01472 L
.97394 .01472 L
.97394 .08012 L
s
1 .894 .882 r
.97394 .08012 m
.97394 .01472 L
.97425 .01472 L
.97425 .08012 L
F
.804 .522 .247 r
.97394 .08012 m
.97394 .01472 L
.97425 .01472 L
.97425 .08012 L
s
1 .894 .882 r
.97425 .08012 m
.97425 .01472 L
.97449 .01472 L
.97449 .08012 L
F
.804 .522 .247 r
.97425 .08012 m
.97425 .01472 L
.97449 .01472 L
.97449 .08012 L
s
1 .894 .882 r
.97449 .08012 m
.97449 .01472 L
.97488 .01472 L
.97488 .08012 L
F
.804 .522 .247 r
.97449 .08012 m
.97449 .01472 L
.97488 .01472 L
.97488 .08012 L
s
1 .894 .882 r
.97488 .08012 m
.97488 .01472 L
.97527 .01472 L
.97527 .08012 L
F
.804 .522 .247 r
.97488 .08012 m
.97488 .01472 L
.97527 .01472 L
.97527 .08012 L
s
1 .894 .882 r
.97527 .08012 m
.97527 .01472 L
.97555 .01472 L
.97555 .08012 L
F
.804 .522 .247 r
.97527 .08012 m
.97527 .01472 L
.97555 .01472 L
.97555 .08012 L
s
1 .894 .882 r
.97555 .08012 m
.97555 .01472 L
.97598 .01472 L
.97598 .08012 L
F
.804 .522 .247 r
.97555 .08012 m
.97555 .01472 L
.97598 .01472 L
.97598 .08012 L
s
1 .894 .882 r
.97598 .08012 m
.97598 .01472 L
.97619 .01472 L
.97619 .08012 L
F
.804 .522 .247 r
.97598 .08012 m
.97598 .01472 L
.97619 .01472 L
.97619 .08012 L
s
0 0 0 r
.02381 .08012 m
.97619 .08012 L
s
4 Mabswid
.02385 .60327 Mdot
.02406 .60301 Mdot
.02442 .60256 Mdot
.02453 .60243 Mdot
.02473 .60218 Mdot
.02497 .60189 Mdot
.02533 .60144 Mdot
.0256 .60111 Mdot
.0261 .60049 Mdot
.02662 .59985 Mdot
.02666 .59979 Mdot
.02709 .59927 Mdot
.02747 .5988 Mdot
.02773 .59848 Mdot
.02801 .59813 Mdot
.02845 .59759 Mdot
.02891 .59703 Mdot
.02924 .59662 Mdot
.0293 .59655 Mdot
.02969 .59607 Mdot
.03018 .59548 Mdot
.0303 .59532 Mdot
.03045 .59513 Mdot
.03079 .59472 Mdot
.03126 .59415 Mdot
.03149 .59386 Mdot
.03185 .59342 Mdot
.03201 .59322 Mdot
.03239 .59276 Mdot
.0326 .59251 Mdot
.03287 .59217 Mdot
.03313 .59185 Mdot
.03364 .59124 Mdot
.03378 .59105 Mdot
.03407 .59071 Mdot
.03444 .59025 Mdot
.03473 .5899 Mdot
.03533 .58917 Mdot
.03554 .58891 Mdot
.03561 .58882 Mdot
.03608 .58825 Mdot
.03626 .58803 Mdot
.03681 .58736 Mdot
.03713 .58697 Mdot
.03755 .58645 Mdot
.03773 .58624 Mdot
.03796 .58595 Mdot
.03844 .58537 Mdot
.03851 .58529 Mdot
.03881 .58493 Mdot
.03937 .58425 Mdot
.03968 .58386 Mdot
.0401 .58336 Mdot
.04031 .5831 Mdot
.04068 .58265 Mdot
.0409 .58239 Mdot
.04148 .58168 Mdot
.04196 .5811 Mdot
.04214 .58088 Mdot
.04239 .58058 Mdot
.04251 .58043 Mdot
.04282 .58006 Mdot
.04314 .57966 Mdot
.0434 .57935 Mdot
.04362 .57909 Mdot
.044 .57862 Mdot
.0446 .5779 Mdot
.04464 .57785 Mdot
.04499 .57743 Mdot
.04507 .57733 Mdot
.04547 .57684 Mdot
.04575 .57651 Mdot
.04612 .57607 Mdot
.04654 .57556 Mdot
.04688 .57515 Mdot
.0469 .57512 Mdot
.04748 .57443 Mdot
.04795 .57385 Mdot
.04807 .57371 Mdot
.04836 .57336 Mdot
.04865 .57302 Mdot
.04878 .57286 Mdot
.04921 .57234 Mdot
.04966 .5718 Mdot
.04995 .57145 Mdot
.05022 .57113 Mdot
.05055 .57073 Mdot
.05075 .57049 Mdot
.05128 .56985 Mdot
.05141 .56969 Mdot
.05155 .56953 Mdot
.05169 .56937 Mdot
.05182 .5692 Mdot
.05235 .56857 Mdot
.05287 .56795 Mdot
.05316 .5676 Mdot
.05327 .56747 Mdot
.05379 .56684 Mdot
.05419 .56637 Mdot
.05444 .56606 Mdot
.05467 .5658 Mdot
.05486 .56556 Mdot
.05501 .56538 Mdot
.05533 .565 Mdot
.05573 .56452 Mdot
.05587 .56436 Mdot
.05606 .56413 Mdot
.05664 .56344 Mdot
.05684 .56319 Mdot
.05709 .5629 Mdot
.05757 .56233 Mdot
.05772 .56215 Mdot
.05819 .56159 Mdot
.05853 .56119 Mdot
.05876 .56091 Mdot
.05929 .56028 Mdot
.05948 .56005 Mdot
.06019 .55921 Mdot
.06038 .55899 Mdot
.06053 .5588 Mdot
.06087 .5584 Mdot
.06129 .5579 Mdot
.06173 .55738 Mdot
.06183 .55727 Mdot
.06206 .55699 Mdot
.06248 .55649 Mdot
.06278 .55614 Mdot
.06309 .55576 Mdot
.06335 .55546 Mdot
.06359 .55518 Mdot
.06387 .55484 Mdot
.06425 .55439 Mdot
.0648 .55375 Mdot
.06488 .55365 Mdot
.06538 .55305 Mdot
.06558 .55282 Mdot
.06595 .55239 Mdot
.06628 .55199 Mdot
.06639 .55186 Mdot
.06663 .55157 Mdot
.06699 .55116 Mdot
.06748 .55058 Mdot
.06776 .55025 Mdot
.06796 .55001 Mdot
.0682 .54973 Mdot
.06874 .54909 Mdot
.06926 .54847 Mdot
.06946 .54824 Mdot
.06975 .5479 Mdot
.06996 .54766 Mdot
.07018 .5474 Mdot
.07072 .54677 Mdot
.07093 .54652 Mdot
.07125 .54614 Mdot
.07149 .54586 Mdot
.07174 .54557 Mdot
.07212 .54512 Mdot
.07242 .54477 Mdot
.07305 .54402 Mdot
.07314 .54393 Mdot
.07354 .54345 Mdot
.07368 .54328 Mdot
.07409 .54281 Mdot
.07443 .54241 Mdot
.07461 .5422 Mdot
.0749 .54186 Mdot
.07499 .54176 Mdot
.07529 .54141 Mdot
.07552 .54114 Mdot
.07579 .54082 Mdot
.07611 .54045 Mdot
.07649 .54 Mdot
.07664 .53983 Mdot
.07684 .5396 Mdot
.07707 .53932 Mdot
.07731 .53905 Mdot
.07738 .53896 Mdot
.07778 .5385 Mdot
.07835 .53783 Mdot
.07878 .53734 Mdot
.0791 .53696 Mdot
.07949 .53651 Mdot
.07975 .5362 Mdot
.07994 .53598 Mdot
.08025 .53562 Mdot
.08032 .53554 Mdot
.0809 .53487 Mdot
.08102 .53472 Mdot
.08154 .53412 Mdot
.0816 .53406 Mdot
.08193 .53367 Mdot
.08213 .53344 Mdot
.08228 .53327 Mdot
.08276 .53271 Mdot
.08293 .53252 Mdot
.08329 .53209 Mdot
.08345 .53191 Mdot
.08358 .53176 Mdot
.08398 .5313 Mdot
.08456 .53062 Mdot
.08473 .53043 Mdot
.08484 .53029 Mdot
.08526 .52981 Mdot
.08538 .52967 Mdot
.08554 .52949 Mdot
.0861 .52884 Mdot
.08629 .52863 Mdot
.08687 .52796 Mdot
.08702 .52777 Mdot
.08749 .52723 Mdot
.08787 .5268 Mdot
.08836 .52624 Mdot
.08856 .526 Mdot
.08876 .52578 Mdot
.08926 .5252 Mdot
.08965 .52475 Mdot
.0901 .52423 Mdot
.0903 .524 Mdot
.0906 .52366 Mdot
.09101 .52319 Mdot
.09105 .52314 Mdot
.09154 .52258 Mdot
.09234 .52165 Mdot
.09271 .52124 Mdot
.09286 .52106 Mdot
.0935 .52033 Mdot
.09354 .52028 Mdot
.09395 .51981 Mdot
.09421 .51952 Mdot
.09461 .51906 Mdot
.09493 .51869 Mdot
.09519 .5184 Mdot
.09532 .51825 Mdot
.09584 .51765 Mdot
.09596 .51751 Mdot
.09607 .51739 Mdot
.09654 .51685 Mdot
.09686 .51649 Mdot
.09717 .51613 Mdot
.09729 .51599 Mdot
.09797 .51522 Mdot
.09819 .51497 Mdot
.09854 .51457 Mdot
.09871 .51437 Mdot
.09903 .51401 Mdot
.09915 .51388 Mdot
.0996 .51336 Mdot
.09983 .5131 Mdot
.10023 .51264 Mdot
.10054 .51229 Mdot
.10094 .51184 Mdot
.10122 .51153 Mdot
.10166 .51103 Mdot
.10188 .51077 Mdot
.10203 .5106 Mdot
.10252 .51004 Mdot
.10284 .50968 Mdot
.10317 .50931 Mdot
.10329 .50917 Mdot
.10405 .50831 Mdot
.10418 .50817 Mdot
.10451 .5078 Mdot
.10483 .50744 Mdot
.10517 .50705 Mdot
.10539 .50679 Mdot
.10594 .50618 Mdot
.10621 .50587 Mdot
.10644 .50561 Mdot
.10693 .50506 Mdot
.10714 .50482 Mdot
.10734 .5046 Mdot
.10768 .50421 Mdot
.1079 .50396 Mdot
.10813 .50371 Mdot
.10862 .50316 Mdot
.1089 .50284 Mdot
.10923 .50247 Mdot
.10949 .50217 Mdot
.10962 .50204 Mdot
.11021 .50137 Mdot
.11045 .50109 Mdot
.11074 .50077 Mdot
.11126 .50019 Mdot
.11161 .4998 Mdot
.11185 .49953 Mdot
.11213 .49921 Mdot
.1124 .49891 Mdot
.11252 .49878 Mdot
.1133 .4979 Mdot
.11353 .49764 Mdot
.11376 .49739 Mdot
.11407 .49704 Mdot
.11432 .49676 Mdot
.11446 .4966 Mdot
.11485 .49616 Mdot
.11514 .49584 Mdot
.1158 .49511 Mdot
.11602 .49486 Mdot
.11627 .49458 Mdot
.11659 .49423 Mdot
.11672 .49408 Mdot
.11708 .49367 Mdot
.11726 .49348 Mdot
.11749 .49322 Mdot
.11798 .49268 Mdot
.11817 .49247 Mdot
.11863 .49195 Mdot
.119 .49154 Mdot
.11934 .49116 Mdot
.11991 .49053 Mdot
.12025 .49015 Mdot
.12034 .49005 Mdot
.12049 .48988 Mdot
.12066 .48969 Mdot
.12112 .48918 Mdot
.1215 .48876 Mdot
.12169 .48855 Mdot
.12171 .48853 Mdot
.12213 .48806 Mdot
.12228 .4879 Mdot
.12244 .48772 Mdot
.1227 .48743 Mdot
.12288 .48723 Mdot
.12354 .4865 Mdot
.12408 .4859 Mdot
.12421 .48576 Mdot
.12444 .4855 Mdot
.12462 .48531 Mdot
.12482 .48508 Mdot
.12512 .48475 Mdot
.12544 .4844 Mdot
.12572 .48409 Mdot
.126 .48378 Mdot
.12643 .48331 Mdot
.12668 .48303 Mdot
.1272 .48246 Mdot
.12724 .48241 Mdot
.12772 .48189 Mdot
.12792 .48167 Mdot
.12824 .48132 Mdot
.12843 .48111 Mdot
.12895 .48053 Mdot
.12935 .48009 Mdot
.12985 .47954 Mdot
.13027 .47908 Mdot
.13067 .47864 Mdot
.13079 .47851 Mdot
.13105 .47823 Mdot
.13122 .47804 Mdot
.13176 .47745 Mdot
.13212 .47705 Mdot
.13247 .47667 Mdot
.13283 .47628 Mdot
.13293 .47617 Mdot
.13312 .47596 Mdot
.13331 .47575 Mdot
.13371 .47531 Mdot
.13419 .47479 Mdot
.13432 .47465 Mdot
.13459 .47436 Mdot
.13494 .47397 Mdot
.13527 .47361 Mdot
.13582 .47301 Mdot
.13587 .47295 Mdot
.13624 .47255 Mdot
.1369 .47183 Mdot
.13705 .47167 Mdot
.13728 .47141 Mdot
.13757 .4711 Mdot
.13818 .47043 Mdot
.1383 .47031 Mdot
.13867 .46991 Mdot
.13899 .46956 Mdot
.1394 .46911 Mdot
.13964 .46885 Mdot
.14 .46846 Mdot
.14028 .46815 Mdot
.14049 .46793 Mdot
.14068 .46772 Mdot
.14109 .46728 Mdot
.14132 .46703 Mdot
.14167 .46665 Mdot
.14184 .46646 Mdot
.14237 .46589 Mdot
.1429 .46532 Mdot
.14303 .46518 Mdot
.14344 .46474 Mdot
.14375 .4644 Mdot
.1444 .4637 Mdot
.14464 .46343 Mdot
.14496 .46309 Mdot
.14527 .46276 Mdot
.14541 .4626 Mdot
.14569 .46231 Mdot
.14604 .46193 Mdot
.14647 .46147 Mdot
.14675 .46116 Mdot
.14728 .46059 Mdot
.14754 .46031 Mdot
.14779 .46004 Mdot
.1481 .45972 Mdot
.14847 .45932 Mdot
.14868 .45909 Mdot
.14913 .45861 Mdot
.14922 .45851 Mdot
.14952 .45819 Mdot
.14999 .45768 Mdot
.15028 .45737 Mdot
.15052 .45711 Mdot
.15071 .45691 Mdot
.15104 .45655 Mdot
.15148 .45608 Mdot
.15158 .45598 Mdot
.15197 .45556 Mdot
.15275 .45473 Mdot
.1532 .45424 Mdot
.15348 .45395 Mdot
.15376 .45365 Mdot
.15393 .45347 Mdot
.15425 .45313 Mdot
.15482 .45251 Mdot
.1551 .45222 Mdot
.1554 .4519 Mdot
.15577 .4515 Mdot
.15586 .45141 Mdot
.15612 .45114 Mdot
.15653 .4507 Mdot
.15716 .45003 Mdot
.1572 .44999 Mdot
.15761 .44955 Mdot
.15814 .44899 Mdot
.15831 .4488 Mdot
.15877 .44832 Mdot
.15925 .44781 Mdot
.15955 .44749 Mdot
.16002 .44699 Mdot
.16032 .44668 Mdot
.16088 .44608 Mdot
.16111 .44584 Mdot
.1615 .44543 Mdot
.16176 .44515 Mdot
.16184 .44507 Mdot
.16217 .44472 Mdot
.16234 .44454 Mdot
.16266 .44421 Mdot
.16273 .44413 Mdot
.16309 .44375 Mdot
.16333 .4435 Mdot
.16387 .44292 Mdot
.16436 .44241 Mdot
.16444 .44232 Mdot
.1647 .44205 Mdot
.1651 .44163 Mdot
.16545 .44126 Mdot
.16558 .44113 Mdot
.16574 .44096 Mdot
.16664 .44001 Mdot
.16666 .43999 Mdot
.16721 .43941 Mdot
.16733 .43928 Mdot
.16763 .43897 Mdot
.16783 .43876 Mdot
.16816 .43842 Mdot
.16847 .43808 Mdot
.16881 .43773 Mdot
.16884 .4377 Mdot
.16903 .43751 Mdot
.16962 .43689 Mdot
.16972 .43678 Mdot
.17038 .43609 Mdot
.17056 .4359 Mdot
.17084 .43561 Mdot
.17119 .43525 Mdot
.17131 .43512 Mdot
.17167 .43474 Mdot
.17194 .43446 Mdot
.17226 .43413 Mdot
.17249 .43388 Mdot
.1728 .43357 Mdot
.17289 .43347 Mdot
.17325 .43309 Mdot
.17353 .4328 Mdot
.17422 .43208 Mdot
.17444 .43185 Mdot
.17484 .43143 Mdot
.17546 .43079 Mdot
.17576 .43048 Mdot
.17606 .43017 Mdot
.1763 .42992 Mdot
.17675 .42945 Mdot
.17711 .42908 Mdot
.17727 .42892 Mdot
.17751 .42866 Mdot
.17801 .42814 Mdot
.17812 .42803 Mdot
.17862 .42752 Mdot
.17904 .42708 Mdot
.17935 .42676 Mdot
.17982 .42628 Mdot
.17999 .4261 Mdot
.18026 .42582 Mdot
.18053 .42554 Mdot
.18106 .425 Mdot
.18118 .42487 Mdot
.18157 .42447 Mdot
.18206 .42396 Mdot
.18281 .42319 Mdot
.18295 .42305 Mdot
.18334 .42264 Mdot
.1837 .42228 Mdot
.18404 .42192 Mdot
.18433 .42163 Mdot
.18466 .42128 Mdot
.18478 .42116 Mdot
.18504 .4209 Mdot
.18538 .42055 Mdot
.18577 .42015 Mdot
.18605 .41986 Mdot
.18621 .4197 Mdot
.1865 .4194 Mdot
.18678 .41911 Mdot
.18727 .41861 Mdot
.18744 .41843 Mdot
.18766 .41821 Mdot
.18807 .41779 Mdot
.18836 .41749 Mdot
.18872 .41712 Mdot
.18911 .41673 Mdot
.18932 .41652 Mdot
.18937 .41647 Mdot
.18991 .41591 Mdot
.19013 .41569 Mdot
.19029 .41552 Mdot
.19075 .41506 Mdot
.19095 .41485 Mdot
.1915 .41429 Mdot
.19177 .41402 Mdot
.19211 .41367 Mdot
.19276 .41301 Mdot
.19303 .41273 Mdot
.19366 .41209 Mdot
.19385 .4119 Mdot
.19415 .4116 Mdot
.19465 .41109 Mdot
.19493 .4108 Mdot
.19551 .41021 Mdot
.19589 .40983 Mdot
.19613 .40958 Mdot
.19644 .40928 Mdot
.19685 .40886 Mdot
.1972 .40851 Mdot
.19764 .40807 Mdot
.1979 .4078 Mdot
.19822 .40748 Mdot
.19867 .40702 Mdot
.19878 .40691 Mdot
.19905 .40664 Mdot
.19955 .40614 Mdot
.20001 .40567 Mdot
.20035 .40532 Mdot
.20079 .40488 Mdot
.20096 .40471 Mdot
.20148 .40419 Mdot
.20162 .40405 Mdot
.20206 .40361 Mdot
.2024 .40326 Mdot
.20258 .40308 Mdot
.20293 .40273 Mdot
.20324 .40242 Mdot
.20337 .4023 Mdot
.20371 .40195 Mdot
.20443 .40123 Mdot
.20451 .40115 Mdot
.20506 .4006 Mdot
.20511 .40055 Mdot
.20543 .40023 Mdot
.20595 .39971 Mdot
.20611 .39955 Mdot
.2062 .39946 Mdot
.2064 .39926 Mdot
.20697 .39869 Mdot
.20704 .39862 Mdot
.2074 .39826 Mdot
.20765 .39801 Mdot
.20779 .39787 Mdot
.20828 .39738 Mdot
.20849 .39717 Mdot
.20873 .39693 Mdot
.20905 .39661 Mdot
.20924 .39643 Mdot
.20963 .39604 Mdot
.21015 .39552 Mdot
.2104 .39527 Mdot
.21074 .39494 Mdot
.21093 .39475 Mdot
.21139 .39429 Mdot
.21171 .39398 Mdot
.21233 .39336 Mdot
.21267 .39302 Mdot
.21298 .39272 Mdot
.21329 .3924 Mdot
.21349 .39221 Mdot
.21401 .39169 Mdot
.21436 .39135 Mdot
.21473 .39099 Mdot
.2148 .39091 Mdot
.21504 .39067 Mdot
.21563 .39009 Mdot
.21588 .38985 Mdot
.21616 .38957 Mdot
.21658 .38916 Mdot
.21675 .38899 Mdot
.21688 .38886 Mdot
.2171 .38864 Mdot
.21733 .38842 Mdot
.21758 .38817 Mdot
.21785 .38791 Mdot
.2183 .38746 Mdot
.2188 .38697 Mdot
.21916 .38662 Mdot
.21963 .38615 Mdot
.21994 .38585 Mdot
.22032 .38548 Mdot
.22041 .38539 Mdot
.2208 .38501 Mdot
.22116 .38465 Mdot
.22139 .38443 Mdot
.22192 .38391 Mdot
.2222 .38364 Mdot
.22246 .38339 Mdot
.22293 .38292 Mdot
.22351 .38235 Mdot
.22372 .38215 Mdot
.22387 .38201 Mdot
.22412 .38176 Mdot
.22437 .38151 Mdot
.22459 .3813 Mdot
.22483 .38107 Mdot
.22513 .38078 Mdot
.22579 .38013 Mdot
.22593 .38 Mdot
.22626 .37967 Mdot
.22647 .37947 Mdot
.22666 .37929 Mdot
.22708 .37887 Mdot
.22732 .37864 Mdot
.22767 .37831 Mdot
.22819 .3778 Mdot
.2283 .37769 Mdot
.2286 .3774 Mdot
.22882 .37718 Mdot
.22896 .37705 Mdot
.22943 .3766 Mdot
.22958 .37645 Mdot
.22982 .37621 Mdot
.23009 .37596 Mdot
.23078 .37529 Mdot
.23089 .37518 Mdot
.23127 .37481 Mdot
.23171 .37439 Mdot
.23189 .37421 Mdot
.23237 .37375 Mdot
.23267 .37346 Mdot
.23335 .3728 Mdot
.23338 .37278 Mdot
.23385 .37233 Mdot
.23386 .37231 Mdot
.23436 .37183 Mdot
.23451 .37169 Mdot
.23465 .37155 Mdot
.23488 .37133 Mdot
.23518 .37104 Mdot
.23564 .3706 Mdot
.23599 .37027 Mdot
.23626 .37 Mdot
.23665 .36963 Mdot
.23726 .36904 Mdot
.23747 .36885 Mdot
.23795 .36839 Mdot
.2382 .36815 Mdot
.23826 .36808 Mdot
.23851 .36785 Mdot
.23888 .3675 Mdot
.23932 .36707 Mdot
.23992 .3665 Mdot
.24003 .36639 Mdot
.24046 .36599 Mdot
.24072 .36573 Mdot
.24122 .36526 Mdot
.24132 .36516 Mdot
.24161 .36489 Mdot
.24181 .36469 Mdot
.24199 .36453 Mdot
.24235 .36418 Mdot
.24243 .36411 Mdot
.24281 .36375 Mdot
.24338 .3632 Mdot
.24363 .36296 Mdot
.2438 .3628 Mdot
.24427 .36236 Mdot
.24485 .36181 Mdot
.24526 .36141 Mdot
.2454 .36128 Mdot
.24569 .36101 Mdot
.24606 .36065 Mdot
.24653 .36021 Mdot
.24673 .36002 Mdot
.24702 .35974 Mdot
.24724 .35954 Mdot
.2474 .35939 Mdot
.24786 .35896 Mdot
.24794 .35888 Mdot
.24853 .35832 Mdot
.24874 .35812 Mdot
.24922 .35767 Mdot
.2497 .35722 Mdot
.24987 .35706 Mdot
.25015 .35679 Mdot
.25052 .35645 Mdot
.25114 .35586 Mdot
.25158 .35545 Mdot
.25161 .35542 Mdot
.25204 .35502 Mdot
.25253 .35455 Mdot
.25276 .35434 Mdot
.25302 .35409 Mdot
.25343 .35371 Mdot
.25369 .35346 Mdot
.2544 .3528 Mdot
.25458 .35263 Mdot
.25503 .35221 Mdot
.25532 .35194 Mdot
.25585 .35144 Mdot
.25648 .35085 Mdot
.25678 .35057 Mdot
.25695 .35042 Mdot
.25732 .35006 Mdot
.25747 .34993 Mdot
.25758 .34982 Mdot
.25788 .34954 Mdot
.25814 .3493 Mdot
.25832 .34914 Mdot
.25881 .34868 Mdot
.25905 .34845 Mdot
.25931 .34821 Mdot
.25959 .34796 Mdot
.2602 .34739 Mdot
.26054 .34707 Mdot
.26098 .34666 Mdot
.26101 .34663 Mdot
.26157 .34612 Mdot
.26172 .34597 Mdot
.26233 .34541 Mdot
.26253 .34522 Mdot
.26268 .34508 Mdot
.26286 .34492 Mdot
.26338 .34444 Mdot
.26388 .34397 Mdot
.26417 .34371 Mdot
.2645 .34341 Mdot
.26478 .34315 Mdot
.26495 .34299 Mdot
.26531 .34265 Mdot
.26566 .34234 Mdot
.266 .34202 Mdot
.26643 .34163 Mdot
.26662 .34145 Mdot
.26729 .34083 Mdot
.2676 .34055 Mdot
.26781 .34035 Mdot
.26806 .34012 Mdot
.26845 .33977 Mdot
.26876 .33948 Mdot
.26889 .33936 Mdot
.26923 .33905 Mdot
.26943 .33887 Mdot
.26985 .33848 Mdot
.27022 .33814 Mdot
.2704 .33797 Mdot
.2707 .3377 Mdot
.27112 .33732 Mdot
.27157 .33691 Mdot
.27185 .33665 Mdot
.27213 .33639 Mdot
.27264 .33593 Mdot
.2731 .3355 Mdot
.27327 .33535 Mdot
.27349 .33515 Mdot
.27397 .33472 Mdot
.27448 .33425 Mdot
.27452 .33421 Mdot
.27493 .33384 Mdot
.27529 .33352 Mdot
.27546 .33336 Mdot
.27584 .33301 Mdot
.27623 .33266 Mdot
.27664 .33229 Mdot
.27719 .33179 Mdot
.2775 .33151 Mdot
.27772 .3313 Mdot
.27829 .33079 Mdot
.27836 .33073 Mdot
.27863 .33048 Mdot
.27874 .33038 Mdot
.27913 .33003 Mdot
.27947 .32972 Mdot
.28008 .32917 Mdot
.28034 .32894 Mdot
.28084 .32848 Mdot
.28119 .32817 Mdot
.28159 .32781 Mdot
.28188 .32755 Mdot
.28225 .32721 Mdot
.28264 .32686 Mdot
.28284 .32668 Mdot
.28334 .32623 Mdot
.28363 .32597 Mdot
.28375 .32586 Mdot
.28411 .32554 Mdot
.28453 .32516 Mdot
.28477 .32494 Mdot
.28486 .32486 Mdot
.28514 .32462 Mdot
.28535 .32442 Mdot
.28594 .3239 Mdot
.28602 .32382 Mdot
.28647 .32343 Mdot
.2867 .32321 Mdot
.28712 .32284 Mdot
.28748 .32252 Mdot
.28767 .32235 Mdot
.28823 .32185 Mdot
.28863 .32149 Mdot
.28879 .32135 Mdot
.28891 .32125 Mdot
.28917 .32101 Mdot
.28939 .32081 Mdot
.28956 .32066 Mdot
.28993 .32034 Mdot
.29031 .32 Mdot
.29064 .31971 Mdot
.29108 .31931 Mdot
.29152 .31892 Mdot
.29175 .31872 Mdot
.29219 .31832 Mdot
.29239 .31814 Mdot
.29292 .31768 Mdot
.29337 .31728 Mdot
.29372 .31697 Mdot
.29431 .31644 Mdot
.29443 .31633 Mdot
.29468 .31612 Mdot
.29484 .31598 Mdot
.29542 .31546 Mdot
.29576 .31516 Mdot
.296 .31495 Mdot
.29619 .31478 Mdot
.29653 .31448 Mdot
.297 .31407 Mdot
.29737 .31374 Mdot
.29752 .31361 Mdot
.29809 .31311 Mdot
.29827 .31295 Mdot
.29865 .31261 Mdot
.29875 .31253 Mdot
.29907 .31225 Mdot
.29945 .31191 Mdot
.29958 .3118 Mdot
.3 .31143 Mdot
.30032 .31115 Mdot
.30045 .31103 Mdot
.30086 .31068 Mdot
.30108 .31048 Mdot
.30165 .30998 Mdot
.30193 .30974 Mdot
.30221 .30949 Mdot
.30245 .30929 Mdot
.30283 .30895 Mdot
.30287 .30892 Mdot
.30344 .30842 Mdot
.30403 .30791 Mdot
.30422 .30774 Mdot
.30437 .30761 Mdot
.30468 .30734 Mdot
.30493 .30712 Mdot
.30529 .3068 Mdot
.30539 .30672 Mdot
.3056 .30653 Mdot
.30595 .30623 Mdot
.30634 .30589 Mdot
.30643 .30581 Mdot
.30706 .30527 Mdot
.30725 .3051 Mdot
.30737 .305 Mdot
.30788 .30456 Mdot
.30796 .30448 Mdot
.30832 .30417 Mdot
.30852 .304 Mdot
.30874 .30381 Mdot
.30927 .30335 Mdot
.30971 .30297 Mdot
.30991 .3028 Mdot
.31014 .3026 Mdot
.31044 .30234 Mdot
.31072 .3021 Mdot
.31098 .30187 Mdot
.31135 .30155 Mdot
.31164 .3013 Mdot
.31209 .30092 Mdot
.31258 .30049 Mdot
.31275 .30034 Mdot
.31301 .30012 Mdot
.31323 .29994 Mdot
.31346 .29973 Mdot
.31372 .29952 Mdot
.31396 .2993 Mdot
.31425 .29905 Mdot
.31465 .29871 Mdot
.31473 .29865 Mdot
.31505 .29837 Mdot
.31539 .29808 Mdot
.31558 .29792 Mdot
.31568 .29783 Mdot
.31607 .2975 Mdot
.31622 .29737 Mdot
.31654 .29709 Mdot
.3171 .29661 Mdot
.31722 .29651 Mdot
.31744 .29632 Mdot
.31788 .29595 Mdot
.31809 .29577 Mdot
.31837 .29553 Mdot
.31878 .29518 Mdot
.31904 .29495 Mdot
.31962 .29446 Mdot
.31967 .29442 Mdot
.3202 .29397 Mdot
.32052 .2937 Mdot
.32095 .29333 Mdot
.32119 .29313 Mdot
.32128 .29305 Mdot
.32164 .29274 Mdot
.32189 .29253 Mdot
.32216 .2923 Mdot
.32231 .29217 Mdot
.32261 .29192 Mdot
.32313 .29148 Mdot
.32335 .2913 Mdot
.3237 .291 Mdot
.32412 .29064 Mdot
.32436 .29044 Mdot
.32482 .29005 Mdot
.32515 .28977 Mdot
.32525 .28968 Mdot
.32543 .28953 Mdot
.3257 .2893 Mdot
.32582 .2892 Mdot
.32627 .28883 Mdot
.32638 .28873 Mdot
.32676 .28841 Mdot
.32714 .28809 Mdot
.32743 .28785 Mdot
.32795 .28741 Mdot
.32839 .28703 Mdot
.32857 .28689 Mdot
.32896 .28656 Mdot
.32934 .28624 Mdot
.32962 .28601 Mdot
.32968 .28596 Mdot
.33021 .28551 Mdot
.3305 .28527 Mdot
.33082 .285 Mdot
.33114 .28473 Mdot
.33143 .28449 Mdot
.33181 .28417 Mdot
.33223 .28382 Mdot
.33272 .28341 Mdot
.33284 .28331 Mdot
.33321 .283 Mdot
.33342 .28282 Mdot
.33401 .28233 Mdot
.33433 .28207 Mdot
.33475 .28171 Mdot
.33519 .28135 Mdot
.33527 .28128 Mdot
.33553 .28107 Mdot
.33589 .28077 Mdot
.33617 .28053 Mdot
.33663 .28015 Mdot
.33674 .28007 Mdot
.33689 .27994 Mdot
.33734 .27957 Mdot
.33786 .27914 Mdot
.33789 .27911 Mdot
.33835 .27873 Mdot
.33877 .27838 Mdot
.33882 .27834 Mdot
.33927 .27797 Mdot
.33947 .2778 Mdot
.3397 .27761 Mdot
.34012 .27726 Mdot
.34051 .27694 Mdot
.34082 .27669 Mdot
.34118 .27639 Mdot
.34128 .2763 Mdot
.34154 .2761 Mdot
.34203 .27569 Mdot
.34248 .27532 Mdot
.34249 .27531 Mdot
.34273 .27511 Mdot
.34324 .2747 Mdot
.34341 .27456 Mdot
.34348 .2745 Mdot
.34375 .27428 Mdot
.34413 .27396 Mdot
.34437 .27377 Mdot
.34474 .27346 Mdot
.34506 .27321 Mdot
.34534 .27297 Mdot
.34544 .27289 Mdot
.34558 .27277 Mdot
.34601 .27242 Mdot
.34649 .27204 Mdot
.34657 .27197 Mdot
.34714 .2715 Mdot
.34727 .2714 Mdot
.34766 .27108 Mdot
.34795 .27084 Mdot
.3483 .27055 Mdot
.34869 .27024 Mdot
.34892 .27005 Mdot
.34925 .26978 Mdot
.34962 .26948 Mdot
.34988 .26927 Mdot
.35009 .2691 Mdot
.35032 .26891 Mdot
.35055 .26872 Mdot
.35088 .26846 Mdot
.35107 .2683 Mdot
.35121 .26819 Mdot
.3516 .26787 Mdot
.35198 .26756 Mdot
.35211 .26746 Mdot
.35257 .26709 Mdot
.35293 .26679 Mdot
.35316 .26661 Mdot
.35353 .26631 Mdot
.35377 .26612 Mdot
.35413 .26582 Mdot
.35477 .26531 Mdot
.35478 .2653 Mdot
.35566 .26459 Mdot
.3559 .2644 Mdot
.35598 .26433 Mdot
.35631 .26407 Mdot
.3566 .26383 Mdot
.35689 .2636 Mdot
.35727 .2633 Mdot
.35741 .26318 Mdot
.35784 .26284 Mdot
.35839 .2624 Mdot
.35871 .26214 Mdot
.35899 .26192 Mdot
.35957 .26145 Mdot
.35987 .26121 Mdot
.36016 .26098 Mdot
.36057 .26065 Mdot
.36103 .26028 Mdot
.36116 .26018 Mdot
.36144 .25996 Mdot
.36161 .25982 Mdot
.36228 .25929 Mdot
.36248 .25913 Mdot
.36253 .25909 Mdot
.36273 .25893 Mdot
.36299 .25873 Mdot
.36358 .25825 Mdot
.36399 .25793 Mdot
.36414 .25781 Mdot
.36438 .25762 Mdot
.36486 .25723 Mdot
.3652 .25697 Mdot
.36558 .25667 Mdot
.3658 .25649 Mdot
.36619 .25618 Mdot
.36653 .25592 Mdot
.36706 .25549 Mdot
.36717 .25541 Mdot
.36779 .25492 Mdot
.36786 .25486 Mdot
.36825 .25455 Mdot
.36855 .25432 Mdot
.36908 .2539 Mdot
.36925 .25377 Mdot
.36958 .25351 Mdot
.36989 .25327 Mdot
.37042 .25285 Mdot
.37067 .25265 Mdot
.37074 .2526 Mdot
.37096 .25242 Mdot
.37153 .25197 Mdot
.37161 .25191 Mdot
.37223 .25142 Mdot
.37276 .25101 Mdot
.3729 .2509 Mdot
.37344 .25048 Mdot
.37372 .25026 Mdot
.37414 .24993 Mdot
.37442 .24971 Mdot
.3746 .24957 Mdot
.37523 .24908 Mdot
.37565 .24876 Mdot
.37589 .24857 Mdot
.37595 .24852 Mdot
.37622 .24831 Mdot
.37647 .24812 Mdot
.37664 .24798 Mdot
.37692 .24777 Mdot
.37738 .24741 Mdot
.37784 .24705 Mdot
.3783 .24669 Mdot
.37859 .24647 Mdot
.37922 .24598 Mdot
.37929 .24592 Mdot
.37956 .24571 Mdot
.37968 .24562 Mdot
.38035 .2451 Mdot
.38039 .24507 Mdot
.38065 .24487 Mdot
.38087 .2447 Mdot
.38105 .24457 Mdot
.38128 .24439 Mdot
.38179 .24399 Mdot
.38197 .24386 Mdot
.38239 .24353 Mdot
.38269 .2433 Mdot
.3832 .2429 Mdot
.38354 .24264 Mdot
.38378 .24246 Mdot
.38401 .24229 Mdot
.38421 .24213 Mdot
.38452 .24189 Mdot
.38486 .24163 Mdot
.38503 .2415 Mdot
.38563 .24104 Mdot
.38582 .24089 Mdot
.38614 .24065 Mdot
.38661 .24029 Mdot
.38685 .2401 Mdot
.38694 .24004 Mdot
.38751 .2396 Mdot
.3879 .2393 Mdot
.38804 .23919 Mdot
.3884 .23892 Mdot
.3886 .23877 Mdot
.38883 .23859 Mdot
.38911 .23838 Mdot
.38927 .23826 Mdot
.38942 .23814 Mdot
.38984 .23782 Mdot
.39013 .2376 Mdot
.39079 .2371 Mdot
.39096 .23697 Mdot
.39128 .23673 Mdot
.39157 .23651 Mdot
.39169 .23642 Mdot
.39224 .236 Mdot
.39248 .23582 Mdot
.39265 .23569 Mdot
.3935 .23505 Mdot
.39397 .2347 Mdot
.39414 .23456 Mdot
.39435 .23441 Mdot
.39479 .23407 Mdot
.39487 .23402 Mdot
.39543 .23359 Mdot
.39581 .2333 Mdot
.39587 .23326 Mdot
.39637 .23288 Mdot
.39656 .23274 Mdot
.39674 .2326 Mdot
.39713 .23231 Mdot
.39745 .23207 Mdot
.39804 .23163 Mdot
.39848 .23129 Mdot
.39871 .23113 Mdot
.39914 .2308 Mdot
.39922 .23074 Mdot
.39981 .2303 Mdot
.39984 .23028 Mdot
.40034 .2299 Mdot
.40047 .22981 Mdot
.40086 .22952 Mdot
.40097 .22944 Mdot
.40126 .22922 Mdot
.40164 .22894 Mdot
.40187 .22876 Mdot
.40218 .22853 Mdot
.40233 .22842 Mdot
.40274 .22811 Mdot
.40321 .22776 Mdot
.40342 .22761 Mdot
.40378 .22734 Mdot
.40418 .22704 Mdot
.40444 .22685 Mdot
.40461 .22672 Mdot
.40488 .22652 Mdot
.40514 .22633 Mdot
.4059 .22577 Mdot
.40616 .22557 Mdot
.4064 .2254 Mdot
.40651 .22531 Mdot
.40703 .22493 Mdot
.40735 .2247 Mdot
.40762 .2245 Mdot
.40781 .22436 Mdot
.40834 .22397 Mdot
.40847 .22387 Mdot
.40882 .22361 Mdot
.40916 .22337 Mdot
.40929 .22326 Mdot
.40945 .22315 Mdot
.40997 .22277 Mdot
.41026 .22256 Mdot
.41076 .22218 Mdot
.41102 .22199 Mdot
.41124 .22184 Mdot
.41155 .22161 Mdot
.41175 .22146 Mdot
.41207 .22122 Mdot
.41234 .22103 Mdot
.41273 .22074 Mdot
.41307 .2205 Mdot
.41336 .22028 Mdot
.41355 .22014 Mdot
.41372 .22002 Mdot
.41421 .21966 Mdot
.41443 .2195 Mdot
.41479 .21924 Mdot
.41532 .21885 Mdot
.41546 .21875 Mdot
.41568 .21859 Mdot
.41611 .21828 Mdot
.41626 .21817 Mdot
.41658 .21794 Mdot
.41709 .21757 Mdot
.41728 .21743 Mdot
.41785 .21702 Mdot
.41824 .21674 Mdot
.41865 .21644 Mdot
.41877 .21635 Mdot
.41904 .21616 Mdot
.41962 .21574 Mdot
.42001 .21545 Mdot
.42051 .2151 Mdot
.42078 .2149 Mdot
.42127 .21455 Mdot
.42145 .21442 Mdot
.4219 .21409 Mdot
.42223 .21385 Mdot
.4223 .21381 Mdot
.42289 .21338 Mdot
.42296 .21333 Mdot
.42328 .2131 Mdot
.42339 .21303 Mdot
.42358 .21288 Mdot
.42394 .21263 Mdot
.42433 .21235 Mdot
.42478 .21202 Mdot
.42486 .21197 Mdot
.42502 .21186 Mdot
.42545 .21155 Mdot
.4256 .21144 Mdot
.42596 .21118 Mdot
.4266 .21073 Mdot
.42685 .21055 Mdot
.42693 .21049 Mdot
.42734 .2102 Mdot
.42779 .20988 Mdot
.42821 .20958 Mdot
.42842 .20943 Mdot
.42903 .209 Mdot
.42927 .20883 Mdot
.42968 .20853 Mdot
.42995 .20834 Mdot
.43059 .20789 Mdot
.43067 .20783 Mdot
.43118 .20747 Mdot
.43162 .20716 Mdot
.43206 .20685 Mdot
.43234 .20665 Mdot
.43243 .20659 Mdot
.43301 .20618 Mdot
.43324 .20602 Mdot
.43373 .20568 Mdot
.43399 .20549 Mdot
.43444 .20517 Mdot
.43519 .20465 Mdot
.43532 .20455 Mdot
.43545 .20446 Mdot
.43568 .2043 Mdot
.43625 .2039 Mdot
.43649 .20373 Mdot
.43705 .20334 Mdot
.43729 .20317 Mdot
.43744 .20307 Mdot
.43779 .20283 Mdot
.4379 .20275 Mdot
.43818 .20255 Mdot
.43857 .20228 Mdot
.43875 .20215 Mdot
.43902 .20196 Mdot
.43912 .20189 Mdot
.43991 .20135 Mdot
.44026 .20111 Mdot
.44055 .2009 Mdot
.44074 .20077 Mdot
.44101 .20058 Mdot
.44126 .20041 Mdot
.44162 .20016 Mdot
.44191 .19996 Mdot
.44209 .19983 Mdot
.44249 .19956 Mdot
.44269 .19942 Mdot
.44334 .19897 Mdot
.4437 .19872 Mdot
.44383 .19863 Mdot
.44406 .19847 Mdot
.44444 .19821 Mdot
.44457 .19812 Mdot
.44498 .19783 Mdot
.44521 .19768 Mdot
.44594 .19717 Mdot
.44606 .19709 Mdot
.44661 .19672 Mdot
.44677 .1966 Mdot
.4471 .19637 Mdot
.44722 .19629 Mdot
.44758 .19605 Mdot
.44788 .19584 Mdot
.4483 .19555 Mdot
.44862 .19533 Mdot
.44883 .19519 Mdot
.44901 .19507 Mdot
.44958 .19468 Mdot
.44965 .19463 Mdot
.45007 .19434 Mdot
.45015 .19429 Mdot
.45048 .19406 Mdot
.45065 .19394 Mdot
.45109 .19364 Mdot
.4514 .19343 Mdot
.45162 .19328 Mdot
.45211 .19295 Mdot
.45235 .19279 Mdot
.45257 .19264 Mdot
.45292 .1924 Mdot
.45327 .19216 Mdot
.45369 .19188 Mdot
.45376 .19183 Mdot
.4541 .1916 Mdot
.45441 .19139 Mdot
.45503 .19097 Mdot
.45516 .19089 Mdot
.45567 .19054 Mdot
.45591 .19038 Mdot
.45613 .19023 Mdot
.45636 .19007 Mdot
.45695 .18968 Mdot
.45707 .1896 Mdot
.45744 .18934 Mdot
.45766 .18919 Mdot
.45808 .18891 Mdot
.45822 .18882 Mdot
.45851 .18862 Mdot
.45889 .18837 Mdot
.45913 .18821 Mdot
.45956 .18792 Mdot
.45995 .18766 Mdot
.46041 .18735 Mdot
.46087 .18705 Mdot
.46122 .18681 Mdot
.4615 .18662 Mdot
.46194 .18633 Mdot
.46208 .18624 Mdot
.46229 .1861 Mdot
.46268 .18584 Mdot
.46295 .18566 Mdot
.46322 .18548 Mdot
.46371 .18515 Mdot
.46383 .18507 Mdot
.46414 .18486 Mdot
.46445 .18466 Mdot
.46468 .1845 Mdot
.46511 .18422 Mdot
.46537 .18405 Mdot
.46583 .18374 Mdot
.46594 .18367 Mdot
.46661 .18322 Mdot
.46722 .18283 Mdot
.4674 .18271 Mdot
.46767 .18253 Mdot
.46777 .18246 Mdot
.46806 .18227 Mdot
.46851 .18197 Mdot
.46865 .18188 Mdot
.46899 .18166 Mdot
.46911 .18157 Mdot
.46951 .18131 Mdot
.46984 .1811 Mdot
.46994 .18103 Mdot
.47036 .18076 Mdot
.47056 .18062 Mdot
.4708 .18046 Mdot
.47119 .18021 Mdot
.47136 .1801 Mdot
.47189 .17975 Mdot
.47198 .17969 Mdot
.4726 .17929 Mdot
.47283 .17914 Mdot
.47321 .17889 Mdot
.47336 .17879 Mdot
.47343 .17875 Mdot
.47385 .17847 Mdot
.47399 .17838 Mdot
.47412 .17829 Mdot
.47495 .17776 Mdot
.4751 .17766 Mdot
.47541 .17746 Mdot
.47588 .17715 Mdot
.47599 .17708 Mdot
.47639 .17682 Mdot
.47664 .17666 Mdot
.47688 .1765 Mdot
.47715 .17632 Mdot
.47776 .17593 Mdot
.47802 .17577 Mdot
.47816 .17567 Mdot
.47844 .17549 Mdot
.47885 .17523 Mdot
.47897 .17515 Mdot
.47938 .17488 Mdot
.4797 .17468 Mdot
.47977 .17464 Mdot
.4801 .17442 Mdot
.48064 .17408 Mdot
.4808 .17397 Mdot
.48101 .17384 Mdot
.4817 .17339 Mdot
.48193 .17324 Mdot
.48219 .17308 Mdot
.48252 .17287 Mdot
.48274 .17273 Mdot
.48322 .17242 Mdot
.48329 .17237 Mdot
.48366 .17214 Mdot
.48394 .17196 Mdot
.48439 .17167 Mdot
.48463 .17152 Mdot
.48532 .17108 Mdot
.48555 .17093 Mdot
.48601 .17064 Mdot
.48634 .17043 Mdot
.48673 .17018 Mdot
.48722 .16987 Mdot
.48769 .16957 Mdot
.48791 .16943 Mdot
.4881 .16931 Mdot
.48848 .16907 Mdot
.48902 .16873 Mdot
.48923 .1686 Mdot
.48963 .16835 Mdot
.48979 .16825 Mdot
.49033 .1679 Mdot
.49041 .16785 Mdot
.49071 .16766 Mdot
.49089 .16755 Mdot
.49103 .16746 Mdot
.49152 .16716 Mdot
.49173 .16702 Mdot
.4921 .16679 Mdot
.4923 .16666 Mdot
.49278 .16636 Mdot
.49294 .16626 Mdot
.49311 .16616 Mdot
.49364 .16582 Mdot
.49388 .16567 Mdot
.49416 .1655 Mdot
.4945 .16529 Mdot
.49458 .16524 Mdot
.49522 .16484 Mdot
.49528 .1648 Mdot
.49565 .16457 Mdot
.49581 .16446 Mdot
.49621 .16422 Mdot
.49655 .164 Mdot
.49691 .16378 Mdot
.49726 .16356 Mdot
.49784 .16321 Mdot
.49822 .16297 Mdot
.49853 .16278 Mdot
.49868 .16269 Mdot
.49904 .16246 Mdot
.49957 .16213 Mdot
.49985 .16196 Mdot
.50031 .16167 Mdot
.50048 .16157 Mdot
.50122 .16112 Mdot
.50163 .16086 Mdot
.5018 .16075 Mdot
.50193 .16068 Mdot
.50219 .16052 Mdot
.50234 .16042 Mdot
.50285 .16011 Mdot
.50316 .15992 Mdot
.5035 .15971 Mdot
.50394 .15944 Mdot
.50426 .15925 Mdot
.50453 .15908 Mdot
.50468 .15899 Mdot
.50492 .15884 Mdot
.50506 .15875 Mdot
.5054 .15855 Mdot
.50559 .15843 Mdot
.50598 .15819 Mdot
.50637 .15795 Mdot
.50668 .15777 Mdot
.50715 .15748 Mdot
.50729 .1574 Mdot
.50755 .15724 Mdot
.5079 .15702 Mdot
.5084 .15672 Mdot
.50858 .15661 Mdot
.50891 .15641 Mdot
.50925 .1562 Mdot
.50935 .15614 Mdot
.5097 .15593 Mdot
.51017 .15565 Mdot
.51027 .15559 Mdot
.51078 .15528 Mdot
.511 .15514 Mdot
.51116 .15505 Mdot
.51165 .15475 Mdot
.51186 .15463 Mdot
.51205 .15451 Mdot
.51215 .15445 Mdot
.51297 .15396 Mdot
.51312 .15387 Mdot
.5134 .1537 Mdot
.51372 .15351 Mdot
.51422 .15321 Mdot
.51479 .15287 Mdot
.51524 .1526 Mdot
.51543 .15248 Mdot
.51578 .15228 Mdot
.51619 .15203 Mdot
.51659 .15179 Mdot
.51694 .15158 Mdot
.51751 .15124 Mdot
.51768 .15114 Mdot
.51792 .151 Mdot
.51823 .15081 Mdot
.51848 .15067 Mdot
.51865 .15057 Mdot
.51878 .15049 Mdot
.51897 .15038 Mdot
.51925 .15021 Mdot
.5196 .15 Mdot
.52013 .14969 Mdot
.52029 .14959 Mdot
.52057 .14943 Mdot
.5209 .14923 Mdot
.52116 .14908 Mdot
.52133 .14898 Mdot
.52166 .14879 Mdot
.52192 .14863 Mdot
.52232 .1484 Mdot
.52249 .1483 Mdot
.52277 .14813 Mdot
.52318 .14789 Mdot
.52339 .14777 Mdot
.52356 .14766 Mdot
.52413 .14733 Mdot
.52444 .14715 Mdot
.52463 .14704 Mdot
.52523 .14668 Mdot
.52562 .14646 Mdot
.52602 .14623 Mdot
.52658 .1459 Mdot
.52675 .1458 Mdot
.52698 .14567 Mdot
.52724 .14551 Mdot
.52792 .14512 Mdot
.52797 .14509 Mdot
.52854 .14476 Mdot
.5287 .14466 Mdot
.5289 .14455 Mdot
.52929 .14432 Mdot
.52972 .14407 Mdot
.52991 .14396 Mdot
.53031 .14373 Mdot
.53063 .14355 Mdot
.53101 .14332 Mdot
.53129 .14316 Mdot
.53139 .14311 Mdot
.53172 .14292 Mdot
.53207 .14271 Mdot
.53245 .14249 Mdot
.53255 .14243 Mdot
.53296 .1422 Mdot
.53329 .14201 Mdot
.53346 .14191 Mdot
.53378 .14173 Mdot
.53423 .14147 Mdot
.53461 .14125 Mdot
.53511 .14097 Mdot
.53532 .14085 Mdot
.53578 .14058 Mdot
.53623 .14033 Mdot
.53651 .14017 Mdot
.53666 .14008 Mdot
.53715 .1398 Mdot
.53757 .13956 Mdot
.53802 .13931 Mdot
.53815 .13923 Mdot
.53825 .13918 Mdot
.53865 .13895 Mdot
.53871 .13891 Mdot
.53901 .13874 Mdot
.53949 .13847 Mdot
.53984 .13828 Mdot
.54023 .13805 Mdot
.54055 .13787 Mdot
.54098 .13763 Mdot
.54116 .13753 Mdot
.54127 .13746 Mdot
.54196 .13707 Mdot
.54213 .13698 Mdot
.5424 .13683 Mdot
.54263 .1367 Mdot
.54286 .13657 Mdot
.54319 .13638 Mdot
.54323 .13636 Mdot
.54358 .13616 Mdot
.54391 .13598 Mdot
.54428 .13577 Mdot
.5447 .13553 Mdot
.54495 .1354 Mdot
.54559 .13504 Mdot
.54578 .13493 Mdot
.54616 .13472 Mdot
.54625 .13467 Mdot
.54683 .13435 Mdot
.54718 .13415 Mdot
.54726 .13411 Mdot
.5478 .1338 Mdot
.54816 .13361 Mdot
.54867 .13332 Mdot
.54874 .13329 Mdot
.54905 .13311 Mdot
.54943 .1329 Mdot
.54974 .13273 Mdot
.54994 .13262 Mdot
.55042 .13236 Mdot
.55049 .13231 Mdot
.55115 .13195 Mdot
.55149 .13177 Mdot
.55193 .13152 Mdot
.55212 .13142 Mdot
.55224 .13135 Mdot
.55244 .13124 Mdot
.55311 .13087 Mdot
.55321 .13082 Mdot
.55397 .1304 Mdot
.55412 .13032 Mdot
.55464 .13003 Mdot
.55486 .12991 Mdot
.55503 .12982 Mdot
.55545 .12959 Mdot
.55577 .12942 Mdot
.55595 .12932 Mdot
.55622 .12917 Mdot
.55644 .12905 Mdot
.55712 .12868 Mdot
.55735 .12856 Mdot
.55758 .12843 Mdot
.55778 .12832 Mdot
.55809 .12815 Mdot
.55828 .12805 Mdot
.55872 .12781 Mdot
.55908 .12762 Mdot
.55918 .12757 Mdot
.55969 .12729 Mdot
.55991 .12717 Mdot
.56032 .12695 Mdot
.56059 .1268 Mdot
.56117 .12649 Mdot
.56149 .12632 Mdot
.56171 .1262 Mdot
.56217 .12595 Mdot
.56244 .12581 Mdot
.56281 .12561 Mdot
.56319 .12541 Mdot
.56337 .12531 Mdot
.5639 .12502 Mdot
.56395 .125 Mdot
.56448 .12472 Mdot
.5647 .12459 Mdot
.56511 .12438 Mdot
.56561 .12411 Mdot
.56586 .12398 Mdot
.5664 .12369 Mdot
.56679 .12348 Mdot
.56698 .12338 Mdot
.56713 .1233 Mdot
.56734 .12319 Mdot
.56754 .12309 Mdot
.56788 .12291 Mdot
.56817 .12275 Mdot
.56827 .1227 Mdot
.56877 .12244 Mdot
.56919 .12221 Mdot
.56953 .12203 Mdot
.56993 .12182 Mdot
.57016 .1217 Mdot
.5704 .12157 Mdot
.57077 .12138 Mdot
.57098 .12127 Mdot
.57131 .1211 Mdot
.57149 .121 Mdot
.57174 .12087 Mdot
.57194 .12076 Mdot
.57244 .1205 Mdot
.57297 .12023 Mdot
.57305 .12018 Mdot
.57344 .11998 Mdot
.57359 .1199 Mdot
.57375 .11982 Mdot
.5742 .11958 Mdot
.57438 .11949 Mdot
.57483 .11925 Mdot
.57536 .11897 Mdot
.57553 .11889 Mdot
.57557 .11887 Mdot
.57612 .11858 Mdot
.57624 .11852 Mdot
.57647 .1184 Mdot
.57681 .11822 Mdot
.57715 .11805 Mdot
.57764 .11779 Mdot
.57799 .11761 Mdot
.57819 .11751 Mdot
.57858 .11731 Mdot
.57874 .11722 Mdot
.57901 .11709 Mdot
.57925 .11696 Mdot
.57958 .11679 Mdot
.57984 .11666 Mdot
.58003 .11656 Mdot
.58028 .11643 Mdot
.58039 .11638 Mdot
.58073 .1162 Mdot
.58107 .11603 Mdot
.58117 .11598 Mdot
.58161 .11575 Mdot
.58181 .11565 Mdot
.58222 .11544 Mdot
.58245 .11532 Mdot
.58297 .11505 Mdot
.58302 .11503 Mdot
.58325 .11491 Mdot
.58383 .11461 Mdot
.58426 .1144 Mdot
.58451 .11427 Mdot
.58495 .11405 Mdot
.58533 .11385 Mdot
.58575 .11364 Mdot
.58601 .11351 Mdot
.58606 .11348 Mdot
.58635 .11334 Mdot
.58658 .11322 Mdot
.58687 .11307 Mdot
.58757 .11272 Mdot
.58765 .11268 Mdot
.58793 .11254 Mdot
.58824 .11239 Mdot
.58839 .11231 Mdot
.58915 .11192 Mdot
.58942 .11179 Mdot
.58976 .11162 Mdot
.59031 .11134 Mdot
.59065 .11117 Mdot
.59092 .11104 Mdot
.59113 .11093 Mdot
.59151 .11075 Mdot
.59169 .11066 Mdot
.59198 .11051 Mdot
.59233 .11034 Mdot
.59258 .11021 Mdot
.59293 .11004 Mdot
.59302 .10999 Mdot
.59327 .10987 Mdot
.59387 .10957 Mdot
.59401 .1095 Mdot
.59443 .10929 Mdot
.59458 .10922 Mdot
.59462 .1092 Mdot
.59492 .10905 Mdot
.59537 .10882 Mdot
.59601 .10851 Mdot
.59631 .10836 Mdot
.59647 .10828 Mdot
.59691 .10807 Mdot
.59714 .10796 Mdot
.5978 .10763 Mdot
.59789 .10759 Mdot
.59844 .10731 Mdot
.5987 .10719 Mdot
.59883 .10713 Mdot
.59902 .10703 Mdot
.59954 .10678 Mdot
.60004 .10653 Mdot
.60013 .10649 Mdot
.60035 .10638 Mdot
.60086 .10613 Mdot
.6012 .10597 Mdot
.60141 .10586 Mdot
.60217 .1055 Mdot
.60247 .10535 Mdot
.6026 .10529 Mdot
.60288 .10515 Mdot
.60335 .10493 Mdot
.60355 .10482 Mdot
.60391 .10465 Mdot
.60421 .10451 Mdot
.60453 .10435 Mdot
.60495 .10415 Mdot
.60527 .104 Mdot
.60553 .10387 Mdot
.60574 .10377 Mdot
.6063 .1035 Mdot
.60639 .10346 Mdot
.60695 .10319 Mdot
.60721 .10307 Mdot
.60756 .1029 Mdot
.60792 .10273 Mdot
.60827 .10256 Mdot
.60844 .10248 Mdot
.60867 .10237 Mdot
.609 .10221 Mdot
.60949 .10198 Mdot
.60977 .10184 Mdot
.60991 .10178 Mdot
.61004 .10171 Mdot
.6105 .1015 Mdot
.61084 .10134 Mdot
.61126 .10113 Mdot
.61177 .10089 Mdot
.61194 .10081 Mdot
.61235 .10062 Mdot
.61281 .1004 Mdot
.61289 .10037 Mdot
.61322 .10021 Mdot
.61371 .09998 Mdot
.6139 .09989 Mdot
.61434 .09968 Mdot
.61485 .09944 Mdot
.61503 .09936 Mdot
.6153 .09923 Mdot
.61588 .09896 Mdot
.61603 .09889 Mdot
.6162 .09881 Mdot
.61659 .09863 Mdot
.61699 .09844 Mdot
.61719 .09835 Mdot
.61765 .09814 Mdot
.61806 .09795 Mdot
.61833 .09782 Mdot
.61874 .09763 Mdot
.61884 .09758 Mdot
.6192 .09742 Mdot
.61963 .09722 Mdot
.62001 .09704 Mdot
.62055 .09679 Mdot
.62089 .09664 Mdot
.62124 .09648 Mdot
.62147 .09637 Mdot
.62167 .09628 Mdot
.62204 .09611 Mdot
.62249 .0959 Mdot
.62283 .09574 Mdot
.62319 .09558 Mdot
.62336 .0955 Mdot
.62367 .09536 Mdot
.62391 .09525 Mdot
.62401 .0952 Mdot
.62446 .095 Mdot
.62484 .09482 Mdot
.62506 .09472 Mdot
.62516 .09468 Mdot
.62551 .09452 Mdot
.62593 .09433 Mdot
.62636 .09413 Mdot
.62675 .09396 Mdot
.627 .09384 Mdot
.62717 .09377 Mdot
.62725 .09373 Mdot
.62742 .09365 Mdot
.62768 .09354 Mdot
.62799 .09339 Mdot
.62864 .0931 Mdot
.6287 .09308 Mdot
.6291 .09289 Mdot
.62989 .09254 Mdot
.63005 .09246 Mdot
.63035 .09233 Mdot
.63065 .0922 Mdot
.63089 .09209 Mdot
.63132 .0919 Mdot
.63164 .09175 Mdot
.63167 .09174 Mdot
.63205 .09157 Mdot
.63238 .09142 Mdot
.63269 .09128 Mdot
.63314 .09108 Mdot
.63326 .09103 Mdot
.63349 .09093 Mdot
.6337 .09084 Mdot
.63411 .09065 Mdot
.63459 .09044 Mdot
.63491 .0903 Mdot
.63526 .09014 Mdot
.63547 .09005 Mdot
.63561 .08999 Mdot
.63587 .08987 Mdot
.63628 .08969 Mdot
.63649 .0896 Mdot
.63676 .08948 Mdot
.63725 .08926 Mdot
.6376 .08911 Mdot
.63807 .0889 Mdot
.63843 .08875 Mdot
.63856 .08869 Mdot
.63897 .08851 Mdot
.63931 .08836 Mdot
.63969 .0882 Mdot
.63973 .08818 Mdot
.64024 .08795 Mdot
.64053 .08783 Mdot
.64075 .08773 Mdot
.64105 .0876 Mdot
.64129 .0875 Mdot
.64166 .08734 Mdot
.64182 .08727 Mdot
.64212 .08714 Mdot
.64245 .087 Mdot
.64254 .08696 Mdot
.64317 .08668 Mdot
.64349 .08654 Mdot
.64361 .08649 Mdot
.64419 .08624 Mdot
.64452 .0861 Mdot
.64464 .08605 Mdot
.64529 .08577 Mdot
.64543 .08571 Mdot
.6457 .08559 Mdot
.64606 .08544 Mdot
.64648 .08526 Mdot
.64709 .085 Mdot
.64741 .08486 Mdot
.64759 .08479 Mdot
.64793 .08464 Mdot
.64839 .08445 Mdot
.64856 .08437 Mdot
.64873 .0843 Mdot
.64924 .08408 Mdot
.64933 .08404 Mdot
.64993 .08379 Mdot
.65032 .08363 Mdot
.65092 .08337 Mdot
.65112 .08329 Mdot
.65129 .08322 Mdot
.65171 .08304 Mdot
.65205 .0829 Mdot
.65217 .08285 Mdot
.65251 .0827 Mdot
.6528 .08258 Mdot
.65306 .08247 Mdot
.65341 .08233 Mdot
.65376 .08218 Mdot
.65396 .0821 Mdot
.65408 .08205 Mdot
.65462 .08182 Mdot
.65476 .08176 Mdot
.65511 .08161 Mdot
.65569 .08137 Mdot
.65593 .08128 Mdot
.65649 .08104 Mdot
.65657 .08101 Mdot
.65702 .08082 Mdot
.65708 .0808 Mdot
.65735 .08068 Mdot
.65782 .08049 Mdot
.65825 .08031 Mdot
.6583 .08029 Mdot
.65857 .08018 Mdot
.65876 .0801 Mdot
.65884 .08007 Mdot
.65967 .07973 Mdot
.66011 .07955 Mdot
.6602 .07951 Mdot
.66061 .07934 Mdot
.66088 .07923 Mdot
.6611 .07914 Mdot
.66146 .079 Mdot
.66181 .07885 Mdot
.6621 .07873 Mdot
.66259 .07853 Mdot
.66275 .07847 Mdot
.66294 .07839 Mdot
.66351 .07816 Mdot
.66374 .07807 Mdot
.66418 .07789 Mdot
.66457 .07773 Mdot
.66494 .07758 Mdot
.66529 .07744 Mdot
.66547 .07737 Mdot
.66556 .07733 Mdot
.66601 .07715 Mdot
.66604 .07714 Mdot
.66666 .07689 Mdot
.66669 .07688 Mdot
.66695 .07677 Mdot
.66727 .07664 Mdot
.6677 .07647 Mdot
.66789 .0764 Mdot
.66819 .07628 Mdot
.66878 .07604 Mdot
.66914 .0759 Mdot
.6693 .07583 Mdot
.66965 .07569 Mdot
.66985 .07561 Mdot
.66995 .07557 Mdot
.67018 .07548 Mdot
.67051 .07535 Mdot
.67105 .07514 Mdot
.67111 .07511 Mdot
.67139 .075 Mdot
.67178 .07485 Mdot
.67201 .07476 Mdot
.67238 .07461 Mdot
.67279 .07445 Mdot
.67288 .07442 Mdot
.6733 .07425 Mdot
.6737 .07409 Mdot
.67397 .07399 Mdot
.67402 .07397 Mdot
.67458 .07375 Mdot
.6748 .07366 Mdot
.67497 .07359 Mdot
.67528 .07347 Mdot
.67546 .0734 Mdot
.67577 .07328 Mdot
.67631 .07307 Mdot
.67685 .07286 Mdot
.67695 .07282 Mdot
.67741 .07264 Mdot
.67754 .07259 Mdot
.67806 .07239 Mdot
.6784 .07226 Mdot
.67883 .0721 Mdot
.67891 .07206 Mdot
.67946 .07185 Mdot
.67971 .07176 Mdot
.68008 .07161 Mdot
.68043 .07148 Mdot
.68078 .07135 Mdot
.68111 .07122 Mdot
.68185 .07094 Mdot
.68195 .0709 Mdot
.68215 .07082 Mdot
.6824 .07073 Mdot
.68263 .07064 Mdot
.68322 .07042 Mdot
.68367 .07025 Mdot
.68383 .07018 Mdot
.68466 .06987 Mdot
.68471 .06985 Mdot
.68503 .06973 Mdot
.6853 .06963 Mdot
.68542 .06958 Mdot
.68563 .0695 Mdot
.68605 .06934 Mdot
.68643 .0692 Mdot
.68672 .06909 Mdot
.687 .06899 Mdot
.68721 .06891 Mdot
.68748 .06881 Mdot
.68793 .06864 Mdot
.68851 .06842 Mdot
.68864 .06837 Mdot
.68924 .06815 Mdot
.68936 .0681 Mdot
.6898 .06794 Mdot
.6903 .06776 Mdot
.69065 .06763 Mdot
.6909 .06753 Mdot
.69121 .06742 Mdot
.69168 .06724 Mdot
.69211 .06709 Mdot
.69244 .06696 Mdot
.69311 .06672 Mdot
.69338 .06662 Mdot
.69388 .06643 Mdot
.69397 .0664 Mdot
.69472 .06613 Mdot
.69492 .06605 Mdot
.69518 .06596 Mdot
.69545 .06586 Mdot
.69598 .06567 Mdot
.6964 .06552 Mdot
.6965 .06548 Mdot
.69673 .0654 Mdot
.69689 .06534 Mdot
.69765 .06506 Mdot
.6978 .06501 Mdot
.69828 .06484 Mdot
.69857 .06473 Mdot
.69902 .06457 Mdot
.69921 .0645 Mdot
.69956 .06437 Mdot
.69987 .06426 Mdot
.7001 .06418 Mdot
.70048 .06404 Mdot
.70055 .06402 Mdot
.7011 .06382 Mdot
.70129 .06376 Mdot
.70146 .0637 Mdot
.70188 .06354 Mdot
.70204 .06349 Mdot
.70247 .06333 Mdot
.70283 .06321 Mdot
.70322 .06307 Mdot
.70368 .06291 Mdot
.7039 .06283 Mdot
.70405 .06278 Mdot
.70437 .06266 Mdot
.70492 .06247 Mdot
.70505 .06242 Mdot
.70529 .06234 Mdot
.70561 .06223 Mdot
.7058 .06216 Mdot
.70608 .06206 Mdot
.70649 .06192 Mdot
.70668 .06185 Mdot
.70719 .06167 Mdot
.7073 .06163 Mdot
.70754 .06155 Mdot
.70786 .06144 Mdot
.70796 .06141 Mdot
.70813 .06134 Mdot
.70885 .0611 Mdot
.7092 .06097 Mdot
.70956 .06085 Mdot
.70973 .06079 Mdot
.71007 .06067 Mdot
.71016 .06064 Mdot
.71058 .0605 Mdot
.71064 .06048 Mdot
.71096 .06037 Mdot
.71117 .06029 Mdot
.71138 .06022 Mdot
.71157 .06015 Mdot
.71203 .06 Mdot
.71253 .05983 Mdot
.71269 .05977 Mdot
.71301 .05966 Mdot
.71366 .05944 Mdot
.71397 .05934 Mdot
.71418 .05926 Mdot
.71483 .05904 Mdot
.71498 .05899 Mdot
.71544 .05884 Mdot
.71582 .05871 Mdot
.71615 .0586 Mdot
.71648 .05849 Mdot
.7168 .05838 Mdot
.71689 .05835 Mdot
.71741 .05817 Mdot
.71779 .05805 Mdot
.71793 .058 Mdot
.71814 .05793 Mdot
.71836 .05785 Mdot
.71868 .05775 Mdot
.71903 .05763 Mdot
.71937 .05752 Mdot
.71973 .0574 Mdot
.71997 .05732 Mdot
.72011 .05727 Mdot
.72053 .05713 Mdot
.72102 .05697 Mdot
.72148 .05682 Mdot
.72173 .05673 Mdot
.72206 .05663 Mdot
.72225 .05656 Mdot
.72265 .05643 Mdot
.72271 .05641 Mdot
.72332 .05621 Mdot
.72361 .05612 Mdot
.72387 .05603 Mdot
.72434 .05587 Mdot
.7248 .05573 Mdot
.72487 .0557 Mdot
.7252 .0556 Mdot
.72538 .05554 Mdot
.72578 .05541 Mdot
.72587 .05538 Mdot
.7264 .05521 Mdot
.72664 .05513 Mdot
.72689 .05505 Mdot
.72739 .05488 Mdot
.72772 .05478 Mdot
.72797 .0547 Mdot
.72808 .05466 Mdot
.72835 .05458 Mdot
.72874 .05445 Mdot
.72888 .05441 Mdot
.72945 .05422 Mdot
.72966 .05415 Mdot
.73026 .05396 Mdot
.7303 .05395 Mdot
.7309 .05376 Mdot
.73111 .05369 Mdot
.73143 .05359 Mdot
.73178 .05348 Mdot
.7322 .05335 Mdot
.73228 .05332 Mdot
.73239 .05329 Mdot
.73268 .05319 Mdot
.73281 .05315 Mdot
.73313 .05305 Mdot
.73351 .05293 Mdot
.73375 .05286 Mdot
.73407 .05276 Mdot
.73435 .05267 Mdot
.73477 .05254 Mdot
.73491 .05249 Mdot
.73526 .05238 Mdot
.73559 .05228 Mdot
.73577 .05222 Mdot
.73627 .05207 Mdot
.73665 .05195 Mdot
.73713 .0518 Mdot
.73744 .05171 Mdot
.73778 .0516 Mdot
.73812 .05149 Mdot
.73874 .0513 Mdot
.73889 .05126 Mdot
.73914 .05118 Mdot
.73945 .05109 Mdot
.73977 .05099 Mdot
.74016 .05087 Mdot
.74077 .05068 Mdot
.74087 .05065 Mdot
.74127 .05053 Mdot
.74169 .0504 Mdot
.7421 .05028 Mdot
.74225 .05023 Mdot
.74254 .05014 Mdot
.74277 .05007 Mdot
.74332 .04991 Mdot
.7436 .04982 Mdot
.7439 .04973 Mdot
.74447 .04956 Mdot
.74463 .04951 Mdot
.74504 .04939 Mdot
.74537 .04929 Mdot
.74584 .04915 Mdot
.74597 .04911 Mdot
.7462 .04904 Mdot
.74649 .04896 Mdot
.74688 .04884 Mdot
.74739 .04869 Mdot
.74776 .04858 Mdot
.74802 .0485 Mdot
.74807 .04849 Mdot
.74849 .04836 Mdot
.74859 .04833 Mdot
.74892 .04823 Mdot
.74908 .04819 Mdot
.74926 .04813 Mdot
.7496 .04803 Mdot
.74996 .04793 Mdot
.75013 .04788 Mdot
.75062 .04773 Mdot
.75074 .0477 Mdot
.75097 .04763 Mdot
.75117 .04757 Mdot
.7516 .04745 Mdot
.75208 .04731 Mdot
.75217 .04728 Mdot
.75256 .04717 Mdot
.75278 .04711 Mdot
.75316 .04699 Mdot
.7536 .04687 Mdot
.75388 .04679 Mdot
.75395 .04677 Mdot
.75444 .04663 Mdot
.75449 .04661 Mdot
.75501 .04646 Mdot
.75507 .04644 Mdot
.75537 .04636 Mdot
.75556 .0463 Mdot
.75576 .04625 Mdot
.75599 .04618 Mdot
.75632 .04609 Mdot
.75665 .04599 Mdot
.75687 .04593 Mdot
.75715 .04585 Mdot
.75761 .04572 Mdot
.75791 .04563 Mdot
.75805 .0456 Mdot
.7585 .04547 Mdot
.75863 .04543 Mdot
.75939 .04522 Mdot
.75954 .04518 Mdot
.76016 .045 Mdot
.76039 .04494 Mdot
.76082 .04482 Mdot
.76091 .04479 Mdot
.76145 .04464 Mdot
.76175 .04456 Mdot
.76217 .04444 Mdot
.76236 .04439 Mdot
.7627 .04429 Mdot
.76285 .04425 Mdot
.76323 .04415 Mdot
.76363 .04404 Mdot
.76387 .04397 Mdot
.76397 .04394 Mdot
.76426 .04386 Mdot
.76464 .04376 Mdot
.7651 .04363 Mdot
.76542 .04354 Mdot
.76586 .04342 Mdot
.76597 .04339 Mdot
.76638 .04328 Mdot
.7665 .04325 Mdot
.76708 .04309 Mdot
.76739 .04301 Mdot
.76755 .04296 Mdot
.7679 .04287 Mdot
.76804 .04283 Mdot
.7686 .04268 Mdot
.76874 .04264 Mdot
.76899 .04258 Mdot
.7693 .04249 Mdot
.76971 .04238 Mdot
.77019 .04225 Mdot
.7704 .0422 Mdot
.77076 .0421 Mdot
.77114 .042 Mdot
.77153 .0419 Mdot
.77155 .04189 Mdot
.77215 .04173 Mdot
.7724 .04167 Mdot
.77281 .04156 Mdot
.77339 .0414 Mdot
.77353 .04137 Mdot
.77382 .04129 Mdot
.77422 .04119 Mdot
.77442 .04113 Mdot
.77464 .04108 Mdot
.77502 .04098 Mdot
.77534 .04089 Mdot
.77559 .04083 Mdot
.77572 .04079 Mdot
.77615 .04068 Mdot
.77633 .04064 Mdot
.77672 .04054 Mdot
.77703 .04046 Mdot
.77708 .04044 Mdot
.77761 .0403 Mdot
.77775 .04027 Mdot
.7782 .04015 Mdot
.7784 .0401 Mdot
.77889 .03998 Mdot
.77909 .03992 Mdot
.77928 .03988 Mdot
.77953 .03981 Mdot
.77997 .0397 Mdot
.78027 .03962 Mdot
.78057 .03955 Mdot
.78072 .03951 Mdot
.78104 .03943 Mdot
.78143 .03933 Mdot
.78159 .03929 Mdot
.78173 .03926 Mdot
.7821 .03916 Mdot
.78216 .03915 Mdot
.78242 .03908 Mdot
.78293 .03895 Mdot
.78316 .03889 Mdot
.78343 .03883 Mdot
.78368 .03876 Mdot
.78415 .03865 Mdot
.7845 .03856 Mdot
.78474 .0385 Mdot
.78498 .03844 Mdot
.7852 .03839 Mdot
.78573 .03825 Mdot
.78598 .03819 Mdot
.7863 .03811 Mdot
.78651 .03806 Mdot
.78701 .03794 Mdot
.78738 .03785 Mdot
.78752 .03781 Mdot
.7878 .03775 Mdot
.78832 .03762 Mdot
.78851 .03757 Mdot
.78893 .03747 Mdot
.78906 .03744 Mdot
.78934 .03737 Mdot
.78967 .03729 Mdot
.78984 .03725 Mdot
.79019 .03717 Mdot
.79068 .03705 Mdot
.79098 .03697 Mdot
.79132 .03689 Mdot
.79166 .03681 Mdot
.79215 .03669 Mdot
.79266 .03657 Mdot
.79298 .0365 Mdot
.79328 .03643 Mdot
.79337 .0364 Mdot
.79348 .03638 Mdot
.79374 .03632 Mdot
.79432 .03618 Mdot
.79471 .03609 Mdot
.79484 .03606 Mdot
.79541 .03592 Mdot
.79556 .03589 Mdot
.79611 .03576 Mdot
.79627 .03572 Mdot
.79683 .03559 Mdot
.79692 .03557 Mdot
.79756 .03542 Mdot
.79782 .03536 Mdot
.79807 .0353 Mdot
.79845 .03522 Mdot
.79865 .03517 Mdot
.79882 .03513 Mdot
.79922 .03504 Mdot
.79974 .03492 Mdot
.80025 .0348 Mdot
.80053 .03474 Mdot
.80087 .03466 Mdot
.80124 .03458 Mdot
.80153 .03451 Mdot
.80187 .03443 Mdot
.80217 .03437 Mdot
.80286 .03421 Mdot
.80327 .03412 Mdot
.80353 .03406 Mdot
.804 .03396 Mdot
.80435 .03388 Mdot
.80491 .03375 Mdot
.80498 .03374 Mdot
.80553 .03362 Mdot
.80574 .03357 Mdot
.80586 .03354 Mdot
.80622 .03346 Mdot
.80655 .03339 Mdot
.80668 .03336 Mdot
.8072 .03325 Mdot
.80742 .0332 Mdot
.80789 .0331 Mdot
.80834 .033 Mdot
.80888 .03288 Mdot
.80929 .03279 Mdot
.80937 .03277 Mdot
.80991 .03266 Mdot
.80999 .03264 Mdot
.81019 .0326 Mdot
.81058 .03251 Mdot
.81066 .0325 Mdot
.81115 .03239 Mdot
.81145 .03233 Mdot
.81151 .03231 Mdot
.8119 .03223 Mdot
.81233 .03214 Mdot
.81285 .03203 Mdot
.81302 .03199 Mdot
.81316 .03196 Mdot
.81371 .03185 Mdot
.81392 .0318 Mdot
.81448 .03168 Mdot
.81468 .03164 Mdot
.81488 .0316 Mdot
.81525 .03152 Mdot
.81544 .03148 Mdot
.81585 .0314 Mdot
.81628 .03131 Mdot
.81676 .03121 Mdot
.81683 .0312 Mdot
.81729 .0311 Mdot
.81765 .03103 Mdot
.81807 .03094 Mdot
.81827 .0309 Mdot
.81856 .03084 Mdot
.81906 .03074 Mdot
.8193 .03069 Mdot
.81989 .03057 Mdot
.82031 .03048 Mdot
.82052 .03044 Mdot
.82107 .03033 Mdot
.82136 .03027 Mdot
.82177 .03019 Mdot
.82197 .03015 Mdot
.82214 .03011 Mdot
.82258 .03003 Mdot
.82297 .02995 Mdot
.82302 .02994 Mdot
.82351 .02984 Mdot
.82367 .02981 Mdot
.82409 .02973 Mdot
.82425 .0297 Mdot
.8245 .02965 Mdot
.82463 .02962 Mdot
.82514 .02952 Mdot
.82541 .02947 Mdot
.82579 .0294 Mdot
.82596 .02936 Mdot
.82621 .02931 Mdot
.82658 .02924 Mdot
.82675 .02921 Mdot
.82724 .02911 Mdot
.82757 .02905 Mdot
.82784 .029 Mdot
.82813 .02894 Mdot
.82834 .0289 Mdot
.8288 .02881 Mdot
.82905 .02876 Mdot
.8292 .02874 Mdot
.82944 .02869 Mdot
.82985 .02861 Mdot
.83033 .02852 Mdot
.83066 .02846 Mdot
.83109 .02838 Mdot
.83132 .02833 Mdot
.83155 .02829 Mdot
.83178 .02825 Mdot
.83223 .02816 Mdot
.83261 .02809 Mdot
.8328 .02806 Mdot
.833 .02802 Mdot
.83356 .02792 Mdot
.83369 .02789 Mdot
.83443 .02776 Mdot
.83451 .02774 Mdot
.83489 .02767 Mdot
.8353 .0276 Mdot
.83549 .02756 Mdot
.83581 .0275 Mdot
.83609 .02745 Mdot
.83636 .0274 Mdot
.83681 .02732 Mdot
.83699 .02729 Mdot
.83732 .02723 Mdot
.83755 .02719 Mdot
.8382 .02707 Mdot
.83844 .02703 Mdot
.8389 .02695 Mdot
.83914 .0269 Mdot
.83937 .02686 Mdot
.83959 .02682 Mdot
.84031 .0267 Mdot
.84061 .02664 Mdot
.8409 .02659 Mdot
.84109 .02656 Mdot
.84136 .02651 Mdot
.84153 .02648 Mdot
.842 .0264 Mdot
.84224 .02636 Mdot
.84269 .02628 Mdot
.84305 .02622 Mdot
.84316 .0262 Mdot
.84337 .02616 Mdot
.8438 .02609 Mdot
.84424 .02601 Mdot
.84474 .02593 Mdot
.8451 .02587 Mdot
.84534 .02583 Mdot
.84543 .02581 Mdot
.84594 .02572 Mdot
.84618 .02568 Mdot
.84682 .02558 Mdot
.84707 .02553 Mdot
.84736 .02549 Mdot
.84766 .02543 Mdot
.84805 .02537 Mdot
.84868 .02527 Mdot
.84885 .02524 Mdot
.84911 .0252 Mdot
.8494 .02515 Mdot
.84988 .02507 Mdot
.8504 .02498 Mdot
.8507 .02493 Mdot
.85089 .0249 Mdot
.85149 .02481 Mdot
.85186 .02475 Mdot
.85231 .02467 Mdot
.85267 .02462 Mdot
.85279 .0246 Mdot
.8536 .02447 Mdot
.85392 .02442 Mdot
.85408 .02439 Mdot
.85447 .02433 Mdot
.85486 .02427 Mdot
.85508 .02423 Mdot
.85522 .02421 Mdot
.85559 .02415 Mdot
.85577 .02413 Mdot
.85619 .02406 Mdot
.8564 .02403 Mdot
.85681 .02396 Mdot
.85701 .02393 Mdot
.85749 .02386 Mdot
.85752 .02385 Mdot
.85784 .02381 Mdot
.85818 .02375 Mdot
.85834 .02373 Mdot
.85874 .02367 Mdot
.859 .02363 Mdot
.85912 .02361 Mdot
.85967 .02353 Mdot
.85997 .02348 Mdot
.86014 .02345 Mdot
.86035 .02342 Mdot
.86105 .02332 Mdot
.86134 .02327 Mdot
.86157 .02324 Mdot
.86222 .02314 Mdot
.8624 .02312 Mdot
.86274 .02307 Mdot
.863 .02303 Mdot
.86326 .02299 Mdot
.86375 .02292 Mdot
.8639 .0229 Mdot
.86435 .02283 Mdot
.86442 .02282 Mdot
.86481 .02277 Mdot
.86495 .02275 Mdot
.86545 .02267 Mdot
.8658 .02262 Mdot
.86607 .02258 Mdot
.86628 .02255 Mdot
.8665 .02252 Mdot
.86692 .02246 Mdot
.86703 .02245 Mdot
.86759 .02237 Mdot
.86781 .02234 Mdot
.86797 .02232 Mdot
.86815 .02229 Mdot
.86872 .02221 Mdot
.86885 .02219 Mdot
.86916 .02215 Mdot
.86921 .02214 Mdot
.86948 .02211 Mdot
.86981 .02206 Mdot
.86995 .02204 Mdot
.87033 .02199 Mdot
.87046 .02197 Mdot
.87093 .02191 Mdot
.87136 .02185 Mdot
.87159 .02182 Mdot
.87199 .02176 Mdot
.8724 .02171 Mdot
.87249 .02169 Mdot
.87307 .02162 Mdot
.87332 .02158 Mdot
.8737 .02153 Mdot
.87391 .0215 Mdot
.87433 .02145 Mdot
.87469 .0214 Mdot
.87475 .02139 Mdot
.87522 .02133 Mdot
.87534 .02132 Mdot
.87551 .02129 Mdot
.87621 .0212 Mdot
.87657 .02115 Mdot
.87678 .02113 Mdot
.87708 .02109 Mdot
.87735 .02106 Mdot
.87799 .02097 Mdot
.8782 .02095 Mdot
.87846 .02091 Mdot
.87895 .02085 Mdot
.87936 .0208 Mdot
.87944 .02079 Mdot
.87985 .02074 Mdot
.8801 .02071 Mdot
.88045 .02066 Mdot
.88073 .02063 Mdot
.88106 .02059 Mdot
.88184 .02049 Mdot
.88191 .02048 Mdot
.88222 .02045 Mdot
.88235 .02043 Mdot
.88288 .02037 Mdot
.88313 .02034 Mdot
.88338 .0203 Mdot
.8835 .02029 Mdot
.88398 .02023 Mdot
.88431 .02019 Mdot
.88479 .02014 Mdot
.88512 .0201 Mdot
.88549 .02005 Mdot
.8861 .01998 Mdot
.88664 .01992 Mdot
.88704 .01987 Mdot
.88746 .01982 Mdot
.88784 .01978 Mdot
.88815 .01974 Mdot
.88831 .01973 Mdot
.8885 .0197 Mdot
.88897 .01965 Mdot
.88947 .0196 Mdot
.88979 .01956 Mdot
.89011 .01952 Mdot
.89086 .01944 Mdot
.89111 .01941 Mdot
.89164 .01935 Mdot
.89183 .01933 Mdot
.89206 .01931 Mdot
.89252 .01926 Mdot
.89277 .01923 Mdot
.89312 .01919 Mdot
.89349 .01915 Mdot
.89367 .01913 Mdot
.89392 .01911 Mdot
.89455 .01904 Mdot
.89482 .01901 Mdot
.89497 .019 Mdot
.89524 .01897 Mdot
.89563 .01893 Mdot
.89641 .01885 Mdot
.8967 .01882 Mdot
.89712 .01877 Mdot
.89721 .01876 Mdot
.89778 .0187 Mdot
.89786 .0187 Mdot
.89836 .01865 Mdot
.89845 .01864 Mdot
.8986 .01862 Mdot
.89911 .01857 Mdot
.89918 .01856 Mdot
.89962 .01852 Mdot
.89988 .01849 Mdot
.90034 .01845 Mdot
.90052 .01843 Mdot
.90069 .01841 Mdot
.90127 .01836 Mdot
.90143 .01834 Mdot
.90176 .01831 Mdot
.90209 .01828 Mdot
.90236 .01825 Mdot
.90271 .01822 Mdot
.90311 .01818 Mdot
.9033 .01816 Mdot
.90371 .01812 Mdot
.90427 .01807 Mdot
.90467 .01803 Mdot
.90533 .01797 Mdot
.90542 .01797 Mdot
.90577 .01793 Mdot
.90615 .0179 Mdot
.9066 .01786 Mdot
.90667 .01785 Mdot
.90693 .01783 Mdot
.90734 .01779 Mdot
.90758 .01777 Mdot
.90793 .01774 Mdot
.90835 .0177 Mdot
.90849 .01769 Mdot
.90884 .01766 Mdot
.90937 .01761 Mdot
.90947 .0176 Mdot
.90991 .01757 Mdot
.91026 .01754 Mdot
.91049 .01752 Mdot
.91095 .01748 Mdot
.91107 .01747 Mdot
.91152 .01743 Mdot
.9117 .01741 Mdot
.91192 .0174 Mdot
.91245 .01735 Mdot
.9128 .01732 Mdot
.91297 .01731 Mdot
.91373 .01725 Mdot
.91379 .01724 Mdot
.91443 .01719 Mdot
.91489 .01715 Mdot
.91505 .01714 Mdot
.91541 .01711 Mdot
.91582 .01708 Mdot
.9162 .01705 Mdot
.91658 .01702 Mdot
.9168 .017 Mdot
.91733 .01696 Mdot
.91791 .01692 Mdot
.91803 .01691 Mdot
.9182 .0169 Mdot
.91853 .01687 Mdot
.91868 .01686 Mdot
.91908 .01683 Mdot
.9193 .01682 Mdot
.9195 .0168 Mdot
.9197 .01679 Mdot
.92041 .01673 Mdot
.92073 .01671 Mdot
.92088 .0167 Mdot
.92127 .01667 Mdot
.92139 .01666 Mdot
.92166 .01664 Mdot
.92199 .01662 Mdot
.92245 .01659 Mdot
.92253 .01658 Mdot
.92278 .01657 Mdot
.92334 .01653 Mdot
.92354 .01651 Mdot
.92385 .01649 Mdot
.92417 .01647 Mdot
.9244 .01646 Mdot
.92492 .01642 Mdot
.92533 .01639 Mdot
.92561 .01638 Mdot
.92576 .01637 Mdot
.92629 .01633 Mdot
.92662 .01631 Mdot
.92681 .0163 Mdot
.92715 .01628 Mdot
.92767 .01624 Mdot
.92781 .01623 Mdot
.92834 .0162 Mdot
.92887 .01617 Mdot
.92888 .01617 Mdot
.92949 .01613 Mdot
.92964 .01612 Mdot
.92989 .01611 Mdot
.93002 .0161 Mdot
.93029 .01608 Mdot
.93088 .01605 Mdot
.93104 .01604 Mdot
.93137 .01602 Mdot
.93148 .01601 Mdot
.93208 .01598 Mdot
.93238 .01596 Mdot
.93271 .01594 Mdot
.93311 .01592 Mdot
.93349 .0159 Mdot
.93382 .01588 Mdot
.93396 .01587 Mdot
.93453 .01584 Mdot
.93484 .01582 Mdot
.9352 .01581 Mdot
.93547 .01579 Mdot
.93586 .01577 Mdot
.93632 .01575 Mdot
.93662 .01573 Mdot
.93689 .01572 Mdot
.93726 .0157 Mdot
.93766 .01568 Mdot
.93811 .01566 Mdot
.93816 .01565 Mdot
.93837 .01564 Mdot
.93863 .01563 Mdot
.93888 .01562 Mdot
.93939 .01559 Mdot
.93961 .01558 Mdot
.93987 .01557 Mdot
.94015 .01556 Mdot
.94045 .01554 Mdot
.94088 .01552 Mdot
.94108 .01552 Mdot
.94134 .0155 Mdot
.94168 .01549 Mdot
.94205 .01547 Mdot
.94245 .01545 Mdot
.94266 .01544 Mdot
.94336 .01541 Mdot
.94339 .01541 Mdot
.94398 .01539 Mdot
.94415 .01538 Mdot
.94442 .01537 Mdot
.94456 .01536 Mdot
.94472 .01536 Mdot
.94529 .01533 Mdot
.94553 .01533 Mdot
.94571 .01532 Mdot
.94628 .0153 Mdot
.94657 .01528 Mdot
.94683 .01527 Mdot
.94752 .01525 Mdot
.94759 .01525 Mdot
.94777 .01524 Mdot
.94816 .01523 Mdot
.94827 .01522 Mdot
.9487 .01521 Mdot
.94911 .01519 Mdot
.94937 .01518 Mdot
.94988 .01516 Mdot
.94998 .01516 Mdot
.95048 .01514 Mdot
.95072 .01514 Mdot
.95096 .01513 Mdot
.95113 .01512 Mdot
.95141 .01511 Mdot
.9521 .01509 Mdot
.95227 .01509 Mdot
.95243 .01508 Mdot
.95292 .01507 Mdot
.95309 .01506 Mdot
.9534 .01505 Mdot
.95375 .01504 Mdot
.95415 .01503 Mdot
.95417 .01503 Mdot
.95435 .01502 Mdot
.9547 .01501 Mdot
.95501 .01501 Mdot
.95523 .015 Mdot
.95543 .01499 Mdot
.95588 .01498 Mdot
.95599 .01498 Mdot
.95639 .01497 Mdot
.95691 .01496 Mdot
.95753 .01494 Mdot
.95776 .01494 Mdot
.95806 .01493 Mdot
.95846 .01492 Mdot
.9587 .01491 Mdot
.95897 .01491 Mdot
.95947 .0149 Mdot
.95967 .01489 Mdot
.95999 .01489 Mdot
.96019 .01488 Mdot
.96056 .01487 Mdot
.96071 .01487 Mdot
.96129 .01486 Mdot
.96143 .01486 Mdot
.96165 .01485 Mdot
.96174 .01485 Mdot
.96205 .01484 Mdot
.96242 .01484 Mdot
.96275 .01483 Mdot
.96305 .01483 Mdot
.96358 .01482 Mdot
.96371 .01482 Mdot
.96386 .01481 Mdot
.96454 .0148 Mdot
.96462 .0148 Mdot
.96532 .01479 Mdot
.96552 .01479 Mdot
.96572 .01479 Mdot
.96626 .01478 Mdot
.96646 .01478 Mdot
.96685 .01477 Mdot
.96716 .01477 Mdot
.96726 .01477 Mdot
.96743 .01476 Mdot
.96781 .01476 Mdot
.96805 .01476 Mdot
.96835 .01475 Mdot
.96863 .01475 Mdot
.96868 .01475 Mdot
.96902 .01475 Mdot
.96929 .01475 Mdot
.96973 .01474 Mdot
.96998 .01474 Mdot
.97002 .01474 Mdot
.9705 .01474 Mdot
.97068 .01473 Mdot
.97107 .01473 Mdot
.97114 .01473 Mdot
.97139 .01473 Mdot
.97173 .01473 Mdot
.97193 .01473 Mdot
.97206 .01473 Mdot
.97242 .01472 Mdot
.9726 .01472 Mdot
.97287 .01472 Mdot
.97331 .01472 Mdot
.97364 .01472 Mdot
.97401 .01472 Mdot
.97434 .01472 Mdot
.97484 .01472 Mdot
.97521 .01472 Mdot
.97535 .01472 Mdot
.97566 .01472 Mdot
.97612 .01472 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .55653 L
.10458 .50771 L
.14415 .46397 L
.18221 .42381 L
.22272 .38313 L
.26171 .34599 L
.30316 .30867 L
.34309 .27482 L
.3815 .24422 L
.42237 .21376 L
.46172 .18648 L
.49955 .16214 L
.53984 .13827 L
.57861 .11729 L
.61984 .09712 L
.65954 .07978 L
.69774 .06503 L
.73838 .05141 L
.77751 .04033 L
.81909 .03073 L
.85916 .0236 L
.87754 .02103 L
.89771 .01871 L
.91765 .01694 L
.92854 .01619 L
.93871 .01563 L
.94354 .01541 L
.94878 .0152 L
.95341 .01505 L
.95832 .01492 L
.96273 .01483 L
.96524 .01479 L
.9676 .01476 L
.96976 .01474 L
.97173 .01473 L
.97277 .01472 L
.97391 .01472 L
.97509 .01472 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 0 0 r
gsave
.5 .825 -152.375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.063 moveto
(Sum) show
149.625 15.063 moveto
(for) show
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
178.375 15.063 moveto
0.000 0.000 rmoveto
178.375 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
188.438 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
198.500 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
208.875 15.063 moveto
(x) show
218.938 15.063 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
229.000 15.063 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
236.188 10.313 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.05 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(min) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
gsave
.05 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
70.375 16.750 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(max) show
93.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
107.625 15.000 moveto
0.000 0.000 rmoveto
107.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
gsave
.5 .17 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partitions) show
142.063 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
156.438 15.000 moveto
0.000 0.000 rmoveto
156.438 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3000) show
1.000 setlinewidth
grestore
gsave
.5 .14 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Partition) show
134.938 15.000 moveto
(Norm) show
171.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
185.625 15.000 moveto
0.000 0.000 rmoveto
185.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00155087) show
1.000 setlinewidth
grestore
gsave
.05 .1 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Integral) show
149.250 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
163.625 15.000 moveto
0.000 0.000 rmoveto
163.625 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
1.000 setlinewidth
grestore
gsave
.05 .07 -61 -11.7813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 15.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
%%BeginResource: font Courier-Bold-MISO
%%BeginFont: Courier-Bold-MISO
/Courier-Bold /Courier-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Riemann) show
120.500 15.000 moveto
(Sum) show
149.625 15.000 moveto
%%IncludeResource: font Mathematica1Mono-Bold
%%IncludeFont: Mathematica1Mono-Bold
/Mathematica1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
164.000 15.000 moveto
0.000 0.000 rmoveto
164.000 15.000 moveto
%%IncludeResource: font Courier-Bold-MISO
%%IncludeFont: Courier-Bold-MISO
/Courier-Bold-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.99993) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 540},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H000272000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo000O0?[`iP@000000P3jl>H800000080n_3V10000000
1`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H0000000000004000000040?[`
iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H00`00000H0?[`iP<0
0000103jl>H2000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`0000050?[`iP<0
0000o`3jl>JT0?[`iP40oooo000P0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP800000
0`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0n_3V
0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H00P00
00090?[`iPD000002P3jl>H00`000000n_3V0?[`iP02000000<0n_3V0P0000060?[`iP8000001@3j
l>H2000000D0n_3V0P0000050?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000?l0n_3VX`3j
l>H10?ooo`00803jl>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2
000000030?[`iP000000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003j
l>H2000000030?[`iP000000n_3V008000006`3jl>H2000000`0n_3V0P0000050?[`iP8000001@3j
l>H2000000D0n_3V0P0000050?[`iP800000o`3jl>JS0?[`iP40oooo000P0?[`iPD00000103jl>H2
000000<0n_3V1P0000001P3jl>H000000000003jl>H000000?[`iP80000000<0n_3V000000000000
0`0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000/0n_3V
0`0000030?[`iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000000T0
n_3V1@00000=0?[`iP8000002P3jl>H4000000<0n_3V100000030?[`iP@000000`3jl>H4000000D0
n_3V0P00003o0?[`iZ<0n_3V0@3oool00200n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V
0P0000020?[`iP80000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`
iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`
iP80000000@0n_3V000000000000n_3V0P0000000`3jl>H000000?[`iP02000001P0n_3V00<00000
0?[`iP3jl>H00P0000090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000
00000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000`3jl>H3
00000?l0n_3VY03jl>H10?ooo`00803jl>H200000080n_3V0P0000000`3jl>H00000000000020000
00@0n_3V100000000`3jl>H000000000000500000080n_3V100000020?[`iPD000000P3jl>H50000
00X0n_3V0P0000050?[`iP<0000000<0n_3V0000000000001`00000I0?[`iP@000002P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000D0n_3V0P00003o0?[`iZ<0n_3V0@3oool00200
n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H09@3jl>H2000000`0
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H200000003
0?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP030000003jl>H0n_3V0080
0000o`3jl>JS0?[`iP40oooo000O0?[`iPH00000103jl>H2000002l0n_3V1@00000W0?[`iPD00000
2P3jl>H3000000@0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`00003o0?[`iZ@0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00?@3jl>H400000?l0n_3Vo`3jl>HH0?[`iP40oooo00100?[`iP800000o`3jl>Ko0?[`iQL0n_3V
0@3oool00200n_3V1P0000001@3jl>H00000000000000000n_3V00<000000P3jl>H3000000<0n_3V
100000030?[`iP80000000@0n_3V000000000000n_3V1@0000030?[`iP`00000;`3jl>H3000000@0
n_3V0P00003o0?[`i/T0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V000000000000
0P3jl>H200000080n_3V00@000000?[`iP00000000000`3jl>H01@000000n_3V000000000000n_3V
00<000000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000280n_3V1@0000090?[`
iP80000000<0n_3V0000000000000`3jl>H200000?l0n_3Vb@3jl>H10?ooo`008P3jl>H2000000@0
n_3V0P0000000`3jl>H00000000000020?[`iP800000103jl>H2000000D0n_3V0P0000020?[`iP80
00000P3jl>H2000000@0n_3V0P0000020?[`iP8000000`3jl>H200000300n_3V0P0000000`3jl>H0
00000000003o0?[`i/h0n_3V0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V000000000000
0P3jl>H2000000@0n_3V1P0000000`3jl>H00000000000020?[`iP8000000P3jl>H2000000D0n_3V
1@0000030?[`iP8000008P3jl>H5000000T0n_3V0P0000000`3jl>H000000000003o0?[`i/h0n_3V
0@3oool00280n_3V0P0000040?[`iP80000000<0n_3V0000000000000P3jl>H2000000@0n_3V0P00
00020?[`iP80000000@0n_3V000000000000n_3V0`0000020?[`iP<0000000<0n_3V0000003jl>H0
103jl>H2000000<0n_3V0P00000`0?[`iP@00000o`3jl>K?0?[`iP40oooo000R0?[`iP8000000`3j
l>H500000080n_3V1@0000030?[`iP@000000`3jl>H2000000030?[`iP000000000000@0000000<0
n_3V0000000000000P3jl>H4000000@0n_3V0P00000`0?[`iP800000o`3jl>KA0?[`iP40oooo000R
0?[`iP8000002`3jl>H200000280n_3V0P00000a0?[`iP800000o`3jl>K@0?[`iP40oooo000P0?[`
iPH000002@3jl>H200000200n_3V1000000b0?[`iP<00000o`3jl>K>0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
02H0n_3V0P0000000`3jl>H000000?[`iP08000000030?[`iP00000000000?l0n_3Vo`3jl>HS0?[`
iP40oooo000W0?[`iP040000003jl>H000000?[`iP8000000P3jl>H00`000000n_3V0?[`iP030000
0?l0n_3Vo`3jl>HT0?[`iP40oooo000P0?[`iP<0000000<0n_3V0000000000000P0000001@3jl>H0
00000?[`iP000000n_3V00<000000P3jl>H00`000000n_3V0000000I0?[`iP<00000g03jl>H40000
00@0n_3V2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H40000
0080n_3V0`000000103jl>H000000000000000080?[`iP@0000000<0n_3V0000000000000P3jl>H4
00000080n_3V1@0000001`3jl>H00000000000000000n_3V0000003jl>H00`00000H0?[`iP<00000
103jl>H2000000D0n_3V0`0000040?[`iP<000000`3jl>H600000080n_3V0`0000040?[`iP<00000
103jl>H3000000@0n_3V0`0000050?[`iP800000J`3jl>H10?ooo`008@3jl>H2000000030?[`iP00
0000000000D0000000@0n_3V00000000000000000P3jl>H2000000030?[`iP000000000000T0n_3V
1@0000090?[`iP030000003jl>H0n_3V00800000g03jl>H2000000@0n_3V0P0000020?[`iP800000
0P3jl>H2000000D0n_3V0P0000020?[`iP040000003jl>H0n_3V0?[`iP800000103jl>H200000080
n_3V00@000000?[`iP3jl>H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3j
l>H000000000000:0?[`iP8000000P3jl>H2000000030?[`iP00000000000080n_3V0P0000020?[`
iP800000103jl>H2000000030?[`iP000000n_3V008000002@3jl>H5000000X0n_3V0P0000000`3j
l>H00000000000030?[`iP800000103jl>H2000000030?[`iP00000000000080n_3V0P0000000`3j
l>H00000000000040?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V00<000000?[`
iP3jl>H00P0000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
00@0n_3V0P00001[0?[`iP40oooo000R0?[`iP<00000:`3jl>H200000=`0n_3V0P0000040?[`iP80
00000P3jl>H200000080n_3V0P0000050?[`iP8000001P3jl>H2000000@0n_3V0P0000060?[`iP80
00000`3jl>H200000080n_3V0P0000020?[`iP80000000<0n_3V0000000000002P3jl>H200000005
0?[`iP00000000000000003jl>H00P0000020?[`iP8000000P3jl>H2000000@0n_3V0P0000000`3j
l>H000000?[`iP02000001P0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000060?[`iP8000001@3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H20000
06/0n_3V0@3oool00280n_3V0`00000J0?[`iPD00000303jl>H200000=`0n_3V100000030?[`iPD0
00000P3jl>H2000000D0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP80
00000P3jl>H200000080n_3V0P0000000`3jl>H000000000000:0?[`iP80000000D0n_3V00000000
000000000?[`iP0200000080n_3V0P0000020?[`iP800000103jl>H2000000030?[`iP000000n_3V
008000002@3jl>H5000000X0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000
000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P0000060?[`iP8000001@3jl>H20000
0080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V000000000000103jl>H20000
06/0n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000X0?[`iP<00000g@3jl>H200000003
0?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003jl>H0n_3V0P0000060?[`
iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H200000080n_3V0P0000000`3j
l>H000000000000:0?[`iP<0000000@0n_3V000000000000n_3V0P0000020?[`iP8000000P3jl>H3
000000030?[`iP000000n_3V0080000000<0n_3V0000003jl>H00P00000H0?[`iP80000000<0n_3V
0000000000002@3jl>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H0000000000004
0?[`iP8000000`3jl>H00`000000n_3V0?[`iP0200000080n_3V00<000000?[`iP3jl>H00P000002
0?[`iP80000000<0n_3V0000000000000`3jl>H3000000H0n_3V0P00001Z0?[`iP40oooo000P0?[`
iP<0000000@0n_3V0000000000000000:@3jl>H200000=`0n_3V0P0000000`3jl>H0000000000002
0?[`iP@000000P3jl>H3000000040?[`iP00000000000?[`iPD000000P3jl>H4000000<0n_3V1@00
00020?[`iP@00000103jl>H400000080n_3V1@00000;0?[`iP<0000000<0n_3V0000000000000P3j
l>H400000080n_3V0`0000000`3jl>H0000000000007000001T0n_3V0P0000000`3jl>H000000000
00090?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP000000000000@0n_3V0P00
00030?[`iP@000000`3jl>H4000000<0n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000001@3jl>H2000006X0n_3V0@3oool004d0n_3V00<000000?[`iP3jl>H00P00003L
0?[`iP80000000<0n_3V000000000000403jl>H2000000`0n_3V0P00000R0?[`iP8000000P3jl>H2
000002h0n_3V0P0000000`3jl>H00000000000090?[`iP80000000<0n_3V0000000000000P3jl>H2
000000030?[`iP00000000000080n_3V100000030?[`iP8000001@3jl>H2000000D0n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H00`000000n_3V0?[`iP02
000006X0n_3V0@3oool004h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`
iP8000001P3jl>H2000001T0n_3V0`0000000`3jl>H0000000000002000002h0n_3V0`00000;0?[`
iP<00000103jl>H3000000D0n_3V0P0000030?[`iPD000000P3jl>H5000000<0n_3V0`0000040?[`
iP<000000`3jl>H5000006X0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3V
F@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`
i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo
003o0?[`i_l0n_3VF@3jl>H10?ooo`009P3jl>H2000000030?[`iP000000n_3V00P0000000<0n_3V
000000000000o`3jl>Ko0?[`iR<0n_3V0@3oool002L0n_3V00D000000?[`iP000000n_3V00000002
0?[`iP040000003jl>H0n_3V00000080n_3V00<000000?[`iP3jl>H0o`3jl>Ko0?[`iR80n_3V0@3o
ool00200n_3V0`0000000`3jl>H0000000000002000000040?[`iP000000n_3V00000080n_3V00@0
00000?[`iP3jl>H000000P3jl>H00`000000n_3V0?[`iP0G0?[`iP<00000g03jl>H4000000@0n_3V
2`0000040?[`iP<000000P3jl>H6000000<0n_3V0`0000020?[`iPH000000P3jl>H400000080n_3V
0`0000000`3jl>H0000000000006000001/0n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V
0`00002c0?[`iP40oooo000Q0?[`iP80000000<0n_3V0000000000001@0000001@3jl>H000000000
00000000n_3V00@000002`3jl>H5000000T0n_3V0P0000000`3jl>H000000000003L0?[`iP800000
103jl>H200000080n_3V0P0000020?[`iP8000001@3jl>H200000080n_3V00@000000?[`iP3jl>H0
n_3V0P0000040?[`iP8000000P3jl>H010000000n_3V0?[`iP3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000040?[`iP00000000000?[`iP8000000P3jl>H2000000/0n_3V1@000009
0?[`iP030000003jl>H0n_3V008000000P3jl>H2000000030?[`iP00000000000080n_3V0P000000
0`3jl>H00000000000020?[`iP80000000<0n_3V000000000000/P3jl>H10?ooo`008P3jl>H30000
02P0n_3V0P0000000`3jl>H000000000003L0?[`iP800000103jl>H200000080n_3V0P0000020?[`
iP8000001@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H2000000<0n_3V0P0000020?[`
iP8000000P3jl>H2000000030?[`iP000000000000<0n_3V1000000L0?[`iP8000000P3jl>H20000
00030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000
00000000/P3jl>H10?ooo`008P3jl>H3000000T0n_3V00<000000?[`iP3jl>H03P3jl>H5000000T0
n_3V0P0000000`3jl>H000000000003L0?[`iP@000000`3jl>H500000080n_3V0P0000050?[`iP80
00001P3jl>H2000000@0n_3V0P0000060?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP80
000000@0n_3V000000000000n_3V1000000=0?[`iPD00000303jl>H200000080n_3V0P0000000`3j
l>H00000000000020?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP0000000000
0;80n_3V0@3oool00240n_3V0P0000000`3jl>H000000000000W0?[`iP80000000<0n_3V00000000
0000g03jl>H2000000030?[`iP000000000000D0n_3V0P0000020?[`iP<0000000@0n_3V0000003j
l>H0n_3V0P0000060?[`iP800000103jl>H2000000H0n_3V0P0000030?[`iP8000000P3jl>H20000
0080n_3V0P000000103jl>H000000000003jl>H200000080n_3V0P00000J0?[`iP<000000`3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V
000000000000/P3jl>H10?ooo`00803jl>H3000000040?[`iP0000000000000002H0n_3V0P000000
0`3jl>H000000000003L0?[`iP80000000<0n_3V0000000000000P3jl>H400000080n_3V0`000000
103jl>H000000000003jl>H500000080n_3V100000030?[`iPD000000P3jl>H4000000@0n_3V1000
00020?[`iPD000000`3jl>H5000001`0n_3V0P0000020?[`iP80000000<0n_3V0000000000000P3j
l>H2000000030?[`iP00000000000080n_3V0P0000000`3jl>H000000000002b0?[`iP40oooo001=
0?[`iP80000000<0n_3V000000000000g03jl>H2000000030?[`iP00000000000100n_3V0P00000<
0?[`iP800000>03jl>H00`000000n_3V0?[`iP0200000080n_3V0P0000000`3jl>H0000000000002
0?[`iP80000000<0n_3V0000000000000P3jl>H2000000030?[`iP00000000000;80n_3V0@3oool0
04h0n_3V0`00003L0?[`iPD000004@3jl>H2000000H0n_3V0P0000040?[`iP8000001P3jl>H20000
0340n_3V0`0000040?[`iP<00000103jl>H3000000@0n_3V0`00002c0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`007@3jl>HS0?ooh0800000A@3oon02
000000@0oooP0P0000040?ooh0800000A03oon05000004<0oooP1@0000020?ooh0800000103oon02
000004@0oooP100000140?ooh0@000000`3oon02000000@0oooP0P0000150?ooh08000009`3oon0N
0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh000
00080?ooh0040000003oon00oooP000004D0oooP00<000000?ooh03oon00A@3oon000`000000oooP
0?ooh0070?ooh0040000003oon00oooP000004<0oooP00<000000?ooh03oon00A@3oon000`000000
oooP0?ooh0090?ooh0040000003oon00oooP000004<0oooP00@000000?ooh03oon0000009P3oon0N
0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh000
000;0?ooh0030000003oon00oooP04<0oooP00<000000?ooh03oon00A@3oon000`000000oooP0?oo
h00:0?ooh0030000003oon00oooP0480oooP00<000000?ooh03oon00A@3oon000`000000oooP0?oo
h00;0?ooh0030000003oon00oooP04<0oooP00<000000?ooh03oon009@3oon0N0?[`iP40oooo000M
0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP0?ooh00000090?ooh0800000
AP3oon000`000000oooP0?ooh0150?ooh0030000003oon00oooP00P0oooP0P0000160?ooh0030000
003oon00oooP04D0oooP00<000000?ooh03oon00203oon02000004L0oooP00<000000?ooh03oon00
903oon0N0?[`iP40oooo000M0?[`iR80oooP00@000000?ooh03oon000000@`3oon0010000000oooP
0?ooh00000090?ooh0030000003oon00oooP04D0oooP00<000000?ooh03oon00A@3oon000`000000
oooP0?ooh0080?ooh0030000003oon00oooP04<0oooP00@000000?ooh03oon000000A03oon001000
0000oooP0?ooh00000090?ooh0030000003oon00oooP04<0oooP00@000000?ooh03oon0000009P3o
on0N0?[`iP40oooo000M0?[`iR<0oooP0P0000150?ooh08000002P3oon03000004@0oooP0P000016
0?ooh08000002P3oon03000004@0oooP0P0000160?ooh08000002P3oon03000004@0oooP0P00000W
0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0
oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3o
on3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`
i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`00
7@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`iQP0oooPo`00003Z000001/0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon00
0`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<000000?ooh03oon002@3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?oo
h0030000003oon00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?oo
h0030000003oon00oooP00T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04X0
oooP00<000000?ooh03oon00B`3oon000`000000oooP0?ooh01:0?ooh0030000003oon00oooP04/0
oooP00<000000?ooh03oon00BP3oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh>H0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon38
0?ooh1<000002`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh03o0?ooh;T0oooP8`00000:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0<00000o`3oon2_0?ooh18000006P000?l00`000000oooP0?ooh0060?ooh0<0
00006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2W0?ooh1800000
20000?lJ000000/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00o`3oon2P0?ooh10000002@000?lA00000140cHDo2`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh9X0oooP3000000:
0000o`/00000803=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP0?l0oooPU03oon0:000000P0003o2`00000Z0<f5?`/0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon2?0?ooh0T0
00001P000?l;00000380cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V
603oon000`000000oooP0?ooh03o0?ooh8X0oooP1`0000070000o`X00000>@3=QCl;0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPQP3o
on06000000D0003o2`00000o0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00o`3oon210?ooh0L0000010000?l:000004D0cHDo2`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?oo
h7d0oooP1`0000040000o`T00000BP3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPN@3oon07000000@0003o2000001?0<f5?`/0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon1e0?ooh0L0000010000?l7000005@0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh740oooP1`0000040000o`L00000F03=
QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPKP3oon06000000@0003o1`00001L0<f5?`/0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1Z0?ooh0H0000010000?l70000
0600cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh6L0oooP1@0000040000o`L00000I03=QCl;0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000o`3oon1T0?ooh0@0000010000?l7000006P0cHDo
2@3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPH@3o
on04000000<0003o2000001[0<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M
0?[`iQP0oooP00<000000?ooh03oon00o`3oon1N0?ooh0@000000`000?l7000006l0cHDo2`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?oo
h5/0oooP100000030000o`L00000LP3=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPF03oon0500000080003o1`00001e0<f5?`/0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
o`3oon1E0?ooh0D000000`000?l6000007P0cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh580oooP1@0000030000o`H00000N`3=
QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP0?l0oooPC`3oon05000000<0003o1P00001n0<f5?`/0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00o`3oon1=0?ooh0@000000`000?l60000
0840cHDo2`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh03o0?ooh4X0oooP1@0000020000o`H00000Q03=QCl;0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP0?l0oooPB03oon04000000<0003o
1@0000270<f5?`/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon00o`3oon150?ooh0D000000P000?l5000008X0cHDo2`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh4<0oooP10000003
0000o`D00000S03=QCl;0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?oo
h0800000203oon000`000000oooP0?ooh03o0?ooh400oooP100000030000o`D00000S`3=QCl;0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP0000
00L0oooP00<000000?ooh03oon00o`3oon0n0?ooh0@000000P000?l500000980cHDo2`3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?oo
h0@00000203oon3o000003H000000`000?nI000000P0oooP1000000K0?ooh1h0n_3V0@3oool001d0
n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooPo`0cXLX`03>Q
bP@000000P000?l500000:80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0
oooP00@000000?ooh03oon0000001`3oon000`000000oooP0?ooh0090?ooh?l0<j7:;@0cXLX50000
0080003o1@00002T0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh080
0000203oon000`000000oooP0?ooh0090?ooh?l0<j7::`0cXLX500000080003o1000002W0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
o`0cXLXY03>QbPD000000P000?l400000:T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbRL0<j7:100000030000o`@00000Z`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh?l0<j7:900cXLX500000080003o1000002^0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLXR03>QbPD000000P000?l40000
0;00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon3o03>QbR00<j7:1@0000020000o`@00000/P3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:7P0cXLX500000080003o
0`00002e0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPo`0cXLXL03>QbPD000000P000?l300000;L0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbQX0<j7:1@000002
0000o`<00000^@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh?l0<j7:600cXLX500000080003o0`00002k0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLXF03>QbPD0
00000P000?l300000;d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon3o03>QbQ@0<j7:1@0000020000o`<00000_`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:4P0c
XLX500000080003o0`0000310?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0<000002@3oon3o03>QbQ00<j7:1@0000020000o`<00000`@3oon03000001/0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLX>03>QbPD000000P000?l30000
0<D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon3o03>QbP`0<j7:1@0000020000o`800000b03oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?l0<j7:2P0cXLX500000080003o
0`0000390?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPo`0cXLX803>QbPD000000P000?l300000</0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3o03>QbPH0<j7:1@000002
0000o`<00000c@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh?l0<j7:100cXLX500000080003o0`00003?0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPo`0cXLX303>QbP@0
00000P000?l300000=40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon3o03>QbP40<j7:100000020000o`<00000d`3oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?h0<j7:1000
00020000o`<00000e@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh?`0<j7:100000020000o`<00000e`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?/0<j7:0`0000020000
o`<00000f@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh?T0<j7:0`0000020000o`@00000fP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh?L0<j7:100000000`000?l00000
0000000200000=`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon3e03>QbP@000000P000?l300000=h0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3d03>QbP<000000P000?l3
00000>00oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?oo
h?80<j7:0`0000020000o`@00000g`3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooPl00cXLX4000000030000o`000000000000800000h`3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh>l0<j7:
0`0000020000o`<00000i@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh>d0<j7:0`0000020000o`<00000i`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh>/0<j7:10000000
0`000?l000000000000200000>P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon3Z03>QbP<000000P000?l300000>X0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3X03>QbP<0
00000P000?l300000>`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon3V03>QbP<000000P000?l400000>d0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3U03>QbP<0000000<0
003o0000000000000P00003_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooPh`0cXLX300000080003o0`00003a0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPh@0cXLX40000
00030000o`000000000000800000lP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh>00<j7:0`0000020000o`<00000m03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh=h0<j7:
0`0000020000o`@00000m@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh=d0<j7:0`0000000`000?l000000000000200000?L0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon3K
03>QbP<000000P000?l300000?T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon3J03>QbP<0000000<0003o0000000000000P00003j0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<000002@3oon3H03>QbP<0
00000P000?l300000?X0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh=L0<j7:0P0000020000o`@00000o@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh=D0<j7:0`0000000`000?l000000000
000200000?l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon3D03>QbP8000000P000?l400000?l0oooP0@3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh=80<j7:0`0000000`00
0?l000000000000200000?l0oooP0`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh=40<j7:0P0000020000o`<00000o`3oon050?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
c`0cXLX3000000030000o`000000000000800000o`3oon060?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPcP0cXLX3000000040000o`00
0000000000000?l0oooP203oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh<`0<j7:0`0000020000o`<00000o`3oon090?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPb`0cXLX3
000000030000o`000000000000800000o`3oon0:0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPb@0cXLX4000000040000o`0000000000
00000?l0oooP303oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh<P0<j7:0`0000020000o`<00000o`3oon0=0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPa`0cXLX300000004
0000o`000000000000000?l0oooP3`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh<D0<j7:1000000010000?l0000000000000003o0?oo
h100oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP100000070?ooh003
0000003oon00oooP00T0oooPa00cXLX300000080003o0P00003o0?ooh180oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPd0oooP00<000000?ooh03oon00203oon000`000000oooP
0?ooh0090?ooh<80<j7:1000000010000?l0000000000000003o0?ooh1<0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iPh0oooP00<000000?ooh03oon001`3oon04000000P0oooP
`@0cXLX4000000030000o`00000000000?l0oooP4P3oon04000001/0oooP7P3jl>H10?ooo`007@3j
l>H?0?ooh0030000003oon00oooP00H0oooP00<000000?ooh03oon002@3oon3003>QbP<000000P00
0?l200000?l0oooP5P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon00
10000000oooP0?ooh00000070?ooh0030000003oon00oooP00T0oooP_P0cXLX4000000040000o`00
0000000000000?l0oooP5`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3o
on02000000P0oooP00<000000?ooh03oon002@3oon2m03>QbP<000000P000?l200000?l0oooP6@3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh;/0<j7:1000000010000?l0000000000000003o0?ooh1X0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2j03>QbP@0000000@0003o
0000000000000000o`3oon0K0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP^@0cXLX300000080003o0P00003o0?ooh1d0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2g03>Q
bP@0000000@0003o0000000000000000o`3oon0N0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP]P0cXLX300000080003o0P00003o0?oo
h200oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2e03>QbP<0000000@0003o0000000000000000o`3oon0Q0?ooh0030000003oon00oooP
01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP/`0cXLX300000080
003o0`00003o0?ooh280oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon2b03>QbP<0000000@0003o0000000000000000o`3oon0T0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
/@0cXLX3000000040000o`000000000000000?l0oooP9@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh;00<j7:0P0000020000o`<00000
o`3oon0V0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP[P0cXLX3000000040000o`000000000000000?l0oooP:03oon000`000000oooP
0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:d0<j7:0P00
00020000o`<00000o`3oon0Y0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0<000002@3oon2/03>QbP80000000<0003o0000000000000P00003o0?ooh2P0oooP0`00000K
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:/0<j7:0P0000001000
0?l0000000000000003o0?ooh2`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon2Y03>QbP8000000P000?l300000?l0oooP;@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:P0
<j7:0P0000000`000?l000000000000200000?l0oooP;P3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh:L0<j7:0P00000010000?l00000
00000000003o0?ooh300oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon2U03>QbP<0000000@0003o0000000000000000o`3oon0a0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
Y00cXLX200000080003o0`00003o0?ooh380oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2S03>QbP80000000<0003o0000000000000P00
003o0?ooh3<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon2Q03>QbP<0000000@0003o0000000000000000o`3oon0e0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPX00cXLX2
00000080003o0`00003o0?ooh3H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon2O03>QbP80000000<0003o0000000000000P00003o0?oo
h3L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon2N03>QbP80000000<0003o0000000000000P00003o0?ooh3P0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2M03>QbP800000
00@0003o0000000000000000o`3oon0j0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooPV`0cXLX200000080003o0`00003o0?ooh3/0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on2J03>QbP80000000<0003o0000000000000P00003o0?ooh3`0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2I03>QbP80000000<0003o
0000000000000P00003o0?ooh3d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP0`0000090?ooh9P0<j7:0P00000010000?l0000000000000003o0?ooh3d0oooP0`00000K
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh9L0<j7:0P0000001000
0?l0000000000000003o0?ooh400oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon2E03>QbP<0000000@0003o0000000000000000o`3oon11
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooPU00cXLX200000080003o0`00003o0?ooh480oooP00<000000?ooh03oon006@3oon0N0?[`
iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon2C03>QbP80000000<0003o00000000
00000P00003o0?ooh4<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon2B03>QbP80000000@0003o0000000000000000o`3oon150?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
T@0cXLX2000000040000o`000000000000000?l0oooPAP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh8l0<j7:0`00000010000?l00000
00000000003o0?ooh4L0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon2>03>QbP<0000000@0003o0000000000000000o`3oon180?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
S@0cXLX3000000040000o`000000000000000?l0oooPB@3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh8`0<j7:0`0000000`000?l00000
0000003o0?ooh4/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon2;03>QbP<0000000<0003o000000000000o`3oon1<0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPRP0cXLX2
00000080003o0P00003o0?ooh4d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon2803>QbP<0000000@0003o0000000000000000o`3oon1>
0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP
00T0oooPQ`0cXLX3000000040000o`000000000000000?l0oooPC`3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh8H0<j7:0`0000001000
0?l0000000000000003o0?ooh500oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP0`0000090?ooh8D0<j7:0`0000000`000?l000000000003o0?ooh500oooP0`00000K0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh8@0<j7:0`0000000`000?l0
00000000003o0?ooh5<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon2303>QbP<0000000<0003o000000000000o`3oon1D0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPPP0c
XLX3000000030000o`00000000000?l0oooPE@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh800<j7:100000000`000?l000000000003o
0?ooh5H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?oo
h03oon002@3oon1o03>QbP<000000P000?l200000?l0oooPE`3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh7h0<j7:0`00000010000?l0
000000000000003o0?ooh5P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon1m03>QbP<0000000@0003o0000000000000000o`3oon1I0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooPO00cXLX3000000030000o`00000000000?l0oooPF`3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh7/0<j7:0`0000000`000?l00000
0000003o0?ooh5`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon1j03>QbP<0000000<0003o000000000000o`3oon1M0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPN@0cXLX3
000000030000o`00000000000?l0oooPGP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh7P0<j7:0`0000000`000?l000000000003o0?oo
h5l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon1g03>QbP<0000000<0003o000000000000o`3oon1P0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>H?0?ooh0<000001P3oon000`000000oooP0?ooh0090?ooh7H0<j7:
0P0000020000o`800000o`3oon1Q0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H@0?ooh0030000003oon00oooP00D0oooP00<000000?ooh03oon002@3oon1d03>QbP<0000000@0
003o0000000000000000o`3oon1R0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>H=0?ooh0D000001P3oon04000000P0oooPL`0cXLX3000000040000o`000000000000000?l0oooP
H03oon04000001/0oooP7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP
00<000000?ooh03oon002@3oon1b03>QbP<0000000@0003o0000000000000000o`3oon1T0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000003oon00000000L0oooP
00<000000?ooh03oon002@3oon1a03>QbP<0000000<0003o000000000000o`3oon1V0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H?0?ooh08000001`3oon000`000000oooP0?oo
h0090?ooh700<j7:0`0000000`000?l000000000003o0?ooh6L0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1_03>QbP<0000000<0003o
000000000000o`3oon1X0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooPKP0cXLX3000000030000o`00000000000?l0oooPJ@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh6d0
<j7:0`0000000`000?l000000000003o0?ooh6X0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1/03>QbP<0000000<0003o000000000000
o`3oon1[0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPJ`0cXLX3000000030000o`00000000000?l0oooPK03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh6X0<j7:0`000000
0`000?l000000000003o0?ooh6d0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon1Y03>QbP<0000000<0003o000000000000o`3oon1^0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooPJ00cXLX200000080003o0P00003o0?ooh6l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1W03>QbP80000000@0003o000000000000
0000o`3oon1`0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000
003oon00oooP00T0oooPIP0cXLX2000000040000o`000000000000000?l0oooPL@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh6D0<j7:
0P00000010000?l0000000000000003o0?ooh780oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1S03>QbP<0000000@0003o000000000000
0000o`3oon1c0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0<00000
2@3oon1R03>QbP<0000000@0003o0000000000000000o`3oon1b0?ooh0<000006`3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1Q03>QbP<0000000<0003o000000000000
o`3oon1f0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPH00cXLX3000000030000o`00000000000?l0oooPM`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh5l0<j7:0`000000
0`000?l000000000003o0?ooh7P0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon1N03>QbP<0000000<0003o000000000000o`3oon1i0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooPG@0cXLX3000000030000o`00000000000?l0oooPNP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh5`0<j7:0`0000000`000?l00000
0000003o0?ooh7/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon1K03>QbP<0000000<0003o000000000000o`3oon1l0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPFP0cXLX3
000000030000o`00000000000?l0oooPO@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh5T0<j7:0`0000000`000?l000000000003o0?oo
h7h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon1H03>QbP<0000000<0003o000000000000o`3oon1o0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPE`0cXLX3000000030000
o`00000000000?l0oooPP03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh5H0<j7:0`0000000`000?l000000000003o0?ooh840oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1E
03>QbP<0000000<0003o000000000000o`3oon220?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPE00cXLX3000000030000o`0000000000
0?l0oooPP`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh5<0<j7:0`0000000`000?l000000000003o0?ooh8@0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP0`0000090?ooh580<j7:0`0000000`000?l00000
0000003o0?ooh8<0oooP0`00000K0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh580<j7:0P0000000`000?l000000000003o0?ooh8H0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1@03>QbP<0000000<0003o
000000000000o`3oon270?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooPC`0cXLX3000000030000o`00000000000?l0oooPR03oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh4h0
<j7:0`0000000`000?l000000000003o0?ooh8T0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon1=03>QbP<0000000<0003o000000000000
o`3oon2:0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooPC@0cXLX2000000030000o`00000000000?l0oooPR`3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh4`0<j7:0P000000
0`000?l000000000003o0?ooh8`0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP00<000000?ooh03oon002@3oon1;03>QbP80000000<0003o000000000000o`3oon2=0?oo
h0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0
oooPBP0cXLX2000000030000o`00000000000?l0oooPSP3oon000`000000oooP0?ooh00I0?ooh1h0
n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh4T0<j7:0P0000000`000?l00000
0000003o0?ooh8l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<0
00000?ooh03oon002@3oon1803>QbP80000000<0003o000000000000o`3oon2@0?ooh0030000003o
on00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPA`0cXLX2
000000030000o`00000000000?l0oooPT@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool0
01d0n_3V603oon000`000000oooP0?ooh0090?ooh4H0<j7:0P0000000`000?l000000000003o0?oo
h980oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03o
on002@3oon1503>QbP80000000<0003o000000000000o`3oon2C0?ooh0030000003oon00oooP01T0
oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooPA00cXLX2000000030000
o`00000000000?l0oooPU03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on03000000T0oooP@`0cXLX2000000040000o`000000000000000?l0oooPTP3oon03000001/0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP@P0cXLX2000000040000o`00
0000000000000?l0oooPU@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603o
on000`000000oooP0?ooh0090?ooh440<j7:0P00000010000?l0000000000000003o0?ooh9H0oooP
00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3o
on1003>QbP<0000000<0003o000000000000o`3oon2G0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP?`0cXLX3000000030000o`000000
00000?l0oooPV03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`00
0000oooP0?ooh0090?ooh3h0<j7:0`0000000`000?l000000000003o0?ooh9T0oooP00<000000?oo
h03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0m03>QbP<0
000000<0003o000000000000o`3oon2J0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`00
7@3jl>HH0?ooh0030000003oon00oooP00T0oooP?00cXLX3000000030000o`00000000000?l0oooP
V`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?oo
h0090?ooh3/0<j7:0`0000000`000?l000000000003o0?ooh9`0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0j03>QbP<0000000<0003o
000000000000o`3oon2M0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?oo
h0030000003oon00oooP00T0oooP>@0cXLX3000000030000o`00000000000?l0oooPWP3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh3T0
<j7:0P0000000`000?l000000000003o0?ooh9l0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0h03>QbP80000000<0003o000000000000
o`3oon2P0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP=`0cXLX2000000030000o`00000000000?l0oooPX@3oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon03000000P0oooP00<000000?ooh03oon002@3oon0f
03>QbP80000000@0003o0000000000000000o`3oon2Q0?ooh0030000003oon00oooP01T0oooP7P3j
l>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP00<000000?ooh03oon002@3o
on0e03>QbP80000000@0003o0000000000000000o`3oon2R0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>H=0?ooh0040000003oon00oooP000000L0oooP100000080?ooh3@0<j7:
0P00000010000?l0000000000000003o0?ooh:00oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V
3@3oon03000000P0oooP00<000000?ooh03oon002@3oon0c03>QbP80000000@0003o000000000000
0000o`3oon2T0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0030000
003oon00oooP00L0oooP00<000000?ooh03oon002@3oon0b03>QbP<0000000<0003o000000000000
o`3oon2U0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>H>0?ooh0<000001`3o
on000`000000oooP0?ooh0090?ooh340<j7:0`0000000`000?l000000000003o0?ooh:H0oooP00<0
00000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0`
03>QbP<0000000<0003o000000000000o`3oon2W0?ooh0030000003oon00oooP01T0oooP7P3jl>H1
0?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP;`0cXLX3000000030000o`0000000000
0?l0oooPZ03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000
oooP0?ooh0090?ooh2h0<j7:0`0000000`000?l000000000003o0?ooh:T0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0^03>QbP800000
00<0003o000000000000o`3oon2Z0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP;@0cXLX2000000030000o`00000000000?l0oooPZ`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh2`0<j7:0P0000000`000?l000000000003o0?ooh:`0oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0[03>QbP80000000<0003o0000
00000000o`3oon2]0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP:P0cXLX2000000040000o`000000000000000?l0oooP[@3oon000`00
0000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh2T0
<j7:0`0000000`000?l000000000003o0?ooh:h0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0X03>QbP<0000000<0003o000000000000
o`3oon2_0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP9`0cXLX3000000030000o`00000000000?l0oooP/03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh2H0<j7:0`000000
0`000?l000000000003o0?ooh;40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iQP0oooP0`0000090?ooh2H0<j7:0P0000000`000?l000000000003o0?ooh;00oooP0`00000K0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh2D0<j7:0P0000000`000?l0
00000000003o0?ooh;<0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP
00<000000?ooh03oon002@3oon0T03>QbP80000000<0003o000000000000o`3oon2d0?ooh0030000
003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP8`0c
XLX2000000030000o`00000000000?l0oooP]@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh280<j7:0P00000010000?l0000000000000
003o0?ooh;D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0Q03>QbP<0000000<0003o000000000000o`3oon2f0?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP800cXLX30000
00030000o`00000000000?l0oooP]`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh200<j7:0P0000000`000?l000000000003o0?ooh;P0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon0O03>QbP80000000<0003o000000000000o`3oon2i0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP7P0cXLX2000000030000o`00
000000000?l0oooP^P3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh1d0<j7:0P0000000`000?l000000000003o0?ooh;/0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0L03>Q
bP<0000000<0003o0000003oon00o`3oon2k0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP6`0cXLX3000000030000o`00000000000?l0
oooP_03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP
0?ooh0090?ooh1X0<j7:0`0000000`000?l000000000003o0?ooh;d0oooP00<000000?ooh03oon00
6@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0I03>QbP<0000000<0
003o000000000000o`3oon2n0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH
0?ooh0030000003oon00oooP00T0oooP6@0cXLX2000000030000o`00000000000?l0oooP_`3oon00
0`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon03000000T0oooP600cXLX20000
00030000o`00000000000?l0oooP_P3oon03000001/0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP5`0cXLX3000000030000o`000000oooP0?l0oooP`03oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh1H0<j7:
0`0000000`000?l000000?ooh03o0?ooh<40oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0E03>QbP<0000000<0003o000000000000o`3o
on320?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP500cXLX3000000030000o`00000000000?l0oooP``3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh1@0<j7:0P0000000`00
0?l000000000003o0?ooh<@0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon0C03>QbP80000000<0003o000000000000o`3oon350?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
4P0cXLX3000000030000o`000000oooP0?l0oooPa@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V
0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh140<j7:0`0000000`000?l000000?oo
h03o0?ooh<H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<00000
0?ooh03oon002@3oon0@03>QbP<0000000<0003o000000000000o`3oon370?ooh0030000003oon00
oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP3`0cXLX30000
00030000o`00000000000?l0oooPb03oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0
n_3V603oon000`000000oooP0?ooh0090?ooh0h0<j7:0`0000000`000?l000000000003o0?ooh<T0
oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon00
2@3oon0=03>QbP<0000000<0003o000000000000o`3oon3:0?ooh0030000003oon00oooP01T0oooP
7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP3@0cXLX3000000030000o`00
0000oooP0?l0oooPbP3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon00
0`000000oooP0?ooh0090?ooh0`0<j7:0`0000000`000?l000000?ooh03o0?ooh</0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0;03>Q
bP<0000000<0003o000000000000o`3oon3<0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?oo
o`007@3jl>HH0?ooh0<000002@3oon0:03>QbP<0000000<0003o000000000000o`3oon3;0?ooh0<0
00006`3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0903>QbP<00000
00<0003o000000000000o`3oon3>0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3j
l>HH0?ooh0030000003oon00oooP00T0oooP2@0cXLX2000000030000o`00000000000?l0oooPc`3o
on000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh009
0?ooh0P0<j7:0P0000000`000?l000000000003o0?ooh=00oooP00<000000?ooh03oon006@3oon0N
0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0703>QbP80000000<0003o0000
00000000o`3oon3A0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh003
0000003oon00oooP00T0oooP1P0cXLX3000000030000o`00000000000?l0oooPd@3oon000`000000
oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0D0<j7:
0`0000000`000?l000000000003o0?ooh=80oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo
000M0?[`iQP0oooP00<000000?ooh03oon002@3oon0503>QbP80000000<0003o000000000000o`3o
on3C0?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00
oooP00T0oooP100cXLX2000000030000o`00000000000?l0oooPe03oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0<0<j7:0P0000000`00
0?l000000000003o0?ooh=D0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0
oooP00<000000?ooh03oon002@3oon0203>QbP80000000<0003o000000000000o`3oon3F0?ooh003
0000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003oon00oooP00T0oooP
00@0<j7:000000000000003o0`00003o0?ooh=H0oooP00<000000?ooh03oon006@3oon0N0?[`iP40
oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon03000000030000o`00000000000?l0oooP
e`3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02000000P0oooP00<0
00000?ooh03oon002@3oon02000000030000o`00000000000?l0oooPf03oon000`000000oooP0?oo
h00I0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003o
on00oooP00P0oooP0P0000000`000?l000000000003o0?ooh=T0oooP00<000000?ooh03oon006@3o
on0N0?[`iP40oooo000M0?[`iPd0oooP00@000000?ooh03oon0000001`3oon04000000H0oooP0P00
00000`000?l000000000003o0?ooh=L0oooP1000000K0?ooh1h0n_3V0@3oool001d0n_3V3P3oon02
000000P0oooP00<000000?ooh03oon001`3oon0500000?l0oooPfP3oon000`000000oooP0?ooh00I
0?ooh1h0n_3V0@3oool001d0n_3V3@3oon0010000000oooP0?ooh00000070?ooh0030000003oon00
oooP00P0oooP0`00003o0?ooh=/0oooP00<000000?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`
iPh0oooP0P0000080?ooh0030000003oon00oooP0?l0oooPiP3oon000`000000oooP0?ooh00I0?oo
h1h0n_3V0@3oool001d0n_3V603oon000`000000oooP0?ooh03o0?ooh>H0oooP00<000000?ooh03o
on006@3oon0N0?[`iP40oooo000M0?[`iQP0oooP00<000000?ooh03oon002@3oon000`000000oooP
0?ooh01:0?ooh0030000003oon00oooP04X0oooP00<000000?ooh03oon00B`3oon000`000000oooP
0?ooh01:0?ooh0030000003oon00oooP04/0oooP00<000000?ooh03oon00BP3oon000`000000oooP
0?ooh0090?ooh0030000003oon00oooP01T0oooP7P3jl>H10?ooo`007@3jl>HH0?ooh0030000003o
on00oooP00T0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003o
on00oooP00`0oooP00<000000?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon00303oon000`000000oooP0?ooh00<0?ooh0030000003o
on00oooP00d0oooP00<000000?ooh03oon002@3oon000`000000oooP0?ooh00I0?ooh1h0n_3V0@3o
ool001d0n_3V603oon000`000000oooP0?ooh0090?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon003@3oon000`000000oooP0?ooh00<0?ooh0030000003oon00oooP00d0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00`0oooP00<00000
0?ooh03oon00303oon000`000000oooP0?ooh00=0?ooh0030000003oon00oooP00T0oooP00<00000
0?ooh03oon006@3oon0N0?[`iP40oooo000M0?[`iQP0oooPo`00003Z000001/0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N
0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0
oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3o
on0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?oo
h?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3V
o`3oon3o0?ooh1h0oooP7P3jl>H10?ooo`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M
0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V0@3oool001d0n_3Vo`3oon3o0?ooh1h0oooP7P3jl>H10?oo
o`007@3jl>Ko0?ooh?l0oooP7P3oon0N0?[`iP40oooo000M0?[`i_l0oooPo`3oon0N0?ooh1h0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003A0?[`iP@000000P3jl>H80000
0080n_3V100000001`3jl>H00000000000000000n_3V0000003jl>H0300000000`3jl>H000000000
0004000000040?[`iP0000000000000000P0n_3V1@0000040?[`iPL0000000<0n_3V0000003jl>H0
0`0000080?[`iPD000000P3jl>H400000080n_3V1@00000<0?[`iP<000004@3jl>H3000000H0n_3V
0`000000103jl>H000000000000000060?[`iP030000003jl>H0n_3V00@0n_3V0`000000103jl>H0
000000000000003H0?[`iP40oooo003B0?[`iP8000000P3jl>H2000000<0n_3V0P0000030?[`iP80
00000`3jl>H01`000000n_3V000000000000n_3V0000003jl>H0100000020?[`iP8000000P3jl>H2
000000030?[`iP00000000000080n_3V0P0000000`3jl>H00000000000090?[`iP040000003jl>H0
n_3V0?[`iP8000000P3jl>H2000000040?[`iP00000000000?[`iP80000000<0n_3V0000003jl>H0
0P00000:0?[`iP8000000`3jl>H200000080n_3V0P0000020?[`iP8000003@3jl>H2000000030?[`
iP000000000000l0n_3V0P0000000`3jl>H00000000000060?[`iP80000000<0n_3V000000000000
1`3jl>H00`000000n_3V0?[`iP050?[`iP80000000<0n_3V000000000000f@3jl>H10?ooo`00dP3j
l>H2000000030?[`iP000000000000@0n_3V0P0000030?[`iP8000001@3jl>H2000000030?[`iP00
0000n_3V00@000000P3jl>H200000080n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0
n_3V0000000000003@3jl>H200000080n_3V0P000000103jl>H000000000003jl>H2000000030?[`
iP000000n_3V008000002P3jl>H2000000<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V
0P0000000`3jl>H00000000000050?[`iPD000001@3jl>H2000000030?[`iP000000000000L0n_3V
0`0000060?[`iPD000001P3jl>H300000=X0n_3V0@3oool00=80n_3V1@0000040?[`iP8000000`3j
l>H6000000060?[`iP00000000000?[`iP000000n_3V0P0000000`3jl>H000000000000300000080
n_3V0P0000000`3jl>H00000000000020?[`iP80000000<0n_3V0000000000002`3jl>H3000000<0
n_3V0P000000103jl>H000000000003jl>H2000000030?[`iP000000n_3V008000002P3jl>H20000
00<0n_3V0P0000020?[`iP8000000P3jl>H2000000d0n_3V0P0000000`3jl>H000000000000?0?[`
iP80000000<0n_3V0000000000001`3jl>H3000000P0n_3V00<000000?[`iP3jl>H01P3jl>H30000
0=X0n_3V0@3oool00=80n_3V0P0000020?[`iP8000000`3jl>H2000000<0n_3V0P0000020?[`iP80
000000H0n_3V000000000000n_3V0000003jl>H2000000@0n_3V0P0000020?[`iP80000000<0n_3V
0000000000000P3jl>H2000000030?[`iP000000000000X0n_3V0`0000040?[`iP80000000@0n_3V
000000000000n_3V0P0000000`3jl>H000000?[`iP02000000X0n_3V0P0000030?[`iP8000000P3j
l>H200000080n_3V0`0000000`3jl>H000000?[`iP0:0?[`iP<00000403jl>H4000000L0n_3V0P00
00000`3jl>H00000000000070?[`iP030000003jl>H0n_3V00D0n_3V0P0000000`3jl>H000000000
003I0?[`iP40oooo003B0?[`iP8000000P3jl>H2000000030?[`iP000000000000800000103jl>H4
000000030?[`iP000000000000D000000P3jl>H400000080n_3V1@0000020?[`iPD000002P3jl>H2
000000D0n_3V0`0000000`3jl>H0000000000007000000X0n_3V1@0000020?[`iP@000000P3jl>H3
000000030?[`iP000000000000X0n_3V0P0000000`3jl>H000000000000?0?[`iP800000203jl>H3
000000040?[`iP0000000000000000d0n_3V0`0000000`3jl>H000000000000500000=@0n_3V0@3o
ool00=80n_3V0P0000020?[`iP800000<`3jl>H2000000<0n_3V00<000000?[`iP3jl>H05`3jl>H2
000001X0n_3V0P0000000`3jl>H000000000000@0?[`iP8000008`3jl>H00`000000n_3V0?[`iP3D
0?[`iP40oooo003A0?[`iPH00000103jl>H2000002l0n_3V1@00000J0?[`iP<000006@3jl>H30000
0180n_3V0`00000R0?[`iP030000003jl>H0n_3V0=<0n_3V0@3oool00?l0n_3VP`3jl>H00`000000
n_3V0?[`iP3B0?[`iP40oooo003o0?[`iX00n_3V00@000000?[`iP3jl>H00000e03jl>H10?ooo`00
o`3jl>J10?[`iP800000e@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V
0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`
iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3j
l>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?oo
o`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3j
l>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o0?[`i_l0
n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40oooo003o
0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II0?[`iP40
oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3Vo`3jl>II
0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool00?l0n_3V
o`3jl>II0?[`iP40oooo003o0?[`i_l0n_3VF@3jl>H10?ooo`00o`3jl>Ko0?[`iUT0n_3V0@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 599}, {539, 0}} -> {-0.000977654, 0.999955, \
0.0166978, 0.0166978}, {{30, 552.75}, {419.188, 102.875}} -> {-0.421857, \
-5.45735, 0.0064631, 0.0313725}}]
}, Closed]]
}, Open  ]],

Cell[BoxData[
    \(Clear[RiemannPartition, RiemannSumPlot]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowSize->{744, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 33, 0, 67, "Title"],
Cell[1790, 53, 73, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[1888, 58, 40, 0, 52, "Subsection"],
Cell[1931, 60, 114, 3, 29, "Text"],
Cell[2048, 65, 554, 9, 86, "Text"],

Cell[CellGroupData[{
Cell[2627, 78, 561, 12, 170, "Input"],
Cell[3191, 92, 368, 6, 44, "Message"],
Cell[3562, 100, 356, 5, 44, "Message"]
}, Open  ]],
Cell[3933, 108, 72, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[4030, 112, 58, 1, 50, "Input"],
Cell[4091, 115, 159, 2, 49, "Output"]
}, Open  ]],
Cell[4265, 120, 487, 8, 86, "Text"],
Cell[4755, 130, 418, 7, 67, "Text"],

Cell[CellGroupData[{
Cell[5198, 141, 4173, 70, 710, "Input"],
Cell[9374, 213, 362, 5, 44, "Message"]
}, Open  ]],
Cell[9751, 221, 300, 9, 48, "Text"],

Cell[CellGroupData[{
Cell[10076, 234, 82, 1, 50, "Input"],
Cell[10161, 237, 146111, 2914, 548, 28404, 1456, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[156287, 3154, 281, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[156593, 3163, 366, 7, 111, "Input"],

Cell[CellGroupData[{
Cell[156984, 3174, 83666, 1853, 548, 23737, 1107, "GraphicsData", \
"PostScript", "Graphics"],
Cell[240653, 5029, 92652, 1970, 548, 23688, 1113, "GraphicsData", \
"PostScript", "Graphics"],
Cell[333308, 7001, 91691, 1968, 548, 23878, 1126, "GraphicsData", \
"PostScript", "Graphics"],
Cell[425002, 8971, 95611, 2028, 548, 24043, 1139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[520616, 11001, 102914, 2139, 548, 24409, 1165, "GraphicsData", \
"PostScript", "Graphics"],
Cell[623533, 13142, 105433, 2192, 548, 24769, 1191, "GraphicsData", \
"PostScript", "Graphics"],
Cell[728969, 15336, 112515, 2312, 548, 25326, 1230, "GraphicsData", \
"PostScript", "Graphics"],
Cell[841487, 17650, 117198, 2402, 548, 25858, 1269, "GraphicsData", \
"PostScript", "Graphics"],
Cell[958688, 20054, 126285, 2568, 548, 26736, 1334, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1084976, 22624, 142313, 2820, 548, 27637, 1399, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1227292, 25446, 155057, 3064, 548, 29025, 1503, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1382352, 28512, 176291, 3422, 548, 30734, 1620, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1558646, 31936, 195065, 3784, 548, 32878, 1776, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1753714, 35722, 212548, 4171, 548, 35790, 1984, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1966265, 39895, 241801, 4749, 548, 39329, 2244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2208069, 44646, 252636, 5152, 548, 43854, 2569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2460708, 49800, 269283, 5713, 548, 49817, 2998, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2729994, 55515, 280736, 6306, 548, 57399, 3544, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3010733, 61823, 280305, 6884, 548, 67088, 4246, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3291041, 68709, 295355, 7825, 548, 79595, 5156, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3586399, 76536, 284130, 8644, 548, 95720, 6313, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3870532, 85182, 232611, 9248, 548, 116356, 7808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4103146, 94432, 214370, 10608, 548, 142770, 9719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4317519, 105042, 240528, 12968, 548, 176777, 12176, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4558050, 118012, 284772, 16121, 548, 220494, 15322, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4842825, 134135, 340519, 20173, 548, 276573, 19378, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5183347, 154310, 412567, 25376, 548, 348382, 24578, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5595917, 179688, 504668, 32044, 548, 440524, 31247, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6100588, 211734, 623666, 40611, 548, 559553, 39814, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[6724281, 252349, 113, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[6724419, 252356, 499, 9, 152, "Input"],
Cell[6724921, 252367, 135, 2, 49, "Output"],
Cell[6725059, 252371, 116, 2, 49, "Output"],

Cell[CellGroupData[{
Cell[6725200, 252377, 89412, 1969, 548, 24459, 1164, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6814615, 254348, 95807, 2059, 548, 24641, 1177, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6910425, 256409, 96539, 2090, 548, 24996, 1203, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7006967, 258501, 107869, 2251, 548, 25359, 1229, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7114839, 260754, 110912, 2321, 548, 25907, 1268, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7225754, 263077, 131579, 2684, 548, 27713, 1398, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7357336, 265763, 159509, 3137, 548, 29472, 1528, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7516848, 268902, 198946, 3839, 548, 33095, 1788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7715797, 272743, 231468, 4456, 548, 36668, 2048, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7947268, 277201, 263703, 5178, 548, 42063, 2438, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8210974, 282381, 297742, 6677, 548, 59991, 3738, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8508719, 289060, 311501, 7924, 548, 77995, 5038, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8820223, 296986, 267597, 9538, 548, 114009, 7638, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9087823, 306526, 214561, 11038, 548, 150069, 10238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9302387, 317566, 268821, 14946, 548, 203780, 14138, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9571211, 332514, 448136, 27935, 548, 383926, 27138, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10019350, 360451, 628194, 40943, 548, 563297, 40138, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[10647571, 401398, 72, 1, 50, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

